(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* https://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[  26938105,     456170]
NotebookOptionsPosition[  26934941,     456069]
NotebookOutlinePosition[  26935285,     456084]
CellTagsIndexPosition[  26935242,     456081]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Animated Riemann", "Title",
 CellChangeTimes->{{3.545582461709139*^9, 3.5455824639555426`*^9}, {
  3.545582568382126*^9, 3.545582589052162*^9}, {3.5456689287135954`*^9, 
  3.5456689295846453`*^9}, {3.5456691029681845`*^9, 3.5456691083352804`*^9}}],

Cell[TextData[{
 StyleBox["This ", "Text",
  FontSize->12,
  FontWeight->"Plain"],
 StyleBox["Mathematica", "Text",
  FontSize->12,
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[" notebook is an extension of the work in the notebook \
RiemannSums.nb posted in the ", "Text",
  FontSize->12,
  FontWeight->"Plain"],
 StyleBox[Cell[BoxData[
  TagBox[
   ButtonBox[
    PaneSelectorBox[{False->"\<\"Mathematica part\"\>", True->
     StyleBox["\<\"Mathematica part\"\>", "HyperlinkActive"]}, Dynamic[
      CurrentValue["MouseOver"]],
     BaseStyle->{"Hyperlink"},
     BaselinePosition->Baseline,
     FrameMargins->0,
     ImageSize->Automatic],
    BaseStyle->"Hyperlink",
    ButtonData->{
      URL["https://www.abstractmath.org/Mathematica/"], None},
    ButtonNote->"https://www.abstractmath.org/Mathematica/"],
   Annotation[#, "https://www.abstractmath.org/Mathematica/", "Hyperlink"]& ]],
   "Text",
  CellChangeTimes->{3.520283147145875*^9, 3.520283281833375*^9},
  FontSize->12,
  FontWeight->"Plain"], "Text"],
 StyleBox[" of abstractmath.org.  It is produced by and is licensed under a ",
   "Text",
  FontSize->12,
  FontWeight->"Plain"],
 StyleBox[Cell[BoxData[
  RowBox[{
   TagBox[
    ButtonBox[
     PaneSelectorBox[{
      False->"\<\"Creative Commons Attribution - ShareAlike 3.0 License\"\>", 
      True->
      StyleBox["\<\"Creative Commons Attribution - ShareAlike 3.0 \
License\"\>", "HyperlinkActive"]}, Dynamic[
       CurrentValue["MouseOver"]],
      BaseStyle->{"Hyperlink"},
      BaselinePosition->Baseline,
      FrameMargins->0,
      ImageSize->Automatic],
     BaseStyle->"Hyperlink",
     ButtonData->{
       URL["https://creativecommons.org/licenses/by-sa/3.0/"], None},
     ButtonNote->"https://creativecommons.org/licenses/by-sa/3.0/"],
    Annotation[#, "https://creativecommons.org/licenses/by-sa/3.0/", 
     "Hyperlink"]& ], " "}]], "Text",
  CellChangeTimes->{{3.516312542019249*^9, 3.5163126250020304`*^9}},
  FontSize->12,
  FontWeight->"Plain"], "Text"],
 StyleBox[", which makes it freely available for others to use, provided they \
refer to this file.",
  FontFamily->"Arial",
  FontSize->12,
  FontWeight->"Plain"]
}], "Section",
 CellChangeTimes->{{3.544957698041118*^9, 3.54495774269278*^9}, {
  3.545235279460657*^9, 3.5452352909734697`*^9}, {3.5452353490262346`*^9, 
  3.545235361585504*^9}, {3.545482142599247*^9, 3.545482189291918*^9}, {
  3.545482295747718*^9, 3.545482332731492*^9}, {3.5454823865360017`*^9, 
  3.5454823865560026`*^9}, {3.545482440915127*^9, 3.5454824488284235`*^9}, {
  3.545482504171817*^9, 3.5454825268099947`*^9}}],

Cell[CellGroupData[{

Cell["Riemann Package version 2", "Section",
 CellChangeTimes->{{3.482750361528*^9, 3.4827503673789997`*^9}, {
  3.516747323523302*^9, 3.516747329992052*^9}, {3.5455825520332975`*^9, 
  3.5455825655585213`*^9}}],

Cell[TextData[{
 "This package provides ",
 StyleBox["PlotRiemann",
  FontWeight->"Bold"],
 ", which shows Riemann sum of a given integral with various choices of \
parameters, and ",
 StyleBox["CloudList",
  FontWeight->"Bold"],
 ", which plots the values of a number of random Riemann sums of the given \
integral.  It is a work in progress. You are encouraged to improve this work \
and to use it in your own publications and coursework.  "
}], "Text",
 CellChangeTimes->{{3.516711469484375*^9, 3.51671156396875*^9}, {
   3.516722719273302*^9, 3.516722747304552*^9}, 3.516722867617052*^9, {
   3.516722994617052*^9, 3.516723043304552*^9}, {3.516749294945177*^9, 
   3.516749300492052*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"SetOptions", "[", 
    RowBox[{"Plot", ",", 
     RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}], ";"}], 
  " "}]], "Input",
 CellChangeTimes->{{3.482444309179576*^9, 3.4824443121965756`*^9}, {
  3.482445727166*^9, 3.482445727509*^9}, {3.516711607703125*^9, 
  3.516711615046875*^9}, {3.516747014101427*^9, 3.516747023351427*^9}, {
  3.516747150585802*^9, 3.516747154710802*^9}, {3.5452613545408597`*^9, 
  3.5452613571670103`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"PlotBounded", "[", 
   RowBox[{"expression_", ",", "range_", ",", "options___"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "g", ",", "f", ",", "left", ",", "right", ",", "newleft", ",", 
      "newright", ",", "var", ",", "leftheight", ",", "rightheight", ",", 
      "width", ",", "newrange"}], "}"}], ",", 
    RowBox[{
     RowBox[{"var", "=", 
      RowBox[{"range", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"f", "=", 
      RowBox[{"Function", "[", 
       RowBox[{
        RowBox[{"Release", "[", "var", "]"}], ",", "expression"}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"left", "=", 
      RowBox[{"range", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"right", "=", 
      RowBox[{"range", "[", 
       RowBox[{"[", "3", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"width", "=", 
      RowBox[{"right", "-", "left"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"leftheight", "=", 
      RowBox[{"f", "[", "left", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"rightheight", "=", 
      RowBox[{"f", "[", "right", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"newleft", "=", 
      RowBox[{"left", "-", 
       RowBox[{"0.25", "*", "width"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"newright", "=", 
      RowBox[{"right", "+", 
       RowBox[{"0.25", "*", "width"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"newrange", "=", 
      RowBox[{"{", 
       RowBox[{"var", ",", "newleft", ",", "newright"}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"g", ":=", 
      RowBox[{"Plot", "[", 
       RowBox[{"expression", ",", 
        RowBox[{"Release", "[", "newrange", "]"}], ",", 
        RowBox[{"DisplayFunction", "\[Rule]", "Identity"}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"RGBColor", "[", 
            RowBox[{"0", ",", "0", ",", "1"}], "]"}], "}"}], "}"}]}], ",", 
        "options"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Show", "[", 
      RowBox[{"g", ",", 
       RowBox[{"Graphics", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"left", ",", "0"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"left", ",", "leftheight"}], "}"}]}], "}"}], "]"}], ",", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"right", ",", "0"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"right", ",", "rightheight"}], "}"}]}], "}"}], "]"}]}], 
         "}"}], "]"}], ",", 
       RowBox[{"DisplayFunction", "\[Rule]", "$DisplayFunction"}]}], 
      "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.482444309179576*^9, 3.4824443121965756`*^9}, {
   3.482445727166*^9, 3.482445727509*^9}, {3.516711607703125*^9, 
   3.516711615046875*^9}, {3.516747014101427*^9, 3.516747023351427*^9}, 
   3.516747150585802*^9, 3.516747272304552*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"RandomPartition", "[", 
   RowBox[{"range_", ",", "mesh_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"u", "=", 
       RowBox[{"range", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ",", 
      RowBox[{"top", "=", 
       RowBox[{"range", "[", 
        RowBox[{"[", "3", "]"}], "]"}]}], ",", 
      RowBox[{"list", "=", 
       RowBox[{"{", 
        RowBox[{"range", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "}"}]}], ",", "v", ",", "newlist", 
      ",", 
      RowBox[{"actualmesh", "=", "0"}]}], "}"}], ",", 
    RowBox[{
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"u", "+", "mesh"}], "<", "top"}], ",", 
       RowBox[{
        RowBox[{"v", "=", 
         RowBox[{"u", "+", 
          RowBox[{"Random", "[", 
           RowBox[{"Real", ",", "mesh"}], "]"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"actualmesh", "=", 
         RowBox[{"Max", "[", 
          RowBox[{"actualmesh", ",", 
           RowBox[{"v", "-", "u"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"newlist", ":=", 
         RowBox[{"Append", "[", 
          RowBox[{"list", ",", "v"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"u", "=", "v"}], ";", "\[IndentingNewLine]", 
        RowBox[{"list", "=", "newlist"}]}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"partitionstring", "=", 
      RowBox[{"StringJoin", "[", 
       RowBox[{"\"\<Random partition with maximum norm \>\"", ",", 
        RowBox[{"ToString", "[", "mesh", "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"actualmesh", "=", 
      RowBox[{"Max", "[", 
       RowBox[{"actualmesh", ",", 
        RowBox[{"top", "-", 
         RowBox[{"Last", "[", "list", "]"}]}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Return", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Append", "[", 
         RowBox[{"list", ",", "top"}], "]"}], ",", "actualmesh"}], "}"}], 
      "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.482444309179576*^9, 3.4824443121965756`*^9}, {
   3.482445727166*^9, 3.482445727509*^9}, {3.516711607703125*^9, 
   3.516711615046875*^9}, {3.516747014101427*^9, 3.516747033304552*^9}, 
   3.516747166913927*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"UniformPartition", "[", 
   RowBox[{"range_", ",", "number_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"bottom", "=", 
       RowBox[{
        RowBox[{"range", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "//", "N"}]}], ",", 
      RowBox[{"top", "=", 
       RowBox[{
        RowBox[{"range", "[", 
         RowBox[{"[", "3", "]"}], "]"}], "//", "N"}]}], ",", "actualmesh"}], 
     "}"}], ",", 
    RowBox[{
     RowBox[{"actualmesh", "=", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"top", "-", "bottom"}], ")"}], "/", "number"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"partitionstring", "=", 
      RowBox[{"StringJoin", "[", 
       RowBox[{"\"\<Uniform partition into \>\"", ",", 
        RowBox[{"ToString", "[", "number", "]"}], ",", 
        "\"\< subintervals\>\""}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Return", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"N", "[", 
         RowBox[{"Range", "[", 
          RowBox[{"bottom", ",", "top", ",", "actualmesh"}], "]"}], "]"}], 
        ",", "actualmesh"}], "}"}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.482444309179576*^9, 3.4824443121965756`*^9}, {
  3.482445727166*^9, 3.482445727509*^9}, {3.516711607703125*^9, 
  3.516711615046875*^9}, {3.516747014101427*^9, 3.516747033304552*^9}, {
  3.516747166913927*^9, 3.516747168398302*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Slices", "[", 
   RowBox[{
   "expression_", ",", "variable_", ",", "list_", ",", "options___Rule"}], 
   "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"i", "=", "1"}], ",", 
      RowBox[{"startlist", "=", "list"}], ",", "leftlist", ",", "rightlist", 
      ",", "widthlist", ",", "selectlist", ",", "arealist", ",", "heightlist",
       ",", "valuelist", ",", 
      RowBox[{"opt", "=", 
       RowBox[{
        RowBox[{"Height", "/.", 
         RowBox[{"{", "options", "}"}]}], "/.", 
        RowBox[{"Options", "[", "RiemannData", "]"}]}]}], ",", 
      RowBox[{"f", "=", 
       RowBox[{"Function", "[", 
        RowBox[{"variable", ",", "expression"}], "]"}]}]}], "}"}], ",", 
    RowBox[{
     RowBox[{"leftlist", "=", 
      RowBox[{"Drop", "[", 
       RowBox[{"list", ",", 
        RowBox[{"-", "1"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"rightlist", "=", 
      RowBox[{"Drop", "[", 
       RowBox[{"list", ",", "1"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"widthlist", "=", 
      RowBox[{"rightlist", "-", "leftlist"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"selectlist", "=", 
      RowBox[{"Switch", "[", 
       RowBox[{"opt", ",", "LeftSide", ",", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
          "heightstring", "=", 
           "\"\<Left edge of subinterval used for height\>\""}], ";", 
          "leftlist"}], ")"}], ",", "RightSide", ",", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
          "heightstring", "=", 
           "\"\<Right edge of subinterval used for height\>\""}], ";", 
          "rightlist"}], ")"}], ",", "Midpoint", ",", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
          "heightstring", "=", 
           "\"\<Midpoint of subinterval used for height\>\""}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"leftlist", "+", 
           RowBox[{"0.5", "*", "widthlist"}]}]}], ")"}], ",", "Random", ",", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
          "heightstring", "=", 
           "\"\<Random point in subinterval used for height\>\""}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"leftlist", "+", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"Random", "[", 
               RowBox[{"Real", ",", "#"}], "]"}], "&"}], "/@", "widthlist"}], 
            ")"}]}]}], ")"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"heightlist", "=", 
      RowBox[{"f", "/@", "selectlist"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"arealist", "=", 
      RowBox[{"heightlist", "*", "widthlist"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"heightlist", ",", "arealist"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.482444309179576*^9, 3.4824443121965756`*^9}, {
   3.482445727166*^9, 3.482445727509*^9}, {3.516711607703125*^9, 
   3.516711615046875*^9}, {3.516747014101427*^9, 3.516747033304552*^9}, {
   3.516747166913927*^9, 3.516747168398302*^9}, 3.516747266617052*^9}],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"Boxx", "::", "usage"}], "=", 
   "\"\<Boxx[bottom, top, left, right]\nproduces a series of Line statements \
which in a\nGraphics object will draw a hollow rectangle with\nthe corners \
given.  (Note that the built in\ncommand Rectangle draws a solid \
rectangle.)\>\""}], "*)"}]], "Input",
 CellChangeTimes->{{3.482444309179576*^9, 3.4824443121965756`*^9}, {
  3.482445727166*^9, 3.482445727509*^9}, {3.516711607703125*^9, 
  3.516711615046875*^9}, {3.516747014101427*^9, 3.516747041601427*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Boxx", "[", 
   RowBox[{"bottom_", ",", "top_", ",", "left_", ",", "right_"}], "]"}], ":=", 
  RowBox[{"Line", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"left", ",", "bottom"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"right", ",", "bottom"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"right", ",", "top"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"left", ",", "top"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"left", ",", "bottom"}], "}"}]}], "}"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.482444309179576*^9, 3.4824443121965756`*^9}, {
  3.482445727166*^9, 3.482445727509*^9}, {3.516711607703125*^9, 
  3.516711615046875*^9}, {3.516747014101427*^9, 3.516747047179552*^9}, {
  3.516747175945177*^9, 3.516747177679552*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ShowSlices", "[", 
   RowBox[{"partition_", ",", "heightlist_"}], "]"}], ":=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Boxx", "[", 
     RowBox[{"0", ",", 
      RowBox[{"heightlist", "[", 
       RowBox[{"[", "i", "]"}], "]"}], ",", 
      RowBox[{"partition", "[", 
       RowBox[{"[", "i", "]"}], "]"}], ",", 
      RowBox[{"partition", "[", 
       RowBox[{"[", 
        RowBox[{"i", "+", "1"}], "]"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", 
      RowBox[{
       RowBox[{"Length", "[", "partition", "]"}], "-", "1"}]}], "}"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.482444309179576*^9, 3.4824443121965756`*^9}, {
   3.482445727166*^9, 3.482445727509*^9}, {3.516711607703125*^9, 
   3.516711615046875*^9}, {3.516747014101427*^9, 3.516747060757677*^9}, 
   3.516747179367052*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Options", "[", "RiemannData", "]"}], ":=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Subintervals", "\[Rule]", "12"}], ",", 
    RowBox[{"Partition", "\[Rule]", "Uniform"}], ",", 
    RowBox[{"Mesh", "\[Rule]", 
     RowBox[{"intervallength", "/", "6.0"}]}], ",", 
    RowBox[{"Height", "\[Rule]", "Midpoint"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.482444309179576*^9, 3.4824443121965756`*^9}, {
  3.482445727166*^9, 3.482445727509*^9}, {3.516711607703125*^9, 
  3.516711615046875*^9}, {3.516747014101427*^9, 3.516747079679552*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"RiemannData", "[", 
   RowBox[{"expression_", ",", " ", "range_", ",", " ", "options___Rule"}], 
   "]"}], " ", ":=", "\n", "\t", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"M", "=", 
       RowBox[{
        RowBox[{"Mesh", " ", "/.", " ", 
         RowBox[{"{", "options", "}"}]}], " ", "\n", "\t\t\t", "/.", " ", 
        RowBox[{"Options", "[", "RiemannData", "]"}]}]}], ",", "\n", "\t\t", 
      RowBox[{"S", "=", 
       RowBox[{
        RowBox[{"Subintervals", " ", "/.", " ", 
         RowBox[{"{", "options", "}"}]}], " ", "\n", "\t\t\t", "/.", " ", 
        RowBox[{"Options", "[", "RiemannData", "]"}]}]}], ",", "\n", "\t\t", 
      RowBox[{"P", "=", 
       RowBox[{
        RowBox[{"Partition", " ", "/.", " ", 
         RowBox[{"{", "options", "}"}]}], " ", "\n", "\t\t\t", "/.", " ", 
        RowBox[{"Options", "[", "RiemannData", "]"}]}]}], ",", "\n", "\t\t", 
      RowBox[{"variable", "=", 
       RowBox[{"range", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ",", "\n", "\t\t", 
      RowBox[{"intervallength", "=", 
       RowBox[{
        RowBox[{"range", "[", 
         RowBox[{"[", "3", "]"}], "]"}], "-", 
        RowBox[{"range", "[", 
         RowBox[{"[", "2", "]"}], "]"}]}]}]}], "}"}], ",", "\n", "\t\t", 
    RowBox[{
     RowBox[{"list", "=", 
      RowBox[{"Switch", "[", 
       RowBox[{"P", ",", " ", "Uniform", ",", " ", "\n", "\t\t\t", 
        RowBox[{"UniformPartition", "[", 
         RowBox[{"range", ",", " ", "S"}], "]"}], ",", "\n", "\t\t\t", 
        "Random", ",", "\n", "\t\t\t", 
        RowBox[{"RandomPartition", "[", 
         RowBox[{"range", ",", " ", "M"}], "]"}]}], "\n", "           ", 
       "]"}]}], ";", " ", "\n", "\t", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"list", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "}"}], " ", "~", "Join", "~", " ", 
      "\n", "\t\t", 
      RowBox[{"Slices", "[", 
       RowBox[{"expression", ",", " ", "variable", ",", " ", 
        RowBox[{"list", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", " ", "options"}], "]"}], "\n", 
      "\t\t", "~", "Join", "~", " ", 
      RowBox[{"{", 
       RowBox[{"list", "[", 
        RowBox[{"[", "2", "]"}], "]"}], "}"}]}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.482444309179576*^9, 3.4824443121965756`*^9}, {
  3.482445727166*^9, 3.482445727509*^9}, {3.516711607703125*^9, 
  3.516711615046875*^9}, {3.516747014101427*^9, 3.516747101945177*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"RiemannSum", "[", 
   RowBox[{"expression_", ",", "range_", ",", "options___Rule"}], "]"}], ":=", 
  RowBox[{"Apply", "[", 
   RowBox[{"Plus", ",", 
    RowBox[{
     RowBox[{"RiemannData", "[", 
      RowBox[{"expression", ",", "range", ",", "options"}], "]"}], "[", 
     RowBox[{"[", "3", "]"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.482444309179576*^9, 3.4824443121965756`*^9}, {
   3.482445727166*^9, 3.482445727509*^9}, {3.516711607703125*^9, 
   3.516711615046875*^9}, {3.516747014101427*^9, 3.516747103038927*^9}, 
   3.516747188226427*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"PlotRiemann", "[", 
   RowBox[{"expression_", ",", "range_", ",", 
    RowBox[{"{", "plotoptions___", "}"}], ",", 
    RowBox[{"{", "riemannoptions___", "}"}]}], "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"Block", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "g", ",", "u", ",", "partition", ",", "heightlist", ",", "sum", ",", 
      "mesh", ",", "integralvalue", ",", "outstring"}], "}"}], ",", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"u", "=", 
       RowBox[{"RiemannData", "[", 
        RowBox[{"expression", ",", "range", ",", "riemannoptions"}], 
        "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"partition", "=", 
       RowBox[{"u", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"heightlist", "=", 
       RowBox[{"u", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"sum", "=", 
       RowBox[{"Apply", "[", 
        RowBox[{"Plus", ",", 
         RowBox[{"u", "[", 
          RowBox[{"[", "3", "]"}], "]"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"mesh", "=", 
       RowBox[{"u", "[", 
        RowBox[{"[", "4", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"integralvalue", "=", 
       RowBox[{"NIntegrate", "[", 
        RowBox[{"expression", ",", "range"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"outstring", "=", 
       RowBox[{"StringJoin", "[", "\[IndentingNewLine]", 
        RowBox[{
        "\"\<\\n\>\"", ",", "\[IndentingNewLine]", "\"\<Function: \>\"", ",", 
         " ", "\[IndentingNewLine]", 
         RowBox[{"ToString", "[", 
          RowBox[{"TraditionalForm", "[", "expression", "]"}], "]"}], ",", 
         "\[IndentingNewLine]", "\"\<\\n\>\"", ",", "\[IndentingNewLine]", 
         "partitionstring", ",", "\[IndentingNewLine]", "\"\<\\n\>\"", ",", 
         "\[IndentingNewLine]", "heightstring", ",", "\[IndentingNewLine]", 
         "\"\<\\n\>\"", ",", "\[IndentingNewLine]", "\"\<Riemann Sum = \>\"", 
         ",", "\[IndentingNewLine]", 
         RowBox[{"ToString", "[", 
          RowBox[{"Chop", "[", "sum", "]"}], "]"}], ",", 
         "\[IndentingNewLine]", "\"\<    \>\"", ",", "\[IndentingNewLine]", 
         "\"\<Definite Integral = \>\"", ",", "\[IndentingNewLine]", 
         RowBox[{"ToString", "[", "integralvalue", "]"}], ",", 
         "\[IndentingNewLine]", "\"\<\\n\>\"", ",", "\[IndentingNewLine]", 
         "\"\<Norm = \>\"", ",", "\[IndentingNewLine]", 
         RowBox[{"ToString", "[", "mesh", "]"}], ",", "\[IndentingNewLine]", 
         "\"\<    \>\"", ",", "\[IndentingNewLine]", 
         "\"\<Percent error =\>\"", ",", "\[IndentingNewLine]", 
         RowBox[{"ToString", "[", "\[IndentingNewLine]", 
          RowBox[{"NumberForm", "[", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"Chop", "[", 
             RowBox[{"Abs", "[", 
              RowBox[{"100", "*", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"integralvalue", "-", "sum"}], ")"}], "/", 
                "integralvalue"}]}], "]"}], "]"}], ",", "\[IndentingNewLine]",
             "3"}], "]"}], "\[IndentingNewLine]", "]"}]}], 
        "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"g", ":=", 
       RowBox[{"Plot", "[", 
        RowBox[{"expression", ",", "range", ",", 
         RowBox[{"DisplayFunction", "\[Rule]", "Identity"}], ",", 
         RowBox[{"PlotLabel", "\[Rule]", "outstring"}], ",", 
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"{", 
            RowBox[{"RGBColor", "[", 
             RowBox[{"0", ",", "0", ",", "1"}], "]"}], "}"}], "}"}]}], ",", 
         "plotoptions"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"h", ":=", 
       RowBox[{"Graphics", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"RGBColor", "[", 
           RowBox[{".8", ",", ".3", ",", "0"}], "]"}], ",", 
          RowBox[{"ShowSlices", "[", 
           RowBox[{"partition", ",", "heightlist"}], "]"}]}], "}"}], "]"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"Show", "[", 
       RowBox[{"g", ",", "h", ",", 
        RowBox[{"DisplayFunction", "\[Rule]", "$DisplayFunction"}]}], "]"}]}],
      ")"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.482444309179576*^9, 3.4824443121965756`*^9}, {
   3.482445727166*^9, 3.482445727509*^9}, {3.516711607703125*^9, 
   3.516711615046875*^9}, {3.516747014101427*^9, 3.516747103992052*^9}, {
   3.516747189335802*^9, 3.516747254882677*^9}, {3.5449921434526157`*^9, 
   3.54499227117004*^9}, {3.544992317236921*^9, 3.5449924070618787`*^9}, {
   3.544992475561599*^9, 3.544992520146477*^9}, {3.5449925515493326`*^9, 
   3.5449925582573442`*^9}, {3.5449926069606295`*^9, 3.54499260716343*^9}, {
   3.5449927688809147`*^9, 3.5449927807525353`*^9}, {3.5449931081347103`*^9, 
   3.5449931584447985`*^9}, {3.5449935106934175`*^9, 3.544993514063023*^9}, 
   3.544993616726804*^9, {3.5449938017587285`*^9, 3.544993803739932*^9}, {
   3.5457373266716614`*^9, 3.5457373721301413`*^9}, {3.5457380803642807`*^9, 
   3.5457380838742867`*^9}, {3.5457381948504767`*^9, 3.54573819670688*^9}, {
   3.5457382674218044`*^9, 3.545738269512208*^9}, 3.545738334907523*^9, {
   3.545738431362492*^9, 3.5457384352156987`*^9}, {3.5457385557571106`*^9, 
   3.5457385760683465`*^9}, 3.5457386250212326`*^9, {3.545738698403761*^9, 
   3.5457387356566267`*^9}, {3.5457390001410913`*^9, 3.545739002902296*^9}, {
   3.545739069608013*^9, 3.5457390744752216`*^9}, 3.5457391454971857`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"PlotRiemann", "[", 
    RowBox[{"expression_", ",", "range_"}], "]"}], ":=", 
   RowBox[{"PlotRiemann", "[", 
    RowBox[{"expression", ",", "range", ",", 
     RowBox[{"{", "}"}], ",", 
     RowBox[{"{", "}"}]}], "]"}]}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["CloudList", "Section",
 CellChangeTimes->{{3.5195880325035*^9, 3.51958804634725*^9}}],

Cell[CellGroupData[{

Cell["Code", "Subsection",
 CellChangeTimes->{{3.545731942127602*^9, 3.545731949531208*^9}}],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"RandomCloudList", 
      RowBox[{"{", 
       RowBox[{"e", ",", " ", "i", ",", "n"}]}]}], "]"}], " ", "produces", 
    " ", "n", " ", "points", 
    RowBox[{"(", 
     RowBox[{"m", ",", " ", 
      RowBox[{
      "riemann", " ", "sum", " ", "of", " ", "expression", " ", "e", " ", 
       "on", " ", "the", " ", "interval", " ", "i"}]}], ")"}]}], ",", " ", 
   RowBox[{
   "where", " ", "the", " ", "Riemann", " ", "Sum", " ", "has", " ", "random",
     " ", "mesh", " ", "m", " ", "with", " ", "random", " ", "choice", " ", 
    "of", " ", "points", " ", "in", " ", "each", " ", 
    RowBox[{"subinterval", "."}]}]}], "*)"}]], "Input",
 CellChangeTimes->{{3.520164834614625*^9, 3.52016503475525*^9}, {
  3.5457319376293583`*^9, 3.5457319391162367`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"RandomCloudList", "[", 
   RowBox[{"expression_", ",", "range_", ",", "n_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"l", "=", 
       RowBox[{"{", "}"}]}], ",", "s", ",", "mesh", ",", "a", ",", "b", ",", 
      "u"}], "}"}], ",", 
    RowBox[{
     RowBox[{"a", "=", 
      RowBox[{"range", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], ";", 
     RowBox[{"b", "=", 
      RowBox[{"range", "[", 
       RowBox[{"[", "3", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"mesh", "=", 
          RowBox[{"Random", "[", 
           RowBox[{"Real", ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"b", "-", "a"}], ")"}], "/", "2"}]}], "}"}]}], 
           "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"u", "=", 
          RowBox[{"RiemannData", "[", 
           RowBox[{"expression", ",", "range", ",", 
            RowBox[{"Partition", "\[Rule]", "Random"}], ",", 
            RowBox[{"Mesh", "\[Rule]", "mesh"}], ",", 
            RowBox[{"Height", "\[Rule]", "Random"}]}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"s", "=", 
          RowBox[{"Apply", "[", 
           RowBox[{"Plus", ",", 
            RowBox[{"u", "[", 
             RowBox[{"[", "3", "]"}], "]"}]}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"l", "=", 
          RowBox[{"Append", "[", 
           RowBox[{"l", ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"u", "[", 
               RowBox[{"[", "4", "]"}], "]"}], ",", "s"}], "}"}]}], "]"}]}]}],
         ")"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "n"}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", "l"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.482444309179576*^9, 3.4824443121965756`*^9}, {
   3.482445727166*^9, 3.482445727509*^9}, {3.516711607703125*^9, 
   3.516711615046875*^9}, {3.516747014101427*^9, 3.516747108742052*^9}, {
   3.516749256648302*^9, 3.516749257288927*^9}, {3.516749374632677*^9, 
   3.516749395773302*^9}, {3.516749496445177*^9, 3.516749519570177*^9}, {
   3.516749600007677*^9, 3.516749605757677*^9}, {3.516799552995764*^9, 
   3.5167995803059916`*^9}, {3.519587469612875*^9, 3.5195874725035*^9}, 
   3.519587506956625*^9, {3.519588009300375*^9, 3.519588012769125*^9}, 
   3.51958827065975*^9, 3.519588509269125*^9, 3.519589083925375*^9, {
   3.5456691628614635`*^9, 3.545669163940483*^9}, 3.5456694510594864`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"MidpointCloudList", "[", 
   RowBox[{"expression_", ",", " ", "range_", ",", " ", "n_"}], "]"}], " ", ":=",
   " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"l", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ",", " ", "s", ",", " ", "mesh", ",", " ", "a", 
      ",", " ", "b", ",", " ", "u"}], "}"}], ",", " ", 
    RowBox[{
     RowBox[{"a", " ", "=", " ", 
      RowBox[{"range", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], ";", " ", 
     RowBox[{"b", " ", "=", " ", 
      RowBox[{"range", "[", 
       RowBox[{"[", "3", "]"}], "]"}]}], ";", "\n", "  ", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"mesh", "=", 
          RowBox[{"Random", "[", 
           RowBox[{"Real", ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"b", "-", "a"}], ")"}], "/", "2"}]}], "}"}]}], 
           "]"}]}], ";", "\n", "    ", 
         RowBox[{"u", " ", "=", " ", 
          RowBox[{"RiemannData", "[", 
           RowBox[{"expression", ",", " ", "range", ",", " ", 
            RowBox[{"Partition", " ", "->", " ", "Random"}], ",", " ", 
            RowBox[{"Mesh", "\[Rule]", "mesh"}], ",", " ", 
            RowBox[{"Height", " ", "->", " ", "Midpoint"}]}], "]"}]}], ";", 
         " ", "\n", "    ", 
         RowBox[{"s", " ", "=", " ", 
          RowBox[{"Apply", "[", 
           RowBox[{"Plus", ",", " ", 
            RowBox[{"u", "[", 
             RowBox[{"[", "3", "]"}], "]"}]}], "]"}]}], ";", "\n", "    ", 
         RowBox[{"l", " ", "=", " ", 
          RowBox[{"Append", "[", 
           RowBox[{"l", ",", " ", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"u", "[", 
               RowBox[{"[", "4", "]"}], "]"}], ",", " ", "s"}], "}"}]}], 
           "]"}]}]}], ")"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"i", ",", " ", "1", ",", " ", "n"}], "}"}]}], "]"}], ";", 
     "\n", "  ", "l"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.516800494183076*^9, 3.516800535226536*^9}, {
   3.5168006066112213`*^9, 3.5168006328746605`*^9}, 3.519588342862875*^9, 
   3.519588466316*^9, {3.519588713831625*^9, 3.5195887152535*^9}, 
   3.51958896440975*^9, {3.5195890535035*^9, 3.519589053581625*^9}, {
   3.51959954447225*^9, 3.5195995448785*^9}, {3.51959967072225*^9, 
   3.519599671441*^9}, {3.51959982640975*^9, 3.5195998268785*^9}, 
   3.52018747669275*^9, {3.545668603977166*^9, 3.545668604087166*^9}, 
   3.5457319041956778`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"LeftSideCloudList", "[", 
   RowBox[{"expression_", ",", " ", "range_", ",", " ", "n_"}], "]"}], " ", ":=",
   " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"l", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ",", " ", "s", ",", " ", "mesh", ",", " ", "a", 
      ",", " ", "b", ",", " ", "u"}], "}"}], ",", " ", 
    RowBox[{
     RowBox[{"a", " ", "=", " ", 
      RowBox[{"range", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], ";", " ", 
     RowBox[{"b", " ", "=", " ", 
      RowBox[{"range", "[", 
       RowBox[{"[", "3", "]"}], "]"}]}], ";", "\n", "  ", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"mesh", "=", 
          RowBox[{"Random", "[", 
           RowBox[{"Real", ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"b", "-", "a"}], ")"}], "/", "2"}]}], "}"}]}], 
           "]"}]}], ";", "\n", "    ", 
         RowBox[{"u", " ", "=", " ", 
          RowBox[{"RiemannData", "[", 
           RowBox[{"expression", ",", " ", "range", ",", " ", 
            RowBox[{"Partition", " ", "->", " ", "Random"}], ",", " ", 
            RowBox[{"Mesh", "\[Rule]", "mesh"}], ",", " ", 
            RowBox[{"Height", " ", "->", " ", "LeftSide"}]}], "]"}]}], ";", 
         " ", "\n", "    ", 
         RowBox[{"s", " ", "=", " ", 
          RowBox[{"Apply", "[", 
           RowBox[{"Plus", ",", " ", 
            RowBox[{"u", "[", 
             RowBox[{"[", "3", "]"}], "]"}]}], "]"}]}], ";", "\n", "    ", 
         RowBox[{"l", " ", "=", " ", 
          RowBox[{"Append", "[", 
           RowBox[{"l", ",", " ", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"u", "[", 
               RowBox[{"[", "4", "]"}], "]"}], ",", " ", "s"}], "}"}]}], 
           "]"}]}]}], ")"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"i", ",", " ", "1", ",", " ", "n"}], "}"}]}], "]"}], ";", 
     "\n", "  ", "l"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.545566736830944*^9, 3.5455667386093473`*^9}, {
   3.5455834932257524`*^9, 3.545583496844959*^9}, {3.5456686076020727`*^9, 
   3.5456686077130785`*^9}, 3.5457319075616646`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"RightSideCloudList", "[", 
   RowBox[{"expression_", ",", " ", "range_", ",", " ", "n_"}], "]"}], " ", ":=",
   " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"l", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ",", " ", "s", ",", " ", "mesh", ",", " ", "a", 
      ",", " ", "b", ",", " ", "u"}], "}"}], ",", " ", 
    RowBox[{
     RowBox[{"a", " ", "=", " ", 
      RowBox[{"range", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], ";", " ", 
     RowBox[{"b", " ", "=", " ", 
      RowBox[{"range", "[", 
       RowBox[{"[", "3", "]"}], "]"}]}], ";", "\n", "  ", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"mesh", "=", 
          RowBox[{"Random", "[", 
           RowBox[{"Real", ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"b", "-", "a"}], ")"}], "/", "2"}]}], "}"}]}], 
           "]"}]}], ";", "\n", "    ", 
         RowBox[{"u", " ", "=", " ", 
          RowBox[{"RiemannData", "[", 
           RowBox[{"expression", ",", " ", "range", ",", " ", 
            RowBox[{"Partition", " ", "->", " ", "Random"}], ",", " ", 
            RowBox[{"Mesh", "\[Rule]", "mesh"}], ",", " ", 
            RowBox[{"Height", " ", "->", " ", "RightSide"}]}], "]"}]}], ";", 
         " ", "\n", "    ", 
         RowBox[{"s", " ", "=", " ", 
          RowBox[{"Apply", "[", 
           RowBox[{"Plus", ",", " ", 
            RowBox[{"u", "[", 
             RowBox[{"[", "3", "]"}], "]"}]}], "]"}]}], ";", "\n", "    ", 
         RowBox[{"l", " ", "=", " ", 
          RowBox[{"Append", "[", 
           RowBox[{"l", ",", " ", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"u", "[", 
               RowBox[{"[", "4", "]"}], "]"}], ",", " ", "s"}], "}"}]}], 
           "]"}]}]}], ")"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"i", ",", " ", "1", ",", " ", "n"}], "}"}]}], "]"}], ";", 
     "\n", "  ", "l"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.545583378737151*^9, 3.545583379220752*^9}, {
   3.5455835030225697`*^9, 3.5455835293866158`*^9}, {3.545652764440732*^9, 
   3.5456527653607826`*^9}, {3.5456686122961273`*^9, 3.5456686124011335`*^9}, 
   3.545731911961507*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Subsection",
 CellChangeTimes->{{3.5457319599631753`*^9, 3.5457319652138643`*^9}}],

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"PlotRiemann", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{"Pi", " ", "x"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"ImageSize", "\[Rule]", "Medium"}], ",", "\[IndentingNewLine]", 
       RowBox[{"AspectRatio", "\[Rule]", 
        RowBox[{"1", "/", "Pi"}]}]}], "}"}], ",", "\n", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Partition", " ", "->", " ", "Random"}], ",", 
       RowBox[{"Height", " ", "->", " ", "Random"}], ",", 
       RowBox[{
        RowBox[{"Mesh", "\[Rule]", 
         RowBox[{"intervallength", "/", "n"}]}], "//", "N"}]}], "}"}]}], 
    "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", ",", "12"}], "}"}], ",", "1", ",", "100", ",", "1"}], 
    "}"}], ",", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "]"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.545669810821873*^9, 3.545669814470072*^9}, {
  3.545669943805874*^9, 3.5456700188132534`*^9}, {3.5456700489575024`*^9, 
  3.545670071349327*^9}, {3.545670172412007*^9, 3.5456702903312225`*^9}, {
  3.545670323548999*^9, 3.5456703378181114`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"RandomCloudList", "[", 
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{"Pi", " ", "x"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", "300"}], "]"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<mesh\>\"", ",", "\"\<value\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", ".5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{".4", ",", ".9"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"Axes", "\[Rule]", "True"}], ",", 
   RowBox[{"AxesOrigin", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", ".5"}], "}"}]}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
   RowBox[{"PlotRangeClipping", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5456692015624948`*^9, 3.545669274969455*^9}, {
   3.545669329098019*^9, 3.5456693942564864`*^9}, 3.545669466552987*^9, {
   3.5456787563896513`*^9, 3.54567876674807*^9}, {3.545678834015388*^9, 
   3.545678868881449*^9}, 3.545679270862955*^9, {3.5456904100196733`*^9, 
   3.545690444558134*^9}, {3.545691717537944*^9, 3.545691728598363*^9}, {
   3.5456919203070993`*^9, 3.545691955235561*^9}, {3.5456920193672733`*^9, 
   3.545692022128478*^9}, {3.545692111750636*^9, 3.545692171919942*^9}, {
   3.5456923630046773`*^9, 3.5456923830507126`*^9}}],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], PointBox[CompressedData["
1:eJwVl3k8VP0fxW1FTwvKLi1CiidKhVIHWUsoKmmhLJUkSYXsSykKlVKULSVt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    "]]},
  AspectRatio->1,
  Axes->True,
  AxesLabel->{
    FormBox["\"mesh\"", TraditionalForm], 
    FormBox["\"value\"", TraditionalForm]},
  AxesOrigin->{0, 0.5},
  PlotRange->{{0, 0.5}, {0.4, 0.9}}]], "Output",
 CellChangeTimes->{3.545737909376944*^9, 3.545738033350362*^9, 
  3.5457380969003096`*^9, 3.545738234224946*^9, 3.5457382971086564`*^9, 
  3.545738379570401*^9, 3.545738468958558*^9, 3.5457389074613285`*^9, 
  3.545739151269196*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"RandomCloudList", "[", 
    RowBox[{
     RowBox[{"Sqrt", "[", 
      RowBox[{"1", "-", 
       RowBox[{"x", "^", "2"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", "300"}], "]"}], ",", 
   RowBox[{"Axes", "\[Rule]", "True"}], ",", 
   RowBox[{"AxesOrigin", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", ".7"}], "}"}]}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<mesh\>\"", ",", "\"\<value\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", ".5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{".6", ",", ".9"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", 
    RowBox[{"3", "/", "5"}]}], ",", 
   RowBox[{"PlotRangeClipping", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5456695152586174`*^9, 3.5456696268401003`*^9}, {
   3.54567896043801*^9, 3.545678983791251*^9}, {3.5456792041104383`*^9, 
   3.545679210350449*^9}, 3.545690456538955*^9, {3.545691746366794*^9, 
   3.5456918068637004`*^9}, {3.5456922368004556`*^9, 3.5456922962989597`*^9}}],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], PointBox[CompressedData["
1:eJwVl3c8le8fxo+RkIw0jYyIrCQr1fcqpVKStJBkExVpCRmRtHQSDZmFhEoS
CREi2zn2CBXO85zTIFqifvfvr+ef+3Xf93N/rs91vT9Kzj7WbvwMBkOLj8H4
/9dU2VoybFkFhFaUqWsHUUiplVjY9iQfUYs3ec56TyHniHPUn5oGDPWvVDDy
pCGmldoqv6cNQxeKJ4sZFNwlXmXF3upElIiXkeIiCplG2aXvQl5j5khXZzOT
gq/ryne1uiwUiITl1JL178aYs2fK9uGa6S0JwbU8ZDo9n3VJpANf5YP8gxu4
kBzd9VI6pw1Tnwt1nL+NYK/nYqZbKhuVNrReayAXvm4BcfY9bATjDcuGSSPq
45h6oF8b5saZ+5fqUtAw+Su7MD4Ph9XkB3mqNNZ1PCg4/60FL8QNdviI0Ujx
NoqqeFcLcdMaW30HCoO8QduO6j5IfNhe8nGExiXRgE2LL7HxWFeUnqfPg8W0
1207w1b8u1xjv9GTQviYtMZx7TZMeA9udrMk+9co8047VcN4RrpdwCQNX9Xg
6J6gWhgO1Cptq6GRoLjLY8aNKsT6bq5OU6Th8GV80vZLFybz/xOp/zCMULkf
vp1nkyF4T329+UIaFXO5T1TulMGwXzXk7QiFre/HdRiv23FBu/rgmR08JOUn
7hVR7IBm/uGx9OXkfd7vt8zTacLgbn71xRMUGLcy56ZF3YZM246+uGU0gsZL
PLKliuFuKGeo+oIidTl/7F1eGVrCTnwoIvtzQ5YOzSDvHfXRL+1EOxc3205H
Ckn2wNXq6eGQXAqKR8PPT1fEIG9V1o0Vi2noLsp3ODmehvkB/FlC22gsN0/R
oK4UItPKRTZMhMbzJ1IirsdqoH7V6fXoSxotYiHGxf7J6G1uOLtFjobN61/r
s/v6cKWet6/4Bo2dHzlqhrEtWGgX5tRXSGMqw+l3lG4tNM/Pet2mS2NhqYOb
cFgrvi+sE58tyINs0fwhsdQWvEq+4+uhw8XulM0mApHdcKTuysQs/oSEbfqi
l/grQK00Cpu2o7FYeLRooVQLNBu/z+mI4CA2Q+dcJV8jTozaM5XtOci9sNXE
TTIPpQKZOqVbaKhtDE7Pj6xB5JpDNdMlFM7xvKqZ2jWoWR1bMt5HYWj/KX0B
/ga4+/53ZmshBbnGswtqJN9CJ2tL0m3yv/e6N1/ZcLwPedLXP9Ql0NAaiNp4
1LMSeloXHOSW0MiyYu/dsIPou/19jNCuEWwxlbRsLy9Cvq6C1H/qNPzZYSpG
loWQnP76x1qcRlf5029nRp/A9eBYQ7Y9DZWH7+WoX5VYYPgm+NYrCuWzzqFZ
IwB8xpoHnJXJ/jOD/xtvZ6O99V/9VQYHtzvDHwrFl0LnnEHLlXEKVu2sk88K
HsA+6i3jrQGNE4frdpfNrsYppoyQyzsOfsfN8VM43gWXoP6IneUciLSmzM0d
a8BDsXAFlwTSLxVmfnwXSlHXz4oR3EOB+cdLXeLqY9QcXG9zDTRGRA1O/0mq
wr97EjoRUhRKJk3H9zIrEXrs1odtG0k9TPOvB5V247ukG0NknIuNeTb95q4s
zJ+zUluGovEr59T4lnk9sFppzVfVz4G9tHbizjXFEJ68wPZrorFx4oy8ilIj
DgR7eRzV50L0/eVLuU9Z8Ior3i4nScO4eO2M4yWtyNfpyrbi4yKCT+NRhWg1
irLT1feS/pfLM/KSP1CPJuECZa9ZXLjvXbs6uKUE1U8jhe/tJe95xPyVUu19
FP5V+OpP6nWqzvSx29JerNpk8ZH5m8K679XfNic8g66TbOUDGxriIXfadym3
oTror/nsv8NgHiucsYvo7Uhl43WNnVzE/ju05+3RcuQnarwQ9qPBcujccM6+
B8/wMkH+PhdBthqc1i8NOLtqpXRxJ9H7Yt4Pt/FiaDinaV6apqD/+YXdhNoz
zNE/m2DZQCGUedBg+kMjvP8WPAn35KLzcseaGRcK8SvE1ZW7i4ZjM9uNGk7C
7i98+UwtGhMDep7fP7PQf/PnhFUQFzK3vb8us29FkrT+H6UoLkJFNTXyvRNx
3m68qmo+jdWZasP9zt0QuP3fBbEEDjId5HPjvcvgt/v31/23id+JOQbXRTxA
n2NvjstcUu8nro2R2YXgD0yHngANplFYj49CGZYmvr1mSfyGcVbj5Yb4Zqyp
sih8GcfFrJr2Qz1DbEhrq8ruZRG984t03gjLxSA7fkOjJo0SJ1e98q012N2+
9pf2Dw5sW9XYB73aIZexMpxjPwKVst4SrYB8JP0ZXJUkTWPoTtDhrZpsGMvu
0igQprHi4+vtHrfbcYDfQFT1Ogc21SeFFxwvwkSc/ckUcl/jiJW5T4y6UOR0
yMiB9O+cOwvN6q52oCppYmYNxcXbaD9L55vPseJ1VeyQBI0LZnWPNnxsxUVN
/u4PwcMYzOt+MuVzEWK9tQFH5GnknTsz+4ZDF7TGWsX6RUegO/nSrfNAO6r3
mxfplXChckUrMEy2BkeXjGcprqCQffQHrXTvDUy02Str3tDwONt4NbC2BXKT
jgNc4oeOJmbzu/zCob7q68QAyYueqAUDaxT7sCnxYkHy//Px2N/Zdl9rsKb9
tIx1Jg3Nly575A+0wtpuq2pfO6lX09Rds3wWNr1oUd3izUXmbWZWk8ZTRFtI
7WsyoxEZcCZdJL4OTe5QiSH6GjS/VTxrZwyW+twMMCD+UZG1NyNHsRneJSfE
xzdRUI/5nOnlXow6l62zpHlkvX1uZ3osGxObh8e1ijjQKarLEKTbIe7O0veM
4YDRsutg+I04ZFy0lfYkfmaub+yt8o7Up1/zU5oDjaU6B1Q6izohE2Cx+acc
D6PuqauH5zZDvX7HJ+sxGjd19R8pHcyHym03w3dONA4tXXbgzg42VC3mXOCZ
8KBxMq0w8U8nnBusYrvUCG+kS3XxpuvgInMm+F41jfKcm9IF0dU49EAlO5nw
S+5Lp6g5ZW/RWqNatMeaC2F1h31DV9owuuR13RJHGtZDoZuCT7+GIjO8/fdx
oo/LOw/b+bwBY0hYgEH8RHGTN3V+x0M8YT2NMCF5VN4d73pX7xGquz9duThF
QVJJ3sRChgXnVOUfSj5cwh1u1K3fBeD/0usvMYO89wqb5A/aHWCcTJgtHUIj
NJozV0r/EVRk7keXk36xaUspljatQ2xTQbeZFenHC+f+5JhU4bbfXaWvjaR/
sqx9fFYFIX6z4IF6Uh+mXePHkMssdHydt/J1OLlPdNydnNNNGLgz+EExhfjH
6uaTjOp6dG4THd5cOgILTy/ZIxL1qEhXX8n/gcLRP/9GHgV1wCAkolltIQ+h
0nHbN2l1oit3VeqCDB6iZm23dAqpRN/a6LafbynoOAcmsVyqcD9pRowU6ee+
iO+/TdbXonesz3PInuhB0H/xIOGbvgXJl4r/UUjas/brxfNvoOK/75t9L8kH
m37+ClE24j00B6/5cCCY7fJDy/INhJz1yxKWE55QvShUdpGNaQUFD02iL5uz
c24McV7hu0ua0fIiCs0WJt6pW9uRkjx8bIUejYh0rvuOK92Ec6QljVtJXqj6
3R1oa0EG44tfSRwF9oEtJ3I/92B1JJXLfs+F4syySvvYZzhZWe07k/gj19h2
bvTsOsgUtK5q3kX0ccV2Y7ruI6Rmm8bPJ/vPDKNXx4W+gXJRyZhCCIXhhqXf
9bU7cT39eVgoub+ihF5mrkcHtNnnnOHLRVRAg0/Am+cwdB1mvyO88elUm/+w
fDvOp03KmBmS+yX6py5Tf4W/7Z3Oy94S/nxo0mpE/DN2C6tZjvjdzfsqAtXX
e/Hv605D2VcjYO+8dkkrpRU5Dw/cYWwn+dIVxlxzohOOFp4D4vU8iK+y/IL1
Xaj4xfgqoMuDs+Zpl79q5XBfMD84NpjwntTko7gZVWAalD3YbUTD89Oi4+MJ
XZgWCH6YsZoDi64Ey4GxLlTPUVi1//MwJl6rLJV7VAdGinuQ6TEaTY8j2b5z
2bDqyJE5u4FCTH1co8zcLnScEzGMduJBTlSrydqAhfiP64YCFSicMPvvx8rp
DEzV+3kKkzy8X8RvJni9A1OLV8Q63aXh1/ayUrCKjewSCbM0Vw5OLOrVuR3Y
iC+eLgKMf8Tvujojkt++QAg1Zfp4J4159j+cg64/hcMfAdknQxR0n7FHm6Sq
YZvRHMck+nfcfozvt0Qyqrb7Oc9bTXjIrq1hSykbjgz71Z9GSH32hGhxra8j
xsJuf50KDWHZb61mcvXIurZsav8t8v8GWWVHmgj/iRpYJN6ioDLrxO6otH7o
er1IaezmYc7PI9b63u8wsfD9gTU3efC/FX9P1ZeNin9t4Y0rSP+FSA+z91fC
M3v9B0Oid92FqqyJnBcwD9xx09Wf1Jsau1n7oAEFBdd2jI5zEJqg4MSa6Y+k
k7xPl5VotNGCAi9fVcBYZSDnwl/Cd+aedr7rOiH5jE/9hj8XGoEcTMeXo8v2
9xKnMsKbXnbmJ7bn4Gdskd36dgrC4xaGL/mqsGbWXetImkL0vU/c+bu6UHP+
iBmbycO34w5U5DwWBM8I7ewYppClF7Zo3J+N/I76an1zGj9NQqNDH7dCcKr8
70gFDatp5aqiO3Xw+FJ6OvU9jUwRGbcdc1oQM1BY+7GL+H9p8El/oU5Ey29I
VIvkYvxMl/d1sSoIDi5z6CY82kYNTT0PfoWKU48rj5I8d7wkmrbvZwYat9ka
x/2fPxR7FHcLZWLEP3/yG0Uhn6ebeyybhf+6v/s5Eb4bNf9zVcu/Dv1nk2Z/
Xk2BOqQdYClcB6/0kxfnCZJ+ilA8cWh1HsJGR8T5yPyxTmnHtiD/XPR5u6i8
2EvO+1ZWX5ZLeCbu+4/hHJK/Y3c7tEl+yUpNJu6OoJFWsOvMypPNqDv3IXxt
GQ3ByNakYZU2SHb2jAsQ/YWmsmb1idWiSU/X468UDZN3y/fdFK9BUI1yN186
hb1/itS/MVoxbGUmy5Qj+pHW2PKundTHI1UqM4n4t8FrpozwK2QHJ2+b4Ufu
P3DkznONaoi5br+3R5+cJ1e+U0OYhSs2cW6J/Fy02e21Xn6tBT9lQgpzH9DQ
a4raovS3Dr53NTYcJedHWM57WaXVgcZ3qZUbDHkw6gk33RzYjacXU8579HEx
lSfE92d4AHrrT//az09ho7Gv2anJN5g/Jl71Io7UdzB8uiKkDVsf3D1ndJXw
bG//fpvzhRhlj4alpVLwr5grl931BIpXVmt/Jjw+5Lrvo3F5K64XiDKEQgkP
p+tUKuRV4tNlkyXyHSQfjXQUk7K6Ubi4rkz1GQeOn/ISnQqyIDYzRfQM8bec
qUQ+Thnxm3TOpwQGFyKRUg7fBdqx2LEld9KN1HvnmLizcDUu3A/fYEB4hvFg
QDM/gImqTLmrTDLv9iqFlsSHdcP1ML/j9ks0Bp2+3+fLZkI3wVJz3iIyP56Q
OXyvMQcbJ3NG7Mj8KMcOZubKsuDTUX9qI/GH3JkHJ3X2s+HpLlMhKEShJtHw
6s/eGuTIMnCqmAPhwDVW+lUR4KRxQ91VabyPsVA05rWQeczFJOISF9UBz86V
3GpBg4+PjBbh3fI0q0XxA/nI/XU9X53wIeOQ/7Mf90vg7mpllk14kPvYaN3P
wDewKRj+uTWA6PvuuOvPW43guh73KvpK+kVdfJ3H/D70pYQctE3gYfdembiz
GV14q1/gHnlvCCbJPhrK81lQPnJXam0FF2H+w+VSqj2wvDf1jX2IzNtDQSEp
rWWI9JRIMyX5eEfR/pD2AzZ+qBnKcxR5UKDuqF3+1wiLsIn3yoSnTL3fLAub
0YV488AKTjIPwotFBSt/9WCde5ae6ioOPt1XuLKnuBE9n3uHMggPfzzusWfU
rQPHjbO6Wh5x0B99S4Vh2ItHDac7DEk+VEyVN5dyW2GvvvFfeRUXLXKmy91F
2qF1/pXah8/Ef0baupXFKiBXKvbRkvhpl9pai9a/Ldi5VYv25NGY89h7h1Ik
Cy+kyLgqw8WvCu1fp46nIyZU0rtaiPRbCP+BoWdv0Ge7ZNWinzR8m9gnJ8ar
ELHb1SGom4OYRa9i56nV4EHxehkxMo+ve+UzopH8CE+X0SKiIkQPtkbvpSRZ
aHio0iTZROF/2e1law==
    "]]},
  AspectRatio->NCache[
    Rational[3, 5], 0.6],
  Axes->True,
  AxesLabel->{
    FormBox["\"mesh\"", TraditionalForm], 
    FormBox["\"value\"", TraditionalForm]},
  AxesOrigin->{0, 0.7},
  PlotRange->{{0, 0.5}, {0.6, 0.9}}]], "Output",
 CellChangeTimes->{3.5457379096733446`*^9, 3.5457380334595623`*^9, 
  3.5457380970407095`*^9, 3.545738234365346*^9, 3.545738297483057*^9, 
  3.545738379710801*^9, 3.545738469114558*^9, 3.545738907601729*^9, 
  3.545739151378396*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"circle", "[", "x_", "]"}], ":=", 
   RowBox[{"Sqrt", "[", 
    RowBox[{"1", "-", 
     RowBox[{"x", "^", "2"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"ListPlot", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"MidpointCloudList", "[", 
      RowBox[{
       RowBox[{"circle", "[", "x", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", "150"}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"RandomCloudList", "[", 
      RowBox[{
       RowBox[{"circle", "[", "x", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", "350"}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"LeftSideCloudList", "[", 
      RowBox[{
       RowBox[{"circle", "[", "x", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", "120"}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"RightSideCloudList", "[", 
      RowBox[{
       RowBox[{"circle", "[", "x", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", "120"}], "]"}]}], 
    "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Red", ",", "Blue", ",", " ", "Green", ",", " ", "Brown"}], 
     "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<mesh\>\"", ",", "\"\<value\>\""}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", ".5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{".4", ",", ".9"}], "}"}]}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Axes", "\[Rule]", "True"}], ",", 
   RowBox[{"AxesOrigin", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", ".5"}], "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotRangeClipping", "\[Rule]", "False"}]}], "\[IndentingNewLine]",
   "]"}]}], "Input",
 CellChangeTimes->{{3.545732179047388*^9, 3.545732286198948*^9}, {
  3.545732321267828*^9, 3.545732368774021*^9}, {3.545732406526782*^9, 
  3.5457324476293993`*^9}}],

Cell[BoxData[
 GraphicsBox[{
   {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8lekbxtURQ5YIk0opZKtsdaZkurJEJEqbJUuUNCkVP8z8VDO2sTRC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     "]]}, 
   {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lf8bxkVDCKGSzKJJfBHKuDSNKBFpSEYyKkooShlJk1BmkUShrLLH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     "]]}, 
   {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs41OkbxgepJNYPkVboYHNFByokuS2S05WSq7NDMqKjw0qJaFRGtlIm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     "]]}, 
   {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXlUzAsbx9u8LZY27ZTCla6l0Ei434hCYSQJSUXWiVS6hTQIDUlFHRqR
ULfV0G0bqmkmGa1TTYvSOjO/368SeSkJeef94znPH59znvOc830+5zH3O+Xm
r6SgoBAmr//33i5eVkrMW1z+VpnOMiOwaEd0pE5NM1RyAmXfTWVQC+i9ZsYp
w+Ggy9qLdEl42jhY6JU2YMdah12ZhTJYZp0pd9V8BRbHvO4eX86LpOwIAR8+
gzub60sIWDONPx/NFaMgPuNMQUQ/4j7ozA6mpWN+5+Lvns8o+GjD+n5VMkIe
Rp3IeUeh+PkVcroNH2X4NybMn4RhkZrLQ/0iXFU8FfBPJ4mjuUdc1wvKsDrK
aI/+fBJ2Se46/l11sJP8ClUalyGmXvkPs4dCMJI8Lh3TIHAuOduZVc2D1k61
yIuRJCQaph+mxjxHaukSS2dfCmOBbUfevKwCzzLqfXw8IZ9H3Dx6phGmH7Wl
O7gyMAyfVhmuFyDmjEOQlZz7nLgZvKyXh6xvepoO80g0hJ+LDDregYIcN6fa
Egl2nrL3VVQQI7rG4SwrUwINwebDfxmUQ0/jArd4I4mzU8bTX3dXQbLGJjsi
j0Bcj46k2LgMS006o/OiSXh5bxcrqwqh/8hCcVevDApzbnUfPDUHP9iRsx+b
D4D+yTEusD0beXujF48xKBTy1I9UZDSh5sNTp5/dEnBSGpdI+nKhRW+Yu28D
BQdPrS/5jDZ0vV5XscWgH1R2iE+npBRZJqM91xfK8/K6MZfObENr8qaO2oA+
FNPcyq2vt0M0s6exNkUCijG5MS1SALevydeiHhM4MNU3okHAg5A7YbD1F4GR
9iKaj+YTbKzOsbqWQSHsa99waykXh1qztWgCEoGV1tqJ+TkIt2ZXEEwKdiVp
sgFRPfwMXnSHpspw3+BZ6MplhfjTZsMCmiGFk4pBwm4uD9FihYu87STu+/1c
fkfaiogOnxbF9D7kDDe4v5C9BmedBffuWQIOTL82d04znEICUzJWSDAyI8M+
0TANlY4P78xOp+CXqWdIsxAhbu/kxfmfpfBsO7x/4G47rBTffl/vIsWGfSUP
dCQVuEVT23R3BYkVYXkjiibv8NX3aNKM0xK43hcbWfJE2LdG1f/uDxlIV0f9
k194qFKtTfgeRUJ6u/b0qpA2lHQFBHAj+3DAeWDYtuYdNHQnDzaZS2Ah2j3M
6mnG4GoD7R/hEiyqichXb67FkPubOBWWDMy6Gm9W4UNss48I/vySAr8+dlur
bhcOJPQUvG/vgUNjY/GqpnRsVXjMHmNREHrtW2/Ef4Or86xT9x0iEPqs1Huh
jRB606eeEFTK8zjJSHDgpCDaWD8mVkjBa+uvWM3cMkQfM9aje5Bg/tfiz1D6
LdTXPzfTGKXwhEErd5nSjMMbGSs5GhIwXFx0u/LfIyggvuloUj8m1wYtq1Js
xhb1GRa/bGS47pZjQ8laYZVBY8drSyGVZJiLHr9FbG/sieNBMiQUF1laT/Kw
KebQ+suTBCp5zz9/7W7AFLYvfe+EDLyJWQt7TrZifsTfOxO1+iHc9kNPlfYW
vgU+icE8Ah9/e6n/Z6AZZtsPSxur5Tz0cfjsJS+Ru+Z0qEYhiQ0BKmpf3Kvx
2vunGxEng1YhdU3LqQ4J7E2XchMJ2LdI8hnfWnG2r7bo06AUF0KcWbcz32OL
kjo3y6cXm/Qa2cOCN/BWpd1sEhP4kGts63yqGtWfQ95tX07g2EErdlIdDxOW
PbaaowTqOXOOtW1rROfEmBs1U4YPU7uTUluEsP+UdH7reQKezrvBmSlEDr39
1e8Sua/nPqnaOUdj9Vwxw1RpAN1FH8euGohwPljnpsZiKcZH907Pm8YHf7Li
YLUpiai/90jg0QKVpsKUPRNS/LriGOWVzYe/o9RbaxcJxm4i7e0sIYjbzOu7
ygmM/6V++4WTEHld5cWOHTKMTLJWDT1Kx71h+xj6LQrMZ5HXbpTWY66y66sb
PVLc0TVaZ7+xDqvSXhkVlMjz6jZNX6DbiTKF65prEnqRr8LxO54uhqaHgW2h
hXx/P/Xh+Mx/MW7aELxSmUIaJ+z3gvlNUDZL/OPBRwlSb/KWvg+KQfTTJykO
PynMkU4V+CmXwZTHslVfTMJSVyr6otSGiMuSEd/MPoT22Zu6XxIhQan8k81M
KS5vDuDHzGpE2LrFJnUh8vuYk+9ne78TOlz2oDEp9zfw1gWitBieowE3aitJ
OGW5tJt1iBG4cPDVKFMGQ2bgavaDl1h+fORSeRiJoZ//WL0pasG68MQ6ky99
8Frp8f2qSQtmHjM6YBcrgeEM+poboha8tO1ZlfW6Hxz/5t3T/EvgYqfywLee
hDh8niBZWo7UsC0ZQxtI+ESSwv2zk7F2/7StV+T/yDWN3j2u3oBKzhFfjjoB
8xd5qYK7nTD7enbR7w65z8zzU3YnilExdK/wiKAfGtomC3aIivBo6RjfYy4F
tcHE8c3zqnEvVL/pAl+G80NOXDo3HyHmhi9MbSn8DzmNy2o=
     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesLabel->{
    FormBox["\"mesh\"", TraditionalForm], 
    FormBox["\"value\"", TraditionalForm]},
  AxesOrigin->{0, 0.5},
  PlotRange->{{0, 0.5}, {0.4, 0.9}}]], "Output",
 CellChangeTimes->{3.5457379099541454`*^9, 3.5457380341303635`*^9, 
  3.5457381564900093`*^9, 3.545738234692947*^9, 3.545738298590659*^9, 
  3.545738380007202*^9, 3.5457384694109592`*^9, 3.545738908022929*^9, 
  3.5457391523455977`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"sine", "[", "x_", "]"}], ":=", 
   RowBox[{"Sin", "[", 
    RowBox[{"Pi", " ", "x"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"ListPlot", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"MidpointCloudList", "[", 
      RowBox[{
       RowBox[{"sine", "[", "x", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", "150"}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"RandomCloudList", "[", 
      RowBox[{
       RowBox[{"sine", "[", "x", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", "350"}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"LeftSideCloudList", "[", 
      RowBox[{
       RowBox[{"sine", "[", "x", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", "150"}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"RightSideCloudList", "[", 
      RowBox[{
       RowBox[{"sine", "[", "x", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", "150"}], "]"}]}], 
    "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Red", ",", "Blue", ",", " ", "Green", ",", " ", "Brown"}], 
     "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<mesh\>\"", ",", "\"\<value\>\""}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", ".5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{".4", ",", ".9"}], "}"}]}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Axes", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
   RowBox[{"AxesOrigin", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", ".5"}], "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotRangeClipping", "\[Rule]", "False"}]}], "\[IndentingNewLine]",
   "]"}]}], "Input",
 CellChangeTimes->{{3.5457324847496023`*^9, 3.5457325615480347`*^9}, {
  3.545732594781204*^9, 3.5457326080680757`*^9}, {3.545733377884186*^9, 
  3.545733382388237*^9}}],

Cell[BoxData[
 GraphicsBox[{
   {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkbV2G0jlFZkkrESVLZK/lV6EsbrcJnyRZNSlLIlhoNEifJPomQ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     "]]}, 
   {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VW0XxqVIqJCilCnhpUGShLplJqkkGTNU8koKJWXOVEpIJCSikhTJ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     "]]}, 
   {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8lekbxoVpQba0TNpspSxJJjLMRYMSlbRROkmLHCKVlGyJRpaSbWTL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     "]]}, 
   {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk41dkfx4mRLUNp0xjb2IqSLJniraxDU5MSWlWWtJDIlkoy5laGkqIm
ZcmSJaTQYr2S3XVxXdxw7/eIEka2huL3/f1xnvN8nvOczznP57ze789ROebj
4L5ISEjoLj3+Pw/9o3UCeAY9tchP+nYEW5m2aTUiHBw3O+7kHCVA2HfdMrnu
K9gn8lvL5YMEQuv18q3k2Yg7vdJ123g/wpbuOqjZF4C95xktykcIwmLdfWzG
c+FzrbIq0ZhAL5VTE/soE7JxublfDxN0iqi61Puzwb5w5lSQ5wAaxU7qfPir
BI5XroYyYgi4UQ9sftzCg0TMrtqo2R4ob1zs1bEkH2UNffYPPQl0VWoGHndV
wSRm2N8wmMB5KDJdPbcYSau0/s5cR3DZtmmby3om/DdUkuyjBP0Lr1JufOmE
X4eSSNFiPlgpSSciX7LBP5UlaS1CQXvRTdX98ywIrdGR3fmFgttdZWnHo23I
NtRUsXgtwOEhyRupdyox4T0RoBtP4T7brpejwURkY9tfHxYolBl+DPm+rgM/
VHsrlC3wwRg1yp+eZuO6yUD2vCZBeuk/YYeaOhEd4BlzJrAfQ5zitveOHXhc
rhvF0KJgZF+ytvBeK0aDPRIlnQSY1DHx88xqhWbeZt8gGYJan8C+uulaWP5X
p+B2g0LQZmuzVY3t2KzWGpDhTsHAtCbReEUSeBannQJcCMyeJEZ37GiEc7OB
361SgputpbXGfz6FvPry0lO/EySFxf2uw2TDQ+5hkb29AIOrhAU6o83ITa5W
dKPrH5pz7QAjrgfPHZ+JtlT1wXxtdsIioVI01xf65kURRM/7fDX8tw1VbyNm
d1kJ8OZ0NOuaQx1ENqz80YRHoYQnz7v2iIfRo+HvtMcJRgcW88xc6HobbfA1
H6Z5aagsaJe4Cj7zlHT9IQJ/3602O2fqsPZciPacJYXw7oz235ILcDExP1Qk
nMB6VJlaZtkNq0t6kck0n3Fl3BWx6Z0QqneZVOEK8Dh44fO0Kgs/3Vnxg+Y7
AVybw+UNnqRB1kD206AzgXlw4eePGndx7Pc/OWV0LN8SrmNnwkLmjSvbE0IE
sLQpnHxhU4eJ/uyRTQ8oTO7fY7tyCRMyTWZHuyMI3kR/Z918ykFvnUFE2L98
vE8fboxe0wJukp3s5GqCkSr383sZTPxyaFxCoELzaK402N/2DBpbekpmbAhi
PdcJHxzjwtdtrjHhHB8nBOYHrIVfQEw9b7zpFoFyiqLFkXct6L5/7c5vcQLs
iF+9LOEyB5nDN5SW7xHAvEk5R6EuGRa1ArcoJ4JVG5tlddua0fOt06BrowDn
74wGpbnUQ99uFjxRAtfxbiJZdw/py9Yx5U7S+Q3G6qeD/8Fbe4VU8eMERQ4m
ZVQSCw/GAk1SaD1FfDF2LZNrgfdGj9K72QIE39Y7EnCyA07fQwck1QjyW4qS
kqU7YWXd7SE6x8eGrIu9Dmo9kFiqvk76R3q9LMx4nFmIXneG8iEFggfbxZvk
ttRDkZj6xdPvE3jwjSHDqB7LtbhxJ74RdNfZBvtrtmMoe+edRz/xoeq45HP0
zjrINmnlNs8K4PYqf7Qoj43q8CuHD4zyUSt603CGzYbjQqm2tiEFHZUjRtaV
LdjpPTcSlCqAUKWCaWTkc3yW0Q5iLiWYZE1I3tNtwdPGu75Sjwh4wd4ivvFc
GBu6FPwXyofxvM1F55kiDI+1a4l7EfRJe0coDPNgW/fIvnx1P6YvbDZLs2Nh
ZN5BMUybQNF5iMiUcNH7pJb7MZyCv3KAutSG5xAVl3NT3UZwaeyJxwovNmQP
J0ftC+TjwYh+x5v2Othl6H/eN0XfLyxEqmNvIbhBJQWL1QnI+/XZ3hfboVIg
bu0xRfBYbbdYYlslpFd1BVjo07yf47A9L7XisMvfOXkGFM5bSeQsv8nB49O1
YcW/UnC12lJ5XPUlVgpP2L0xJxBPSrHbdyMFkcFzUZscCNYrTtq4nW9HhlJn
RN99CuZ+lvdLxZ7AnGOSom9FkCAuPDNoUQiDwUxHs60Ery6cTTS0qsZpCS8T
yzM0PwWtC8W+hTDq4JE9HnTsJc38Y/Ad3nIHfCouUmCVB5gy717H/uhytXHa
z38J9nlq85EFV9bc4/9ov9RiZhiEerFgNCJ/eZueANK+jGClrGIUFWZfl6T5
DbN23eBv3o6jZ4XWyWgLEKGu/mf8dCOeWWgk1AZS+Co8u9HKshwza1qiVukQ
7HXwGtiX04pb36qLtq2mIHTR58TfYv6IXJt45Bl9fnrqjMQr2y4s453t+iLC
h4x9TNmvij2IyVp09QqDwiK72kG57mIIrLMmztB61TG1sZxIbUB6Xc6L+SgK
P7tO/hrjx8OUw/vmpx/6oLR/9q+pWw2I+Np5u6ye4HmPV1l5fDt2T/iZXO+n
QG2sMex49R6C0JYlXTr9kPeUYr5Y342Rk1VLtMBHTZtMmpxZOVYu1oyXof2j
W7WPKx3SA+9wW/9dpnyac1POpdSbyG8e3i5L6/Et4yWz8XktPjjHpms3Uahw
Mm4wYBThNX93hK4iQcmc89IBxTSkTFcpUbsJspYue+QezMYay4TXzcEUkq6u
vcgeZsFcd5lPd54Af3gGse9l1CDDJHZHRRqdb829udPCSXhZE1LuQfvtDr2G
LKZSNc451RgtkaTrcW7/YrXrTxHh9DmHv5fuN/KXxOz02xCdedaA20/7kdqB
nk47Nt4efi9ks4mC8sIpabfMO+B0mfYecCUwiPVuLv1E90PHnyuKkwk08n4J
HsvqQc3ta1Jhor1o/6FAahe/A0sXPmntF+2HStun3mO2nSgd5nItzlKovf3G
PqOhChpBAfLJkzRfUxW59U45cLm1e4fNJoILm214t/wr0JGvJ/JwO63X0shz
qYMc9DTcK3SneRwxEWVUWPQAEWK75fp7sWf64wePbTx4JAlNEBGCzWxOegrv
OZw0tn6bmqYwZZuXmGjaismBrNuX9AWQDf/0k9zrVigw9Kd1ZgRYPbM2ROlQ
JaR8oy6PDdH7Ja0DVevr4Xx1hbN9JIVj1lmTzsZ1MI97PZ9H98tXo5Ul7w5W
Qa9G1fEP+r9zQrOxK0KnGjsfYnaqk8L/AHtcuf8=
     "]]}},
  AspectRatio->1,
  Axes->True,
  AxesLabel->{
    FormBox["\"mesh\"", TraditionalForm], 
    FormBox["\"value\"", TraditionalForm]},
  AxesOrigin->{0, 0.5},
  PlotRange->{{0, 0.5}, {0.4, 0.9}}]], "Output",
 CellChangeTimes->{3.545737910297346*^9, 3.545738034613964*^9, 
  3.5457382352701473`*^9, 3.545738299526661*^9, 3.5457383803192024`*^9, 
  3.545738473357766*^9, 3.545738916868145*^9, 3.5457391526731987`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"circlelist", "=", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"circle", "[", "x_", "]"}], ":=", 
     RowBox[{"Sqrt", "[", 
      RowBox[{"1", "-", 
       RowBox[{"x", "^", "2"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"ListPlot", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"{", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"MidpointCloudList", "[", 
           RowBox[{
            RowBox[{"circle", "[", "x", "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", "150"}], "]"}], 
          ",", "\[IndentingNewLine]", 
          RowBox[{"RandomCloudList", "[", 
           RowBox[{
            RowBox[{"circle", "[", "x", "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", "350"}], "]"}], 
          ",", "\[IndentingNewLine]", 
          RowBox[{"LeftSideCloudList", "[", 
           RowBox[{
            RowBox[{"circle", "[", "x", "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", "120"}], "]"}], 
          ",", "\[IndentingNewLine]", 
          RowBox[{"RightSideCloudList", "[", 
           RowBox[{
            RowBox[{"circle", "[", "x", "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", "120"}], "]"}]}], 
         "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"Red", ",", "Blue", ",", " ", "Green", ",", " ", "Brown"}], 
          "}"}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"AxesLabel", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"\"\<mesh\>\"", ",", "\"\<value\>\""}], "}"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", ".5"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{".4", ",", ".9"}], "}"}]}], "}"}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Axes", "\[Rule]", "True"}], ",", 
        RowBox[{"AxesOrigin", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"0", ",", ".5"}], "}"}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
        RowBox[{"PlotRangeClipping", "\[Rule]", "False"}]}], 
       "\[IndentingNewLine]", "]"}], "&"}], " ", "/@", " ", 
     RowBox[{"Range", "[", 
      RowBox[{"1", ",", "200"}], "]"}]}]}], ")"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5457334280236607`*^9, 3.545733440281475*^9}, {
   3.5457334858996596`*^9, 3.5457335021981497`*^9}, {3.545733728901435*^9, 
   3.545733729180451*^9}, {3.5457358931159782`*^9, 3.5457358932095785`*^9}, {
   3.5457360355442286`*^9, 3.545736035887429*^9}, {3.545736842972883*^9, 
   3.545736849914895*^9}, {3.5457374845006866`*^9, 3.5457374846254873`*^9}, 
   3.545739473919352*^9, {3.545739525176512*^9, 3.5457395264165134`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"circlecloud", "=", 
  RowBox[{"{", 
   RowBox[{
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4ldsaVzlyuy7lKE3GCmmbdzTxc5TSLiUiCW2KlDF1OhpESZQplMxH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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lGsYxlWytZAiibLGEUdSiZZbllIhSSiJHAkVolRIypI2WRKJskRI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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs8lIkax932xEaEyi2ki2tlmbQ5Oj8REpXV1a2sEx/LbKxLRa1UiIrs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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVHk41IsCnVARUupmSUUJJVkut8XUQV5NlIoWqSRLm1eKLJFeJCRahKKE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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lOsblkuRUh2dQmXpONmidTrE4c7Rnqw1aVGWMiW7ysQplSXJmmOi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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHc8lW0fl4giFZJVhLaRSEp8Fcl4KkXTSBGykqchJSNPZQsZkZGRJFsa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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs81IkXxdhSbWKTlLz7VUravJMcSumHPEpKemD1EKKMqJYGeYSkIbSV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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81Isaxm25HdTRaaPcMaQS7r1ZT1l66FBI2myV5FgyKGuYCAdtsoVD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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk41N8bVSklSRFCSCVtyBItOopKo6QMaSEVspaKTFIoxTdLsiVUylJo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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lf8bxpHKSCHZWfWNSiU7yiWrQlGElnxTikQDqYiWJElDQyqlgWQl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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs0lXkXxx3lkpE0KhYqUjJqUqS00LfIhFcXkUuuifNKSkmRTMMyruOW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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41AsXx6mriyal3PHSZisUkoTQ/Qrdp03Z3t6uLaV1cjOUDJEtJYpo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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk81Pkfx6csOzuVUhLWVY5FkphVTfJK5AqV0qGcSUu6FjVZJCqKXJUr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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2cgVn0bl1FGZDSoRB5PtkRF8vSTlTZllE1akrQklEJIKkUqW0lWIlnZ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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlWk41IsXx9WN+NNeKOraUorClSzpO9J9Spab6kYRlZItiupas4RUtmhU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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs01IkDxSkqLbEqaVq/RFGSx1CpNDcTU7/y2j1WVB4xqNSQMyFqEXkM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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lWkbxyUlJVvT5C2MvdNizdSJ8jMq0RiV155KsidRpmjBpFCRSihR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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2cglW8bl+yRsoqEyGxpUtQPRUQlSUIlSUOIKIVIRaESpUKUZP0blFnI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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81AkXxilC666U3pSkIqQsttA+KhvZtqSbxDYKIYpa0kQXl0lRSS1l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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs8lIkax2ULySm6WGHlsmIrt1A49JsWKbVat0LUVEIXl0Qhm4kuHFMp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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs01Pkbx6eiRTSuv5BQ5NJaypZWybuVipJKtpVChiS3VWkYIZdK2RZJ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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VG8bliIq0qZEEkJFIkXid1MS2pRkSYSkBVGSaBFSoVJkSaEoa0K2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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHk81Ikblghdi1QSsXJGJW0Hq542ku1AlMSu2pwpZ6WIT6jVZeWeksKk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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwdlHs01AkfxuXyJm1JhC0yuURuuUVk96HQZZNLii4iJN2Q1LJ7elklJe9K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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk81NsfxqciuiXJaHELY4moqCxRPCktCm0KSUW02rpuylyFSpaLGGMp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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VW8XRcpQhpCxhERJSSmlsiRDihJCKpK5hFRoICqSQuJXKlMhEiUa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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41AsXxyckKVqkRbxZIlt1s6XbvX25cVtkvSHeqTS5Ra9b0yZtlopL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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs41Ikeh4eWOnKsUIgKTaXIoaUnbZ3PdMGk8khuW5LtLDkqJWoprG1U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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lOsbxodKkj6RFkXRSCF7KtXkUo5OOTqlRZiKY5mQMiRRFOpYS5G9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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VW0XxqVIkiSikpSSSggNb8mNjCVJkkoqkUIUZSivoYlSJENeSZTM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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41IsXxhEpS1GkLJXSLkZF6qoXpVDZCl0UikIYlaSJ4t4uk5BkqYnf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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGs8lAkbxqehJYUpqbcDsUnRCUlILmfekmNSCVG2g0Q6aTcZSnKo6KBa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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs8lVkbVWPKuBRKESm5VSoccqtpuU0hkTLSjHKrSGp0nHL5okg6IyOl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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8le8fximzrFQSkk2SioZSLjRERvoWkiSRUSFRkpW0taRJwwgJqYwG
sh0znGPPhPM8x4iSlfK7f3+d13POed3PfX/u63Nd74+8o+de5zlcXFz23Fxc
//+MaPGuXupVCz46RDUrm8L6L+WH3abyEVZ1/XKOMY30L0puDaFvkRfNvbZm
gkIz09ltj3IDdp27qh+wgAb7hK9ysgATneZzbsWo0uBbqjKx06QJL2+72Z4Y
/44bj06oNxxugz9T7apZNw2t4CSNlRVN0OsxKxbMpVHqu4+n1awV59z/DadH
fkfzimcWbxKLsaJezmW0mgLjzNuQy1Lp4CuVCHUwpOHxJLi06FojVCIcNvGG
0di3E1Jm3LV4Nih/4UwGG15mwqeNZjOx7qH0hcVCNI7FyUvJyBbBPaz78dX/
aPioRM4ftypD/PnMuIePaEQK7BtRtqnDFT2DNfb8HOj//iO5eOo9Hk3K9PhI
03jh0lFk5JiGM1ve7nhvQepxMs8qTjsN0p8uOD0ZpCAte1dljXcHxr+uVVIu
HYCMyKPEZWGpaN66cjx8Mw2lcNG/KeuK0XvgXGnjOxqcuHlGR441YnnZ23b8
4aB7vqLC4cUxuJ1y54SeOA0H++/UZNBnrBXisok4SMPO1K70zXAb9nOHhHT+
4CDiDYNzIC4fGWcfGFnJkv/7rrhnrc2CgHVCVUsfjWLPrAHFTW0YlFhetMd8
AK3X5vxa1lkI85OBj5vsaDT5sc6P3G4Az63ZkkVVHKwRsfbwtS/GDPfktReC
NA5O7ueRaWFiuGlyk2ohG7YvXadcY5uQIfn9owTFgVL/SquNMfWIEPtzJ8ea
wtWETLVf4gxcEf0+YMNH3m9zcq1NdQlsZFaIs+Io9BhO7FyTXYtwy+M/hjVp
5Mt2cFjKp3C6o0OpQ4GGWN6l5pi1H+HgvV06NZSGrfXTKXpjA3L0DkmLrqRg
O1e27m5IB6QP6E5gLwcCb6uY5b+/QuXf37a9JzkQs+punvFmYOeunS/GCmhA
rPbfLqoN464ZyjLrOFDT6H61Q7IQphMFRmkSHDCUj8e1lmSBawEjMLyWQoBD
6n5JoxaM3zMv75nTj3wp/5aJ5ZV4KJYl+vQqjSSLYzomRV+gFSD6bXwL0ZvH
khQ/6jPq07fk86ZTGGo9fUTgGxMfzNolw7I4sHN+o6W4pwR2H3cX3h+msMms
rSjSrRYs37sDXSwKXG7314xWXYCI6uESU3kaS9osbggHt2DP7LROnBAHskd3
d7HXt4LPc+ZZoeIAdo17fbbsSYXT30V5lDANiqlWLdGagXjtxS+Xd1Eo1bg1
3S7ZABE/1/VDhhyE/ylSvdtXjmLdwvobQWxcagplfvfNg6+gtMz57xROmk5k
nzpO9MLL0q6rIP21KjDv5pMv8JcwPJFjT0MuhnksdOcbtKqqz/0sSuPbwejl
H7PqIVTgUr6S1DtMPcpAdnkjavSHXv48wwFX939Wqy9Z4FH2wsJmch6dtqAi
yQEmWAt6Dlfz0LijcOXa/Y95ePJ507tUst9o8cGZP7olEOn2y9xVTO6f+1r/
UvdM1HILplTI0QgpLX/25WwQ2LWzWvbkefJr4tLpRV/xrpIu5N7QD0m3ved0
HfOQky28SnIH6c9puw/UxTrY/CyfN9xNQWXFubnDV4owHHKHuSeIhuX7V0GH
ROrQ66FSIvaErKcxtiQ+ohiUTJDrO6K/qyfnG6RNlKMmOku75Ae5X4sa/Ss3
S+CX8ffN2l/Eb/gYHTeGGjGndT47nXsAKyJ8PO2MG1Ceadb1po6GcpTGegG+
BmQuFQkKK6Mw3sf9+rkRE+66P4aGbcj+nDU/LH7VgfBEZfEPWf2w4V383rup
APXDF/aF/aBgtXbzapt/1Qjl/5M60UxhzwZuP+FvQfh3768eS5FGwICDBF1f
A1ntY/IXp2mMiDNlyt2q0em699RVooc1tkSGsqUwZO5YZbmfRlpusrDqvSYY
1Nz0GgjrhevM0Dmh6QooBOXO7Zqgof+x49a60UZU6gs2GYzSGJM8VSdd34iL
r3vjRmVoOI3NcdnnnQnH3y1Veado8Lw+mencXY2gtsKQ4+tIfWYHZ/T3l2Kg
fw7v5HoKErHrxbPcitB/qiN52zSFxNqSy3azpbDl0emojqaxrsPtveOBarhK
NPglO1LQf9Wbe+7VZ0y1W1xgk37iCREM53wsQdriNR+GO2lsufPVSC61AFIx
Lp9CW9mg7qWMKa6KQX65RxIWEn0caFhYFN8C7FaFZiYbotJZK2aNW8Ar6bPh
UBWNm6lU59abNVjo1tV/1J0Dyb+M/r7Oz2B0cmPiG4XzknNYi07UQTjcx4hr
Dxv+M1MP68SY8EphKXPP5WDDCU0nXf0M2O67O3NXj0ZVp+jzm6qN2OTxoMrK
lkISU5fLzTOXfC8wOQbSj+rxvfsD70HsY+hhlxU03inqLLljx8Q4l4Kzyx+y
36t6Uc94WLjoeG6Bk/wA9jjr3LT8ehohVm1vFIn+qDzJ2i8+dVCvZWf5vKGx
OmJfUKJaPVgdxvFlv9jA4XMNvO5dyPmgw2NO/CsS0Ns024KEEdHjnC0cHNS7
lB644wFGnU65b11CY9Z24Y+5/PVQ8f53ed8pDgJWxXycWV8Jy0SF5a1r+iFe
Pueyzpq3OM+712b4GI34Jsnth6TKkZRX8CcqnQYXPxfbyyIdTyQTjXnP0fDi
sOJNvzWgp1e6lu85ue8GVxNZ/nbUUzpVG136kF/9KGaxHMm7Y7aHRdkUwvKi
IvzXlWPFfNaRn2S/z6iSxnlL2sDvaf7jNsk3STWhuCC6FYtkz1GxZweQ9Gaq
qZtdiHAPmyqtTFIPx7PB6X5JKA78ujR4JQ21u1qT2+uS4DCUeFie+NGd4KoA
g4rn4Bsu9hok/CE1biRmWtwM9YSNvy8mD2AwOdFKI6sSSj//6Eaqc9A8Fex+
tiwXI21TUjY1JK8mZVV7G9IRHney1FGNrG+4rOTXnWbw/TKY8SJ6jS+9wLJs
KUa76AuGSDMNBbN/9u2cUgg86Xss00FDJmoVt1vmOxz9Nxu1S4tG7X5j27n3
yftWuW9LeEaB32XQTlO+AFcuzIVaE+mngHu7Xe7UwqlvVuL1aQ5O2DjEFawu
wiG5r803SH2fnLU3/mJZC72/NVbnzUn+WP76OVXxGLsm9cb7JGjY/PD9777S
Z/iPSOzoyqZx/NjgUy3VWoSaDsomkX6t6k2bOmRWDpbCf6/XXSd55ruMk3a6
CSOyCm7RxWwodd1N8HuaATlrWfSr0zhxJK5c41oTrIyqY8YPstGcotPAZudj
6abLVn1HaVjxaaidUauEY3bVJYksNmzip+0WrPyEawJpN1YTfonu0+3TPNyA
XoH82Z/d/SizLf+vO7MF/2LuSAh2saHpqdrN8WPB9bFyUbI2qWfH0EuRuiYU
v/XhXZ9Pw5XllF21rQlyHgbeYvxsJHbV8ZeN18NFV2vW5DCF9BsC/LcfvMaz
wIjzefNpmPatYTIMKlDZaqY+QfTO5cXVazkpD8+zUUf/kLyZOWfR26pfi52S
aXPiBwlfvdVvvpzXjLKejYvkPxG/a5QPfyb0BlJzv/++Q/wraZtThdZwBoYM
XmSfXkvj2efNwbKK5WhtqNu0jEmj/klKm6lYFYJjfxdK19Pwm1U3cOZqx8P5
yZ+O+HFQ+Lxi3CmkDk5Pmdv8r5P1+5sPhixrRv5rP83zYxRkzaOcskn/tl3h
SxSepPDmpN6WjJli6By7d0SY3PejZzzeX3+XoOGCb1oMg8KL5PL4eE45pq85
piw/RPywz+iQCuGxOMnXZcIPaQh0CvyULojFg8F7vo9W0yiI/7FPLJsJ16ZL
1YlWFBS2ndcoVGTBJDFK94YjB2kbVlk93duE2MAVDsMpFLqjW1ammd5HkopC
k87/87SqWUjdrxyp51zomIMkj2TU3YQ3FiCsKzZyD4vGdEpxr1ZNLcYe5wTk
nGbDIdLodIraQzDaslu41tC4tTUoNcaHiezCGe2pbX2YN1fx3THtZtyS+jSU
LkUR3k1eZvmZhbS7KfUxpD7ba9LNikxqccb3ToifFgc5v0dH/HqbESDwTGhd
Sh9U/A9w206xcFviz8SeDKKvuurc42OFmNsW9KnfhcJg3CXBD0blMLHlkkwh
ed62TCdwsdg78LHqfq/WoRE2KjqVOF4FPfPsnvdKNLrdtXJ7bnRCT7/K59sg
B5XzdAKWubSBY7Ahw+ZHP7aE3q+YL1iKTbyjHh89iB9tazc+KluNxatSuwTF
CV86W6YVXyhFarP9/OZYkkfDPvxrdVjYGWQWPvaXjWn7TA0ewtcjf7PGP7YT
fqnrZnI7JaNb+WIniB79r30XbLpbAOPKLX8HztNo/VL2AmMNsOnUY5jYkvVr
ciIZ1R/gl1wo6TxDweHfGa0TEy3ga30Y+96UzC9xyuvo3SWolmscTvIj/mKq
/5ITTfx3qdTK6ZoB5NUZeF2OaIf3Hz6L6yM0DEv9jVUuNGCj8c0to0UcbB3l
avoT9RFC8Wk6HttoCJWJiwodacPbl2MV3xM4CNGyGhE3Dwe/Vtr1HBUai6YK
aR3lWGwIjbQVJvXjuSeRKtDLgnrfUd8vxF9deX1XzNlRi/Sl3WL2TDZG/pVL
yfAlImDBepM6Ml+pzVt7RruVASF6jO+5JgcaolJhGwU60b5bvXGeUz/0E8V2
b4upQkFq1UJfwieGM95t8YZF4HJPyA124kDO8u2+7spiKNaWV2eQ+x9dpuS/
0KgZianlYyNKHBxR7353/l89apMl3PyHOWiVWfe6TKsFSt9abvEZEZ6eCSrg
7W+C4VWh7tF9/UiXnqcVIJMGk/1rdBVIvhbPyj3ODCvD2Id+J34vcp8uaY9O
KlTCa+MO124yPyVuTq2MnMci/SkVxtNA8vo/ZfuekjwkaF5/G5hIgY5N29Hm
3Q7uhLIzW0hecqX26eZKuoJnR7G7N1mfq61SZb6gOy7fONC1iTyPj0h/sH/F
QqOwT/U04TPD6MjdXV8+IO6h71GrRgpeqSRrOsqg3XkZ1fcpRE4XTC4QLEFW
/lTUvP/z6aqQDZvzX0Go8eCxi4SfWa7xi2WmGqA+avGf5V5yXivb+sbcfMQX
PhPWX0ajz3r89lypDrziWr8keAOFNUmje3dxZyN+Wqu/6y0F1rtpXsP7LDAO
32yjBTgw3dpyaGqgEM/E3yWZ3qLRs2DdnBX99VDeZ/2HGuDA/eD3Wb6XDVji
Y/Lbc4DGqm0a+gnRHZih7k60VQ3gw2MD0YedDGzd08CQNSc8Sok88Y6Pg1zj
Jsl6ZZIvTUFRFq5MaD884Z5O8rzb2kzOr6oOiwoENA1HOIieZli9DHuLg/Rh
0dXEf6ObReyWVbShP/5g+eAVGk8z1GQ/WzaiR05EYnE58a/1ivkvGbno/LlZ
eyOp7y8Fl305m8n8W83158cshV2jGSZFW9sxqkSX3ErqB9eNItWAIy8gNVB/
3UyV8ETFY4PnylnIGLZSK+2jkGL/l/30fgmSGIG7GOR3rqf/pnhr6sCaZ+O4
4RqFhHlr6y2XtkA3PJnfjvDDok02u6mZUvTKvD57L4NC8uMhKyW3OszvihE/
UEHy0Trii0FKK+zm1GQIyRG+C74hqXT9ATz19ntvIPnsIN+97WENE4ZHviXI
qw6giXemZqEmqffvds9ICTIPXV+40/5uBRiM7KNNlRQ+7HprXMOqxrBVsI8Q
4ZP03o3LRxQYOC+XNNeL8Bnn7pmcOpEmGFE2SuJvyTy2fLvZZ+lKZGXITB6d
JO+bvcwTqvwZfhs2bn5BeFSTz2H3k6tNcPJ6PSTK4IAaHBgK5k+GtcmOxa9W
0dhl7b1dfDAD4V8/mfoSfzcvbLVxVC2A1S5x4RFVksf9mhUp4Xn4fi9XMJ/4
0e0VXvOlYpsQI1mHjD8UGn8UbQ/RJvMra9Ta4AgN9w3GQiqCbViXYKf961E/
dNbFIv1oMzxEHBJ7zAeg7L1O0Hp/B9ZMdWT72A5AZIv1wdmgdkS9cblud6Qf
V9N7Lubz5MO41sNQl5uDpEduQvfFclFjEq260YrGq7UTLyy2N2OtfFz8zJYB
vLio+utocDGURHx4UpeS+4z49tDILgdJy6XeMQmPhn5pNg/81YwIEcWfqgoD
mJc2PnsrsQSTgT3XhYyI39V6zlq5ZCPWl02tIrzPJXcvRyY8CobXTBbqLyd5
nay5WHt+NfY3zRxoCKehUXfUpsqwFGlZnVVvnrMx7mzEnWdTjSU7fMY/LeQg
vV6S8d45CwsvjJycS/QSEu/A1I6/huWMR3sCSP7qcM/nZ91LhqXEJhtjwkdi
j+WDrU1asIB7wJX/LwdbAkNO9XIXYe6VmW83T9MQVdvqWcj3FTzj9g1JXznw
Yf5MsDrYDD22n678/+f9pk8ZpcyvuHjZ0UPuKBv5i1IOety6BrHirEmK5JF+
4o3R4oMXoPrzqe0V0p/5IQ3ca/Wv46vHSYkuos/4bo0XjCeE19KbVZYRPnS/
eSuDpd+OKfeAK0ecaITHxloa95RBgF/zy/0hCidm7JynSb+0lOVwvRcmeaI7
YbldmQFWS/Q38fU0fDyNnm6UqcHkcb7N9TUkn2dNajP3FUOjcEmgZy2FiPd2
XezjTHAsJRyvK/Zj0n/UvDm1Du3Vn+xkfUkedslUf1zeAQsjzSELMi/nv/9k
q+D8GEzhQItnYoQHwy9pzjJq4ehQmhSWRGHsmmFoT00DFtaU3hJUYCPhoqji
893vcKJjU/xFcr4U9Uibc52kXv6hA1f9+6C29s74Y90OeL27rWkZ04djHcrm
qxPqEJAyeNvyOwXXaPc+W81avOkOlfzG4sD8r9ZSf40qfEpYVlFO+ik/XWfE
Z6gekWzPf9nHKDAKh7T8ampwvmPrQ50PJG9WrtY6JdRJ9DX5k/c8B3e6UsN+
P66HVMSa9zvFKGyLOhJVO1ILf4ltV5zJ/Ji/f9sX7ZM5cD/zUfcM8bd/r21y
JaK+4s5YcHLcGQpWPtEPHoQxcXxzeaxfbR9MpQIWtD8sgVqOjevKXApNCwKf
33jOApfR7HlH0p887xuPxTkXoDKkjOoJo/E/DKwRJw==
        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41IkfnkJrPdqsbCappSRyROSqvKu2smWZ7doRJaIT5ZhYJFpnpUPK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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwV1Gk81IkfB3C1GeeiQ6RayllIyVXJh0TCqm0RodoSkURJjhwhIqwiHZtC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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs8lFkcxl02uZSEotGNXWmT+yWp9TCUS9qkSGsQa6Ry7SLS7kRWqNQS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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Vf3bxREypcyFlJIhMkWpsCSVBtVDqSgVGgh5IiJJktSPzFIpwyOi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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs81Pkax5GwViQlsXY15RKiNCqST6kUdSIUNrGlXFK6yKWbu45LqWyk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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs41IkXxieJogvtbLcloqRSI0xJw9uGKKk2LdLFZSN6Qq1ri5JKJVJJ
TSi6TuMnmkilpXGbcb+MMc24xMz3OxeaX6q1pVbZ2T/Oc/4673Oe93ye9ywK
itwZrEWhUOI19V939zSpDWG146icNVSaTUJUbxMdS3uNI4Gxfiu5UpQEduta
zWoDnzbvf3vHSBix9GpHMwR4T3T/c/McAUuPmWdHch/ju2jmnb5NKthHUo/J
ikSIMBw035wgw966W55XLPnYtSv2YBRDAWbDJ9Ww0yvYPnPyGQpUwjrY4OkL
9CDHZ3bKu/uDCGiL7E9KZIF/5k4GO0YFl0VrWNQYzT4zKE48NwIUy5HWaZ9/
hrsyft1R0yE8HlblloRehPfkucaPPqtwiHg/jxbRiYJGy4YqHxIBMbh7ksfD
QeN6nilVCa+M5Omj18Q4f8bWsXORRo/60TGz2huy11XrFi8cQuiFtMDxmG6M
HSgQqwdkiNsR9XjOGyGGdFuPFiUTSHfzeDnGF4D0ZzLtGARkD9RXRUwBTj5/
UJHSSGLmuMejff4SbGgUfjOfKoWvWvJQlHofZW476Z2FKqg355uuecNB/Kbe
HR5bVSA+fHALQz2qtk8/rtZTwj42MrE4rRUxQVeqmCMkxvJUZnrWVaCae68J
36fEc5Ejc9IXHs6xW9qLpihwgtxjiIVdSMuyn5xUQMJ6sey6r28TIjKvFwym
K0BJCnq9RxKKrI6/x/LnD8F6m+hE/8c/EfO1e4PFqBL3ljq5DiQIoaYlBfJn
kFBvYTMeTm+FkDNxwcdZDot9YQ309h7U3y1fPawehOW59TlGO+pQFJqrS3go
MOxWurAxrBvrOvJLHFtkOCKha0e8E+E5J4QlGZLiomiV/nlRJ3ymGnC1H8nh
a8A6Vq/bBFv3/lFbmRyJCtWVkZcdCPm5+96SD3Ic85xm3k4T49fsnRxfoQwS
mqGjGUcIm2hDP31rEqpb22/Y6rXCcvlDS78nCsw1OnSXjOTiwFRPbsJJJZwu
RMct3SMAW87l/xJPYOv1OMatCAmC/DzKUhyk8Obt/yr06QTjyvZpqVVycIMk
R3VrbyMlZQXduUyFNO0bs2MP9ULY9Ue+TtYg1P2FFaP32hDkkDlxeJICe7VC
7+U+EcDFxdQo3IvAQjHnx4IJjf9rdN41fyVwJF/Zel38HGaT77foFyhBefwi
O82kE1rJA/rOq0j0ZMu0Yib1otRlhVmwhvfDq7nfdYPr4Newq27BaQWi4ydc
QvqFiFpvTxeHEBhnJb8q6CrBRidlXY+vCkxVwWDp2VpMsotsrDuuQMynsNNb
TSVwb6V5ps8hceF+5dj8OCHoS6p7va008zDYH1FaC4Pwki2VyUrsvTn0iePe
CEp7VH1NvhwTZ880u67swx+PMj+/YMiQ4t5FbfPvglNHojPtohz+y36QMo27
UfJ0ppdvLAG7iIflVzm1ePlXdmNuqAJXut8mXpvSg5RtNVHZNwdR8fsxp4RY
ARz8u26oHsqRvuWqiVVqC+6t/W2Dqa4c4ryzffFzm2Ca55W5liVHg3Tqgm2k
GGEDch4rQYqxQKONzeU8xFPWJDFNFGBf3pqmbSbA2INvB7azNHzW7x66Sm9H
+H5Ky55fSLgKjU2MKxpwuXl5w3/5Io6eMcP14p9IrnWgZGryRfxSEBWZUgGX
O/4zjqcoMfzTM4cFOWI4FPkW12hL8SXOvjFk3muk1Qdq9zbL8GVRZXnlgBDk
ctsHhVokLqe+CdDa2IZCygkrPyM5Cl33WZnr96P50rbfvLIIjFKSsqfnt2HQ
57zRRI4c/4C+2tyrB01/vY+5tJpERTX19ao8EVY2DVXQFCSSA9QLdboECPcz
MciNJDD2dvhLXAIPw2wbdZ+FAtk/naonzvUhfXbGkQXuBB4n0rCE0QGLk3Oc
+KMkGqrnbPr47Q4cAnu73IpVKNhAMS9nPsGTPlfmih9UMF1lR591rQs+HEFW
trccNZf1qN+2iMGoMrII7CRANd7QsvvvKnyMLrsktVOC+SJawGkXgrGyJcEw
i4R7tGPZttJqvMlZHJnwVIEW06UnMg5qeIg83myZSmAyqaVb7NUJC/XT2ww2
idFQ+sp5F8qhyHJU1xir8OkWm9Yx0oYwvbMSv3dybDSdtVV7SQ02rz9lEuGk
yS99qs5bBwHivk5ZK08nwaWerivKyULpo7d7qodVCPV++sY6rQ7J61dbJKxT
au7gqMs+dRvzTZYdHnymQts467viDB+lk7pkLwIUCFjmba8zpwu7bUbEehwC
tM/cSil/AOEuP7q/2kUgKLV6izCvA8WXbZ75H9L8gySbwv1sMYb509mjl6TY
tS7+Nu9iM8y0Ur7Ldsoxbs29b/h7K2qCl2zu7pFDjz72YaqnBJWLlAwduhTJ
HlyhOCkDlCi60vJvFea5bXR+RrxCW94px88aPzcVHzRbGySCslnlGHxABqtx
51UHtNvh7cVvKrshh93/eb8uON2Jt/sP3/FvI/Avnx3IrQ==
        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXlYjNsfH3G7cVusiUhIi5S0adF8UlRKiYiiFP0sibQRklQSUTS/Vgmt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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k41O/7xUWLJJQsRaK0SyqKFkcliZRKPpKyJEqFJKlspRCyk+wl0bco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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk81IsaxoWcScUUR1TKVgrdMx9tQj1aKJUTZS2EUzhJpyPdooybcizF
kZs1W40i66T4SKGyjWXGMItxDColv8VyWg5a79w/3s/71/vH8z7P9zEM+O3g
cWUlJaXzivn/5rWtz9M4041S9qSuw1kKrPjils99tXjiIV7pbUDiaZrFlqN3
MqDdXnrg2hECj9rJR1tDhmDL0s808qLx1C8l+9tUHlJItY8NvxMQiqi10eXP
4Lm+N1YjlsRoXZPQZUyEBnO5hts1CmsmZgZ867lgR22wipATiPe5+t26rB/p
DBO9rFIK1m7z22Y/CbAnu3tXfhaFhIu7AneelaM87GZEYTKNbdOe7PWCYeQN
lVltKaWRM1Igdd43hHqbiOdaG2kUP3zg5akvB5lSUHltzziY0rLxotRalE2r
RWaokvj5ToB8ub0UNzQttWasabxz99B3WNIA+Tv1osYzJFSiV+l9XSdCia98
VUYOBXfxsnf8yzWYn1OO8L8JhNlymto2iFAXObXmkD0NtV+vinduEkLwhcmw
TqCQTthm5xFSiN5o//TjORrK861/LHDvB8Oc2ajTQMHBKWrxiR+E+OZYpWLC
pkDkt6VsNe/CpvDm2G8mFLb1T790GuuFEvPf7mMLafxxfeDeHnsJGP+Z/e+o
HQ3bYrskt/4ejMxzutLWQcG5oO5ixA89sPzA3aHeSYE7meKX//02BFpFh0Lj
CaSszLBdu7gNX+JeeA2PKPyUqPe91hNhaog8u0Cg0FfNC9U63ofw9iJW8HEa
BpE1v9xWe47A+KSeCTYJO+1ea+Nl5WAN93cWVhCwm1UqMHx6Hnwj/2QdSwIl
+zV/UvZsg7aEbezZTsJqYpgaOsWFpSjag11KoEAtOE/nSQosAgQzdS4E3njN
mMaWDYI0yHkQGDiO5nX7xGYiMTak57eEfqFwsa1sNEizA8yDf77uAYWAeZdF
BTlSnFxlslxLn4Zw9Zy0yPhqCF62xKUwSTA8WUrZg+2oc9Xe3EWR6HvB68mo
FCI8mPOZe51CyTEG/1yuGMdW3W85wqfw8BB3XfmVDnS8Yp0UxlDw9A9x5nkU
INh4wd3QCAKMLFPvvN0ymMlMQvSv0Ogy3ePk3CrAp9pnpoH7KXyQ5RpabOmE
A/vVE7+NCr/3bSpREQzggnuAgdiMxmmeoHZGXAuT+0m7xQtJaHEmfg2aliLV
yuPyn4p8ajg9NG52bEbmbWvXrS0kdosZqSyhCKTZvSviSgoWCRa6FxbyIeE8
Tq30obBct2y1vU07uIyqwSEdClbess2rD3CxLc998T+9BJ7NtIrvTPVhQfH0
1+IaGr/rjd33nOnDivOX34UZ0yh0Sok4uvY5lPsYJfZZJNSzfdmfG4WIUJq0
jDaicHr93iu1EYXY5qyjrhdLQHyLm15lKMNazvY79tU0wj7MHTW278bBup09
hu4UtH+pzlDhdSIUyfxzxyjcCM71P/q+CWpnmaWmPBLFepkqOyob0HEzuL/a
hsSA/1Rae0Mfkk7HMNcl0LjlFTe/Pb0P3TcnT0400mBFzf7VVVgO2xh21/Zq
AjrTraGqrv2I2VjxvnmEhixqbSunvhVSs6bg6FckdDXiuDYbG7HjMe+M4wES
S7IWRSYldsDMwHuOSy8JS0K6d3vgELwTThVbP1b0k0euX+P7brhd91lUsZnC
tH6s0F31Ab7EDy+34RNwDpFnxVsK0cvzOXz2okKP0rrI7U2dYPkn860dFHnk
fN++ub4TiQ6Of3x6TSKzamnoV7EYaUZOc6SfKRyOzz/dPVcEbRbn8Nw8Csy5
UZdC2m7jWoPEIjGKwJqMF7t2hEgQEDRQK15Pw/WtsPxQqQQDNqyWcEVexPsW
vglYKYLP1XLOXzMUXHfHxp0pkcGuSjkxZsE4zHPnLXLxGYTQiTs+GaX4x1uD
HX5dXCB66ZiniICr/Qufvbw2JH9JK5LzSVjru9XLVPtx+UQi5/Uojeyc5Lui
S1Jwh48Szor7FxuuL0vUl0FuqSPUVfBUWOM2MnG7H3cuHI41V/Shs6NkVcaJ
TqzZ/TLjvoI/50zDcM2WAcyMVizPNxmHg2lWXk9CP7L5qo4DaTQyh5aF5gTe
RNiwrg7fj0CA1GfEWCiEKZEk9pqgsDStdcW0bRM6vQfvOmaQiDc6We2iOQCz
rNUH0xX6Xi+58fNmtxbUfXx6zz2HRKCv6F69ZAABiXevTfqOI2VB06TPbAUa
DxiEBDUSuPHk7yVpEhFUNbWY85fQkP/rZuy5GT6KGp0q47ZQsPNJ/cZpa0ew
6Tev4+oKvs0Ha8yCuqBRPzaZyqRQy5vaoiR6Bjf4Pip5SqLWOcPbaFsLUgRv
vYKukpCpXxojBVJMhIWs0Oui8dvS8fG5/hLkysTsoFoFnzWzz+vc6rFamupy
i0Vi/5Mz5oylVWhJLVwo5hHIGVbWtVrUi8J7w5IjdhSKy30/7myug0r33pOf
zEnY/nNKds50EBVxrSsuOIzjf+xq0jc=
        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVH001IkClSZJr6TV5qOEUaLShJSoq56h1IZ8Ljb6YCO91sjnlqyEmjpk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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVmk81WkbPmMqLbaMURRDjCyJQmksl1Ba1BgpKp2MHCRGllAhNaJSh0S2
yprSYmtDQijbwbHvS0XT06rEGE3Te78fzu//7bnua7mv+yg7e9vyRDgczkX6
/f87a3Ra4V5YJ84844WEZDAMa/89mZBzC/pff9QwXcoQOfkoJjJbCClbTW3u
Pobu1UNKZqcL8Vx988bmZQz+xnJzcVEAUU6nw1FnBl2Fz4a1Uan4JKZ3Yr4q
g1lcUhmvowSuktx34qsZPA8prni7pRoJdvfrtdcyyI+ud4z0a8PdOnZ5+ncG
ucy+4BnnejFywkBzSyLD5ahfzIp9BThiGp6btYdhbGjV3gD5Hth0RHKcAxmm
mmUGP04WofhhkoJQl+Gm10L+4ue9mPh+x/knSQwB3OPcm/924tb7PJnd8QzL
4rpHlks2IEPLxJ23lSH61/mRbru7MBL64juBF/GP5R/w3laMsXev7XUNGBav
Oyah/2sjZvsszblC87mq1Sjbb38Iw7MveYUrGLjay95t29mF+yZdd0MSGLZJ
LGQe5e1YeIiTtNOf4fwgL8b9WQuG5RI6fnNlWFhWPdS/T4jnTv8YSBGe0/NF
IlK7MjE01f/nA9JLLF9tvFGhGzPt507E3GP4rDLxaGJONWpfpkpuJr0suYsn
yxV7cHtTVcrtB+QHz1qm9GUu7kjZ/7deg6E2Vkw2c7IQZSX6Vz+oM+SvsrBT
T+uGYbhNPQoYXM41tj+b2YTebftG3awYYsRO50a9qEX43ffzSrYwuHtl/Pyo
/C7yJeJ01TVJP5dYK8nRCpT3tTlW6TBwWs6XXfDPx93pbRdSCa9I9dCX+5s6
cS80w1TTjUHdKE1hb8U92C3OzNddznChrsf3/vtuDGryWy0zGawHSuZ3PmiC
HHd2sjeP9HXqTzy6vgrJ4vKGdpYM11+FmTtOF0PU868wDdI/bEtNg2x7G7jn
562NcWRo358gaaQyCDsnRYnyQcKvnRExsugxxgZamuxMGGK7S/Z71nXgdcD4
DvPLDImjhWIB1U2ocjeSmLOboe1728du89qxo0m2b+Vx8udNu76nTAsy3DxG
88gvPVezp5p7u7G1Mtn8VDTlrceZP2qch5Y/3A7+oMVQGt1jFqAygF3H18zR
Oc9wUK/Ja2tmBpSsHFPnkX8xh59L747uwKnEWcLPPgxK8RNrW4IEeHVhmv/Z
hvy3Wn18Y+UdBHFOOc4nf6T8pD+JTd3Dct6x0CjKk+kV+QrrawJkvb40nE95
T7Lfc8yjSYDckNNGN60ZDLZ75nyo7UVAHs9HKY70tmi1kJ/ZiCin8e3ZtJ9m
nnFxL/p94Tew03fxEob0wOy/S0IaSK/cFzl29L5+y/B+4w6456QknDpH+tUP
fRxaWwQOZ6PJCfK74kcF0+sNhVjJqWjzJ75Nv7CeVGUBJvsdbMtpnidWzc6j
Tu3Q7NiXGhzMMGSZNXz5URGiT8svO0Xziw0kc790tqKkUdewivQWuug0REyW
IMDx9SdX6gsR2dxA7eRW5CmLzljEZag29j/3IOQOrD+FSwwR3qs5Fq2qsqUQ
OpRLRlNfWMsGmclrtKGI65B1gvwZv2jgN24tROc1b61ZlAe5MNc/javrYTN1
r02P8jNsLF8/WpOJ1hRlj4CfGUYCh09qlwohX9gerLWL8Nojxf5ZI0THpasF
agcZ/ps2T99Z04POQyMNr6rIr2X7K8biS3H2tI3IT4QvtbaKd3jkCTKklyTp
bCK/Y+ZceWpVB4tw/8KNxC+NM9sieXkrNszaf656L/G/6SyhtqQH/PQ1H17F
kt83nvm1ujQhwVsiqpL4SmX2c8SVL0Fq+kXPEcpLUG/KD00tffivdoGv6xPy
Y+kcLuyboTj1Ubqc3le1CbwZP5UNM5M77pXUxw7rks4vTic9DsRmqFHfhpcd
qt8wvxeJ/NtR2jWUP26yinhwFcbUP7iN/sIwo/n9sWy9ZsjNOvLvvF8ZNnzt
O3Ng1g04jF5TD1ZjONLRstn0ZCt4vES+rC3DsY+qRy8EdsHc4/C3h9Sf2RaT
gt8ru5GVvrtz15/E5+3qwtzQ67j+ZeUZHZrHztRIx+G7xzgcH1zibkp6iI7d
+uyahViLo/nZxK+sOH4w+msbcDZHhrlT36U3P4zwf4K03/yET2lfp5R8Asyb
iuGa4/DXG22GiLnSNZZTZWhqjqmZ0qP32qzMFlZehYOGYqAL+dmu7PQ9L7kW
sw/ayu6lPKdtfpjefTQR/QE+kt9UGM5twe98jRZcUfIbUtlJ+28awNfSLMb7
lAX35fTpPrnvFeWr3oV9gk9vAeEt2Rql53SS+EoWNK/JZTDc32UkpfIA19TO
vHWk/rIu9dZRC6uG9NbxMjUj6sM9d/6VEq2jfvjn4xrCD+q79WYutw9nlhdk
Z5LfY201jevftaK23jl6nPpFXlPZ7EanAKbBCyel6X4Epddn75qqxbDfKwPl
bdRvA0sOvhXPg+x2ke3x1KdzjQ4YTKt24fY6mZAtadS3VT/5R8z0QGdivuJc
2uewcV2tIfNqVF/VrTM1pH3+S6m+rK8RfYrqNZLraN9E3lgVFWWDkxTu1Up6
bQjZI7Lbtwsrbo44XqL7FKFSc91frQeWB1Q2KV5kmG3VJbi/ogvavb5nLqdQ
Prtf8p/1NuN9hEHWOO3L5zzxpScHhEiftjHRofwKtQ663jnbjoKzgXm7/mAI
DdXdvLWvDd+qd9j9RH2ipFag4RCah+Q667qXlA9Lz4u3rVWr8IX728o1dL9y
07J8o/Z1YebjsloPukdBuTvqRXMe4do3+J8gPkHRFrx0pwqYOC2fGCX/s7wr
lzbGtUBq5bxpy6MMnas7rnBTqiGrcET39kaax9/Hy+XEJdSLC21dKG8VYz3W
EwsacD0kq/SrA90XiH57RP9fqiLOdvZTHnQV0y67DCbDVGOm9CnKS/AqnsyO
YQGcKnxH/MkfgfKia6m3BHDgRibX035xsywa/hCrQ/hJ/UM3KN9v3sXs6zk5
AFUlEdkFVygvq6Ta0/gFmJLxKkqm/pLZ0/DUR7ER3j8ohxhTPv4HbOii7g==

        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c81P8fpyRKoiQyEpJkVb4NqSeSBt9+lFFWRVRSFG27JSuVVUkiycye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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHs8lAkbFdbiy+aupC3RJuV+TeWQXLJlRUrZbm7lkihSrFuXSZclXbXG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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlX04lIkaxidbUhKV2iMJGZRKmj6stHtHnIqUSaSsaql8lVSKOoqdCjmy
MkVKsflsVIikMMwYGsY3M8zW5GPmfeddW2KntiicOX881/PffT3Xff+u+zH1
O7nnqAaNRotUz/93s7ht2Ox+O+5nN/e53yJQspkTEpGbCw4/s21xDgVtF98X
DladUOjHXdxsoEDA9el2+jkixE0aa+yNJqAvbH3SNfkKjTut6iMpAtNPw+jb
VSEiifed4c9JJFYdtZ63ux1XYvtjrKUEtkSzq7/b14baL/UJcl0CI/7n16Sc
6IJj2BD973g5+pfVsT2d2TAMjif+GqIQFmbrysopRmaplH7MioKkabjElurB
ptwrHkEzFMibTNA7e0yItAI6e20xicA5ev7v+x6g9hf7AadyCtMNWUc3vBXh
5XtmXfNJAkKr21vy2vjQlpIVPBclwip7uzkf2uCV04HkSAK1oRtZ/iNd8Ena
fqTRjECA4TrV92QvuHN/2OV/YRD9hUuefrhzD6u1/vQfFVDobAieakEXvLIs
u52z5YjVPMQ0HqtFqEp0OyNAiUDfqgCl4ytM9WU94RuSIE24gUXVYsguiUo9
7eSI+mKWJR2VInN//O8ZF/oRWPcy4gxDCK+1V7dONRGgFYBx1ocN33meh75T
+zHyQLGulxAjLd45aIIrR8X+rZmBNx5ij9n2d5szKMyZWuQuXVIDx2eW2VFc
JU7Ndn+l9O7GH1H5IXflcthozotzLS0Fg9fCs5+j1otmTEUsKEIb23cZ34eC
SfFcpr6sARoSh0fX7UjQdL7Vv9vfBdYXD8YbZ3W+sbxrOl4SSI4VHpeNDMB1
eKDcbkqAgcdnlxkkkjjysZw/7UI9rHKSRj/pKXG+ZcFxS6kYOdnbePe15HiT
+H6id5YM5I2V8YmWfYgcv9Hx64x8dJ267/ngFoWNjOdhS3+QwF77RWr03kGE
D/oeXBjchJbqmv71q0jU6uRPrr3HA8OmJPtikjq/4r6Oay2NSFWpxkPCSYRX
TpP4fW3FkkexJsV3FHCxLDE7cV0A/eVibuwEid513/cZ9wsQu99hwtZaCcnj
NCqD/gjeWumZpb+q/WA6xWzakAvTNLMst3QKN2+0WJX2FsDrjtkn3m8UYnJO
q3jMfHw1fhCukU3hw+6b/05f0IHiPPMyj4NqvteYMRbWiWATrPGjvQEJji13
e4VHD/jHb7rohynQn/Cjj0KDi1Ta2IErjUqU8a72j2qLMHhLi+e4gIDPDPu0
A6wa+KWVbKl8oMRig1mGQ+Z/gO3/8MSL0X5s1U2kNZc0AiYufc3/EIi5Os6c
n1eFFabpJfPclbA5dPcEPZ+HcvszeU9JEpHC6IUHFY1wkjwLv5uvvi9Cdnln
ngTTWR+FpZ0KrBg6omIYdWFi30YmXOX4qTW1/vAWMXpy81nGdXJo5ax7bf5Y
AD+GndBLV4nDFkUsg+ZCmLuxXhv7UmhP8YliHy5CcnfwP+QZCrUhL5VT50Q4
QJk/8txEgP+xcJ/5OzFOz/jd+5TFIDS1sxfUWPeAxWM5ZDXJUbVqJuMvm27U
6cpSrVbJQaPvza1I4qI2zJbupa3Evrgdaw0KOEjQOmRxOIDCUNTC10XidlgX
f8PUEwXMy9pLLFJegyYSvgpI6Mfe8cPJ9OdSnGivbNgYMICdzBR7ppiPj6Oz
Io4VkBhZXTOvUvUE3FMbwsg9FPT2Cj3O10nR+d6fG3NpAJGfg2b3rS8B3air
0SyEQpXpxToduhBxE0FL+VwCnPDWoJ4tHXAanX6Lw1GA5ev/6WfNN7iqUDqY
qfvri8wpzLxWiNMnqxvfThLYtdR6vfnuBpzTyY8WTpG4kneuIkTVCfb2+3pu
rQpsf8y02PGvCgTrmrq8FCvRbsCuLGQ14IJMJ/1kD4GdMwP7/CwlSOINr04p
UuDJyG6Vj2c5WjJDJ3ItKRTE78o4NM4FFXn7v+MqEjGh1Q3hfBHyjjRkvplN
wOT8O1PB7W4YuW6yJwYVGPaWOY6ZysB5eTomY7kcxdXiU9LoMiQ4uAZ1Wav1
/Lw4sykZjhQJNecrZQiZ6/nt3NoO1CwM4YxdJFAl++mGd3ITjkvbZyeqeVLM
XHSt6bma39ILnG27CLhH5C13bS1EjGvIa4v/qHlwfbvN+24yLpclMUf+puDY
NDZtZVYljr85GWun7ifvlX8K4ukt2PBbXqn1GRLDzhr+lxJb8TDq69S9IgKL
HGX7PS+/wlG+nulgFAnxOqMVW8vU/yTRrZzzlICgzP+8JLcVmo/WFLd6E/jZ
o7G3xq0dwijpMtoOBT7GlVW6lAgQmFJX15NCIiU6TWE41Ix7JlY2qW4EnFJn
5m4414Nhd+aSsosDCPvc/fAXtgDmPVEN46EkUhXPztYu6QUWNzSNMRUYnWmj
YTO/Bys/f6OVJcthonLuFF3OQHyBU+OkiMLy9HKHygNCdFLcwvpWAgUzQr86
ydvRVqph+25MzTeavxiNCXBza4tB9gol/geVHuED
        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk41Gsbx1UqR+icVuT0Rsp6MZYKg683nTZyaJhsEZE6QpYkco60HHQU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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHk8VF8fliRKQpIQkmyhVIrIo6goSmiTJGkhpSQVJUSyZvtZW4YoWoQs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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs41AkXx6VcmtyyEV0QidxL0mXqq15KtoRVyzZttpVLPLFi0s0lmmiF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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81AkDxl1Fot5qYkiuJFE5klXokViWt3KTiqJj28pQKlFEvYwwaJ3R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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk81Vkfxkwpr7SZolfKOtfela264zEpsoRsI6WIKBExlXoVouyGEmps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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3cgll0fVrSQVQop403JSEZCXpekUBQiWshKUikvmaUIJZFKRUNGSjKy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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs01Akbx13iyJttareUS64V2i72lbyUr6JQtmanpdymMO2FrbAZTbVR
qVEi00WUQhEx27jfbxkhG2bGdYb2qBTz+/1GmpDS6p394znPec55znm+53m+
z8cs+CjjkIaamtpxVfybNeOkw6eZ3agtl140cSWx6WWpJuthP2i1I2sj/6QQ
2xFxLbWoFUmnow+G2ZM4sro6yfHTIJbOG/X1OEAhJTrV9FNmN6yh8A6Vkmhs
sK9vMWrDjxO1e3uEBAoP6XIf58pw2elObIaZAmputEum77eB3b5AkmAhh09G
aozUWoxp26RM504S7H1FK45d6sHREpf7j+tIZObY3ToSUYdPo+VD5jsIvIwZ
jXw53oq42j1VISMEki4ea5JOPYLk82zHr+VyOHNG9ZOvyUD1nXHpWaKAC/eu
fsGYENxshjBZpSfEw1dx3VCMY5lzAt2fSXgszmGIh4VgWfB0y68Q2LCJ8tl1
oQx832sO18fkqFQI1LOG63DFeLUj24dAvPumKTd6Ib7+2s9mT74ctayi6aDh
AXh85bLY2ImCKMNy7kr8DXi9sfrwp7ccbstmql3qSpB/VaM5/m85RnYrfa86
SJAaXLWwbZyEadQc88CjEmwtMr5i91yOq/malZpxErQ2PA3+qpnE5ntW3Pva
nSh1vdTt70UiOzWTV1LUjXl1XWsurKZw0GaHuqFbFtS3fRh8ypbD/qT2qsAC
CVJq7Mc5mhRYKafNJykZNm91PXbWQQGawMXTrLcNuS/id0abkNiwo0Gbw2lD
YHHioFoaAdH8SLX/3S3GbAIv3fqJHBMxtMCdK9sRe1KjxU+dRFp9o7rL9ACY
6UzIuigYnNML0rGXgOW/OPbFIImepR0aB9kiNIvfuk9mk+i/G9Y1kNILmeOY
fuAhCsqADa+bT/fCYP1Z+++GSUTrewctyB2EZL5m2U9zFGYYFS8u8SqRuyPQ
lm9EYIjlcNRITwi76SHWQj6Bns9f9uyzkmD+eFbTqVwSNnccgpdbiRCxyOCo
8iqJ0vbeh2mJ7bA8lxFrG07CSMv9S8rAc+jeFQgGXBUY5keHiHxK8MCzxeOg
WI4TWnkPRlv6MNHENpVdoUCvj/PYeP8pmir2rb37LQmdGQuxU2A/JhJu8M5n
qPTRvbbMsxZiEVny3I5HwPHNEg0nQTcM+hucftKjYGnjRZ1AKZaafMn7Z1qO
vbL9xq5PnoGddP9lgBkJJSMlaeWeQeyetr9lWkTB43WBlnOMCKe0qYrN1SRi
1975zj+3AzFVbo0z10j8Nh1Z/CqvBuHicuVtPQLpE/0py3e0InaZTmMnQaBO
dG79rWERqi9bF2bsIqHW/Rd9PS0Lpu7BNwvC5eA2VW0fPSOG0+325Y58Enk3
1EL6wvqh4SPnPuymsGzleuHKgBLsv7ekzV8mB+08QzPQtA+0uY/qJx0p1FvG
sv851oez7QMW/ar7OR/2ZYz6daNvW/7HsQwSIoa29S2lEPy8SVuHewRm1I0Y
734QgVHcunMgXuWvWcst79hl8Cx848z7IIfaOQun+coWzKwcISfKCAwfqA17
/YiPodbA37Kq5Ig97/JHVEg2+OLQD79z5TC9rX/+7WQfvL7NN1BWULALZbR6
resCi7frjjOTxMhxmmDN5g4YGlcMaQaQoLWerZzy7cBeYTMpVc03IMKPVHsP
QGIQdfhVEIUNe7rrl9ObMJLmVJYepfITL+v2FuM+5G1PGw1ooHCv2ni7TH8Q
WcVhz7bWUGBWGb5b6Fmh8p1R4dbFqn4TZ6eWfV3Q+XUwXUonET98K0ef+wyl
hjn0KFX9j7/UJkynAx+9EhNqpwg0FxuVrssXI1iwXfD2PYkfx6okvwcMoXJp
cl38YQXyIo2PfyOVokdM5ylNFXBjlswM/NKJz12fsM+JhAt7r427ohPmZpw1
G71J+IR6V9yb7EFhbQCL40lBp0t9oXKkAQu+L6kx3E3Ab1O5RaJBH0ba13DL
mkgs+kbL026VCDVpLxofJJP4HPyeMGhtRszGMUF/4b+8e2K+RjCAB5ocl8R5
Kt4P1tDG2x5hmdawrmuJHB4nqCCZsAenj+eZ/Ier2m/2ksRR5hCaLH9+maqh
gPJxQ6FWRyNCntp+5FwikLzNkT2aL8EDq4R02ymV/kOJ3zNDcpHzRhAXkCmH
3x+L4wIKO3Fd3V85l0IicWrdk9lsMVoKmJ6DKv87dC44cia3C+25CSefqXj3
eklEVl1nJfi6ZPgKHQIsvqbF+os9iOx91XQzQsW3TbO0/zr0Qviw4uLsrOrf
V0UQdca9aEuZDL3vS0G2ueCQNvsx6Ltu2gYFEciiiqQ+n6Vw33lk/MMpCmN/
vbp6KroDl4moYA6LRA7/Hc2cNoB5wWOTy9JUPM+9TKdznmFn6IVpvR9IJHuV
6i5qy0Gk2VRx/jk5gvv1/Mr3ipHKebHilwskwsMTVmuZ94FrkvOlTKTiOyf9
xKKwVJQ218cWMuXY/8R77W29HvzdLKjgWVH4P9542Ww=
        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVWs4lIsWJt1IUqmQtlEUuuhyiDi9bpERddxOMZWUHZWhGbWLyr3YndAu
lZ0utImOS1EuYTDul4S5SWTGfDPfJ3RVJ6L2nB/rWc/6s9b7vOt91zIICPUI
nKGkpHRGEf/P5rosXVWVNlh7JkqX1six0TnXSH2ag0JOgFrBAhK2WwOcC/pj
sPOQEffn7GFsv5hCTsh6ceT9Q1ZmrhQehectt6jwcaJiiul5gMDcPlnHw3+1
Q21Hvo9PpRwBrWm7BEa1eLf5bXFLBgnNruvWnZcrsZH/+7R9Kwn++21Ffs2N
6B4fiZGZy2EZf6rimEoxutrf6h1dRSEqteHO9v0dWGjn7jNNydBknhYuudeM
g38+Kx2PlGM0Sy3av6YJFgtOBQftk8O+vm3CK6QBDSI3HdUtJD4sSjTJkfOh
r0FJGn6RgjDbr91tUQ+XxWeNYgblyDiupJT7jy7EMuwlro0EaBqtNiEqJaA5
XSz5soOC3vEF9oKuWpjdRvBlkRypInncx54+cGyfXBLmiLE6Y8MpjwQBzr30
fTQQJ8U39nRs2oI+fN2bZ9pTKsZd+qa/KuaL4Ov7sOxDvwQ2czyU267ycGYR
sygtXAr1p2FTsy4IYe1Lz1fmSOC1rIY283s7HmXGDhd+IcBcOGAWOlgGWs+W
2/qqFNrqPKJMb7bgwhunsAEvOTRLJR/MRrPxfMXAB+0UCucqLWZdy3iN6I+B
zbutxUg0z0vWHcvFxlrz1rI/KHxKWuFzMV6IA2m3V9SxCbRFpuvdH2vEMpbE
uEDRr6mjWaUrUADVEzonBelD8D1PnBX4vYB7WL2Dm4Lf0Y7Wdv0JAd4cczIo
FhHg+uSpbk4RYmV2UIwgR1HL6E2qefUIT8gK9C1U4LO34xs2PgPHTaziYEmB
crfK8/4hhHfEZMYboyEkvDoqGjvIg4Nr207HWClc99xYvluBb81noWiwhsAd
cO+qh/Nw8kd1nV2lDHsdBscPP+5FS/707q+mEvgfTjnCzc6GrLz4bHEyhV7/
3GqPbC5Ocye9Qm1IUGm0kHTzP3CF4dA49xOFeIOoS8bj1fAZjDZ0qiShbbFh
j7unEEfOKpexNAnYzsg2Zh3joySKWV1iKYNtrvPrvZduwbGA/eVULwWkxLo8
CH4JrQv17Q/pcuyNYseciqqB7ed5Ef/cR2I0v+By0X9eQjdriiPLI/DUa5Gg
+kk7qt8s7bIqlCEnZmJX4vIaRJYdXLWdToITFKm+spSHlRlkiM4iKaIigweW
s3kYDbkVYBZJ4JcsC8OBVTy8YJcGi20I+HtkCTV5JeA8b94Q40FBMy56Vmuh
CBETc5hlWVJUOd9PqKbz4OPtPb76AYFgf5t9i5ndSDrtHvelmQBD80uyxfZG
iDkMx90v5Ag39Cyc3S0EEf5t7LcDUgS2hM67W1+Cx98YG5nbKBBrbXcYsGqh
JE9YL3Mh0Vlt4n97XQ+MIt8eSeZK0Ttdmzg/OwsR1wKr7v2XQti1zn7SLx5D
Zj2ixzOGMbV9ZstxXi/KzZLZqeslcC6ITta/zoe9+uST84EEdK/qjBznvMK6
kYAJuqkUTnprrAIlfMhNn0zd7yYQlKhFsQ/Wwu7H8/37vUh41cjJXL+ncDzJ
ef8/FQpKE4ZqrWsKIMxiRySEUtAOTy3UPtmG7/YNTYl9Mkw6xh16ebIX3lQW
g/6bBD/pFbHxN+vQVGwyWPVZDo71bdN7Y33oNhGyWsekMAisMB837MHQqvIe
8XwCj1xcmLkSAegX+K6k7xBShSX+fr8/R55E3+R1LYkgK7dNWz8VI9+kKblc
ca9s9u9xXK9VCaXvYtbEIYUezt9zO9DJRY8nu/vZZhKMkNR/byyqwrKz77b1
h5OgzbF2GDl+C9/cXL9OK/S1yHypXYC7AO5LCWX/AcU85StzuiRXwQspXvx1
mMIuT7u6gGNtmGHQOVerToZoONn+lZCJ4TtXzunUUshhzClJtuJBtrpZ+6KN
DGfMVaQrKB5or9qUcrcSELt2HLMv6MGdM2yxcbkUmiOzpxrTO0F8081jdCr8
+6fNiYXGfei/YqG+TiiFLc/7Z0R4KcS0HaZtBhSKo7TWhi4R4fKh0qI9XAm0
c9YaRJg+hVrodBJjksQt+7u+zzREOEcb2Wm1egiTS2benL24Bxq5H2saXGVo
MVG9seVRC/SSVuySchT+2vVg5aOkTOhdoe3cmUfhRMdKZmxmBRxVPo9ZCkk8
rgtLnkqvwa/t1Z8c7RT/yCU0qU7OheDtq+smaiQ2dJ530k9rxr0+pnJJvwyd
TZMlHYp93yodPDT1QgLKhBc6OvwQGuMDiWEnFPp0bgk46sQHKyLI/907Ap52
4ex5Fa+wJm6245JEMRIMEtaN+D1H0FBRfoWIhPht9kHfj6lQIk+vblDwf7o5
UIP+vg+OVZuYXgIFP5bjOtuyU9BhsJaF9xS6Olkv0n/mI6P4aNb8wxSubXGh
JXCbMO/X4AZLbQVehtuOqm19CEhbcoN/SYy/AQqH0sw=
        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns41Okbxqdy2lRIS23anJI21uEnOeXWytKQZEMOiSJbaVkUIiRUWsWE
pG1UKCklZIhaZIQMBmMcOiDUK3LItUYqv3f/mGuu+WPe7/3cz31/3q/K/gBH
34UMBiOdfv77Lvw12PBnLgelvGPBhToEX9wvtUqnlWD002ha+gYCka/Q2eFD
C77MbDwaeIhg59u2wIlnlZATBeXt0SVYpKSyeOpyL0pn2Amn8wli1N6Z2d3I
R5FRjo27BgH7w7GZLL0WnBFWy5ntJ3j6rruCV9yN9y+llBpPE0iMLy5P38GH
Q3SK+Fongl/NM79bYvcKMmL1zFfJBHmTc6tOpQjx/uATu5Bwgt3aD/rOxbTg
VFkHz5vqCVdY1mTW04ZhJduo62EEUpy6/foTXXiTHpqdXUGw/ECRwngyF5Gr
zjmXmRMwZDv3ndD5AxWav5+SViXYU99ul3mnFFN5T51mNxLYGLidjTpWCC2G
o8HR9QRXxP3vJod2YqKNNW1+i+CB38JhF2s+Ms4VlSt6EEjGDPWdUe2CvmfI
oak/CeySD9pYuzZDPT0/7KYjgYW4mDbHqhnLOwRRoXupPpU2ZmtbDV76MWbn
QVBVmHHY27AZi81qf1pzgCA5imO00PwKStU/vQhWI5jq0Gy/mtMBUb2/ou0F
gvpE2dAvS2tRYptVa2pMUONwTLRxuwD/dlu/zzlPsCRqvOp5aAvy+5YlPPUk
WNl53+O3LS/B/ByjpMYjCOR4Mf+cbEVsqKb/WBBBZrtxa8HlGnh6XmRZGdL5
NQKnT3pXI3ZtzS7/TVSfc6pO2+I0BB555pVL9Yh1myzfbf4SOqx4UyafoCvm
F1fpOw1g6wktTSzo87RNJJMr7sEsc0Qk/xPB+5A11usDilG3N2vHKurviZdX
4r6m81HQU1/g6UBwr+nRp4mbQnzL1NbdQfenOSA5JAgtBrnu2hahSZA63xst
dokLW9VN7pJMggxWvnTQmgZ0Xo2oWeBG8DVykFmh2o2QuXq3H28Q/Fi+qT9J
JITZlPhc9TGC1ol3wyFPhNDJitTSjiCYDiqqimhpxZ+ZPf+c8qG/qzhjfwU1
4uoPJ54lu9B5czOizmd6Y4DpWyBB86GeyDjyybELV6v2M4wv0fPqU16kTaVi
m9NFNRb1g63KV55a3QETq2/frw8hKDCZs9ul0g6fRcy4jScI/l6U3aegzEVG
sdVugRGB8owUvm0UYGE+Q1siie67oH73i5EbEEu52yS/jkCp+O+VgZP1aJhd
M7KO5qN0ZsPr2w2dWLJvsLGMTeAWoTOhXy0EO/IRdGkfOsY77a2XcZFlPzDr
Qvf3+7acWAW5XsTw96YH1hP4uyhKwegFXrOk7Z2sCXTP6LnJ1LZg/rUTW8uP
7u9D7wPrHiEMLzUeGKf5Xtk0PRQR/wQ+51s0A6jeRxNYkNIggNObFXHasQT3
644s4IsJcGGLxBwjleDjs3kLi5o2hDyU9vjqTiCrIOPcvbIenlqiaE9LygMN
S6sG7xrwxhV69DdTP55xLFt/78K3bnHfl/cICmUyC7olW1Gu5xkwRPPKPiyY
X0348Duyh3+N6jO5ViH3v5N85Ipkue60H4tzGm6G9LfDQN55epr2IedG79vc
0V6wb5nr/U39jCEPAw2vpGCPjX6FPN1PSend57vEBTjl0M/RyyDw+6ih9sM1
LljrZi1O/EJw/V+H4ZuSRVBIFlOcp7zbnyfsF9J5yn5TGXl4liBki/Gjvr4e
+PS4smcraV7Kz6Yd3FcLl9iiTr3tBHFa4nuCvbrRuSleaSmLwLfXUG/RnQ6s
jx44oBVM+2i66lDaWQE+L987YRZIYHTxgprxQAOSxHp42Vspn94uaA872Y7N
xlnK53zpfpZX1x193IaSp6wCjX2UH/Z8/9Ss87jvIYiOp3ksqkh7vmKwCiE+
T87nUj85L3a+qhq/jpEIxpsxOm/f2H6pPJcqPFcf8EzUp3p7XJcOLuAj0dw0
QOUg5fklsSYO8yFk3UfrbGi/VqyeDft1qAWDy746X7Kl+g6xFP1MKG9DfEXh
hZQ/roaW6r58vJpNF12l/GIWLzoeZMODdNaFWgkvgsMbJqNaXNvRWnugspLy
rmqtnNfY7avwHjKaa6J6ZA+sUE6Ra0KefE5yNeVlUJh0ZF96K8Z89DFIeTn2
NdXCwbod5vaNEx+pX1/uRabXzvNRKmw/FE3768Abls9fUoNwH9ckIeWLxe19
moZyZ5A4WVIXSf0QxYoUDT7S+d4z5O7EUN5sNTJ43VmDx6xohTED6mfjs2E3
i3xU+G09vZLuN2ey7IOmPA81SWaP79N5jOZGx2To/fHLGZ+mK5QPSrs+h8FU
iA/rzD7zqB4lxzVEwvEJUrNVcwNpH8xH3dutep7DYcukkxrt05edKphilcLg
g3KnJuVbYX8lz8yqBM6ci7Me2rTfi37McpOlfYqIf1tA/z+49la5kkUPRssD
DMQpr5/e7T3+9mEnWC4PZqOu0b7Xcc2EqW0goUMfO7wJbhnO745/04OujY8j
frpJMMoL73NfzEM6044p9PiPR70ykv9WImHcxciP5qEw4mBCHuMOmr3Db1fS
+zfs+OV427giqDtvKB6k95lnxnesPaV8dKWae7+i/BQ9jTIXXiyEZsx29nbq
T7KuX5AG9zLmvX4esaH7C7fdZTrk34wyS1PuBdpHqXVLuKvW0H02Fk5X7aT+
3PP4Y5g0Qjf4JPs47f/hap0u86B2bJt3VLzwB72/N2dvuJFRArG0I4Lf6Pn1
75KOMwSNCIxo5nyhz4+cmTmb0MCFc+zdmQnqp5ia/Omak4Uwvt6SqEHzGax8
1+7ynIDm4/x7gxTab+fTOsYmcfjGT/zmR/d/Qv2M/XhhC7QW7paNou8Df+2w
d3vy+hpqGPnsLKp/5YPsSMEED0e1g9JBeb9tNMEmop8HVaMluuZ29Dyx1Umr
rr/ACheNfkvKW4m476/l/9OFAdbgg9xHNG8jUsc4X0uw9rBO1T/0/cjLUkbV
cPNj8G2yTLNovpiN3dylR2vxKHbD5A9Uf57fbY+y5hYUcf0SFgQQ/B8tob+S

        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3dcje8bbhFKm1IaqKSMiEJyhUpW0iCkkqykKZJRkQZJhZZQJIk0nXba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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk4lOsfxoeTQ6lElFOcn0KN5aQSIWfuEsqpScnSQsjSOiVpIUlI5UiL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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81AkfxxGlVZJVeTY8rlA6JD0R+VA2NpqsJ3JmlCtHTXSzkdglRMvG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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4lGkbZ0nUSitsSscllJDG6qB+VCuHHGMTQnKKGZWQDqjNotaSc6mv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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c4lu8bxqW3QipKaCEjIxmlQji1RKmMkuxEyS4aSlLfQpJZRiRRUmZG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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41Wkbxw8l5VUaJMtliSwHlSxpFN+TREoqwwzeiYrWkdeUN06llIRk
77W0yN5iyVJDVLLHOemc4xxOtjFmNOe3kIi0z+/9476e6/7neZ77/n4/971i
/3+8DsizWKxIJv5/jgQbvA/0r4ebs4JHvh6Jrf2H1BqWtcF/rUWkXB2JyqA0
Q2Or51D3mc9f/4EEqe/VOZ3Pg0ukwfq0HRQ6W6uUIugB/Dulx+JQEo1qQ/W8
U44SpCu0cubzKbCCc+LU2Fq4oj3vtqMhAaNH/l4Hw8XQngrTe/GRwvGLJlVh
Zv3QUw1jZxI0+qu674vfifHZvS/sf2E01svKj5yb/xJzS7oDRmgS27796Dlt
2o3j513NHBIpLMob8Mvm9mD84ZVrC6xpqBc3ZMar9GLzRIKVQxONaG7RzgWN
JUhV5dywyCDAksT+tDXlAYZTDGveygh88ZWPKZY9Q2/yWUFyBAnLXcfuhGu0
IHV7yeSaOySSsmnvuLFu6JnfNdD/ROJpYmXLcIQQ74Zed5d7UtjgE8jrSuuA
U86tf2lPk8g10nc/FtwDd+PnozUzFCr75hmzpX1Y9cepdrEKjcbZ7JgsaS9C
8xX8UqNp9CpXhCi5SyEqeew5UkgjTO2EJzujBrafVN7d/IOAvNuCdWwdIVwy
73xlRVHYqF0Y0SKT4PnixKlBOxo3bjYs+zzZCY/zj3VnJCSkc7OnW9TKcNux
uD0qj8CVtTtDewQ8jFJmynbeFDTzZncXTr5AyIbAFvUQChy5xj2K/43Dvcd2
0UVOBOr0/eLrEgbxp3gN8SaOxl5dqxbj61GYs/Hxe2lHwHuZwQ7L8g7w7d/2
//mVxKTCjqctvq340nx28GgZiehjoYp3iH6oC298e3+YxsolZSEO95qxX351
UNsVEq8n3vJc1krg7f3XwglnRt/PxQUOTgJ49wcdvdRFYSR4VHBRKgbRpZQ1
dpKG6/oa/XmJ7bC2PvhdFvPe3oSotJDafDz5asDeeobAA5Murb6yPqzrMD+p
Z0vjo5ijPL2Y+f+x6Si7KRrWp0unF+Z2os7hzc++SynkBZ9pV9qWhKKNiQGx
rgTWLc+VF3AHYP10ySLVaho2l3IMDf1qEffLphWlOiREs8M2RtcFuNCWNOaf
S8Fy5uZUCasFvAKZvkIBiTNVQ0fGQ3tgJxffnxJDYeBa/JEVTi1QDFDIf5RC
wiwja0Mk9RSdQep/zewmcfWAVtbyy1XYlO4xNcEn4MDausScL4TwfoLw0UEK
Dto/mPjU5uGrs+GWgtMExIWXK2aj+QiN/z13wXoKV+99sLHoEsDsHDfG9ywF
J9tb25daSNCeNhuhpEzD4EmZ/+DPQhi6DEz5u1K4FykyHaP7kHeX4FMXabAf
Wr8c3CNEyFRaYbMVhTkfs0D5JU2oD1SILr3A8P5+lDdo1AtzXenXLnOGp3Df
hZXHWyE/oZwRMEaCc6rJuPFDJp6N5RCl/gQEllZ1x5e1I10m/VTO+I9jdSl8
TCMRBbpGsRVbCJS5yo12l4ux9GqDDbeWgse2KaP6U0NoJC7HaW4bR/A2sZxQ
RwJW+BvZKJfG0u6K+e3eV1FbcHdO14dAYcqWXIe4YRgeH1cRHxnHyC4X3tEz
RVg1tO5XzysE7jgu+6K4SoK3v/kbhgfQ4OQN2btev4S6wATjvY4ENHz/XsG2
5aFoglO9y4RCmGl0vOaiNpSZNgzo8UisbPqdl1Pdiv5hF2u1BMa/0Rn+RTlZ
jE6Xi9uY+lzGnNU4kc2opHyWLz1EQga2aZSqFB+GMssVXWjMV7XN0S/ox4hQ
U85oksbA9b+rgjYJwHu178RtRwrRHsWSGlETRNnsVBPm/rwLzRr2F3Nx076s
iT5B4Pn3HNsV3ZVId1aTd5MQsLTyMM3ndkDLyvTsSWb+8jfuifk1thaVOrI3
gXIklFWLCs+X9MF5YWzzNYrhS8vitdwXPlY3j0hvgYIbma3hM/0KqceykrUl
NMTb51a7GLchiZ1je5rhJ/n5byuL61qhVJrxUYfRm2WzvD23OhEii7GWKEav
Z7K3sfo6dWhO9iT0jUhgnkV8+7c+uL+YupbAzPfojx5ejftj4Zjwy74opr+y
vfk6oWZd8Dxwn6+ygOF3ZPuhKR4P1T/u2zrrRSFWXfV0Q3cvUkXGJ7Zb0Yg6
9PDRYsWXyLa/Kkp2Y/aDKL3EyGQ/KHc3G4kpgcMmHcHip49R7arUKDUncfhT
RavcT6/gFKnFjtlFg58s4taxRXiguSPVP4nC6Jnvkxr2SsHK/q7mYikND9PF
mnrpDRis/8B12czU9+CozfuADrD0Exq4MyTClTQ5ESb9mOJ2VFzuodHQOiKY
+0GAN/adFY96KEy+VhHWcGvAMRV7dYkJBKlSDemJIswYVXgsHKaws1XXU8Ow
E3rVGy2L75K4lGkQZfO5F82qT8blBBTi9eflh1dW4l3t/nMh9cy+qetZrOC4
G/HmjScHVjJ5/eYDawyyYe5Xm4qDBP4BJVTAyA==
        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVGs41AkftROF3NkloSslVNIiydEmt8rQTrFlIyRCVFLJxNNF0SYpY9Aq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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lWkY1TTTFJIWMnVRWZKytKFBx1yVpaKxlEIj40paiCQl+0iShCQp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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VWsfxU0prgwlpIlGV8KVJg2LRGkwlOSqkAq5XEOkkAwlTUIkQ8iU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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHtUzPkbx8clRKitsG39DBK621JttO9SMZIuw6iIymWXdF+taZGhUhFZ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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41AsXx8cSJZWIqFspl0oia6R8K7pCyZbordAit0WWG6OQ6h2VUhK5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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4ldsbVZluyZUkGSqZK1QyVpYrCUlIKYRryJTSQCmdekxFlK7Mw1Xp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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHc8Ve8f154okTSMorSEkKLeoiKjVKIkyWhSSkQUKiPJiKaZvZIVkmTL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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs41GkbxycdXqdEVNO4chVaSbTtbinFt9ahIjWmsi2KdGKipFKSQydR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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlWk4lAsbx5GklETJkaRTUVlCKkX+2tQ5FZKyFGfOUGlRWplUyP5eJem8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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs41FkYJtYuSVspElsqkktLZqmhXnRRCFmGFSLWpai2laRoXFJKuVXk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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k8lF8bpiKJSFGprIWUXWhzIakkSRSSpEhCEkLLn7KVErIVCqlESWTN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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs01AkUx0etLUVhR4U8o7aXlSQk3yVLRVFZa6M88mhLmh5bGk5RqKNI
JOQ1u4mQzGI0mJzxnkKMIa8pFWnm95uJTHpYw87+cc/9737P/d7z/VyjwJP7
g+dRKJQIRf3fY3X/LdE70o39opjF5lwSpt4m59kHB8GTv5u02CXB7Omdc9+7
1iHkbJ32rA+BRQfuRcrXC+H2S5iVsb4UGwrr9Iu1h9D7UvdQm6UUlDVbMgv7
7oJ7qE48fUQM73E67VtNNe56G6zz+CBG9lq1qhv2A7g2bRqfvF0CxqZsg7EP
j9FQOeNVpE7gLVVJJl3RgcvtcUolMSTolTdHEl6/hHR598jWS1Jwb/rk14pf
YPLz7pU6RhLcxjbj/ardMGGNQFRH4qu57ocKEQucFMNlWSoE2Pk6N8Mt2Ajj
UN8ZzCMQ4vvw56hN7ThnutL4rTuJ6MTXufXd58BP0zz9g7kYCz8yY/xucLA0
0rGRfoSApabJnx7+LbjfEXd+IocA4+cyd76kFaHvv29aMU2ggOc44WTbCnZ4
GpU2RIDZrQ8hKwMyWsHmV4cV83bvjQuN7sQe18pxUQqJo1u8Ss9ktoJWlGFd
wifweMHqthPH+3FLVjO7JlyCnhsDL+JKBbAzShUMl5BIGh3tik0bxC3WyDhb
XYrfUiscqJM8xFhUe2/KItCQfDj5Mp2HV+Mttk/WkxAdbJTemuTC3uC9HieF
wMy0gdfV3iYs7PNI/32UwLIS1yibNRwYyqrmD1EJeLjkL8hSa0HBOTdVwyoC
f8lZbu5qfMyJGAlXkkn456ka73d9hC1jq3Mta8TgXL9n8+ZrP8565cquF0rQ
X7crmVVRhaRmm+FLMjESTa8IZMJ+hOx+m/KdvgQpO9gHViY3Imvjr0c/hxCg
x3Cvcw7wcTM+IyA6gURQo/OD+Bke1qnuTefJCJRHsx7kVA/gUzPB0f0mweu5
C13NbvXoOBfRGepM4IVKw+GoXCbyejVcTg6IEeZQ6Wv7pg/C3kEnWZoElJqs
QDUHDuqJCDd7EIhwijH7dycLIe1u74PmE4g8ZFjTM/0MdP1Su7I5ApVlBf0b
z7NACz/WPzglRsZUy/PE3d0YU1IeMh4kkeHHqviplge/nt4Ss60komxSXplQ
e5Fr4rwo+qYESobu34VbCEDpevep5w4JaukX2z+8niPMnhYvzyDBdBFQtUbZ
iLJcp7JkIYGd6l3eHnp10Agp0gvyJ+BpeHjmgm4euqPtBuPPiHGRrxFRc3oI
9w4118vMJYiOS7A+eaIPDI9VjtnpEoTrDVtcSXwK7uTTlj0Divttu+ZqU1sO
p2wra2dSjIkkxlXd+Wx0+Ld7zi1X6HXjnXHZE2y8X6fmv5LAF+pmytemZmh1
aXlW5ROIOrZqtWh5C1QNXVLkrQSE4UEawnmDiGGKWskNUnxi0SM9Ex7icqNR
cV6pGLRCbeYV6jMwggsZ9xxIUH4ZYMSnM3G72TPAkCsGU1dz20RGJ3hLQse3
LFP4UdMeVjGvHz25ynqzGRKERAaK/L34uB9cGHvnKYlTP5bNH2trQ7T/P6kH
FXksc+wZV1XpQtdXy+ED/iQq2ymc0fpO2JYauXDOk2BYzOVQt3IRq7xYX8+P
wJ0vRePvg4aQPeAaflxPCvOLQ8ek8iKMKBcoP/xbDHOm7187tFqwtiDwuEU7
AVOfuG0POvvgmy8fS0uWILlYuMdCpR06opFiL0WevzosVLOc68UajkWGu4zE
tRvOIVbvK/BpheVPldMKfn10/WDT0gVeJNO8kU0iIjhzwGOmDObv5HyfcjF8
p44KNV82gG0/nJJUTMB7/asC9/JK7J08FWTWJ0aQgKltncPFkkXV+wJ2E4jt
z6RYGXWgYXjYcP4SEg+3qQfS7MvR8vnur6xWMRga9+M9n92B6EuoXYO3GLfj
UlQ7x57DyY/05ceTeJApizjU3Az6Z+t9zxaQMKOU5F1t68OjB39sLlLsVzx3
4m7XVT4uVqVOtZ8l8ca6Wj4+JkDg2t6XUaUkeI+3m+nwe5BEPfJwl50E3mc2
XK9b1YuZ2oOxIhaJA6rHgyc6hLge8ILGvCeBpMnzk21OE/IDkrPfRhDIXt8/
nJfQBDer2qt7bhGYkP6tyfo4iMLVfk8G30hgSD/qGZT4DKMfdlzosCSRTYv8
0n25WsH7IK1IfQI9B42FFTYvMLup1smeIcGN9bcd1G27EFj+Q1qiiMSsL2JC
5wZxeEOxO3WLFL69sb+xhztgos/kd4NEVaSB9nP1V0j9nbv35SPFP2gYlk8p
CTBP500wLYeE9Y50Zf0j9RgLvKWTsIsA126x60xpLBJ8HBOZ28Vw62RfXCf4
B+oFVfLTjQq/haVTPlpZsI37UXNloBgCfvumpRoC0APoqze2KnhloffkfGMb
nIO22xlpkZi45lrxqJGHS3c1zS5oknj9OWx21DQJZ2misGQXMRZPGG04psLD
RHqmleM3AoS2xr5TOzhIZZvuqVhK4D/PaN7d
        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVWs81IkCNdzdTKnU9Wxtra1UyyqiuD2OR2lSSsmrtUwTtW0eoaRYrbR5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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4lFkcnohpVchlyVqXkK67XeS21cuIokiKlEsXt5J0sVQWq0WppRFi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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VesbPZcyRaaSNElIFJJM0XKLklSGSJo0ioarJGlARSRJqQw/RS4l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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk81Isaxkd1HOupI+Qi2XLVHZS0SfeZjjpNqBCVEqcGZyTlRIs2W2ls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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHlczAkAxYckjbZCkhzFYh2pJrJkttelxY5t0EHFRsd22JSSSCFUdCcU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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns8lHkbxof1IkmErTdWJcnKqYOy1bqQJKeQDHLepXbjZXUSUkTJKcnO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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2lcjH8bxUOIUlHSJlEpochWiVMk2dIikkSkTbTYkqQISdqRNoUW7ZYW
7fumtEzNtFOque+ZonpEKD2//6t5M5977rmuc33POSvPOBmfm83Dw2M5i4fn
v8/YTclVmQue4/7jXh2xVTR2LRfQFXvbioUee1IN53Gw+UrYmlWzK+CTPp/e
3U/B7uuYGm9rKu4HRhlkK9Hok3I1XVPYiyvK6YbZA0M4Kngwo5jFQEQFe4tQ
BhsWN6y3FOdVwYQqkltQQGPjRBzvGadaTNkXa6z0ppGqOCKxc301Lt3h61dU
pFC8/siLG6wO+Kje2mlYMITLF+SCBxo/wSz6vuEuqSF0n8w3/7utEhethl9u
qaEgzdpTefBOJzip3a6qYlzY7TQ7ypfsizNZQT6CsjQ8Qq87X9xZC909ovZT
TTQo/mese0MfMfle9n5zCgW3E5yU3ZvaEC6+2MHvBQ3n21GFSUdzYdCo/Vsz
nMJlIUnOHIESmGS5d/RtplHj7TpPO6kFVxpfKrZH0QiXcvHOi/mAd7YbGcZ7
yDxcPJmfNrRitU3u6JXJQexarWHpN94EvRMREUuvU/jEfrL4xBUmDn/9Ox5p
xYHLjrGjRys7oLT8r9+YKoUjMpk3XgwVY2qRbW98HwXVs8e7xtYx0MOO/C2z
nIao2arp+HIWYrUlkz8fGIYxVcOf4d+FRN7+tPu3uVAKL7bJMcsB89KzRVev
0jiSek7kwN5CfK8Q4UbdpGGbvVn5zuF2yE4I2EzwsuFVkJEd/OsDnPq3vUzW
opF7v9W2zKUVVZ7ZG3gKOAjazXpDs9pxK9PFjleTi/ocnaOuf15CMFA6sXID
jS/jwd9n7WpBm6ZNllU+mV9KluQP4TwoJ2lX/OyiYKoTvtTtfBPu6L2en7KA
A6X7je7/qssgEBfTG3mGRvuK6672dxsxW0eyuKGGxoY6izShpiYyV/20cIrs
5zqPr6lYLNh7wvmEFGjIstY85ZxvRaqgpa6IKweasy0i9I9UYm5XiqKaFQUx
gcIwuX+t8PGNVKmOouDoLbFU9VY1BhLsJmre0tAeuvlOvLQRPm3bzCWP0Jic
v2Ta0LIF/jK0w/eDg1DSyg2eZ/EeMYNC/D8CaFSZ/xjOTupEhE3SCrfLHHhk
39I382oBd8mrG9/3chBr3FQ6KlQP3b72rnUv2Ngw7baDx6Ic7tq8o9vKaXT7
+OhWtecjZU9akpgFDZ7jD15Lt9wF94W1yF6iT742UY+ET0kIarRhPlCjccjq
Q4nAzXZ4O3/bnxpLI0lMXPGJXR20GRp95h0UhC9yXFeuyoRBbxwkeGmoK2jm
FPEw4ZiWqn7FjA1N7X0jZ+1b0F9ic/UTm0Kv4GoTySdNiM0QsF9iSUH9+umH
SluYyHvEa/V5gIZ8QqCOYVsdNG0c7TJmcRC+6S7WUpn4yWPM6/6ZQuY826W2
4yxEfOwVNnlDQ3zT2v/Nk8+GnQ/1ZRc/Df2EQ0rdfvVYdirknpkIB2FsWYsc
on/f6wO0ui+NkuWXjB+YvYes2rzjW+eSey9Ozm1f0YIhLekypi15XoxW//TN
VryQyQ03EqdhZpcqGGdXDTVpzfy4+zTWCUrIcw0YWKe7NjZjFQfaiQe7zp8o
g/nNRxM/cglP2O5yhyprEMLL3PygmEbmqr78wK2pkF/wnVdJg+xvxmJ92jEG
PB7ecf+VxsbA6/m3EpOqYWYyEbijjAOVNSud2NwafBE/d/iwAweTQ2FqwlnV
kHLa4LFSgYPMkLDLEmeqkdDRp+dH9nUofseKx6u68fudBlO0kA2z/Cg904pK
CE//mQj6jzfLH4u/jWdg2NEoVludhv/SPxxLr1KID6tvSYinkWca4hXpVgbP
YMEb5yYozLHVMZ+LNtTYu6YXWbEh+0E5JEUuBNMnvDqkV9L4MxnOR51noe3G
CltWARcHpV91L8MnxO0RkhCxpjDlPhby1KoEqyd39peFUIi01ve8ntEEqeev
8g7Zs+HT2Wl1Ob4F46PC6nLa5P2Efpp1NzIxcfi2j73XIEYvn/0Y2lcK1qm4
vk7ye7F+tXd2niyD6p3vS1y9KCStTnh3WeAdXL8K6DRL02hVTw/UJPwIGztm
rf6NhkXWGKdHhAmhOMaYVwAXCopDNfvrWfjW6t9rQfaV2u//p/LVR6jxPtMq
dqSRsFh8Ms2lAC0DG9MNL9AY5lifsn6Qip1d+/rMRWhIf4xeyLTvRKddeE9E
ARvCvN80H5Smwk/gwwfWPqK3Br8F6ocLIKbB8Hy4icZp5+TM3c0FSBbb6lFu
+N891908Fl2B8AmLtfk3aOh9ED3883YLTIwZOx4RXr0fOGpm868OW67JLPqV
S2FBvvr7w1YVeFFy7G/wNcKfaaaKXWsrBpaENqYRvji6Pb3XJ1GDewI7kyhh
Dgwz6LGlP5Pg3xuw6OU6Gr+2M3R+32bCU/1PrpQ7md/ER9pmfzbclteqzcun
UCXhrhBX1wOl/P3Z/ISfIzNtZx0cmpFaK+DrTNMY94+zHQ5n4uEX4SgF0NiR
wD/Fm9IMB7OIiGFlDirO9rc9u8jCy6Va1dnyQ3ALihF6kNSIyQd1gir7aZxd
qrmy9XITAlRE90wEUFgXOXp8ZroWtJPrVWvCL7dTeSbPNjVAfnPPo+1VNEbf
puTf+t2G/+m9CzXNIfyvM+ce3/cRgt0HjOYSvfMMB87ce5iNIsal7/OJv6pL
Ksj1HXbD5ZfLNmoTfYi/KL9i/iULSR7C62f5Ex5r5TwRkq5EbNx0zfpJCmXG
z/mtXjejNSgo4QnR/7yJhecHDZnobYu52mjGQYn7sX9FIrHIk9vd95LwfCD3
fN5ilU/giY/SW6FP5ttv6O1wpwfSF4zzWx5x4PvTl3kzIRPS2kkzMltp9H/6
+MT/bzfq/eVFT18l7ytG5ZuxmrFH5AkjkvibceLXG3RnM2hZp/TQUA4Kxx+7
S7o2Q/lEdM22UaIXo932LceqETzeLJyaQyFldf9+9S9MCOfVKLido1HgGZiw
WakNq76LiFiTeQr4OEYEWpbi+bHe0EziFxdvOW/wyCtDen+RbUw2DaWo1Y7u
yz+Dt2ff84oRwpe2UoecXBbmRrfG0okUfDfnaMV410N5+FHmvMUcWL8pFMsr
rcbmzgy2WREFQa627o7fLHgs8XR+eproz88kjf9gDQxq1HakfKfB7PRODnVo
gZHW4tlidzmwt8t2XsOoQt63L9JBhL89ltSy8WtNUI95O+ZH/H5Ar7J6VRQD
HYWiAa6yZD7KC2jrDxFQbKeGmmUIT24MvxuwJPd3Zc6PNQdpeGqUz6HZXbjQ
nJ82wj8M/hedWxwDGYhe4ZK77BeFokuvjnv4l2BGK/0dQ54Cz+k/H0y666F3
a92CBGuSR2yt9Srq6tC7oH676R0KdH7xPG1HJgYqpW/2hLHRbFUxzX7eg7Kb
K5Y0H+dA7MipvYG/GXAXEpppcyX3cmOsaY15IqqSZU6GEV5be3xW0f9fE5Y3
8F8/xR6ErOr0fOviEvjku7y9v4hG2UmdSqcjnVDlf7JxcoTouY+pK6bXhaZD
VgNKMlyEf5XyX5FYD9fMrRKu5D6vsFSi431ZUL8QYf98O8lrV005vUFZqDNR
DtBYS/JAnjDD9kc9fo79pWV+U0jl2+GZaNKMCvVrgzMcGunvfXtdHD7C322r
isUGCmasS0v+TudBdPXAG2U/GjEx0ftX2n6CwdCcw888aGweDSuYjCkFlZ+9
2ucKDdW+LdeW5TNRf3aoclKSgrOg01SOcxEy7y/KKHpKo0mgQjeWrxaZi7S5
N1bQiHZyUxfUaIHwZF6sswobPB+kJSnr6xh5+a7dkexvk9GTHRFZFTCf6lfS
0KHx9pyx/rMrDCSaGOUcYbDh8bP4UumbDsgr7j27a3QQfGW6+cebWxFU662n
SvxcuOCdBOdLKVQ+brg9FEZDRNvz+lhNFWqXN/w8Rp6fqbjTpauzBiMjn80z
Z2jYKUozBgM7QTlXLfrvfWy+Be+sMeuGdYF5wO29XIx23ag9nZMOx+CfrYW6
5N7N16rpfS7HXa03wfucKWiUrtObFVWDHr29UeudaUzJcPOUcqsxtcRFMvIV
ydP6Z+f2zyqH2ohxiupFklf7bV7f7SuHjFDYawOSt6mfZgUb3Vi44CDoI3WP
iw3xtnqB7lmIhaPDsXDir+c9E898bUbIjvZSTyEKJfY5j52DDaDaMmy6gPQZ
9dBSSHFzED82p69ujMLpEymrNGRycGae9oudZF9T3rx/jSw74KlfUr40go3L
lZ3JP1lVWLeCWx7QRfb7I/ZrTlQ5WpL09WqZFGSLv7sI8cRjo9V9rQbCQ6WB
IWrB6zIcVtMVfBNDY+f9dS4ig3mYvKtXXvaEwjf3wwGOvN3YVukvoP1yALzW
pnlV6xohGeiwKHstB1Z3JmuDdboxOcvQi7GVi83h7fEWYKLqz+1rNqk0Ev9t
nWt2mol2Hjd3S4n/7m/mu6eiJQx9olT2kv/3ahXX5e1QK47K73bP4ZJ5fro8
FWDWDPnzMndbZtho3R8s5VRJ/MXqingO2V9R38yyBqlO/JD5dOlK7wC8rirZ
dIS2YXuN6bODc7joZLHEJJtb0P5B/KGUIfk92bCfsYqbkcf8fu0f+b8zAXPe
aa/twORFjmhKCg2ByFyuXWEjmOJ3e/at40Defnvya9s67N68Zou+Cg1B/wEp
wWoGZh14rR95YgirRzrW2/BWwvvQxlCRBzS8Sg5zr8m8g/XdAYk9QxQsKuxF
xW9X48uyTxe1dck9yk108/9uxRzTy+MKiziQXf89TiczFbrdnwvekDwtvlVZ
rrShAQaJavK7jnJg4F++jVFB8vzOStniNhoR+3WdZkVVIsbBzUABFPRDBWsL
lqej/4W7cTnx25taJ2xckiohWh+VoUP4axh866/fqRQIZcid/B/hg2Hfy8WW
Vokw9nNaXEDyxq7xByMJHW0Qc7M57WTEhZeYRuT6rLv49mRlmCHZR9NMdZLV
xlL4lxsNbAuh4ftgqfg68bfwVBYxDiH55NKRl5+3jbRi9jz+zgziZ8nzI26O
ZjBRcDaKU6hD/FZiKoH2bsJlc+NwU6LPg5zrpe//VwoF0wwP031E3w1Gsk2t
zxGUphB4Qu2/e5k0euTYhuYZ1W6dWxwcDGSfjd5eBIZJfK6LG/HnyibNke7n
0BcvLpBYSHjb4JcXbNIO3YxD0b9r2HCwG6hQL63B0PhT+a40wlORO5LdVXXw
a7prrSJF/Icv7O+F/a2YPmd3aaU6yRe5ZVX2i9tRLOlX+PgHyRd+HhM2W0oh
W7Y1/E86yWdXK2d773iDe0Zbklx3Ed6ad30Rtc3DgidpIdxgGi+6DeasCiP5
UEflzmPC52+XcmuL4ppRv57n9u1qojfusUviJ+1wybw4k5/MM+/GEudppVYo
fTCLSSZ+VNK5+MQ93np076GOdF/jQFnv4M+WBwwIlv0Ie/6N5GG3Lz07lEpR
hvA7p0k//9J4UId7NAO1ORmzQ+zJvC/FSy0ZrcITBxnTWUS/NmljawT1SxAZ
1pXFriN85WXMnG9oh61Tq9IVkh9LbmtFKW1oRFF09oW962msXqivrHOlA3G3
54YWEd603Bs44R9E8lzIknRbMt9i/YB2AVYdVH4Ku10gvCn5V4Jk6iVO0R35
D2cRv3lY5Pj270M4G5RkziF9/nS+tfoVEQZOJCQ6ux3gwqyyofqr6QeMOA6t
rSB8Nz87dvWcQQvOJd7cK1bFBpMzM/lqvAMGohqsoCkaasI3LTrrWAh+yJey
LJ2Lqwd6Y2gJJipOx00mku8Pjb5ZW9LYDdXvwjPt9l9h+zrx/YJgJjKct9qv
JPdebX/e98mrdpy/vWhVEOlj8idjX48/rUeBr9/6bxI0KgYkqhXvlUI0Lfzo
bMK/EqP+otH5pdCfz9doaUlj4tGE3NMJBrIUG3/kMAYh3SvnNaDRAKnhYekV
r8g9fy5srF+fDX8RhSHvKQrjpxN4XVq60aCsUnJShoOApv3eN8J7IDs369oU
6Rv7n9vsFNjXgK6PZcoz5PlixtGJuw+0YlSTypsmeVbT6tivhW9YCNgWt8Ti
NtlPnKXRCv14HPGPWSRF+sm1aROjp9ZvYbNmUL3SiPQV0B3OIq3o9e/Sy3s5
iC/n6aD2ySzw8AhaD+wg/NF+kWsecx1fDRmP4+TIfSjJjcQrF0GU0znrLenf
XzZ91VlE7qcqcPXcfySv6n7Ua3caqMemU3ou0+Te+KT3O50ofwHrC5ltrqS/
8OgL+t5QuojgiI47j4l+R+/n/ZiY0wjRlAytQ8s5OJwXu9NkUwmGJ0oX3tEn
7694zOGVgi/sNwhGxxK+XttUVvIql4HgwW23w1XZaIoPLRycLITewzVB0WT+
QS/5Hlzuicah7VqqzyVpBPlYB0+z2/FdJ2LL4DgFvTWF1QnmpbA4IsN/LI/4
+ceZGfpYHjRSfQ4tqaUwOZFh4ONVDg+mQ0Z0LwW+UPv+vXcLkLrwbs+31xQ8
G9YtOsr/Bg/21LC8SL7MnLcqvPzxY/SGSSjVCpJ+xWY1evHmY/Hvr8xwonf5
Ne8jT96pQ//UXquAWArhNo2Gfb+KoDmm+rzrEg3XuOYz2YpMPNo35POP5F/J
54y3u8yb8Sh01/F9JD8KF+PzH/McdMkcWHzXi+TrZJ6t7IttOL16WaTxKQ6c
lTPGXTc/Q7qboL4a4cWP1Cef3vdkw1hneltwBIVhCSutrNd1WHHrb+LeP0Qv
59xswgS74CgWOXX4FRfpWc0fzvxjwaLAnrmtn/Rd24LX79OYEGhpVkh9yMGB
c7qL9gW34N7Hjpr/FVOw9jb89ysrGXmcn06XN9JQEJ73Uba1Cc0x7RslRDjo
N/kjsWNLJswVL36NI32nO7xBP+5bGXpYai/2kn5tJ9zu/fRABVZfTBa3JPlQ
X3qH4a/em5B8VyQ3JE/0kxJStS+mAcbVmwU0P3FgG64x6izZC0ufg9qx1v2w
8B/uDxDrhNr7y+Nn+CiIOyiaxdq0IOSVyNv2G1z0/J5JvhbWidSmqks1JF/f
G69MWjWbgbbNknwppRQyHwivG55VCB/T7P5+0r/+DxGTHKQ=
        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHk41AsXHi2i+kqiKKMUke2iTaVeTXQtbbppketpoSy5plvZbkS2kr5S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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVWk4lAsbdilLllK0KU4h4ujISUJyp+Wrr8ZBdEInRJYkUjK2LCmKSNbo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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8VukbxjFlKWsSfsnSQlnqtWbCXLKFUpYWNShKtNp6y5qlKEUR2WXJ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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk4Ve8XxVEJTVJ9UyElpZIhGVJZmpAoJIkGSYUoUxlSmYcoQyokCSEi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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwV1Xs41GkbB/AhIURvZy3JvpGERDmU9tsR5TCaVLJzUXNpt1TS4bIOk2gj
Uq+3MaTT1jKKGaxTRZRjmRxnxmkcmp1Eu/P7/RxShN63eX/vH8/1/Pvc3/tz
34855wzrmCaDwYikz//vQf1Zi80sCbTNDk9PppIwccxZ8tNWMVpu/TNkMpvA
uE3n0DBDikIPzgXTJhKyvfbWJ5rKUPRySLi+XQXK6odTYSvF4HKDbv0hJRCr
SuxyXCqDjsXW2QOGFPDRRn1liRQ6u2rO3fuDRGbld8tCI8Uo9hQLPi0nMWFx
1UAe0I1VT6M9+IkkejUu39tKdmCc46jt6Unhinvi8t9rZXiWESvjMiiYXM/s
cQ/qwN4FnDhTLwpHFpgJTiIN8oszsQ4sFTyDTsXHZT/B5/hjObc+q5DE9QKZ
W4wAL2n5zmYVfkviTialdkGoUbVZeZ7Ct92ZfrPO/Shz+pqgP0NCwa0YKv3S
gUh+wdb3WhTebCj+euNcPZQzQcK1GQTyyx9G2aTI0Gj3q/L6LImsG6d1ZDIp
VuT+VREhJREW8KdTjpEEQtnO8LXhJIp/Ebnf3NeDg76meUZ0Pfbb7UjDUj6m
xcM1LYEqXA/+snqlRifuNvzEPGNP4Za6aNPKZ3J4n+IV73lCwc+rge1cKAEV
nhrxrxsktNosI0d2t+N7h9B1KZkkqMhrtnM+l6KInT81f0iF3MhZh0N9ZUg5
NDnE7lShHDfT56k68ShEtEURTuFhevPcBb0i6L13bP+QpYJbUZxIy1KKxr6N
Bc1CEhuvHbCMvSYGIyM5bscUgeN8C04z6zVOFZ48b1xDYLtel22SqBN6etxn
A/+mMOAUyYsj5Yje4qldr6RgUHNCvmtTC86uv/Ak14aEckNupO23Cky/ndj+
yoGA20Wnas7ZWoQGsLh3vAkc6Z62uP+iGgP2g/msowQYX+TWr6xKkOkere3f
rwKHoVCMzHSDXzrYuf83CgFnCzRnnCqx4tHa6U+GBCKb0k4M15QhaXsg64Wa
rlcYXWxiXgGMsYX5NgQMtrA5ftkSeNsqHt+g/VqFeXBP1zfA4Zha4RxFYGah
98FF/jIUSn6Md40h4WlApbFZT7Gk39nrgQkBBa97bPP+fth9fFfDYoxAt9K4
5K5/LX6MGSk9FkvA/Xzj8Y9z5WDPuL6OeUr391usWMkoxtScA9rN3SoMtcWZ
/zBbD6ek7BT/OgJKVx/Bw0N14KkPZhHHCMjeNfsdH+iCXjyz0or2YaKr/aIp
+TUkas2X81eSWO2QM7bGXo6U+GxjMzsKu5rqer76iKHK1VBIKQJBNjxRF0eO
c3nRaXuSKaweVaklVvVYOE5Up9+n89zgsGoNPxMzaSssPYJVEHg8ndpQ0IgP
IY5CppjAaoP4LGd+PQLTfy7RDCaQ9DBLXpLehXkFpwWHCyk659nxxWlSjAS+
yhidQ+FRW+Sq8iN9qD5lt+qveAqMbaGa1ksfQzIif3UlUwWDQrDtfaUwKtDn
jXykPc33ufS8qRqLqdbl/91JoMREGPu3qAmD/PwsJu3DZNBsX29iLsBLvaZx
UwWXWU3TZaGt6Csn0/dEkKhZdNHFYm0zZr4G94+a0v7Xe1X2GlfjuPD8bf8D
BMp5FpfDfV+jNbzYtr6NgNHwgRU9Bp3YsTv2adEbEgHGB7dY+rZhoii2v1JA
Qm7EJb6v7UHf+MaQPCmFbR4WUbyTiRCubnwX4aYCr3JbR8IXObh3na/P/Uqi
JS9Ncya5F3UhfINtYxRGW9+unTzcCF3daE/1C4KeFyXHzq0OoznSiY5LBP7j
2R7TdaYUKiyWTdB+44abM6TsHpRsiw5Lu0PBbsls4OH7LdBTJO6QWpMwWHR7
4wkHCa4ulFZ1/EJioO35XtOETtwL3e8S9DOd73t3Vl5CBQYKRUXT31QQs9SP
K7J7cKbmgV3hWQpWVgU+7W+qcS5EKyyFRSBswrGi9rIUnoanzfljJMpX5G84
81iGscCGOH4tiWCvG2KXl3LwBuxuVRdT2PH8YsZKZhPCZPd2/sOMhKSpKpMh
ykWc38vlmvR+8CuYO6hl0YP8rVPq2z50/49kHRpQyiBZk8/QMabgUrLsUq1P
L4qqmEn6wxTcat9wmKMtUPAbl8ZmkOjUnDw/70/6P2AWZfZ+IsFmuz4w2VQB
u2SjiIRFBBoCdOrniNtwh5lwyHI9vS8SDddo+ilg+WHfOjfBCJ6fZtvOD27C
kl99TjTkERBoiRg5461YmGp51vooiedz7/qqBDXQsapN5dG+ek3S+6a8O2HO
aRh8q6R9GSZNachasarL5ar+OwISZukDvys9iKqqUy6m/ZatO1nsJO9FyZML
vcpOCrkWMUfZ89qRZl5PtLmS8Bfsvqq+3o1p7z0JgmcUiv4Oza7xeAlr3ag9
VUwCZUferr8c0QEd/cQ0R1cKvlHfdL/TFoMQUawPcgJmDh2/u2Z3wY8tSw4j
SexKWWoaFSOBj9e5/VH0+/8H1PjURA==
        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXlYzAsbTYmULorU0Nee0I2iq2s7qVzpo/VpJEsq+fosNWVc0yIRLS7S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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns8lOkbxtGBdlPUrFOinH8TknPT4UJySmyDGpklZB2zEWWXhlbRTwjN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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k8VO3fHuWRooXKI4WkrGlBpLwuqZSlLEVaSEkqQiUqlCWlooiQSlki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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlGs81IkaxxEOEZ1OSpIoYiXNBzlWWz9SGUJtSihMKqZDllOn6GInWTql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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk8lIsaVigUkdKVdCppVRFKksflStxxQ/bklGMqkuSoS5SRrUN17MlM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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk41WkUvjXMIBkqaoSxJaEkaeyvLHVD1iGlpE0SSpMMNVlStoSyX1lK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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4ldv7xkVKCKUkp8GcJBxTkdxSSlJIycmcBlQi0uibpJJEg6SOIkWi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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs8lNkfx6eSIpfChqlfEb9Ykhpd9Io+hZBSattVupimoqwY7ZSRaSRd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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs4lAkbxidaoRwuKkXbIjSJdSolh1uopSIklbDO2o4K1UYqSlQrKiop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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk81F0bxqdo9D4klUpZMiJRliRSuCqS8EjSJtFDkqUiSyLpfVIhya6U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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4ld8XxQmpqMgYKslcRElIllLRQKJSkWQokUJI9c1UNKCMJRUSQpnH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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs81IkWRxETbeklIaKokAwbim8ktCRbrRabNB5RqNy4KYuLVN5JVOSR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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGs81IkexqdJ6pT7raV26Ry3aJ2Koqwe5FItJWaVkimhNjZKzZaUS1ST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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk4lOsfxqVC4RxLtEgpQpSk0xDqJku2CklaREpIi7RJ1jZaqI5CJR1C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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4le8blyiSooikzBCFjIroo9KifImiSCIVUdoqpSIyKquSlEghMkr2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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVWlczAsXHtl620mWcG+JZLtGLgp50qVQlBZNcSMlFS0UskZ7dFs0UdEe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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk4lQkDxW+mUlFIsjyUbUIpFXpMfB0hjFQmlSUZTMkyIZlISWi5RSpE
SiRqrFlTXFPERZd7w73Z47rL+76qsZct9Zk/znP+Ps85v6PhFXjwhASNRgtb
0H/uYXnkr6nTGdgSkRnxqYbChQm2mU9+A5i7DOsffRGDZVduMtvCQE74Jiv2
cxIef3xsXxpSA/HQJvZkGYmaAoMzSrdZoA0N68rYipEjMHVJPtqBuHOqhZrf
BqFffDhTIZiBAv1hnvE0iby1p9IKQ7jwL9k48aNPiPKkQymxA0ykPdt/LNGe
QFKNfbzOaibSE5Ntx/UIyF7ad4x9gosgGfGU80MhKlxsfU+oN+N5yWMDAy8C
jnon5GSS2ZDOfOLh1iOGzTzn3Is6JvIaYpy+uhNYvOvnjLV9DBSOejwTniOh
ND9dZ1/IQYHNFSdlKzEOvZnO/GGUja7T8kVDuRTCHjJ0jV61Qn7Of86gSQyG
3bu7webd6K+Uqa35KAD/lPWzPtoDkJUKSXW9FHJsOgNOqpbBXGndtWk7Com2
L6JXjHRhhfThmH9ei3BPlxNRbFIB2sqxT70ECSljxaovv/GQLupq+dNbCDq3
N2LfhzzM2bWyt6RQUN9zpE2vvQPt0qxTAdoClLiJ5bSmWGgfcu48U0RA3f7K
z4+bM7FD3XSsnUmhuFrlgIpENVbFmuQMvCbxWef7my+CaqRxatKIryR0o8J9
vuiz4J1felAtTQzzKWrZ64mbcO/qjT49RaFmUlvt3+j3qOk7zHZiizBufSN1
ZQMXjSk7HpYGCeH+9Tn7LacWL63N6ad0SKyYmveyjO7EaPsvscckhejSDdvT
FdmG7HPazY6aBKZzVu92WsXCw4BUE2UGgRa6QrFooBdqj2K1B135SKtlfOas
5IEpMKimLRZCtM4vuTa2DBtrZiuNHShUJocbMiz7kHx2r12uoxBhKoyT9404
UHFpC7uaL4LzpsW/VsVXQVS89BD9ColLSditlFOGuJWPs72NKKgOZJhMreDA
TWHNHwUTIjxaphHes74K9kNzG6TGSIxe26gQocXCerV4hbWBYkh37xTPh78F
c/nVTtlXBPzch7LC9HhYlubL5TxY6O9awh5ORTWMvSP5JV4kivVD75p0MnG8
OO7y9jwCIc4yE+VCHowPSZqVDgtw94naMCFXi5xhO5FoPQmziPZTj/b2Yvt1
riYu8KHumu/wXPE2gjLNDGZHKNjfWZ52tKgO6iekbofwCejf+nMiy7cBEq6j
4i0WBFhqWyy+D/RAcVLO9/A1EdILV3+IedKOQn/PmZ16Yryc1NphrliKT2fL
IxO2UShbdoFkjPVC3V/R2CdaCJNIU93EyAr80CbsLVdS4Hnet85Qr8Cqsmyz
iwoUfJKKnj6w5mHUXi/dakwID7MNuoT3S0ybVOPvJBKzq9cVhCx/gx6OnHqu
LYnpHsubvJIq9M8ZVVtyF/K5Ttm3urDxXop/o3CBf9mf6iPm17bia7bG5WEH
ETRfN4uOGQ0gV/XFb4IUPsqFXfdu3WvAd53GnOW5BKSbrDyNXdsw+Hrz0K2/
xDjodufs1tleVJl2Bk8FCBA9Td/aur0TnK6KospgAXTPNJ+7WV6JSaa/3/UW
Eg5HZ9q+rMmGklX+uMsCv65WXQ82yL6ErQ613vcdCW6wQmZb8Dv4VZVX92sR
8JBflKrTWgc5XRuNTxcJXEp1YbLmMnGRVjs2XUhh2t3vouXHDijpKmZdtRVi
OIetHPO+B2wZX3bYeT7c7gQcOL+/DhpPd3d2bCORlG6R2ezFxfHe0PoAWTHo
joUKlVlv4DwSojXPI0A/76MaKNmBJcf/3R91RQR3A3lx4ggP3w0TjJufCnAv
YpFF240XoLgTPMdVFEZnvD45BbJQMJI1ESpP4NtFUnl0rg82gcUDi3MGsSyO
uVUithfbSOv06D18rMqKymAm1MNBM1WS70KCRi75XtJSgVbb0KXOVSTqvTdM
1mayMLh5W02jD4HsCw5P6deb8Oh+6GyQ6gKfIcVxnqZcfD5yM65rYU+0S/sf
h+vH4uTcxkVNXylEEfJS7qrdqI7+6XKqowgM7fHSNt8aGNRO6c6lkFBgsZaO
/XgPK4ZVZzw1iJfdH9i/W5bj5uZAiwJtCq2SWk7jahUYMraUspWjEH/5dzPy
UjfWHOV3W7mIMP0/8aDFoX+QHdR9ZidImEsGVhPbkxB8evjA2GcK9O0RGoZX
OmDlwapqNhWAJvth360wLUwy6vUSNYawc+apwNi3HyOPZ2KK0I8tBhLc4dmF
f9J4v2tf/SDiEkIbU6paodo49aBUVoTLbuW/KvOa4O25NyYymIAE268sNLcF
r5bI33GyEYN7Yywq4HYP7sVEld2+IITPvgRDuhcDGS55Kp4VC3+65PzMeedO
mH1TTuOrCPBtxjq40uIJ+sY1pSXzKPgd+/x2dXwj7u/Mp1nbkaCHGjrPNNUj
ryTLv+I4AWue08yi5c0obYgO6r8qxv8ByeHhQw==
        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs8lGkfxtF20EqzDq0tSzmWwzBCltmuEm0hJU1JYURWUlTaV15kkdYu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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4le8fVomMomwhFVFGVonKLSuVVUmUZDSsSqXia1RkREPLaFFRVhlZ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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk41ekbxqmTpe0XhUrpKEs7bWi9LUWUdYQiWQ4ijTIlSYsoFYmyhCwp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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk41IsaxydH0bFkqxlFiVFEZDt1yfOVFg7dCmVXsnSn6BDti5ZjipSl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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns8lGkbHm0nbUIOHWkVtqSkKEkuSUg5DW22fCoh8cmp+iQm7Na2EkI6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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Ve33xqWJikoqUVIZGiRKRHSr8EaKzEmoFGXIlKTeKCrJ+zVlyBQy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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81PkaxxEHRVFRVDSISsW6pCSfblsjtYkIaUNRLqvYklxqTunQ7skI
iVbRJAkJbVK5DDHGLRlMMw06hfS7ELmkZbW/88f39fz5/X6fz/t5Pyzfk85+
CnJychHM+X89PZbLXq7yGpPnY26fCacgd17TLertBRQqjpgbrSfQJ2vyrCwt
g6a+pJM3l8QPPznpW23uxsWZqUUOXjQSWffuZljVg32l1WkOi8JSPZFj3QsJ
RrXHGmOW0xDGr5rP+v0VVFntl8wPUciaCAqd25wFSjE4cWkMAY290PRWqMB1
+cJnngdJdHxVGzEUv4GV+nSdg5DGc4Owa7whCcxSYzpm9dMouxCnq2nfBrVx
vweCfgoabFVlqfVduFeURdxPIJDWspVTZVOMabXHUyZiAqZd1wtbhCLMq9qV
cH6AwhYum13g8Rt4qgI5220EhOs0QmxJIRaNCFZm95KQKrFWm6Z3oEQor3L0
M4UD0ott0/JvMeC1XzbzhcYaiZrzL43NODBcH923lUKERZX8bF4xwiflR38W
Esh5MBYqtWvDkLnl5XJtGtkbnDK5kRXwP5dxxtuQhLXnkxj9ZxIInjRFuajT
yFgZr3WrR4wDCvX/SZ5Do5bv/uhfZC42dfcEXuMR4DmyJvzY7TBRt/vswGHu
6+afbR/pwZBgoCs/eBDGvcqWwvf12L91zRV2EYm03Uv7Sgpr4bVQsMngCold
h02IfHE7FtwusAhn0wj5avMkOK8dWsqb2gUCCpw7w8tKMu9C2KhDRHEI+IaO
SWtXNCCjo+nNAhuGh2yeya7617A0XL9FuZvCGs3J5szKTtQoB1/JUKAReOJH
Qt71LWYsBgPNv9M4ce4jppn//vLbBG/bchJyrr5Juy1fgu10MlyaRaLZwDnh
uHo3tJqCT7odGYR50VvNcx86MZx2kzvkSmOSKAuN9Bdgp8pkhbiPxGJzrc02
rAZM1f2tHfmVRPWy6suW0cU4MJLStaCOwOm3n45lcmTI2fOHmZriIDjxOaGz
wpqwQzqvNXoHBe/Ze95It99Ckf9E4MYIAsHeHiaT32tRYDT6aHYVCVPBg0PJ
lQ0YbLgzM5pLYrrkMG+moA6WtrtD8q+TMI8aym/4uxmpeq2LR05REK1fwFOu
akfPpWPcJD0aGjasWq2ARsyU1/S7bqLwqnfvr38WN+KYlWqKgh4FO19zM4eI
MhxaHf/fU0tIdLlVpuacEOBvTV5OTTUJg2il9337OrDoZBxfx5TGtu0VoRwH
EexLHhr5V1N40fRNwye7E833+qP1Rih4/lV+gLunHV7xfNN5djQ+aTuGfByo
ht8fCw4WxZHwtrDJG/9yCyr8fdPjwQQmBkSlErtO7GwirQtLKSTe3LvJTFWK
2HTH3pYMGjnXF5a/6u6A08Nd14q5FPhRvWf2e8Uhui5v5ywQUA13PG0wrxG7
s0RR9pYU2GP/Vhq3q0cB2ytSV0IiZQ23K6+oEyqvktO/+NAYZj06qbioErfn
6viXu5AIedVUTL/rRu1N1MYH0+jRDFIyelgFr4B3rmk+JIyNg3pEZmIMXJaR
4NDwcRz1i2fVoSZ8cq2WkERNyjeftpR2SPJr79YOUjA473VuRc4bOOdOaeg/
osFP21p7a2MY+t8dDhOtJSBICkViphifvhbPWfKJ4Xu5vdGWhiA89Xa6rGjK
+Cagb3bD9kok9kTqT7FIlAnC1j1fXICfDFuHdz4hkFjzaXGIwms8aqk9LM2i
YBajEdBqJ4HHO0U393Aa1juHUtOUK+Gn3zluY0VC73ZRrG7kS5QnfL0x9YBE
nIvSD7uaZeBqJ+8gLzDvG89rJo2vwoqovBrpQGBmX/dT9f91IGBZefFChve/
jDM6PV3a8I1LJPOZ/ifpxj7fP/oGNWZHpS4eTD7fcy98XCqGdni1Tr8hDcm1
uJjjo1KonWBvtY2kIWZZsufXdCBWnePfc5+Cikanm0xWDWe11R4jHIa30nWL
Nxu34kWYQ5kc4+e+yBeeM6ea0ShR7ajuZnj59YPawYwkxLivZuntI4Bs6+XP
5ET4vH9h2qWzFNLEZz4Uy0rg/DG5YNs7Au5PItJN0u8hznadSlksgcMlw0c0
ytrA/9GycC2zP4JGfftWHn+NTHv7CvciCutueFgfWtGFx32uPvdKGZ+X6t/X
Hm5D4LHrsVveM/lMtMyqWPkMeaqp10p1SGy4wz/iuz4TlVum4vRDCXDk/I/l
bm/H1bSz8v5yNOLPXTh6o0kGz7lO3hYezLwHfZf9nO+PMB8996BVTL5uc0VW
mfdR06tssSGVQKUr1/CSRQ0u3jNR/sj4J1Jc0Z2qLsKtjYO2t8cp6Cm+XCRt
ESGhHqeXJFHw/f0It2evDAlF5RLdKsZnxinnK1Y9hXue6YlYdcavbVnz6i07
YRz1YY7SPhoRmtkBj692IMLWJNpPRMFo1qH0JqoRn4XzN7MYX/HTvgXy70tR
8KeLdkoZjTGdMd2eWBGcjrsEpDP76x/rK8uQ
        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs81IkCxYcil4TKM7bc3sU1pjxSHLrD0tY2vVNambCbkqKQ2l2PtqyQ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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4lOkblq100YZCUrshPyIiJBVu2iHrrIPapHLqiJqy5RI1LElIaKJs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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VW0bxRElQ0TKG0lIkkQq1StLigxp0qBSyZSENHnRpJJEiSIyZcqY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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81IkbFvJrVwf9dttVm3SQol1FbQoPKUelRJION2VDioRyVCuR1eQI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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk4lAsbxsd20mQ/keX0JS2kJKVIcqskpEjZsiQqFKVIyhLlcohWkWQy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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk0lWkcRqncUk0pXLIkWySiIcs8inSto9IoS0UmbRhNRa6a0iCytEgY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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VP8Xxok2SRSVomSJb1qIKC2PJC2KLJGSlERa0IIWRYtEKimECpEl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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs41WkXNW5JhSnky1EuUSgxpENlUYqvlEtNeYTKZDRSTY9GJk5F6IIi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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk3s0lAkDxgdt81EiiziL1RYhK+NSSvUUm+wONWxXlWXQZmOUbpI6Uy4p
vshWkksKJbdmSorcGTOJmsll3G/zzryvS+LbTVHsZ/94znOef5/z+y1nh3gG
KNNotLD5/NvBRXmh0toWJEdHtmQ9JbBFI72x+X4+Vn1KHb1ziYJlsAc7kfsK
llnEB9cCBcThhYH5eqXQ/nxxdKCYxOscaJ4tewe3T879JhIC5QlJ4u0fXiL7
uPnYrSMkHOjnR+rXFiNeN9xzfIrEWALnhd6NVtwy3WJeWUcgUzBUv49ThMys
sDNpIRREb21LBMMNMKj5ahUerEBxp8QrWkcCiwUHXzruJFAQ1mc9MtGIbYZh
cOqUI3743vcNPD4uutK9vv2DAs9dKB3rzoJ6kPviqgwKtLSRU7OjOZiMl3fH
Jsxv/cmVJVub0eB90NZwnABP5HPuBqMcHq26qiliEgtCvH92zhXjye4fu+6+
JlBdFU+meBXhcrqfyGo7hemVQfWTJ9sxdvyWumUsgduRaikHuDUIPQh+PpeE
1gCWxTB68WWbwRqDgH5UqM2Y3oxvwYl9cyyzEhl8D9m2VTj1YLXbUo+69/2w
i0sQbop5B3PHmYoioQw+B/SipQvSMT4UOMYVU/DvefxQGl6JQ+yCUYdCEvku
ljMjR9vBnF10WYVHIP2DwvEXIwEcvB+xv++b/+uB3dn9DAnadaV64fZyqJo7
6G/vfYokpmm8uyMFa+F15whGDcQvBV236xXIJW2OftIQgsNzN/MyVqBZy+hu
uFUztErV3D9fk2OPQafkLNWJHCt2KuuVDGMXjHxDzjUiKT3qXlmPHLlPExln
x0QISussrhmWI0ynJE99pAiLbHXW9LAoGJekK0npEtDWjie4qBMgWDrLnvlI
4WT0wE+texDvmQ7J/2PxYSEaSeraQyE18edfcnx6IHKkirwDZdDc0bfBfqIB
KUuUN2d6KtDRUZ219cJdhEsmao41UIj6mFFhbyNEUVZMuIitwB6Bcgnv8Cv4
B1WYs7QUGLjS1lt5uAnxO11cVdzl0Ht054JD0xuYV5trRv+owOIVbaxav7d4
8a3VwnVHCTROt3N8M6uRt3oirvoaCZU3pEHxT72YeZcekRI5hGOThYt9Axrx
hoq8+9xDAZ+s0lKHiTo4ufnrT5YrcKuvXD1BJoFdUvK4jo0c1pr8YcKoFntS
agc/zfvD0rjuxOZkglYaNvr7awrcBwt5kW8b4THO1NzFkkOQo7epeaoVU1Gt
p5XnZKiNDXX97Xw9/O6FFE7eVIDL7jIL7RLhRdfxpdMPFfi6fsPUgeBqmDLp
N8rySbQ+rMr84fMTxPH5ApNl8/5OqGoeuVaPBXlzAwH3FdiiS3+17O9s7DAt
/si8RaEfJYOCdU8QpV/r/N6GwuY4BdXp2Q3vik0F4bEDWDz+G38oqg770jR2
RRUrwLv+NcT2myYoG/PMluTLsdnwy6G9cbXYbHHCVM+fRPGixdW7p6U4KVKn
P2YMYmVx1YfYh91wKaSHDHgNwGxR3/L3X57BzNT043Z1CpkJS46WLSwF1yhn
16JHJMKGfeh628og1K4fXfueREdagZOWaxNUNuares/z+XS57BIV0QC3yDn/
WR0FfnJ93pHtK0Vr1TWmHYbAVeMuUFs2z7OKBdNfqgDtm3M6RRsrsfBOdpHT
FhLic2YRtrF8uHFGernuFJLn9s0Zbe9EU+AU/bYNgVQP06Meyv04neYmusOU
oWBg5o/jfd1wY16wCWDI4GHX372cXQ0P862f/7EhUW6u/8RFS4yMezF+/0QT
oHqfrrNb0QOvtDmXx7QBWMcmKBlaZSLJ59i+EQmFYkHHnSstPbBUsfvvxbBB
NCiXK/k41SMxTJn7614SWzxCngTWlkJ8sj6xqIjEbAnlNGwtgTZH1Nx8kwAt
cH/u5RN5iBgT2O9OpCA4EWoo6W7D4doWnY2XCUxdXRnccrgch696CCe9Sagn
Oo7Sa1vxwd3gz4xVMtAcZOufG+3F33ON7DHDYRxj5ScLpp9Bd1cUhzVA4thy
xsW6yBsIZq9cbUNQCOe7Mf+80obpl87GI4MEcg2qc9fXNKLO/h7pvFcOs1UX
T+fGNYPgRGuMfKdARvRCjaqUdrj0/hDN7ybw3VCfsP1KD3zj0x/Zf+yDgc1Q
eYqJAGUWhfxeExKJ0YVZga8KMJTxZS7iJIVWRj9vUKkEqcleqibG834clOd5
XW3F/Qryk93sEMrXcBlJpBirtetTgmgExKE6zp4WqTArGTf4vZXCEeWPNpey
a7ApQ7/Jr4BErqdQaq/9Gh3Hb+/+HDDPQ8iDm6djz4BRmG+wYukwXHQ3SF5o
V0PrvklcpzWJFVuv0e1WCRGotD9uVqiAMSPGvjK4E4U1zzafH5fhVJDp7H+u
t+Kvc0qVNdoyZO8Ymvi19B0qL6xQnDklw2zAGcutp1tQGRPa1pNCoMlo3GzH
X03IJtX1VWcIhHKecVgT7+DaFeDM2ynD/wFjSMuZ
        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwdlXk8lekbxhkxSUhJ2qbGlihKthFdUZEUR0SFMLI0HSqpiUwSEamoNEK2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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4le8fltEQmZUZEUqlTSrdKSUNCZWWSgNJXyt7hUooQlZSZFVEw0iy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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwdlGs41HkfxtFGiSRE5dkcSoe1kV0ti+em7UAnil2UqKnssNIkuykRhUiJ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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs41Akbhicmm+2wdkWLfC5lYwtpk5DtEfow21UkEiEVM0UOySGbsJ9E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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8VWkDx+2ZdildRhShZElqEvKLSobiJlkiUiqpKGV5LUXhFSluTV1Z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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHk4VG0bR6VdFIWEIkulJB+S/FRIKmlRqDStJCWFQkmKtJAtSSVJtmzZ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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs8lOkbxu1WyCmxJKkkpZCmktocLr9fJctIyJRjckpJ6FMW22EcKiEJ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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk41IsexhlOOVqMrkKrSihpOVGK02spWyXJETq3qKgkS1JCQuoqky1E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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk4lfkbxlFkL1qotAhFUeiELN2mVH7TQqJSiRFnbI02REj2UooQQv1s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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk4VP0bxi1FWSu8lSxpsYQiKlvdklSSVNrtpOXVhpAipRTJLiR+kUol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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41Gkbxx16VU5RElaSSDqZ2laEvnTUJFmNdWh1QE6pJN43ZaU2kXZH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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs01IsaJXnVHFERbuHIK8ml3DxKWyrk6iV6ODreRXVMDkWRdxQlJLpx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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk81VkfVqFSI5WlTbpvl2uJSiglzx1U05QZyYTIem9NFMVNQpIw2RUj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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VG8bRlFpjxApSdJCRZQfubWIZE+2UEQkSwkpKlQqImXJliWFFoWI
yh7GboxtRNow58woS9rR935/zXWuM9d7nud57+deVjl6mTkL8PHx2fPz8f3/
N1v2ocLh9+1oUC5vXFxPwylMzXzgShN2/bktGf+YRsfz3bRjRiP0gkyVeTdo
+AhnXdoY0QVNlvJC9QIKJS1XVwtzmYgL8Wv4o8vFxm0M3fNNqXCQnHcucjUN
icGghOzTMbhAnb67WJJG7of6+weWdsHJWkR3yX0ONjsfH598kA7HNxtfVQvQ
8Bz4tmdVeTduuNeFDaXxUOF0q7X0XDVmZ3tMm0XR2Fzi9vn14SSw1i19d2cz
Dath85dWZs9wRaB53+LFNGa2nVKk2tkwEjMc8HPlQcw3bdPyGW/hfPfro8Uj
Q/DM+WZms+Md7v1pU636woP9y38Z+oLdMB9ZYnh7GQV31bCY9yFdiN/NMVrd
R2PP8FN+Lfk3EOfaC6nwKBS/XTGZ49yKyHtDaZ2yFGxFd5wdHK6A5y1+w9ps
GhO6cpKqjjXoYR81dxXkwj3t849LeTWYzdD9tiGeRnUt45Dp+hf4tffs/U25
FLRvStIp+s1YYPJbbDubA5kOu6fG4p7QdJn0f7mKhqjYmd4zn9JRZfG1sUWD
Bod97shmfxYa79ZzvidSKHg+bbY0tgOaljX84rlciI5Of/5pwkDQNomIZz8o
5Jop74pcHYKzT/kXC6ykoXlF541fcw+apJ36Xop8QhRjjtvDY+3IWJrnlU/m
zed013YqmAFqoZvN4m80jkQUvskeZ4Ct4DsakE2+FxvqlcerhlrnC40sgg++
W14dNg4lkLlqmGBsR2Oe5tczKlrdWFk4SUn7cUH9c/n1MIKB4DG9PJ9g8v+5
xotdioKwfUreQIDgo7jk1iYNnTaE2Sn8/P4fD0EWrrxDR6vwVCP1n+t3CjIu
7trO2nFQCRszOEbw4/qpxS0z/QFmTxulrllIzrse3NohlYfd1vUu8v0UJnUF
/nm3VKDfPzh4z14aQdPPTVvfBuG3RmXkVjLP0YhRZuxYFFZYLlC/IkvqPVk6
tPIfG+0nrCY/xg1hkUbcfo133RBIEG/LBhe2qUZ/prhVmDxsZx/sQ0FOIvFb
KLMdtToTHZZhFJZEBs5yP9iFqPLlI/PMeXByo1x2ZDCQ9r6Kc6KJQs7M2niN
jzWQHPn8lVdLw2uFSIGxVBGeFpc+8jGiUehirbWylg1vpiQ3KZ5Cuq/gfu8q
NsrNFpoN1lM41vtk50mVt5BM3v9GJpGL3FcVy6yS+yAfJKeUKcNDWIHP2Yxa
JtQeNDb3fKIR9U3N/phGDvSb1EanQaOCjv8z0lqNmV27nAK6KGz1/eF+orga
dXruFzxSaQQOFHlOxjJRJy1Z2/WOgpO/79FB2UYEpKqE9P6iwDc0lRV4PhV7
EmyWeAjT2G7qXv7mCANiRk9HCorJ+z3n6tqsnbEohaX3kMxX9kals+gaBkxn
GO63CuHgZCqlJc2rR2JocMgYl4PAZ2IhnsZMbFnzqlGYj4vhvoH1Kp4suI62
cu1SuAhVvnOukstCZTovzbSKwhz1tIAorz6EhGdMUIU8aNOSMfMF83GUb3+K
oSJN6m6UKAurxH3VP4l3/88P48U308+WYnZP+l2/DTS0j4aO+UU/wo3r7wai
VMn9P1hWF6dQi0CtR4GFt2jw2gpaH5u/gH/4fM9mfoKnlzet5hyLR9dfFeXH
K2j0O+YGKgrW4ABf0do+BfK9/GZp5znFmO7j3Mwh+LNR8lhwcl0bYs5V6Iip
keeV+hbPgnogL1V9gtpC7r+Rz2uuYQsWanbsdjtL+CreemzphTyYJYXOvmVK
48LLichxBxaqTgbNiXLnIKlDbW7Arg7cVTupmsWgEFXjGXRwIAbu33gBhUqk
P8HUH2f350E2caXVL3MaJ+dlu6Y75GNGUuSUAqlfa5ZGwKBkIyYP2Nnl1tGI
DhsYeyDDRNlq7YpbNynM2z3uayNXBQXPA7I6b2h8uihuucexC/nx/o6hKzio
23/ts8Ta+3B3+rpd4ycF//KxsDCpKuycUlg4U47ow8pj03lZPZCzT8kNJvub
/cTWXHZzG4zOVNxljlAQCL5Syk1g4xmvMcDgEA/XvC9FG8d24VzRpgaByzzU
3cwTWMV4h3ith9FavkMQukWXZoWy0cAaVu104kK+SUSltqseVPV5S7vXNBYd
6xGfPczE1AOfkR5XLn4ExLydnNuOryllTUs3UAiytNspVcxAkYXu1YdnaJwQ
5qwLuloJJq+gWaWbwodnjq3cvTXgDDXqh38k++HSOOOg6FvE1Sg2lF3iQjPe
MfZVTy7+KkWzshspuBbFf1CPbUflb7UuVWMuRnmTjLmO12Bg6KA6IUP61R1y
K29gINPz1vcD/2gwZ//SvZGWjP5/F/XuraHxQ1Bpo+hKFi4vj/xr1s9F/IvW
4Q+BFYiTDq/zIP28SBDVsbzfB6W3ye8X6tFwOCC9w5jJxJGbb+cueUb4imE/
/8x4FczNDKxL5GlsLdjkfKG6BmJQ9bCZ4iAzuj9348du+F3OuSltTWNyfWke
enogOG/NJ/bUEMIjRE332lcgeYH6QUvyXk5qq07+RDe0oz/y3V3Axb3XR7du
UGzHEu+dMytv8uAt8b3R/3orhLYvnzOTJt+PnXSYXnEPIQvYBteXEb12lrri
EVGNGknxn5MtRK/da/WnlxUjboLDLib8LPHP9rPDnSfgzMjIPiNC9mPYnJr9
pBLn+B85fyb95Pr5+p872Qn9TnZR1Scu7nOTtnUFp8B55psL+7bQSPbr6qlm
tmGG2UXuMuIvgl6KrzwReRIamSqdDYSfg/rSFBtsX+NmyK+oDMLn7q/derV5
LRjZezKghvDrUP4pgRC6CbZH4W5O7s++sJvlymDBv1D5/eAHLg6o+nZyS7tx
vCzS4qsjF0HqkVcOaLnAdTCqMZ3wFR/TI+bF9kcYC+Jf7Ez0UWY778O50HLs
7zc58DWJwo1xxdYVdu1YkH88xsqBi+zb7AArBRbWlztxQPhT8jRUrQw6sa51
c5KdCReBOssZp6c7cE1z0dFYPg7cNek1FqR+zbqlgpbexB/cond2HWZiWvrH
gvuGFJaZqhd36vTh1KKINBcbDjaOVGrf6+zF0XU2LVZELwZs7bWGb/XB9Eo9
b1qYh1xBoXuG41ko2/nvtcFWso9ClRqDPq3wp32lOwjeCt7KJ5xmVCIqYIh/
CdH/pkpT9pREAYYXRK08M5vgVbjWo+ZlOZJMpPZk5VNI9o079GFmLyxK9UJ+
7CR83v9i7DkzAvhPjJcrTSNikcLezE9sLHhcemkvwbuou7ntcGkH7g9HKnqN
kvl9MokZXBsGlXsNHrMJH6y0VC06ym5HyojC+g3SXFy80vhK9FwTpBrDpR34
uTjtmjf3Y1kHYiUsZ230o7HbwUdduKcNyb36y4NcyP6M2pwSv9wOGb/3M6c0
uUh78usz0zQeocNOJi6LaKQUXArxPMhGwO7bVzIfcMHKMzKJWt6D42tNkrTA
I/r2tPhkeydqM8rnsqKJn6z4JLxdpwfZfyMiO5R48CndeT5yORO2YmMxKx5x
EG/eILn6NhN9fwsd04heCmxZs1w9qxNaK5YsMZ5DIVCtyihRvQpW+8eSrBqI
/1C2k9M0K0FiY5Uya4KCnon8hmihQsz+o8ef2UmBnRzEL9pSg+VjOSNR5Ply
TrtNRWw97t2a9WxdBA0xiYY3J6reotbVIzI9h0JHlMBtvnltONY1uUXShAe5
fdcPnJLtwJPske1ObTzMM2Vs185loNXU4kZpMg1b3dshSmJVsHhZ3zyylEaD
Wq3BEjYb+1kJVu9fcdE/LL3/jFozePWrgyKJfxsVlxE2y+yB3tJH69rf83Cw
KOtCws8u+PxQy427w4XeUdP+oD/ZCEs28PMk+v6hZPVr/rpGWMzt1LxazcUR
qmub4okmRHvtXl60gMavrkPCkznNsKlxeSNN6q/QwKPAYTaalhxcPz93AJrt
hee9Q2qQnlI5q+E58bez17ttG7gM/chri1vJfgldCQkw12FhY4KDt+EkB3yj
5UuDjc7h8w+BRX/JPqoj3DdqaxuYHZ7aEU9pfNltYFPP344tO6QbS82IH+yZ
qnsQWoOCSz+vzyd6qCJ5pH5+SjXcBg+mOlIUHimVDjvbsnB7ofCIwxgX+WWc
lZdV2KiVGe1INh6Aq+4p94Wf+nFkhYHQxTk87DnflJ6r1gQZt1XjCtbEL39R
bXvd8gpHRg6uuRhH+PP9dYm3nU2wr4nNtRWhcD9oaXSXchWm9x0aGPanYaxz
7ddwABMxARdNBd9SSNzHF1mvUAJPh811BjpkXqZnzvKWNcC89fijvLXkvN/M
jLKvdXhXVVbuQ/yP58hS6vbraiR+tnTQJ/P908nYuPFMK4x3ftDPEuJCURcP
L4h2QyWBcVeE+Jui3hqJ8M42pOieOjI8yMGvV4/fX68vJbgwWuekTUNesWT9
rkXVsHkvX2JD8PxH5u0sVtoLXHJc/7yE+JeQ8OL/FNOYCHujeejmXC6KPyh3
/lRg4PChiFlJnjQ8KnMKNLnNuHYz/ZKtGBd787TjPvlWQk191ZSRGNn3DLXQ
10PlWH9RaXAx0dOfa/dx2cpd2MrU+VFN/IzM1Ev3gKkeFHuJTCgbceFdEf1k
t1YuFtnmWsmvI9/X99Vs+8KCTey6+257iH+pWTX/5KYmhOw4afXxHg29hdyA
i333MC2bmFwkRWOud13mZeVG1Hnd8hQmeqK9da3Ul6xMyFxeYrllPg1Kfk1r
pWU1HraYfMrbTSNyZPCK7gM24iQkcvP9KfR5D3NvGrNQsCvTNliJ8InV+oRJ
Zhzg8rffn+i5t56+eMHvDoyrKhvOFh+CwX6B4Avrm+AxeGkigOSZ+wGKql92
NePJM8eNvPM08hxskzlPO5HdYSjdTfLP3vTqHbK72AiVk99uL8CFnNIQv5lW
C8zjPgxJrqZgs+LaeeHNDci+/qZWbw8Xm2fYxIgTv3RAIyCAY0XhQmX3wqZW
FjIda8+sKKEwc0fUqTfWVbC3kC1SLqOwqOft6MNzmQhbJpncT/pN7jv2t1u8
CRVNZ4KfXSP9W6TnW89vwNyQ5U4D5hTumT8Uc2GzkMgnx9xkQvhnd6Fu67Yu
FNVnuR68z8Plr4pVJYIViKi18NWuIPoiNj4Vq98LJcWfFsILOfCf689aU8bA
RipruFCX6LdCvaDHwufQEn8yS/09hdoYF0X10Qbk9R5pnf+RgzGuy/xqwRZ8
Sx9SCx7lwETo8qvzj3twTGL8eyDB19ZKxpyVXUzEBqWvtiP5PijAwPSIZhVu
i5jXmBF/zrc4d1Dn9wuwXO06VhO8eo+JjBvsZiLA+pXjd8Kvr+6eytEMZUK5
wkrmZRGNtN7rW+jcBxDOXPTT7R+F2+wbm6xKm7Eh51VN+GIKK61KRfrmsxCo
lP4q4DjR5xxLkddW5QgtWvq4soICk/Xa6HL3HWif5U+a+X+9lxr9775BNQJ1
KxeUChL+764f9Lj+HMOHx8ueaZJ6J/s+5rV0oDT2zjquJfHjjJbV5u6PkNjU
2aG6nvh5PU9vzTPlqP+RnFj2kYKPBGJrDxO+bdlvbmjPw3/p/xXbJLdj5pNA
bcUW0m/9+T6W9RvIv4vbJvWN5EnKxyIgs4Pkivr8fD4arXl26brNLGzJLtDf
HEPBzI+pMzenC2UVhlqHrlKoc5DwOn2+A1XvZsxLnUX8sKCstOdHBiYvr1Xi
PuZg5tXe318aunHy0pcx0/NcLGqciN6VkI+lO8R1BEk+0F6las1eGw3RQ1Yb
PMh+hR5ffKp6DeEboRNFy8n9uado1/cV9uDc7xPWvAYebndOrDiq1I6xY7OF
3bKInx55rS80HAUzQ1H7aTI/25KbOqXGldCfI7a9PYHojVyhyPuYWlx+PtBt
dp7CE63MF8OvO7E+/vjfsTAy7x6Xmiv7y3Enr+fCXoIvpzohnZf7mjH+Q6/v
qCXJj+brGqyJX5OoCM8VjuWgZPPmf6tEbuHDpqcJ0qTe7ZH/qrvE2+Cl6VU5
0E3j0TJZlqhLB76XB9x5Svwn9Xlvf9uFXGiHuj0o2UfOF/54bKlCN8Ks2vUR
x8NT2bs3DYRKoHHiT7LkYeKvW3xtclobMb1jxM2c+Evt8qa1u0YbEcWr9286
S/iitziJl/UQw6nhU4Zk/7Q9Cz2u8C5hjtJaRtz//ePxNXx+wV1Qf1QjI0wN
QZTuuaHZX4mkScHUxj4KGpyM1DiXFnyQtp6yIHlz4mJP35uEXvhUZS5+qs9B
hCYa+wl/CntGyq3zGoRMyxHDd4nxCDHrMbgrTvxWxnTFmr9dYKxdaN6mRcOf
xQ56zL2PcWo8bTnxW1Fu5+Ry572EfV5h6yplGj79GqMjwiXw61ag+Ehei2Ns
743veAvlcKglbePhSOT6H0pdjThiLVXUeZ3kh/7KA3tmvUZwpWvVdw6FFu2u
DeHVTHiHp8z5bExDYf680trqfJIf71C3JMg+RG1cm/YxDx+8o33JJmLBn9wS
qc9sHGjQFmm/OAyT9UFXorUfoWlC5GzjEMFrmvZKk8lmlG7KN3Q2pmD0pOLI
j4VsCC3LeGlG9CHo4JNdhWaPcW+P0ephol9Ov+M328j3QEIq/N9jkkd2aWXs
uBjfjppFQ7Irhgg+1J0PtKnUw4Lx5EVKGwdl0SFTDsxacA8HBtpF0oiXFXxh
XpiLyS//CYmS/Gdzueniqq+dsLo0uTPqGhdCAdRI3okXGGr1pv+RPM48UbTq
JesBtq3tDjQh+/xBbm6OWPpz9N+e+Bmj9//7SqxTIHpYw00OdDciem7ZtrM3
tpXofdn1ZT5kHmVxd54v7cD2dSLPFxTSMLjj11A9zYAab6OQrQ05by99NSWk
EWf+9jwflKTgYna+8bMXA97fdUuqozgYtYvh/5hRhavNp6VSucR/89Vf+ylx
HMM/la7/H1/9WS1rbOkOMH3SK2NUhvBpwrS4+l43HmzgO10zwYNozaqp+KfP
QbWeT+0n9ZrvP5ycxcrGqwnrbbb6NP4HYF4eIA==
        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk81IkfxscxZBwRW8Ta3ZxJSOfqeLalg4rZhok1dtWvciUdUrEiR7Fb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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlPk/1IkDxociMSFH2QiFtk0hR6GpB6u2VTk7djuEkA41MkQkSUWXLrWl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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4VOsfR0Ql2W7WSkLTjRuuFlsfqVuSblq0cUuoO7qkoaiUiEgpspat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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Ve8XxSVEUZo1UciQvoYUUlklTaZQSWUoJEmGSoRKipQilUJliFBm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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk81XkXxxGlyBalSYpoVLYpZXLVJ0qjGUqKEpNSlFTKE4/CjCWJIksS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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVHk4lAsfVX2KrpQirVKpyFLdq49LHKRCKYRoQW5pIxKFiOTeZJnQKGkT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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns8lFkYNhZtWm0hSWLdShJRTVrlSWstEWV1sUoouYQmUYgSyiVbk3bR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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4lF0flrJHkkgbIoUSWd4SbhWFVEKSLa9KWsRLQkJ7KZWllIq0kC3J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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81IkbHjkiNptcxSoqVPrpIkd6bDokV9g2RMqRLUnJMulOByqyZTum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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41IsexpWEZIlocpJREi14OoWJvJZyNaESlYqLy7lJZY9I5lLSQpkm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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lekbPpEkpDQt0zRGltJCG6UZdSPTJHWQsmXfxhIlSw0aa1JKKI02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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c81e8bxqUSGlIJlTKjoiSVhCsjq4hkFFrUV0NRIjNCMhIlK2lIZlbK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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41AsXx0fRMqISupSia7xpxJC6lqavNlR0JSnpUcry3q63cMkSlaSL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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81IsaxrWdtHBCSrrdi2jDcbSgxNN1urQgbZJUJNFJWcoaUqRSMiGy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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns8lNkbl6UiJKWbFllJyEpIyHdUSpYspVgyWDZSySUUCQkrlVzKipqu
xiYsVhpiXGLKbQxjmEGr3eKkWpVVkfzO74/3M5/3c857zvN8b8+s9g128ZeW
kpK6TJ///0rdLZOzSTqIL78qHJynRTBewCQ5P1UhbSZqnYYxgYOtylczjyFY
VoS6c+8TKPA0yk97C7Dk4sG2e6cIolZeYYZsvIFFv8kEWGgTeA7artbndsE+
y/ZJ4EEC7u8ZrvsfDCKEeS0zOo1gNN9RYUFeFXYmm6k3rSeYen26UrenH9ah
B5JnuQR+M4XeVg+6cMGokdV7nICjdab8TF4r2B0t/pVOBH+tuLTXOjYVoW12
FwNovTln1vHTd9bj3HlRmDMIWhYbMFOt+5DX80HO9QHBUPNl/xunhPAaODya
cJnA20KrbUApE9fiPVeK6fdTcxoCk86JUPNO84BONIGd7/DQSIoAq3rkIr1j
CCZ3bSrdzxhAeUJNwthvtD6lgCVPuzuhq7AnTcufoHSq0aVOtg87rDVTUoop
XrnmbdMmtzDNuJ90aQ3BxPQv5BsixNnF//VHBBEo68ydl5n0Jy7YBi5T1ycY
sK4J4qi1QeGtWPGmF8Wns1+FV9ONqfFoY7mzBBXxa9MXRIqxZFmoYyKHoHbj
mOtjwzJcUA6Y3KBLEMMOrdT8sw+107Xa72m9b6XCo65/7MTQkfdW2nsIPh1+
JOvwsgchwXKWa4IJWMpL5q+/ycLlmJLIEsrX2m1jBRktveh6crV/ez5BHFn8
NfxABSaEhXn+6yh/04ljzF1x+CgyGnGheAXZ3DG6Zy/BjbMtxcczCVJsXAzV
funAy/vtMfW0v/HG1+1OGi0YLZVdpmFFUGb8rGzzcB+K3c6/zD9PwNfc8KKj
PQNFn0z1P9DzXMY9D9dJdePRaUeeuy+Bx14lD75PNVZtbvrr2UaCu5vOx09F
92P07WDitVqCL3fy7SaaOhA78/HYwh8o/uVJ/ibpFZBf47P1Wz2qv1N+I1Lb
72LD2vpOE4q/WJhWOK+pE9zLi5TyfiToebFgVamqCNIXA6XfXCUo+nH84a2l
Irz9udo+6DbV87Pn+f1V5VBUnLlRTfvn78k09vUeQscscyj5JYFmh+zG0e/v
Y+3dhKt8ur6EMQmt021o9vB/o7yX3qdS814S1IgGR1lD3iaC3unEgIxCHn76
bkql05rimZuVLTHLxs1Tlq+MviMwyVuf8FqDj1d+jFU6lB++q3K0DoMFmZlD
knHKz17l7/nmSjx0C+O2/+1MUBV26JVtYRNUBr4NY1O9M04ULksPoH4Mmeu0
J5ags0Jav251HRTbGOu1TSheYklR4IIBnNs0OmPxhO5Pm/qUopkMN6nK59co
/kbpry/PqWhB1Zk81WgX6o/0uef4rAp84X9kmhrQ9Z7qY9VvKD5rXOLUIwge
+P62b+nPAoQV5RRso/e52e1I8isQweEwo+I19atUxDaXFbr9CNPT4/rcI/ja
bMBPW96COK83+rE2dL+jZXtJ8ACq++KvvzpNcOE+UU2s5gIFFxK2bqB+U3Uy
sWgfwKl4UpjxnPqjPcY+9UM13OEt+IPmkabMtRuGNkKEi537fALofR21YnPl
MPi6a/DVaT/mwytX2wXyMXdBnqbQkyA9Ur3dK6EQsc7uKm1UD0s8XUfKDrXB
7HBHZbIDgfQ84ZB4Nx81+9ao+dB80Wpyc7qd14Vr4AXvpniwYkqOBIW2wrRJ
pWKa6ifxG9MtVbEipOmNycefoHnBVsx4mNOKsXQdzq5tBLxT1UP/LeSD1bou
OorymWv0ddi9V4yTkqNKs9TP7Jpi4cR+CQy6fAcc4qnervsf0o4VgMM0a9ic
SPVxJjOday9CbWDXLLeQQM8+ucTZnAvFX0xTjAwJ5sv/o+meXQ71OaYSQ5qf
K69ayUjWilApcTIOoXqe8lFtztzYAp19LvrTdgSCusWpCWl8xGkYPGaGUj0t
+vza1p7mS/QnGaskgr6LPkN6rlwsZHaHrzCj+uObh0siMlD8u02KB9XnfI7J
wp05PTjwOfyZ7UWqn79crJ3LGrDUSe/diDnlQ75wpJFzF2bj/+TwqF4Ttcbr
zAe70OekYJxL+2PpGHh7u2Zjd1axpR49T9Pd6ruXN89D8HH2cy7lyy5LGFC9
rQcdt463yh2h+5u1wietWcgX53bl0/N47ofi4qtrkS6Wypmg/RfH9u9SahKg
b0BcvIHm3fet2ufVBnthvHLrqu6TBNq6lnGlj+k8+GmI029Bvx/kxW8RlsJg
2LFRnuat27YFeWMfuAgt6FQso/kS4JaQbNfShfknXG8JqB75HjrT5R/qwCDZ
LCHVW+O+gUT/WCEmI/c3yB2m/FReuvHqXBoG+xJL/qH1s/qWNYSG/gmHg9NL
BTR/io5H6FyQF+BpVXXqUVqfTfQJzLZRfwe0fL5D803ebbEqY0c72Dd3zw3c
TnAs11VfpN4Er/BdgjZar4Jn5fLW6cfY8cZeIGHQ+fHzQ6Ug3XrUjr9a3EXz
hC0bFPJiqgFmoa7Jz+n7ofx/w56m8JGtdtH6y1GCP7yE5rLHaqBikXrUlvpf
x8zmd1+nTjAi/n1i4UcQwVyvV1IggGQ4OtiTzq8vMv85mj5sxAwjuEtiS/D3
0JZHqkdvo1umk7mJ+oXNeGcWdz0THI93Mt2032PmJ+XOGdyFFdthRI+u72Xe
e/F34QMEH2VlWlA9eg4sN1A3FSC7rNPH35vimdV/wO/kE9ROJEi7uNP939rO
WMQ8woiZeOs+qjeTgIlVLVkVqC9K+iGJ8qtw9ldZtR+bsVtmblj+FoIr1jqF
1/f1IYsdO/u2kuZ970kX9vICuCkV24p0CKzeiCINDYVYfm8o6j2dR0VHPifu
eMqBtojtFUX751+KjN3yJQOc0GhdTao/3sM2ibNUJ1Ll/NKeUz7imq9MzOzk
wXzLOt0J6veoSRGLVV8P6bdVHe40rybdvPZvzhDAW2lFk5j+33nKZXO8g/qx
XPLoX+UCguaUTEvn0V5Mni3IXvEr1fOtT7s4t0ohkmKobaLz+X/yRLT4
        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4lf8bVlEqSSUKFbIrvolSxi1ZbVSSEZUGKUJpkZKRMkqFIskeSaLI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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk41AsXxyct2riWNipSGupKKSHSlxa9JN6GFsWtNISiG9VQIkK4JJEi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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs81AkbxS3RdBFRcr9sueS15DJtCac2S22RsCW1LpkKUZK2GEkN2iJU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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekbliZhSrbfJIlzOLIktIiy3BFZUqFTSZhKpyT7TjWdg2RomVKo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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lG0bxiXFaykiWqQIpVSUpCynKKK3SJF6KyokRWSpZGmhkL3IFtJm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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHk8lIsa1rRYyzQhMukkLUTZbhktTyldJKeFwVHJvZHKlmjEnLiTSpbC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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVWs81IkannKtnZxYNdYlFWUqpVJbCo/kGuGwWcltVUoX2bCspHFJSaJy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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk41Gkcl2hpJ1G2TcnWboNSEoUc86GYRYejkiuJRVJSzmnl2GXJVaTc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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2lYTV0bTm9poKIyhWZJZSwNqLsBRbO3REpJKhVCvKFRAxIaEElKgyRJ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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlX001AkXx4lNpWflZast60iRqU0aL2VUX1GhJu95qGkoMpSWyJY9rVBL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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs41IkexqfcVkRKSSRKUaQ46xr7btlyXVHZ1dK91CqaIowi1Nl0c5dy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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8ldsXxoWu6ZgKCRkadJSkQorjMWeqRKScQjKUIiXErSiaZKxIXHQM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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VO0btiXKriRJCO0rSZJb8hWlhQ+VLUVIElGpVEI+RZItSyRJVJZs
EclSTPYZy9iSLM05QwsJleX3/v6a672uOee8z/Pcz70onThrepKPh4fHlpeH
5/+/OX4+VoEb2Jg8/m6x9rEhbPyrep762IwQB9nf/olcODMKixZtr8MmrPzQ
YkfhgEBe+v2lVbDgRG+9pE2hO4h/80+RLnA7VpZ+5htEkkBsyqHUDOjazTGw
X0rDb0HSVQE/Jk4Yj84+KuHA67xK7uZT7TD9/ejSlieDMPvdkclY0IGxTa9k
e8SHEdqSLERda0XVtcWsnXpcjGTdjGuqeo+xZeIpPqDB9bzMbCrvgdCGA8Hd
P4cQm6QelFHCRlm20FRHKw1F9h1+vsePkV5Qx3ixgsbMq7u8Z+0/QL5OatZ2
Kxdlt25lZmvWg1GkF6diwYGl6w6J68dYoPwHg1et5sJ7z4t3gu/L8Kbxcz5z
FY32YHmnz+212Hv6jGJEAAc/WEsEGlqbkHCAczo+hQNlRRGDNBsWeBbXpvZP
Uhgbs5cN066B+V/1Ohc1GiPmjTO/H9Sgt5oRH/6BgwdvBY7n2zdi8sOf2w62
NJosStZJLitByLaqEIY5jTT5xAuPPLJgK/VoffdWGuF/XDN0E5iYDWozcByi
MVV6Y8PV0Haoftu9OXea1OMTeHTKPwXzNB41dvHTCHtwtsFgKAXifZqnjEn9
TelKPw7Na4Cdzx6usz4XssGu+/cLMBGzprVulyoXR94xr+l2lMNwdcBI0lcK
rgo13yVtm/D9uvej24nkeWOJfMP1GfCaO3I5fC+N3h/ZtQdLKqE6nesY5E7D
zPDaYkGtWgwkp3UMb6Dhs2h47e4oFioThU/5nqAQsS71+NPhFky8pEPzHblI
29h/6e/+NFjw9ItzRynwTcplTyt8xL3QcmvrhcMom+f/pVKqAWPKl61/WnLQ
5J+mzWZWILkg5Hnhf+T7WtrZMRK1uCwv7RokRcF92Fo2Y0468lLlMrf/Jnjk
CTt1s7MNZl8/2VlGfcG8Jbf/01dmQnzNJ9Nr7QSPXr8Fg/nLwEp7PX9KjMYi
5osDfmd70D2cPxplwcUvpaHcUFY7nNK+lw5P01g51TrqavseJxYm24jupMEj
FbVQ8mI1VspUaL18TiPJ6O9UZ2YevnAetJStoWGnE+JsJHYP1IHtjALS/6AB
BakFNU8xJ8eM84f0r9aekTHq0gm7j3/lFZwogpurPqKJ6ag7JuP3gryferDm
weeSYjR4VN+rTaFgkRkzKT/eAdmdKgFxr7gI8lzX2jNYChavvtK5eTTcIxd1
S9Vk48a/UpTULIXXCm5xW++8x3oZndB+SxpntkQVtSt9hHrxxZKNDyhQ0jI5
Htw8dPI+lCzooJDC+3VZj+d7BAmqali4UfgWZfJ07rIWyP7qiI/s5CJ88QzH
Y3k9hn5ZLusU48KK/6O4+y8mliyh3y4/RqMuKqDf5XA56qZvBYmQ/ez0ipKN
VWbD+aK1U/YLGiuO6aYpxhRh91Y+YWHCB1Kl6328dNuwPS7x7B570k+76vHh
TAZ2azcO/DlAI0+mpElg6weoXYi0b2inEGbW7vrUIgkikgfXDq0j+53U9szl
YSCqJZ6pMpRoyLu2tlepsjDbfaxqifsQmnYMW25NeAtR24UO6uJk3n2TKmc1
KhEnbrciqJhGpGAje5lqFZoNgwUTRMn79p46YhUeglVU5WONlTTmWriqSo42
QtFiOnVkHxeHzhmOz7plgs/2lFSEMQ1BlnJcbGAr8pumZLYLc5G94lTl0ydv
0GX2erkgmb/FAqk4wxvZePeRlXByI4292/pLytoY0GL+WHpNngv95FiPlRu6
cGuxrk3S2y9IVio6YvuhDbsOBY/s8ueifWHcvqnBImz6YmBzVIvGW83Cr58k
GNBexdphxKUR9zt8kleXhamq9HEHsr9yMXmKvgvY+LpbpaX09BAEvdOPXi9u
xsraueLTozTuay9M+LWyAS9rAgreuXDxJVvaskynHWLBn+2bST9CzoQJlsa0
Qe3i0Au9Cxxo7LD1CdQpg119pNDJYQqGWYot0W86ofjwikhYP42CwHeHLgWy
YWG+75lmBBcabBcXvvds2IZO8355RfqteWB1dVQTKuauGf2H8HGQmXp5GKMC
heabZlN3UQj9U9rNl8uCVLZow6lmCgoc3XOpbjmYMxrnOGVHw/m/GymdHmxc
9d14PcCGCwMTms/RmAlNwfFlSz9y4fhMpLomtgP2lcPBJauG4Oifbx/IboXr
zPHpoy1caHK3S3jsaoZNUcE8Z14uzOYcfugY2IHhHekKY/LDyMku4T2X0QoV
h0ERKwMKw31ev7z0mRgMlJgYEaZQNbNLcSicCeZZE5niz1zsPxWjEni4Ct62
bkf1CR8HrZgp2P+VgUKBrA6rMAoBp92MHj2qR72+2eeMyxRsrvnHrd3dhMxw
LNS6SWPnVLTdg2A2mOx4ul+cA191Q+kfywuga8x9ZvcPDV+D1zb6gq8RaLjr
1DoHGoyXB72dJpLhIxGUUi1E41ae5E4l1VY8UHpnyKinITLZsFxveS20X82P
ulpJIemO+BbhOQVoi63qrzxN9rFNaUiD1QCfJccelg18waGfb3de+PoGk+PT
SvJ/KYw6P941p74SDdJ+HhXbCH88fBhn3pgOZ7dI7f3kLP1+z5//upoh6INt
swTvQgZMk/57WZAwKeRnC9K4o66UUuGVj8JuH6v9qRS+ZOYaDwcysd9CWuFs
DtmPI3LHZu0+YpXrp2eVqYMYe5S86ie7DL3cO8ai1hRiVrRw55YUIaUunb7p
R0PCp0Gvpi4QYt0HGg+TfaZeLVD2cSjG5sbU7UNeNKwlHp5Y11OO3T8KJDY8
pGGoaiAqergRPQ/VL62N+P88dOd9cCX77ZO4bakx0ZPLp40rLWoRmPft+owt
hVKZnVkzT1hwV+H1/x3AJXqStOLpohxkL2ix4BykkXAqyN7VpQNGIVbr1Wtp
/LApkh63ykDB428H1iwi/BBY+v6OdTLCsyun88l+F/e+knA2bMG2lh4/Z3sO
opbU71JwK4S5am/dRB6FQ1ZX5vZlZyJwLOKGB8G376CATnSrO3yCFc+/JPX5
Zkb/qyXmjhP6v1e2kjND+rCRuS4TPE81uQ2uQyjc6fGvO4OB11uzZFz+kvrr
Y42eeldAuWjT4/n5NMoqa+tMFdpRsmsqXX2Ag5XRNRYFb6pg+BZWZaQfP+Lb
X2t0M1Ak5eO4opAD6y93JXZF1cFpwNMdhyhI2M4t6RyoQ696ZJ028RMCtgri
D/4rh4W97/XLnwifxlNJ7lrNWHS7ULnWdxBx9TdzXrQ1IfqkAf9FD4KXitGY
fTGNKDRNGPJ0pRE9EHyWd2kr1rNXFwWS58vqg+rrut5Cbbe6szzRPwEjfr2H
yu/wlO+Ow051GgdY19eIX66HgNaO6J4JCmKJ1eVG85oJXw698CJ6Qq3/Ia0Y
UQYdF9rbPJxC9ojCzFO5Yqwtz2yakKPh5bvlp2ooCxd9/7HRk+aCxylaeTX/
LXTfGC5arUJjbKgx9/63Jggl9Q6PlJL7NhZ+2aRaAPlu5y3XlQl+3A4Kx1WX
wMvy/Ko+opf08Xw/AU4GMrwm3SSaKMg2WEpdF02ArHsYbhD+tUjQt0wcZCLn
k1/iV+IHmHJihW1mbXB+Mqk3c5GCWk+I0J6aj5BifDs7uYqCztzFPjW6ndjh
mbcla2MfFB00/pj2vEC6oKhcvjCN/eVhwqzFH1F0P3HBueVD6H0XGXVNkY3C
3lzdYZMhtDW6PVWoYCHW8oDLUeK37WS81CVC3qD0CkPC/ySN1a/T5Pc8YML2
qEj3M8Kv3r2PRg2FWjAb7akSOe8LNNzvDY7UJyPvo0qhEtGzyxd3BHeer4CY
pJemvCGNtWNnfPRLGtGusp+bE8NBr7/SIr/vubjZHvsmlviFK72Gatm+rXBW
yg7UZnKho2nu3WPRDu/aRRvniA9hvaxS+cNrzfArzBUOZdGo+bS/QYunEyIb
Rk11+LmQEjN8dCi9Ba8Pf/+5YmAAs+ITdWPvWUj4cHbNem9y3203Uy+N1+Om
o9rUjkpSz6LUpxUmHZgW1DVxJ/vDY/tpTnKJNbIX/m4RIPOSngme37+tHkLL
RfPKODSGLQ4d0fIoAzd1/ckjxO+6J0ZI3fzcjFqHfEOdjUNgHHBaGpMWg9DC
RTu+LqMhl7Phs3xcN8Kc9zuffMaFQ/x/NfzSRXApMH++8weFoOSOR063k1Ch
GxbZT/rFYxD4X23FGcSKZhzwJd93vaV8fK5gDUwEB/yPl3MQcm+L05XgRtzY
7Z4iRfxJ2W2PBOEFL6G+uHOtMuFHLdt/jD7osGCr6XGlkk0je1BaNMK8mOSg
1cyGGArtDKbCTWc2PCvXFU9Uc6Hnc2dL1aF8cAdbPvgTfNwdXd86lNMCSv/S
hUh9CuIRMwJrg1sQH+xpsfMpDQfzkAPN5u/xqt80/Tnp/9rDymLbdpRD7m1h
DItBQ9ltrDTMkQndb1FqiRak38r3D9r3vELf887F/grEzw/0xxq71aBKXzKe
8Yvw2yWXK5tkGWhqGj9/j5dGyy0vmzRONSw9nse92E+BIdsVnWXTCOemNWMj
xJ/sFtHMWD7dCp3YM+dO+3CRFHqMcrwWi2bfMLdBaRrr1Aw73h6Jhpfg2a+F
isQPZ3Js3x9thq+dqW3JOVJ/0P1WmWUfcObCHoevZN/NFgkIa+USPPrEd2Xc
4SJgvt4Hw/AaCJdoZVNsDlKK10bfEmGgTMNunKrloF2x+nXpnRo4pFu+sy2g
MHD81fNx20bYvRTJPEr0sqeB73inELmfrK3JLNEnIfuEhc39rej073rMl0RD
TXXj6pmIN/jcrPXJqI/ChX++f9UVeIfDbvzfWIdo6OipsQfFmqFsbidhOcHF
rquPzo5JNiGkUUhQU5bwZyrPUo0NubBYeroi7g2pp/VbnbF4LZZlTWsOEH/b
O2kV+Ew8B6PfT96qInrum7SqbEnVNdQU7o1fRvDkVfl6zrR0FZqytjptN6Eg
5SQjP2PJBldF6NdFAZInKnuevy+Phq2CZZsx0YcFqwy2G5WS/BGoUBxSSONj
lqfflpY2XJ2+47lHhotu6Yz7qSvrsTTDWOhkLIWQu+zD13bU48He+TcrDQje
PfNs/m0qQ5rvAgd2A/Hndl6FK1o60C2jJqX6hPip3xPyGwle2VltwrQjjYt5
l2k3q2Z0x93oKA36gs05coJ9rTUoVlH4phRE4fumZCE15ypYaWUnbL5G+MmM
tc86uQI6xe2LS8j9VYR3JQi4VMN5us0udT/xvxMeGQOu5eDJ3GywTIDkv8vO
SQN9hfjhcPwWRfJv1REbIy2DQkyN+qs9J/83CzH5dneMheQPvClbvpG8snP7
pVa+PMj99K+f10/44UhwtqFBIyaWF4YWk/m1y5WqFu+sh2lrT+hBotfyEicE
3Ooq4eq6MSoygcK5vHlHJ25W4+psydhyMg8hSxkdtb9FcHz5esczov+9l/aL
NISxINS6RCWshZzXyRh1XaxAwMR3Qc1LJK+oNk+pvm6Fzd+EubZnCB/Nc+0R
yG3C6b1vRFotyf6K10SkBDeAKla7cVGE6P3ae97qEhWw1I0u82ymYdy3vD2P
pxG3/+2zd0zmQLDysbfhdiYCTTdX6itwEBBRzScvzMBGg/vefMQPvp5lH9E7
04z1Ph3lJgS/w3Mnx/PkmfgRSIl9dyP3fxh9sUKzFnm+tV2910m/zfMcHkYw
IPaO1/UlHw3eMJi6mLLhHVkldCuPRtvztX8e8rOgeXrhlFQvF51D9XYBd6vR
ULp6/QThm5KccN7a+vfQ13dP+Uv8/QyVNmrNaYHxAWvXtjtfUOLcFCO2rA3u
y7rdKow4SFMoPh8xWAM9maubkj9TUFzxd3hibwZUlL8nZhJ9N1b53tk/1YAY
079Xa8j783wuC22m23FIf+iqAdGr9sgi6bR1DbDQuRnwNp4LV+GmygC5V/A9
+oLFQ/xr4bacXVa/XpI+yl1r2kH4eJXQMONOJBz7rFxGiL7nzfIdjBpvhOzj
B6FS4TT0Dufy7vQowLuS5NxI4s9iopfIStk2ozRe9VnMKAd9QoM3+W1boNBx
7nbPdS4svtX//BDcBo2MgPk5WRSW57Nt7qz+hHPjX+1WTnIxPHNKmP2+DF43
rWrcyH7yRCfmOJ2vwxP+zHR5eeJfvFbKafd14dzhZ5WLsjjwec5/P+93E9je
ojUBjTR+ixqxRxx6EOnafKIxjuRnb+2y+IxmXLo6R9xPlvgVycXF1aXn0VNk
MitO9Glq2d7TXX5lWGBa8GTvWsLHvw31Lt6NhUhr9ofThK+zn4dOfNRiQJ3h
NEsXUzgi+eTUiltFSDKz3No1Tvw//bTZXrcIoZmN8YdD/l+/4sbwC82gwiVe
yBZS2Bx/1LPMpgLD0RvE2KeIfo5rRhZVVONJQ/pn9SsEH9Muam6uFei0GjGy
n0v0peqPjsqGVphFrHleQvJOoZH86s+Wr3BuzZOAND1Sv4/DrHhzHs5Zbjuq
SlF4If2ptU2uAuMZiauvO5N8F/HjZcpdJmJ6fX+9naag6X1627eSfHxmpLSk
E//I84rdUZkSB4cfwo+nFxD9MnLy6/ZpgcGDwDNJ9znAR8/vISbNCB979M9E
KYX5ap6Bh7WqkZY+zFp+loJjdt1oYlgtWHddR4xJPeFZ9f11TxjY97dL3Z3w
u0bAkQLmxvcIC4mLFSX9OVj5b8G1DaUQzNvwc5r4HxmGpL3T9ha4JjScKyT+
Mi3lxaXNm6ohFv8iV4Xk30zJl5UeGzogOaosKJ4zBDO58VlPrQ6keAbI+h0d
wm4hH+HFm5sh4bZm9dvzNHySc3+nJtaj8fqkdyrZxzxDPdk3ZmwwTAc69hJ9
ds2eX7BlvBbt1tvgQvxk0z7Wq7c738JaildmazuNVaG379bGNqHm5KXlhwJp
GFhJWG/RYuKOp4Z2IcnTKUnblPb5dWFss69MpyQX2hopykfT2uD2Mf56F03y
joR9b9enJuQ+nxj560v8zJL41yYkby/5IxbXZ07jf5JhDjc=
        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41AkXx1WbrFuKNltGNcJuym1bseHrCdUqXaYkSaRsVEo3XYwal5U3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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk3k81AkDxktJrQ60H3Q5UrlCQoQ8yBv6aF8r695SjHUXS0qSXEmHCVlH
7FCudUTknJGmcjaZGYZRzpn5zW8qx7t2qWy9vd4/ns/zz/N5nj++n0f97DkX
itSqVasuruj/rmykJLq9rRXxOoNVyhMkaIs11N2+PDSRN29G3Bbg/ODqU0o5
NCTPZB+5ypCA7u1+ofw6D6F/ceTW+AmgqDo/kfSJi8q1c7Xv/Ah0ysTUFven
Ity4p+e61DvEMe+NUv8ahChlnc9whwBuqlt/et/Jw5P1LzydzokQu9T6TWc7
Bxcebb9l8oWAz+dek9VneBDoGoXJBYnwx4E7KpcK32Lzw/LsCo1prN0U6D0b
1oeC7ozjuzMJrDqxdd7c6QXcXM9cblYl8XmtVKBWIhvhHXVN5b0rfW89FWJ2
ccEv2+e9nSlEwrxmO9i1uJikHh8UJ4GHit378HdMzBhc7Sh5IobcA78ilSst
iKHp7bX4SsK28bT8gi8fq+I6t3YKBKDEX0lU3TgAN6PeK9JtBKxd1J99ZXNR
HaQ5Z5YnRFSBvsJ8EAfB9bz6yjMi1Kltqjq9mo6cTQJVSjqJqJd2cmdlJ2CR
f7A3QncSzkOn8qUXBhGclzdH9xDh/bLsZLD7MIylTTRPbxCiZOOuT2tZLGgt
Hndu+Z6AL1Pca1pRDht78ZQGTYLQ80rKedpsMEJq5GnyBMK9rcUj27iwe51h
l54mBPXd1Ien1VzIuQ6YIIPAesfcS/dkxxCtv+RTlD8FvlbxNy+dVtyjWpr8
9wMJrQ2pM2cd+tDKiqcbVxFotD/W4vnkJdROOBnvDRJDRs3U5ihzZGXX7bW3
/zSm1lQ73gr9Ddml1BDWhASKi4nLduVcKFGmCs0bhKizN/qxe10dNuu0jY/a
S1D374YIJpOHgLGxpIgGAZR9bcYSargw/xf5oElXCO4GW9bnw+PIiPeJvXxk
Euze8S/0cT5qFXsK9PaLMPbYRqZAbgCdmZ6xPzgSMJ6MVjC4PILuGxYBf4un
sadkSVH/Zw7YAbNX61fy1OUjjB1BBUjRM9Ew50lw0y14woLNQVZepnUHTYjS
2yGVPzZwMZzxJvJJFIFsvdlNFpk8xOxwu3jTUIBXxo2bgynD6O10nOR/EGL9
cwfmmd/5uHUp2VpACsC35MoemKdjqdXwp9JyEhqCfQ66vn2wtM6zKqcTiJUq
/M8/VhxQbbzjxraI0GVa6FUTMYi4a7eVUuYEkHvT8V3i7mLk1pdqbKmTQGfZ
tkb2Wy/+jvrF6k4lgWqKYmDMXiaWuk7cjTxIwrmsXlvww29ICiq683xyhX+Z
5YYs/wpMeFDoBVkSJLDJwUvujbgmz/j1kIEE6e57TM3O8qFwLqhGcEgE5aA4
SrNVN74F0AqWWASGjurNDO1swVK3gkOasgQTIwM7GCND6PlI16tqEmG/UHFc
8zMXupVmyz4hK3/SiowWxY6CLd4S3zg7hT5Gwd19qTTQND++3NG9wr/a6Oyv
pmxUb03Yq/eYQE/Uq1PivD6EfQrMvegjhmvpUgvNqAccbRm181VitEV2v7U4
wEfU1XV/GuuK4HvcIKNgpB6HU53FF1QkaDuWU+oXxkNrq+x6R0cBzJLIkwt7
SrBzUYOMqZRA+Sj/7ucSFprk00LNskSA8ocxbRYbXxc73Jx0xDB20w9RGO9D
9IktzobJBOS+PFUdmanB3MG6/XYREnQcj7YWcoYwVGGf9WSbEC/XfeIkZA5i
zmifYZWHELSAWNNGv2bs2GNDrJkl4dquU7SaNQAF/8h+2kMRGl0416x5PLS4
B9iYPhYgIWrs55zQPLDCitt8X0ugot1iNRfDgR5jyXpBROCF9GgTo2oQ5sZx
h21LCdx39UlrLGQh8o6S+sP7IhzjGA0kU0dR9KbVRr9jCvurNoXntD9DE4d0
bXMnsd2lMy0yeBTn2aOV90uEsF4d07ytvwnLlxOppkISJ/d9MTd2G8EWM9Pd
mfNCVPzxNi5jAw8T+R6eibuEaEl6+TSroxmZORaeZXslEJXtrOi89xy5IW01
TblifMp6sTayrx76lvSaTIoE1VOUIuXZZvieGM72GifhRN06Hri5B2rJdbUJ
XDFK3NKvWidx0eB1Ue6GkwgB0f5jWn+O4Lz0jYVHfdOwTVf2apTnwF9LPfgf
FRGyG8z6sgy6UdQ+r/B9nBjfhqTkiCoG7C1DHtVVkvjITLmR3DSM+Qcnw26w
RGj5/RdbGU47ioIjP47GkJBYYTRx/ikCugzSGF/EkKRE+NlvHETK42Yv07tC
dPXPRr9SHELRIxemxnshqp9N9LEs2cg/YHdv1JAAl1gM2UV0YefmgkK+Fgl6
x1SohTofvYWn0u8Ip+Hsq3Td3KMf0pf6k9zpYvQczb2S4UxHfjF3doZBYmaA
u/PdoS6MaVIp2h/FSLRgpjhYvkHqQvd3JpwpLDzutzNf7oRVulRxxBoSZcsu
qdONjyCupLEnTCSoVZLqOV46hK+VB94z2wX4H6sh1JU=
        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4VWkYv5UmlS1LaSxpLKlQ3EtEfjIqlIgYNUnZhkZjC1MU2TISGiUq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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8VW0XxhWhKB5EJEOigRDJkKeLFJJkShkKzUmSypSQVEp5NCGJoqQi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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81YkaxhlHSEooWaYbJbKeT1T2x40wkQ6uZUJFaBVRjSsVkVTkZBtr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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk3s4lAkbxksiqkGUkk9C2pXjJCGfGzluwlc60WdRoUaHpSLbtohKq1BW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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs8lGkbVivKl5CkNknjLIkModZVaUVNu3JK1IatVianCvkUioSk0bbO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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2lcjG0bxnsSKkn2CmkliSg8ljhsRZuiRQsptFjKUnqSKCFtFBItohWV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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lWkfxiNL3k62iF7ijOGN0qSSTNF1tKhESQt520aTmmNrRFT2sUwy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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwV1Hs41AkXB/BBlDe0Lsmbu3obt6R0Qepbcq3elDfEKrZUVi6lpMQmuYVt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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVmk4lWsbRfFp4BNKqhOpUDJmJoscQ5s6UpEoQ9GkSBFyMm2klOFkKlNJ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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4ld3X1iTJmAYJIS8SJUkSbmny9qoQGfJDqag0kFTmpFBEc6lkSsp0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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk41AsXx13Zr9srlxJFi+m6pLeLROirCF1M0aboDRFeLYob7drrSRT3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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVHs41AsadimGctLqlKSLbGV1MSsqYl6lRJTIQZapJkQ6KRERISQNK5XI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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns4lOkfxgejZEttW8vSCjlmlEKylXskZURqWOVUYSu/itJiVQ4lm2M6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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4lX8fRmVHqaSSJElRaalUbitRiVRISKVQVkiZkaRhtZCUjGRUyN4r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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHs41PkXDmVrlVWxUo+emRqX1LaFhGpfWrnEptYUuRQTIgklqY1cfglb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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk3s01IsexXFympw4TB7dSpludWVKTCSSLSTFidAp7/IoqptHpXTcUl5d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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4VekXZn5oRhhUSEQUoSnX4oiXLhIqSYVyGSEVuRQiIkqTSiVEVOjC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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VW8XxQ39hExNqAxFipSIUMqKJEQUSpIpSSqVSoqKVGQopKSEVBJC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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81Ikbx4fU5sgObYUiKrUqUWvJsX1UchQSliVehQ5RxpaEpURZSWIl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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGs81IkaxxVtbZsuuog2t5Tcok4JxW8oi1YUVjZFmEplDjm2JBVdRKlE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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk0lV0bxlFJhTJUUolSIYlCFC5KpAGJSJIozUR9QkKKOqbXFJkqJUMK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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k8VG8bJipRKBVJKEuWQtoUdVEhSotky99SKqVSSKgskSSJolAhZU1C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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs4lIkXnoqibKuLUk2WLrK5lFaS0ot6Go1CiVy2SNOmkksXKclUElZC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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVknk41IkDxqdDbKXUGFpRlH6FQiWxy75ixnbI2pIjlCa1tR3CVo5INinK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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkfPglzMlrQJ0maatCCNmup25pKWc754iPZiowOqWTQYsioCAkp
USLr2DsiyyS7LDnncCzJ8lF5ZGSmSBHf8/3xXu/1Xs/7/Lb7/t33epczLFcR
BoNxhz7/fzdKF86VXOMhNmmVnNJ5ArfGX/vsZ/mo5qavmAok0Hc11t6zOAzc
tjY83UAwOmJsVq9RD2P2hMdFMwJR/ffniheqUJbaYNa/j2C6/mXo9oFm+JzS
4EvYE0R6x9glnWhHWPHD3k1eBNu9xyReLamFgrr2ttPGBHMVLNaUdh1k6huK
cuh9Jx/e0tyVtbAU6dZ2MCJIDrKazPbmQjq/uOK2OoGkuoFI8GA7HFZrL1Nz
Jagaq/m7ic2D9pxcXAytP3hVqLaUbQ36C6JcYml8D5MDgpBrnZg3jfNMfEDj
f9px5Lp1FJZM71eco/2cvDQoSDvYB7fKIw1W0QQ3oxnqSrEl+Ma5oySzjf7P
NbI1za3B15716+poPYN88wHZq0JoV1cWfvclyKxuOepu04uM8uft9tcIipNS
jN4G8sCafbjimTfBu1nTS3lMPuT6d0ouDiKYDYjJCgtoxPTGV1M8S4JPSVqx
n394jROCm8pp9wiMvi1ayXEQYMFb7NdaD4Jz9yrj1Fk8OOXmc2qdCRSYYoWB
63uwduqG74Zsgp9uPb7+wasDtvYXGNqxBDqGkgMlleXwKpAfv6tK690VbtE2
kARbZ4e0gJ8J3MVWHmlUaYO09LIEU5pfaiZLht3dDIbFqohz+yn+qyZkROQE
GGZkrDFwIkhYiNiVcvsllBQsrp5yILgUpNWfsKETV7bNzVjTfNWhO97LBrbA
zzy3dCu9/1lReLSpuw4TBf6MZlM6n9t+7sjKR8E3NQkZFYIVa2c0lCuboPx4
3sPQnKDb785Fi6hiMHJHvbbQeduXdLlqRb1AyGxNq8EeAuP4G5U/DtYiPYRv
3UD5IfnWbsBF2IK7HaVJbWyCCsvV9x1/bcapmw8TB2m+d6yfl+ddqIKvdVyU
lw6BpeYhmVDNR/hhxxrVKdq/uVD9r9MdQiyfDDg6SPkwrjaT7j/xAu3Pjulw
9An0fpb6LaOY5nuQHq1xkKDd52yJ1N43YM8EBt3rJlg2Ff2FXyPETt4iJzOK
j36DWAOv/jaGZJ60DlM+qb/IEC5f0Y2VefksQvE5qefDT/NrhYivo2T8SYJG
06W2Gcmt0Ph9dWPZAcrfrZ+fc51uIa932cnNGwka3gnzem+8xuj1iP2MmwR+
ly5zLSTKEPLdfjVTk4D5Spx5XLkb882uFdPFBHFL34irhEdC7siAyxjNb7wm
QGrYsxGvK5VrztJ5qJaN7NUTq4a47vXDz0DQEeii5/qlGzMfm/wfldJ4eob7
4oc7kJzyJmUwkiDsxvmXO6xfg6OfNmVQSPGJvvvB3K8aeoVp7ib0/uQaicvh
EVycOxaXbLGZwLuJmTvzgQvvRfmL76sRCIP6N+462QqXOX2XImsCxe+y+xT0
y+AR6XArifLx8i3ppiujQmyYcTRm0/kV2X4ZVWc342v8NTEW5ZuluKOjilUB
DpgNCFK3Ur3Y0mHscigXXD3l0meUP3puk6qpe7qgGPlD8BJ/gpZ+BjfQWwAb
vaTwmFNUL6TsOlesy8JFNOxV2ETnH8CM/lurBpIfW1vWUz45nVfbNqrHRU5m
ikwgrdeLe3Z8qlQAjY12h1qCCTgHtj/P1X2NgBPDjybqCByuSHHyQwQY5YVP
qND4kvdKJf5p7sL842ZmVg6dj03Kj8tSahEZbbJlyoTGF83/t8Hd5zCXDzhs
sJ2g76+fxj8Z85B+VqjDofpUdb/ofnJ+CkL/k10bpETPrXeekPylCiotL8R2
6NJ+G42Kvcxq0fM+3KuD4qcQMy2a2diFKJuPS59eJLi+wq1lep6HxD3CE79c
JmAsPb1HJN4FjAX18SUU/3HdxQl36/iYYpsEN/9GoHw//J/IeT7cxnaXL1B9
khzJaza3EML0yHIT/0sEv+VGPIkRr0XF0MBjAc3vaZtUkLi2B8ezS+xUK2i8
Rk+pNyqNqHOyHrlD+ao+KF8anNqAue8KOWMWBNxrP6ZeieTBTFg+V07redB+
4oZkdhf2x486+9L4M7qyUhH2rXjsOqzHO0pQKjd8qHfiD6zdemlJAOWP4ovN
vqnyRSj6LOFsRb8r7u88rjMqgJbNbo3FtP4RL9u+isMCCGYTNAcoPlX8g1LH
p0oxOv40pJXyQyvxyUu+GA+P/jHJa71A/alToiZ0STt0Uro/bmER9JpzLGdN
O+Be15d3x472X3RHtKmlB72y5m36TyneJj2NdvFdsDxW1cXMIGCHBJ7SecvH
5OXBJ3JUv1lyp1k3Wjsg+uis5bHfKd+3xZaNXM1BjLyn7DFlAv+BZ03upu3Y
+1fJ0zqqZ8w/WZq9ZkXY9Dmx/yqt766+n9a3KyX4I7Uj3od+tx8hWsVb4tGV
/vqwgO578q4qPseICw3Hya8PKB8H6zSdJXPjUDQ/wDai54bigaplCj0Q3a20
+00M5ctC+TNpj1qwTvl8zDWk/Hh/RmqjZA06ukVOX9SmeiFit/xxBA8982NP
5qjftk0ws9K1W8B0f6lrQ/FqNzlobm/didiFyxw29a8Z+YR631U1CF4Xs3WG
+lvvcMAr6SA+tiXGFNyk/r2vLMF/zLAaD9M37+jYSyARNftJ/KEQZSH/LfSg
fqkcN/NIWfEVctIkVJrofihiHTtSohNjQ0PlQ2G0H3tZq9zbZfj66Ttjjvo3
UyF46IV/NRLmYqXZNJ9uf+Y9rncn7DWNMq0oP4eIuMioEg9eNhHO7nS/7c+9
yeZSPN2Gbd87exJs+joS2uTVgoDFBgGbqf+/Y0baW7W3wGejJSeb6o34S+vV
nz3rUW038naM+kXB/tgcra4quPy96ZAhrV++5syk1Ldu2DwPc/P3I/DVcFyo
tOhC9NrDm0aS6T5X6VuqyRagT+1mvc4Wqqcc3mq90AaEiapPL6J+U6Cy+Uuf
6iscyOSXF1I+DcoV+5j6J4L/UT3rOsWLs92upvJgJv5l/GfGUqo//wPnKLLY

        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k8lF0bRokkqShRshWJkiSVukRFUlFIyla2hCiVlle9JSEkSkIhFJEk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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk81AsbxSfpNg1Z2nBzQyIVbguRqw6l9NqT0kaI7KUoWbIloWQtJPEa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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk41IsbxadJSkm3umoKlSWUQkyS7ai08dMvkitNEY1Ubk0RKtojlKJI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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk41dkbF9K+SItKC5WSmpBihM+NwlTKNrdmlG0IKVsqJbljSzFCkT20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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk4VO8bxodWssbXVlFSISGijW5JWsgaUkIqbUjKkqJFSZZSKERJlkSF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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41AkXx1WMV5tK2VKvUnKN1aa2Nhvfrrq723LZIZbRbaZVbxfJPaxU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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs8E4oflUoU5dJj0WPWLZHH6solcopeQl7p9SMlal4pxfUrXEq1kIgo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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk81Osb9UN1tQhtEmFKya5boujIlpRyu+6QpboVTbbkyloUhSK5LVQ3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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8le0fFhUNvRqKBqKBKDulXHaKEqmUhFRGiUSlIikrDfVSRGUlQq8V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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs8lPsaxdFF7ZKUozkqhWxCQnE6RUu6iFxio9xSSOXa2VIRNlOJwtkp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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs0lIsaxl1qbwcVcpncolBpuspBF88kqVQukyglLSEkwijbnsql2ns7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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs41OkbxrsqohxSWqcNiVLOh0qUWzmn4jdFzVZio8YhOUTKYZUcc4hO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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VWsbxpFEyhCp0ECSqKSkCbdwShMSkpBENJLUJ2VMUinCIbMM0WCI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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlGk81Isax6eoELccEk4LISpTkqak7k91ZKsUipshha6Q6lTniNRwqsNk
iYiiThwkhGwVKmUpWWY0lpmxtFj/y1AqS8W5//vi+TwvnhfP9v39dA8fd/SZ
yWKxgpj4f25Nic61cqyFq0uDekkDCdZBj4nFe8phGUqt4WuQ+FhdwLHSfIGh
UH1r3mUSGQJud/lSEVzkdR0XCig4Gt6LVa5ohrGB4uf3Byhww4dGzow0I7vp
dI3dUQp7DCTnpr7lIka7NU41h8CwQsaP3zfWY/RFkWGUEgWbl45DVtxa5OtY
GxZ2kIiqKGw/GCyGd5Z5bEs3BeFV+/igv19i9OLkrC8DJOaJrtiEXn+Ep8us
rL+rkWidtP3ww0sISxMFnkY5BacxObuxeClc7gi2qVjSOBxV93SrpAVS97Yt
RtlM/eE5alVYFbTm1rxT3EBCWTldMzVKCDkD1bshFRTsf/RGS9jtkDfxuZ0+
m4Z08I8tweoi6J914FQFUchw0DzD0+qEm88ZfQcXGXOXEJPeC7lwCyDzVqUT
OH9s8q+Kh004c2Uw4o49hXfxbHrydRmyNvmEDn4nwPfYWb/Lpwuv/WNaAk/K
UDj8ImOBKANi3kRceByB8GazsVq/dqjoL9UpKqFRItZbRofXg2PhujdgLoVy
2cJFYR/aYDCj2TTLiIaCjdIidVYDDvTg7dJSEnyt8cYRqQgeSUO3GmTMf4IH
I2dmNOLwitzwrXoUcvolGy+dFiExr7Gs7wMF4+HRNxHhIrxJmil3ZymNwrJ0
9t8Wd/HlrZtWUgIBKvBsqleNBK3zJ5LTZ8qQLvS+0ZnSBtcxl0pai+m//rz0
vlst0hR4mXkPGD7sk3W4cg0QiE6LjneT0I86EDYqeAi1PIv7/I8EShZExhsT
DVBSq/lk+YHE0Z8U++v3SUEf+NN49TgFnaWq9pcVpNjTqe/w8CWNL4HZIV6j
Itiqv3fDJQpDmv/m3NZ4DrZ99qHJQBLJxcXyKdFiDGroz/lsx8yvmrbkhW4R
PHXNt7cLCZh+vaizTSiF182hN7tmy2C84EQfd4UQwwMzxAk+FAor+u6u6s5E
Re/h2FBmX8HaxbuDn1QjpvGvN9cySNQHE2q1Ra8wK4Af/lVM4oS0J+uQbRuG
Yx2HficpsPKcyz6qJYGfSDh6cgnwiiZftdQ+gJmKg9O+HgJc0683+GbVWLiD
syHyHglt64BZq526Mdz4rdjHTQZLtY2U2WAiMoLm6G3yJMAx4u9MXi7Cf09E
jpTMYfib6PUX9nXAMi5Eu82TxoVFI5uVNQthtEjZOrqYQPD7wb3l+mJs2sLp
aDGhUTxwf0UY8QA7f33obd1EYM7403y1n0XINK9ZEsbw+DUs4l+9Vzqxxny6
t8CJhrwnOu3aH2PO9VknXVaSuJ07EFz1jwDT0q6eX7woHHQc226ZIsK83zZ9
c6umEORr+CZuczO+HXVRf+VHwXW86blmnBCZQxtunbxI4Yv298qbp15iOmH5
z2UMD10Bvv2flkjgLpWZUT40ChTd3c/vfQ3WBSWBwICCUi+hNlzYgzq7HKWt
FA3WS/u6o5w6zHVu/TBdRqLA9rNfaF8lli32frRFm8T8c5eWjzuUYZ2qkB9N
EligYRWWuFOMnO3yv1o40HCVd4o4aNgFYWnHSZV6GvsXD7ALEiWYXtyer3yW
hulBXjHHWYzfAiMFjhU0opp9tRV/acLw5n27nNMohJ3s7BlV6QBHWU2Q4k/D
b23lRqlrCxo3zVBMrqVgbtvmJhckRflbX4/OSBpHEr1OeV59jPDy9OCFXwjQ
pnWNQT4SjI6fak7/TsMo5k6TmZsIK98GRa03oHGxYtpiPaOXwMrJWZ4yEql9
32YT/rWwm5+i+oLxX5ngtbP+jS6km5SU8hleW3fnH7HpYvyNx/5PmicF+Qe+
HnqZTxFxtqTuOeNfxqM8lcn9Quy/NDfS/ziF2R268y4otUDAG7uayej7dZ+r
v8sKCfbzom6zg2nkFFvIZhY9R1rmSOkBVxJ9DmOJPtwOjN2qs+s9Q4Nc92hl
9eM2LOjZfKx6GQ1e5T/Jfc4hqIvZUXd1HQHtfZXe1c86kM0698eAF4213Yfk
bINaofTEOMW3ioLRNY2sm6FiRE9b6Vhdo5FlOXn4RI4QuiHvzpsyPLVWxX6P
39qBsqnq+0fcaSzP7i98kt0FPTPJMW2Gb8uA9P1+HqlYs5VzduwYgajd210E
7aWwmXv98vNPBISGGbZZDE/q7pJ2jdU07ijNMx25KMET20OuxmIaqf2Bqe3c
GszbdWGJVjaJPfXROcVTCThmlZIb4UzAJC7/R2lLLZb07zJzryVhHjs1kKRc
h4k1bKepfMavznFvKUw1w8T/SQx9nUKzxK6+c1EnwvNOFAy8p8Fn6RxqCe1E
7Ptht52BNHYb1gSzOGIk3GA/uz1JQXV5Epu9rRXX9uq5ej9j7p8YajH6rgDs
CU5uRgOB1h33UtLKqpCawD2q7kfif6zy2Qs=
        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk3k4lAsDxdEoSllyFUpEKG6FipAzla8USUil5eJqX1B8luZmrSRNpZDI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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8lekbxjUpzaQyLSMV2Tpji4YK/eiylD1JTKUY4hzioJR1smQZQiWN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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lV0bxVUiepuFzBolIXpJYqUkGUJkKJk6JJlDIlEiSiWVJKV6S8gc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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41XkUxlHhDkZC2uyRGjJFi8zMe6dkUCmFRpmSNDVSYWxFlqIpkuzL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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs4lAkbxoeNUA5rKRWRjZLQ4ROVulFJJbssMbFCFIXUqgaVpfnSptXo
IKUl5Cs6iUJJTcgpxgxmxqCawzsz73RyPuS4vj+e676eP+/r+v2eZ0nwEc9Q
ZQqFQpuZ/2f5rRj6Cs9m/BN5nKqnIwOFHLa02ZIFLbsC19OlJOy1qy84r7qN
82aiDwcbSdBDfzK+TC2DldKdQUGLHOb/rRjz83wM27g1Z2P2kiD3hLUmxnZC
PYXyg9F1IbSGk2wuGbDBpi1OK1kkg4nKndHvUib8FLl9X8zl2NbhJKkQceCQ
e9FNuZfAHQHdUOLNgyojvPawoRiUZRpRPq5NeDjn69S0vhS1kgvS3dZ1mNTn
Wb8dlKLczDzWybANhxh5p7bQJViu7JG8PPMFDu/6vH5+jRwhgcKrasosTGQd
0RNOSTHa9FKrPrwepnmGV0rzZSjyST2g95yFBsdKZmw1AYpml4bqggo89LKj
fnwlh/DOg/t/jaTjc7ZTk1IXiQ/uX2Mmu1vxzTlw9HUxAeJgd9vszGKY66n3
UVeRqDUrXmK/gANNSIKzSqQwvPFY49l1HgK2qld0lIqwyvL3dWanq7BmO8V5
pEGGkDy9rJhRNiRhDmEBpgQuH5uSbtrYjomq3d/SxwlcmPbze+3RgKF274iE
CRnKnx58HFlSiQOKRSOsOjkafbfPkXi3wf9tjaHLNIEDF7LO6wi5KJxlaNKf
SkBtSWDRoYR6DPs/nLAbl8H/KXegW9GIrhqJFs1Whttd3euf4w1e6O/eUD0g
Q7fB1p55g3X4j1d8yUSFDGrFqfX1mTzY+NydunWPgOPAu6T43kvYuSvqE2OY
BFP3fE6lRTqCc0+E5shI9O4YmxtoUAjz58z8jREkOsausn85V4Mg5anUsWMy
0H5RrliwsAot3W5BF1TlyDi3/+ysT12wm/78eHSZBMdztfj6KgLcvPilQ+kk
gW8hrHVnFrbhjxbKvG0XCXhFpd10//wWtMRZVnrz5GAaPFpZ2f8Iogz76IxY
ErxRR4ukuPdIfH80bZMOgZjvXqLO7GLUJBZx6UtJ+Kaenkz48BqRpsdDHrjK
ca9ty7O3i8vh9uBrQKZUjs6l8f6snwToN+KXeRwTwantejbp0gH95qTz3RIJ
GNbfVWlljXjziNp3xVOKDLMWcvwNB2oHzK7F+ElB+qeeopq3IGHxBPPwHBnY
Efk+gSbVqC1RPBtulaE3aClV3bAaEsup9ssMGRzfOuQzK5LhmzOx7H8UBaTO
ojC6jAvtnmeN8QUS+Iaq4+buZrTvurYtbIYH97aeobUttbCnRFjW/yhDWFQM
mIF1SDL4OlKYLcOcx59q18s7cLIm3ZIWJ4KWZYnKtfxuOKZIZ20OEKM3QX11
Sl8pVHOclKKUSJTG5U8uLetC9Hyfbob8I3Zuep/rYMXBeu83yf3PCew7z7X9
53o7DI1y0vwrxfBgrmJwDvBx9D7/sjhSDBrtRYdbYzE2Z9EP0dVI/K7PsLBN
ZOHuwr7F7pkEfF1n264mebC/n9CiqBXhXHTShhRvPl4yHYTpOSI8dW1L4GU3
ozae/9sGfyn0jAoX7adx8FL7Nbd4IYFfzdcWRqyrRsc755OHwmWYG/KKoTCp
QeEGi2ENTTn+TFtbrX+pGLS/jP1955No/FXrCfsiF+seDSzPfyLGjuNqhQVO
AqjYrKtScSFwK+Vd5IptRQjuOcUaD5zhNc/l1U37CvB+5I7q7JMjdw8zOrep
DV2ml3w6AyQgx+lm3oMNcOWmVdZHSnG7PmNy4Ew77J4JMoybxODnTZrWGwkw
Mo9qR9hIQO+pDt2Z3IpwF1ZdMINAmEGAIGK6EbdKqqi5M7zQy5T8A4s6QbuX
zIlIEaIKV5w1dnbM+MD7+4mrCArTlqaG5Pc4czKDv1VbAt6JQM2Prt2w9q7J
tPYRgly1b03hrkropp1O0naUg7S6NDGQ+Aaa4wX2jJm9dfOusqA17UhljDqu
nhDDovkGs9eNA+t9liWOxlKIUwtVjAV8fDicohbtJ8HI0a2W7hwujD282A+W
isEs1bl8b8lZUCLKhG5qCjCbPH9+ofsSu5UdOfMVcvQ4PAlyshXAuTdTyD0r
hlpal9XdHDZkzSc4LwqkWHmLnqM7zcOCd+5HcqdFqKexFFc2FiNKe63/dDAJ
HSslm+HwSqh6mPi45skRPWTnGz/2GrE/V8TE6MgRVtxf61Ldhi1HH3q1Jkjg
olE3lPoHC+556+cWuEjROzioPH8JG/dC7l//eIjAn1pFs/OnTkBjaqRTTVeB
HUNbJ0vZnbjqUGn/9LYIentuho+94yIgz9JTL3nmn4Tu/Tg8wIGuTMSuT5Si
7BU1hrZdgI7ca3EXywns9Zn0VOGxwdXfvLNhJQG9r+WM9L+f49GaPUO1M/c2
Wp21/zdWJ5z8v1hkPxBiRUFQ7LARH+3HNloW7CVm+hmNntTswhm/5H0q5kI4
xH3eqJjVjjsHx34weipGP0G7YUjlz/jXaHi/T4x/AYZZ2VM=
        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lWkbx3SaGhK+aWMShiFKhOx+JylLRUIbIksSERmylYyRjCxZkizh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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Vd8bxUkhNEmSOUqDTNGgYqmkUgqJokGaEElCUhooiqRIKgqljBmS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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs81AkXxkcpUqrVLiqJraSSpstKUY/cck2kTG5re92ryXbZlGjeQptb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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs41IkanpRdtthELovCkYawLrESXglNJ2TTzSWFVCpHikw3nGqxajNs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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4lOkbFhZJUUraaomyKjqQbX7IvYYcskVWOkg5TSPllJHEqrWFXQkp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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VO/fRpKKsmRX+VaEJO0qdUsI9StbkUraCC3KmogipE1CkspWSUhE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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs41PkXx2dRTNnCtlJNRSZFSy2Sbt4uu2nHNauo3Y3YqAhFpYnSZRFp
JWk9S8l1Y6OmRpKxLmOMyWga1yFS/Mp8vl9+q1RTlN/8/jjP+ec8zznn9T7v
55gERfrs1WAwGLHq+H92vP1mvabJJRTIoxwWeyjBFvlciBsSIp1hvn/jfwka
lhe/ag7uQWjM/OQqHRpG2xyYL8fFuLBidD9nJQXbu5VvWVdasacq8eTQCwJH
On9FcEIRnAM8tI+nKDEsrgrpdpXA2jLjZowjhcACQ+fAM9UoHLCr/WRPsNdE
+0HEqW6sGrjUNR5HI/2w4HJvtwIRQtUW9oxRsPxT/tRgimBxoDw+VUIws/5q
w60sIQI/fNBJyCIIjJorfRUhhkw6X8fqLcFCbt+Vo4tlyBp5tW2aT+Ee8/w/
ipdytDhf73efQYPNTcjd6duJDWe3Z7gQClvufuf2fL0IwstkjPuaYCxaPEum
kEFxN0fKF1LQLZd2Hw1uwWHfjYsH51EIXz3b+tvlUmg94Fq9GCCYk5P/6TS3
BUMBrEd9Myg8tcrvC9ZtwZ3DAneHLyiwNF63eSyrwwaL3VeMowm019TLpetk
OM0P6tYPpUBcXbOvXVJg1e2oGRpMGoX/WQfRm04E7l/4YlREwU7Jv7ovtRcq
78Yq6I2idclAXcqZJgwm7yjjPCdIP94xf/fdCgSVjX+5v0YJXtGmfQzTJswc
0l01mUQQblNeuSW0Cp9F/BI9U3X9jqUfPuv3o3SL0eelTTQSrtY/suU2QotS
ubkWE+wLsN+kMSLAgZzfXu5YTaC5b7pT92IDxjgxf1txCYzXNL714MkwucnW
SK7m65+x9k2NRjOWXV01QXUQ3Jb+yAvxqESNBeNQ5Fx1/z/an/nVduKPyx96
iotoxDgOORWFNaHc7bTfRDwBT9+/+lNLJSyiJg6oviSwjyj4IYPRg7Ys00k7
GxrD3HM9ssB2JPLXpB3KohBne+bzMLMLj4IaBg3saSjLF48UMNswYeBzqded
ws8MZm6OZj0WrYwwyDtO4MkSn3de142T1pPsy4k0Mr11dONKEjH2lTnFdlTC
ycTT0P99N6K3js6y1KRhceIDdb2pFzNvlQ2f8qIht7Htmq2+l4YLtbtaQWNj
Ui7/SfYTeM47z3uTRmHYfkJrIFmKiGddxxZ4UpilK/i7oKIFNecaPE2YFEbW
T2duTmqG54ah4EK1P6asb+66VSFEe0evo2iMgEzBSXFejq1K6orpgNofC0YE
07I2PP6G1qWtKCQ80LRblpEI/cC+d3ughNglJpP3uATF37u4lvypxLhXrWRR
YCOuDrNd4ksJUs6L0ruSe9H8w2BIoXp+3epSi6EACXyEC31Zaj7+glOyX7Ly
kH3f+uKmE0r0DAqUIeYChNzgZ3J+IdgqKVsuz26FvTJskhdJoZPd/XtOoBxj
lhNLU0MosEnRlNYoD+RdW82jeiW2Ws1iVyxqQMN0vNQ6liD/3QFeUawCI8an
SwO209CJ+to2WdAOm5UvnJR6NO5NFxQLJ1vgvsNwkUEApeYRz4iIeoRnE5vM
LLUozDPV014TUw/esSduHrkEtsPrSpn36yF34lg6+BBkJ2k63R5+iF7hURfJ
ZgLGUWVdy71ojL1JmmKsVuLfm+a3nDu6EJta0abooBFefOSI64AAe2YXmj/Q
Jrhmk3pMta0TKtGKsWiu+r5UV+LW3++HXWm6od5zGo8DzcLWlbTB2ra25noG
BTPWnIUhI624uNpricZngrrQyJGYfztAJHac2TNpsN4KP25USJG4J7q8yYyC
rwfvOy8/GSp/Ws78p40CXXvTeIlXCzY6PLsQ0EPgPL1iuYa4C7I7JU85bLU+
lea2DjoC+Hwy2RZhSFA9FX7vrzk1yOMcufi1F0HsqWtFUlElti6p7pitpd43
sfHT92nRWGBYX7XbSok76dzbjJMK1GROWEbspTFoI3xdtCUTa90DXnr7KhGi
vdbF0aYXE+2hWamTNH7L0+v3MnyKl6ptrqx2GnnWv+7s67qG6z/u83Y4pETe
DLnlzJpGiG8tCuVnEHil9z3oTBMiKLxvARER6Luzm8M2tEJVO9Djf4CCwY22
1I9PJKCz5YriVwQuGrHBYPbCLM2tKk7N92iJq18p1QN2cGbK75E0RoanNkvC
HiLBqUT0ekqJ48fstM5qyjFyTq8tN51Cel1XntOLDhgZ0EmGQTQMRn/Ke/+8
A3VWv/Y7+NHwfW87/TFACuPCn5P97CkkV6U6c6wfwvM06+C4PoF3nVuoZFc+
OLILD9NOKbHa/qCZSVofnCeiTdq9aYifvpWcXdUAvquukWMOQUJzVyQTcoh3
hVVsv0dBa+UcKl4sQaHx3hvh6n/1/huOoRm3Czn7VddVar39y1h6cx/ykXzw
hKnzayV0+st14jZ3wnHvt665ar81RN3dSfIV0NIqK2+fotGbYgLZqAxWh95f
MhBQqH48MP7XmT7wd5r2rzQaxf8AbYLStg==
        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs81IkCxUds2ViUNpI89hZutaimIptDWZXKnWgZWy037aYtjEdIm5mk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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4VGsfnRyq0+krobuECKnhjC+F0XJLoY8IdTq5Ri5JNxkPnShJykgo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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8lW8fRopKw2qRiCRUkt0vV9kqslPRUkIltJSMRCiUqChSSCVkJ9nZ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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHlYjAsbxjuVSaLttAzpVEcn2boqUoi7j4RUHyk6akJpQbbSCEmEnCQt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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs01IsWxz2KSel5CqUHpURRZKiFb4eKRNEDRSUSyZWj8igV8hhSDUqa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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8lWkbx6VdKHrfY0mEwigpg4xMv6wptFpOyFjClD29RZIWVGSpkJQy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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k4VV0bRlRIyRSSkAplSPKmvN3eoiikgZSiJIQMRWkgJRSSVERIkiEK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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk41AsXx2mxVJaoCJkoS6QIheSromXKcmWpxlZpuwm3FLrKtChKCEld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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGs81IkXxodYJfmXrcmnVnchKtHGip7uF93IbjvRtlSWioxSCWFLmwrR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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lF0bl0+JEr1ljUIL7VlD+DFRkihpVYMhpGRJpYhqCKGFiJKGKLJU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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lWsXxklpQKJEKlNCKdEgleOWpE6kQuUUkkxlzphwCpUm1FcUilQq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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs41IsWRe84InJ9OZKMzlHq0AMJawhFNV+m0txC3UFCV1IpetBJKk1R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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk01IsbxmlPC6nINkVS2n5uVNYedJM1TNxKLspFF9kuJVtDCNEvLj9q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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkbl1KWNG0iGbJNcoSUFuGHKQxaSFqQvSRrmRJaNcRUKpyoM4Yj
5UjKVvYsOTmKQ2dhclCkPGNJozTJ5/qe+eO9zvVe53nv+7l/263pG+YSIC0l
JcWkz3+/VqmrTofta4D8Oc+gvTYE/yaktE1oNOLMkJrGbCuC6lMPUpm7BGB5
/znADSQ4o2uoWFFWh0vB7wpPbCQw0W7nx/c+x4WneZsKdhAcKWti9su/REPl
6r5xX4JrjS/8mIxnWMJkHlhuR3B518y7fv+neGJlw1lsRtBwca184MFONMkt
+vMQm6D3/imzjxkdmDOQsKZrO4HdSPqn3ZJXkDCbNN0iCbaylx64d6oTPwzb
LrxwniD/08sY12ge+grC0487EQjVUgvb7wmh0peaonqCwErLkTgzkhCadnXO
Iy2CuUGDnOYznfCP71ANyidwnXl+/UVhPdijcvFO9D5ZIXY7i488R1FbiL7f
LoJch9z4yVsNeMQfipTZTOuPvn84ld2B8LGvme6htL+ra8DM7XakTgQXKbkR
5D0we8KqfYXs0Kg1UxcI0nNGPz5K7oHcsZNjE+0E9tLx10PdeNh5OmdtHJ1v
uvxaqNcLIQJva/9kf4TgsyjvyZpoLga4/N71FgQr/GZMBewOHDKQbz9D51n2
NX+XSms9bJ1lxg6YEISPbtYavfYcy3jn/3q7m9Znt+7dX12Oqtlv0h8zKN4l
mX/NNqnD3McW7krGBHeqEiyPMtqhFmv1+w7Kpzzzpov/1V4Uz1verN1D0MVh
WPecqcFg/DPJCXp+qMBieUhVK1iLgia4lM93npYX65qaYLFt3vzTDgQb/Azn
2BW34sZ+vabXlP9bmi15m5Nfo0VpqOtoJcG5Lx/So46LIP/l8OvydIIo4ySZ
F2vbUaiawTkXQbDwMK/+s1kF6tW8+nLWEZTK9GsMDpfA6HPC09bVBCsNNSb7
vTtx7OlLv925FM8PZtXJTo2w0hHu/2ETwaX/pXJ78zLx7DNRPqVDoK8SE2Uc
IsbiIF+nfk+Ci4fvKB2LFOEu51BM6RUC4x13c2JXNcPyu0tEmTWBnpaEl91R
jnfy9lY9BgT7dike/jYsgnaqeWJgJkHdxxhbXVYmFBosNW1o/Vgp2w2LfLvx
ZuDvqouNBPMHH3xxTuoC2+NlZjLl59p5V4UrOyuw9QQ/1HQNnT/UY/yXdhEm
D559EnCZ9j+fqPK0pwCfzJmuHnoEBYfPKHt68sGWjLUGHyawEbsYNBl1I19o
Z8bKI5Cqk/7jFt8anJPtXtOaBMm+FyQGb4WwJFlX/ZMIzL19Yjm7e+F024Tn
ziEolGtsGuV24NfEwfLRgwSszWFX8+Rf43/Lxu4UlREkNdoemO/SgdcHaqOd
qF7erLNmJ08+ALPLI//7KoJAI0F1hGwFLmYOKfkYEpQHeA8lLW9FbYSFdooX
gcfw2NK98S0oDi9RHqH4efdzGRzePYxLx+jP0O8zV/j0f7vcjks/tyVqB1P8
eDeNwle2IsUxre0B1cceblylu003rO65Mk4kUD398vXor6wi3KlwCluvT8/b
W6mvdWbBYPXF9Wso3iqNW+QyVLrQprClIonyb+ymwuPEXofDyaV+DG3qbx0d
G4G6EOzab7O23CDgZimNoL4YyfvZxvW0nnSJ05cSg07ckvDkFmbQ87kGje2N
hVi63UO+7Sfqh+bCC/dl+ShUuuE3ayf1z0aLx6sGcrAhepsgnPa/JozqnBKJ
sL06MNQ7m/o1wedu9fBD3JCocR3pvFuLWkfSZZow2Hm3JNKeft9nwF9/sgfK
13/ILhMS/PFPn6mvoRADQnG0nA/VL3ptHjPE+CzbMF5O88Nq2+Tb/tJmrI86
J+23h/4fr6vjpvoc6305x5ssCdRWKvNnrldCf2VTTTHVk7HjJy2ZbQVYKkoR
7aT6UfPIOlvp0Aj7H/WCJ2l+1xntPmix4zf8+75UKoDmXcE1b3mz1BJsCNng
IaF4VKbZmTUxKqEet4ATQPWuH2s+S5BG88fGNm0v9Ufe3fnlSRXPoJkTeT2Z
ztOwPa0+v04Edp2Tqw6T5uP0pe+Rt9pxWWbc8YoL1Y/GzrOqByogI3hrXE/v
J7W3+ZWrXTDETMeqxbR/1pNF3BubcsAw1zuWokvwd0Sqc3h4C1QVc9fFUT1w
TP8dYEuJ8TdP4evpaIJIr54nZ8U8cF0d1obQ+ntu1hu18Rvh2rY69RLdH5oD
Vm9EvmJkK9wJ5lD8nO5Eb3IxbobejXXbdV0JwtaJEsynG8D8bXPwAMVDLWIv
8RqVgDUUtuxEG8EmrRjD3ntibN7i/mYyjcAgMbT+669CdHYImDUnKb6aZaF/
epZDPUPGu4jmp3e1GW/lkiLENysuOErxfnZ6wl5rUAxZs0tJc+k+6uoeHJh1
qwY2E1lzDel+OPciUFfai4vFAsslaZQ/d/3v3cd3PIPsqTxbQvdlvPUK34iz
YszfVKflH0sgEY6lf74vxs1s6dm+d2ne7RmOzOc/gFncvpkPNP+C5/746MLv
HYgsnjJ4SvspT2cH5u/rgu6C0rJ9Vwk27pNXLgutRPiyoN/vU79KfZpVVuVz
E6XV9bqrqD96NRQLRkbrEFP9Y5y6OcGHzpfcluPdUDnyUfIqkWBk2Hrq2Kti
CMprrxykerDW1390taIVslopwZNUj1JT5d9N2SykV8m2O1M/tEybHA0y7UJk
pFKKOvXTyjCRGn/eS/zjbuPoQPNhftX230YKaxCqstvHk95noYAz4K6YCwXT
OcIsnf/y/GP5xs4/EO82/v7of++HPoXsYtXAyWlRarAp5SMgc4j5swCrVoxZ
vKf5ofdXUIP6KAchpbfZ1RT/cwqLPhYqV8MtNWfeOOVn+t0sAS9XghUR572O
0/0y8qUoZ9isDRJF1aoJf6q3+Ay7t1qvcWxJUL8kjmB8udVPGgk8MDW2nPpO
96/9NyOTKYca7FBbaKJL+TNuk/PreNiNBWsz/GrFdD/WP+xboS8Av3tUKZHm
e3NNlNy2zAbUDhsw3v9M0Ld1jon7ZCekB6acdXMIfFhJYfP8W7DYqYTB2k/w
f+1Brj8=
        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8Ve3bxYUylKJEUgmFMmQmyRJ6CAmlRD9KSD1SaaCBVCqVilJ5DJEy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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk4lQkbxmVyQlSETCvZypKTkBrm1udURk0RmZMm0eKiRCpKoywposUS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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs81Ikaxq1UyLWL3C/pYksUIkWPg53KQSJCSoVQqaXkdnJUkkUR2ViF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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4VesX1mnSNTRJGS5RIVFKmYoXDdwMSeM1dFFcojL166TTYChKIjdE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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4Vd3blpCIN0IRojLUmwwpMt0SQprUW5Ikc0UkpVDmIRRJpVLJlAyV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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs41AkXx6WU3dXFbdOFZN1CRVH0pi9yySUZl+zIrutGkxSVdHlb2ZIi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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk4FAobxUf3apS9Ltmu4kabNHWlK3RMJSIlVCpREiVEEfr4yL6FQmgh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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lWkbNynZkkrqkyRtMxHSoQg/pdOiVIzIUnQUKWMryyBbaoyS0xQT
ZckcRZH9RCEOZ5yObIfjWLJ8pfSUbT5lJE3fM3+813u91/Xc93Mvv+VdzfK1
PTVHSkoqmT7/vuMfzVyIbXuG7E+z91wMCCw8bVWe7eViN9N3SEOPYIjXu6op
lo/GI7bJD5gEJfIbq7jmIrjXJyrwnej5g2OF5TH+YM4fUtDQIlg+J0zJYpMQ
lyW7ttntIKjZ6xNouqQRo8vO7tviSsDn5OV/uNWDl9qV8ZyLBINX+444Tl1H
6hHevS80Xjd120K7za1In/kxbL09QZT35T8mckvwNn5R9tgmet7kzkplxya8
zNrzLPQgwZlD6mVDxq1o8x1cIjxKMDsbx7b7vhacIFnbgO0EyxjeDbk1PCga
5WyJNiGY2ywfsrzoT1hlaL2tpfGWrIKx/UIJxj61+EYGExxfsKxbvKUDMt95
mdWfJ9jY6x7dYNCEi94HxxVpvwLD/hp9GRF+rDLp5PkRMPRtpAWGzegXpZmO
uRMoXTrdO7qxE4UXDdxmUwh0ZJ146nkvEJx62i3biqB54Y1VBZaNYP1toRe9
nyAzLFx6SVAJuI/PLNH+gc5L3kO1yqkE/sqmD0G/tdS75Bn6zdDx8uqb+ZFA
zcw3L8S9FYss6xdecyM4GvZztZ99B+pTwi2rWAS2C/LUPU9VQDbB7OYcus/W
h+/3yQXyoTfy7pgxvd9iSVWW2qViyPvWKYTRea4v1j5X39eOrbXM8EUJBJrR
z6dlvs+Bh+vNmcb1NJ/gxEe5/C4Upx/39yolUHG49F2wuhDlmw85PdlNINW1
eLv5wEt8Nb6yadELAofUR+aTx3twbYxhmZhPwNYIWjayrR6RPzUm/7qLYHpq
OGlzwlOc7M6QyTQkkMw0E7WRdrw92+gscaH4uXkmpfNpIeRXOpr2bqT12K/K
iCy8h59dWTG31hJssNGx3rlSgsu+oUNaZwhCQwfulDdwYXj/S9V1ileLVcFF
v7g2YW6jfbSzM62vbG3Iqz/TYd9w1UFC47cF/bTKyqQI9SpRK/bq0PlYd212
1gjHAbWsnUyKP6tUr5mpI71Q9P5WOU37qWZZjw/OkWB9/6wRM4vmV71a5TgV
Al77O0t9ep6zYdzxoOUT9Lje4SzSJ+DpVbLs66ug2SY4D12KR0UNvtdpIVh/
pKS1Uvx0yh9jTzh0gOs5v2prFN3fxTjugb0F+GhW5nF7A8FE9+dzEWef4yax
vlVrSfAxKJZBEuqgH7jAyNOIINzr0kxkhwSqM2lGV8oIXOKc29d+7MWr5Xq+
Hq0E1tOOMRqpTeiqCqlMpHzg3Ltfoa7VhHVd9yU8Oo8K9YwbTzu7MDFQyU25
SVC8fc6kZ4oYd3dmKSz1Jrj6OuQaz5UH04JuVizl77Ytr5qVtZrh08Be/NqH
QD+51NdTXIPLGZGCV7SeTEbiP6ul02DfvGa/E51vkqRjuDG/ABM2LnGy3xPI
Rhw3eFTLx/2v4qKLBwgMij5X2W54geK+fzKfnqB8kMsd8XfuxM5Ah8nGJAIP
Ta0RztU+aE2n9JeNExy2T3rwYcMdvOWbM//dv6lwy+0nFxogW+A2v5XiL87+
RsoK3R5Y7Dm+QlZA0MJ9fsrFSAzTYQfOg9+pPnyRi3nzqR8qJCeyLJ3i5awZ
f7ykEwEuCzSFtN/Tc/+aqgkVQneBigaD1hdySbvot8QmtEQ+nBdL+TUd3Kxv
FdkCD4/0iP9Sfr8eiE6xaOyDTevS2p9uEMzPSevyXcfHRuWw6xIzgrVYyN/9
RweSUycqPl2nfG4yzJlU52CdU9aZ4XUE7lNp1yrErTDpP3TsLc2fLzfrJ9dV
jeqPVj/XU76W3ww+9dhQBOk+tdQQL4LkRJX8hYfb8evy13WzkQQsj712BXYS
PPGMWDYVSKDsGJpxTpAGVazdp07nU5iRfJTlI0FA1XxZBao/UollkUqpj1HI
qNt9meJdEKhpo+1Th6DPcrvcab1up2ebHy6shuqqzfJsyp8dazgP2GEvEV3B
FarS+MVMzWrFCTEsCiLGe0MJ3lmvZPzN4iP4kKOSmwXl59gM89GsCP2/Phno
oHgeKVUSHG7uR81fbVERowR3Ptm6xWRKcKBgOsyP6sGmN8Yj//uuA0rZU5ca
qV65GUwcvTFdDY7hKLuW6rPxsH+BuXE3hFmaubkcet/tFXZXwiRwieL0nwyg
ePDN/mbBvA2XrEW2SWsoHn7YKr7nRP1ik5Xfen+qv3pN39ZE1GEowEzqP+a0
/1v3yy8w+WCfSMuUo3gePC1z9j+TSfBQHin5h/J3Ojtj9bx3ElyoYC1uLaF6
7jwvqIchRv25943NlB8WRslpSWdqoN6iO6+X7ud8TqLTrR4BBl0UcZHm8wlk
DBv4tUNta/bSPupnjNqaD4XTQkjfZynsoXq2ujTnuJjdhtkev7xuur9SKS6v
sKYFozzFjQl0v4eXrAluv1sDtsyeAbl/989skXvjVgLbxJkYDW0CVR87kQlf
AvNju04l5VB8DhTutRngwURN/90FEHjzr2TPO9oG0XaT6X6qh95leY85r0pQ
VzceJaT6o6Kn9zbmhzaw3ycs1qV+GjdfUd/CphC5V0e5xtRfDpY6DC8VtsLQ
ve91CvVn3kO1D2tOUD5EzxU9O0zxFJue7/r3C/ju+HzXhvrHbpnS5+wPIki1
vsl/QPmrHyoTHpZQj0GN+BtNdH/suteBfz3Lw/Psk7LxVM/syiO+fHUUQWeb
buBmip/gSU7vWbEI5c250gzqt3ZR0e7zbjehScWWKaB8YItyKzN1soBAeelv
lC9H3fdZBb6vh3H/b3FF9P+jZsj+F6WAUkymcycraX++4fYn1MVdGDBzfxQT
S3Crd1Al830J4r5Oemyi/a0871g0EdoNnWgjryiq38LcA247gsW4RxSKy68R
vDgsPddf4wUeSV8vVz5JYH4k0do6oBMHR8Xc+LvU/6p+53pJdaBhv76XgOqn
W9J2bV5bBUS8u5NPGVQ/OPF3tBcU45xO8Dd/qneaH06oqJjxYa4pKA81Jfg/
ckStZA==
        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8le8fxkVJkWgnIrIVKWWUC0mUVUoqIlkpZBW+hYao7FSU7JWVFSor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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs01AsXnTzioqu8Elblpq7yuhXyqLYVkZIYvZaMV5IlQtNDEspKEhFx
VSqpUMlFXjFETOQ5Mx4zDeK6it9Dj5tUivv9vj/OOn+dtdfZe5999P3D2Idk
WCxWJFP/7zv3FeZ7Eb24Eum7cmqQglOM4bOE7f34cDTNdPEIhfV54rNLUwRQ
dJ1xS2ZRSHc84tvhUo+17dOKvxwkMbHmztcZ4wGwZ9rO7LtOo6KE8+nzoxaY
XmoMvFdNIjxQVlLkJkRO0h2vzksUorjjJQ0SAbSGDowvqaGgEjbrVereBe27
n60uHKNg4LojSMu4EtOmWYHFKiSMeyIvy6gNoF9fVCXxoOG4/nKM15Z+CAzK
5XeF0pDLF7IyNIfgHbu4XnfPJCyDHAuPjPNRsaHPMKqMxH7srvZ2laJcTnTA
PIGGoWfVPIUfjdC/ZCodjiHhv1+Grxraic6vYpnz2hRGiox+wGEQu581qXKC
JvHxIOe/aw1ClD1VyW2vpxBnKNts7t8B7605Oc/bSBz9+qL/SHwrbEoLWrdN
MHgZ/oJ3j6tAW9u4BX0iMPKP/StfeT4kY/m3dWpJfOMrR6rWF0PPKO70wCMC
N65Ey3FHJNBOPNaSFkvDfzhAZDvQjsr9Z55mr6aQpLJaOhzfA9KcJ1tRSUE7
t0VBLrUHozdiH7mp02h469nQv68UY+8f5i0QE3AI3qsTndmPe++T03b50jDO
TKhzkvIQ58I5pr+ChMps0CkVXjdoP6ULlsEUWm2WcDpZNehXm95cu4pEyuZJ
qdlaCQLSb+fVVdOIs0/srrSVwBS3FTbV0HAYUxgrjOtC6F513RdsCtlRxJSg
6jX+kA6uzf1Bg5WoaW20qQ4J1/08JUtJCLzKwnwb8uHhPLzkdDYBjVjtJ5p1
fWhjB2wu2EFDRS6ErercjWSRTXtpJIXtJj0h49dFUNLxqYloZ/jemz0wuKEH
WQqr+fXdFHydTrvrPq3F963xmsf0SBQWrTweWdsNR23jX+4nMPqtSz0XHtYC
q8MHQvuGSASeu5b3JksAZd3J35YVUNDYpgafi61oTvb+8vULiYUSyS7rCQY/
eGjU4iSFhL6ll6f1m1A1Vt6dc4JEPielzcZHhL3eL3s9LGgs1PPhZrTfx3uH
Dlm/VAINFh2OZo18jLwPPcErJZF2a9HOZd+fIkrJy108Q6DNc6OzYJ0E0j1t
D7o6abiudLKnIUXAP7rb5lpp3I8e+Vl1txCBH1k6Nxk/sLxT+9PoJCyWXfDV
zoEAb37OizQ7MWoTSb9rcgy/TuWW3xdkYv89f+9cD8ZfBGvFrdomNCedPV9R
Q2KjgayR7XcJ9LKbrS1caGhrzNea1e/At0KhznNlClMP0lsCpnoQ0pK3Ik2H
hm1j1B0PjhjFRrdcXzL3vqbUSauqow1l864rJelRcFl2aWPr7TY4ip3/fsHM
P5g4/OW+ZRGOsZ8d55cQ0OKNGpvY92JOjtf5LY6GdTTPQ/6EBLsDzbesZvR9
J50t/LVIAOEmdfmkCgpUlr3fgcA+qD8eEx5m/DyxyqrgKE+IrKuvL6sq0/jc
bLFBy0SEadtPbdx1jN4pbwM4SrWYWrziT8PlJOQU9+xYrv8SCeoXq/gqFNLq
D4RrfmsC969wh5pMElyZEO/jzrUYTTXL3W1Pou3km0OrIoR408CecPqdgrl/
k5G1vQjLX2XsJOYosBaxV595lIid9uofS+wISJoOz31WqYTPorJhjiwJ+aGT
purXXmJ7dnxeTQaJaVnDsqG/70JuLtHFIYpA4SmC45iViWkfjbcXPAlYTf2q
GCEeguC0c29sBI3C6mJdDYNWGLjbRrkzeZHWLzX+0dmBdPMII9tUCo/U8q/y
Bgaw31gaeq6CBrmy8yFHmQ+dVwfb1QZIaMeME+mC56hflLnguwOTpwevq7I3
VWDutrOb8XsC6Z6/UQudpRjJ2BZy8ddJvOhJXes3K0HMSx224b80BkWH4m2Z
fd3KDa9smKUwqLTs8yf5ISQtG5oXfJyGgpW9v4m4GSdPqWrm3iThsGm0L1G3
CWpd0UGPS5i88k3OqTQXIPZ36RZzdwpWvRr/7ZjlwcWOeBxqQOJ82NI79qIq
VGcdHhkhCfj5RlWfzujB9oIr7mLmnwwKxX5Fg1KIFc34K6do7KbiFq560g6T
c2cmCywo2P2x7fgn04dwfJtZNv2AgOLdHfeSZaQw+iu4UD2MRriLaZ3OnjJ0
HdwV4jhAQG7U1TU+oAV7zc7UdTN+X/ezoZiuKYGe9hA3sIPA8n+fe66/0YiE
iMtX9nmTSG8sDm5ukkI4w3Uo3cLkeUZK/c89fbDzSjF4+5hCVrYye0ZdhPHo
yXdUEgVLmd7Wrq09CMgfVfzQSOGoBlUeW98Al6sDf/JTSPjalOcsNhNAxd/y
w82jFEbJOzrhw0Kkh3xwi2H+m7aJ1lnuvQqUc71KXOeRcHyVIlPS8xrlY4Hf
uPMnUb7GFVefdODExKooTSsK/wN5F8iT
        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs4lIsWxknJ7vREdJVrLoV2F6FB9YpyohtDIkQyUilKTqJ2N5EukiKp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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk81Okfl5UslUprETXYIostknG+/XIVmwrrTn4jWttUWEpCihylVpFZ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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Vd8bxYWkFFIyZKqkSUVRKrVMUSrJlCgkUVIoIZkqJE2KSkWGiKTM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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41GkfxtU7jhFJKryF2FpvRXbJVroJu3a3KB1Xqs1ZmJR6KyqHhpU2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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs01IsexSWVQWWh6aWFGxNSR3KkmtqnUqYXPURTnVIp6eFVUqEkXO/I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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lekfvRTtkigVkl1ljSimQyZJ6BbTgmypEBMVoqhkKdnK2iZr1qyR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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHk4VG8bFkKFIiWqH6lkqyQtVG7aSAiV0IJIElKibCVlCRVKtkihJC2y
Z9/3ZazDZEk054yIUlTU935/zXWua+Zc7/s89zqrTl8wPsPNxcV1ag4X1/8/
U+wiNCfla3FNv2SFYRwFZd3KFRVLn0PMTokvbRWN7YY/Xbnv1cJt1c9Vkgwa
RVvyV+VFs7B9NG3AXOkzlHs/tjkN1sHf/W5W8RgFzWLvnuGwWqTzRAZEPqcg
V9tl8mZeLXybtGnOMRpcws1DYn6VcCjfvpv1jEboz6tHxONrkG2uVOIxj8KJ
zQdlcnVy8Fet1m/bPBp/hXpmTb4wIMnUWryVi4blt2wzPq4i1FbnxsZcoTFl
86FqyJmJxaU7FKzf0mi9TP1w729A1OLNxzOvkPNEZuqNtrXjukLhLfYFNi5d
HX63PrYBBTNPLG58p8CVbC8x3nYDZc/9g4z/o5HQ57dDb3EL6kYCS2dNOdgc
arN4zfkSjJQkLt/zlUJmXPwS6785SLDk5tLhpcE8E/baQawLqXvOnLgTOoyB
BdsZosxr2HpT5XbyahrN388zD6m0YU3hLCWaQWNiX2fCI7E2SOexrli5ciAd
olB+K6gWz7p1j811YGP/2Lbh5cL9SFdvWaIj8gVpGtalXrtyYeCskOyxl8YX
U6Wvg+aVYM13n7oQTWEg+hnXsrR8FDXYtnf9Ic/HEuv5ldthO3eBYc8tGh+b
jOi77z5ATdQi6fNSDpL4z0hVmGdhfnBDRLscmd/Y01+2JZ0QGG4YVomioZNH
xVk21mGT3Gpb7yIaskuk/h0Tb8FQzeGMH284kHURLkjkasGWd1G/5ldSsNvy
I31LTj1mDKYlIqUoHMnb3HiW1YgP7INSWlI0CiYXHneX64aBx/6F+XmfcUny
fZLcZDny1i2MC1GhoTQWE6hg1g12Xffe9mo2Bn5f5Dsk/AzaG8UGH4vScPA8
EHvlQw0sFe5pOOhyoOnQs4nZXACRH3pG4bYET7ZF5Y0ny2Ez3mnmnEZBTTmg
uFWyFPdthU8nZlNQ+Soxq1rXCpHI7zulJil0vz5WLxGZBRNN84+FTAplzdK5
VUJdOPy5uDBmbAgNJmeWq9m2I3+9oa31qi9oenjolMyeFsxfoBxqdIQNdROz
2XxHFopsB/4IJ36BdKzgnDtmYfByCfknR+Zp+WxIYJFaCoRXqbTOjFIoWXtW
3/5AK8Z8hdtTHlPwSq85O3W7Her3nz+2EB5BjU+PhrxnEeY/bd+r7kpDz9Yw
nZPQBONxsUrVKDbczPK8Bk1ZMN/K+db6hw3NAe3RlA3JkA2MKz0iQ0M6SHTO
qvAPUB3iEnCY5oCaqdF4/zETGw5Nr5unRMNUfpdotWEd+m7sE9eLJPukDyuz
ysvwyPEeLdxOwXz+UPbX5HLs8FifG29Jw6Wo8kYC1Yzdu96sNNnPgfNcW4P1
Xq8hsu2zWqkiuZ/T3WMm9xLgFKGw9Al5v8C7o4sNX+Th6TnvHTThT+A+rQVd
2uWYHjmrTH2kYONgwddsV4f8vMFgoRIK0oPbBKrHUzGU0SQcRfCRhoRW2f2V
ONFZFHXdk8LbdnrPmAcDNgM7Ti1V5GA68+2WaJl2rEmwFbytRsHxqN/3TrUe
SKnX5Tr0UDA119vqpliOP+ISPwcIXlTHIjJDtrThcnzwwuIpGskS2rMOMRWw
upafEj+HRum2+jW77zMwf6vSJ+F1ZD9yLqKea6uhYnK7s3sHjUVnwwROXqlB
n9/3sAWvyPxaWftcG7OxXyFsjj+Zd7Ku8brN/h1oTwi6tNqWg2Xrfzsd6e+A
xcyID+vHMG5qZZ0xPtkKqaKYIbt3HBTUU6tWpzVDXXKnl6s3Dc2V7IMX/j1A
TK677Ch5X83YxrLVkwn4u8AxWJyHhtXSI8Jda1KQ65Em/Wsl0TPXFW6Ou9vx
24hH7N5lClP1L/WFGxh4pLJFZI38CJT0zR03h5ejbyCQV+k5DeV79ZEMv/eI
q6jZuDWHQpHkk7aq/Uz82R0lKCbNhvSXWwtLP6dD89GM1hINGis9XtQ6z63A
wykz07+ET2++SVawaAZsd1Ajr2U54Cpg/ubd6QrJEH+vD8QPVvA9svEcrsCW
pn4+bWcaJc9eu81khaDLfv2vb2uJPnXway2Va0TS5+td8TfZSMnKaNAWZMC+
Ud4w1ZpGSOvepOKXrbDTPGbhxkcRvlQKqHk9w8G/a97ILabh7topdNaVBY/T
ybuuZnMwMBb40Jw/HMrvhjXOryf4S8t5neroj//eqDNWkvmkSLD9Z9Qqwb0h
Oo1dRmMmtCfJYXsrZFYGTPXf+YwUpbyr3Ve7URvEmHUi91uUc4X/TAkDsTM/
gjtGOfDa7qM4LVaFnLSb7Kw6Cn9N18gzRNugb3TL8SXRI2p25PbJdURvrwUK
FYTTGBDItuOmw3DpM1PZkvDda3f1soenupGik3D4UBe5/4oDwndTKrF4Zsue
EREODHdfLtfo/4AKa3bTKaI3Oke8Z4OOv0PD3Q63CfLcY6a7tSeiEwd/aU2P
5VEwNOXKsi99Ch29T2eFFhF8FPpWpfHkgv9kxcNjNsQvS3K0pfTLkD78XJT3
HA3eWQMr0ecZmJy6zFdB8CPdG3ZszrI43DVO+BAuSM634Fvbx4Q2yMY7spdd
oyHXWGAhtz8bC7cLaf3f/6K2Hl7u6dQF3WomX5sgB6oGvuf679Wh8ruB1i5p
olfye2NGxhhYvNB4VeUYB8Mbiia5dzIgVicrmreRwu2fzjNXtrSDr7tUTyqd
7Of+nvrHFWFoMi2MD5KmoaC/xvMOXw4mJucJy8oSPT9Xte+iXRvmavzuUr44
glGNm3LXhFrw7uDvTRtYNN6ecPF3XVmDU0fZh7cQv0xQutPJvBUNZaNdXcYE
f5b8ljxTNzqR2Wv5Z18i4dNGnvH7rDpQHcc3lGWS+RaECkUf6IZ+xbro3aeH
MHpoHw/vv1bsyDRJ3Fo0DB/bSP2ZjjDYHNlmxk/2t/0I28lvXTY+ezc/GvKj
EfU1uWRnYSaub4BeUgUFD5Ukv1NHGvH+wnV//VLid3mnpWMM6vFb9yC/fSnx
rwUy8Te/9UKnS/+A0RcO1Ld+7FSI7oJlVZfxneVkf34iQxqKFRjpOmpaKULD
o4dn+uc1FnoZapKRFmzMhLnMF/tXic6v5g7HWBRmgjJlUw83oDPih9OvAaJX
nosW+P5pxz+jrTm3ST4qiA7z7uSrh78Lby9fPPE/5Z23VNdrQkRivtxfMh/D
Ji3NmPpkhFjHZ5zZSEOl977WkXmZ4Ov02fbLiOBF4tKcx0vasczILXFwCwdD
/z08J9ZfAJmN/Dd8SH5ok9H+PDPZAhd7iaNtxE9T/KXeqA+3Y1Du4o5RJtEH
eZ6ThpXdEEyYo1Z5k8Zdc1/VBMdUbLnkeU1uEw2nb0sGmlVa4Cw/MLL9IYVt
z00ihJxLkG72fjJCnYZr8uXQHmYrxD4tqjRtIPnLR2Hw2m9+ZHMsrf+Q8w+u
K7vwMq4Ug46th8IJPjVxMiE98h0uZZ/IMjehMf+v6oUb5i3QkC79Lz1pGFTv
/rcfXrxHel2ZAPdVCnz2VoE1LzPw9JJvpcE3Crea5Q4Mqr/FXoVDN8vX0bDo
b97o4V2Gjy4ByUvWED90DDFnnm6DQ1OOHEXyZpS78HqfEB/ITUyc4Cbn8al0
OMqxC4HUOW3HcPJ7m4JxeUZsBTR2OK3n9qWxJkNLUKiXhc3Rq9o02Z+R9Ip3
1/IXFdCxlb+eR/D+VvehYrLxc/yNXs09I0TDOfnQy4Nu9XignbvJdRmFvWJF
vynZLkQpqwg/iSF+Yb1RofwDA0+HbePzJzjQk3UZ2HGwA++y+eY5UETv2v12
m+ZWY0C94ePPVOKfmcMTD+4Qflfuz3qkS0PEVthww4USpBUXfEzfSc5vuzFM
ao0lgios/oSQ++wVWr9fybcZv6V/+IeSPE49VA5YmVCK8B9DYS7hFGzjr/vp
bWzE5FPLwvn3aFxmDq11f9CBHcuKmS//Ugju+/78XEI3FnflJ2kW0BAN+l38
70E1euSaug/MUmgJjysfCEhEFFdXlO//88I12krgShvqhSa2Gk6TeW09pyro
Uw/BtaXJoxOEvy4rs9TMGJj5xX6jWEyjL7P81NdsJjL9ON65k2z84rK8JsVf
jbxzyif7SF9oDBHvs4om/sq57Hc1kw2e43wP3n/JRugu1pPZIzSMy5a+qbIt
haTxpJRhMsmfBZzTrJXViP/walzlJoV/w3F0fFY7zKtu2M5JIXywOyxZRH7/
JzjgxBkDGv7dogbHNFtg35XXlRxB/DTQdo5/7XvUuA23LiD6wDPX/nkjsx0u
4nEZEeIU/rN5Z+Nq2gJveR3FSKIPbx1PXpnoLkbfgZ7xSnuSj9QqTn3vzUEI
9bDcKoMCs/tGWLVGOq4OG7xef5SGYGboWL5pN9KFhMvKs9iwk9DV3qPdin8r
xXXVrDmQCVe0tHWoR2C47m/BSDZURzvdPfsZ0Je1kvhE+G8oeMvv7eHHYH3v
9bpD/PdWv1Zr2XQHrGb6p+8Uc5Devzf9uxsLdi2KP8q2jcAoKuXpllgmggoV
RIz7SD7YORFT1dSG6frqOoVUonc/Ds5NnWZg/NzG/QNtBJ9fLil4C+XBj1Pg
fl2S6GXb/eYvp/IQ0RuVeIpBwYLhohq+KRduxl7RsQuJP95NsV50lPB/ov2X
7UYOBHR0bxS6dWOfn2j5MOkTHonvJyqDG8A7/+5p11gaLT2s8F8XH2NZyNUV
U1rEL5yWpMULtEF8SXNgYDmFXPeD7s11hRC4o1M49IbCVeGtq94H5EP94rru
Xivit1E8Dje2toNbku9o5k6iF7su/lLMDEefYLldA8lXmtvVRRtv1iP1rNgZ
tfuED7GHR/Y+vwOpcL6MR2ReMjMFvSeyytF2JSgxj/TLqEtvr1/7noDWwnw1
DwXCl/qwa/+YbdisnNp5hPhv+6qATS8+ZKJFU+mpK/E3n5FbXpteNcF+w9ev
6GWjJEVxcZLGYwwIC77O3UBDmyXd2WzRhMw9ZhllyylodM1xt7jAxKnS/7ru
nuVA7LFFyTOdLGiYNXesvUDyVGT5wSj7m9BcVOjuS/RDpdhwrCOqFH41NTm9
HIK3XcGC+2O70HDaz9k/iMJkqX/B6k8M8Dlt0tF4TaHQXL7yVioT3q8Mbq+c
Ifoa2ldu/8EABXeuvBsl/C/WMIs5b1EFvRqb47F3adiZ3pP886IaKY/r635d
pIgu3L6Qzs3A4+ok40CSt53Rsu7ksgSM5XR4Cq4g+f5STvHMim4IievyCnVw
wDwkGPdyaQZYG/ubTYVJPlk1WywQ/xLGVJbsOJmfsdG6FQpfqjC/eqHZlTUU
0sx6btydbUJd5JD/e1EOQt/+W7LhbiYqmfHJQb1kv4y5L1sbC+GztnbQmujz
sk/FigvyOzCvm21XtmEE+9039C/PrMU2G8es8RjSV38+KeYjeUQqasVCYeKX
V91Oa7UF56DuvvL5OxJEr50XdV01ysWzx+9j5ARoGMwdzLPsaIRGaH+r7j4O
Budf3lvp24GIT5zrXaSPLbN8sPvavUro9E5tZt6jkJBnuO+mYhtGU2ciL8+n
ICfowCmWeIvx5gfdR8k+bJzOlynn9OPEozjWM9LPSub0cFLcXKGx3D6ISfBh
t1dI5nZlDlyElNsZ8RSUL8b+W7muHqJMmanEbhoPYoZDZPaUo2X0xPEoJ4LH
Zyf1vP2LMDuedEY1gEaiwy0568OVaPJ4aFNH8rxIXwa//iALcY0fUzqsSL4U
eeSWmtSBqNuftQM2kLz93vvb7K5SrD20Q6RFlUbmOaNfdd/K8MKrZH4TwWPg
n3dPhFPeQq9dQ09kivj7gu55NWph0GlYOmVH+lyIpJOHvGo1BMpPWgYQv+KN
sA8uCmjFAfUXo9V32bD8yLuNe+878Dm3lkGc5JuCGzLeLs246nqvb2gTBzGB
OxvSG9uQ1G7t1zNKQ/f7D9lBcQY+tek2XQwgeAzxbfI1qoBXLBW3zIdG0j1R
mbYz5biqqF9wzJ3wK/dw49CvAkzKPd7zf305Uc2TyTzfiqmwr3KjLRykTe9U
bSB5P7zTa0lqM8m7bS92+xaFwqD1zJv3pH+GVGuei9hdg1Dx2r44EQr+nrxD
KUEMeNx6IeBO+kFz3xUjZ/RA4YBU7tdBDsZVu1r9HzRhd4VNkPu2z3Dm/SCz
WC0ZJaJah3XI+0T5Z4oTuAtR81vuNDfxw3uv6EWv1/aA+0J/ewnRG9vQgqtt
cZ04xcVrkNdC8qWsooTeoscQNbCa7iT4Dy08Uca4no9BD6n1ck9I38zccnFV
+yuY9vXf2PiDPC9N7ty8LAoB8o5zdxK8q0TVTSS55OFrnt02FZKXpArDFpQr
Ej98tMzKOHoEms0xVZUdDzGQk3s1mHw/V/VbopBBD8Ybln8Ybyb4e73oAj3U
if0aN/y1iN+sOHHM4o5TGVw0FHiz0yloW37fPJrRjPBMr26hVxSM71/m6c9v
g9Lp+y1dZjR6Ih7e7HHpxKbX0oHb9WgssD5dqD7ciYufwj3nxo5AmSW+eyjj
AorqXmo+J3ryH2v5h27PFnzO/2375gLBNyNf5fCPWjCnnqqn15C88uyg40R0
CTQOnDNRTqSQZJp83e9aK04NP/ldfukzuA4d4E13TcdSCevgcMLPRw5W9m8m
ylAgaXy/VJ/wX8npx+CBXrypuLPLzZ3og3cTt6ZYIlZ4VJ8/t4/Gak+rlIWW
3WhqWvji+xkK0ze5lza7vcO+a3b756iRvPBmLLupuRMH/tilNXxlI9dTyc0/
7S1eZ2mYPjlI+JnaeTwZLJT9qFbKkx6GziXZZlXPZkyWjLUNnGeDawVzLk9w
Pk5/DVJLqCX7+i3GKySeCaZztcQJQ3I+3jrRGYcqTL5oFtYm/ccnV5H9tvAW
aixyZPhXk75pVXVSySQf1dGK8/7/f9vZBWYr/XazsHRgV6WyNukT1rf5v3uV
YKY451QswYu+9EWT4U1VUDY8IuVD8qhy/d8oedtgmLx9vO8J0ZNTniHKz86z
wNpj8sDz5BeUBLyPNQpmwJdHWf5MFxvOqRGLEgMLIFyYui3CkML/AAyPDsQ=

        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs4lAkbxtlaLSGnQmUrq0KKbSkmdU+bU4xKKOUYskokKZJcRaGooXwO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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs81IkCxZVHcodIIkI20XqUmIS0ZyrW8255JEWJPEoRvUhkQuQZlaK2
NPSQjYRUZhuxmDvMMphYr234zfxmpryLXuy97h/nc/47/3w/5xyDoBOeIYtl
ZGRiF/R/L20kk386WQ2PReazX7+JEXLa4z+csNdg/movZ88So/1Do5HEnYWC
9FLagWgxFH/RGfRWr4FKooVBHE0CH6srasvPt2Dg/Va6WymJ4dpPe//b1otZ
0pKiKSJwz2x/eKTiALKMciq6+0dQyYi9lKFQghfnLeXW35fgtGem71MTNqy9
8/e69JGwaYy2rHZrA0WniJJxQoRYbi031HcQ7BPvBHZDBHIaHmoJa/lIrAoJ
6LQRofJHn6W67//AvGvYTLS/GAZlIXaRmkNQtF1Jvx5DQHVzOoXZ1YDCJRcM
N3qKMWq7IlZ1cSvMK7q2rSgWQfX+7O2ZJXzMxtYKnE0IDAb8JPfwJAfUwueb
1L+K0K1qYhBAdqChKdXkS74QlqeuSjdc7wRT4UZqPFWIzKYh5bthfyE7ub11
B30Ev2teN7+X/AaNKsbGp8rF0Au083Hf2oXiDPvPzX4iZPu81FZ52I7c7V71
h9RJ0KkJT9bYRcLgiUH5YU0pGuUnK3kv36Il6taaVG8CTXn84UjWWyyj7wuw
khlBVMmoXYxyD+QP5HZOK4xg+WyToz1rAB+4lt7cVAHsF19ReEF9i/FH01ap
cSOgTk8d9pP2wj8+7llSwzAsuox/DjhVC5MS66C8MTGc2zSkU739oDYe4cJT
AJq535rgHDb0rXd731IT44JGCaPwci82vPQj1d8KscNruDc8gI/cd7HdKzuE
cI6zjTaz6QFdizPpdWoEuuZWHvd1/8a55S9VHBMI+E/I7dPgtuN0SBpjzpAE
P0fWwfwDB/zx8V1K6SRyfc6MxP/YgpxvFq901pOYzL6ZwUptwQ9Hjx/NmRNh
RqdO5p5DN9brL36wiCtEVx6bJ7OFgyNjF9leviTedCw5m1SRjTmiOuPeRwl2
Ltm1+pwfF8pbnn1anyCC++Y7BQp9bOQeTNYQPSBx+hLzbEcKF9PxnUYfXUQo
/my3yN6dh9ZXqfO5LSKYRchPnrnZg+/vDg1vFo3A2yNR4urfBma5zmvXDBF8
+o8VXNrdjjL6K9NrFBG+UD5t3ZHAROqr+qscigT0/qh/GKHpqI9p/xdFVgpa
RNukuks7/jiREtO9wDu0lqfoZtiNGnWn+kAPAjJ6+9v+1IyGfP2qtsaVUkSx
WUlnxvogDPwou0ReiPyOh6vZ82xkOR+r0TAS44V7s8eYSje0Rz/H+Z4VQlG/
PRwnhvCP/xMjfjiBgsjiFH1+F6jB+w6ZbCGw5mtj0tT9cqTn2Xfu2imB2bqn
Z4oe9YGq7BLCLBJg1EpjCM0tqAsOrHteR+JaYdJ4SSQPLhoDJ5fxRBBMM1b1
2pWh7JasYX2EBM5VpTOXIzoQns2O9PoihIV03dDkTga2aHd4BL2Q4A2DwiQS
y2DA4qWRJRKolS5vK9cZguFN3YqNEQRyv7g6h9b0YvUuV8d21jA+XeNsEFU3
oSbiVOvRMBLh0QF9FdpNWOn0VVZpngR1fhkv2bkclzuc9d47SSBXPa7VkNIM
B+sPnJBIEs4rNaXGsYOwia0LGbxDQC59hq5/YBDkTfsq8ts7uJ2jP2Ytq8YF
+7LoQTUJuEpiliCmH2ur9G6RhQJYTpmaJuX0wDovyMx4jxAFSUedPFb1w3aI
EZhZLcCkhm6F0k9sqCj/tn/fWhJmu+9WOu5qxooQn4vZTSRom36N2e79HFHe
tm/2LeznOfXzgpzHfHwJLNtECReClhMWPMXgIijrVUbfNhJJukrK+cV8HIla
KxjXIEDzeVBndOgRtmd+87IolODfZ8KyJgI6YcJ77jK2TgibdU+3Ts1yoMVm
pAlyRdhLvPS4GjMIqyovTTd7AWyUepamaTGxI4KWx7oghsLd8HWM1ylIu/g4
z1FeCrrrcc+qoEyo+e/Z2zAnweVjDvJ12X/i2aixnM+EEDeOH2SWtTXCNHiO
FrVDDN/uuz602T64Nv/y2t90BJOq80sDne7jGZVLHHsiwW1CGmyh8RYu/O2L
fusUwrBr+grzcAdq9awUKxfy7Lrzy5Qc/0Lq4T2XRn0JpHx36G2idSKjKM70
50kCdN87CbTQCjyp+aTNSZZgPMR6oiWzDyZq2xmXRAIoynP88s14UMq6tqrq
vRBrrgWcv9HLRnwQ1aSdQ+J44oTmwON+eMebt+pECKDk5h7rqMnDkY88p5Np
C30A3Vw5qwYJF68KVi3wiJpfPmHb2YXCG9SZp1EEDl3f9EOeUR+yPGUebSwc
xvrwY7wxg9uo7HSv4LVK4ND+TCq7sNd3628IidSF/6HYPAi92IW50gqHtDwC
VH35/VcjG+ArkVV9kClGWIFO8fffe6BVtG13iDYBvWHckVH8G4vCFYry/N9h
KX1AhXKwDdT+xNfqQyLQVvCTm3dzMF76NDorXYT/AUvHsrc=
        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lWkfxmnilSTjUIqmFCEkayq58NornWQvJSWRiGRkyZJ0apBTUkmR
LYyWkbJkObZDhbPocIipiercb02rmUmkud8/ns/zeT7353me675+3+u6NQMj
3INmSUlJ5dLr/3e5GSeGk+4o5O5d3HPjAsGrZPWDa9sGYG8jU/7qKEHEqynt
Cikx+jQt13DuEFjKX5UdrBXDe4v8paoqAoPoe0tihoZQpTC+Vcymz4LhgRat
bjQwVQartxJoeNQtjXPrh/LYkn0vfQhyIjL8CKMV/X3am/bYEOSv9Lxs6CbE
hFX83Lg4AkfupzmXLcWQPVhtM0L1+InL5HsNBVBZavM4chtBWXZ4paltO+Q6
soRtVgRi1Yc5bJdRDCdHyM6ICQKyRmXXDrfC4oVP5EYQKNeIb18KeYLS0VyZ
8+cIVsaIFOK+DuILS8E+tIiAH9EnFGrV4eI8zjV3U4IRl68Vyz4KYHFlRj8l
iSBPx/FVh9p1wGqgfYEWgWTJIEuPJUblZaOJhHKCKBYjwL1wFGktR7m6H+n3
dF3ejXSJ8XcA46NaCkGhSkM1R7Ubkv8q+ea4EkTeHjvzgMVH0XurLVN7CWrk
dxRYjnORZJw0GeFC0BjDmrcquhPS3h4eBtYEUplzgvbdD0JkaKvc/OUEz1da
rZ0VV4Xk1+3bJXp0/cuMINr+FD6TxVv203XuVGjMuLUAqfGtP52MJOh4ET/n
5JOHGNjG05/cTvfnnBLcVEb9e7UrwGo9AfM7J1AleQSrsiwPzBYR7OznVK9T
6oLUtz+jDen8Ov7z5S/Nhl7Eemvb+NH5SX2SGDsn9CP2dZX24xMEISb/fC5y
G8AHC+vo+9kE56WNlBP1xJBRl1gV5xPErd78TO2bEMed90WmpxGscxq8b6c/
hMSS4zLHjxG4XvD1WWXZgfLo0+d4awnCrnw4l1Epgq1r3BuNQwTJ8h7z/+dQ
DpUyO1sZHQKz2j7bqSgerk8uiTxL9cVq7FyayhaifXgTY0cY5e+e8NnLtFYs
sGJH795A3zdnMlLWRKJGK+T0AupP/gbjzTM/98NU4Xm44WmCSu4u+xUlT7A4
Z4Vp+x4C3cf5TjqXBbjmHVJMjtD9Ptr/2emNAFbhd001kgmWZbazCpcU46dE
j8Y52gQekt9eCut7cTGBwS3YTflj2+0d2/MQ/Poru6ap3+vb7SqdFz3CVx+u
MbYQjOeN7I73eortLtOJv3AI9oeMj5rN4qJeaMFzcCbIXeWZYOrbDXnTZVOp
dpT39q9MzpchRM/SFzFoHkriWzkq7XmoVGx5cHgFwR1Gc9hYRztuqGwprrYn
8Ip5aXZ8sxhh2tusVXOo/s4bjRtlB9Gp+Mp553XKb3btVNmnWjA21FeIjAjS
UhJ+JH91QcK2rg/fSHktVjkjNm8Au//5ynxzAoVfwxRjzvYgjqUzKKH6Ob4f
NtWqZUFTV7c8i/qZ0XyBcfRLGwK/Kc5eRP/PdHwzOYd1CdN96d4Xqb6Jum97
+RZP4Kes80dRBsGjZHfn5EPDeHxWzrqM6vlBM01szh+CVbJXcEwq3W9a0tFQ
CJHWoP7Swp9g9pB37Jl0PiYOGBkfO0xwi6mgfj5RiHmPhcZhpwjqDN7qKSrc
h887zprlqwjKr6z8Z51BLWTsN7U9MyAw8TzGXaAuQLlmzET3foIZ0Ybgbw1D
8LMomP89nfL2wqxfI28IMeLXk7ebCFrVo14s9+eD4+1wtd6b8hNo4HFNsRjD
MXs8r9F5M83NVikHdMOrfm1zoiPdX1DX7DAl2ief5wW+ryDolG5wzc0U4cMR
JQ85yg/H8sSt95Z5KNvl4mRL/XjO8Eq9vZCDnu0HFE/S/FWWbo8dC27Hn+ld
v0xS/s0umsZZru9FdtFMAo/2wVee3EnHS3x4qObN+NM8c1KfqbWo3UBYBa5m
riTobvq12VU0innME+wf3tN+lpZRe/iYi0C5UBNpmo+JmsXOO45cRkxGwa1l
tL+yjKVcHGbxsNtasJC3g+Y1K7jflPrh7GfieIbqX++pf/b6/HZ0pnpLFVkQ
hHsGvrQ7z8cdk7nHlA4QSDc16Mmd7kGhoOJD4SaC7Kysm+ZCATqCLn38RPUd
uN4wdrxrGOcdntb69tH+2DpbT0lmFDyHBaJEHoGR2105m34hOPkrjLxovg3e
upSEbuwC6VUrDaV85esrz+1racXpB4u2uNH/8xe8iKhjd2Fd995D62n/T0yN
B0u8evHPTxMPsmmfMrfWjcRr9yJf/vWFxTvpesXtZvEdEUp0c3m7ad9IDLVe
9+Q1Iq6WWchbQ+A5XiA0DxhC0+c4w4mbBG0GHsvZEjFet/a519cR9NhM3s14
KID89599q+j8i7PeuhgktCKs7bC8vxk9v7ZVz9xTb4VCRtff/lSfj+PbpzL1
1QhbmOt1R5/2+xO9qGXh3Zgx5m7VdyJgJ0nELibDKJ8b2mycSaAVaskRSrJx
zlMg6qT5KTzWZJQ5WYqMIwZRv1O+OpZqsh6ojuDowqrfWp5SP3TNGwtae1Cm
4p5rv5kgYbZUdt/OAaSy697pXab5+KQ97dn4O3w3ElndGtov7qlpK0b52G5q
+MwknObzbcOc615caIhO6XQ6ENiozk2u/bkUFc0pNzspD9Glb+JdA2jf6x4q
2cokSBnLueWlLIBljv5H6xh6HinF3k1p4SJ95J2SM+WpKkhD69FhLj7xhc/C
6fkaLTM9FPZeCBaSQzoSCKyCGAGVto+gPrLeSYr6t9o0pe1HWT6WRJ9bdIrq
SddbPfw2ow/201n1PnRe06ykba6zRtCU4a7S1EIgV5PmvyH4Lu7HRvgdo/lt
C7HfkeHCQ6fq3MYVlL8PS6VV/b//hlP3+GcMqd81JmYdcswOOO8r0z9F++fv
zB9/ZyaJUHReUuBP+++5bU2pv/oVJAQHPJ+g+QtrOsi8ldsMP92edTuNCT4+
0InKfjgEe6Wh492U3zWZdu+tageRmsqyu3uS5qtAdWzmZjX+yJc9EEX7JSdX
1429vAuVQpaLD81/0dX5btE5fHyZjAjJ8qJ9qqN5Icl9ACXcwq4R6se/oAih
/A==
        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3cg1W8bxk9ClEQDJe0im6Z5pUippEFFoTSULYmXhCREGSXJz0oZIXtn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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41Ikax8llpctGyiU1JWlLLm2DOPJVayKzsaEolXtRp4tiDtKKk+hi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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81IsCxeVKeo2hUCq80Yqu3etOXjnetUylNEoSaREVCU+SpCypJsvD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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk81ekXNiaayVJZIimUpRpjnVDUU7Ykykg3S0m6JYUkGltRdmGkxVKJ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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHc8le0fxymhVEZSVpSnohSPtBQfoyFKVkSS0RSiVDwlkVEpSUTIloZK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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlGs41IsWxjUpRaSIUi6F9oxyShG1yzud7JIkx60eiSeXTcrEVoZ2kQop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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwV1Hk01QkbB3ChIaVsWarJDSHTIqPd9OUlRaWmcCwxKuQiJCJxbU1htKhM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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lekbRpImSiohEkqULDMqWeZOyVJKI4pSI8leI0ujUnFVyPKbQhIR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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lH8bxVWU7EKLPUUoNYhK6khlK3tKi5KIihZR/SSpiJDSIoRkSSRF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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk4lIsXx7UQrkqSylJIRZsK3dLyzZJwJWVJcRPJNolKbrLkV4TiomtL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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGk8lQkDxY2spdS8DUOMyhJRXGL0oqNeW8iQ6rYYe1knphTRFKJMC0pK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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkfRiqDNvmGiJAla0iWpDuh0ZcSSUMRhsJEJVmylyVTTNKYHBGq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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHlcjO0bxYcWRWlfKSQt2kmWtzpJZHsjEiIVSrRYopBXGyJR0h6tIpSS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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs8lAkXxwcRFeKtrIqlrFQiklvys+liK80mzYoucilFaT9U1Btl1U6l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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk3k4lIsCxqdpc5SjbLnl6KjDnYOOOZZouV5LSqWypSmTdG+Lji3STdFi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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk41ekbxmlMe9qkmGps2VKmEdlvkWXsIUoqmnCSvdLQyVgqjaQsFTFZ
olAzdpGDJGuWs3DOGcuQGnn9DIkUqeb9/XGuc53re97nfZ77ue/P9ZU9HuDg
uUhEROQW/fz/W/7f4fSGzz04n7v/u58eELjnHnyjo1uBZqe0pkQ1guBSieiH
Md3Y6dv/8mECQd5p6eRdOXzcrRf7NTuNwDjSa41k8BPoHmafGN9NkL7lXLzi
Kz4mLj0ZHwsjWGQp9jQvmweu8fyFmECCsr5EdeMyAeaL4xdW0PNPv4qmcdZF
o9bs2/R9cvR+281W/HcVUNc5+Wj9doKiz5v5cs11kNvvNVinThBoUmp+OKAE
X5i/Zi7eQZBotTS5sb8V1bWar0wO0uen/X7pD6xDk5Pbw7X6BPaLR2ubvuMh
eUj83dAlgk2GnCtTniwEOhjPvN9JcMVjarf2hiK8niqXgjLBxyIxkxRwMWod
N38zgiDivsOGZ0pMLDrg0qBB+7OuvtrO0yuGnqfAxl+J4GToNfmxiwI8+Dk0
2iqXoHhZwDXd4QEUyASVlt8g4MwrVWaY9mBN1O8lN6keyayF60bDHMze3P7N
9aMELdMVi5wquhD3iKWoQfXJO+VpWaQqwOZn9w+E5ND53WLnzGR5UFa/P9h8
nqBZY23IRKUAz3K3xs/dJYia0Pc7PSiEq6zn/ehwAumCmxmCw0JI8H2YRqUE
mZknl7Mkb4Il/nNhsjytdyGny1KyCWJVnxm/2RCM8y0aeBH12KM/FLKR7s8u
bbVnsm05tsfIB0+pEnQ3eJ/953YbZGtFzbOMCc64bx3rSOLjzE7JbbnZVC83
mw8idikI8Ti7oovWd51largV8tEorV28N57e59vRkMHrw4S47x7rBgLl1b3R
LqtbYe1Xv7ia3t+duX75pHkHwmOl7Fq9CNaN+Quaddh4937r8KbT9Plyy4K2
aDbm0+1E9h2ifpE4pymSVATePTP3aeqPYjuPoDEWG7ma5Yd0qD4p+VPXld+V
YOzD+It6FYKs6bDyrGU8xLkJVsrFEPjzn7x44yhASozX0J0sghyN8Lzdea0Y
SUouWEXrs28lTj57Xo+SCBa7yoDA8BA79/JQCyR9ljl/1qb+ql9oX1hagE52
zSlnuv+gN1WbO3yq8SbW3tF6FwFr7kPCwN+P4RuwsWoNzY9MRuEfjVN18A2Z
qo2hflS7EtZ2xKkbeXe6ngddJaj4fj5opRQf7L22SY9pP5JNMoJ40T6obz/H
suokGHJkpLS/E4Jzod5qF4v6J22fjMIeDpzqq+5soP4xq/gqI2LVjbNLLKML
fajf7Tt7j0nU4K0vJ2heg+qludbZ2qYaoypZc010v4kTelp+Axx8MpWUFVB9
tdUWefe1cTD2JfLCNJNAXDP1jZTK3xjUnjh2eZzA0/X9kf3zfJQpDKneTSQw
8lXvs4m8jDM/915h0Dx8/OKun32RjT8VfvgQ4UvnjQ3LMAjhIWeKHzF7mWAl
e0a6Lr8P+5Wlh0LzCSamtkT1GbdhhaR1vtt+AlkTzsFUZidmj93EKWuCuOwl
v+jffYrwxte2ZTp0Xoc2Q3+DdkTveNAZd5j2e3qLXbIqB19lj7WHMShP8uqM
03/gYny0655WNN1XU9JI6fI2FAlrLVIdCUS0Bzw2xjvgYF7CyBdZgt6Z6rtO
3n/BrFP4p/85An2PAN3anxoxp2vxUZH6O9Cm8QTflo2jqtbB/nSeYXMTb/GW
F8gV3eJSZUp5OGeSxr3aAgO/T62WPxGc13ysaPtHPQx+5Ta6Un1nmNvCJazY
WMRY0LR1pvnaddzkKO855o8/nH5pSPt3zy7e4tiN4Wc3XufRfBjxUxUfzVXC
pz2I8Q/1C1Mk8bj9By7qE+s2DFH+iAhlVFIq/bDNmeiupXornGfVFsRy8Ft5
sMZkMPWvsSWzTKcDI02MvlEPAvXqWzaaK4Sw1o/Za1RAz39Dst4qhaFXY5+c
LD1v7/e9dzKvDkOvMjkTegSMKN1SX1YWIkb7X+cqEBjUphhH6/SBH/KjVkk5
gVVq5cyCTA/2CcXeMzwJRk/qdaRs7kH4pV0eNWcI7hQubOqwqIGFWXqCDeXz
0Ofz3NnHebCRb19vto2Aey2f+7tvL47q5Bc4UP8yfyfNbjv7Ebg0+JZPN8Hz
Hv/bsaYcmOrMauYcIXDQsziwPpKL12ed38bSPGf/taFgU04PGiw/BV0MoPmU
vWoYY96Dwe3Dc0tSCMS+9WC59vXhgVeNoKuZ1s8a7Hk8XwPpPzUqmyjf7T2/
NUqXj0KZT2myN51/R9PMnlXmHNzeopShEkKQkaoqXmgxgPLIfzulHtH9Xlrm
PqUgRMQTA1NFyl+Pwm8SiraxoeeSpGRpSfs9kPJWdKoDuVKfr7pTPXZed+XE
LRmAu7BccZZP9ckhLiYL+TCO03tkSvlgaDdcv5vbiRzx6a+HXGg+HPZ5hEbl
YuxSzeqnVG9Rz/5y52V9MG5QiHSkeVk63TIS+ttDlOyVrzan/DJKGD9Rc6QD
mcYrvvTa0jyfuXekY3kn0meUzy6l/rqiq3Tj6eJ2cHRXOb5wpfozI9WYWhnY
GqpmmEnrS3fJvAzQfoHE9lPx2W4E/L2OkRsX9+NNhsbegiqaHy2b/d7be/Gj
1GQ6g/LxbsVQ3l9qPGSXr/w4SX8bBcRpd3/iYcbDY+A6zX+g18kUrdk0DI1M
LlyjvD9x55F5kXoPAn9ZpiGWRPlv3OYkp8SBcpnGl9U0X4w/VJivIynPzbhC
NuXT83VH/S8rt2FNcqJEDO137J37xUsnesBe8+LlZfo+IBLxP7vw2yKw7Bh0
+UTzunDYN5qVxYe+53fFltcIDt5uOV0dXgVuRGh99w8Ecgupb0UdhQiLqQg6
X0HQuV5FZkr5OWJnD48fonmubKxedUNQiajJ9+FXKA+1zXtTBeolKPWcbFlF
9e2fFsZ9/7AKDFUbu35NyrNDJ0cSJDmID+Dd8TxA+ZU20mGxSYCo3IhXO2ie
+h+cYlS/7IGaVL5AguZzpZuL7e7YVvi3en0ooP8/U/dJ62IzC5b2Nv01PxL8
B4CNyUw=
        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4le0fp22EVyRkRCTKqOzyyYikIZRCSKQkoTS0UFSyEqXISwMlQlaH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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHk81AkfliO8pdBhVSK8WPdatWTrKb3pcjVS1s5utqW1sWgTOapxW+Ql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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHtYzIkexhsqbGiUiujCpqPVslq1ieOd2lK6UPIQORk5lDDUJjXoxhKK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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk4lekfxk00uZSUVJrBpChSmCRmLDcVWdLIXgojTkV2YhSpjK0OqsPI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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8Ve8fR2iQtqzMCqGsaPFGKqmUkRTZyipFJKkolUSkKCOVyigiZG8R
Wdd1r3HNfMU995aEdur3/P46f5zX65zP83zeU87Zx8KNj4eHx56Xh+f/z8ZM
NWnZ4grs48vZt7eQggt18MaPSCaUyk1C10ZSKJdTDMlPa8VF83w1Sw0Oci09
F26sbEPCw6khp8ts8DQkxAtmeAHbdtQ1yFPQ0UjpXSrQDbrK+S+lB7iY90PS
0tWsFnnZWLS9hoK6rO+e4fVPEem2wrNtDQUR+/buTe/f4XLSiVNy/hQerZi1
ObynF7X7Ei9sDR5FeGx4nsVQBRY7OmZzVlIwC2vIlxLshvHZMAO77RwwksVT
1yeWQeiF3Iabtyiwh6SyFZe9RNfvx9FFQhSuVFsf3N3fBqt/akYrhCnQ/Ncv
HNjwBtGyVZdlNCjQ3XRvlHX2oljdDmo5HLQwJse/bqLjg/JPeuU+Dnp8tU6t
oL0F1Zm5ZMCDAv+eDLeL1/vwkv/52LcUDmK8Ni837KvEDSXmgnhdClH8fCmf
2llI9BbffjmHjZh8s7ws8RyEJ/RolRpSiNv0u0zbaQCpDReWM+d9xJzHpidE
LtVBfduWGs1PbBhs2kAviyyDYMZoa6QrG5uKjuoMKeSCb3ZX99YtFE5szJcx
UWqF6TuXO+YrORj+TFNQWDuAMRXdU1P/jcKg+ITToU/3odr/MIy7jkLawfhq
4cZ+GAU+WWTygAMblVvax+TzUF7d//LFQzYKzl25ef1WN55v4D0TeXUcNtcv
WEVFNeDp5MmXFRwKJh6S4Eh34tjpt6PfJTio3y+4s/pON35QWhXh7mzY6FVl
hPvXQNc3wqC+lA33obhHwTylKN796EhaAAX9f70iN/YzcKs3NZt2kw0j/+PW
Ws1MhGy3Xpp0h0LgdtGYc9vbkSbm/dljfBwNXaqSab878fDR7fMcbS4ihT+X
zX1Bx9TNg+/D/TgYXMFz5JIODffFrpQ0c8exzlpPztauC9TB4iGO8Rj0zdZK
jBTTEDLLlvnaNQ4ee4m5x3EDixV9rirLUDjzpPjsZt8m7F8zeXP5ZQ7eFA4z
+6/TIfvz/cne0DFU/ligGDXWBL49lrMLBMh++9eY5A2mwuIg68/APAp280qD
9eZ0oYv98ILfXTY0Y0Xbs+NYyEhYvWpBNgVZ4aFbb7RzsKlaeYmIPgXxkoy4
eaMd8KUn0RtXU/ghvOyvA7kve3fByGKCl4IobvVrBRrW823XnXShcODHkIJU
Yiek+I8IeF/hwFXn++S/bDr2Tgcck27iINkuZPNrej0yJng7v5lQaFVo9HO4
zUTiHMdfK7+NI+Rx6cPo/muoFcvx+U7OyxBwP7fvFR0Ls81UvziQ/QicTvq9
NxWiSup+xcoUOhP5nq672wiesVtjrmMU2lpeNOt79yJycdNLjSEOLrsdeqXN
V4uV/IZ3xT+wwXCzPJBm3wMNmwKWrSEXzNa8x4vr+7Hs+jrf7fiIH54+/zkd
yIdZiszV4WUUTtXf8oLkK6i+zjznTf5X8J0muOhrNYyeJO9tnWDj9F1Lkbkz
XTDe1rNqahW572m1b/SZQky6tnVELKdw5H5TfeFdFviWlBTPNrFRr8+3mDnW
ibsM+SzzDDYiC+u+BK5iYbjUMEF9JRebBHWfbYkrgmJSUX/+XzbMKr1FfJI6
8PlK77k1uhz4XRphmT1mYYLWq6xcz4VSwM5oMds3sP6zRF/7Nxu5i/2Dcpwz
MXimxKSL8Gf0iohLQxkDL3lZOxqfs7FWvfqTfhwD05q7RYXEKCR8acg9ptqK
rk+/x1Vm2KjufCDHNxkLA6GRVSbkvOyU/Jvqfm04fz/r4G4DDmaYI14m8V0o
KJoaaAMXYjt9jheKNGCltnfb6cMUJPj/6dKLu8Bwyui+fY8LR8GWDqtzVeCn
xcvd2Ueh5VuWYef7AYj4eG3/J8uF9FU/quVML3a7TvTWp1L4c0SqcWYOEzwP
lx6WfTWO02veVmwsase3coMIrdUEH4aWG/u8Y2Hp/4uvh+ivStDw8XT/QbiP
ql/fYEz03PInJ+ZpLrQPfnkbuYt8L89solSxHmmrozYGHWKjeIWI+W7k42F4
19TxuRSkjb9Jzr1IAz3f4FfdXA7Cftwc2N2SCymLQ7rccTYOhJzSM9JIxxa2
15KODRSkblxdInekDjdGhUypFDY2zksWLVhbC3kHMbqfCIV54tLJvg+fweC0
zWdKgcJa6zk+jiYdcLVeWHzyO8Fz7Mk059AcPBT2qOiTpDDYo7RudjITzOXa
8+aQec4cD0iIrapH5v1MMZY5hVwfnjAvASaORAU7bGZRELpnvvfp0x64BQvu
6/07il/ROt/XbejCei2fzUOTHBQnWzlIf66CyLvRotd6FJaNjAv8lWiHas76
wIj9HGg66HAKeDshNPaVI7SSjcQ9Lo18kW/x/LSVYlUiwbt6jwzP6kJYW4av
20z0/MfGi0r86WnIeibzaD7B45qb7lIRHt1ItYm9HE/80nTRmuT+v0+RrPdZ
dpDgzblclCdyuhm3t3nrKjApTOUZ+HBDe6EzEjPhGsaBhKCa/1PNVjRbfGsX
OEohuPk834G+TkReMFWYoggfLL5rFo42gfdenfpgKAWDnkf5nlOpcI7PTZlY
T6Fnt+pPEaoAewu7Yrzq2Lg+cfqQ2MMeXOnweb4klAP9hsf8rRf7kbeQX1NE
jkJsXqWOdUotdo+8iqx9R8Fb/qTlBaUWFMc4dDyjj8Eg2u5bkGQ6lDzU5zkR
PJ3atrrZ/18TeErfzyoRPeMZmK+X3tKJV+9PbdcnerVJXebikuE62Cq0bctL
YuM+xbf3h1wzPM6MpB7KYmNGpqu6PL0bEXTZE2eVx3BrrtkKxx99qNWrMHUs
IPngP9aJ54y3KG/oHOdLojDBuN18YTUNC/R+IbWIwt5gHn/ruw3IVWxb4Mxk
o9w1gVdA9Q00wXnBVqMQpm8mOdZbAd78zp370ikc14+JdHDuwYR9T0DKEaI/
p5XPZ7kxITLW6CYRxMVJrtRrzwomSm56WSd8H0eB9GPmNaEuSO/odV22jIsX
DNPP9oJ1+DTnpVY3wW+UmrlgpnMz7DWstyqFsBEWqpvNNuuDq5exhcBfDobG
49NDHtNwpEyPV6OVwr1rNLuqsDYEiHevnxJl442MkpKzSDOe1fLxnfahoCpQ
Ot+D5Clz/smyZWpsTLYcfW/0lYZ3TmrJ8gwKxx4fTt+VQEdAw+FeH3kOYoMk
DlsWtUGdt+ee8ggFjW+DQ2NHmeC3ver58CMbanmBchtudUIsOu0OdZrClq2M
5vwTDNRlVLLDbbkIln1+/Y9CK9Js/LMrE9h4XdZtvHV1DZKXFX7o92TjLXfn
nBHzLszcszL+XslBdbBDyL0HN+D7MspOnez/wL8ruTxWBK8v6O0K9cR/ZaoX
Rf5sAO1f9jVRQ6KPeZ+0Iu61QyOgLF5UmYP46Y8BQutasU3+0BX/D2Q/mos1
49CMFab+J65tIvngdNKnv30MPNtbMsFqYcNTYNH6B+EdYF3pCLx8kgMps5o9
NwfzIEXZ5CxaSsHh/J9Z/5QO/NKQvTFwnELWtvU6x/16oFMSOiE7NQ721qzg
Sz86oPpHPkFlLQfqk5+PPfoUC7oS8zGH4N207ZJDs0EJBD+2zVf4ReZNk9F9
QvShOjP1ztwsDkx5/vWbJnXC2v3k/GQa4VdgoO6+hCKYiDNX3pplY1pUZ2jn
vQEMD6camfFw0fJhdeXoFyZywz/X3qwg+9d4ap7eTsOcdI6IxJZxrD60fvfT
uQz4PRITrif6NVVY9iemqR05kwu9j5E8oXpDys5JqxvyMuyZAUUKtsMex0qT
6QiKay7ytxiHt1jooNFVBoYOvA35bEn40zSrPxZNQ8THOqOAGcKHft57hzi9
CI4a3OgyyQY/V05izrO3iIiP23mf6NPkCpNMp8AE2KksFf5C+NGz4WRKEZWN
zqCaHj7ib5yIyJDf00xIFO3il37OxSDX1mC3+Rt83/hl3Z1hCpVhiRvbl9Ch
fpCHme/CgcHhShlXDTpmgiy+d1mPgV98V3ObLAsuyW4f9HU+otgwaU6fdC4S
b3z7tiSZ+G3TxP6WomSwVvvHz5DzGUfQ9utndUJpUEjMyGwcY66/0xdYdEPn
/vUOPX2Sj6sNehMYiag6V6+SQ/JFS6igl9m/GtjFTS+PJP2lwMxcZOvGV4gI
qb0aSvJ+ZWlZ/n4tFnJGGeu33vuAM/IRHkfc85GrYHXbhJw/RGzGTEPlAp6N
n1w0QfYfcylgco9CCUSiDtSwST4VzlyTaCVO+HX5gbxRCgULfXpWnEsTAj0u
1azaQUHMs6OZNbcJtKnAY9VTbAhr9jpI3mvEfWWDMOmdJO91z+O9ONQCqfBl
9OElxA/tghc2nGEhnD/WQUOSDU4L3wia3+C1Ikya2yjcWtbVt25OK9737lLL
96VwX6D+LU9NExpNUyf7uRTGtiWdCOV0ostGQtxrLRc9qh/O3fxQjhkeq/JC
oidMG6Ple9d0QqN9QWI4uY+gqCY//hQ6fP9Vzu5WZYM3d1el02gPHrmMajnw
kX7iErSNZjkA1xLv2CqzD+ApXNp4YLUtIvobBBYTf5J6rT2p7MzC9Tspt1aJ
cNF4xraiya8A99OFAvYSfU/ek86v5l8CjtemRXLE3+INkaFm3I8o90VRNU84
uHs+UC8xux72N/Ru6+URP74iY/uXmYU94ppZ7mR/Ujv2FWkU9EHaxp0SqR1D
yDzvLTaR0ZBUETfeT/5fopk2v+BrDX6NKJbMaBO92mYRvGJVPla8dH4bKUhh
Y971KC0fOlTzuXNXjFLYURysoEL6w4F1gY6V5D4mO4x20Csf44vv1SyHjRQu
RiP7IbsFl7XKDus1jkPFciT1S1c3xFwOjiyu5iCjPmPB4NUydNfaas6uIHx4
Vr3YIiYDZ5XX/PeM9K9or53exTzvsEjPLSfy3Thu20l8nTjeg6XihpLJF9lw
XBm8ICioCtoG9+2irxN/Ot/qObGwC1v3RshyCf+35Y8VmAe1wmyD2IxdMMGD
l+YAjbcOMSJOiQpEP3huekynK57GU9OdWY4Ej9UDxuenrrVi7P60WI7zGByt
2NIho7ehXK3s0iZL8tDX0kgPb/LenJW77DmFDCxxR9xrHFyS3K5N8qek8wZV
QctBFH5sNNTrIn3Po2zH0oss+FXGfGNZkry/6uwZJf4OND7QCvefwwbV4aLK
aehFlcDPNmdhLkK7LlEevj1wt/q+3ZfsP0TeaLqJwYCwUeH3dGmi/+8Wf5ua
acVha+tcbZLX8h+O6UfatCKsgfn5OJmHzT29+O6/LmjF75Q+RvqWto2wVplM
K850lfJX5ozByCNXlhFTC6uyHdPRpRRerk363ZneB/Wi+ULv97OhMXvhmach
k+hTiK/9b5Kfg7vsA1/VwmTg3MWaNMK/PFPrpAP1qIi3kzv5kYJ6yllGhEYv
cv1jef5Gc6Gy4tHY0hkm6jyXlppmEX/xPOA3vZQB+YDU/xpC2TAZiT3ylVUP
PaEWnVwhCgFBXl6bdjBwbLSQL4D0gcqrZ1/8+Ej8RCfh/Czpk8nzFRS+WLZB
1+nB7lAhNkr77lVvPkDDWPXSVWa8HIg8z1iflkn6rPNat4lNHDSWnri6uZqF
PuOW26KnSL8u8NXc5xmLooGauxVE74p/zFdaM1UAwWtkCpJn3TJ9t3hMsCAf
nh4+OI8DHrEilifh86uDA5o+H7mQEClUMb1UCxvRcyd6jSjcDVjt/6KjE98M
DXnGy8YwtytgjWp2K1S2Zyfba1GYUS3rOS3eiaX5Qxv4zbiQnZ4OW5RAg7Ch
uYyWEwXRSMXYzMoeQJ/nj9Yz0l9/Z/K3t8ZBbsD+VxGZJ+FVordORi8K0yMU
5Xm5MPH1rhO7W45klVS57+VsvPOO56T8o0HTzYx5/R8bso9cXFfeTUVxaly0
OckDlQppisdCadjvqvEnkuT/Ya1/vSESL8AyrAv31aSgJCcvrK/7GsV/swQM
CR6PvF5Y2njyFWaGb3/0W0v8b+VWp1kXBjSrWEKc+RwoLCwpjLrei6N19OA5
m0dR7ZU0yGrtRIX+BTNJku9p/XuHxO4PkXxyR23fpo8YfeDw5Mm+HmiZfyi2
Cv4AGx1+2byFRXj59HzqxG6CN4u0qx16NJiVpXn2EP86dvH2T8eaPny5JKTp
fomNg1+27X91ohtTyhYZ4ndJH0uT2FPqew+iaWekz64i/rpPlXE/gQXJJ6v6
n/lwoBe2UejXmw6cymsX8rOmYKefsyBVsgypOknx+0nejFm5o/y/uio8Up4a
DyH+ZGqUqrYxhYG/pwqfOgmOY3p4h8vx6B7IDjlcwFsOLJtEIiejquBe8u3K
VCWFpQI52cVv6Tix1+fo3LkkX811+e/OtkY8HX45Pi5P9IR2Z37Tyhf4bfZI
lpfoa+evT7GVIk1Qr64bb7ch/DgsVnTNnIazq/j7ZtlsLB9ZRs2hVUO57t2M
CukT9mcKBtmznQibcaAWEz/iUZWZ99z8JtzljpaFkn0cOKQkcQdP8SLB2e3J
agq6h376b87ogY16ef1tgw9wLG4JNNaPw4zTzVcMJbLfnZn8vSXtoMls3bTs
HAch9+ZvfUb3Bt0qcI8a0QsTobeevxgvsKbyRONdoq+T0eqs4bQGBBg6RZkQ
/d0Wv78mPL0Jg14JpYMg/WLHwRarw13YIn8kSiyWg3m24xZmxM/SOqccde25
CHM36tVayYJ1wEErkxHCPyeFSW3bRmy5ZOy5oIYNY/WFTmeoPmRsqku6U/4B
xlnvcpjXKxD0+kLq8RMUapQNdi2OYcFVTFQ2IXAcb2p7XtgPt8BEbQtXyZqD
V3biRn0BXWg5pp0izEfuR6zhvP+wHoxleRxmiV47FklKaorUQ73QcepTFYX+
eWVuUrV9qPte9/6a2Rh2umXJPihphYCtQOygLwfG+yQ30yO7UT710HbLAzYW
v4lQPPTyOW5XiZZWE35UMyrkFD3KMdz71efoOeIPGbG2sQvj4BW1Q3NU/v/+
xlyvdrUZAWeG7xylU2hceXK92gMmfIefXzzmxcH/ABJd5io=
        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlWs81Ikax5FOpCyOppUiUo4G2crIbus3WWFIF2sdyrpt2Sgqd9WJnC0r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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41IsexifjdihuipTtNHU6LZRDISZ5J0tESiZaRXErXdGJulK2NtVN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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4lOkbRksKsynS2kqWTg6VU47t3QEVQsoxh3LqZFOxbVGRQglhpX5D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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk4VW0bxcncIEmlUqZCSAhRWEjSICISklSSuUkTOqTyGiJJhJIiKlKZ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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81GsbxrUelVeiaZE3Q0nZjy0KV05lqCyRkjjVUC+pkDinslW2ciqv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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4lAsbxqWNRLZOklAZOXNVHJIibnzKaRuiQmkXOpQ20k5pQsun+WwV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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk81GsbxmmjhUo6DUn2FopSKS0XUkfIUhgvWVJpeUVCKKR4oxKVFlIO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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k8VG0bVklCe6kkeyKylLcouWyVNgml175GWRNRUVJUUoSEIgotlCX7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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHs4lIkat6VSqRRNKekikiPpyCCTX6Eh9pTjhKQ0uReSGjQbS7qQS+4h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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVWlQk4cWRUWlbFJwBJ6AWKk1CFqbUgoqh8WlVFHEDUUQUCKKCqKyiY4F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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8ldkfVqQ0irGlRrokmlJUkmh6kJBQ2bONZMlWWt2mSEmFomRncn+D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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8VW0Xxg2RRpJHVE+RUkRSJ8l0FT0IlSRFiDKUjA1mQqZkSCQaJIRE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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlWk41Asbh1HidKxN2SItlDqIkiZLP7IUbUqRIg7q1DGhzKRjK0lFhQon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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs4lAkbxqdySotqOtpWipCIUGlTd4qSaDvKF8VOQjVsSzmW05ZcLdUY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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lekfxpWKjJZJi0z2FlFG6ITolhokjK2SsqQsjToY2UJDqoOULKkk
2SvE6RCHSFlysh7LEcfB1FR6jFDpN42K3zN/vNd7PdfzXs9z39/v53u/yu6+
dh5zxcTEUunz31tZcvm1YDMe5iac21r3K0GKnJX1xAs+OkYvTq4LIDA23TBy
y24A3qPi+35OJWgQttT61veBX2fL0mER3I3qKk6b7ofWLfcVJxIJMtiuC19l
FWJ9jI2V/QYCPV7vhZSiRhSEXp9bZ0Dw5d7SsOwPT2Hc5xOwSZdgqX7j6oQ1
jZDOrLNfQvf9D0bNVSrmI6qF4c0xI3AY1l2QN8ZH2uDRqJhgAj+i/GhQvBt4
PmHtdIHg6Ibgw/0tPTgnvbI68DjVw2zzv1RRCN54XFj2eoJlPtPzX7J6kMIo
LP/kSfAigM8eOt8Nk3t/V807RvBWOyaF1zeIy6VFp83LCGxUh3crHKuHvJzy
g/WmBEruzv3pB1rx+6KJg1+OEsj6xB6bNOdBKGWwMdia4MSBgTQuOHjzOPnO
d+pXznVbpIFSL/QUzvU53SLg3NY6ZBErgOX4h1WaaQROigrKF1lCjDeHcgKo
/qsOa9e9uyDADv27ph2hBKc8rrp2p3XBatf3fZZnCEYDX58/tEKA5yfHDwTT
tUWRGbNMrxesngHe6Wjan9djjNvMRGS38JhzVKne/fMbjAob8crizPJhCwLp
dNfsGe0GVP/vaKlwO0FQsrSl234BTBcv+TRxhUBkfsg3Z7oTo5w1xTaR1A+n
0OHE6wE8e6Jv+Rvtp+VUZSInvQ8q5PTkFi5dJ23fe315DW71Gfm2bSUI+VCr
1lpaBF8XpkKZGsGVnQkMDj8bveKxf3WvI5CUqlZd+CcPU3E+l7/tJBDT2Kpv
8aAW6g5dBVlUz2r9OdtlJ5/DxHFIxs2G+n/IYnSOdiNXzPi8ZwSBikz2IqVR
AdwuOr3dcZUgSTZmftvfXdDMCGNMUL0O7zZ+mZDn4Y9fi0kI5SVS9XvcjinK
p9Fz57Fy2i9W/quNYi3Q6ZHY6r2HgFehfsBsWSlCDL6Fm2oQ/JnRa8o4WI6/
0ysiiDrlNbYlOqJACOYJm5hrjwleRWTtaT3YhQW5F6y8DxP0iaeZIJwPwZWz
7I5Agtwp921qNt1getj8/P48wZNH4nukAx/ga/OqY6b0PPaz3WP+9wvhL8tU
v0v5SLqumj+3UwQnOXn99stUb+jwqfbkGxja/HqpCu2fVkYb2WiUDnvOgGwc
XYuGhDdjWpvwMbc5SHIXwWNnsdt6XfVoVQjcPEXraUgWPHNRFMJk/FH0Jg7l
ZXx2v/+bHpS94gxv8CLIPG5bLku6sSDITr/SlcB1UEnEyhFgZg5rfSWdX3ZP
U3mcAxfbDrg0/a5DoGn5TW7DbD/6NEoyH1cSbOK+TwnzacBobqJRCZ2H6/X3
g5e8b0XRqldHpi0JCqy3CS/f6kfE6mXZT+n3bvVLV7BXdcH7X41WNQfKp0Ja
h6W6EJmJZp7hdQRM7aSjHvcECG2o0fb2pnnwos57n1YHynd1xXjS+WXW7htv
aujGDxGGgj2nCdR2Xky8u6UE9nEG/ta0nvzpsbyZljtg1vune1C+XHp+qTH4
3AO9npeB+ZdoffvP9tnNa8L45yj7XQzqfyjemDe/GpZDm+bKaxMI3Q6LLhoN
QInNymckEyh8l9Gxau9Ho/GUiFlN86N692Ylz0YkJTh7B1FeQj+dLOh42YK1
wW/mGDoSSCwuveISxgc3c8yr047gvjBgNkqxCJ9u+n6vonkjnDlzXP6aAN83
b1ZYS/2oerD+lS8rggIRBuyj+4YBGpKRj5vg3a+acpLm7cfxsQ9xR3ox7vbC
P7aIYGvsvkcbPAew23b755k2gs91x+9xPPkYnqMzk+dO86nKK3Wz/BNInXuf
HGhI+XgyMmJ0aAgia2UJOQHBSOIvw3lrRFgqE3o4a5DAsdrRqXVFB+5z40Va
Jyify6PvtVjnwVReoptQPSHfCiVFfjVwudEV0qxHoGvakVjtU4UQ6doOjZ9p
/wwcOw+NZaG9UUfCcC1B6dOHAes7XiBiS1ilfDpBXMU4w0RPgCFB9B7fkwTm
H4NTa2af4H1qtKsN1ZfqWuGupfQQzlN2s50bqR+vgOvhGd1g1Ik8M2MIYkpU
BpMv3MTJ7LZjg5R3KZs3p3qdWsGd4B82d6Z5oZ768lvQHajHNRZdo/2eDo/2
KrboQfze2rYn8ZS3/FMPKg/ywZSOqHXYT3mRDjf+cWENqkZqjRtov7k/HO5X
kaiGlZ3hlgItOu82k9M6uU1gs36c0LCl/P+UE615LR+p84cS/qLnn1192Tyy
Swj7fxI/e6UQNOeke2jmCsGdr5nPpXnktK5ZPCNrAKdv/7ZwRSvBmbBvK/+J
50LRpCjs4CZaL/7lrzk+V1Ee53/sGvUjvZILC2shJgyWF1fRvLexXOu6MmQA
9ittZP6bh5ThsEgHGxEWFUixbtK8UvrX7CFDrhEarT+Y1u6g+nSlshw/3YOJ
pNWdjzQ/qjQkb0XmtWO/TOklEf2f+Q2WhleOFSDWaG9wPtUfGSVKKM5MxXXp
0BA5ev/ZHO07asYD6HWYnSdLeZ9nGa/91rEPbxYt8nIJo3rZZhyVZe1gR089
H6H5wJ+0CGcnv4BAMfrlDZqvfpaTn5KlHuKER7oim/JgXlt8cpETD2fk70fr
Un49tLMqbH/tRdGaXxTrg+j9ZgENbd0FsMpWbv6J8uVXVdL4l20/3qanlAbT
fGALCt/oqrZDcjhcrYTqjxSM+EnnM8FQNX63WoXOn3x8eNbxaqz9vGTTR3rf
l7LFvIaWVuQM1O+JO0KQnEcyGP0DUFm8kJ3RQfNIaVWTkzgPZoe+2m6l81hm
uuurmOAxzmro6X6l/X/n7qIUtLIXSWbBTO0sghnNULcH3C5k7Mz2e079RRKZ
t6LRJOhe7FyjSetl2CRRoff0GUrEPH6UoP+jqRrHL/4qXTAtyE6y/YNgzXqx
hKHuXuQ9rQ/4M4Pm9cSllANHspDZNEzZoHnoIBngbN6JqtuRLbM0//4PFpW5
fw==
        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4lF8bti8lW5K9ErKmJInqpkRRtiRpsYRIoQihUhFJkRRtsi9FiUL4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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk81Akfx6UtRTlaukyKx9qiw3pstY79KBmRZzto00ZEuRaNHYMnbQeJ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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81Ikbx6W01FYkhIqOte5Nh9piPpKQ2i41bFTywipnrhWt6KJWKtUi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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8Vfkbx5HKlEJJKZVQGgk1ki0fhaKhTF1mcH+Wsqa4lnbZUiZLibKM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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8le0ftjIqUUZSRlFUkhUSLkkoIynJyFtGpFdRkraM8kqRVIqEJElF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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs4lAkbxh1KiEhfh++LlkZ2VUKlFZNbhmpquppUvpR1qU1NZtIkX3yy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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlPk/1IsChi0l0YKKLEUlTs60neIYy3lVitOZJNGVi2SNIls10TIXN0vu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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4lGkbt1aRQ1FKW7SK/aKtTEUh+bGbWFHWtw7ZRBRFydYUlTSmnEZC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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHk8lG0bpVBEUZJCWVpEKpRQX0dUyhYisqSkIhWJSJRCliyJLJXySij7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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk81Ikbx6djXRVSIlfSUE1SSbRRHyVif7qkiBKzylSODildbKdKsnak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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs4lIsWxp1oUzJpF5VuQy6ljodKQ9ErQkWETeXsXdJOJSFUpLBLGqHk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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk4lWkYxs9EZgqFTBlR1pHKLltxN4VMkqYoYSypcVpsgyEKqUS5yJYa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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2kglF0bFtlCCaHyFhJKRVIp6kJlp1VJhYpSEalok15KKGUrLSKSN0t2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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs81NsaxhHV0Y1K9xwabEk3l8n9mUQ4aSiS20nbVuTkVlEpFPbOtSSh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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXtczAkXxlNCq9XERFHoXrK6WZTVMxHFKKl4c6ntMkS6UaLpslGiMFJ5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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVmk8VWkYV6OSDJpI2rex71kK46+UhGxTkhQVkmylhbKV0mKmhbqksaSr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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8lW8ftiorEorISEZCFEJykVmUFKVSRqU6pSSKSFaiYf1ISdKyCiUy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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs01Akbx6eWqUW6Ibe2ofctuZSlhPAtilJvzUZuKZfkdaRUi2Vri5RL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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVHk41IsankoljSKRki6SLJ1Li5S4r9DmkRwhlQctTlkaREQy1FBapBCn
CKWyHVuWSLITI2NmzBimwaw/y41bKictd84f3/M+3/N8/3zvpnsyyMV3PolE
uiiff7Du0mb9jbWDaGUpX45wF2HpE8qJWN02+Dg+i/sVKkOyjxmh6d0Ed6+b
rsN1UjzateH9+koOEjTyLb/RhPCihPg5c9lQLlZV8FsoQp3Smn8tFjTC8+20
+/cUGcJ311ADptsQP8JtSuFLcb37k3XVABdikkrnrYpRRCzw0krPZiDj1EDj
+TYJyr+vPKI1x0KmV6jyJT0xGmdqCVddNh4f+Gx9pUUIs7Q0zUPDL5E/me7s
VSPDmWPplKsJfchhuIg/FkgQO5vltDuOgXQVZXrdgARKq+NDKWu4iLHLpK4Y
FMFn24vWV1uY0P/fmO06qgQ5VT9+z5n3Djv4am8cLSXQtrbNj7Fn4q8W22xu
uRg2kgql31Ir4OqRsiHPhYBmqXaVwSQX7DjaEZLrKJItwg8d9i7AxyzD2fXx
BBqyH5uXZA2g/fuyVV/txdi514Cz1rUKJa7stEAjAs4HuxM9tfpw6XRGp+CV
CLGC4BnTmR58oPTc/pAv/zdqu5XpvDQcFGdXvhslkLzocVdiRCXYc3dI3nMy
jBsM2fgW9SFvaj7ZXEeMykUXj457dYHGdErwS5CCpO4WvWm4BoZOTnvfahP4
MK6iS97YiqQ1VV81w6QIntN6uyUqG6lq27nODALTyzZtvRU0gHP9S0jPA0eh
Y3I2KuVBIVZ3ROVaxhGwdAxp6Algodime/m18yIY+9Z+N7ASoOnGYfvmUhFy
mhIXdn16jLoY3ZeLyuT3lxspLtX9iNrsb6p2XogpvtENUWEOmHccgo62EbB2
Tw/IiadjaXnk5rxaKcgXZv/K8uPhb+/T4woYhSa1rD7pcxMeLNT2Dy6QYlmg
TfQXJQYc795UUGsTY/bWiC0z6AmK11VPcysJ1KeG6Vx7w8RtE+cpxwwJ+OU7
SUK7DjDcXf7T+W8pUu3e1dEDuLD2ONfdPzwKsttRv4O2/VjZXh+vOiTEkPrJ
d952TJCTurgStgiaRyPDLSJeI67p8THF4zJ03ttlz1pXh1Ze43DEdXkeMqyt
6U5VcJcK9l5VJRA7prc2hfIcrw6eDi6OJWAWw1XeaPoU4fPoD6IyCHj8Ug1N
SeOgxFx7/dqtQtj8fj9Jl3Yf65+yhA58Av47vqi9uM8D20BzenP3KDrvPFtJ
c+fD+Jm7k3LTMAxD+RoetCYwvScrJRdk6Nq2b8IqvBXeyk2HKCFSXHyunsfq
KcD9EHLDrkA5/wqDRWrquaD/9D1DbSFww8Rz1L/6JQLpoTt9lAhQO9xWGff0
488SK5r5NxGm3Wx5SY11WBD8dDJMIkO0qXWoGasLmpwFOWHnpbh69kPRRrn+
vLQrPKNgMdamV75cd4cN8i/Fjmk/IVS4moqZ9XSoyGZWeSlIUMLLSBovaoa+
0G7hbUKKs1zOl94P9ZgrZ2xSCpNBbKGqPFRcAecqgxTyIQIHAquMHNb1Qi9x
YemxVRJceuqmbRzMheqK6hZbByH4P1+kOI01gpE4feHwIxlu39iyi+XJgFNk
gee5BgketOu/2RHKQTs3LKi1YRSmm9UT7duYcLHov5zZL8L3T8Yacx502KdH
lgfqSdGYQqv46dyARzyT7JB6GcwGypb0OdPBY5SmvBGL4cX/81VhCBu98c0+
TDURVOw9Jcmr2/CwwSrsuIEUzcsjc91cO+Bbp6I3KN8dC4fXhGf0414COVVd
IEQO21yzUVANF3vTJKtWGbb779HVi24FW+S9OFmuX6zBgYi4//Kw9OTSYK3P
IrSMtN/dJ2JjwtLlbH+UPP9fbh7ju76GlSuH1RAowx+GpGfbbvaAyTFOXtEt
QVmmW6FwexEGNWKXUGgErosU4+3VS2DwgPrwVCQB4u2evjkvDii1HdFHSELs
N59Zbzi/HiYT+uM+b2XQ0T9bo368D6d7E8aufhJjPNfI4kcbCx4BCW90w0Uo
IzsIcgcrcVz/29PqrQTseac6k/sHERLN3/Y6bgQ69Phw0Iox6/4j4Incb2af
xvY8VGyCYtCSU5bJMswaUkiTSS9AO535hDotg+JzamsYqxaCaJwh58jAySqQ
xs0xUNKVOvHHlLyvH3rPw2Qusko/Sy83EBDk9hSOBL9Apv/dTQItAjkrovZT
e7Jg7ntN4xKLwP4NfVND+16hILfr1hBThhuCy7z4Cj6uBZS5xnwbwRmdVRu/
Sun4OWH56EeQFJHmu51OOgxiWcXRYQ9CCEfSe7ahcy+KWz52Gb2WYJeGXZHn
RDtoIuNCX7IMX176Vtue70PA1eZI8zwJJseMLKiNvZjSsznxI0uCz7pF+le6
e7FmT/zdZnkf+fw2M1TDfY88F9NflfcEMFv8EWlW0ciXECFBy8ag8p4ccsLp
Odr/Lmw5eIeAwvKO2gYOH8W6viyzGBH+D3gXz6g=
        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4lGkfHiWlE2lVn7QSOa2zaqm4R+QQaUitSoxDSl9lWSySQxJaK0lK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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk41O0bxSVpIREVStZkq4SE1FEkskVRSUJIZektihZLi5Q1JEvZKjtJ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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHs41eka3WkfOiWXMzqEhMooUj0uyWVWDarBRGVKqZRBRigMI0Vuwx4M
oamkJBsxoXRI7RA7KSl7Y7tvt3L7XZBNbslzfvPH97x/fO/zrvey1tJyO3/I
Q4rFYoUw758Y0R0mWebzFi3nQ6cfqlD4LTYFq63rYWFrUmE2RKKwJz5657MX
0Gk4OXLYn4TpoL6lB6saB9c37wixJRFR417740guWknvDNVbBDTPNWfkdggR
XqeoPZpIQV9T4m8b1IAUqe3tt2kSmtEhbK3/CJC6VcV/KY1CtjF3x1ljEeTy
bdz+MKXgqKX9YXxzJfYq8NSjjZn69guePV55CDVOHtH+i4Dy/eLvm7d0InGd
QkVMPo3SiP16M2lVKJy3uHrxNInd1UMuyRsKcG21+g8N2QT8rOrqM7vbMFNl
oeSwROHNXoMTAu82jKsnO/j70chvMjrxzoYPz+aP61fdJsHK0j1ah3BoJlX4
qBoT2Hc7+k2CeSuON0z37txFo3pfrVlSdyO2/ipT9CicwgvLz4qvczrwUke/
ZLiKxtGSPqOPCh04q2x7JdKeyWffsexazsWMs3XprxEE3OnZLZadedD+wvVf
SiKQ1rTK8178Q7hLahcCHxE4ZLleRVexCX26N9WXeVKQfvgy2cSvC99NRRq0
qo4hpMR7ccWmRlxVtlfY40VBJ8Xysc10BS67O+z/04rEXNOmxY1KAiRVHjM8
EUvh8pljoyZzfHyqdUrm3iGR4hQ4mpffCb+YF4qRKTRG6XCVic+NyCUjC9N/
orA/dyHy56xKeBZaqfHsSLwtiDtSPCaAUc2o4eC3FJyvxqTZcbgYtzQZvBJP
QKD12L7QrAn5o2stWJEUWCuIsAGfG3iteZJNujJ86GWzfE2EkG6YKDtTT+HK
39JV+i4CHOPkkf+7T+FC4oJ9cehzpAQodsmZkhDNZqs2Svjo5SWF/pRLwkiO
n+1W2oEzDjG9Ub40hMunq07Od+OUtEXt8wNj4CWJvwzcaMEfH3/rHVtFg8Vd
Vc/Z5ofRS31JL/QIvFHdezZsWoBfQtLoBTUK/T/ujFgnEcHI2+qtki0NsdNA
QuLmNryYmvDvqqNwq7Xsu8N1ndglE16hPPUP3rtLG6J7sLFGu1PPlMb8vzQa
xVPNULdLUCrTYvjjustarVwIo/608O+fUmjrZ+VoTYhxSTPQe91dGlGS7FsW
vj2onWgcSs+i0XNngpayEkOqwofvEEUja+ZSUuWnTHiVDih/E0DAaagz+7Vh
O3LvTXTU8Wiwl0lmgxXeQW2rf+1RNoV8H4/w9sx6vGFXpMUukAhx8eYaBNch
wq34z/JaRi8yw74DVo+ZvehH2YsI7FZypNMD70Dq+MVrfF8CLFGNn8L9dxgM
cWiRc6agktn+QMIug1wvfW5yjPkXZNqQLZkA21gy4E9gVYFbybXP3SgsL70e
rzGGlQ0G/NnUp8g2NX5oLUtiVCg7tKOiGbP9W03GRimsKDldzqkTQ8Uu+JWV
F42Vjx8NqLW+guxpHfW10yR48Qtfa962Y3C5a9d7EcMniXOiyYFnWPKSScqS
I+F406Qr1iAHn/6rIXWGQ8DilV68OF2IsqUTiwN6FMyCx6KTJkU4ov5eOmIn
jbA9uqOG8UIsu3DZozKMgsRoMW7t9naM37J2LHWjwbnrnoHPNdAVNZM1kSTW
wCnAV6ETv7BPTgYx+pe6ObjXZU8HdIY2uCcm0/j3XrVC6mE53lNnMianCSh4
vM89+qEJG4ecNzhmMPyWNkldnDsNjrmddcS3TH/GypsT2trQ4HFP9Qoz7+bO
Cyun5F9CEvDF+CvjRz49wek+wyLItnJSNcsp3J67YM0v5cPC7PzV1VwSHI2c
qS1SDQimrPebWTH6u34p3LC7DKnKnfaDHwhY69noaFZUQyX5apGOJ+NvUmkP
Auk8aJieqvg9jcDca4OR9xb5KH8wJpK5R0DFdz5Ief9T/CUWms5uIiEWLrk+
uP8GT+YGA0IFDJ6DzZHq21WYMtxuP3iQRGZUyIE1nFZ89bHz0npA4/pperzv
mQhFn7q1ArfT0DI8t2WxQYj4yzb2lS4UTsrPjMxsa8Piwq6ZonEKXn2yxN01
bYjK0RH8wMzP2c0vlt1dhuHtaU/MCQJFxxyMvML54Ml5BrEPMfiZuryVLD6c
v1kX18Pcw6dwblmqUjXkuv0Tm/eRcHfSHDfyaoPrl6OtcVwa8ZVCuxKIcUd8
kMM1pOFsq3zj0R4+al20I++GkRCGxcqXhhdAVdi9/FAmgSyCP0VMleDJTQ3e
3X4CEUdi5B0VoyE3WXgc5gQ2cO7V6BwQQOFwVbv+Ngql+66sTtjMR4aq1/lT
viQ6nh135kWWQ8ksaAlsxk9FNwMX8kowL3/ZiSck8Hx4uH0yrgVf/Or7JVEU
rAu3xpTHNsB1zJmr7UBBwS/V1dy5CSeaLl5P8abADv659cns3zASPVvec42A
2C0d3PwCmPOa1z6/QeD/dIXXOQ==
        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwV0ns41IkCxnEilYg0i42URnsUh6IaWbySTaRU5CiXxMjqiKldl4q05FaS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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns8lGkbFrX6pFo5VFspGjnUJqXC0uXUtg4VYlFSGFbWKU2SNmyf6IBK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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lG0bxsfaJmlHKZKlEHqjz9aJJqmUkvJKSaKIkC0pJVulyFpaqSTZ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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHk81YkWv9ainrIWsmZCY+u5Eq/mqyJKqzUlyYRKtFBhjBpUejzRs001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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVHk81IsenfCylIkaLYr2RBcVTxLOJVeiFekW2ZJKvDyp5LlItOuNLKlc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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs81XcYFjlZGGpZzcbc5pKjDjYleeREOajDypRrSoSypgyNpCmidnaK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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k0le/XxsmYJEqGhEJmGdIoXRJJpVGGSChRyVxKkkT5IkkqzURIQuYf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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHk41IkbZ9JGp/A4trT0K2xajVIq8qGwJVKZWrTl6nJkKxTWasK0EjmS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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk8lIsexicSKkunU7QcW8rS8im0qPQoQqFsFY66klAJLeKgMZY0FS6h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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lGsUx91WypYtpUWSUrJd1aD8qMm1hBvlJkIlJG03l0iFlKUoshVK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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8lV0bxSVlaCBUpqQSMiWPRIYVmR8iKqFMqTShCU2mIkpSFE8klRAy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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk81Akfx0e0K8s8T0KSowgdylE5Eh8Wmx4NilGeVBOFTmVD55O0HXLk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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk01Asbx+eixRZZrriVZOqN0qIo19XX6SoJQ643I7J043aj0I1GKm1v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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lWkYvRpt2ktNZUQlkX1r0M2RLXVlT4ayDF2SIlsxXUuWImWdyhJF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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2kgVX0XxUsSESpJSJlLJaVJ1FJPiTTIg0qSJBHFE8qQTKVUMpWUzAqh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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs8lAkXx90qJKY2idB9aCuljReln8rqIpKkUnqlXCptrpOErHdWVKx7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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk41Isax0VhSkWLJXK7dORxypmiopq+usVVVIaOmyWFLEci0mTJJFqm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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns8lOkbxic698tGshIlCqvk2CaHLlkJSXTYcdqsipzKuXLID7E2VIrI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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lf8bxlFZZWREUoQiqRTJKJdKaWeFFqlUlJIKfZOE0CBZGSmrSEKi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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs01GkYx1G5VzZsU1GKSqXUaCtt+rZJShkkKQpdFBHWPV1W28WEkGYl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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVknk4lIkDxwexSkWSbI1MZJpUjmptOfoWunTpUKlYbCqjEIlKS2pRj40y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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs41PkblVq7P22a0kWSRFcUm4oKRy4TliglFKFCRCorhAipDbHJpVxj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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k4lG0bpiypNwlv4RVCklSiRZZO0aJQSKIkiaJSkiUlkaVCCBVSSRRl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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHs41AkXllQiSZNqJ0pFiG2sJN28FNFFhEqFbipZIlvr0kzqG5awK5ek
m5DFRkKI4SP3cRk0MzQiURP9LmKF9UXa+f44z/njPM855z3nfd/Vp30dz8rL
yckFyuL/WW+lfglvpAik1Mny4XsCec3ZrPJradgktB7edJVAHM8t3ehYO8xY
T1SG91EoN5yqnHQpQ2Jzs+O2LSRaHDb072CV4PN2c/YudRIO1xrV7kfkIEPP
+Ku0gMD1twNvzI5VYacPz1mQReLzxB8+Rtx2yMc8tniQRkEjaV2I5jkRciSU
jeEHChb7HK3WzlzHGpu+Ay82Eygsv9wSZCfE8RseQaPTFPRmNL8ob6zH6n8O
J4a1k/Aw/6AcrC1A/NhrReZuCloB+yfoOAlcrw1XRGrSaBfpb2WdKsLQ6bl2
PcMEohVLJkzZQlz0ktdZUkZBvtQoMTqmDm90pqa980nksSeeJFrUI4URcuHh
YxIazY84fQ118J4UTewVkrjDqiit7ivFpAcV/lKGv9X4YGHq8R7Mcxr1/JZG
I7nN0O3bmiqM/HyXcciWRPp85vdZF5oxc8WMqWVOoSmr7CfjeCHKtnqzYhfS
cF3UddN4pgmOo+LSo4sonI/qGH8cLoT0ffoIU1b/cCvLiHulBufGo3L9w0j4
8Td4carqEfDA67e5ZSTq5qefH7Z+jXJPlzGtCQr8eatE7MgChI8/qj85SGCh
ynd7XX4Vtj3XvaDpRUL+jJJirZsIWT8Wn5F8oWCQ6sPR/d6FwOY+ETuCxqLa
/0yqJGSB8djglXkaAcZMaIJFiBjq7fOX59pRSOp0N94nzYAtq0GtKZ7AGmma
Zw+rEZTZ4oemS2X/uzQ9a9QyFrW9Tard9gQKFlQHqvm2IGzoWN1qPwrJ3MFv
qxreQBprenWFM42w+9I4hm4xKuSmLPgfCYQG3YV0txgOvQ/yNprQKOfEvevk
dCDPg51cNERBW2/Kisqpgd+4lCfwJXFPU3mOjnwntqxcLqAUaXiUKOTfXt8L
pgkDJ92GcDO0cTBIWYiJPt2IsRgKy0/4Zl/TFkHo+kOupQ4Nw+aQz8dKazDm
E65yq5KEq9kZP6cdhShZbNRwR3Y/ixCXEOtD0Vgz20KavIuAkUmzvM6sfGwS
pGWIqgg4tGXGNOoVIXz/6KLvowT66paGBKSIkVhobiJaRsPB1bvfbfNdTP/Y
8/SlG4EDJVapcq5vYO/42lZwg4ag6yf1orZ2/HyrIDDjBwp5JkdPHtn7CnHJ
HYOcMQrtK7kHX/aLsUQy+7nGNhp+xYOhvy3jQdnIsrjbhESDzdy7AdrdmNYv
eU5k0dg5OqDxWrkTkwZt7hP7aGhNWwmY927AdlycdMCMwNMVv+6aMexFsYKC
elQ4jS/xb2/4+LWCyawMNp4hkZKvf8RGLQ+Lz/3xZF0Rgc+zXn2x5bSAG9p/
3c+RQo3SggV7Ijpg3b+prkiBxqf0gk42oxXpOY/8e9UofHRI1YwTvwZ/z7ey
OWwaWQbxrjseCHEvWGn8+AAFwYu0qubpBizldmoqSUh4vgtmHs+uRCGTv1Hk
T2LAzv9/Vr1CrDQLIb1k/0n2rXX2Mq9Ggqvwpj6bxIrnBs+sJiQwnWs/ckqG
bwG/w3467QksenwCmp4R+BTg3DhSxccJ1cjB1A4Sl89nRlxQeoHhIr/Mv5RI
sD8NeMZk86CuV8wotSYR+E5r/7BWNxR6U6KIjUNoV2xh13Bl889XHPkzmYLD
+rZixYHn4N7xiSYoAuJjT3Jc9/bAtsFli7rhECJuX1zyXaUCadIY3h5LEk6c
1ljeUQnePh3k/25PY/vXWAmvqgHGqrh4eiUFhbPJ8e6nmsF+N5HozqSwnbKL
TIiXwNNpq4G9Bg1d0ewOoaQJzt4d2aNTJPqcSH1mQTXWc89q/OIs81fJRQ3v
2UIwHKRxPlkUpLbi7kJGDUIvtXYsfETCqOd9xrOgGExNORcr2xLwOHIvdyam
C2cMtQ2U62X8Uawe1LjRgAq28eGecpk/BdX+ffplN3w/meaKx2mM/PdF8syv
CTj4+z97+p1lfI4cj+dy/sRXFalPfTQB57Cp4VNHO6G+9N4vjcGyfvuZ3N0D
TbC/sK42dxeFkeqdqcRkKoqzdS7f5sj0oSX++5JtCmyNWhayrxCQyzjhs8aO
g0BWWqzTJgK8bP/eAC0J5qjuNLCU6WEgs3vZga4u3IwY+pLbQiN/1KzKtL8R
Lf41Q4INFBYlydmwoqrhNWko6jhJYnZk5v7V/dXovWuxyymaxMjWiPTjH/Lh
EqcnsGmS7T/XpWJM9xUO71mdoyehwLvIjz27qh3beVRpzFkKKXydEF4CD7ob
gic1VUloXfpo7m8dhcokUXCTlcy/5l0lC0slMPpr8/sMdxp5sWvPZ0o6wUyY
5/5Um0bGjnlLDj0TgvfK49BTBg0T+bDcc5VtyHP1ZIecpsC0v5nbfe4NXjCk
a1tPyPxu9/0s1rYe+C1ru1Oxk8a/AKjZUw==
        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs41AkXx2exUqHRjSQhZbeyKFoVvrVpFkXILZWKLhQGrVCyI0uyVGTK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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs4lOkfxpGSpIRliZakpJTDpHaW7g5EqBxL61QitXIosrId1ZJkS1sq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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lt8fxpEGRUKSrCghIZGUXNJQNIRKZVVIyMrXLlrSIKJSUVQayMpK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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlH041GkXx2VNPSkZlcdUZDSS3uRliFW+JXrxmtekbEhMm4gkCVtttaVC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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81Ikbx8dR2c7hlSIqVlklP4qSko8zJLs5VyUJHX4VQ1JjN2m1jEQ2
hVWRDpVQUyOFNmcME2MwZgya4zuHI21Eh+s3vz+e1/PH88fz/rw+z2EYEul9
WJVEIp1Vxv9zwrd05/iRTDCNM7SPiBWgnNrsNv9bNYx8jV2PaMtBouprNXPe
4SGzrerAJwK0DZ47XVaykXl8UcE7JgF9T466yeZORJ+yi9FqJdBz2t7lzNdq
JLses3TeKkdb0Z2Vb+TvoOHwRw5xSopr7tqJ9TIOOrcUKCZuSUCOLXa/N90I
58KQ3+/8IwM3fsBPs+kx1tDa65efUMB2gfmuaRMBHPMSQmlhQrQa/dwxksyB
amrBG6NKKb7bqobkH6Gj2sYvdMhUgWM5g/O8pA2ISt2jp1CTw57oOde7k4G8
jxELyVNKPaK+sMLMSphRHY03BMpBWCxpmIksg9X1M6uzvsrhuzo8RvcQEwYu
1QYXmFLsUtXiUfV68GhR+o2fLhOwM3gxe+8JF88KHkz8fYWAwbXBN+eykxAU
L9JTIw0ga06sK/ELFxmvEvJPXiQQv8pdbJbfAcGZMPOl0RJQ6Zeft+zlgeef
bdnULoK3S+rTw3f5mNJ0s4nIlsBE5GXklUjHvKDHlgxrBT6frP97zVw22DNS
2k9HCRC1X/sDaWxoOR39MvCcQG99w9ilSj78iU3vtueKIS+IOalPdOOpoM+n
1kCMDIX+AebFJrSlq3mPsqSotvVPS/TnIc/IWk23VAT1Zl0Ot7UO6tUpfvfH
ZDh7Y2FervQ55ub6uyfaKnDhSFqobIoHRYu5kfpqCbZmTqvN6lShRyW+zKxZ
joeLnpe9Kq6DfePVxKNkOar909ga6vXYdMGapOcuxx9vyRY53FbktNylzkoJ
dJYKJV5rOnGr8abs6isxPpYOmr4c6gIvptA8KZvA2/1U2i82HVhvfGOHIILA
3OYbo1MvOCj3td0+EiNBKafJty2iEV4k6xq7WBksWlTSt5V04p7qhkfMNgKF
mvPuX+/sxm8vWcET0WIkdD18kfKMhmEX1+L9kwqQBqMPpja2o88xQRwSTkBn
spG0PLUWW9Ko+iX6Sv5r5HKirxf7ZD9wmq9IcHsO+0nv788Q92mZiY2nAiyB
h/vuvi6of3xfksoXY8MK8XFhWRt8NaW1K/sJeLv6CdWC+pFiuTQ76Xg/SBZb
T0++sMd/PIdykg0GcJcxY1S0uBO7WAFBaeFSGLzyDtffX4eEz6En8j2V/Z0i
7Si+hbDPiqR/yVagiPFwflEFH1UOy2aGGRIEL1L5NdIsE7GZl+w2EEo9rja5
Sf1VoI9+m2/wRo6bxXsGvT4144jam1gfJymE0uAUVUYLBmc7173dIgVbn+9E
j2NDI8Nez5lGoEKUxKQECzBO6Q+IWyxEwDaVqFEVDirKCinrraXQvzL/rsdQ
B+KyjIV310mQ0TnybenxUsQ7nY4O9FGgQvCeqU3pwjZTYzWrdAkopow8v2oe
CtwOR4//KYL9/uOUnVQeVjhEvdzTK0JY3aWM8vYuhGZ1C5kHCNgvKeuNyU3D
8PzwCWulPyEDD1Z/iKvBZE1rAN9PjiYncn3H47dw/CvOMFNFjsNJP7IyCnig
tGQ6HwuTwGN36m2qnI/yd29DY0bFmL3sHdOQ9AwOk3wfL12Fco5r/CbKWrD4
hHv5uhkprkj7dPzcO2Fv9rEyIk3J+/qBzrKQZuR9OUuqUda5N8zoLmu5ECWs
9QhnSzC1ezN3dvMrsDQXXG6skSPQRfT5N28O/uvjsGAtTQJ7E+Oo7SsuISKH
vHTHdwXWHI7TvVBZg+SJ1XNZDBlUdYqZdkMNSDmxbzF9lww9zQ5WfzbwcDLc
xsfxsQQWRnc2CZc8ATE2epG8X+knSSCee2IePhs2dAoMB5AirC0NHOBi4GkU
62y3GFtitK0+LBdA9cOK2/2xSj53j2ucQzxYmQeyHlmLcM/71/fxlSyUF3r6
CRxlCAjUGG563IIfi7Ra9FSkUNfZ51/hIIDW65xDzeFCmKwysaiZ6AbZ16JZ
iyRG0tq9RdVmPASpdOh6gQB5wU7GM1IdnJv4XyRTMmjYyXasP9eBNk0vS5au
BMWk4m1Rkg6wCKsPRt+U+/REe6ZtEQduo9mj1VUSaG8kSkJLunDKJOF76xMJ
Hh5yy2PfZ+DnMI+0r5NyLBwzDOa112F93Vgkba8ce8jZUeazXOxlTHf3jhDI
SQzjDtN7QU4uDKcHS7DxKqpuT7NxnshymN5EYM1Fjawfyu8gP9iBbvxagZu0
YxGtWwVwTV7wV2WCEPmFmpkHm/mwLdSbc2dcjH9YQ13Dpj1YrJMzmOEvwb9a
Y1+utzfhkk6UZJyjvH+fqRTOunaMU48F/atGYOvITUdjERNU9aPu55OkCDbV
Lz3XX4KUg9Y6k3HK/3TrvHn1GBffl1tu1COLUWvasv19MhfqigM6ucp/OV4k
d9vkx0fR+KpU4Solf7pNQMWWblDIA7drX4vxP6MTzuM=
        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4FOoXnqIi41rrqpBQqKhuaCw5RCUUt8bSgkISWSpbZMlSEl2pRvFz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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lG0bxtEqRKWShErqLSRtlJyFigiVRCIpkra3LAlFlFRSCNkVSpJ9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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lAsXx11rSSlxEclUN90sKbJU+ml534Q2KWZIknJLljbiluwp3ZoW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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHlYzAsXx0f0Std6heJqIS0aRV1p45tKi0S0aiFctNfFpSKKUjIqLSRL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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs41HkbxicqZFepXqfNS1LRhnKKqDuymy1RYhyKSFJKB+lAKqV6lW0v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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3dcze0fxosQxROKNIyKJ0RRkpIrCSEJRULDyCqSEA0VLZJKU9EQWk+7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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHk01IsflchSSjslpsUSktKjLO8qJUWSlifqKWnQsxQqPZIkJru8ymR5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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk3k81Ikbx0fajlV2RkUNWpKyLWHUph/1aTdXIXJMlJZsihQ1Ua5Cp0Sm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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4ldkfV4mKEoO0mbpE9nVkmz6SIiFuipSfG8kwqilbRYXsWmhjohIV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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8le0bR5KkQSJJIZVViUjWl0hkpEi9Klmh0kKhVCplpKIor4zMhpE9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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs8lGkbx+elqHdVvKXXpx2HVMNIoqQ35Bc6IEWSVSYrNhG2SG0OeYmK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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGk41AsbxmUJJVSWqYSO1iMhlMTck5pOJAmlLCklCo0UzYlQJ6FyjqXS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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs8lNkbt7OSlBZFpdINIUKY+mX0dYmkm4TcKrKmJCG7NZQhymIrXW1u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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8VW0bxUVpkFIopUQJUUIqaVhSKUOUzJVkqmgOIURpRCQiJPNUmUKm
ZHbMh2Me4kHO3oeiQUXivd9P57e/7Huf617XWv8lYXlF34abi4vLfA4X1/9/
mS9XujsotqNGas813RcjCJSvOSi8sR2Zru9XCtUNI/f6/h8+WSycTE1XnPlO
IWtukqLV7Q7czNp9d4/9CIQq9+l6WnUj9vydyUUbOdg5na7orNqDvw9i5oWY
U/A2nYiZ11sDS/GXBRG/KJwP1pHah2KccnHJ0cykMTOnrqbVmwHergDl5fYU
forfLpF/2wBrkbEE/t80dnRb1IbqN8NWtF1yaQgNNZUXDQpvMxE19jaFT5ZG
zd/Ba95baxDU0je17CoFcY5qVeLWSJiuVf4ntYXG1ryly27qtGJsMu2Ktdcw
zPScFrvv6IR3kHGHlukwGMKfNLh/M0FVK4d9D+bgz4V7/5pPp0N+2Qov2UM0
ZJr3a2SKVyH0nrb4KV0aoUePz/O9xkLMCXfxviscBH6zF5U0KcVFo9Fuv1c0
+j8/o7+UtWHprXc6haJsJOl7+BjJZYOXbVfTNkAhyeytU10OC+YDk43dfYMY
1/laJBP1HiNn+5eM/0dBaN8Di8aqZpi7Jyja/hyGmudK9+0n0+DI82AmcYrM
T7+spb2aBSPVr5KrRDm4wpOXemkNE5Paj+RPZdNIP1aftD0jCr4b7bOslGis
Xyg8ZNjZBD+Nf7tPyg5jQefK5dYvm7A6I1urVGAEzMD/9kz4FcEw3XBoZg0N
Kaq618GpCcOrLqWJFVEYYf5b8E6sBXpL8iqspilwMcMpUZcCHOl/WCTeQkFn
lcxc6QPt4Kl+u2/ajIJAuE5Ir3IOzH6Xxi+WouH5MFlsg9ZD5PqnLxQXp7Em
wiZrTl4pVLTDq/LbKJSWfJZo6c/CYiFBvT3kvtIn9kdcL6uFzcVH2hLvOIjq
3nZ7/cpaFElf2Of7hIaVY2zNhH4XQmTMmjZJclCipyeTYdwNvafPNvPt4kBm
S67jneiPEGVIu9UY0ziVr6LE0emCQv+3ZIWPNP5MX9gpxt2IoTe7qpLHKKjm
mRjHx3Vjh8Ch5z8d2IgSipmJjyyBU4wm5/UX8n/fSG4wcPfDs/lfCo+Q7xdZ
d0+ps5aBQH+VnskIGnVLP87ruNqMBTWHVh3eQsH63GrubttW3D3B7E4XonB1
fMdNu+PRmJlh2fko0siPtJewNG7F95+5WUIGI7CcYajPFrOgu/Zaf5objRTd
wLbotW24uFnzgWgFhV99ml683iVYp8v5PVVNYWrnieCPZ1hwvsc7wlU2DAXf
l5Z3skowMJsxIHaSxlS/oaX55xo8Pr3q9S9XChGntf6MKjOx7I9a+LIHFBiC
xlxfGfWYmD4anpJKw6SEs4KV8BFBhf787kI0Bgxlhn4rspAwectSYxcbHWsn
ZoQvFOMzo1S1ZDvZB3WxmKKvLYiJ2f2uQWsEOnd2B/6+zQRvQqj6aRsaCiv8
HnEC0iFwKsHnMA+Noij34Gv+TIhHnZDnfkRBTUqOTa3yg5Kifvgw0YfAIl22
xoV2xJ+b0o+1o1AXSv/JOFmPCHvxzCY1GhFGd45cDGxA2NlS86TdNGz5rYf5
5JmIqo3zLtpFznsZbjx7sw07PL6b2fOS53vmV5oiU7EjWn1MUptGpW0sqzm6
C9k3kn2ZZN6eC1oERJ88xqknupwIcp/nmbmz0caFuDO8iX48h4YFd2RJ/hAD
rjntwUwyT5WT1VcEEtqQ8DZNM/kGjaED26zarDJhG5ca3qZMQygjNPna9XL0
SGcL1Gyl4dx/fNv3LQzU9WtFZOwgfnHHT21TezX+2/vys1sjDfHjP9JsHjNQ
riJjOaHFgYOprtork3L0761IvGlB9BnOP3uoqAm5r01+3o8h+nvSeWSLog+6
zlXJDZL9PC+4FXcVS6DBOhixzZ7GaLvmj5cWTeB3M/j16SyFAIV645zfzah4
t/iQbAHxy7VPQys0gzDY1fb5oCQNUdNz2Xt3tsFfhGtz0F0acRZtjrUNOThX
4eg+pUejcb9iz6R0M+7svhUrTFNoCSzR6Z6pg2vY7N/512l09My/EKZUgZST
Yev5LChcszmq0nCyB6PWwkc0u2moJ0nQdbtaIX+4+j3Tng1xWmDFIZ4yiKix
U80MaTip7J3tduiAsopcyFZ1GsoyOpJtG9rQ+6S4xucJhQHXoAmu5lKoz829
oZVAo3cde8RbhYUwNc4LsUlyvjXXP+eL9WD8Kv210IaNKWrFYp41PciN22K1
+iUNhhgdInWcCaHl67k1VnNwzD9YfTVPHi6mJzzl7KXhb5UXK7W5EoVRtrxl
z2gs+uB4KmJXN67unxDbKcaBYULUs86zpXih/l2O34HoSdXj+5fnCTgfn2J+
jOjt8XDw1rqHTQiPHAgukqPhcPaC5H9C3ej/HrvGyWYQkn+99sOoDJaPw7y4
XtOYK36sYdKoDtc+ZyqOlNEI2LRRYsyIiZ7GuOos8r5f6eu7b7u14qLkldCC
FA5Yc4/bGHvnYTz+B9PtMo3rfHvEz67oQdWY3dgXLQqU7/devrAGiNVZsu96
cBDS579voW4XxCRSNwrXEP8yyLhsbBCOrLHImU2iNIoXCuvVjpTDPvqi5FOy
36eq2OtdXTvhKHzHNHmWA+/0cC/1oXoUhjWtWJ1P9BiyYk6PTiFK/horc89S
MIlcyvVTuhFmQyMjuRtpSOzp2vosuAt6Vpma7kIjOMjiTVm8pwu5LrZJfxOG
ERX4YZEeOjDx6FZByEoK+xR+7UV/J1Y3uySaVLLRsP9dMqOnCzqFZj+qTIbx
hPuis0VUK850Sx0+3k7hqamp9yeHHkT6yPp0XWOja/OW2MUzvZh+Ubwvbd0I
+nd5jd4XeQ81Eb7ISRMaXPM8d8m0luFNsPYig60Upsd2mlrUlMJjpfbG4T9s
HBAdPKawvgUmzbr15npsCPi7nTt3KAbp91r/8agSf0pjTEtzCF8w7E5slqXg
tGDjpytKddjESTPQYtKIchp7P9EWig5+9t4dxC8a4i4tTDvcjBPmnYLuLeR8
baleT/Fs1EUluqeTPONaZ3V4zYlgrHvMnbB5A/Hzd4xgfqVqCM95pZkpQSNm
4NdUeWQrKjXn/gzKorA5eJ9EGV8hTtqeGpM5RkFenjM/P7cH6ycsolcUEH9l
NlbfIPl7uzVySZo/DbdVjaNzTNtx2MtizFWBQq39vISfcr1YJdXoypogeTqW
9UlePw5e5y33ZBP/ET9TlvnSsRiRxvrF3aUUKv5JpEV7M8Fwb0+kvWnUe40c
zO7pRtG38uyhfsJPlu3jKXPzUKj+x9aafF8dvpYsV2fiTlGoVyI/BYfwtdVd
FgWIeD4eUHiKhtJMb2BlLQsL3b4lnhSmUD1u/IW3NR9tLnzmHxfR0A9pLD99
uxNfvAueNsVR6Pf1i7gxVgiD4t9bzqcTv2KLbroxlI8Ud573LoS3MpsYKzXe
dEDYsmj8Lh/hsWj1Bz8vNGCIP1ZX0JiNRqm3mjaOTJSpe69lmHKgFGS1xHa6
E1NpB0qM+Efw18vg4+UbTES0Sz39E0X8++9Kvg97qrHmfU5i7BDxDwZT7emF
PMTc3x1/jUWhcHowdUdXHS4kvXM2I/uzZ5FG1C5WK0o15i+8ncjG+U7hYvfH
bdjjMbf8gDIHB20eeR0xbsAeX9Uj/5lz0NS74ZaSfTWcBI5YbS1iI3fvgUlL
/mqUzPHleuhHw7dwqweXAgvfXl0WNXemELokQ0naLh3GrldXWn6lcDvyU7t0
Zgush/pyxgY4qHM8k5VGePY6F89273IakZFHr2zr68S+7jRdVZJvLTmllUus
69Cw70Lj2VUkPwXCgt22pyLz6H9G4eR9DL2S0dI9ydB6ZmG7QYMGdUjpuLNY
PSSXrFHsCuAgIDn+THZTLY6sl9YbiWbDkz/GVK4uGX9UF6acFSZ89uLSvAqB
duyQ2Zye/IqNX6v/TkiVNsN69UaGUgfhvZCNuxStWNBYlrwrxIWDU9tSJNp0
ajDg9dn8siEHBs8HI+a9ZCB8YpSf2klBxM5/YFr2PZ5HBmworqVQXFA+6e4a
gTULZ35sIf6p8/CHoZlcJeFsAV0+EQ6sN0t6jVfXQGbA5uvZYHI/7o4+rYtL
wJ/ev8HyA+GHFy+KZiyC4XZCzk2a7OOtm0bLKZ8WxBV0dh9WHob7mas++4YZ
WNOwWETpLgeeFdlGexMZ+P7DobiRzGvqfFLpEcVeXLl8z2oB4XXnZ1pOG01Z
0BPqGmHWsaHELdH59WcZzET8dr7pIfrptr+69+sHVOV1m2wxp2En+spvKjca
i59YafuQ/br1alZOzr4Va6dMFsjyUFiTumzk3acqKCl3PKol+67gQee+FsxF
d55dHS1G+oFyvM4B4VhI+knLuPHRYJ78GvuMuxePnpnGTnIRP/1nlRdUWAau
7+EP43xoHFOI/sV7pgJhu8OTXA0p6MvtXLwhqBkNsTNHVQvJfhfK7YuUz8ep
0p2L95O8UHPuXH8inomZzGWeAYM0flpXHs3ZX48dwnnbPmaSfiF05dt87QoI
2oXIihC+0UEoK/BNDiIicg9N3iLn6Tts2jScipc/vGMV1hLec97b94a/ERp/
Y9T9yf2/qWsS4y2sgdKC2mu934geqzQmufWrYK3+cMCRTYH/M+/BNI8u1J9/
lTlHnsaChn3dkcwqiPksyDP7R+O5oJswK5GJjHql+jN8I4gKF9VaUVaJuT3R
mYcIDzoOvrZh7mfipxA/r+kzCmzzVLvCok4EHT8/mrCc9FPPtTdW+XXjdMb2
zFkdDq7fFct0FG9GYXBA1OE4DoZyVVpSustwwMJD78wJGkcC6rssRCuwTjJQ
+bIO6RfVprHjRhGYu54nxHAJ4T0x14NLNOowdS7upSHJRyFRWb7lYR34z4n5
UJzMZzzTcOFx7gJ82Wc4mELm0xfmsrS0qQKcv03jhYIkH2y8rwiOVcLO9d4p
zkHCH7ckooqlKuHSV/2lyJONQhN91r+VTRDOH85qmM/BAoawyq+GDAjGuoj+
JXpYcuN5fLxQFwpu9mup+oxASqRvxL+nBSw/foPHWoTPCs9c5TZ8Dy33zspv
Bwg/rPvTnabahJqJAd2UdzQm1S9ZKFwtx/7A45ddiB7LzmbfCVrcjumnfIwD
RA8B2X/K3D58xO26ihjeSXJ/87+ItDB64f0bW+OdR/HG5EF04vZWDDTz9Bxr
4CBs+ePO9MEWRM7Rq/tA/Ni3+5DIh7vV2La05/jR+xS+d0rXt9eVYWRhfZ8J
4aOAR3NrSo2S8D036iADhOdcBtffzqqBx3anmYE4GoLjPV/OX6/AVOiL82nH
SX55JmU5LqpDgbGnx6ICkpdOIgUn1t6D0IqHrRfXkfO4Ct32bmXh6nFrpSvP
OOCoKPg+T2xHqM7qcn1Nwu+fLh54l/EMY0EDgWqER5RvDMz+mmrBn9ppVkrM
EJYfqZM23FKGjxPv6YBwCs8PnnLxmNuBnm0eg6dJHpk7aThoTnRDVN+/YC/p
K2oHk4x+sp7hV8ic0uhNNLJ+Lbv2WqgCdvSr2XsraMgKnvbvryqD34hl8MAZ
CuVBTQ7rxqvglpufvUKbA1f10ZeXTTrRY/pqd1zBMPq1/c/oEX6UMX4lfIlJ
YfzfsuR3b7LBWT5hte4R2cd1q0OrPtVDME7imM0xwmMGXDulN/bAikdwsWzi
MMrVpPO4uTvRfmnlroRkNiq0v4fO53Qgq6K0gCZ9d8VVl7DGqS60eafMa7pE
+mHuh7Xlna1ICk7VyXpM9o3ffxmT6HH9Rj7HF9NsbGPkqgh9boflS1mjjvdE
b6lsnk/5zfhUJq306jvxnxdK/G9354OZdWe17zXSBxXsbs3PqYfLUq0MXqJ3
T7+CD6V98cifcR3bsJD44aXT6UrcOdgYvdK0h5tG0M+1CU+SS5Gzkp35mPi5
7lHR+oeve8Ga8dgTuXMIwXs1H+zgasUTtumJ96T/5FZcLKz0i8Jr/oK+bKL/
w28jPCZuEZ5Xn7rJId9XmSktf+BkEzIXPwk+vY2DLWHPJaxrmGgPvFrrqUp4
ILvT4Z3pfTQc2/TBmPirrk+nOjOBBeFQLuUNZL7cCoJz8nOrUef6PnuY8P7w
qLzBn7wKWFnez5q6QPxgw7zZhNFufFArbjJIoKAivjPxunYjJO8Y2vvnkzzI
mDPybVsB3N5kXfhH9G9uO8sa35YFMWSbLSP7pMo8PGs4ycRZG5OGo6tGUGwk
ed/hZjHMrZ/ny7bT4G0sOdYWUA3ePfcT3Mn+xjyIXuVv3wO9DSd8zy4YwZtF
Ffrhk7Xw1Vfqe038h7Y9uWROdRmsPYU3X28i8wy62sA+UopQ7YCuCPJ8ZK1V
4Fa/CgQ6pK7ZrUny/pPBLhajCdpe7TZ/jTiwkJkf1ng7CE5u6tmy62loqQos
FRRpxYqj5wSUX7Nhq9BVLsmdh4QTo107iL7VwiPtHa50wemz3iLt1iGIbMof
y2kvwo7HqTZhRO/3X4709V5vAtep3V3Tl2jEpwqPnbvchfW6wjVmXSR/A5tr
h+Qe4+Do76Q9ZF/7dAzls1+2QPrbdsGYWA6eDCvft3Jqw11ngUQG8cc7Uv9l
LBppxXabkrcvhAkf8NSuO+Fdjrjg0zd1P1PosXIdknpYhzdn/45qyrPxaIvI
uaNptThm87ypkUH6jPMuOkMzHU7Xr5//Qvw7Yv5IcPvfRpR+fRP2mvSP9H2T
3FunUqCRV7qXxUPya3JbGiMnF677X9cIkr6ssCBYz28wBx+UntzcsoBGt3Gt
XFVuG6bLWT5HizjkOxQFdt0vgeyMz2Q56fcPg84Mq9bmY8Da8o9XGtHDcal7
3ms68dMoeiCd+HdUkEqQ3oESuCZd57gRnrH79/S4gFILBL6VHGX0seHtHF3+
3bUcKhHHfoWQvhdvsLGh3rQCs1fPGSv4UhBIVgwXmd+AT2/5NlhLc3Axc3RN
6aIObK68NlBdTcNq+Jxz4bFmtO3XqjVLJP4hKC42/SYDnzOos3tJX6QYT/75
ySTj6I20RauXkTyTFxRzE65FhEP1ZUfit7ZLB+WDhkn/1hJ972dF4X/j4xKS

        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41GsbxyUl9fLW4ZROKlSWQtI4EfVFi2SJUYhy7DSNVlHeplApHIyl
hcrWSjXhlZZXMWVMZBnNGCOjaJHfooUWh07O7/3jue4/nuu+r+u57/vzeQxC
drPDVVVUVA4y5//RTFp2q6pYCCH3XY7nIRI1Cc+c6UglMiYkt6a50phyXn1Q
L78cXqNVfYHPCWwsv5vi+7Qd1doOlwKyKYzq3Q7tuyaBtr3fVfMoCiXFoUMX
dKXwy90xbiGhILsXxu7pace3FE91gyQKymkC9xWLO1Fp2XDjRxcNzROxp3f7
t4P92z3fziwKlk5Gu/Z25yPeZF7jEQ6BuOO5nwR5nYi/X6SmXkbjsMLlRDOr
DcLVznsvRVIwmGHc3X65BcHX8gJs/CnsD3ap6PfrxobJxmO/fqWxsNDW30ba
Bm6Igav7LApBU60d0k9U4nfK1sm6nYC+8tayrohjmJnCCctZScBsX4C++iEl
LAP0zY3yaNy7LD/VikaocTIbog0p5HvtGAwuliBhu3ZfhYxCxYTwuTqfG8Dl
Hx2dSZBIyi1Z1EaJIDB+E2ZfxPSzvi62J64FXd/+Z/qGQ0HTLntZfMkLONst
/8N1E426IXP7FL9GiA5kO22VkphEDV6M81BA+SBrcoopjRHfj8Yi/mN46nCu
SKJJJHt78PRKuqDOq5HZW9FI1fD/sqbzIVrP7KsOjiFxk1SWf9xTifKP3xIG
CALzPG+088O7EVG2vnf0Cg2SG3h2qLEHZ1R1bcSxNAqKJlu5NyvQLeFeWaRL
g284506+eg98lvYmK57Q6E3+ffqRv/IQayuYbBpF4JOJTpVawGMk9Y6nG3JJ
TB+vqNQML0fBwq/Cz48IbN4/d0n17TrYD9wauJ5LQs80c/Uql/tQowW34zVJ
mKS1SFKk7cj/EGJ/VkChoMxqQ9ksMXRPmQvCX5DgLi0eDbNWIE9/PN2vmsa5
3CCXT1sbYV66vYD/k8SP05mEt08FfOo0Mv5VSyDQ12Wvg7oEyuhnMYJ+Euo+
Vt7ex2T4Mb52TmcBhZ1TQqhIZn79RIGuSy+JqryMU+a8Z8jzaGLZsSnUBsU6
7ywVQ7ptpCTmA4mnohMvTSY34KLaAtWBAyTqz+m6cy/JYLFjt5lnNwU/83Vn
bmfUQztxuP7DeRKHXjvOzy3uREnp7rHCQgq9U20T6jqe4YIPy/1KJoUvYkmy
+LsYUURb+isRiYGwOTdfxonhsW650wYLCtcFgsim/3RgJU+L98skGleb9qcf
CZbjvp6geYUNDdpSZpvHFqJqXbz3UASJw64exicONkMx3Y09kUXh1VdWWr9I
iozkwew/KQoX1p9kDW9sh+fDCcO+1xn+vHy1TIPrMEXEGVO6kyj9NcLdu7oZ
xoE7H9VupmDypMbU4rsIqlrZpEYZCZXMqylam3JgF+/mcJNNQGsgNMZlJcPf
0vWRt5bQML+45H727no0sUZ+hGeRcDt6znDBHTmIRayuBTU01BNtPn8Sd0Lm
b+heHUNjQbHXcMXMBjiGRiWlvCKRQM4eKaCTwD65ttHQlkDybL5lTOoTxPSl
tbOTSLwe89rpaC0GNdtsbFUfCS3tytS3JULsMUiQD3qTuBd1XzymUMLrxccO
Hk1DIL5+mSOR4FHi8TifOKbfnHcfjf77AoVHFvZO4tFgVRVlnrFR4O3THXwh
s/9fVnCS85w6UXinmH/nHYUfMQ37axfKMeRyTCXmEA3Ladf8tzbWQUW3JvVl
JMNTp2vlzywhVLP0CI/NJA5O3/KbSvgjvAqauYZzlMT7KuuXf6+SQ0VYzAly
ZPIzveaHqcoguLhGM8uWxsBDvqPZcC3K/j0SuvMgCYfqpohTkkRYvF7ALmHe
r3J4iPszqAza1KQVvMsEVruN9N0pbILDDastxYyvPMu9z66LbQQ9WhTxeozE
xKDlHSsXXUURW31vSBoBvm1gS05/J9b+9VgkEtAY1JwhJzaJIYib8uALs5+5
3+OtWPM7YHah1S09hIZNWdUD+l4zMqQxy86vojBd2DxvoLEGkov21ibGJMpF
SweunhJisTdXpHaaRNE0cUdN2Xnwzhc8LmH4D+w3jfBsboXJmHDFUx4Fq+jQ
v/9IEqN5W+QrxyYSSpOk4qQ/72JEfxZ33xCBPRuPBKQteQYP96mXtjH3G1fe
vD6lXIRdKttVTzN+jF6V3G1/WYqf0QZtshAKh+Z+8Ds2okT6xsj4hmQatxWf
Zs3IU+B5pSzb7wCNiUvmvnf+0gW5wV2deub/yN/2djx9iwI6GiEjORaMr7b+
IifetOH9Z/nA2hqGr3F55l3+A5QWNrbwjEiwjk/YtyWsFQ/26utkn6VQxNoX
bBL4BK8f0gUnGb/WxRqVplZIUc8agTuT71XKlWk4KvFt22epFoeGS2tieGqU
BInccI3a+YwPqNNua3JqsGhSXOhLWxJ7ooVvM7vPoqi7/vDDIAJOLcb9CvNu
GA0vtVs8SsNOa1fQBefnOPeox7WXqf8PSRPZ/Q==
        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk41YsWlaGjbjJFplceKipDkkLd5b5HN5LkXjeiwTw0XL1UMpRcqZQo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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns8lGkbdmg3fYkOm4x8aYukVMLmlL1SQmtMklRSaycmiYjaFFtySCI5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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4Ve0XFVKhkqRJaNSg8kVCw0JIMiVjKElIoSiiyRcJDVT4KFNIMmWe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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlX04lIkaxq3kIyVJNSyyQhHa7ZrSEW7UliRJhS1p+iCcaCXSymQ5lcXK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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGk41AsbxgeVIs6oVIM6dVpOpJNE9NbrFoU2HEo5Mc1Qk1ORilIJuWzJ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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnlcjVkYx1PRMFETYkwqodIiXSM1Lb8sFUkk0aJSkUKLtJC0KUSaSokm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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lG0bxqWQ5S0KpU2WJHuS/e0UicqWFqJFmrIvlSIiO2l5tYhKUmmz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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHlczPkfx9OtpcmKQu1qlRZJIRXlFakmbGWUsKiHyuasRsiRTTp0oXOV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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk81AkbV0lecqulbKQSRTYk2vK1WUJqM6akZHVMpMOxrsKmRIZsUW9F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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk81Okft7Y2IlR+jqVzM6GTUnK9xUZpxCJHGSVHpYjsItocUY4tVIaE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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k4VWsbx1WoJKQyRYWSKCHJKfVXcaIyVKJSmkynzFSGFJWidKKEQoQi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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs41AkXx91LmEKxU7PSTVO9qVxzWV/d0bTojWcrbYqQhMqbKaum8npT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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81AkfxyeDEJuorZXsUE+xq9QmuvQRElFEq1LbISrFJtuyDSoUkodJ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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns41OkXtxK1Yf1a24okly25NWlRunyqh0IRWpfEjxUi1q2i3+oiqayd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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Ve8XxYlKIyKhASXR8CUkSS2kUkmSZqFCSoZKhVAUkUJRyVyZy5CM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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHtYzGkbx6ckoaKYmHUok+gwKlk5lW9jsek8pEirNpRIYYV1zO40ckgh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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk41AsXx90ukTZkaU+0ShqKJHxb3NKt1KUaFcpOmSG8mlSi283+pozb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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk4lekbx6WUKVsz1GilJEwhyZ5vSoUmyZ6MkKU9nSRCspsWy2GkrMnW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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4lO3bjijRpoRKopBStiQtnCptUilCeYlUWryWyhIlxVu0qsiS0GL7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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHk41PsbnbTccpMkoqi5SvYiirrlyFKSW5EWkUr0JK3q6tqXhIRG1nKT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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs41AkXx0V2pEQlq+zmVtJu7pJ0+VoV1uOVxi26kGtF2iTXSqVs9WZj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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8ldkbv92pRpOmRoliSmUQRdaxDN8SMrckhIqKum3G77ZYUtFGWZpy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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4le0fp0RvJCFFMkqFVDRkxAchvREJlaRIXpWiRJIkFTJLVkZGySpR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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVk3lczIkbx9UL0yTtlA6lbatNIq1iRak+El2uSheK5bWObl1MKTrEdjFJ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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81Ikbx0cpJrpp5Qgt0ulapRYfFTmjpiWhA2VLLdV2jEg0Wr+VlB9y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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns41Gkbdlq0msghJWuxPklO6UC+2hvZnDYiSWqMHLaDISutU0lRaVms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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lG0bxi2RSpaXRNYoKYVKUclpT6hUlFTWEkpJsr2KEtErIZSsLXaV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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41AsXx4coa00LauhqU12XG7oicr8uymi7pSmSopKlJFpl3KtEK5Ul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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs4lAkXFz6XFGLrSyRpu3wbiykR5ZehdVlk0YUuyqeSwlbKvcu3Ma2Q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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8lFscxoVEpUVSKtutpAWhNAqPbEl125AsLSIia7cspSxD2q6yttzU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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lusfx1FGSmYqnCgjDRmpED7oVJJQOlIy6lhHEkIcW0ZahCj7SNkz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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk01AsUxy1F9aKk0iNbIo8YyVJKXxQZL2mhkvKispQ8o/JUkteKFpTK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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81AkDxieVJWrlVUk5qmGsSkTlpfZRKyRF6HiJsNqNQjXOdEiS0BCy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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lWkblkYqxlJk+U6mskQdOyWpS2E09haRqJMiYSJhkLR8QodEEVJC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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VPsftiVJIiRUVLaEEmVJ95VKlKRI9qQSkSukwrW051KEQqRsqZCE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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41GkfxpFLkoRVWVdKG5ZK0puk6KadiorSCitKyWFLSRqJIsU0Kev0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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk81IkbnmIpbNlqS2jCTo6diEiJPIgix1JqlXRMq4t+6EByhVhHpSgW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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnlcjGkcn02XKyS2SLRFFxprihx9QwZJupEQW0zUFjsddlOjQzrUSLLC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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8lN0bxkep9CZUWiwVESpKklS4ECUJKS1UJKGSslRCpWRNEioiIRKS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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk81Isaxic3lSXRyZmWaULKNlroUKgHVxsRklNIq3YlpWuJEkpOnaaT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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs41Ikexscl6apyq5WatGrPuOTSSp3WO5TQkVKzGoaSZReHSCVFulCk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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk0lesb1TE0oltHSRKlXDehkDK0jSXVIZmnpEhlbFAol9A9qVbcchGJ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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lv0fxRUyiidCymhJKskshCMhSaI0RfSohJZsispKyyxJUUZkbwnZ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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41AkXx2dTKWWotPVKRVlbyKV6EdmvemlJdNHq8iaXLi7lrsjaTSNs
tCjTKLpMcnm9SFGZiGYwRe5jjBkhq1S/y5TwMiR23j/Oc57znOf8cc73+zl6
PsH7TsxiMBhRyvh/7t6squ6m2gaqaSTgkhcF8ditlNNOQpwOU3G8eo9E3ppr
p90/NEM9KG1eEJuCXX+aY8WPxVDZ5bPgz5sEFLYOK8fCu6H9NaPctodGkX/Q
8OfAGrgzC7emxynnOZodnOudMP5hlrNNAA2d0Wq+n/Axpg+2PEtaTIJxJTdq
ZWoNDn9ztrhfTsIno+nmu+1SiBymi3WiaKRZ3v+obVaITW948Z5cAqNxmg2c
FW3YQJhvD5dSCHkYy7LQuY+aNrdhg5cENA2+C3lqHovqtznbkiwJ9CdHGQ+E
XoWbWW/D+z0E1PokjVkyAQ4/s7CV/0biSbjf8/JFPOy76qC77DsSiSb2DsKS
biQPzsScbaIxdDCiNLg3H0aFqRoReQTsPP69Z1CzEdmHXe+c1adQE7dgcbBK
Pe5cp75cfktCKzP3oDNPAH99tyHnSBJ2WUxS/lyABAaf68IisU5m1CeLEUNq
Eex/N5SGpKwipHyfBD9drFO/rLxP/zfWEfFYD3okVoEH7eTglfj0dXlL8PaG
sTCBRcPYRveDxttWRM37YLCJRYGMqHn2n/tduHE2e74skoZfxqm9rXQTmIvM
w754UGiRvSQnLrxGNW+L3jwvOTxqwyvrjd/gxMEvdcabaczjZP18hC3E1jGP
tse1JGKLha1rk29gQNAfVeBNYJhy2WAa2A7D6LP6+WkUPpn7P9INfIjqi5Pr
M6oI9DL+ct4vbMH3wX3l569TyIufZm5SiDCwKsXhf+EU4gX3CsSDTXgydfo2
6xUJV9GxhCX2XZiaibQOvEKD7+29u+KfyUDmD9cU2wmIdhyKqLPtxdIS3cSh
1XLYcXOWUBOJYNKnZHkgEHRnz0h7eBe8eso7fs1Q7vtyMjukQARN9XUTKWUU
nIfnVgbkdyC6NMz7uIKCUeh/RZEmLVjVVjq+GBT8KmtJl+Fs3O1ML8FFAhyn
6fTKpx3YmOPuG15LYfINkf4lpw6uhtyV966R6FgtK/g2Uwe0F8Sa5pLQv8R5
Ya0vxgibuWrTJyUPY07JBusluJ1Xc4IVTeOVXUvW18+v0KXF42lOkVhodK0o
SanP4qcmwdWraDQ9b1z0y5gQvkn72RqTJDTDzBKQ3A7XNf71QTkUjh9WOZMe
+gJhrcd2y4qU/XOlERqBYkSo5S+Id6Bxcb+jqneMFLfitz5xjafx3uKnBs0x
GQKGuw1JbTlmW74/076sG3/Ym+nuUSj9u6bs2GimAJZVVosoaxLOa51MAla8
xt0j6QUJLjR0dc7dscgUQ/FAWm0wn8aUdGpCptKNc4wrj7UENJYF20SNvmsD
m9myMWaaxDyfvMv5na8QNttpNF5Zh0TPX7fK+yl0L3cnf5shEBO0jpXtX49K
eb18ZpAEf3bVcgVXhj+Y49YKVxr7Aoo09ipeYhZbNcjqA4mc3N/GTNfy4chy
lv/oQeK4aYNaw3IhrO3UfbXOkOhWczeM85BiTOuWV7yqHJ22toGXUyS4NW21
23wBjeWSstwcfi26qx2OZD0i0XZJP8G6rxkuvV9/XxZHwWDp9MZUFxH+OlOc
TMgpJLy4/XPfTj6uiM24Un0lj0VTiaGVJTjJjQisEhJ4tMhhQH5KCJJVPDnN
V/Kwo9Xpgc1dxDhuaS6OIfB7KjtkPLYdiR9ZF5YmUNBRa17/9ftmhM4nxAcc
Kcw9c2gvfHoQM1i8xSOJhmemjkqWRArflQFZXyZo6NNOZXvMa6GwuHdrvJjE
ZoZ5/UWHFkzeGNzAeU6hifM6L0DagJ1uqvtf21Dg8c+3LkmUwCS0QirTpdG2
O8hST+0RTrdNVtnSBC7sOndeb0CCob2BGZFKPYc+FU3c38mFp31ggCCcQOYJ
UUVvthhyR/vCm240MtnlnAO5EjwdFtXWMGh4cQvnRM/5EyOmKb52TgTWuWfe
lpdUoEKdsyZGeR9enqXGnFYpjJyDhorYyn9FVXmmsjqw7V+PXzR9UPJUNqrX
zGqE4dBYi84GCj3S5lLbTgHStpF+bBel/+euvrJL0QluOdcp/CgNtxGe5yfv
PtR8pNRONtNgsP1MVVpqIYiVM+xaSXC1fcuKmK8QbKYbt9mQAtttx/VZW5pw
dDCX3hdFgelpHmns2gl9o+7CFVtoPNOOYhmKGnH0LWWQ9g8Ky0fsC7XkJdCt
a00qqyXg0qefeeizCNUC7YGPMxT6F/bYND6sRNXQr3qXbEiwzxWsFA+0I9M7
/0UAn0Ks3GtWb3o9TgZNhhqMk5iYmf6cIZdBJp5JNfGkIW1a066a0o6H8fXM
slYK/IXxi2cOlCL6qPvkRB8B4oRzz3XPdnTxTi3v/YUC18WquLqbh3eZmg8e
WpHovxf8mBNZhGPsj0PjTwj8DTMA7gc=
        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs4lAkbxieNQ42WzkVyZpdQzpFuZMqZ0oEtrSgNq1Q+Ce1W8kkhlYjQ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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns41OkbxqVpKzkUFdlWQg6tCCFRt+OgNkWWLbOzymnskkQOo5ZaUVgq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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k4VX0bxZEyJFSSSMZKhRQpwhKlklTCYwiJhIw9lFQqUpJQJISkiAYZ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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81AkfHqrpoHJlY4W0HSuRPmHl5VFhh4QOpTYs4VW5UioUFkWaWqkc
myZWaZZoNKgpoSHnkJlxjbMU9TvsFiuR9M77x/fz/fd5vs/xXekbuttfkcFg
nJHP/3fQnvGXaexSFOp6aMRRBD5nflyslCPFpYrR8GobGtwv7lL9o82QLtFm
ualR8JvYKDZY1Qr7F28OvDenMDJ3zSrnk72oSGBOaemNItBlb+yqmJdw9Hlp
xgukkM063f1OWYSwFdWe+cEUat/nf3qVWY7pTX2GuSME9v3nPef+ZwnoD/7c
SjEFRqAk9IT3ZWgxlb8rciCQmdC6o77pESosH5bl6pIYEAT0aJxqA1MlcfOB
txTccrQ4U34laDNjxG58QSDuna7Gk+4OzKjfsyX5NAzeZl0651UF9oIcj3wH
ElppAV7p4TXYkH3ovpULCf6e6AevPTtwzf7DpcBqCmzjNLXf9SRYtOvnMjUG
jTxJkWDofj3iW5SvP1SgwLpwYt3H43VI2cZ4V1BOgs3fV/rGuwZGaXbZm/NJ
9OnUVYbmVeGaH4qXyfEm1isen5rsQtIpZ19LHxpxmVZjK8YTsXlwb3aUNQFW
LhEqTW9A4tLpxqopEoy7k7OB/hHQKzge/sWEQLuwa0ezHxfhY05DCTcJBAoo
x6xjUhQP/3yk7iiFM+pCN+OALrDY+QO9OTRsbTP6GoNT8fevA96/OREQppYG
OWdKsXWpnYmxOY0w7jyl6uUPwU4yvhPfQqBze8+UJEaI6BTf1xuOyfG6Z2xr
vlENuzoN1zv+JOILByr9l3fg8aaTWhx/Gkt4g/oXWS1QKvsavcJDfi/RnyFO
hY3Y1y5SNGJQWJA1x66eI4PK73ECZwMaoq1lBW2yephYmsRVCkkoOex1Uffo
heLXX7bWNNAI8FHe/XSHBLKIApOG3ygccI889/x5CU7lnXPolhE4pOs5fCy4
BS5s35CCPRTmWK1J8vEWg88mmem3KXQP3OZ5lTRghK9rUb2IwrRq/aNTKh1I
T349JI2i0Xq1yux7WRdmmBe7hQtp5NhrpRz+KIKXUVX0XA0Kgfczsn6MeYYU
hk25jiGJybETfzhq1EF5TPsfzXskNOckGc/P68DwioGRpStoTGxUTPjnWSts
uy05mnYUBg1KHkqWdCPKdd3R430UnJepFYW1V0DV96ndYjsSYU85muetr0Fz
eE6QujuB5Cm6O2xBH5oWr+Umv6MQxr9y5eD+fJQk53q9v0bg9IWuWtb3Ymh1
xm6ZlFDg7d/E3RreieiJLu1YDo216fNEPUX9mLF+zGdvovFZ58sRnjYfE6VE
vP8kgdQJr5lP1lcR4jQiK95NIEgTrsuedKEp+uyGnVIaUf2qfQdj2lFgeGd7
EV/OfxtzXXB8CYLSNMv+HSTAMHfnHWz0wqfmRb6WawksCq6c9/lKJ2p+HB98
dJ8GL93Z825YB2Bb+9PctTTUHro03XOS4Piu60fIWXkeDSL6ixRy4WLqyX5z
koC+z9Tgiz4JvOOIvavkfsi+XFz9PLYONwv0TGu+kJi1smnNc21HZ8wPvYes
aeSTBee99XphflhdGuc4isSGJS4mSo0QzYgOfpProW+U2dPf3QMrl6GXgfqj
sAmZVTfzFOPiKxWPN+0U2v5bmG1wogk6am+N430pCGyG367Z2wOVrBhG7QgF
/SO2xGGvMuh84jANxwlMt+4/LK6VIZ934IFFD43Rpo8+gldSqMrq+1/L/a1s
0c18IG7G45xblgrfSDTc3O823PwXZNNv+SmZBIz+ttGPOytDZIbxWaViuT/U
/ZP/qpTAvHpJVtk9Cj3iZvLrpBgWrzLaxscpcHhFQbYHO7HxmUVtRAiNZJFp
U0NjOZ7EiLIGPxLgGqZ1HDlZBa7+9YoENxK2GRbZU9qxYG8RXBeZEeAktXk+
eCXP43Tnp6BJCpLFtNXlZRJE8udds8+ioNK9fc927QJkbohhD90isGB03PV1
VANEfa1uO8tIpL47HdAxkQ3hiOmOeX4EzioRkuIeKYKMdHSuuNCokc5K5y9/
DlYoKdGxJkG4Fk6r7ZLCdrWqboWAwuM6n/VOk6XYwtee776QxHPTFDVuWzsy
DSK+RdrRWH3pzl37uGLoJLmHbisisDs1/8wfbf0IaXNsEqyX6+n5xcPavg/c
jcNGzrU0ZvzsxGNX25C7Mo354gIFp4S4qGh2O2LmCiMzBylU//ve4caFu0g1
SOw1TyfA6ynbxuJ24EZPUOvKWzTmmoXYZC8TQpPVcuLoSRLM1cOVkl1iCCeM
1553p/BLpKmnukMx1i9XVNjHI6DosFV76Q+dWNrHcy4X0tjX9HWWwZIhnDOY
EXCeRjhj50q7R6XoL7/Z6thOYL/qBZ3r31UjLi8qmJLn2bBQoWQLsw0Nd4Ym
ffTk/2AixIvlK8DRbx471ivI+7vWYtdYVAcCA3w3tfxEQy/CfFT1WS1knPAP
626TKE2zT2C8aUSpQGHhuLyv/gcYOdOF
        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41IsexoVuynKHtqmjU4oWKkqLVF6VsrQ4Ua5sxS1NocXRjVKWoymp
kyXLiSLGckhuxCOUUcyMbWaMmcGMysz8fmOog0qWcnTn/vF9vn99n+d93ufz
vl+TgPNupzQ1NDTC1fP/LXDeWf52Ix9t9vXU+WEE8udVvrI1EOJw41SPfbEC
33LzhlvvivFAZO51t1OBW6aSo1VvReDwfAUsthzBcgMNzytNmN77Na5+Tj/a
+3RpK2QNiBDr+mku6cfaPFnwvvwmiAoPXOa7KlFs753McO5E8bI/w5GgwIWt
+jGhbrkYtP8cdKRQBR//P7SLw0rwwaL0qCpKBZ2xbjZtZisOrbX25ugoEWQl
MW4b4GJqN9fxoZEScvKdfo6zFF8dxo/ZxvTBTfOYfeo/36Fq3OJAFvcd6Pd8
yhzuiLDHcvuGiCAFpnaYJO03bUOGVgjDkUei+xGv+fzccmSnPOpxN1aB4mTi
QWvgQfj3vZdnL5DoWFBSoh/EQwK1pV4yRkDjBZF5lSdEsfy9Q9AnOVxNqPRW
6gu8cjpS6K6jgtXUhnfHHbtwBy9PxTfI8HO0t+JxDR+9bDMG7wOJGt+AsB/b
hLiiXVrc0S7HgpGO5DxaB1ZGCFju2QRyzq5v3vZFCJtFPQd33ZAjwGuFZasV
H4fmG6ck1hKQ9BwYMOhtRJFLzWnvSCVGk/b7nGxphVfOt0HuFRKvajrE/guk
mGLKWFXucjA7RV2+jzMw8fe10GaRCtVWhaNbasX49Yy+zbGvMhBXRrljGhyc
uN3yo4OrREZZDSs1oB2B34PJVe8I2M4+p5kWL8J66+35a64q4LXKcOd4lgBV
NJFDyAwCfZsOtP00+RrG9FkfGB79+FwrWFH/pgPYzI4bziJhszRrdvVNIeiU
KPrFcjnG2gqozEAxhjymuyhUBf4T932ftR0fMUPSWLHa77CFRNWXv4Rg0INb
CkwUuP7Ce2KelRDp2x/2qvhq3v6KDpn1ZyVC4/jMdjMVPPNt/LxjG+GfruUU
HN6PB+HsxCO2XaDtiNi1KlHNF2ESnBLNwVBtU+QHOYn/Xnz20S/+DbSy6PLS
KiVuVRT9Y2tUI2wOClZSjPoRu6hWuu2GGG+GNBjCMwrMya6Yz9LlINHMzcGm
VolNnbVfeK5N6L3uc+nWz0o4LatwNd0oBPfgXrvlN+Xoq768bzMtGq8N9xbs
0hnAplmpMmepEGdOZh8yZRC49X5z8pnnfDjHV2w5vpeAHj+8/OQYH1vPDSso
TBJUps9rbV0JPi2uZLx4KAP90nSo0Z4uZC5f+nILKUMBKy2IspKP/IhFRT0O
JCQ24hNXzCX49fH7y15ZMtyRRF6jJjVC80N71/V1SqzdbqTHi2nHCLdNkj1O
4Dn/XoztcDcqIy4mm032gcmJn9R/T0dA1u86TzQGcH9BmtGxSDaO1d3W3iIh
oXNxRtXAqxbYeVqMx6v5SozK17MIK0PgGoPw5LMq3L/t+iLwewf0U0MMN64j
EbnwhO2iW3y4KK/6OjWRkFlf7N7zSw7M94y4j9SpwNQ8nO1i0YVYsX3J/RIZ
qBluyumjHFTxVqRnByuho3ut6JSXCHy2dFnpJTmWWRrlGRbn4ivnU8PdfBX0
RhIqQva3IfaXc9KoOSQ+Rk50mnm8xDnxWc8fD/qxLm1UKjIRIIMkCy2fEqh7
q91gminAgdzZrrlFCjDjv1Hqd7WAete6uESdn1Cby6593RxcP9514jyLxLlP
/qNkWCduXrtKM7xBYnCQSOrbx8dTvYyuZwEE7k8b7XwykQIKdm+uVqqwdIfd
54K1fIgTDlUG1xNIZRUJzeNESBxOflipT0Ceaa+b8oQNvUes3HV/KMF/6jI4
GC6FVwHpQAtR+x/GHp5xpwcjl2M84wJlqK4p3XWKyYHt3MNDU3kkDEp2uEyc
fo3bpWMmPlQ13xc+19P8+bDwJmewPQiMGOzfxmyvw77OQm5adr+aN0ay36QY
enWOHs11MlhlmvuFWpfjeYiYDFukwryy3elvGyXwIw6VdfspEG2X5vmFfgET
4/mvTywYQKNL/Rp/tMNLRSZsnEuC0mp+/f5IE6Tp5tOPU5RwNrSQJvXyob3D
Ua+tj4D9dgHDeCgBgSWp/z46qcLtTEf9EN9qyG/kCUoa+1HgYnnG+jcWpt2e
RnUb9oM58mzb3ZtcLNFme5r3kJhlWj7amFaDManlEscctf5HEWV269R9t2fr
w2lnAjMXp+rXXWPhUXpI9g0rJbondudFHe7E4kDeauZjAuUUZWXwN/W/CjAr
M3sjx5y4ydk566UIiMkTe2T0oerex1GS7MKctMnyoZsyqErXx2e1C8CdDn3L
nUkgXEjsplQ0Q2uVeQ2NTSKY/M3yi/MbxGqt9vDIVPdr7gbffx3ugeGWvgen
1ffGem0l4dGNiF448WqjZj/Cf1rdOy3n4Mn7hKncJ0okrvrGuNQsQab7cn2x
oTrvYclJ/lUiaJy3TT5qRYAe5dXgxBLB6feKpRVWJP4HDrPiiQ==
        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVms4lOkbn6xDKzZKpaKmHEoHSUglP0lW1tBSk0NFTmkqCo0VFckqp0gJ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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VG8bnkgkUhKSipKspaKI3JKk0KK9kCRJJZVCi6UkStZIhQhRlmyJ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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81Pkaxx1KUpvLkmsu1R5nS7RhcolPSUpluyErm0uEsqQbaQnhVEoi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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81Akfx40VtYWJeSRpDWJfytJaEYtPZB8q5Vylc9IhUmTLUYocWzHK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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns81NkfxkfUSkKk1OZOidJGyiU9bJQkqd2XS8huSXaaRCFaiUJhCLV2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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3cgle0bViKhpFRKfUYkoqRkhCsRDaRFGxnlIwqVTyo7aYnMFCHJykrI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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81IsaxilUg0qpU046kqxpuzo6WZ6xhJObZJk6cq69k7iH6ia03Y7I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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk3k41Isax0fpdnJLUyQilKylY7puK74lUpoiJ7LkWipLqcaU7E5iqHRb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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lWkb1/kinWSYJKnJkiapmVRIy/ihZkYmx76kGUqiQqnsSuoUp7Fk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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VV0bxiVTpiRlSoYMDUhImtxCJdKrCZlCUSRlqBRvKUNKRamokBQi
ISSETJkdxzEPUaaz9/E2SUjSt76/zrWv66y99nrW89z371Z0ObXPlZuLi8tx
HhfX/39DfdNPrBJvxfTPdTLFPGPwKeHREC54hfZTMrMvjGl48pulZzqnQDhw
U+hRERoSk3u+nz5ei7kL6klxR2nkLDZYqKBdjvk8nUvT7tOY02oRudXSisb7
T1b/c5KDGF2lnD7XFhxbba+45sIYjg9JGgppZcD05t0PGotpFJVqLs437YCR
ya2jq8Jo0BYOjSc1euHpxbLNGKZwY75lVInSfQSv/+Q8Ik8jTFs16ZZWE2Rk
Q73ODHAgaVdyeXNCOyyZajXeLjRu1+hP/uPTgpENsidZ7aMY9hb+OBSTj550
5+NvHWjojwQZytxohILICvchsn+iF9eU593rGJ7wfS23jIZlgBZjxYV8/Nuy
qs14E43nttE8pbF1SL/0MUjlIgWu4/PjHWx3wlz7psKEInnf++nQ+9PlqNU8
VGxK9hcaOOzWWtKJuaadV+YujsKwiaHkdyoX4DYWyqIpKLeHjjFep0NTdH+e
tSENm1nR6FfL3iJRREN8gRUNVTG3qRXtH2B/wcN3qJGC0wmFYy+MEqEs6d58
lJdGW1Wz3kxmG5IHxT6GBlK4NRXxszC2GW88VFNTJmhsZ6nGbT46AEGj5isK
12lMnIzbZrWSBT21sNrn5FmdT9M1ncGEk/wq/RW1FKJ49vev3dMKYeWWu2UX
aajFv73w5X4vFFUZUv0/ODDLnU5w0GjFccH5j5+NUshw661au7kNGWE3ioW8
yfohl0v6cV04LDf+Vpw9grakr5UeLfU4Xrgk+ooFG9PJXf2B++5DsjeV+qtC
Y5lh65BGfhUsTh3cEV5FQaZV9fWPxnJ4XRK4JihDY3ht9+FvzS2Q5omVktSl
QfkPX4mPb4LnlVbvygs0yi6L+vlV5iIj4ZyxGanf3ZIVKq8fNuFl+5W2tAMU
PALOO3gbVaDmlEZfSTCFvYMqXyK5G3F8+1SSyzYas8ayip3DXdj2oVe9oZpC
Y8NESviRVpzUDPCIXUvD6VBT5snoxyjiPqPGrUT2L/IxfNTSBQ//+ZtOqZH7
2H/pc/fQO1jGrdlpLU5jpZ/QgKBCN0qCH972NOHA8NZTXNJ9gXdTtka1mjTs
z0z+stTuRuBS21fbzEdwdt85AUZrB45kGpoedqDgN/5LO7+uCp7Fh30nflP4
+CulXulNCk7nGvttmE8jRSdf2xwtsLLMCHY1o+CYfPh+9I1qGLQkxCwn9TMa
Y4me0XsPYfMNa1/00Qjc+Ul6iSsLgxSjuE6IgqEFveiibSSS5SuOVJLzVOrZ
vqJs2iDfk2TW+Z7CxTiPPWMGNeDRl3TsyKUQlPKynX4ZgN3pEzNa5P/DvmPH
uJbm4GdCi/aGjTQ2rI2+JZ/fBMuV3z8zgyjYWB3alHQgC4L899ghsxQ0fWSk
Vw4w8bEr1VKijYLe+o7DLR3dyPhiZHbVegzrJk+o8qY2oTzKMUpzkIbUrUlT
hfJC3IxaJ/x6kkKF3Z1GlVd1EH4weyX6LxtBoVORQTsLMPdHnCHEoHFre8i7
kN+tYE8Z+D1iUmhv0vd8NspCLDuy/5scmdcLDnwluSUIb14qYvQPjXtRd95u
3M/ErMV4eQh5X+Kur0/9U9/C6/balWdHKEiJ9IgqjhfgZSEzIIdBQe6fyMKS
n+/RuPahwvoMCvusP09yi1UgeCyr4aMyjdgnqt9een9A1+XjTX8/sJGfayTl
pt+GkRseasETbPApuk1JpXdCfzr88MPLFAINrqt1ePThGFvziyCZJ4FaUXnl
nHbcDLk1ZyZBYYvaxmXMsA5EOuM/udek/rLGMnU657B1QPbGM1L/yb9OjN/m
LVAPCnLxJP15+oal50L7RnDl17AruGh41alXZG+qx2D6eyfzEzQqqqSmbhd2
gcf3QlDGK9JfGuP8h9a3INbatN7JgINEzsJ5SgWpkIqqtL9A9ETg29rg5VO5
mK5N/lvxkdznaG/FGxEW+KSHozb/orFkbnGrrUkftr8TzWh6TPZn2ZQrbuuB
jctCPckxDrbkvU61OVAPYZ5185WjyPx16e4V3duN+7/t759Jo5HXF5G+P7kO
bocyE35YUeCNvvll8eNmeAh+aQ16RYM93hHCGejBg+5v4wMraVTdc40MmFeD
MpUT74zYFMzGZ3ef9WLhCX95bck1Us8Hcp9lz1WhbFtCqHkzhTLdPzoOAj0w
3RBhoXqLRgKXsNF7XybK05/7zLencUcI16IMemGuY1X29h6NbNuhCx6703D0
WWI0S4wGK1cuwmBdH87MmHC7naJxTHCN5EvihzxH11lHetIwPBuj4/wyDUof
EHdlikKVhZrre7xFNlN443nyvbcrEyXer2nHQ4kUxnsnDvI2aOo7BnfC83gk
mzIdhmlIUMyscBXqVTL83cn7u1ZlxSjvKwN3xqb0WaJHYTuTvcq1WHD+u2Eu
Np6NSbUnikrh7XBS1HIvjeMgfPvoZhurMiz7m84/QfZjymlRqxvaIXXyYmbj
vlE8n+TW/lPWi1kvE7P882T/2PKyh4/L4G011yVN+pnLMqFsLusaxFuX2Ciq
0diyqqxRmmahmrq9bhMXBw0HJuJMGrqwIHZWNPbhCGZqLF5q1rIwZxl8eZ8u
ByERAgu15YuwTIxtcECCxsgiYfvbFh9gKxRYmhdI9HJwXStfcB4cO3ydl+qQ
ftxWbm25uxtOs9L88vUclB3Nub4ovhspl/yis86MgXnnQYzzoQaw+k/EB7+n
8ezcofTv5zqgJzl5PPztGMp+TJbKL07F0NgdrqQfFELozw8/iiZBd5JfZ6sq
DcbwSocfWd2Idef48maxIXrwso7hm07ciDSUrRQbxYzV94iXb3owqRP2wo7o
2VxTUDHzXCNixlX6c8i8XpBON/jK6kJkr1V4u8IYZtt9BL/8eoecd3qRc01k
HqVe6/vvK4f38R97RzgURu8+KrO5Q3hBWWuP3BTRo+R/R4UDE8D3rE3FnfBQ
zryB5VVeddBlLRk8L83GoXrWt7o7b2CkyPU4bAmNM+udpzf1tODX4/t3xK7S
KHBwlUjXr8WEBatk7BMb94oXdMxIVUKnJuK7ujaNhyGJA+MVnTh18VRTegkb
d3j96gx1cpBy5r8sV1IPputwc+DFKgTGaO50J/NRO+rWMdb4BK28N/aqE780
1EzoVz0WhL7c3087VhCeOcQsfri0HlEMIYn/Wikk6v0wmdmch1s6OywP+hH/
FkjW9c1MwVwy5biV9NexQz5X9X62QIm6enl9/yjKJEd7p4Iuod4ANmZE/5gp
gzkntBvgyVApDSJ8Ym8R2LCVqwPLfwusGdhAYaaSN9NRoRwJNfSa4EM0LLaJ
yh5KbcYyg3kjT4le8zioGtjn1aDNX+dv1gTxu4fbbz436oIvq2n1knVjuMvL
fDfo3Ywto+vcr/1h4+xVf62l9S3oP372t9lZGj3yKyVlFAYwNJ0dr243ii7v
gn92NFdh2PrSQYF+CgIS44UlL/JxZtS4oECKhlvabROLJiZMmUVmd2aJ/88T
4nbrbYEK95UMHtK/hYJbS90kKpHwz+RYKtHDxj3T2r5tqchizGrFb6BRXzEa
3/WkHcd+H3vzTY4DXYUXjZN6lRDR+fOJlqax+3V5b1hdD0aV5F5bTQ8jSjbx
4L6kLIRUt7/JkCT1P7AsQE41E1tGyle82EX0c0HAwlzvTnCqHKqv/iL+szCK
NrdvxdqW/V5rbpLzSVYWhzi1IbxhyZJBQRrhPzvTagVqoftfWeQjfQ7ikg5s
dHlahofFVJNCKI3iT9oCR4ca8OX5r2sW+cRvHZkfy66yEBHMWxU+R+5bJ3U/
V2EC/E8+SnDWIPf34rV8xwMmduw2uyjATSPCbemX9ae7EbRj6OLTzcTvPy0L
SV1cA74eWTlu4sf6jLVJT5dWotFAZuPkMwptAX9iLvO2gCe9qUDkDgcH6JOu
Kwmvma2YvbXSgvCZGTPH62sHJnj+XDviNwYt1sJrlH4BLneW/Wj8TMFFLyfs
m1kPWFu+SOw/SJF5qNrx2y4DJ21E+f/Ph/knknNXvejEdbe6QeUEGlh14jj/
qgpoHnQ8eMaSRlzaVr6b3K0QCJLmZJO8skt2eiZIphPP/sLWRn8Uc5JTK4W+
MhF3PbP7Yzvhn6ftgvPMQ2HrMCQoTPTDzjYtSz6gDHXF81qtyHPg/q+Xq/TL
YcXaO7FmEQ3Tdpnl4k+LEOsg9q8KyRurjRI4C6U6cLpWM73hBY2TF2OOWH6o
Ilzzh/sx6ZfjgoN5gw/f4L//goJ599I4u6RfI6OoF3usTdxSdnCgvH33axHC
xztvnHX08yb65lN53iroJqhTCfNmSf/w7Dl4z8S/G/0SbRpRemOI9ahaI2xW
hyqtxIN1RJ/D3dxn+aUy8eaayKd9ZD5Z3J8qThb2gk9Yp7jw5yiubl1oKO9Y
iYbnpapxbWzYqd1kMHWY2Oyd5tukzMGMeZO4j30Lom0l2zRWjYKrcqkr764L
CClLjr1H9GFnoGlOo20b0WetlabxRP9+cKhNjjWIqnjl3u5G6i1u2XX6UTP8
Y1Tt/o0kevCtfIyHlYndfLZ9XPw0zrtIDflpl8F0ca/6VsLnO9xLS88ld6DA
fXn3zHI2JIxvL3gf2AAM+mdvkOCAerueZ9uZdgQt0BP4/ZmD6eGDh5R0WqC5
ZFeq4b9k/no3Nr5Y2Q+bcc/gKnOK5M2k0rZjrQiskhqSFSH9v1YgcZ9FBeKC
Uqu/h5B8c8nhlfe9ajQo23YUkTzHXK12QEKkAadb54t9lOaQ3Kfw6ZxBG65L
eySdJfnL0vmXh+zmpzCOaJ/UI/Uc1NvuvWIkB2flrlqNkHyjXmv379/kbohl
hKt0jo7ASe/PwXDdRhw59+E8F9Gfx/Wbt2XdZ4G1XCn6azyNap83uZl6TRjV
4KhfzqEwvXedidAxBs6uOBrcSPSyrPDy7dLVOUgyPa0yQvInl23Pwsi9h8D5
7BinTviuLL+z9KvxFTALBapLCb+GPF2kdud5OxLkOuatnKLxzbIhxEHqFag/
mVMJW8l69QTGPxcawbSXnrAm+UJi5qYGTjOwIMbj/h3/UUjyGT4zFmuCQKz5
GtGFHEymj+ts6+1E113+7eVmhPcs3B+I99fD5PD4peV2FA5YtX1pvdsIrwP8
57qHiX//w0xXtu7BRLRsjJLtGLSpa0P5xjmo2Stj8I34R190W+GUfAN4hjVc
/q6hEdm4sG/xq0bEYTjFpoeDKrMTqV2iHeCOy0lffmEUwhzpcrHSargtYjYZ
TLKxerG8cIBdGxQOslc7N9Do0KnitwysAS/dkH2X8GzxfY7yqFYOgsT4VBdp
kX5IVPZs/d6MS1drF6bKs2H2KXDgyd8qvLyrGzAbRMOPV3zx3UUsSOfrRJlU
E72fuvox4Wo1ZAaFAs5rUUiOKpRPkmiGcmiL/vsnRP/LeXrdDCtxqvy7XQbh
j0yfp1/iMzvwZen5VvMKwo+H34xYGbfCK2Xr8nuaFEQsnTa75OfjmdLM2P/1
vGyrXEH2RAu+FksnMxo5yOZwa/1OqUE2+6/FgBCNG0dX1wrqtyCs/NPGPg0K
RQwD1yGpdlitf/+iP5cNJ7dV89x8ST7J+z5WRfhCYjgqsz+G6FHR7HQl8SOJ
k2tHe/qaUfAjcJwrhsYBM9V0a4FW3F6kG2LyhsKggKCKcH4HrqQKv5Fn0bB5
tDtCSO4ZAkYLrZ4voKEq29Nk7sPEoPfmnJsBZL3k0ey81Jc4GlbP93/e1LKs
eGRWmwRh1/2J+5bRiJJXuf70azGe1SenTKcTPlGrE0w50wGzgShr8zdsHGlr
U49wYmBY8nx34HmSd+9NNSSuroJL6A2vNdPEbwZm/tyzYmAT58M6ZyOi5/wx
/dKED/umOz583TaGIvHpRUpRLPC/3TLaokzhG2XfGNL/HN67Z9f+JP4XtmBD
eTzqUPw5mTN2g0Icv/UXvuV5YBhcNmP8JHxz08Hx5652XJDyvWHtwYFCyzcm
704GMpjWkibtNDI2r3a5tJjwzc93YmbBNNI3z3dn27VgtQW38fN4DlQ53SER
b7PReH/rSS+id9Oza3sPn3mP5F/nFaVI/Sqf8H2t3NCAvCSmuOsgG6Zb2iPy
jAuQMq9oef0M4aPSpJq0kjdYd3ZJQDXhf6dNzmddnvfAIpNlk3OJjeLirxop
mgx4rG4+p0jOXzt+rWyhTyu6Noq/rrej8UC0PPzX024IO8U0KpP+4vqYefqc
y22El31yphRIHhEwUPTY1wB+TQ2z7bakvqvjXrS+q0OYjc7eoT2k36L/0+yj
H0DVesm+cqJXFburQopT2/F376u7uwmPBOZ+Fju/rgcRhYezzIOGYeP5IXvr
kWrYhWaXysURXhd4/2G2jAGNUOfrr/1pOPJv2KR5nQXT4QPR/Y9JPS1/LjD/
eA8nur+3PZMhfOJns3HN43c4Ns0u2kp41ckvYaKU9Q41JlV1MrtpbFe+L+ga
z0LY+GU3w+ukfynZa33VRShTfJgeQPJSke6nniqfPgQUyc6WO4/h4xanf71n
8uHNQwVIupI8mFodW5DUCJ8X2QIMP8L/NWkRZ8Qr0CVWYJFsRXgnPUXEJKwC
CdeKHmyJI/6t+jzFszAV4j7Bt9cRnlsuNRDLd6wNXz6tdr/HT/iiaveD9IGn
kBIyFKgk/a02X8i/3ZGFBDELXetpDuz9BbPPijGgGeh97HoijT3x9lkHFzNx
RKlpxD2Kxtx1m6/avE3QYIcuWZxK9GaVeNluMwZ6vu4PXUz0t0iIdyhtfy8y
3ArPPSLzXB3vxMdM60OvusT3zL8kj2ZXrAnt6YfBr355+7Of0fqAz79grBHc
RbwFn0g+8JfeNZH7LA3XOW25wfOIvqRplbjYMGF0Sev5u2wOavMMjJxcC7B/
l7ifLPGHtua3m/R8u2H9Vj1qK0X0s7/kc1Z6LRgWPZH15P54unpN1A+T+ufu
M+cU0AiSPfBQ1Y4BratutMjUKLb4lFol5bXgweGTe/PmaPwPlpULfA==
        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHtczIkaxrNyVtlx0mXarVac4lBZsy4t+4mHiqlpySUVtnvSycoQg0yX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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVWs01IkbHkIqQhfSqr/7ZUtbEyU5HmslRZed1GLdRZtKnFoVFa2yYmTY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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs8VWkbpemrPiZqSkzOSAkNZYR0ymVJaJIun6SSSCWXKUkxiORSuSTm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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lf8bxqWIhmQlDVKkSCLSvCRFSUZIw6yMfEOIaAklJVmVkKIoJcko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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41AkbhqdJ22E1TeKjk5rSRnROaUYeRca5KJlCtVJJoYOEHFM+lQ1p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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81IkfxidlETJRlEqJxrFsx2uzzh5lVo4s0VSrQytJjtJhdztUtBQ5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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns8lFkfR0St6CVspISkSCFE8aUVyqW0RUS5rK4qQ4m0MUtyLytFLrkl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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c81H8cxynJaGiJKCpKUkaSSl5NKyEpSlESJVSISEZSiKJkE5EVhVAo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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41QkUfU8mLRrU06KZQraSR6Wi7SgZpZKtoo0U2pBIsoQUxqChV+jh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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81IsaxskoIQYlnY4l1G3RlSWpqx5OxXES5aKEmsu0cWRMZUlUIo7O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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk41Gsbx1WSFielhXhxJEtSSEXJV0lITrZDoogGUSnTJpF6i96SmCTJ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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Ve/XxiWUiJLSoIxFRdSXiugmREgyNCcNhkrEr0GUoZQxNJCKFBIl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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlGk81IsbxSfFRf8kpJtCXWu0y1iiUwgpEVJZuiJ3pGyFFsoWIZUKt0Uo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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81Ikbx2elRMcmtLWxUTZyTDZHJe1nxbZyxC9Kqdyi0j1FNqJDFyWp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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk0lesXx5UMlaG6tzQRDaZUJFKGL6WiopBkDKmUuShaFfrdFCEUmW7G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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwdmHk81N37xu2KRCkiSiWVFCVZ61KpyBIKFSVJaRMRSlrsVIhQEfJICEmI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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81AkXxrE2XWwkqWxsF1Nt5bZSVsOjcW1zDVuUkLQURbtewqqU62vl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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs81IkCxb2yinF7yM7Kbksvj0gqXKxD763Y7qyWItE20XiGlSRGekpy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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekbPkQZbZMRmgilkihRSOouTahUHJQ9yZpdMkfZmqKmUJnO1C+S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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k4VV0bRtJsilLKHDKUXhJRt4o0oAhlyBhKGkheJVIkRaZSIZFSVDK8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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs41Ikadp+ohhJKCItSpIvctryKEtnUZjXdZKVoKnGi0EopUyY0SheX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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXtUzAkDHYVTWUkqsz0IiZaUVZS2Lj0kO0svpKEmdE4PCqWi7bGVtknh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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lWkf9klpytiibG1Oja1CKVK5hS9rMtZTspR9y8RkmSmVhMwhpU6y
tFimRNORdXCQ/diXg0OWFpWnEVpHGuZ7vj/e673e63re53ffv/v+3c+z8Xiw
rZewkJAQmz7/f++tK7b7/lM9hlm67oG7CKz8w0468tpQnXMurs2J4PcZhrm8
UxbqJ34cfLKZoDti5FFTBw8K4s7tJvYE8bNb9Y3j+ejtyW56l0wg8dOfKmLr
OtEk+LYiwYvAPVZ2fucvaXgf/H780CaCPafqlOzle2BWeyzDyJogUEncx/0D
H4WvJ5gagQTPGtZ3CU41QJ0vZZVoRtAU1Prc37UDyp9OhMQdJvj5iktbSckA
Fpq+mtVeIUhK7oku38lFiq5DhvxOAtXwapM73negnaJQMkTrxbtsk6m4Ngw5
X5ss20aC2fTXMk7uNTBK3Rsrv5cg9IDSm61afXj+cSibdZbgU4Zwde2OOjjt
e2izn+5nMSIuqTDaA4xa8TjhBJKFClJvdYogNmFTP7CFQH93j6lzYSNWWnLf
pVO8Igua2xONxpHALU462U2wwdLjzc7NozjUfLvBn0/xDl582RAtQJlYg9Tk
ddrPE2v6dIRq8FFRKl1bm2C7YHBLz41RTG5cdkHtGUGJe9B1RI3izvxbRn4G
Qblba9Fz92J0SFaxWJoEAX/OTDb7DUCn/NohlasE3qkHzx+1FWBirJ4ZkE8g
lJklw5DsQPi/Ce29jgS8NofIquwuRBxJrXC3ofjcy6RmzpSgW5tlr7GV8luw
tCh6Xw5Z/0/cGi2CvHdTKw2a+XA1dkZhAPUH0+7b1Ic85CyIPLtL/aAeu9F4
u1gFVsSYqDVvI+DYV063p/ZB2LNi7VAMgck66Qe5Kp1Qdy2fLztKsODrXHhz
phf5od2LKseo3uUJJQeP1CGhvnKyXJf244uxY6hOFxYrtr9bbUtw/57nmtJY
Djb7P+gxVyUw7H0SWqrbg+9/3+kaRf9nMi6nLQx2gFsWKLnPjuqVcHhwSLoZ
yh0tnj2g9T3yDq5X46JWVPJRDeVXVcqQkRAfQ+nx5W8qMykfV6YRYXUgQpzY
7TpI8Cgl0PaeHB85RauynLwJ3sguZdZIDCNXqEGu9DLB3pZLG6w/j+H8dY9g
9m2CTbKvQkLanmBvJwwuUr8ERmvx2lP5aNobqf36HMGK9dzsPWcaYVAy5aJL
8Zgpec0k6/PxS2zTmAKL+nu/zq3s4D5cFd2z7jtPyo8jEarCZUPTWc37bwbB
uctce1X9egiHWeSEmhAsXRWtZx3fjyDt1DRVNoF0pMil98m9UL/M9heNJQhy
uHj8t2eDyBddNyt2jUCHl7v+b51+KJdm9MXR9VOx+84YFDTAa/a04J0+1UtP
fW5HDgfDM96Mf1UIriyLfMpMb4RPjPg9P0uKZ97uhavzJWgUr50oV6b+Dnsq
3mFSj937/OKY/yXo8D8QEL27A8xX5nKPTSne3tDGB1+i8PV+TeNRur79is0X
P58uWN06ohoVTGDNmntQMtCF1vzV26rpPL/QmdLabV4P6fGoiFY9goiPY9Lu
P+TA9jMMR6m/9LQd+ourL8LE6MhffnQ/+Zsn49ObxqDn2ZJZQOeh0vLAhnua
3Uhzu3BpUxDVSyr3I6d0BHU16U01NI/4IVn/rA4axZa4O1eXJRG09oRkFfr0
4kLM+dtR52m/CmZypoPGoZGidUImnfpJ8DC5k9GLzwG79D6F0PwwtVR8GTGA
7uumQiG+BD2WQb6FaU9xuuEUW5BA+SXMJipo1MLIaZWiIu3n1MM4dV5WCSaX
+Ez7ahBo8aYSk50GEZr07xGXaOqH/AKG5c99KL1/P/NiBIGwz3D1JaUh5H12
kjUrJvhnJnn1kw9tqLp3NXcV9T/7eYWNoTMfBl9FcmfPEKT9avhgA4sPnf2f
POsiCb4cU+ycNR+CK+csr+4XAt8sg8W3+6uxjHeJ0a1DkLpizR/trqUQGhe1
T6HzXJBpmsoqHMZ0OOeYLZdg0tGe2F5oxFe5bGvFPQSLr97WsDV6cULior+r
H0FyXrLcR5ExCC2tZ3cOEBT9eLOsv4CHhMDeU5Y0v0UyPOsX1saDNTLtHUj1
uRNcyn166wpev1t/bpF+by8Izxrb0Yf3i6NyIj8RnI1zY7TMdsMkdKrmpgPN
m1+1VHdXd6Gh7aHsBx+ql6Ppf56L1WLYWuEVl/pB3Su2qsKpnfLV+yvGgsBJ
bIdNr1U3Sle4pt2h+63LFrmmOz6IpxvU0m1of+73LDqEx3TD0NHpV3kXgtO/
aUlajN3AuQd8tyo6TzbzHi8txtvhHnm3KMCNIEPETN9JqQ5si6rCLjq/UY1L
DfcUj8LcysW5Y4agZQmj6rbDY3j5hSn9pU71tDwasH86H2HxLN8xmkcTEuyg
afUapIUnpUjT/HOXVeApc27hllXXqz30/Pnt28TD/uV8VP6wy2CA4psLjncL
lxlElGik/hCHrr8cPuItnI40GTPzzxTfzzrJKe7CfajcbxvRR/XNwVOxmpBO
VOYNZXDdCcRusx/NZLYi6qyk8WbaD6EBya1Dyi4IO2mZuJT2O7Cr6PANSQFm
XEX/0Syh+ulPsmwFZWDe1QvTpPprMctSmvrLwRH84beM8pF5KVxes5aD7762
Xl6uRvPNjuujJzqKJL1c7+uD1C/yt8+aGjVj+dzcQw9a75xveGTfhnBMHN+n
u5HWq8V1D4+iUnD7Yl6spX4XmuEnla7hI2Ekqa82nuDAdhHZ4/EcqNjzl5jS
eo5P2I+XnOJDsaTZ6iadT6OQXFbzDQFYliFSN6Oofuy8bN25LtyXWJ415Er9
yzmSOfi1AXpzNquUaH7G2QUzh2X6sInx6O77RJpvh3ae3sXrR6d+p1dKGIFi
s13g2vkhDG7ZpmJO8y8tZrLysKAXQpwtZnw6H+XGrVzmXBO0VU0yS+j5xxx6
HG1h+gRvDVtWatL7gH+icmGn4gBufZCt/0bzIF7NqSRQuAXibtJa0kZ0vm3O
iPzdUIT59pfRypRPd3i05GaDBihk2rwcMab8/Xfbb02rgvWa77uO0fPsfxU2
qsI=
        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8Vu8bliQrq1RktBAaykjCJSUZJQ1FFBKyonxLiraUqFSyFTJKVkhC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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs81IkaxidbIrRY12yMbiZkiWRQj4rI2RSpkJDKdqPO6TYlCRXtEhWy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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHlcjIsax6do0aJNJFEhLZyUSkR+aTvpkkLa7klki6HFvtSZ6KIj3VTM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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekbpik1ojFpQcqSQRJNKGv3SZYWFUkOKSKJRHNCtIwtkq2FsqQk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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8le8btpJQoSU7mRlJSEOXtJCiEC0qfM1KqJSSJJVQUZFoyB4VOrId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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk81Ikbx7EdKCUh27GNTlu6NktRPpUOllWU2dQmOZpRZHIlJmeHhJiU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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81IkfxifpVI5SWpsa12STjaRDvX6PDkKS2rDbboU1dPx2NmlLWCmS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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lWkbPjMkbYpMEUVpCg0RIxm6fJLsbcgZ2bJOjTqIComjyVZK9siQ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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3cglm0bxhG9KqFSSShSZmUkJTpKUiIykyhKkopIXiSvVEaDQmYaVoiM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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHs41AkXHhXFWumeTbKiNtmSbLNJXokS2k/CztamqZR2IpLasqFERKw7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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGs41AkbxufyOpTDeqshSRubnLYccghbbluolk2hpVLKJcd6pRRSDpFI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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8VWsbVU5KVJdKpTJHhIqk+rBcRHW/S1yhMoRDaS4yZSpKRaKkkOFK
hsqspEFHHcM5xDnG0zEdN3RftwzpnnTT1/feP/Zv//Zv7/d517OetdZ+Vb1O
OPjMlpCQSKHXv3fWwtcOV6cCoc9RkldSI3jya4X8K8cm6IiyH2Z4ENTFGsoF
vOKgMGj94oPOBIz48G7Pbh7iUlWlGDsJJAa173NtjkJeyUd5Pl0fdbdldnpO
DhxZlidXaBI0eu4eVfmpD2ZDOntDUgmYkgcPpVQ0IH7Rqhrl3QQTP7h7VkY0
wUm1bLT4AAGLI1PuGVaKv8RyPtvWEszLXxQ+tewV0gpP84wMaT3e4+wuIRuM
w8tO1FsSLLHKFG1934Yzj6Sybl8gmFbR+SV6bQZqMpRt09UJZFcQ7d5pPj43
x3r/7E7wrWp7k/e7Z/iMEJ0uXQLzuJSHXkuTYWZUrGVJvzdPbjzlyI+FS7TN
1WO0nz3ibDWLTCEyZYa/HWomcAiwS0z1E6JT0n1S8h5B7sei58I1N+BiJTHI
pd8HDFj8YSzJQvqGtCh3I9rPFocG4ZwkJFjd27SZ1s9rWh+gHduBK/fqRE43
CTbLxd3X1++GYGtvqlYQ5TOmIdGz3h5fnD9N/1Al+HmBFlu0qwMR8UVxj08R
6Prmjn0UdCP8ZtvzWcUEM/UhSarOfNwVXGm19ScY6tmRWp4hQPqWtI/VVQR/
CQRXJzI50BRtyxVSvrjujA9Z59kot17hytxC8GKd1N5HT+sREzJY5bqNwOUO
P8xY/RlSJdhSg5sIZtv86Tgztw05KIltpfhkm0vOeOe3Y9PYyhG1eIKy6Jhn
dWOdqNBx2BdeSPeXDLR+YFqP/fJzirZZENxh3FLpiGzFAOuK48s9BMG9B2cN
t1Tit33Wi3Io/+qTxo3foltgcil1rps1wdHa6zP9twV48lp20dJzBA8rlpS+
SOFg/HKNezNdP+Q2l78qj4sh17q+KXOCbBL22I3ZAO1Ldeqi7QTsbEaaw3/6
URPrMi96nOrre2T/tHUzGs0cMm9TvfIeOYrHrTgoGBMeqXMhKOCWag7ltYH5
MW6mjD4nFv30m1rQK+R1snJKKP4oBemyt8PX4GZuxqmi85VgJrialfBhK+mU
ke9Dn1OS/S/KP8eWsj/+nruRwLGjfUDMegOtmwrL/H0JOoaCOXa+TQgVr3ZR
2U/QG6973TJQCO6f/gf139D9DRnnv+fWwrf3lrMi3U/xbZVRmgYHj00Ut/J/
pXiVF4t3vuSiMj9Xxncf1adWi0ny7CLkFs+dv536q9wudk/hnXb8YKbGH4gi
UPG77F6+nI8XO4ylc08SjNppz/pLhocrx0z8O2n/jI3Ft4RiPkrXr15uT/GJ
WJ1TnzIyMMm3FFRpUH8VMVO9OI2wC4wyC6X8ztj7z7cWCRF10Wh25BXKp/Pk
uhV/VmIVf8B1EZ1fi7Cic1zmGdwDzKz1DKje01rtV6/pAjviTtPKFII4hxRO
p2Q7ZrJU+iyofnjvh75cvsBBbs9ohyXVo8apsbez3VtxRaxX3LCL4Om3grKB
qWL8lKhxkUv9P3HDoDI9vhmvJVx11tlQ/irUTXRFL+DaN/P7/vUEVic2Dvze
Vgv/tMk9t6hezQ0OKL9M7oFS9Go3M4o3cb7p7yeXNcA3yWbdhf8SlHqN1Ag+
VUFjyWGVnRT/HJu0kL2XeAgsctmW6kXnqR2p5GPLg23n4vOSv1C992iy4cRC
AOc9M2or5Uf32pMJ+3Y8Jz6W14/S+h5Hu87tZ+GLfPKvshsI7MTca30FXWAd
NyrMCSa49L1sTUlyNYSpLvxjFK9jsNeeI6iFa51xdTMIQnP1+almHZj27Wa1
exKoeY40Rx/rxUyU6WqVDgKdN65qwd7tWJvm8bdtJEHyoeqoJm4pArdnBXK0
CLYUqZwmT/uRpH6jUyqD4FD49b7pe89Q22iqcHwzweGRl5WN5nyEvb8QfOw0
QTSrZmF9ThckQ6yqHxTQPH6Q8uZ4awvWP9Ww/3SY8pfP0JhqSUbK2HhLIM0r
pk1/JeteLboilvYpmFC96rOSid5zVLa+1xTTfBOZJnuIm3gQ9j5+V0T1Guw2
Evzow138T2XvXfEa2n9IS4xcOR/GXQnYeozye7o79ZFSA5Kkl/zIpPO/NGR4
126qDYe8/Dz/pvrVXGp8fSS/DR47ZpwaqH71EhZuK1rwFh9d50jqZRLsFu2v
W/xPLtQtFJraaf1pjAd9HhZgUu5yQwB9z+7JG/typAUWPtE7/6HzPBk7y8w2
rgclDvq2Z6nfvFlZMdJdHYjbL+GdF0qQGbY0e59yL0JvjDJu8yke5qUFJnIN
+NBclcU2o/33mg9u+MCGJyexq5/mk0iUd4rZlY+vMQeUt1P+H6btMr32hQ/V
CGfVSZofZ1VDJ0uSOqHiek467jJBiqGNQvNwNaQKXSIf0P9XXZvnmU0zfKiX
6BbYuVF8vSHXDE/cx8t5nd4/03rNkyvH2UGdmP762k8mgeph9MA/MUY9MPAq
FC+sIDCo9dObCu/GScVbkVIB1G9T3WrmDsUY/bp37Q5t6pd4vXfVxxuxYXiy
5DrF/zlo77KNNN9aTBnpg2dpnmnc7014lo68++FXnajf7cO12iKudsNa0iDs
cR7Bvg8nxL5ZPCg0OPcfpnp5XjA+fOLtK+hMhoc3UvwKSVUduxQF+E3zpvy7
JJo3O5c7R7EfYsmDO5+0Kf6wUNtGY7seHLFebFJVTuc9b8OEnlYdPJabfYmi
+ngr90OmObAVLRou0l/p/1i4eZnsps/d6JXtbtPOIaioUA0ItugB12ntqsRr
dP0Rwa1FM17gSc8Z+Pd8ER/FPfojpg6HHwlKU6g/b/oNF150Z8O1fcTGnPpz
04RmYKZtPayKJb141O+Kun7rV3HZSLgQcdaA5plssduD6ZEujDAFspol9Pxw
t+xqv1M7GJtfDeoz6fnHbmgyO/gplMp0z52iecJqu8GwCk/A05ndRRV0/5rx
pqBqzQ4YntL8nkLn4+X1Ii9OsR2JEx4h66heeZV2Z24seALTfQUHBihf/wd/
hL/Z
        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Vd0fxU1JCKWoDBEhlZAp0ZKfJopoQqaSIsqQdCuVyiskIa9IGRtU
ZChlnudrnq45SZxzUSoJpX77/es+53nus88+e6/1Wesre9zdwomLg4PDjpOD
479f1R3dI1GDz/F5ozTLbRWNc3esjo9/zYaRZd39a5EUNJQYHgNUKyqfWLt/
d6UwKBEic6wmHF6rbe7vUqAxNHsqTfxKCdYvvr0gPoWCwr2AadP3PYim5H8E
3KMhSFWZ/lJuQo3wtOGpCDYyXE0TKipaUKjmFxIbR+NGQBJziyoLHstDuczq
KMi9XS0gb9yCznLn/FWRbMwVJt+ryOpAWH5kw99uGuo3Pd51NzTjzfU9Ckc7
KOhEGDk715cgsCY/WrqNwi+RybnR9X0oCB06uv44hQKb73+E7bKx81ykoQ0H
jTdPh3SORGWjxPO+t8oUBcus/IP+y95Cw3zKXpCThurGV8dkg+Kg4i5k46dL
nlPnRxYqd8M6tF8UqiPQUwrVKN7XiALVuXdGu0fx2CYi49mNDtAhP2679NJI
acrbFXYmD0W7O8efLqeRde/z8uI7HXhtEpt4KYuCQ/xHAyOdFJhH+5xpV6dB
ybhtKwptwqFj3LVLt1K4Uy98g2d9F1KPdqezatlQT+HKqUwswZ9DdT/Mz1Pw
c9TbpTtSBI6TJepL79A4/p3Xx3NzK3Lnf1YOGdHgGLYUyJa2BdPZO3tClkbs
sk1jm9TaMfPP301m0aNIlZA1LBnNh3zeohuzBRSsg6NdLPayMHRSWnrBGBsz
hkzOh23tsLgWU+glQd5na9wprdCJ3u0dypFzFKb+LC2UTCwFR+/y89wWNA66
DPlXfGvD/onc8OCzbJjorzi06m0r3tj4+M+R8++SnrRaZtaBGxt3oeg90ZP4
sWuNmc3w+H0+q2ALDY08Kaa5aS2CRfmW0lIUUqrV/R/vbIXk5VQDs0waRcnf
rfykemC9vnoVK5yNhMItVfEXkiEvLDEboUljf4qXjr9WJ3byXV5YP8/GOsv3
JjFLaxB8+LHM+5dEnzkK66vdBmAaV8Y/mcfGW1u5c9L6bUhJFktjKI6ix2hy
XT+zD882TwvGiH/C5E+5vtcxTChUMuuTQ2gssxX+sPt1PwwuhCaI841hJsal
Qv5uL2LuBt3JZVPY8Hiv5dfuGgwqS28WcR6FoRs/07ukBQV679XspYhe1bxf
Fbl3YYKeuNwnP4aaVfaDi4bzkala37SOQUH14IzEuRpf1NbxnlFYQ+N/Ij56
sTmFyNy88hxrjILN2Ul/R7d3eDjneKFsgILyooiB4l9t4Dkid0XVgoLdL//M
+lVdyFCOKc4gemken5/xXZcL5RMLmznkaKww803L3JwISykHVdu1NOYm0iu1
UlnYT23d4Tswht9+5TyCVCeYggHOX6JptAtEmwXKleFJw9iC40U0QsJ4XJx9
qxDnWrr27j0KfdF+x56vY0KGUXbGKpzGsKmbW7p/PjJGbNTqLtF4ZCJZKary
HCVB4fc9lYkeHWuUHgwE4qpWnJyXPNnPkh+LxAOr0PPkxWD1J7L/k0Y+72Xq
wWsh9vvPBAV5nsa43cKtCPH7Z3R91Ahg4uEaQfwfIJi0XkNlBDM8t3Um/FjY
JOZ+oMWWjVD9PQe6yjuxcoHnR8kxGn5RRnt9lKpwRQXfgn5SEBs1CS4WbYVG
qOUvj2AaNb7HN5c7Z+KPlP3Bb7/J+59ZJm/rKEUWa/RV5g0aBoey+20H2sAs
7ost3E6Bl5/X2imqBSd+1dqt5KZheNlp4dGZNuQoFj5wjWZDJiRzIHdpDiR0
jfqNiB9dzoccj9rdgzwBzisflYh/6fm1shrN0OfaG2fUM4r0Zcfsi616UaDd
tUmjg41hxa1U5IYuNAp7Sk2aEH74L3wkEFUDBZFFfNuX0og2Mv60V6wfp3Wt
zZcsJrxKemHKEHmNw7K9FluJvh56UM+vX8yCp2+sZ+RFGpfHWQW7zZ4ipeGH
7QslGgkmkZwVv1iwPrXc4u/IMOpO7Tv6YUUuxKQ6evmMiT926Ms8n+zGZ0V2
Q9qJURT1r5izvNoHX2f3/BWv2IjSeiYy19sCTflv6ep/KPxW3ciVZlmH3wGR
946osBG3zsGheaobASfLpybUxuEne0/woFUBMmoyqxKcyf1rtYzyLLZEQN38
k9VE3wzOjLQqoT5Y9i5TFvUZh8HNLv3IyRgkXlbKr1SlYcKfoCs61IbAZxox
9TMU3ljyijU/KcO3+wHP1D5TCKtt/+66sBS4kPozfy+NjARPqD1rhhJPcOZE
OYUY80ah5tZuuK2c2WDoMoaUfUmhWu01MPw1nttrTuNswke2Q0wr5Bel6ZhF
UPC41bu/sC4R+ftKh+oIT3RzSkQ57FrwbRX7VEgOWT/romPVvgq0XMiuOhtK
gSM0xGuxmQe0lplFsAhfBa9rLBE82ocndx3XWZtTGNiqr6s+WQrurBqf094U
eiaYGq0d7XBNYD8fXTMKjgIVnvSv1fDi2tJIS9Jw1HocqxPUhlS1S2vUZEdx
cPC0XttsE2TiPN1diH8Pvupv1IwpwFW/Q7uPniG8fJxqfWC+GTyS20MFemh4
BedIiwS0oNmBVSefRuP+QrHW3FAWea9nkTovGwpP4zxeubTh4bUYhVzQcC53
uTkgVohmhUX/0z9Ig+f0mEmBdjvK7eIbewj/DXaVZoQFR0B3V27ffmkafzoe
fmH3vYHhTc0XsYT/EWtXd+zY0ohK8ZWRVkspiHzXbdpaXo5VB5UNf0pS8L9d
u3WWsxrOTxY78FI0to03et673od9xWcDzUj+7o/Yyr/EthgKJez45HYaMtqt
WqNlLzDW5K62m+iVcVBqnvasg0CPQ8+VZRRO1QWtja1vg3P/B/+aZuK/l8kd
Pow8THtmX/+fA4VL2wM4a507YCZ4Xs30zQiUcqrDcnaUQ4Fx9fApogebAwa+
oQ9KscpfsftwAIVreYWytEEfHLxndFz+9wl+/iF13v8Gg3fte39FwieN4DHt
Rs1uXHT+PthwZhhLKN863itluGE+dt2PnMety9vsf7jXoViobLdOOgWDPfHJ
MQ+74bvX58zvlDGETUlL0cHpaD34fsELPqL/dE/FgqbXaD1qzP+Ln8ZUJkPh
lVUXzALFp4sZwyhhe2Xdz8hCTfGxmS0+NCz3rLLT3lqJvDuVn5wek/WZ7y7v
0E6BqVJu+6gWjd0PJPoWjjSgID7hZJo9Db097uK/LrBQvap6dsEk4dG35btm
1paAb+jHxPWPNCzK6t7029VDpyi39OwRCr1XjOuk7VvhOc8vYxNEo3GR5tFG
ji7cHpfRSvSkIN6Syb/3SxMMjVKS1D3YUDp72fD2rUYoPcpuySA81+vPZUZq
MfEuaHHzQBfRZ2zIfWchJqL2Rnx3IvtjL8x2fN7biXH+SbNvxeR7LqSeXOzz
FsHPAuQuER6orhtlmO9sxH1z0caBGnI+j61v7WxpACHk8aFYNowzuOM6NtdB
sVjz9Jgd+b9Qeb6BdDPeZjN+6THI95vddF33qA2291Kn3/FTkGo33/HoaR9i
VxZf8hz/j0/vhp/vb8TZy82PlhtRaHuJBNeySuhFer7koCgcv8XZZ7COBR/O
Gfkk/jEsn6qSYd7oht0d6c2DP8cgxOclevNuLTo0o29HSxM+mE1frZhMAr+l
RdFL4sdv8YyUCyIkD/YnTDnN0AiU9YlZf5QFhc0PwkRvjeHhkmjT8/wVmM77
UZ10l/C8pClvWjAJJ7i6xusWEx7bzjpMB7UjUnfdqwJOwtegGE3fyVacML1f
+nmewqqxw/FOhkz8vhnz2vcojQ2ODdvun61HXg2XnAn1CU5LlFgX9ViIdjG0
liV5ziFivM1RoA28om89/y0cxR9thsTAgRpwvnhyWpb0aw49GaW6Iz5ENwE/
pwmvcjYfHj6U3IlhdmPlAOFHQaV184+aUvAm8s/7LSP5OHR3l/6qKsyEqJVO
7CT8k359oVqhG7tSRQ1ZszS8J2w8UjuZkHRrKRlxZGOQ9XO7o+Qz2NRVvpf5
S/LpxrulmoY9CPdfv7WbbxhlY4xkZ8025Pl9L2X9IXzRGTY+cvExpm0bqn1E
yfr8m7VWx7RjaNvfP/xCJC8TXRk7jrXhhEZoRxu5PxeRc5P6AzngKN/kZXGM
Rtnpxzfzkljw0wu1r2ST/Gd4OAl+aAaz4f3GvwfZEFPX4OvaXoqvCkkS+8g8
oXpU67gcyYvUOystJ6xIP9CL3zOs3YzdAVKThcWjkIz7cP7JcCmGc9d3ywzQ
6Fpo9ciutQV/moRGPhH912/kdHNfUo3XDDaXKfHbW+EHShXEv4OyV/fHkHmg
5sjcv2jMg8mHxgvXD9OInArszppvgCmvi5kU0Xvs1Jk1hYOtCJ489KL2EDnv
M51G6jztmC66dE4A5PvYodZZwlVQO7/n4lIyvwxP0R/XaNdh8u/KgqEzbFh+
Tp5wOt6A1NKr/m7Eb1xyo2+tZlshdnT1xxU7aNTHTWaqf2gBx125nW8LRnBx
R5lEhF0bLnm7Rpxfw4bmvtOvrvN0w7OdV9E1icLI3q2D1LkGDPNtl/zeQsG3
gV+AzSZ9d2B+o2IyjdkVKxvLMjuQsmms/6IjjS9pYcEDTV1Qmn0RKqxLeGBa
/c8mtzo8nf6ptujrKB7eEhDLa2XiUTO/sthX0oeLb3rwhDaiziGz4uRKmsxn
SlXD21vRvkTI5JvrKJr16v55dDkbbce2fhIh+w8Z0X//yKIC1yxyhNduI/dT
67dPICyZ9O+MkmsraBTb+nL3eRN+MZb/OkDmyZNLW2Q9KwZg6WJy8McHor+k
XeUL9zxAXJnuJWERGnzV8+J87C7kvy7g5HZmw4KK8Us/kofBPVRs2i7CD5OS
d9s2FCLt+WupHYRXOebcGiuUSB7rcGhfvkL8XnCOU9ooB3pMzukzt2iM7Ao0
VDtWBt86o83dpD/knM7W5+NPRn6Mk1XQEjK/5YlZPLuahUQPL7+/tiQ/Su39
v/JmIlp5rJSD+GdSR5sx97YFcbYf46JjKcjon/x7n5WK8YElaQxDGg7Z5iIW
lk3g1hk3NiDz8792TlxO39thvKLuw3biNwPf1YeCxKvRG35I3G2I9I+4lU2n
p8twk3npQH08jda833O377bAL+aGJjeZxy2NBVQqJsogGRzGnVg9CodtlaJm
3+Lw8OG6oTI1cj47O6c2jWVDkO9z+ONNNHKzHE0fytWAdwv3A08dGoPi9qeC
Hidj7an6nkSynuTlfafOLWhDvInS5/ThETxoi3ieEdkJmyAV+2kzCi8GJfx0
V/Zj3y2NmtqNY+D7s1bQqjMHZ1ysAs8I0xAudJSSKW1CqlGQ6HfC+z+l25nX
NnVjmZC38qWnRN931wo/+J4BuUiFHF8uGnvlvdRna7sg5KY/ptZJ+lVr2YUh
kk9hGwqOPDg2AslBbXHNl6XgCRJSa9tM8nSbSNRekw68SdcMC3tN+PQs5k76
0wIYnPPWKyX5u6KjKsP0bBYC5mb+TbIhPNyr8bT9gi2Onkso3kb66N1z/Vr2
15qRJ1O16rYjBR7TnODtGm/h+01u/APRr3C4J3ezJwvy37/cTCB5dKL7YaZf
UwWqdDS/hpB5gSPIcHVqqTtUrLm0nAhfjy14WnR4YSe8GMpHNCI+IWy52hPl
8EhY3P/tNixO8sxVxW7N83aclurbrE/63+zD1sx060aoM/aN1CwieW8qPjx/
4jFusbalnBIg8+/h/GBtsXoE/zSMl11O8iZoRb+8ey6SNY9+VCym4Pzqc3jD
7WZIfpi0eEbycIXwV/PJjnfgMfzRlvjf/01SO/xq32LjSz3vbRf/63NvyreW
dKHgs5/JQOQYMhRn2ho0mHjfPKEZ5UBDhPuIyrBtPdxa7VZ3KFK4Eqjx5S/d
Ch+Xfc9N40ZQcEPqQzdXE3ad33VrKov4dVaCdyQiB8WdaofiiD7DuliVCY1V
SNBUuSrASfS98+xltbYHWNAZdcKS+MVSjis+ccEbfH63WmxfD4XgDZoLlXl7
ofTzS5/ATdIPf/0W2aDejDlB9WKWO41/eGxohgoTZUkXb6RHUdghq7pnm3sF
9hZ03gkg/bFIVFFVxpcJh27lRPom8UeLnvZ3vhyElFy95HCS6OmabWeHWgdk
kgtl/yH398dqKnUjmSe9mlTWeCwfg0dlgEfGtU7cfsBRlaZNI9H21FzoWD+6
6utX8r6gIeR959fTpf3w6pBWCetl48GrxRHHC1rxzZ0dvuhfmsxTjJqyth6k
JG89sTdoDNzaPkqz803wyHqi7H2H5E/Tp+afjDewnFh792YjBYfPB21eGdXh
MyuiPaeAhuimCeYF6Q78GFiW9msDBYGWqTWVTaSvLzP1n+gl57PoaSR1sh8J
yeZvkpRGEWbPNlZ8kYAArwtGUxtpuK9V8p/NaQEX/9ls/YoRHHkY3MNL1SLl
+tnlb91oGF/6syM1sRWH7Nt1u3XJfPMlqlrodhEW7FE7zsmkkHbebHTqeBk0
4j1E/+sTI94tJ+KvlWDnuJv6M/LsZ6yo7S17DzOf7s9tJ/2n3bX0b0BWCVQ7
u5rekH7j5Pw/0Rr1QrDXVAssInnb+iFGyMmhEz0+1oKq5H6Gb8QnF/0ogZKQ
wyXGWQq7Uw+rFRaS/FG7pT1mQKNDdzZadScTFfPhhX2kr5xwi/z9voiF8cDb
L18ZEX7u2CPLPdQAGQaXkpP7CFJszh6eKizCCedIT5ciktcRed2MiQYoWkUN
cZP8NLAROd8gG4I9eWlVNPF3YPOLmMgzXbCt7gjdJDKC6RffJDwWl2Dm6gqr
LSSf88tfnoipLoDXRNarp7sJ7xSfSf4IrIXsvS5vt61s6Hl2XigPY6JJb+m1
KEEyr3x+nr0lMwLVpdOxw6QPH/BQ/ZLdU4/U8JLi9Ock767wmAtPt0K990D6
G4qNhAqZ/fYVb9Fv3v/mBuFRYLVWcJVhDs5FGAUGy9A43EX/De8qQ5i51DoJ
wjMP95Osv5fysEHyX5crZP2yTZ8HfYfTMbxUQm2K8Eisnn9LcXgXuFZ8Mb6z
bgTNf3lz9Fcl48BuV68w4i8DFK0ztIvGOb3la3QkaPwfXkL+Jg==
        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk8lQkXx29abJElyvKqZGlPjdSU+slSkUlJlkKypqy5xdsQY7kjEZMU
V5ay1FSTQrZGtOLicl2ua8mgoXuf57lhLEPEe98/zuf8d87nfM/3nHXugbZe
EjQaLUwc/8+57jdstBd9wCVVFu34GwIVfcnVOtMcSMT/LkmxSVj8+6WCvpmH
lVbyid+1KaTz5XzHapsxMvQ0MXk/CRrPVj6koQjBW07H1tYLkbsiKq6QU4qN
fEbxqgkhtmlYh5bXcNH+o+a6XUsonNaOOrDVqgs5vs01qvMk1j4d+GJ3rhBW
DZcvKWUJ4TqpE8siW5G/9ub1qkYSstLpc/ybPbjSssX0Yh2FLaJ4kZwMCwLf
3kltSxLcloiRHfvfgXmnVMsqh0BrMZ6o2X1E+rNb58ZuEmjne7yeovcgbcyA
vWK1CG6ZajsjAx7jk8JjBc0HQgTtW536jt6Eub+MLezdSZyU+DzDYnTgovXf
lXQWCamDPiKL5Gq8nlkawvwPgS2M5O8b4jhYuLbXzk2CAs1TT8aJ0YXdG30s
c+UoeKbfqmIH9eDI3T//3q4igiDruPrsmT/BUEm69dyMgLpRnKlWfh8ecpft
jbxPIfrxlGyBQiUM5VycrKaF2Hv/xtJdfhyUajkZ+dAorHEwcX9yuQfxu2OO
6DtQ8LLx0Letbkd6tb3N9bcksmefuw2t5iApbcHFj0HCOlnzjINDBzJP+pS/
CCdx/pHi294rdbCbedM0r0jiuUbmufgKFrRc/HfpypLo4/ZaXo3vxqPeJkN9
FgXNT9H5WuV8LE4+2+XqSeF9Djdy06/N4MSeypXVIGGyLXuxnU4rirYtfi2V
ScJceU5WJ/M1rKqmtk5oEIgq1v9NPqAE9eEqDg8bhci3N4/2zuFB0TN650Au
BdM31NGs6zzoGE4FLKhQEKy07xjxqscXPb89ju0ECjkr6WUyH9D6ibnWIEXM
K+3B+qpDbdj0s/Sdzh4SCklL2ckeXGTfsz0Rep+E8YeFtgvLPyJRZPnsyT0C
G9jqHuPXWsEZ+lLyTczHb2Db2lmrdhw6bcI8lkCCnzX3o5ZuBbxlWDb5ywiY
OBYf0jCIw9R04l/EfiGatI/u9p/pw/cO/e6uiyLQtCvLGxsqYbsw67xrHYEU
yWB1VUENjJTOKJYEiX2rm2WHKVUh6r8li8PF9Y4sqTD4WbcN5SJz0939JAxe
Bz8lPhchYIy9L6BViJy36U92ynMxmmJ9qqhTzFN9+AfF83wEDd21r4uk0Fus
r6vW0gRnsnGl2lkSLl1Dm1OCedCiVOTqv5OYn/nJ2lfnLWpXh4bzQgm8ul89
48Hm4FuCode/t0ncFpQs2N3hwPx2wAv1RyQy/P3cnop554QVnNE1oxBV+Orm
3qREFP90rCjukBBusfqaGqFZ+Ofy+TJDuhC+E5fSyraXYry6g65QJUS/ZOjI
wVc1UGjiBh0MJlA6/Kvbo43d2PGuT71gkBLfZUGKirgfr2xrQXAEidq9jAc6
9TzYDo4HKTqL9y3vkLdEvh0Su4/xhqQojI9G3XNpawUrNjxY0obEyqPS9kJe
M/iR+YKAFySmnTIMnMLK4HLcgoihEYhPoI+5p/JAU5SYFwVRkDJqvXtwqgbD
Xcx7DywJ1N7KOdBi0Ia6K1oDrGUUElxfenbs4IJe5Z3K7ybBpAZPdzfUYdBW
g/OKRSDxSu4nD596RDTfW2euTEJzbJqaHqnB1VtmjbGBBIyLtt39549aeEvP
NmZHEpjQWsaIiOmG67N844MJFPqt2XclmV1Qyhd45g+I5x3eYx+37x0G0yOz
e/MJ0PqPvmB4cKAUmdTQOSz2U1ntNx2/OjgzaYHLqgnYXRnoviRowzhddZWz
JoU5x7iiX/LawWB0VIweE/9XUfiausMlOB+SozfNE6Lq29Wn89tb4PhEaqLO
h4T3WWOBS0sryjfHmD38RMJWutsiLaYHgpci/fluCs57jBNlr7+H6qoTkyY8
AoNLZL8G7++BafmFnHgOBeMDo0L/4D6kxGxoDxP7XdoZLe37lY1oyVO/lBmQ
MNVLKjeNaIPxhS1vNjSQqOxgjg4J21A23Mbvl6TQ5hYiOpzaAQuuYKTDhILO
18PPJ8fFPN6k6i3SFGFT33ou36MTQ+YZVxX0KWQ7Kqr0fe7CtFxInLKqCCmU
svKj0YeoDNiR55AhxGMjvSwbZg+cV6RNnrcXIYrclTrjzYLr7wtqTutJqBCW
ByonanEn71LGtAeBaUFcofHLemQGyGRV00jUB0pt142vhMMoXUPPkMABJS9q
00AOCh0+XmOECVFGi0pbfq0R/r0x30+oin0TNG14e6oJkyFLd0wzSajP+S9y
HGkBTd0gzc6LBP3avqCIdA7c5XbG550R/0+LoxFWURVQ1/zwPFOCADtO2bOO
y0X1O3ZnXi2J5a6smSGNAlh6S+lnJwiReOOkTkY6H8uN+k+YzYvv7UZr+9D7
HCjKBLZkBArRl9y7MSmQjzVmTs3tYp/+B6Pl040=
        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs81AkXxodXGbdSlFzeUEs3oi2U5GEzyJami0mhbJtctiLZqGyUipRb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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8VVsfxjXc6kaSBkNuCckVzSGph6jMY6QyVYZDSBGSVEJIk0oIoQwl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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k4lG0bnqJSKftSKZQt2RJK4pRK5fVGWkibaBGJSqKVVEiJUilCklTK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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81AkXximUopBWSYyKqQhbunwy9Yi36GZZGiUb61VJWSqESpMmzUhS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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk3k81IsaxkVpODmhRXV1k46oKGnkcOKZNIp7teF0xpKESQctKmtoIttH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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4ldkD1q0kWW4aUpZkvTNXE5Gl1GtLNNNoJhTjkcaWLPWbQYiopAgJ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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4lF8bFkohSSVEVChFiShRNyopEqWolCUiFS2ItFgSoaKkUJZSWUpZ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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk41AsXx1Woaydpk4oWST0tyFT6qtxeSnLpFsN1EeWVohTqCpPJbadB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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs4lIsWxl1OVLpQyiXFdArdtTfb5PZK4+HoJtkp7SnXjorEkaSUM2Ko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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk81Okf16EQlSMphUiuEq3WEr2npkiRxCJbyZFjspOMHKmwhKxqoqRW
JcldGUch5SxyDuMaR5EcT7Xlh22jwz6/P+Y1r3nNzPN+3tfn813jenz/0bki
IiKJ9PX/d3MjuekMyS6MuSgUXrxOIHYoeUQSrZghly9IORB0rrFNfxqThyqR
dpEjmgT+eWqfG/bWYTm/JunwPgI/hu0u43VtmPeKzGs4TBCgz+n5HsdHwpIz
iqd9CLi5+1eIpOcjVPRY8286BPP77YbTJRsQWxAS9/UAgaV3SG6NgwBJJMM0
+w+CvO2hYlttHmHghXTahfUEN75t47D+bgJ3ySOOsy1BCu+CYkpVPZhbJ16v
3EnQo9ksETBQj6jf3zpdtSBYv2jgmrkhxR9sN3OyJ4jTjXr6+F4rSthxTfWn
CZ4p6/1wz+zARdHC5lccApNTW5YaHutG2LTydqtwgosycpe+V1ShPSCtKp5B
IOfhnvzZtwuDqorF/WkE3QFZ7d4yrTi3fLKF40SwyuUQc8qRj+EhZa8lbAK7
J90LdBgvQBWSs7UiUInY0HZ4XSnmm1rMVOkRMNRcSpg57RhUf9B8muLPG1n8
iXmvDlNcyVHfXwnSpJOC92gI4RpyJ3jyPkFQS3Tos2MC5Mm93uxwiSCQabTz
zywB9Au0R1piqB7sWr991vexXla6vHYdQXNO8g6OnQDJU76ljkEEB8P+zDH4
Kw8TEymyHC2CUKOtP/OoPiOflm30o/p4pMacNd7djUXnTVwf0N9zjUKnd45X
ITJJUbLAkMBV/0degGknPpKWZVrxBCf70hieaW2wfMcRyJ8kiCzSevKosRn1
M0PO748RxLBWiCg59EC7XD3ZJ4Fgd1yPUtfpNjCkHkb9Qs9n+OQtS+hvAS+E
OxlA9XMWWqsWoQ/PnHoLmTR/QQMq+U8NOpCbo9m02o2en7nRdrMo9WvPgcov
yQQDAqsVHj5pCJBJYfVQvs5bSxK/SnUgcTpbrSmM4A37n1WHlJ9hRfgcs/9t
pn6pNp03Ue0BV5C40D+OwC1srrhMfBkesmb95Ci/vKoqZvLWDNy9J8d+v5Yg
Sj67XcmgFW1RZzwd/Gk+pZU2xP7SjevfF0raZRA8CN7ow7Phw+2EwDRjL/XX
RsWb9a0MrKvWt1L1aR59n6g831GJwKMVEjMUf5+83Alyox58QcNH9T20XxKm
P3TTeJCWqr8ZQft0Nr3Gv9ZKgA+a978LIqh/1Ypey0T54P7bFP6bL9Ur3l3h
/LoiNP+15ZsD7YOSWJbznqg2ODkm7DjjTrDt7dnapq5aWDMLvvpZEyjskte3
FsmEU46TYqo6QVhab53e/CTsMlNJrFejeejbt2VpZiXqh1otdSj/vT+JDN0O
EiL5+qj3h1zKn5G6sH9NA1j9yuN9lgTG87gcmdnHGGFoZntvIqirfmtQNv4I
HxZmGAfRPO9L3NBVp9yAyZTfl4ZTfty83h41tXIEHvc5JUnPTw7VeydBBOgM
eq51zpUgt9gsYaT0Jt6ZhvGu0fskXgk2HjwkQNPbZQ3etD/d40k/2Q12YgnD
TLbsBtV/WcVG/cvtiD5ZsW3QmSAz7Fb6DU4pTK3vFvhT/KTj2T9XRQtgNNDX
yGMRbO4wZ2Rwa/B4xaDDAtrfME12QYTrNeywnWOynOI5pthq6/mUwzApZg+M
CdoCXHjip8rx4t6wapYB1c/8prKEYyXyb9uJxW+hfZa/Ei62tB6bZu2jdewI
Qg5Oi8WE9+NEzdT3rFECyWSTMx6llZBY7lSWup3ev5Zf/NCmCOLvIzo1qV/F
PodnZc4/wLY+3Q111O8aeXHR5wk1YH5e1etB9anL+zorPsPDpXW8m6LaBLKt
r6qbRruxsodpOJxCIHRdIEhR6YHmWOST7YEE/ZvamDtftyKAJSicCiD4fOfL
SNa/PZAauZI73Uz5zdEM9I/Nw0GXytqdFG/ctNf56tpGsGouPWil+j91Y5na
xBQjkq2b1k/n8aFSxvCFsS6IL58IZV+l/sSFfyqzF8Jg/uabD0poXt5VDl5y
b8GAerBxgBe9n5jdMyudcrDcf1zdRfX5oZ9sMM+/A0qlKeaT1whcDGIviZ0r
gb0449hflD8j63WvwZJw/O31PdBGlfrxvqCaGfkH1h6pXelIP1d90/hwOuwR
+LrMh8G6BGOvWyrixgS4lX4Hd6Pp/OBdndJZ0QozE/XMhbQPX6Q/QCCsxI3p
L/pnTAhE0jjP8zWqwZP94jnJJLC6PCO2flEvtnevVWiop3jTikGzObGo1Pmo
60bx1HeNluR+q8apUMMDR3+m+wUTXvkmhZDRy89ppfiZNTs0DnuWY29w2B+v
6Pd8+58Ga6QbkO/odd2Z9uuWGvnVYlc1Gp1yu0ap35bnbD463mtDg0XkBqko
Ok/dRkqG1vTDY4IjMS4gWK0w52Nn9UusXBQo4b+NIFs/WLA6lw8H4wn7CJpn
EdOIFz5TnjhYWD9Xmt7P/7l8gfGnXlRYDbkcpXrq3TqmtFAqH5NHOxoD6Pzm
e1TMNfjnLj42X0zKp/3udmqXP96SD4W8w4/v0/wUN2gMK95uwRPWmNcrun/k
zeJD8+/zsbtEQ9h5guaNnW/3r0YFuOpspSrKL0NlpZ1HURvST6ZaxO0nKNw0
T9GoiA+fnLacHZ4EOkGz7iNvhAgyf1++JI/OS0bympzgWuSbj9nsp/MvPvTG
6lHVOjRaTPZn76b7qH4w5MmqaKAzMvAI5cPdGZ69MSsB7z4J5+vQ/u3m+K/6
SvssbFKLnKX7a6bBxN2ntR2W0VsWtNH9nLLnLP/gqlh8SFhk70v/L2kx3meY
IcQ3J6PK3yoJnCYTS2WLOxCydjN7wWW6vzt1uHbPq/DDVPYNfiG4fuW14dez
rXhlkrq4lD5fiGp5xg55vcTbaVOJQ1T/Az4iG6ccK/D5ghJbm/b99JyiC9qW
Jfjb+60Xm86T0p7FrFNanZgZdjvlS/eNUVkWW1urHS9f+vk10vM+L59zJUOv
HbrChmvN5wlqhSxp7hEeCo2iFxtqEBxv67fK4LTgTYfCQC7V7z/jkass
        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VV8bxQ2VkKI5+VWmEillKkMrDVLIkNAkylSUIVJSaTZVNEjKkEqG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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHs41AkXZqql2lxSYbS68OWyk5IYQi9f2qZcm0QJIYXaIpdISOSSEhLd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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVWs4lAkbnklTSdkUUpJSJDqpzYW0t5KisMyKElGboliHiqmkqcjwJUlr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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lekbVppUclTUqImUNZGTtCjctmSpLKETQ5aUojAl/ETkVAhZEsZY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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VO0bptSXFi2kpGz5KloQyae4KUmSbJU1pUSFoiwhQlJIKYWSlEKS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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81fkax9FqK3VjVOrQSFJkGSoXn5Ol5kqTlEmWCGG6RREllTUmyRYR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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk4lAsbxjW0WU6RIk19aVWRIVHnaO4InSxZ+o5TokU+SXOyVEj6YlqE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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns8lOkbxqmtFIpaOWw6qLChQmNnc7imkkMhJMWGpZrsJoMVNhRShKVY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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4Ve0XxUeDX5MpiiQhSUhKGqySMjRJpZRGRRnK1EcyliSVlKLILJGx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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41PkXxy26aAuVLOkypNJtG0zIT96idKErSroQVpFKwgrllmtJmhS5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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81Isaxi1Nqnus3SK6yhpRH0dOWeJBKgkdkhRCIbKVooU6LdySI1TX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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk81Pkfx/0iRa20qd8mCiFEJJXW8ZoRouTaCYtyV4rJdmxlrcSSEitN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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Ve8XxZFKIpIyppIGQ4ZIEi3KkJIkSlSKRJokokgoJalESUlUKkMk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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs01Pkbx6l0VQohhIiwtWxJRN5iKKWbyCU7VOiyY0iSVUuxlR9JSZqo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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVHk41AsbdaUu8V1KKLTwaZm06PYl3YvDJXRLtHhKC1mq272KS5F0b74s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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lV0XFXozJmWIJDI1p5LKp5ZcigxFSFKG0O0lGYpUqPtVQjJkiCRJ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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VV0bxhENMkUp3spYoUmSZLobhBJJokGlNAhFSoa8FamUIREyq0ik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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHk41Isadog2OWU56SpRTpRElKXoNW6pUxIixmlRBylryi6hLBVKOZaU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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs41AkXx5F1W3JJslGUotsqSyXJVy4lmtZLuS3r0pLUiomk9FIUi1zC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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lekbxhst0zKplDBiJDtJipBckuVkrahQxpLtZ1RGkqUOLaOIyRYy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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8ld8fV0YaRhIqDSMhRKU09EaFUFahkpSRsqJIkiQkJaNoKCmSUZnX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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk81Ikbxxl+pfhlJKmpZh3LtkqptGzkM3SRFaE2IVRyTs4dV9GikyVH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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs81AkbxaeUVEgS1rrkVkahLZfeYk+3162IsVldlndJal1CEcU2iqzK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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4VesXRkKGqER1VYbIyXglUfJSpswRGlQookFKl4SUS9FgyBGqn6nT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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lf8bxlGSUWZGJEl2KEXmJUlSRpIULaVEQyWkRWmQ1bayQ99QZsjO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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs81AkXxqWSzV1TSSVkQ7lEq2yTHk2876QW0YYoijTkVklU3kgJW22x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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGk81Isax0WSJeFYxpKjwmQpN53KcvOjugktFJLtDsVRpBIOJU2LlKND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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8VXkYxg0qLSJFmrKFiEqLphKeyEUIubKlKFeljTZjMtUlbkINhYTK
UmmKxnbt3XTJOsS94rrRGIRfKlthWufXH+dzPu/nfM457/u8z/M9R2Ofv5Ov
pISERAI9fpw3fkkrWq9TClv1zvxaQ4LphUY5a6NboYhpn5jXCMyMLJLGznYg
gLFvdN1fBH2HUs5meNVBdTDz0LytBGtlfeR2ObchUSrYn/OAgJnPXn9segcc
pfYeVjpN4JgddXpASYSiSnF98CkCHmdxXGOvCHE3eSZlbAK3C115qgNFKAlz
S05fQWBtme2+J1CEhIlPKfvzCVY/ZPWbrBHB0jH3Sk8WQYzHPcmPC2/jm8vL
1+laBK/UfRuzZ3ZiyYTipskGgrj72bbrE9oQmcx8M3qZYIXCMMFgJ1zSJuUU
iwlSZKLr73ol4JEkc1BLk2D40FHHyjkNKEjUezluR/B0Q4hWn3k7Agbtg5Zf
JwhaFFzWfrIW0Z7dFkmOBBHKwbLh3FS0Hf2oIUfff1iH/a5spgiZXn9od94k
8N4dOOobXYHwnvirLpsIRBq2e+/3CbHghlB4JprgwypNjUs3mlB9akDq1WEC
hWjDiqb+DrjZWIb8nUsQFl3hYW3eDKc8rt4Mf4I9CdPa52a0I4l84zvfoaNw
Ry8y3ItgfsRDftNqAvZ/DcZu5eWoOunHlVtDYGBQtPJ4agdEc/SDC+MJ5KU3
KJp2NYOZED5W/ivVt+yk4ehrPpz5XVoHTKi+l23Ovp18gCeMje7Oywk8jW79
rObeDJUp1TPfvAhUCgI1a7IE6HkwbuvqTeDvxg5XvNeCMof0CxO0P3GWNHfH
AlqrvZSsdCewCZXjBWjUwt7M3JgLgu1Wr4ZPZ4jxuo3zmHOb4A17beBOMxFy
MGnlepbAYmVUO6u6EUOfw52feBBsVI70maZQC7tU6+PLzAi6u+ac1xooRkTR
qaZ+6o/3l7L9zV7zcKbFZX4YnVdi6ffD8SVBCNCd17BsKUFiYp/EUEEJtPb9
ZipF/Zwb4pv5aeg5/pn8PKtsN0HWu5akuJ3tEMn4+i0MofoYJCtsHD0HUxvT
nfb0/juW8zmBH1+A6b7xcU0k1d+ZI8MOboVpmFqGdCztJ0/6q/+pTlxn1ptL
UX9Waa01KSloRcLuK6ssEwic/ewuHU6vQf7riJtaNB+CgIzA210t+Odq6LT/
zlA/wqxHKCnG7Uy/HlU+wY4vutvUp0T4/WFSbetdgrNlrGy1iRYMPT2tcJ/2
1z62QfhZ/wWMQqLuedO8dI/FRRo6xMBO/G5yhPZbG79IrXt6FqKmhE4NOgTZ
/ZLyO7yL8cu42bUf8y/Rmb2mxlSIe9Z3U0eO03xGatuc/l2ALWWxNU2BBCOV
3a8nh3MxXJq58A9dgqZBRtW7WiEsyrU1OWF0H3bpn/XFdRh8X1a3x5Vg/ymx
SnhJFZQDBZ1RljSP46WG/XKP4Gj/zDt2GcFB2e1DM+0z4KjK6h7QJqgYljVh
ZHZhRafkhi8jBEslv+v5lD1HafRt/Q1+BMVbWsWTo08xfbF+woH1NF88zzfm
qIXxxbrmc9voflz+iXDbWgcdEwfzMOqH8yn6c8dMGxG0NyXDyofA5eBM9Rbd
lzinIG2YwSM4ElLu6Mlsgp2F7JF8JkHPdvWJCIEATdt3bfehfo7x5rKmqxZj
xZUOA+N1BAGh002a5Qux4GKZdz71V/XC1jwWuxmahj/pSp0geMTwcP3FtRV3
TNvbSi4Q2J0QXVmdXY+o3o/FJ2xo/+KF3fILCvDFZ83ea6sIHsaorfmSz8eJ
2l89b5gStO3pTfR/IsRF20S7Wg7Nf6XZZCtPgMSpC2kRzvS6D0tp/axO+ERb
aufRvFpHTgwP/FaGrBl93iFrKc+SCx2UPz1G7+fSvjhaDzJ29hYee4Fd6QsW
1YYSfNtkMHvGmACvqt3nzIoiSBeNLb1mVIfCvSMjVlYE4c0B1br6AiizKlLl
9lEenRenRt5Jg/FyjZpiyj/V90s1Ax/8jX+H3l7OoHop5x6ffBNUDHaCzz43
Os8H26+2i1tbUN/hLZMTRP2uYqQ2WP0MLgYf6r7Q/UvEzk+Uq/wV+64rNetQ
P6Yk2M9Pv9WMHjN/p+AjlC8HtwkYj/Ihrdn79flKAr3N8tbvbz7G3LiV3LQN
BMazni9uls3HxPxVrqsof/pkYlkOe/nYWiHH5lN+rN4xHhYruosexlOpfuon
0Qru2kimCM4XjGzqKE8PBhhr7tAUwWxWaaQHzY/yeeY5i/Ii3JpSiXekfJzM
NF+Ssa4Skl//0LNnUH0vy7cEKhUib7XujE49Wl8VuNvM4KMvSLOmkPovksGP
G7jYiBesjz7lLgQFF9ssp+Qa8cznwL89LILW84KH1pwisNjSxxUof8qHD+rF
51XhpRarOnwz5fe721MdefX4KCkK16T+nYrmr08L5qHpxI0nHnT+6C02a7Id
nkGNK9r+/heC0g/ao7yOTuT0hdj+4LvnovmbHSnftpzcz4yh/RQz5+30nF2J
/GuK7AjK617FBcFB8SKk/i3LK6f7ZnvlF7yLPY5Bayn/JVT/imVZrrNsOdD0
dv7zDq0/dLc3Fpl0YJzxsCu5nOBo8pioalEbLD50Llel+1HPGA22i6mGjDA1
5i+qt/IyLS+ZI8/AYVofLaT+3jr+Z174fjEUxjQL/6R8e9EVwVZrFkGJ4+/V
lkTwxObEWOEWEbq/HbFSSiS4dkMYMPffFvAFPDO/Y5T/icFvZ3M68Db3/KdQ
+j+R+jXLWlCXCLUInYfW1H+f+odDVTQaMNLge1We8lL51OeEsJ5m3Gt9ZXCY
8um+YXm/0I6PWqvv/epUX6fx/VK5P/NRPVSdspnWygw1H/tJLqqTpZ0sqF+3
mP7um7tTgIiYtupomnfrAxLMt8ZVyEmUzTlGn+/ETbPyKm/GxMy2eX2UxwUq
OaYRgmrsamu8NUb5EreyxG6bYwNUQ7RzGfR70e1X/8RV5Sp41y9wxFRPhc4V
oVOx7Xj8yuancPq9ZmePpSYdEuPypXWsTVyCaUJe/mPBc0z7K+P7bgeC/wHF
2riL
        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8VH0fxiWllO4ShbJVJFSylAoXJWm1JCQtdpWd29ZGixQp6k5pFVqU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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs41AkXnlLo+mUqal3brf2wrbC7hfCmQraJrljJvYtKcrdII1MkDVGb
S1m1sb5RoSijCLkLIxozg6mw8ruoKZeoRjvfH+c5/5znPOe873nfs8oncPfB
2QwGI1IR/8/bAidGjXhluK2xKp03RmBo3E2rZq4I/LBB98UXaWQomT82u9GN
u+9zHWZsaZTbmFno69ahqqxzIOl/JLT44aetPzZivviC//43JDr1jR507O+G
WG/pxYHHFAxDzZs9GFkod60NyfIjsCxZ36E9qg0tEob/tu8oOBjtMsk0EGPC
XizXKaVRFbuv5pBmO762vR96ZEFhvE11uapnE2Icf792+gsJf9b43NQTjZBU
nnzxIJVEmxf/e1kMD3kJ7PdZfxJg+2/c4c71A0Mz1JOrTyB007yyDr3nyAhJ
MZZOUziicnuxp0CKp5XyJxZ+o0jdI0/7dk8G1m+4eT/ch0CfyErrsYEIFuvm
T4pn09Ce5bKUcb8HlZbHhVc4NASJ39W77ZDAjHmhjWVAQ2m6x6zudRv4nNc2
LroUVo9aqlg51eIbvqeYFU9CND2xTle7BRYrXfudukjoUsyQ4EVdyO7OTNG8
qdhvRnbBblU9hnxa484KSHgF8zpMOgtgrbqm4tkNAgM7sgtXudXjTYyyU4Mr
iSUH0l32nq1B2HRh/uxwErm/LZqKa6mBerVaRrIPifZLSSWfJe04Ojvi+uur
FLZdObrFQ7UXgWj/mhxEQ8i29/WorAbnm8EcpV8V/NUVR7AiarEt72vTzkwS
qrs0bnnnPIDRJw9e/DiBIxPMa8pWTVi9hGEjWkBB1vyPtEy1Cp+2KnmtdyDx
s41JocG7YmjYMmVTQgLncgsy3Tc8gbjrXqeLFolqpi1XVHIfu8eInGwxAaOL
l5dZHO6CqvrJnafm0Vi4ZtS4XdqKgdQ4HkuB35m/bNxLbUqgNjLFDBQo+FvD
33D4yzOMTHqfU7On8HZ51PmRtmpYxAU4b9pLIoP7ymlWZSOmt/g37q0jsSwo
/FkopxfsQU6OLIcGN2CB78u8Lize2ciUbaTh6Oxam6/Wh5a8xzm8v2mcZSrL
k+aXom/K6atLP4HIR3FndBKE4MqjZ1J20NgV2Pxh92Q3yoOKT4luUMjV/OQ8
J10I59ovddfzaXxrqt2vES3ALbf2U1x1Cufm5R5JYnfjp44L/DlSRf159Yz1
22tAx8i5q5JJyLghh8slj5B9RJDkY04iuujJjEF0BWTzLhZH/EBiYdhWauiX
JlzyD5qaVvRj37Ma2MS+hq7aLOPswwS0Hf40PHP1Ba6EHmwOVuDnornz3dGo
bri/sfneiUFjhOGz747HHawYix60yyXAl45eLx5rRMjtU1eti0h49P56b5tv
NYy5wnTBFhKMD+YqSSF5KBb1mnOzCeQWpPlJqXTURpyzzNxDgJOqXFNq1Yvh
+VERvRtHIbGYPJKXIMBIYm3ngwgKK3K3BjTkV0O9JzxNOYmEpWzvgWNzxYi6
WeTk9IZGrvRh/65ZQnT+YziZdomGu1Oa3XBBB9b85t47E0mhKUb+OoL7EEHj
2mqRKiROEjnj0oc10IofOPnjXRI6HAPDsANC8D5FeCWq0NDzrnQ5H96Au2W2
2veGSUg/F73wsnoAHe+QMO23BOqCLhfamnbhJyWZZ1ELBX2733cMk3VYZ33s
h+2K+674T+rKAstu3DCIXH2FpPA5mm8ylirG2/iLfhMNNJ48CpLoB3XCyIaS
a1VSaHnF5Y3xn6GWuUwYa0fB0zu/JIzbhoovx0vSj1Kolq7WMfGvgKRZqd9y
HYlE0+LMYMd6+LV5dOVlkGC1pIjV15dCr9Xr5fKPBKrfbhzUc0vHrQ/JfyxS
4Jvrll5gXtcIpu/LxSVTJAS68WOcajGWbCybs19tFGuX5rgXWwtw9vLQW9NO
Coll9rRbVD2qDjRTdxR8DsgvBXxMF8NE5aBPEUGDvfLOsFg/E+OOg+U7DxKI
n+hbuG/Nc2RJjI/fn6Hw9FLNCfsGEWLfhI31e9N4lZbZfjb+Llgsgzvrigm4
eau8dMlqga+mcnHrAIm5Ex/f6bHz8TR88jU/jsASpqs9a3YpaOfyyYfvCRiX
9llWqZcgb3dUgF8Hgduef991qRdhRdRyx/+Kaawt32AS2diDg8dNhU1yCoyi
tbtv8rJgle3/x3UvAh27TG97GD6Ha7igq9NfwVes1dMPljxMnZyVKOERkOkU
hjgOCyG3YQcYtNKwlwzOHXV+gcqegOGEvygMd1Y1V2S3ooI4Y9Kh8M9QkaWD
2eYa2DrcbN7HUejJ7dCxhMImuLhWxCxS/JMPZrG/hHJE6Nvsq2+jmK/osHOa
2iIREuwmztudoME4ZJKfwSqEdl7k/k1lBEYWsDiD/UKwrhnGNhQp9D55vF5S
LYRW8Pa9P3tSSL0aRpcZlcLawsySJVPgE9qzTPBcAjbnXaCtwj+GNqc8s+or
gW2GVtDAYwLJpz+yUxYLsF7jR409wRT+Bajr3wE=
        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk2k4lYsChTWIIk6ihDZbSk4iKalbLcXN6ZoaKA0yJNVNOBF1DSmuZEpF
CmUoc6NIGc7eduZ5aA+mzZ6+75OdpI4GQ9f9sZ71+13reekevgdOzZWRkbk0
m/+3lOUTb6fXB7Upy08KZgKEu8tscgnIgELyZGVSOQWFkx9i3L50YXSu5oJi
LzFYg9LqOLDR/vZY8S2+EDvtNPVzWa1I+jnmuNuJwJuMV9UJ29pw+F3OuxPH
JdASZNFUfjVBo6U8OO+1BKSrYuFDcKGYl2g+11cEpUfpKmr5Xci+lPYr77II
kUFTYTtDG5CzNZXvoUFio8/9df7TPHAu8ummsmLI6Czq0Nu0Fg7D7aWX6MPg
lTDUjzt2g7XIcLN1qwjOAe0O/3WowOOVBZGbhCTeFOU+i0t/CfZqVeulNhTU
J8br95r3Q1bNpajQZghn9mumzXytxuum3WYTS0no0MsiJwcYCBf+2LCgkETm
+9Tmr7xYRJH13OAJCoGjOodeWNej4JifwCaawPHT6oXDdmyknTr5NjlaCNUK
Q8ad+x1QrJrqbzcWY1Kpkp62i4scPv1TZ4AAJRHmow+02Pg+r6v8WYkQUwGn
l1goteJ7Wcsa5g8xPt2iZU0b9mBJTuNPYaUQnTHd0vNubGhJM9eOhgjxR7pB
AK2+GRe+1j3YRJcgp8y8M3UxFzGe+su35IkRftRiruyJagQ3VPvzrpG4t7p3
oNemBs63Lny76Umgq7WDdtThPf7KdB7TMBYhccJsxF75Nvyu6V1MlFJINrjN
8Y/tw/n9R9LGFcVwG5PR+X62DP4cvlO6GoUNnypOTRXmQf5Lu/xMOoVEwZwC
vnYB2mixcikJFIrZlpJ1Cn2Ykdte03llCKrrvZofrWvAj7BJ4XsGATl3T1FY
dh+0N7u3q4YNIcfrUEDJOBMBEVMrZoYImHdGDa8uYMFiOnJJjy8JSnFxmLc9
Gwwh9TGYIYZKho5F+N5evFgT0SMrJ4Bj8e8DObc6wPs7orrmnRhKvvOmEz2a
IR2MsXh9ToJtLgYhXW09+DgxcXdghQDmJwZf3g+rwqTmoi5/ExK2ynIuew/U
YMHCwgDbYgId3MDjka6tqBsPUyu6TiD67rd5tS9bEGSVVBidJcEbn5VTGwwb
MWrbqWv5lYCiQ0GQRnMDfFgtI9bJBHhRbLm4uhYcFoVaH7QnMPjd5Ina6l5U
2Eozi23FuDGfSlAvLcdfg1z6n3dJzKexPHNTSrGmsWO37kYKth5f1fPoj3BC
qDxn4hmFmZInj/7U50A6khi5cL0EGjv4qr80upF0gXPooo8Yvw06Gk1sbkV+
/Ecj5Skx+t2j+quiO6HeuDblcrUEUiOfu7setMKq/JvpP/QJKATtKFt6g4cX
Y902/DAx0keWbRU2sfEhQmpjfVwIGX2mMdeyHCfueX5k5JMwk7/pZnOAjz3N
ZddZmSJYxVwPhHYPYh4XU86WApzivjEaKWuD2r939N00lMCbt1AlOrMBa3Wu
XVZ+LkG4zEVdFXcGtj1d1VhoScLqirQ3or0NkJWe/ZkjxveCpaZ399TDyPr3
syZ+BORvjq1y47zFypzO+LhwEm5WjsYf6A2ojHDaMrWSQGagheCQIAlaa8+l
rpFQeO2/9azCgnqMRkcF5S4kwfQ42qTBrwRLpmvFspskthfUhOgmvIN6XTRt
iSYJnvaPlOQKFp6W6yTQ7xDwsbfIerKBBwO1056/IgRIMpLkeIXWwyv+YOv1
XAJ/xJpm9bIrQePW7qKCSFQFJ1SFZLORfVn+n7UzYsQEilXqz/FhfzBpecY0
H69GHuLSZDeuue5zYDnN+tVlM5NWwgFP9epPfooY5VpMK6zn4glNmWldIcCz
No+sttoG3AtxH9j8HwLSwNJ4vV9ZCBmMTU6touB2m6StWN+NySNtI/v7RDg8
ePKtI4MHb1mRdilHBO+oaf18HhObdhypbZ8zu+/7omPramsQOaSZfn4jCefg
2ndX9dqQPqlUT4uVQGexXTD1uQwV9IW6kY0kEogve30Gu6Fopn940E4EpjeT
0HzPwQr2Vq/g5UI8Zj3M6PmtZpa3Vv2lMwHmFdMsQcwNHAv1y/ebpuBNa/pb
nt2ExfMvq+gxCfxkZujrljIxnufx4PxTEjUixauToUUItHOJWxREweJ1Vfyy
deH4dmfN2e0KwwiPefpqwJqDM733b5uNCyDtnMml7tWCqPeK15/l0RpLu+eq
3ATPz6QZ20mCDr8PF4san8JY0ybbaR+FlnP+WWEp1SgSml53yp/1NWRn2jLn
ASzVm2sZ2i+Ax9CVf2n7DoCYHFFiGIhgqCnc3hrGQULDXsROiGGwM3zxak8+
+rNMhpMfDaGuZ8TDZLQJdSWsEvGsL9s/6KdqyNZgm80+k7wRAg/3VLg/38yF
45ZxV/rsf14p3k/sW7uxTzl7x/MjImQeayx1iqjEZ8aZhEXnSbSs2sNkc3oR
2egbx60dwpCl0eNz3C649DkpDfRL8D9z9N7r
        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4VesXLpRCoYi6laFUV+JERaY3DSIlJBVCRJLMQ5Mc9AsVqaQSKlOn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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8Ve8fvymSfJGGUFZIVCgqo95UZDRQRqKQpGgSffGNEtGQpBJCMopI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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs41PkaZ6IjOSRKKbk0plFn040S20ctg03lViOmqUQuR5oucinpVEqo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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81AkDxifbocOxLC+pjeXtcFWOPlI8iiZJKUekEhWhtlGvc1nSoUvY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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk81Pkfx0e0NtlCfiL9WrUyHWgqpQMvxyTZ0LoXSYfIFiVUjsyWcqxN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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VesXxgklIhkKKRSNiiIX4aFBypCuokSpJN2QMiSE3IarVKbMRIRC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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHs41IsWHRQhdDwrj0qhcsiRV4XlxO0UUpJ7QqU6GKlDHlelrkdJElGm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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs41Ikax12W3GISG/J0yCW1S4esSh1f1akkJbprK5wQ2ym55ZRKF/da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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4VekblYrTqJQxJbdOYqjjUkOF1CpJoSi3OH5FUrnLMDqEbphkxi2X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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k41G0X1ooiVKoXlaVSqGgRottWiIgSSqWFFCmVUF4RyZpIKJRdlpCd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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk81HkYxx1RJJUkkStlI2koGcSnpltFqcQSurWJDUlJyuTs0EqiLSpy
JUUJi9LhntEwTEzo2ia/g7DRENpff3xfz+v573m+78/zNtjj77xfTkZGJoR5
vyovWdb6S3Y+Oo7JS3XLCCg6JdTZSJqxpW/tu6mFFNygn7+7qAPp5lcfpJ6l
8X7/1L+TltWgezRSYZsyhcuzS7rG4oux2mVyYPR3AqZ7nu3e+kMIVVaWs6c1
jRuGy6YsDBHBNKZVbWYtDQfNirKbD4TgboiTNzOh4cd+YfJypB3DWsImDR6N
Fr7/sv2KQsju2FZ6ZysNWtt556N3fAi6nHjXzlJ4ojy6ixysw3CQ+o3kDBLL
Ux/pecqXo+BI+ImSeSQOrPBuRNZD8MMWRgY9JPCelJpnuFRgSd6uaRstSXiL
w506Il/hD+GU0LXFJDQHNnXkGTYh0n5R+JvVFAJGtAJz48V4enGOp3YgjT/Z
abf7ta6gYIV/wYmtBDzKi/Ki99fg9/llrpmdJHzU42dcmCrA5rTvZXwtCnkp
fx+7PygCm32CkBrTmLfj6OHPM6tBVRSVdQyT2KLwXSHXSAQdXYG8110abpP7
X3eGiqAuT2ZZKdBgcW0feX7KQqJZ3p8TEwgsO5o3zmkQ4lLg93Xu/RRq+haE
8DubcNlb8LPAgMIkj+fxMoVZsNQPNAuIJJA9Mf5W1OZqyEsntLWLSfx+9H6w
Y10TyCi5gHMHKPDXuX3kuApwcrWM9yknCvZBxsrhmiKkKJ1XMz9E498Zj1Vd
1/Mg5yYdn8H8x+WB25LnT5/AoLWuWUeGhFH2glGDdCF87/mtMr1KIXrP54u7
/dvgzrvWq21KQ6Aq78W63wjC/u7n0kAKC8q4GVab3oLvosov76YRkG1zMELM
h3NfbKQ1i0JcmLUeL0GM09ZVxqzLNBKdR+p/DFai+vhby3PrSSirz6pVIAXw
vCBbFOVHge3bPjjhjxfIVjRiN/qQKNmr07jWno/k0Ry3CbYU+g6zGrjvq+Fx
MyUztYLhc/3G45UOQlwR+nKsGph9HYekkSUCHGizIG1uUciOVek/JmlBrrcl
12Y6jRKxXrL+osdQ2y6X4VxFoGP+nR7zNW2I9RvRmNRMY66Vr+7WJDFU2giH
Tvke6Bd1czKPVqAs6OcXyplElOoFn4v9zdAabKgJ0KGRYb76kdbBFnwKLVB4
rc7sN11aZ/UiHt4DtsmVGwjUl14aUQzrhNOQbt0Hrx6YJazg96c2Qbf9Wazf
CgoyVoPC6a7R4MwdXeUOAvsKtwTYxbQjgDrzm9cojaq61uJe72Z8ePz1m5GE
Qj3VlGvR0gQWcS1aXEBh2p2YF1Nj0sEbCHi3jEtg0kwJ21XM5DN2guKqKzRU
Fnep+lQ1Y+zj7ayynxT04/b55Z/PgMB/Z/nhCwS2szYWB7OKkCtb4GL4kcC/
2Utq1XcKoRXxD9FqR4P9X/Q4ZdiANPc+jWFPCoIEKyOtk/EwkZxurlxHYGCi
n9R0fSci+v56GtrL+GDNtD0rsqphbbzG2UtCov5LvazGykZ02bFD/gqiYCJe
b9FMvYKm5vXQ3jASg8aChkSFdgxwFj5Tu07Dhrs34/M3HkpzzbkH5lA4P2Cm
VGXCx7zwiRdPsSlYJCmMGml3wSFs0bztNj14P6YdEMEvh4qr+kfjTSTSg+xC
s/XEcJ7Fraxh5nG6JRUc3/sGwelCw6/2NO66ln7c6d8MfLKNs9KgIW2brvPi
+hvs2n/+Xj/Dr/Lc8wf5jq04vMtlOOMGhdqq7pGoBYWwWbd5z9lWAnd1c3au
PNKOfSKtrRpMXl55iyT25gIUhVTulnWkwBo+nyZSawFtpJF0nWD6m7MTL3mk
I78xhJfE3K+Hg9hM+akAEwZnBDtyKJToJgaFHWqCIJyyXv6SwqnxFLV3xiIY
Tq/e0WJF41ZR6n3XSeVIJbvZditJxHk2zq3oY/hP9SkNLqdQleQbujJbBGqH
+pvYa4yPDnGq09qqMfflB02fOBK1yvUztal8fDNIrefmEjhTsK2nrD0Ha+US
lMYzmT7ZIFHskgOf3sPmJWmMXzp8rnJtX8JCjparvUmibJVEST+nA46zr5lf
Ocr42vKbX2bmZSg62MeUMPxjPEPfuoY24LfbxZIQ5t5VeT4qn31bwP20pDBN
79f8XbkWBXyciX392HsBheShoeU6s5ogX9FikLCU8UeO/o8U0VvUR9w4PUWm
B0PZJbnHOS1YvmExO3QvjTvN7lTS3hqkjk1U2sj40LR3Dcf0WBfmlCdsS/lA
4+Hm+K/J6QJYzqw66HSPgor7LMtdh+rhIf9zkhfjixzTvB2apAiFWc8D0zoY
fx+sdJ2sXov/Mn+6icZInBqInW3s8xqc3rn2r3IZXkv7ZN45lUNJV0diwuSJ
5eU1ZV3HHcyZNS/KK4xA8oH+I/O/PsGF1s1eLVIC6hFhvJwHxdhUMCTHGSNw
S8P2+cml/+Dk4vG1A1NI/A+6SclJ
        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk3k4lAsbxiedU1mK9k1SUU11ihJSubWhZFTKdqKTNCRbx1EqzfeFyFJa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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8VWkfv4UGrykheUMhOyFDltJXZatouRPCtSZKKkqhjAxlSdqm7Mu0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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2lcjV0bxRMlJAqRoZFKoUEqGhapVEiUCiURoaI5UkTymCKUQtIslQzN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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwdk3k41Ykexk/EqGzFY7tS2UaluJFB6ZUMkso4ppGaFlcle7RQh8d6RMZ0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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlWs81AkXx6ntptbWUpLQzUOeXfdkNfkhi5S7fCIajzvdLF2UyS1RSLJs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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVWlcTWkcDsWVhopSMpVL5Ir2pNKTSkpFtEiypAkRUknNRDdlWkjLVLpJ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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lG0bxpFEZCkhpVRSKpIQUqfKFm2ikEKFFEmiFJUSZXltbaSytiF7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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHs01IkXt7IjpVKRlGT6CZWebCXqs+W9ZMUoj7JDKVnl2YotoQjJoxXl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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk2s81IkChoVNR21SubeKNs1WahIaxb5uXUi508YWIpeixNHU1NKQjbQp
ieZnt5zVSUIuXdREE0OkmQwzxmjIzH8u/0SLSkp0nA/v7/32fHoei4jDflGa
Ghoa9Jn9/zdlZV/RT2iDj986sYm2CluDd2yrXCnBCQZObGYP4N1f+b6sjQJ0
Hf168BCHQHI/i33sPQd+9kOKugw1coyW/Pg88iGyl63kijRJ1NgXaJS096Cj
CrqzDyiQdaH8Q621ENMbzy8JOKxAauDu6ya5fej02p03qUHgc8guo7/jn2Je
Rhj72xw16swEraE6/bi+UWy5L5oAf9I9wVTYidWkQ8TePAKOBX8m6nn2wbi/
a5C3XAaT3I3nNgZ3Y/05jWVrE+SId+gVZOWLoKc9OpeSTWA+NbF4/4VOfJqS
hO2jKvF84eLUY1WdGF7n6ksNneGFvgn6rpUD9+xo97SXKigsVJfv/8KFymX4
fJSfCpzLRy2veRSBH2hmPCIiUcfMr/jM6MKSEprH00k5xv7DSpsdykVhfO9o
6aQKyd//7tKexwM1pDfXuVGBnJxPSTpnJKh8GBukGSzHh7hqI4YpBylFZenF
y9W4esOjY1uvEM+tZQe4e5QYOPA6792GbsyjBGbmx8hBfzv0TXdLO8Z36p1M
mlAhzKQj67xAgimpN2fQQo4Rsd2063g1wj3m7/nLk8SBzIwnRmk8jJPelBwN
FWwcta62GwlA35MavyNPicgPBrn6nr34usEuSf7HAGzfXzuYalOBXN7Tdw47
SNxlLV+Qs10KtuzEvz5eJRDqNrhOVNoMR8rAixtPVSCDKkJ0F9Ui7lPfLYop
iUxv9qTR5xbQ+K80mW9UCK19ZJ5bI0JN/Y/Nzf5KFDoO4xmrEen8JVIHTzX2
/uw2J31KjKJ+P5vrIzIsCFjtNZpyD7Teh1v3a5NwNjMZr/B8hTM9jMbVMjmq
3cZCXBdJwG4wjGeFyfA1xySieLQVa37Tsfr9ywy/dvGq/pYZ2aqOUNLMSYR1
Zunxg0SoXtuq/04sx8CZaOOGyXosPh1VJLmjBlN6P0TM7Eb2LWs3RiOBuhGm
YWlyOzZkLjS2ylWB0lD+TFkvgXGS77BonIDhpbD4ypcteMLhlWdSVIhJr1tz
tqUWI7Mao8J+IpFBiJ7gSBcS3CZ1m02V6OgMzAv4IkKrltDA/iWB7vUe49cc
HqCyjHvurUoN7Qkny6oHEliO1/zaZyZDWsQWQcG+LPCmzf03TZEYWZrm0iUq
hcG309uWXyRBZ1Q0xJRVgze7YO4dSxIppEVxN18Mhsi5jpmiwPDueQWO9Gb4
ObBzCozUaCnbQOP/I8KiLVlnDyYRyLTnzreWibF0V9KubwSBforS+HZbGx6v
HH912kkFn0q6w8I7j+DVerv+HV8NZaANaEeF8NqsVWO1RoHLlewmN68mBJdQ
aw7fUKH8/NhO6tIZ331e8jMFKjQnmQqotOf488wP90LXqLCsnmX6or4Y8Z5/
XNG6SWL3oMniYmkLMuezoy/WzvTUbBmbwMzD7EPradIhEm2Gdo53fXvBCnwd
07tcjh59btWtqpu4tzeA93cmiXB2SJ1Fdxc8mGPDLtYKVFXJI+/bl6Dn8c55
mhUktvvc8zO3LAY/gvJKk0Nir5ARZzTQCy262eMp+gCco510PxCPcKFvwarm
aDWqDEZP7b/Vg4ZxzWfWDAK72x++Lw1ohc9P/1WfilXhrM9J5eP82xjsIb17
IknoMao97q8XgJUYqwjPUKCwodUkPkuAaAdeIamjgDDIwG7ZRwlEZZpV6wUy
0EybYkefinH/2JysqyVy3LWyqzsUKER2a7GT9hc5Lg+pWVu9OSgK9dpKnlNj
Tst3YvKKAG7r7NtXcJR4b3t6YmVhF1KC6A0rnAgsoK9zD3FqxCwDlxS3FyqI
bPry20z6MLq59tdGXzkmir/E1NqJUBj8lv/QVg59w0HuwOwmvNAPmWNkqEYA
1668tkMKdXSsR/FeBcgoZjrXuW2m/z2b1rxVwtXadou/oAeupjeiogJlYI8m
m8bRanC8K2Y4MoaEtOl48im9GzAn309PlJE4orX0lsFQLeg19DOSrSRKElti
WVkieKaF/0Pzl6PEfU9w+6Pn6GlafSoxXYVj2eHzJr8X4U5QinTEVwFn6omz
BuPdmDxCZ5QulMN/bVFQop8QdO9LIbonCXB+fpT5m74UcytEr4euEBjpj/Rs
ftOM/FUuB95YqPBE1VAu2d4Npln4YZ1jchhfkifddBdjwubcxVGhArmfqYnh
K+rRKNSmmj2e6a1u4aVNpR3oTAqVBz9QgLJlLDqC+QTXygM7dlmpEadTlGE7
6xle6hld5H1ToubFJ+IwIYDrLK1/O5UToHolb7b05+EjIabc8VWClWoVYNve
BTrX2TdmO4HIuNdTv0wJsHh4dNpLSiCt3PQ0zbwH5HUMpstkGDteHaZF9GHg
i1nqMz8Zftgvn3/FWoR9l6cTPoXI8T/EZNMd
        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns81fcfx3XW6ScrEsWkrVAdySWKbS4vWrNIRQhJrZbdUIk43bBISHNL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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3dcTf//L0WliSIt+aqEtJHEMw2y0pYRIakIqchIQ6qPykgRkhZSae/S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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXtczFkfx4fubREVuVTSxSCX3Q0rPT6lJG1lQ1bJE4lVapsu0k1NYVBI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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGs41AkbxpElJVJtaYvEizYVmzY5rHsaUdnCChUqOUQ2OXUg5NCBvNZx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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwdlnk81Pkfx2c7WK2UHLVFm7Oii4iSXpItHZhaq3bdZyXXOsqZO6XWkYyi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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k8VGscRiUhoiJZkpAoe6nQI0uqS8mVKCEtVFooKhUia5KQJSoiEiEk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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8ldsexneGo65EKslQuobKLXSlaPAoyTZFToMUqUQkThmivRUNlFLo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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk81IsWn+rWbaOoULZMo+1qfSVJfbmpkGVK4UbSIhpZelxZmhJaLilb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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk0lWkYv6lpmYayVFeLuDfSLsuklJ/KlDUU1SiHbkyyJ2NN1tBCWaJk
kmUSxQhJN7JkuWO7lu61m2tCvZEwM5ZQ8/bHd77znec9532e57d9ChzXo3Zi
DAYjnj7f3m5cT9mBmkdwKGXbKikT3FOoL31sVYqCYAmW/W6CcMmaHo/zdUga
9WpNtCBoP8EZ6rogxKKzSflV1wk8I4XzrE3acWNGs1DtKUFSgZLh+sYSDIds
jNP6kYBh7za27/1WGH0V5M4oEHSGpTUEnO1C2Zpzg9pBBCn5OgnXWa3Qk3wZ
fymYIGo7keaoNeH0NZ658mmC3X5aMhYKnRAz8LQoSyUYFq2cHJnmIs18hb6/
KoGyjNbXiolOKHVFR28oJrAZd8vtWV+HpklGQLgpgeh42MvRNTV4faBFaZ4h
wYGEu8cde9tga7BqTPISwRextCVnhAIsZs08t04g0NMmoREfuQgMWjFxcCdB
oMdgYp92LMxswV7FJqgP1glbmNuDKP5/L7zfE+SOmPcOLCiD02JLvxk6r8zF
ddrS4wKo7E+O3s8hcLviGR4l/gdkeoJHOpRoXW5UPrS7Afx3xtdSzAiKQgTc
gG29ODpSI9gvIpC3H93fJKhAy8cRy5hdBDkTxjtNUppRZHLVK8WaQMdG4r/G
93dw373aetMGAqZJt93k/g4w9a/M9OcSJCo8W1B3rQb92l4aEQYEuuNXTyWK
mhD7likyP0qgMjzOVqxIg/fWt7PnFGk/PyR9dnpViwNzuqFaPxE8uFhl1/2o
FssLbrMcjQlSnV2FnxPaMPvW00MviyCO4aljKV4F+dwjyc4HCYYSmNXm6e1I
UEkJ/d2LYLmilqJFXwcmfnrUFF1G8chuLbka9BC80vm3Bmi/HickNKqGKjHl
zVUt1SNQ7UvNWynVhXrv2ZlnFD+diuC/5//Rhs4Dqs2MZALUZG9U029HcMaI
QeQdAvsym/4SmTcoTNud8c6WYNzSqLtcrQsNmQ6OGtUEN6QWtKZcaAHnsGUj
w5zgVn+64Q7PWti91LRcok/Pb13WnrK5F++zDv+SG0/7S1qu6ewbD1ep1hVf
WHT/+n/KRBuXQ7LCPfU5CEZnR7I/3uxC5dRGOSQRKH3/JMeurBUMnzOBByIJ
Ko8c++cBR4BdMbzPVm4EvE+sQ/JL8xH10NbMaQsBP52ou7Pbof3CzSfxAYF3
KbuMGd6Awb0OJ7cZEdja6C7crtQKTGmknPAg+Gy1SylDjoepdeNf8mj9x/MM
fzfZNqh3buA7uxBonm+8FK9RDr5hW8waHYIAA4knKyrqcfnnn9j5FI/u3rGr
Wd81YvWZlWsNHQmO+Uo3FJx5gxvlD6PU/AgGG20TFNyrsFNrbNP7vbR/llOk
eyUPfiFJkmOH6D4SKtM2nCzFHq3qzAhNimeN0GvLQDkqvlRZf6dB8Mh8XIfB
z0FUWdfcz5sInkLszX1dIU57zw7a+dD6xc3sGutuiOIcDT1KCGrtXRoYv7eB
Gb5nafhvFF9WxPKc1dfxKn1flyvddzjXZG+FbQteGQyImZ+g/DM5q18k0YHp
LTFflhUS/MD9IpV/W4iR7OYXa6k+VcWjHzjKCWEaOcWepvsPPF79WkYsFhWx
BQErqT7vtAw+/vXwH0hq393Jov0Z+X9QHX33EKErzIIXUv0VJo/lT94uh3zg
oZAdVK8xExbnWrrKIWdpniPUIjANe5leXFyHDyTTfyvVp/6m1r+2l/JQeGbf
Vg7VUzGPa3ljjIdSpU/Bz2k9Y85nLvJjPQLjmzdGWRGof4oezc/iI5ojF+p6
hPaz/ev3Q5PtiLM/nujjT/C8OSx0oFiAD7FCGfEwgoHwJRrOmW9wuOCAtzz1
ow8f+TKvuwTQGy4xbqN85/neDLyfK8DUnOmArDPFS1ncynK2GnFvtve47qN8
8Lq/9p/jeeANzyh4Ub51dqru0RA0I3X2CdvGl+D7PeO5t09WI0I9OdWU+rmo
O71aJTMToVlmfzVS/U9Ll1is+KUDZjMzddzbBAuquScPVpbDv0j+CJOeV9Z2
LJ/0aANrbBdzHuVf8ap+KU+XF/BVsAxZrE79S3ak78JyIdTvM//u+JXyi9/h
Une5BlmZ7EX3KH/bR66GWFkV4+j+3oC47QRL3uY1OvQ3Q1lqYmEk9fcizpCv
4t06xD84KmdH98sJM7GfLnmGsmfb/j2lQuDb+FXV5W0z3qQyp6Usqf7ZsjWP
Jl7A6EVW8qgawadHGUwDiVbqo3VlEecI9uRxjuwVbwJPNL0zhObVlOho6BPj
Ctyua+0dpnoxCow1PF3Dh0yWtaQTxYcj7WP673U+dmbpiApoPhRcaz8vLi3A
4x6HQj/qDxFuGk7LT/Pxe9CMqQo9//pybHHH7kpcU1wd3ED1lt4Q3xfU04ZY
E4NWzzQCVh7fZ7PDn1C37i06+e2+bMd18124iHu2UlWHzn8r6KL2O3YObn26
a7aM8rE++3Hcf9EChEXPF6rQ+0Thv95g697DaPKu8j3UL9s9RWtNN7TBYEjC
JZX6R9M/t+xZTiV4reynqUfnb5qwWuRvmIcT1TaRmpup/lLFDdUXCXF8aRbp
pHmZYCDZI3aMB4u73mGS1A8L2uw/rS7mYd3u02Je9FukWufmIZ+NAKv7pxI3
Un/kJJ6R5bVBOiCwvp/6PXNdWOTYh0ZU5L71VKX7TY56knPqxzQYnnfmlFD+
iC0LYC2Na8W462/MkMs07xlLZI3ZfdpSaY3m3/LeKDzgeU1tHYwaEmJ6aB76
fffYW9e5C49LDGrdKd+KAhR9xcReQfG82uQaijdjU2Wq4nggSuLW3DhE/eFm
RMyWVSiHnpbioinqVxHlfvoL45vAMbm33vgind/PyoYb/xRjTbUM7laadzsn
5zBVBfcxtZl9FC9bO6tb7s/5OBdkUZlI/VCzUCxwYfRTuNs/E+jQ/52p6Ctd
p4YKsNLgelDyDpqP5peHN/tUIUKnhcxQPg5umrc+o0+Alyo3p1wuEJRp9W37
xbEWqy7dDeg9TP0xb2PanbkK6C42t+6l/mg6oXtodbYA9hmLq485EPwP7Ym6
bg==
        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8V/8fxWWmJJWMIhpSKVQSGUehrCT6SpFRkTS0h5VdJA1RIYlSZsjM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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs01IsWxyecaJJHycWRtzh0KhMmlC9CdFNeKUMqlaZTiYrkKELIUsez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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVHk81IsWnxZLNYaSJbJUKJLQ4zHFV6U+dLVQRMmVS1e6niWkK1kaSyUh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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns81OkbHW2qVbonlxJpEHLZLqbIcal0kZBQ27KpKbeiUomUldv6qdWN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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3kgVNsfR55CFFoopEhEJSlEfYSQsiRPqCRLqWwlKUuI4knpp4WUxGsl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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlWs01AsXxqXo7jQllBJxdDmIkm7qISGUCCUcyRslEqOEKCFKJZ1kqERj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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81Ikfxh1tu25KSTHRli0hUjn68Uw6BpHJ2k7ZqEg/GR022lzl3EqS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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns8VOkbn0pqpQy1ymVdigwNpZXI5StRoiIkukgWJZQSlbSsHbIVMS7p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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VV8bxSWiDCkikpCZFKkkWkJFhlRCRUQkSaWBSjJkLiQNytyEX4PM
yXjN8zxLUtxzrkTSINS737/uZ3/uvefsvZ9nfdd6pBzO7HdiZ2NjO7qAje3/
n0KyzIBjuV3grB0cXsM9Bl2BtkXSl+9g3Zm/QU4SNDTmu3Jl2qqQoVJyII6f
QmZMn4qzcB/GvvZaHWcbA8O462b9s26kHznEo9hHId9O0CF0YyfsAzZNrsxg
QiA61aBErQAPL58ar9lNw82ot1HsaCW0eKecef1pvCjKrqj63o2bx3mD++so
JMW3/Mi51YxN/dfWnuynoRrtZZLYWAGxi3d3fV5NQ1K8rEulsAsjJjdObAth
QiZR8JvNtkKMCC4qfz5DIYMV99MyOAm/Of6G3hGm8VnFwekA3kI42C/9UggF
iSkbgZ+OGRDhy3ob0UwhpWuLmbxjCxo6FicmRbPA9uyyqOZsP2ZaMh9tpUch
nrCw7vnZJhS+uXdqpQYNlZfRfJI2AxAqWpjoLU+D32XLlltrWoDmMY34ahZq
ZCyCLolnoNBCfcJ0IY3UDuOSpTVluHDFiutHKgUZ209nevgaoN1xZoPIRyam
E9O5k5j1GNr5YMLhKBPDJypnrc5Uwj33rUquIY3BgZC63Wv6odn4qKv9/Bik
nUNbNBQqcfSxZ7jkLhphGz+tdtrdBTNtE9OmUCZW5hUZBZrkQ1d3tOKsO42J
JM2HO8wZGPxqvCdGjMb5RJc419Z+NI1X5u+RpXAz6nvJcvtaDPwLCmwYptHC
IevQEBCG+2KuhhzkfNzCdzXiZnOwMNLc7oItDT1NCTexM92kvg1/bLQobKhx
8qF43uOk/q6EKXUmfNIKtn6ua4VFSanOwpMUVLqECnPSquEacuVkwiS5P+Ob
RwTY+9HM4xlsNk5B97qB7LR6A55v8ijZuI+FYr85eb2EPigX1Yrt/UhDUUfu
nJpnIbhT916/d4jGtNvT+YiP7bjtZDo3KceCzLERPhmVBvRUfb7IiGTCXmzw
eU9DGfQa4xVzHlJwU9EfKV/fDhuBE0XJNixQJZ78LuZ1mCzSzbNXpTCnkTFk
rJ2Dfy2vJT8Y0Th+bonRA7NUqKtIW5SvpDEUnmsoKFMAE86vk+CiYb1a5PyU
Sj72X3SoDSb36Trc+fJgfyeiH+eNP4+gENXMw5mYkYEkQe5P/rMUWor+ng2X
7Mb7hMf6pl40ztomuIjP1mLOMKSvpIkGW4l1UJRhEg7MF719LEtjoEBZTeFB
B4bc9IO+FrIg1c4VyHa6HSqVFU6LXGkcLs0rcDzRC95NjdGHpYleO/8Fvtt/
Hx0OCov0lWho6zXwCkhWw+iliW/GOho5rDPsn04MQi6rs3xzAo2CpQKvrilm
oDiVr9uZl4ZvSq9o1KAftt7c1f+d6MvbhEfJTbUI/JeFv2kI0rC8f2uk1W0Q
tifctL+3jWI3e4ktxepHprHEi2tDYwiJEVSWWNsCvQuf1++9SKNmUU9Xvl0e
2BZ4hSq70Zh6fyPy9SMGpBt3Pff/SuFgifl3U8EsaL3KC6s4QyPq3WHv5qWv
4OofbmrLTfSSpzAfejkZXp8RV7+exqtz2WL74lsw1GD2OvY6DfbLi8ZEu1vh
ekU5wOQghStJpyZnqVI0Ve2fEQikoFXVceevSz6Ue64rX9IivGiSC1/88SEe
qK9LEFKlIW5uIT3g3YZR7toTeqEsyD20Wv/PcACzjy24cxTG4MvOlJ85kg6f
zYcfnzalIXN2364cv2wkDIXsqt5Gw2E09ZPx11KoCRu93e5B45KU5wqp2G54
iHoZf3RkIfOh+Q0mfxv+fLE+f6CUwnGvsSsTL9vB/un5Ot1+FqJa0w2Gc9ug
PukaW7KP7C9zX4tMTDv+CmgKvhghfLTM0LXiaoeChncTF6nfhgtmWzYxKmHz
5bb9sy8ULI+tcTwgUYmk/pmqQh0aXvPy2YE5bdiQtmwopptCDz05qeLdiTg1
BnPPPAXu5hXJS9Z3YVomzFljMQV2DwPjf3al+PJhpzqPEI2kqQVxCY6vUbjg
AZ6S/q5or97Odq8Nmf0eode+k/dvaI7YY5OOtKWu4TfJ83aU81RZfWpFVWDX
WtteJp5s4Vw0fbkKwsmXw3cUk/7N8p/ovVmFHGmdhS/YWchPXBsqcbIBbV4q
H+cJf6fFGtbaeJWCtYVjd1M6Bd9QKytt5ywcvWOxUNqP7GdUwb/xSQUYuu1f
+XpI/YXQ1nerBme31J1wYKdh78YVk3uhG7zTmoIaRL+ihtvrVplVo6BK367n
LAX1Ebfny070IC9DXjp4hgXpm/IHl8h1IMtAySLYl4V7B+6ynq0YwO+nKirr
hll44uc8b+pZgb0xR57VX6JgmNiTtKa5A7ypDdwFakz4RswgmS0Jhf3ukylS
RK/mydnZ+60hfdzbeIysDV5e3a0k2ov4+OM/LGgaCp1nfV4vrIaUbGNOwGly
3tUXVrh6ZcHnw9BRy3LCQ8bxNIGSTtje0XnQysYC7+uk0lGdGhzo1lc5Tc4X
d+N6WXN7GbTcVt64u5fcR765NVdAAp7rOi9u0qSR/7XZ2bqrEwOHYmkHCQo+
qjjH0G2D91Dl7hyFUXh/+Z7gd64P1hyp8lJXSD9vu6at5dEBlUgHzqaLTDy0
k6oyXVsN56On9n1LpKFk5sQQ2PcEI4qL7o1Ikuc3W3zjsCxDfMp/Cbte0NiX
Gtg0VdABOr/kuOVOCi7Kbz8FzDTCcEpkS0QVE16h7i/+xGch8sOtGmt9GgKL
9+7Q1y2EkOvSgth/xI976WeH8l5D6ptLQJol6e/nO9bzv+/Fr3aP5fUkL7AF
3jrG86ASffsn8mI5aZSO/Ch0X9yIPnvRsZeSFOw9YkTalheiW88zOfYZjaWO
C2YOBnSDs9VwQaEgE8drZF6GajTDsTf+TwjxqwHtHO4ssU6E6YXsvAEKS/gT
zwR9qoSj7IX0NaR/ddeeeRnI0wmGam95SzSpz5Ku1O2uTeA+tNecS5Osv2/f
0JVViTCzkR0BpJ97PF902Bo1IKlV3HbNHhZGt84vftfWj3jVDNffliws/i1l
F3y/C5FOg79Tif7ZlIrsrsg3YJpaf1iYj8a2rfMXPl1qh/fm7hr2OhY4UuSs
iudLUcJtukKD5Ku31zyX8qS0QMDgh3CCHQ1O5trQ01m5GDc+bNO3iYaLet3H
SsEWVEzxiGabsMCgJOqfxXbAOu2Je9xXFnRrCg9TERFQdYGenzSNBmGnS8OH
6tDxu6xWlfBS96bPr21jnth+IbdqkHwvYZ80qN1aAZNW1Vxz4ldmkaI7h0vr
UBlWuiyumuzXL9Ix/n4NHE0439ZcIf0w2dyYTLdif530RyqTwko2Rs2vY5kY
2DteH7mF+MWdV/VZI6VYr6S6r7ye8G6EDtJcVwZJk70N+YS/GR4DxkXThRgo
lWqwtif+UHarTIr3HpZm/fRdJkDjtwu7Q134Y9wRjTM5J0Oj7/RanbzKdsRo
yorGX6EwIbLfv0coF3IzQ7dTSX7iFk1yL25phByn3H9NsRS8ZYR0Ukx7EHHq
8qGD9mMw9xsVeW6ahocPz/3LJf71pfbrqutNFfi2VE1yRzLRr1+98L34u1A5
fXK4S474jZKNtZVdJyz/lAYu4Sd6r9TwkFiWhzi5zKYfJH9lp8gnGKY3YtJ1
hsvjLRNJmXi3+W4qRl6XN4aRfBBifNxVybUeTL9TV7cVkLxAO+Srr8qDeuxw
Rp/J//X7bptvagke2J0p5CT+Y+nNYd9dnId+ykxBhOQBNhfVwlNX1DFk+Pr2
H8KThtE0M53uYhyeFeVuTqPg1X9Sp3k8EzyTL2pFFGhMSjQ1B6X1YZV2sqta
zSgMFofW+rjVQIXNeXx0HQUO94ak2Bu9KFbz/LGpnkbyr5krf92rMBx1ZL4l
hsL2Jy0PU3934Y7pDmdj0h9fOJfPBC8qxvXadU9DL5L6WQbzsDPK8ETj+puX
xO8mj49zTM2/hveOBbtdF9A4svxa+LsnVeid0dW7r0jq5WPVu9e0HeGPHnAo
x1GknlmeYwv7sL2LURnRw0TmNpurgymd4G8ceRTCRdYu6V5vFFMg3LXdyIHo
w0Vs+BunXwcmz4p8EyH7k6yotTf78ApXtS8MLD9BY2PYJost3gycix+yUPtI
8pWZuPIXjiysyv6Pp4L8f6VrR/lpm24ojNie3uFP5o01u95nE74ZXMjyehNE
eDT7YHOJWAVWd606es+Z+M3cOt0TfpEIkV1z3pzowffFbPeuX4FIae8WzlhD
Y/7Uiw16s4R3JwPcV2WQ/kwTUlNyrcPxSaHwiXwKHUZLa6BfCmfevBfv39C4
4vhrnPLvg7/U1q1KIoRv0WmTT6JaMFEvlPnsLgsxdw1KE17kw/zCtyWKJL/t
5Q5X+S7cilVzZzb9yKJhflF5u6PXKzQ4VBRWz1EYWKhIyUXVQu1oQZywN3n/
SfepRv0umOvUvY8KH0HCoQ6+gehBmDG2f3QbJPnc5hav9aUCJN+xXPOC5E02
r8xhf5422HjkBP4jvOkw/vHVvuIJtFz18/4RPlof4GnqYZXiccALOTPy+7PP
tu5atKYYaZmfo+V/En/Ycl3xSEAlJAwbT4xsoDF7r/kUY7QKrr/btpqfI8+f
NNo0ohmNuIAjUf/Pl9mDNR3jHk0YkPfR4NIj80AEf8i9+hzErJRIqVtO+ltc
9HOOni6U0gyWT5H+5p4xeVp48DGqrvcEnSR63zwT3Z22oQqF7zYLclTRsNg1
57RTpxEuahqOge9oMB/V2uj09CJQRPiEHPl9zLK8vdIqlRje2ZYeFUbqJ32r
0ICrC2dHwv+LWEbWs8fbP+sxoKdqtV+4iwbH8ED6MfF2qB5LNalXoHAg9vOK
6Gu9OHYgXKTmPROXDwa+j9V+j/3KrIyRIQpGucNzhzd2QVlOrP7EDsKf151i
FvYMOJzca7aD+G9GyJIVvWEN0Dxavn2O+KPKhkCZIMNCMEK4130lPD1+3iqd
71AhLKTqJSTuUyjtN+gdSAuDXeqPzxmE92XvBR8Y7G/DPp/J8IVEzzZhkbci
h6qRGdFXIkjyA/urh2YN31qh/6xYyrZuFBGeytPfNVrgLSk9ZVo7ikm3awKz
3zNgcPARnyzJ74VFRfy8fAz8sZSwab5Ko81vNw/rXTu2CqgqOl2jsTVirl4l
uQsGio0PrjYw8edM7+PI3l6I+01/0nYk+W6iLiraMRsDUo47OVIofPW/JMjL
04DDZX8X5TNJvsyvNZYqqYRRqxZ6HUj/SGindOxuhEm1/8vkNhZ8R/r+PTn5
BEEF+m63yPlKV8b7/fpWhoJleQu1CP8LuTV6+HJbYN+3nO/eVhbOTfOfvyFF
8kNY94HBSzQ8Ig9qX4vqA4dyhmTtEhpmRuPP7RcwsFTRynw14al5ItNyS+J/
2HO54dA1Ms/bPCpS7rxdBb51CE3kJ/fvk+jkV1KLszcPW/4g+uH+Tn+w3lUB
A577ktOEz+qtLwUuJ7XirMrru+ilkC9jJCz+tAkxXnLsTrMszIe2XaxOrcO6
0uBHrz8RfrfH58xFvkKFWGCagDLptwd2vCmmzWi4z+IaGafhwynizM5RjYh/
4cviGglfRj8M+hQ0ocD6kVKsIYWrRkJ/24Z70LHx7o5D4qNQH1W6ubiqCmNh
8gIHykl/1tfO613NxqirXX8wyTuTZT2NWfwMOArP6qoSP5hLjxJVcuyEhS0O
7nEaw6R+alsQZxLEj7ppN20lvH6V0maXVA3uRWM5UitoaNj3ngvjbkZ9+0ds
XDkKTXZeN0XDx8iLWcRZ/P95kHE5tq+zG9EVLX07P5C8tnueUXGqDwp39zYa
O35BjdCe2RijDsLP9G/sZ0aw/3yQyMjzQYxxSwysiGEhLnPPaY533ZD6bV38
bynxV5HwwFibbLj//MPR2ESh+9HEheWHWuGu5vDWvYXC0UkJVtmbVjg5P9p2
1YUJi1qpNy0S1UgNe9+3hszLa315zB/9aEGY4cObEyksKPw6kLoQ1ei8Ujyz
L4fklb+2LR/O12Hig2zLzFWS7+5uPaboUIrQG5GPeDxJP5os2Twc0gtrH65p
V6K363fdv55QHID5sHj9CsIPX4vD2rKvc6ASHarTT/JTAH87dub24CzPdNHO
j6PYkl26lG1hNrre/ZDaaU3eF/hq3dPy2xDJHaniIny0ij756uWebogtG1Qp
VhuDNRavyld8hqm4lB3BxA9XRr8SqSkoQFOGakWmLQ3+WpsJHuF6WH9UzM2x
opC0TLNtui0XClpl2oFryf2b2e9KnmwC24h1x4IKFmSyBh97FFfi1UFxjUDi
N794JFXrPjZByHZW7V0rhfTdB+2GrvdC/sLefW8ZTHwRPzqY5d4Ajx4zd2XS
P6IrFNabrGxBnGrkqWCiN5sdhlwTLdUYUpRP5O8ZRZyOvZLPqX7kRfCojftS
UEjWP+Cm34vcorOui7eNoeWD2B+37S9R9vja7WzCU/u0Rmd9xU4s/RbxT7Js
BNpBP08+9q+Hj4/Y3WWEb/E6Ff1LFPuxzc5l/2AnBVv28tUbevuwcu2y1Y9T
xuAW6Jp/oLMOOdO27u1fmNDafNlh1X/d2Dcqt2HjGiZu9w/XtWb0ofTI59GV
ZWP4MrXxx843faiht/JaZJG88nClpvJYFRqzp1ckkflvVP5v+uvhfjTY5yjH
5n8Gr1ar0L6bxP/n7pi+J/OyeO/X7E3qDPgmccguInnB7fzP8l7NAZQkXPYU
WDyCpOpjDcbBhH8RZX4vyPzgFset3jv7DttWlxUMkDxgYDce4BRXhkSfIYN4
dxqamRvnhZva8Wvub+Gmm2TeLyrnWBxVgI5K2VJ2Mo+VsT1ll8tLAyNu4blA
kidtfsnFLumvgFa1y9Xti8jztFjFGV3lOFoiTTdOEX+UHfePcPMFI2hVYwvJ
F/m7vbRUPPNhTC+/teb//nGbu37d9Ye4d8m9PpToIXvXze9XjzFg/PLcNykV
Giab6tgsd/YgfsuHCL67THznEtl5nKsblR2SN4Lf04jyP5PHt6kZc7Juq7xf
MbFf0CXkQ/EA4V7KBn/fL4g//1Fi4lo91Bl+Bfc/U/gfNpXvRg==
        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81HkXx4fVVe7TFpFraJMkT9qUjy5CWjRJ0YiE0s6zdBNC1IaiYlVb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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlWs4lAkbx2n1pi2lE0LtiKLTZqUj25/yFqKG6KydVGojh9SGVA5Tb6JM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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXlYjGsbH2ScjlSnxHHsiUi7kUr5GRVRSugrDVG0nKgjKTUIhxY1yVDT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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4lF8bllRkKbuiRClCFEqJmxIV2UJEQmUpSYUkSVJpsySpVERFUsi+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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41HkbxlFCodFhaKOmqYhoy9IB+94SKZUQmXVeSZHCbiSphJUyOVc6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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs0lIsaxlV2RLsmKbdDR5G2iNKFksfU0I1VbLrI0RTOpq0tKomMUbtS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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lVsXP2mmkkSpuCQlDVRk6NRPIqI4iUzlM1NuSKYiyXcoFSEzF4dC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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c81P8fl1REkkKDUrYWFUnyVBpGw0qKSom0pFCSrCRZKcpMEhJCdtmy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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs41Ikax6lkklCb1q1cyjpHp5LIvS91kmQlJWNpbSRae5SSXLY1MkkX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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs81AsCxT1uiRKSdG+R67kJUZFW20lZtytye2mQolWhrtaukK6Q6qIw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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lekXp5oISYnS2JOtUorI0tdYb6IoS6m4DRWRRDGWDJKENKHsl6mm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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8Vf0fR4MiKySpiCIhKqN4nreUkvSQFJUURSXJqogkpKFlFaWipazM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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs4lGkfx0cJtXJKSKzRW7Yi1JZZo/rmUC+igy06IJVS2LANObSiHCYN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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs4lAkbxqWWTbVpOumg1UH6yFJtKIdbNm0OHVaTECVsFHIIU2qdoo2x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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns8lGkfxidl37LYrEgqixzKIKGo5LKdqLAoh0RshiU2lUNsalsNSpJy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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWGkgVG0bJpKoLCkUhRbySiqilKtoIRUlJZVkr1AJUSlbSIQIRSUSFVFp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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk41Gsbx0dpjqUiS9K8eDG9OmmzjyVfSdQp2bKcUKSdpE1TqtMroRKp
KYfkaEEiS9I4SmM3thpjbKGU9bd4066Oo/N7/3iu+4/nuu7rvu7v/fnobz/g
uXMGi8XiM+//ld2XXsC72o4fifz8QpJCZvgrI9WxW1g23mtzKJqAHn3/QknQ
C9y9d/DhkU4S7s7HCy/v74HvhIHXbIVxZByQsLfqtGO0ZeHk5noKfqrfLvzW
mwZ2SA+/M5iAe8r1N4dG2nAip6FPbjcFh11tzb8W5EHUH7zvSR4BhQHDoXJz
IT4NV0lV9Ehknly6qjNaBIFJ4TIndxJHF38u79rdgfs66w9zHlIoUkoRetS3
wSJHU+24Mg0No0TOO/9C3OPNiY6sJiBf3HQwbl8zhPmjYy1KFL40J3+ODeuB
q4Jj5OgpGgETV0wKStuRbrnSt3E/DZvNN3jpfh1I0ew+v+QoDTmWr2jVyy5w
Tbd17yBpOGxzYF9KSIL2mdhHna4ENvM+KFpXt+K1kUA+VoNCpaQm5tgMAUrt
QjrbvAiwpFzbit+lGLSYF/pHLQX9n2SV3PAuDDdyHDP8aBSN+lhtcstB26WR
uPnpBDQOEcsv+ktgqKB46/0dCrz3g272AaVQe7faRX2aQGJZ3dvnZv1YkGt6
bFYYDdag+2rFyQRsHtKVXVtLIMBYa7D0Rz+29jcsyF5II0L/VkOcIBesn9XP
c64T+FDdI5l61Ik3kamrV6yjURYVpn1QXIGoP+/6zllK4oxS1j5pYSxWLTJY
GWNP4FTSNGtNjRRPLxm0dE5QWNA610nZrh2vWvx1T12msCdI3a8/rRtDITbK
f9XRqPoWVDQ3sQQGDWpZ7W0Eplr3C+KJFtzxVF3y1pxCRP8Mrre1AN6ayzSF
3gQmPjqlBevmQkPu70CDuwRy1YtuW2/ogE2NV59HOYV2k6pk9nEZ/Ke0bYy1
aDjO9Uq9nlQDtdaRB4oXSYRxB51sWY2QcDsV7jcx828ZsastTkNm3Jsc0S4C
LZpTfOusOhhk9LbFlJJIkCzhmKELRW7hdrVvaDSt2LK6gvcS6/iq0SLuOGYr
0RcbpmWYCgtpVtShkekb5r3G4R40VlZumJVPICj96nTUiwcg37YuullFoEhd
218w8hB6/2pQCX5NQFwTnqSnV4V38786kBtIOO62TN7r2g5Xtlq2l5CC+4L/
lGvLl0J+00yOGUXg1b7qsYFz3Rh/i5e27TQuWF4JOqxdi/TE2xbxSSTKjH0j
Ivub8OOZx+IhZwoB/HqLiMaXUJzzdVdpEI0gjkrs9tBqsOdNR54PJSEUiY3u
9kqhn+Kiwmlm+NpzwU5ubz62fHeVqyshEL8/Jb7v2wvkKZsu/yGiMLCj3UpN
6yiezhun01YQ6Mn5JXtgbQ02OS+ePhJGgmfy1OKEz1X0ioOoODcCAy7lxUW5
UfDMdzx7yozAyKKjA5M3GjC74uXrN59IWIVzJwx2dGHQiRp2UqWhemVH1779
5ejIOnc+2pbExQlz5XwdKWqXPinyOs3sI5p7KeRGGbT5HJPq2QzvJYJA1YAW
HNf5GFq6lcKu+dYsykcGCwes2r6I4S/jXJm2hQjs7sfWHR4kRiTHzv6X3QXD
44LXzW40Qrynis4k1sHKRY8XJSWRvlV9dCxKCIFR300Xpv+2b/T8jxYdyHF0
EfcOU1hXnGGssVEGKashU/kMhZXiW5m/P2iDwtSjnUnBFLJvmD41Eclgfuje
tlTmvyhZx+eIlRDiJyyf6z8IWGbRpv0F5eAKvt/38SMRYbrl/NrtQiibBDbt
kSNx0jP155EuKb5ccxKP3aQwpvrvo7GzanBs9e7vfnwSLIU08QZ5wKZ06ul6
QwI6fw7d3N3XiGHu35mjoRQ2tl7gezwsQ1iZvuZ2NRIVj9ztzZ/1Q7R1eURc
Nw3Juomu6slOnDFbHv7YhgbfceEvinNqYHm6PLC1hLmfA7rOn+oFeHjVfslt
T8ZH019ttVZUIIGz7KcSJo971nHbLh98jrt+f3XqFjO+UQvlmFr2wJT6lpBV
TSPb4/1EYGYJZibNTT75ioCfucUth2Yhcrx9e8MZH520SePILLPRVCOsV0ll
/M7SzF450Azn9WsMP+pS4Cw67Gor7kVSt4Rmn2Z4kv1v4enkZLjM4WskMPf0
6YBzrbxcN47Y3Lcq4NFYFmhmPOv0HVRZa57Uimf4OnvnRN65Fjyn8k3P7qLA
FvFzVlRKYVD/LF6J8akkvvhyurIMsp2ZU3nqNHxiyNj07F6MxfjUiQ3HEdNn
nnfQqBQRKbzPgUxe1c8qJ/csaUNsdGEe15OC1m+T/mXXRbBfuqVfZS2Tx802
m4CMRjjyA975z2R89eDRRDhqsJEI3TN0jcSCyMa+HSP1+LD32h3NOoa3EjdB
peQV7K4Fm6cZj2PA+MAEr/wBvtzwF1YVMPMnRT6pGq6E/RfhZl+GJ/5jI6rJ
Pg9Ozcp9zbkEYvW9lQpSO2CHyrdfTGn8A7XdvPs=
        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81IsCxSnre3Kl5UrZSlOWNkuWyiFyS0qLUB+9JFv11KhrqWvJkq1S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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lesalVDJ6SjadZAkUsnQJVNqCVGZQqWkMmQ6IaTQ4Ny4JE22Sule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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VW0XxpFSkpAkEaFBkoSS1O0tiZKhVERFkkiSVPTKlMpQGRo0yGtM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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41AkXx71dKCvd18h1beSaWEqafBVplqKi66Ta0k2hfctWdkNNKeW+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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41AsXx1GJuO5kS125lP2qdFNafdMipeJmjWKMytw22lwVmdY30kKS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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk41fkbvdUolVJGi8pSI1mKaqiUnIqHkqmfJckWilSMGbvp4k6WDLKF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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4le8fJqUSUkpaQopKKhTNm0hCJQ2KJEpL39JAUcnKSERDGUkI2dkj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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk41AkYx21o25JSRqsyi1RShEYK+WozJJQ0SdLuKEk2shoWZRqxriSJ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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs81IkaxienkEtJCiudyiWle61u8uTSVYQTq7SzjFtKVm2mmlNMCrG0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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns41Gkbx4VVWzmVNlJySrasJq9FKt95hYiSMURKCUm1OjhFL6HaFCHK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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3kgVW0XxVG8SVQaUEQiJWVq8FLvIimVFFFCKnMSQigNkkoDkbFIg7FQ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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81XkfxWVJKg96UEllS2ouyVDqoUO2VGNLpWmkpK64KqrBkEpXJKkG
4dJGjISu0Fz7EpIlS9e93LFVWn6LJVMqjOb3/PF9ff8853ven8/5anufcDsi
LSUlFcKc/98SXb3CpL09UPfyvTi/kwar9KBx2LeXuORN6j3ToVERWBD9vPop
quYM9X7IIqEfuXJhc6AYA4vVqzQO0ZDqkKe9Enk4Gs1/LDhCQKp+QscsxBNr
i0y5bfoEwjn8A7U1ncjKJQZYIgo58WYfTW8K8G1a2tpGkQTnoPa89w6MnsXr
u+MPKIS8balp9a9EXaT9yrsbSeSZS2RGE7ogMHNZ/mCCgsMH2SiloT60sJXm
NuqNwHe38uhxoRCKLl0ZnYtp/KyW97Y8sBsVobO7i5RpCA4ZWwhnBYiovRPp
vIKElUXtJ6IrHwdHfYZM7xDwLXLP7ZjXiwLdz8/N6miMX+9PZKe2onuZB9Ht
ReH+2XJJ9tgL3No72jLDp8DhTp7QVkhAziIyQsWVgHvioWW3k19i7uCe3+UY
f5qz+p1hDU8g0TtCqi0gsX1YsTVtnxg6S0a7dKVo/NeQL1v6rQ1GS2NvODlS
uDzT02z4VzeebftxT18ZBdtNwenF75/D7W0U+94wib0r0zbuHmhATfFO7aIy
Ek1qw8sLEppwPJT1IlCTwvn1Szcfb5RA6uNnO0pjBFYGJv3TAy+we87aRbvc
KSxEWW3mcAMqQ7XZMikklOXFi9jGaTC4G/yo4AQB84dLdeMtW5GkHG68xpDR
v5CYrnyiD3JjxcHjBQxf2aQdQ4udIMM15BzTI1CjdcMk70o1zFV3+RNHSbCu
JY8H6vZgqixH1SqMhnvokJ3mUwl47Nyn7dojqLe2LHzPfY7it6vj84woGJJG
sldyupA7PRM1EEbB45qiwabj2RDNHbe7kkKgafHtoMvWD9DW7zybmkkg1G2C
fdlYDC3258Ulx2h0niwQ/mYqgqguU0lHgcbOtfHcBdHt8HGOY60KofApzVH3
lJ0Qp1lmC/e50+goW3fR3aIQ3Qqmp5oaGN5+LYpyfCG+bOHXterSuD4ZdCHt
1xK4ppqv0Z9DYsTX0keqoRvx1Z3l2ckUlNdlT1VffgnvLS3lh9RofDJa8cxu
twAWCiuXdGmTqLkSIzP3fTEm/L+2vJwgIIlou/hoxwDy1//t5evH7NOTyNVy
fXXIsfvlhCiGRKTikDV7lxgGEds/X52iMC/qD+5QaTMCPI5lpqtQcAnDiivp
OVhW99Vs/w0CejszeSnqneg5VdZ62J7C3RUSs1mZZ/iupOzmM4fJzz523/Q/
ZYgemnzgwPjXizXsejdVj2j+4beq0yTu82IGqzeWgnNT5Yy8CcM/pniTP7cA
MxmsErKQgFGFZc+qFAkcknQ0OxVGcDJikFB2b4Pmvcj1zToUwv0f7zuj0Y+y
i5ow4o5AypOTIkOVQpXQSOCySJycNxUfqiWB0Plqc9wMjZOn87dujerBTqVP
5jJ8GstvvU6JyRLBLT3o+7JaJs+wKZ1kpw7st0k0qU+lYMXa0F7ZGwve9gnv
V1YE+AFPYtI0ipE3RpaZtxDoCk9IqpKuwSMO/jxtQyJ7sKTNUr4cxRmEWtg8
EqdVx328TERQfVUuE5lPwcf2p62pv9Zh8nfv63sukYh/1OR63vIxbgbNidV+
wfSTvNU6Wi8DZ/aaqy28QECrmh0nyK1BvUphm7cviQq3ql0JkyJsKdlU3niU
hvoX+XaxvBCvN2ctSX5NQVg9tsP0Szf8VbaOrXGhwZuf/lk6tRZvoq34A9kk
uPW3bj6s6ENu9/wCtR9GwCGjOH7vOqDH1SqMNWbyPFWZFVbYDheNvOTubRQ+
bHPOuNFTDjJP5X8eDiQkTTKnA1gdGNAKCZl2omADLer9pBiiwYENJQE07pkO
//KsohP29+7xg20pGJ88fN10tAmF339oPiwmcSt1kcNXWyF6Rn9b42pFI/Ls
PwE223qQp/aVvP2GQgc7r6FfoQN33QyE0sUUhhsfuJjYdmC7esSFnSkMH7n8
V0EJ2Zi1ODVgcZWAQmuepmdLBw5kGFDxrhRuB4UfWyLIxPaHxwRVEQRyHz/5
VLO5F7w04Z1V52ho/XSbc7iuDQbpjqufnGP6ibRraJ7xwZ6Qc232awg0ynvc
ueQtxkqeU/66UBpbxgSuC7okWLLC1SVCdQR7Zay6nOIaQVuuLo9i+LllxkV/
9H4J6arzbZbvGH9c/YLawFyY3zzL+pJL4N01R9Uvon78aXgkqc92BH45b/QT
5URYG+x4/eMgBb602+QqViLsvZ5npXgQiNHoMfP8Ixcb1B5zWEy/+Co2N+Sr
i5l/gXd+sJDpA9mpUuuWOvznnWiRcyyJcdmi8p+rK3HcU7e03ZOEsS0vxW+t
GA+b4/ZXzlDIcHwxaqrUi8Ao1xD1R8z8L4gS2Lm0YFfw33YBH0iEq4rtpr5L
cL/yw61xG+Z9dQc0iiL6wPPXSMqvpvEvZKLIiw==
        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81Pkfxymp9dNvh8FSEbp0bofNkbwkTTpsVqXDlqP0azT5YUmOpE0l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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8VW0XJcpQong1qSgUyRAKYUmTUgoZS4TCRUqmovJ1kUqlUihDhqSX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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2kgVG0fxhGlFCqFFksqkkQlqR4XkYfsW6WEsj4hypalUiEkKVJpJckS
IRXKvo197DNIFGbOEEKbwnu/n+bDfc6c+7/9rusvfcrDzJGHi4vLhpuL6/+/
d8YWGfSL0nFu6w2ZtGAKdo9YWg1vbsNB+cq/u2UohPf3Dqsbv8eh+g9rpK9Q
sDYWms4opuGUzbx/ayyFYK6P8T+3ZeGswY+pvybkXObWk5NBdZBb/vNrQB8b
2quuOlQcb8a2qmdfjo5SeLrnSfqYcTLqalUf26yiwN9U/FzLpgoNjrX2koco
qD0x6af3lEJUbSLl6lc2Hta5bdqzggbJjkYV7SAKpcdNxxWuVOE7Q6HiyCMK
946Gc5fLxkGAf3ul/yYKFoMSATHp9Vhh/dlnpy/5Hr3lfXZWJmRjNu2ZNafA
rDeoL+HrwqzcDEPWhAUuzZNXrS7egu+W/kE3Em+v/6vSibZS7L/dMe6+g4Jl
gb2npSUdhoNGtmv5SbxB4i3XflTC7q5Z+/cbFExkvS28JtrRLfDrr1ggB3YV
d7e2NzORPKVmKijCxiIn2XfFhxugqMRaENpL7sdaN/s07j3YVtEZZf4UtJni
mWv9O3B0QE3+gyQ5n1i9V6egDOGxbiO/EilMjOarOrgnwunLrlUaJL48seWt
1Zo94J3axPNteATCnS0392u/xdPfnGFpTwov983tPnKBBvnCD+/Wi1PoL13z
eXJjF3K5G30jWCNYVyNUEvW7DV6yr8N1mlioy9+y94VnG5x2XeS1ARtxTTOx
2odpCJWmHd25kMLtSOf7/vQ2aKh3bZsuZiG1is9xw74uyEF4YQU3C+I6Ll0q
d0oh1TQTpRhH4UOrh+92q1YMJbatGU5jo1D009WJT+0Y1eC5/HgLCy4plKTL
+XK0S+4Nl3Nkg0tH7ufDQC1Ur5qPHpUm8XZGSfmbPIPY/o/+i3ZSMGrUzD10
nQ6p0bDVLS3DQCQ7a6sWHeozLn2TahyMhkrnPPduhcEGfq1FfCMImDzMrRtZ
CKeHotG7tlDw7L3temRxHubv63C325F6pfXt/avaiCgXed1N6sPwbzt04Udf
BDZOa37uJ9+/F2+8ijuiEWfORnywPUMh23+rvEMrHR+0De9pKw6D2VFk9tyX
hqc7BAINisj/13ybG/+diux1y5vr1lLgqmruqLlfhOqXWovlhMj8vP395Udo
JyJ+LigyNhxB0M8ly7761cHjvXarwjgbZ7rPO/pyKmDatobLTJlCasUffu27
5VBd3Vv1no8Cm26xP6GvBelSxy1S97KhtLi+v0G9HiujYiJc15N87zrwcGF5
LTzVi2+sopH7u5Q9MLNqx6SaYbFS0jDafXJ0vOzp0M0ZN75G4kkdyvl75Fgn
JgyEY2+3s3D0nUQWrZEJ+XNMn5lyNgwyw+cjXOsQGdrAk7aRwlIN1jNTly70
bRHjlrBjYavMuYJf/RXo6xo692YFB/20mUnh2HpMn/EsCR2hEDD1w4hSa8ND
+xcBu28PQ/eF//qUzkJwfbMdWnqCgsG6tI4bQzTs7q1bkDhA5pNx0Cb21VM8
d7s4WiRG+DFw85BSWhkmvY7dPtBP4arylTv7UjvhvXAlXviNIC5rtkV0eSsE
Hz92uLxzGFyn/ttvd/s1Jo3NrGknKThc6V5oMVqNkoHxKqX1LCwTy/4jNs0E
e8yJZtfEQfKelj03vdMQFCX4SYLUO0704BYdyWpsH32auu0G4VWAwbePN3Pg
rh0ltleAgnDtCl4tx3pE9tcs/PyDQolJWfXknx5MibN3G+ZSSF7/Z4/cxTa4
qMsfyfpG8vH3/B/9t/lwUpzUHf1/PxRpHdpMq8Od9+oXtzezECObrvz6zFvo
+5wZuX+VQmBR4cCii+2IHnqhHX6PA3Mpu3Tv2SbY381NTxEg9zU4ZdzaXIHf
jre/PD5C+iHw2Hm3n1nYaah3ylWNwp7KNwnvjVow3ZdruJPwpzSD57Th7gLM
zf2TNWZLoTWPh1HY3YN78i9meSU5CJaV8Iy9fwMSa+tpLaKEN0d/xJ+oL4DB
TK/I9FEK9AOnv37/VA6j75um7pJ6GgV3qwUF10Pm+04z9x426rgUz906UQsp
hbKUrTaE3890jzvnVyBB/OPQfAQblwoXRE8m1uLX5m45TcJ/rq9fn0lqp8Cm
Njz27BwbYpZP5jaur0Zp1q/elY1s9Oodoun5dkMqavZGrfkwfjlNt6mLlSHg
TB/jZi8bowukdw8rNiB+lYtkRgmpd9mUg0peDfxolj8CiinUPeP7YnKtDDGB
em5Z2qS/li5cJO/GwFCpwRl2zwhKb6qWXf5eh1jt5f0hLRRGX/zYpb+9Ea4R
zOGPFqS+yfuTvtp+AGPe43OiKoV4ts6DG6bN2GdeonCA9L8cc0HD4/hMnDrg
a7JJl0L+yPW+nwofEDBf06VJ9C5Gg7Zk/XoGOm66979pH0HhqSTmyGgt4jpK
3B5f4UCMenvhGa0W5/++XzjqQ+brQ3jAhEgXHruo2pQkUBBz5qKtTXyJv99j
EibI/Iv1++f+6S/EwTuSNqxQ0j/S+YmmjAuQ4JZw+kTuY60cWbpuQx3ubTM+
/0CDQjc9LXZ0UwNMf1REj2+jUHnE43y9PgOvoqoFXcvIfUt9Q/XkOlG39fJ6
txDC87CNy/sIP8Nj+JW7HDngyuUZu8ydioRvsit2zLPBn2nK/Eh4rvNC6atZ
DRvpe5l6llQLBLa78QpNDEHX8rp1I60PjmGGp1WTODAR+NB2al0tYjXUFjVG
sECbCb3XnFSOn2nuMnlE393M7udeFi+AgvPiBVIeJN/yPHfn3BMQfKtjRp7M
e7z+apUlHqVIWS7nY0XmydPnT5b3qhKopPSEXCbnS6V27f491I4hQ/flpQUc
3PrGsLf9m4idirOG3XJk/uQF9qW1VcPXQNT55QPC28dW23PtciBio7zEZ4wN
l8nGmGTRdoz9G6XJQ3h9nm6R0aDZCAtBgc78YySfh0s9GoWY8DhS5P/rDge7
H97+FvPiIwZTlq2Y0ByFTZOtTuGREkQfifqb95eNu8eya9f2MnFA02u0KYKC
wjoN5btqHSjk9diSf3AE4cvzx1u0GjHaLmCVdoSNapHWOal5Jsar2J9crTiI
/HlS7R+5JjgE8wwWWVMI+3R28aM4JjLbA93kyPsWfO+Ph0i1wZNLIkrDbhgH
grf3G+mV4rnN+skFJH8Tgt4+raMpSL62bO6lCgXG99z22/zxiDjA2bdGgcIc
9y/hm7Ht8Lr8u+GGOhun82/6DWhVYY3QgKqiDAe8vYq8/z3oxPTh4cHVtRzk
KMkU9s3QkfDfuGhrBgWaz/nTycKlaJDYevUw6feY/+zDg8pbIOPWHna2jYOn
fmvnFi1uhqGydIXPJg48W38XR6okwy0wZfzEdgohrMPFB8w/Qt53nq+GMYhB
DXX69YQKNCn+krdxJvU5JvjY9+4z3Imvcv+6koKGlO7Q4/+ywFi5SdFKkALv
s+SZHKV2JCvHnzjSRfpB9OfrDVMlSLO/ZKP/k40dx/LPjfRWgmF08FPaZQo2
16kvqfda8E/mAyHJ1cNIvX9cOnPdO5SvMG0OGWSjb/OycwFdFeBJpwc8DSD+
cZvgzPme57AXjnQt1SP5lNSuL1eggZ/vrWi9PIlHeOXrmEQ/pHzb2WlI9CH1
oXv2iZN0BCWNOwsIsjBpYaX62fEt7g+1PB0yptAZ0vdueTIDjg69V40sB9Hq
Gbb/nFwdjvIwzDQ2E33OsxbVLSghdYleUUoj9zk3vuO+Qh/OGP9KPXJuEG4O
br3p+mR+cizD4rzZePr6valv8SsY6B0L1CX+c2lwHY1PqBHWVYNlPpFEX/SX
qzS6ZaK5L28rP8nfvcCFSasWNUDum1H8wrdsrIh7UvPHoB0Fl72YkYJsfHHQ
kTDX7MKz66Y++kwW7F5+mg4cLoLuYGTOReK3uXCwz03+HPoztazSNpB5enuL
pZH1BqPDJ2rO76HwvHMmTFq8DP84b1/gSPyBxO8FCVpL6Vj94NPi4r2EpyLp
Fu4/6/DXPo3HvoRCbudBw08aH3FIuv2+uO0gVK36T4i5dcJBlxWwcDMHR3Pi
LE3VahCRe/Nk6CDhtYWEYqN9NyZlGUu4TEYQfEDJ1UuBjmnxkx4iqhw8rM7p
367QhWiFkKipVhaCayWSCu+8hWvKg+E8wisTrAtdPtiCnKDuO7zE/5j4ZFjI
nqnEaduDs5mHif+dHUy7blOMYFO69ZH9RC/LskQLlrfA4JttiZ7qCOSU1I3P
HWOgOuLMtlBTDnJ1Vfr6E6rQujIgUTaG+PMYvtOlYwzEvGRFu/txkP3mOrez
QzGmLRnPCwXY2Fz5VbmtrgUbpKt7DptxELfWX+Bhfw2El9256R3IhsO/0cdP
XqPjo+i1W0lhJF/dKz6uzOpAyKFLpg9IPzSdeqTnv7UFQkclLk0TnokZ/xdk
o9GGjg5587h/RvCz2LinfIABh9vOKavjOBBWCV/UYJECidE7py8sJfG+9FvJ
VMvBl/5v0eKaRO8bvKuNLOjob665ynWRwnRnF5MVXYZfJ/+rPXOOjdSUS3mH
XBnYXHch6E00hQS5C9vms1vh7Mq9OpvoJ9tt7uUfIToE1z5+bpbJhqXyptlk
93q08zWpnSf7QGoSt0dZVgG2ts4q8hL/8p9LeeS6yS7QdrzSrt04ArpcL0f0
VRp8TeQuCG4lz8crNDF923DeXMwwvJrCGa+HTw7a1WDnFxWbxnQ2pHxrF+i5
poKhP2kuQPQtqLjgynOV91AvlfW7McSG5+OWrCCbbDT7rDaikfl32ftcpy+5
DHx1vjQbV3L+t3wH6wLx/1WhZWaV5P1TdvWd8524aDaWfvIRB3LtNmr7NxSi
Km1R8UkXwrMf3DKzTjTwejkotRI/wM7RPm7e1IMP8S/mB0JYkPsd05hFb4fb
LT2zjGny/MlLTwLf90JhZIxdnDsA/k+2vsubsrGb7HsZSygc5ojeMk/Jh+K3
8s3PyH4hmCUytGBxJ94Ozk0b7x3G7M0vd3ba9SBso3ttYT8HrvPSqvpP6dBf
8fCC2VkKLrShdQMX2uHK4FON2sBG58srL0SzO3DMq99jgosNRvTobOHbSgTu
j1XLL6UgeyXheMj6Dzhu0XHHlvBnXXCdS6hTNv5ZLFz9UoLM0x6exzP9DVAu
H7yhZ8pGv/rtrojguwjICUyoJvugdTPD2tIgH1KrB8YFSP132fTIyXiX4mWq
RsdxwhvG1rroZdOliNyTF2VJ/JmS9w4x35wKiAZnddyrJX4u+1rRn/4yjElV
i6p9Jn4myS3p+r812N1pVTS/kwPaquz7AZxm8DAtNk7u5uD8j6FJwy/lOPO3
6rhzPRv5Jkan+EuqIVmyR9diMbl/5gl3y0PlmJNXGPjjSvbXNpkdB7gYaIlt
rJWVZ2Hp8VllQd5MJKa7v31uREFKv4kmd70G7kFbL58k/b6/oEol2LoBU5Xp
RlrlFGYNUpkGRUyMWcYPVFey4HTT3tOR8Hv9v+v1fstS0GmwOrbLrxdxDRaX
y46SfeyPk5+SfhMKn6b0PJsjvNC8MB4y4YGNS47sOk14GCMkkjrzsxk/P/Nu
YJL4g4MuHg8WvQjm3uD392QIH4Tur69hVSGMyqkMdCf66dixzGaqE06S38Wj
V7Hhtu3Buzcrs3F07vJrtiGZb147pV3xDeicW7ok8ikb1tLa542i6rDI8bon
Zz/Rn2jhydOVieC17/3QRPaHfFXNoxO9HVDr/vJxBX0Ycn1n/dq+3QSz54zP
xDoKv8ZTuLIHiJ7/2yLcMkHyf41/6lBgLfgtBAaeGbJBv8sJFOtug7d6hnmr
Eqkn/WG/TX81yp8JCnUQv8mv63GfO6oAubSYpXyEPwk95ubbIvvAM573JGgf
BddAl0RT2TbklnCvWWlG9Htn0dXtWq/hxkixMSV8/JDVmaiixITWMfs1h4if
novV5Xk0XovOt5f6T7uzkZC0ifmEwcCltgX6zsEkfxK1XnoBdJzkky56SOOg
UNNJZSaDjsPDX9daEv7EXNwp/C6tE7dKridZPGChWOSgl0E64XVJg8N9IeJP
jU6pi1o0IqvIrWSSfC/e/I7ziHwNhu+JGObbsHHFZq1VHZOB9DcvnkzrjMDu
c0EOv1gBXp5qUkn2If7zuMG9oidVsF1qGLj0OwuZTaWyYQOlGHZ7dTPsExvq
g+/v5YkzoajzwLEsiIPNIbUiN+62YbetsdVf1iBiovVvXxYjfHsxH+FJ8p+8
5rB3m1cHbicLMfMSyfeWyHoVxaQi12Xi+srdZJ862GCbbtGMHXvtO8Zm2Njy
J+TZW7l2/L02Zaz0eRiRTi1cGs106BzifJ1ayoJSdOCZJ2GvUS2wd1GuJIWj
imLzKufKka21T3SG+NkN+y58D5upxN20DgUV0j8bw9cmWG/vwd4t3V+uPh2E
w6bJle9CqqCwcOe5ZWQeDvZpLrj8rgUpR6PedZRwoF1+eEw5thE2CRpZ0QfJ
/lWr+1BnhIZL1295iouQ/r/Lpx+yvxwp7X4KXnxkP++mHL67VmPC6pG5kwHx
G4ZBo35+WbC5pJleQPhu4pXJeH6KCYMVDcpPK0cweZjKcNxWgZYB362zZJ/e
bbdGJM6zFTT1jubPyzjQCBD/vSQslOisUGgZ8Vdi2nlT+gbFeL32UUk66ce8
IenvAsbNuPJyIpWL+LVexU8t3Tl0fP5WHTFK9gMJr+f7KjZ1Icu6PkPv0TBa
VyRMhb1nQiG2qsadl4II16Tpnq4W6B9bd3tJERsZjnHtL8/2wGkZ1711G1no
FR77dy/x/+ahEXnbtnKwkPuO0smSDjyOubpbhuy3T6tpZ9tVK6G8+NXHPsLD
EOOV7Lu2lVicyn/Bn8yPeJ9JmYF6F34HH+68WMhBk7iM/2P/bpQWyiQtJfqc
Hb9ovG1jCAIavvgqkvjmdTJkpDK6sLQyfMWdzyyINB8d83ZvRXySrUqWFBvP
l592u2/FxFkxXeuHX0egkT3V9XVJLaxHZH57EL8+Ztbd+9W7A1Ll95l/vlOw
u3nc4YZ0IZwrErpnSf9PJPgphTqXgjfu7WJJ0l9RqmrVk2tbcfpK2bWE8SH8
D4wmHl4=
        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlGk8lAsUxpmUJG6L/ddiCSWFblxx86iIEimFFluLErJGJSIu0mJJRmVX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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs81IkaxsclqSi5dVmXqY2IDRESHtKRLGt2OpUioRTl6CJyiZDSKqeU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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lWkbxkhllOxSJGSLNNQJg6tspUwInwhpUUayREWEb8Rna1FGx6SN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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk8VP0fxRFRSilUKtlSUUhISaeiXSkkovJoURElRZJUaKGUbNlTSZJ9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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs01IkXnzJJ/fZMkxKV7MqqySMSIfGZltqSrcRqtjY9yOq3ESo5v4gi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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs01Ikbh91CGSmFlHRRq1gbSWkrn4TK1pYsRq65VJKyWxFzUsgtyboW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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx1EZTTFZEqGfpckyZbsI3fGRVEKilGViuC1MJQ1XpZSdapQl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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2cglW8bF8pMRqQlCqUhFYrKTyoJofKXQqFBUpTdlIRUUkZSCRUqshUq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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41AkbhpGUNm0hZhHqi6IapYRSj+orKo0OKslpRTllE9mpxpIV2iQp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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwV1Hs41IkaB/ApcrC5lHVZFevQHCSRqYkHX9atRuiMS7qzSeXEVmTlYEXo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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns8VVkbRoqikjApDL5uOAmRxmUeGU2i5DYuZVS+45RriKRGSRozMrlH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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c4lu8bxiVJJWknI2RFqZSo1KlCklmiRaWykoQkZFUSoayMzISiUNYX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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlWs81Ikax2en7FFHknLLiqVISURpbfkRRxuS1KyQ3K2GosimVGTKJLqt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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81Ikbx4dkK7FU6BBybVaHItloP+rn2vFLKVlXW1PRbBJRqt9Pjh9J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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lWkfx73SOKJoLCNtIoS3miIl6VsRKiK0kLJMljBUMqmEiLI0Y9+y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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8Vf8fx30LKWkgGiqRUSEZKcULpVCkaSaVVGjKyCY7CamkSIiUUUhC
KEK2a117JPeceyWUSKrf5/fXfZzH45xzz+P9eY3ne92pS4fOzOHi4rL6j4vr
/7/RM3NH85KZcHjRSCtODmPnLin5RwlMbLh2Tdp9JQc3wroHk/o7YTk9nbpP
noV+j37zwPt30c08bSSxjsY5leJzW5Iqsd9kX8apFzQKfh9ZEx7LQOKCt50X
yDXXX2O1xBkHhJetrwkh97tKJxyoX8bAy7NWiTVsCjH3lbdXHs1B0tMHLKVV
NI5cWtnQPrcZFnMP2s4E0sjw/uvjeLEDw4YxS8/00GhUmZJzmqjEo/6xNxbF
FHRerLW1LmhB7seLKwy9KXBf3bipKew9NsgPSejb0gizHq1/r1uFt6+57h+a
YkHd+730p7BGBLn39/zHzYbVhXyZZR1tGInrZETqcDDWvmny5kw16sP/KNld
oRCxZuzd02W30SUfohAuQaNcTPxiWwwDS+dPN50oHUbUP8kH+y68R1vk70XW
VjSe2Y9f3TD9ChPskOIgMRqlWbISFyRyMG+QR9D+BI38L0Vt4/4NUEh6GFeR
SeOiheq/O4cYUL107npWHY2IiK5jhuNt6E5WFu1Ro7EkPCHau6wX9n8LDQNE
vuLX9xiPYRsmAuMlMiKuDuHOq8ABdmcP3uztWXePPD+jvtmpSYEBpYa91cnl
FHqdmxJj+wtRcIPzODOEhtKvTGPLIQbU1JZ2vzejMWke8chwqAoHLlfozZJr
rX+llPjYRzz7FI3i0zQkbEIGLn5mYMG72sFxSxr0jheCqtsacfVqrZRMJAuN
xW45PH8eYdBu0UkDMp/eTh7pzBIGfmifnV44yUJFwj0vQ1YeLCsTb/nNULCe
+/a+wJwOrF1gaCDvzMJIRlryzNxcMP9JTuVZ02gJGI45Z1CHCVHN7m5BCj+c
soyUdZmwHfm262k2B1V2L1XODnRitZQCr5E+hf6U5BCDOWHYiPl8jjI0sg+b
uIZwMxA8dD6nwZ6N9EXT11MuFaCmavrDjTM0Pt9ll2IxA/5qL6P4f1LYdmTh
IwGedmSPpZbzeXIgKWZl0OfbBudx5ztvNIeh1aYt7WfbAN+ivGJ+Fg03TfcF
4WS+p1f3pF63o+AgvGyA2dyOodPKD90D2OBixgrnPTmKTPMfVcpkHucO6piX
m3Xhsal2cHwnC8benjJjGi2Y5NccpZbR4E2IWn+qoxMJIue+IYiDmIqW8tUr
azDWq26XM0YheFzORzeoE6nb9y1vyWQj+KFo+3BOF0Q0bidcGmAhoVI5fbAu
CRn9QffalWmYnum/oxLVCE2n9lr9aRpVAuc/r9hUhWdVj9OPG7Ehd5D3nUtq
J6rT47RfxVBoHMhb9+phJSQyjtXqnmDDYdnm1cGf3yH6wZK7379RSNScHci/
wYTT9Oj2LSJs3BJcPCYlkYbYiaW9h43JeamLGcpurkG6nLPpOSEKlkPD+5X0
XiJyV1fVOjLfMQGROpO0RDBiEziSi2ikh3gPTbysh+ihxlWH4lnQbPKJ/Orx
FjZX5vSFk/PZLy76RKCuEzW/Q9N0cyksKFvC3qucB0m3K95MV+L/mYqOz1pM
SLqqa0j6cKD1SbhuHl8xEoPMvvQdplFEX3YPe/4JshHhaamPid/4p/6mbG1H
2CEB/rpNFNK59hw0Xt2Ip2Z6qyqNSD4Jc0T2lTxD7/vVarPziV8zGbsr7DOx
RPvWaiPy/a6xr35dtmdg7IVvcrYvBeamfO3a5AK4yV+xkSP+pHrNZ5qEmxAt
2zIvaCeNpzm1p9Y39KBfeEYz9R4Nm/y5byuvVWIyj7sjtpRCtNWqkvDqeozt
tyxJGyH5crtxdGq2DkIBq9dK8dLoj7Hqd2krxkRYyKLpWBrM81pNXs9SIaaT
1T+gRONHqEbXZ+E6iIgqSoqsJP5ksPz3pnfB2lpYM6qK6E9kR+Rl8Wi4SQ94
rFGg8WjBsHrNyo+4dUGmzGsDhcBPX3rrrrdj0b3OHbGv2PA3ulyj/LcTSas6
9kT/ZEMvrFbq67FWxGa4j63QZ2Oh8errr5U7EV88f6d0AxsXkpcuPd3fjGNR
br0DzhwcUfmVanr5AySeDhZpbKRhpaXDs3N/CxSbUmLRQaFU+UzVVhV/+Dku
aUuUJPnGcbRe5pIKKy6XE2wBGpe1zC7cqspB8dDDm057adw6bHBo7GMt9jgc
NVvbROHajh7zm/db0dcfvezreTbWbzVvPG3bhG49zez1KiRveYr/vdxRhBOb
3F/vrSB6nOvWr360Frq3fENkPtEYP7dwOEi+C5fOTvyu4mKjv7ythUO1YXmI
hnKc8DAUQ5X804xrkZn3Vy1lHhviLk+Nt2i24NWIO8fcnoJq4oXgmsFaSJw6
w39Xluhl3uqpZLMUcG2TeR84S/QQ3/XZ264Mb+T+fg9tobHcK1pZ6u1bLEwN
vdTKIPq5ZV8v5NyG+aHOXQu/sZDfHBO8wScH0oZXBXuJH6h28+wTWd2oWaHr
ESfHgU9ghn2haTnsV3aJzWVReH7NskW+uAl+Ji/ueJXTcJieykquK0PNmK+J
/mcWxrQE5DUC3mHINDeNP43oqXdL3gWTOIwueqbdS+b9Zee46s6iLiS1Mgy3
3mTjweTX1IipRmw7fepB3j82GoV5m6QSunDigbOTchKFou2BbjfKMzBlu2iL
zFwaW9cYekwaNWE0u8/PLoMFnx+u9PMYJ6SrXdweJU6jOFBY3arxAzJrYsW9
31CY7a2ZK3rtIy4Ono8LnEcj+gfTZXl4K9qOYdq1ho0x84Ttsbta0XLb4Y40
0Qv7dtKIonY17DQVPs0lfKDSm2zbX87AVY6/2mztMLjWn9tjbHwWdqI59/6f
p6byioJH+woxUVUwhCfEX0ZqAxpppZDueXLU8CmNsdWXwjsOtaD6nYK2WOAw
FoVvO6Wd0Yoqj6YvRvfZeKab/Wy+UDXG9tB697Ip+Gl9YVDGnYipiuf4NrCw
uS5eqLmgHeX66rwLRb7AoDRm8OD+TsxWnt7+MJWCz7RQWSa/P7xMgsYCyfd2
zlO6FN/JQP/ajEKejRQSwk2S/JffQYB1uNA64k+fO2383u0pcLt3f2w7mce5
2F53wbIKFPCPLhx3I33slr7v+O5C8PEwN4+2kjzWDNmZOb8Mt4/GW69TpaHo
KCuxm7sFG3kF754eprDkDP9u48an2LzkpgJF8maJ9QGhoeIacHikM6YaaPw9
ejdBbqASjHotI61S4o/3N2yPSZbB9oJz2ncOBXWDk281NRshx1u5aXc8hRd7
Oz0cQ1ugxTM+X7uJhZ2Fe7vMHrVC5ZPq2M1xDuo+XVpnZNaIjUxHWTEt4tfI
pwbnattgGeAVMGZMISV+968JpSIUCilRzGgKGW8XyMyZqkTfmvKLFaTPG0ct
ZrIZ+XA9vkxylSnJN7Ob94x1c3Aw+lHBSZLntZtjLQ0rmvHMQfTIFikWupXV
isSEWnH33cA2zz1sUGv8c544luFD4PkHFdOkT6JZckunmzCTNWHD/ZmCoqSP
wW/V0wg9zrNDh+gj+OI6y++/y/G67K3KcBXh0ctMtfnuzcicoQQtHTjoLpJ0
OruxFa7C9vyff5B8KaMbfjnXQU9jfl1LJ40cFxOhOYUNCBTysDizgY2Zx95v
04I6cCyMfXHlDjaWzO7zKmN2wr5P5ZtaMI3Z3wrjouo10H115Z0FSH/Ez1gc
HmyHf1iKkVMaC4e25pa0JTHwdc3xJ5UubEREKY88DanEmcW/5+9YTEPmSvCv
vpedCMGYX5wICzH7+txCzSphvJElEMtHw8++b060bSvELBhj0tc5cNCY3u8v
X4JTqp1xOm8p7Dk28r2apxOHedV0P68hvH5K+Uj/gXJsnf7enx5EIcfxubqG
VgeMDN7UBf1lYY9z88Tmc424qERPSyxn49CtwZ2S/p1oeuNX3x/Egtb5036W
ig9QmNC1OJnoN0v04JpEugMPBGwO9JB+cvUKkR1bwsBz79GzdnGkb7IMWzVv
JeHoRoHRBYR3dz5xik+TrIOfxIeMI4fZuHZ+q7b68VasMRU0Y7SwEM4/FseJ
6kWakeBCbZI/PspmO2Q8rOHgZxChR85v8CunJzG8HXcXMFTWFNMQPZLCl3Oo
AVH+vq9lNCjU58mt8/RoxHqD/ZyeMjYYm5wSr+a+xwIZ7fAYsm88arsskqjY
hCT9OSEZP4Yx6+Qo/Vy1DdE7PJekr6cREJAbo5XPgJV2crrrdcJH/C1DiY+b
URtfX6c4n4MhlRJ9DBcgcWJGZ9d5GqGPDvSyPaqgWO1jE36T9NnbH6JPZrMR
4jLpu0SIhrurwV5t/WaUsNjX0srI/Ciux+ZHO5CmbFD84CwF5TOnm7mH2qGi
OO3yN5nGwmJh7e8KJZh57l0IQRrW/7XfZClV4aaEW+n3v8Rfv5dYf1jciH9G
uvKJxJ/itiYBP/iqobIqenGYNMnrP851J69EIt/nY1gFyfeWB63ai6ua8CuX
8TwSFCBcJ3tyBwOOLw0MPqQQPl32YNm9yiZUH7QbPryFwu4hl/dlWY1I/xo3
eCKXjad3WtTzixphU3UtTsuShZs3Rn7W8jRD3kz5+CllNljmAna1s50IbVrc
LrWOjco9oTZ7CX/vqYvIiVUaBnV4wC+koAbqZ2XW5/dTyOzOfB9h2QxLbT+h
B9soTLtda5X82IyUG8vyKHEKcgfStU4ymJgfou+oxv6CRfm8yoK53WiwVdEQ
lxiGOMc2wVaoAsJWFbJfBomefO8IcDsRvZ74o21N9rXVSj2xqeY1uGNaorXa
mY1Fq8QVnD41wUt3PDY/lo3lz5MEs0wY+LcivWaeCwW+kqrWzJpKtN2Y5H81
ReGEo6ce79pSDAsmm+x1JPuOtk7hyf5srF6/9JKSPA1N07mmvW97oFe/6Kyw
9AiYrBgN1oM2lPYkuumacCD+WCpKxfkFdDd6enWsILwz9cefh+hD5oq8/n0G
C9bXues0Mx/jTEoiVzPhSVRx7VgR34Ihq+TLJTQbR050Z5eeb4JIlLL95y9k
fzWdAnvXe1i91/kTdI/sIz5dj/qVqjEskxporEmDZ5wvWUSgA5etfhesMvqC
qqK5Fjr781B2PHyFL+nf3SM7Z7x12uB22CWS6wvJv0MH6JniYuRobuviWUDy
SCzSs8gtGFwmor2aRP9dUT9nbwk0w1uN988GfgoqPcEmuaoM9EqEhNwWHAaT
w73u3FgtZL845HIXkr6LOZmm9P4VRr9Nub6xIfNy4zO5bZGN8y/avl6zIO83
cXn1RCMfY56dMnvyiL7e6eXvCqrCfUpxZHMYBcHlVQfPelUh309qjYIcDbnb
CdMq6t2wbanVunCXRiHvhkyB3B5wR/S5MgVGICs1/smgsxU6AtcOBYgRXjOX
8nS+3o26m1v6lqaR/2e7PhHeXY9qVQXmplXE7359hyVv1eNUKMukgMw7wsTG
o+BRIRLk7GR1yf3i+W4DHoUpWHvYgZtflIaYxjfew3HdSNz7tUJ2Lgt9BuuU
juhkYSu7Nvcw2Z/eyfd3eNb0YOTylaS7g2zwZ1eLVTUxIGzjqiCWReNqkf9S
T8EunN5kaz66l4MPd5IETpq9gc6LZz2Rf4jfkm77Bp5nojn9b+HaetJnhddj
ZJ+UIjRveQBfL4U36g/qSolfGlhWwacKCU/12Ods1GuAZP2PQKdLLAyGLhYb
COlEJtd/e2pyPkNBNY2ryL0OUVIPs7z7KGzok3W4UdeMxmn/wEJDGgkyevoG
28vR1XRp7YAChf3qh77pa+TCi0O3c++mkay3wuRjx2V48H/afoDka5qr55GB
561Qdo5xvbuNg5fqCRNfc+txJKz13WM24ZPfL++8IP30dYWTTjThz5bJrAa3
wnIcNs/OHugifqz/dew/5178DDLjm7NqBMKw+VVEN6Lg78587nMsNObLW88m
JKPWYZnrfrJ/6DDsMmoutmF0VaBiwp9hlO4UHFxWWgf/gIaMCgMamW4bTAeJ
X7flXI6ZGCb5Fif+Mx+Z2Cey9HK9Po2XOtfzm1YmYdi6SkNfisbr5Y/iM/81
gntyywh3Khvbnov/srCtw4Hhh4zBKAqc6W8fDr54htamykqj5YQ/zfVv9v4t
h3zBkS6+DaS/zLd9a/z4CsYJmnMSzWhU36y4qirbBmNGWU6sOtknddgC4w0J
MG9eSymspeGxOZm/gUS17esKn00HCI8tbZlX8i4d3Ht5v97lJvvAZEnqhY/1
GMlc5VVrzAKX06HfVndawBdhE7WWnPfH6wnHpUqZ8H3NvaL3BQXeOXIpP8/W
IXSTI+M50dt+ls6lR7eY4FMoLd9L+JntHnls9eIW/Iikw7QPEP6NPa8T/zwf
t7P2xCWR8+wOfjwvWqwBx+6dmMOMpBC8gCnuq/gSaZtyG1VGCf//TP6vcUkJ
5qjkbHIj+uA+OaItLPAOCnI8tkrhpF9vB0tfdGvHJ65V/BFM4vcREa7Tl9og
tfTj51XH2Tizq0L0398WLDi4VsOWQ/g8jdVxl9UI1kWXfTsIT6lb+D7ctZyJ
6vINWz3sOBi2tXdMK2HAfb6FQ3cd+X5tG6O5Vs0QnGztzc8dxtnQr5nqczpg
Z+KQ5BFJ5i9mZ7HCpQ4nFZWGboTQSMlYfkTkSzkmNI8yOj/QENZfF49jbfBh
d2S6cXOg91LnW2TuK7TkXflwh/DFtbZylZbnndAZ2/GfFPGj3jJ9OQPpZsIP
9j/cNdmo97Q4UTnRjqD7rJ2tR8nzyXj2bHcxuidOJxYHU7BWqVlqJ/gWI6mc
BU3nKEQt8rLM+9iGgu/zPi8iPEFdnBVI7ChDitbD+PJ9FLhSIofkzHrg2ntt
+QobDsIKo+t3d5P+6nEjrEr4R6pGa1aB6Dfhnpa1FxtPRn9PqZo2QWvbhx77
IQqUacD4Q983WCkma380lPDuqQDmV+6XmHxso1BO9vn1EwPciWNtcC2cded/
Tc6v9WNGS1YKejfFfs8lfMrtKxm/0PAVHkq6bLUk+xhf33kvK9U0rLl3fpsP
0c9vofURPVnleO658lE5mQd7c1G+kecHTC5MzBIi/fk/Ligc7g==
        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXlYzGsfxsPbjpJBVOrQQl7J0nIV7oQkYcirOLy0ncMxRIVU0kIL0SJH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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwdVHs01AkbnmTpguTayEglq8IqlK+LRxsSSktbuqg5Eia6bBHrUqTPotJE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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8ldkbV0REoSw3jWg1UiSTNV8kUdbGeimSQk0zI7JnhtHVQgxCptXY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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Vl0Xh/GqaDCUSlEoJFQoUnh/eosUSSVTiCJkKEpSKlSGDBkis0SI
MoVMyRiZPTxmShnOeWgipSjf/v4617nOua6999pr3eteYmcuHLfmYGNjM2dn
Y/v/c97gBM13vQLbL3sfWaxJI6+dbuey78XH9Kg/hrIslBkcszOQqUOU2OFl
dQM0ROf2pGc118K0rDzT+QwFrhKXrc7LnyHRWzM9Zg8N85O3pE6K5SHWSMJz
jQQNPSqhhu9uDm4ZXZfYLUyjd6XBh4sLb2H4oOdyy1caG+kVvjn7OhDhPhly
5yINuaUbhjyuFaF7b7SGqRoNU069aa3QWkxdam1TDaXB9S3t4vzSZqx1rhDV
FWBBTuHXWm2REmT8XRRmcJNGfmrw4qfD1ajIS052aKZhVRqyeqUhEw3mYuv3
v6eR/pBxc8azGb9PrAs8k07hax1jyZB4LLI9GmKiZMj3L+HJIp2ZeLR8/TPz
ZTQCL6Ydf23zGt5Dmc8tTtAwW1ZpsftlEwJGtqbEitJY3qFrESLTjooizy3e
BRQqvN5pX1tzB5K+3E2im2lEhpXZPcZLeK6LrV1jTkMpXdIlMe0Vvqad+rf+
Ko2cjT8u6k+Xwa7sr6uZEY17uiote0cZqHjhFx8kz8IujXO+Ndv64Of1vUfq
NQWlimnZOsdOeJlEpD8l55NykQgUtqyHVCR7VYwrCxOSP2UG/zCgY6UgJp/H
QkionES2cj5SZH703h6ksN3GcXh7bR8sviXx/62iMOudEujvVgmXLNaoYzKN
n9+CFUzlm6D6Knq5fw6FSZvXDo3GOVDa+qnaf5rCamrQpGu8HYtWCfrET1Do
W873xKe+FcNXuho1r9DY0ndM1l+EiaeqcpJOceN4tv67iGpyLTYZaWvENlJw
mBJdtVn1BSZO2zvrfaOgbngvs+daI252SH4RmyPnEW+cz1xWAHWViVWZJJ/4
fCXHI7vzUfX+m8C3bTSiX27p57LuhSrDdW9sHwW+QrXjlkfakCAju7BQyYLx
z7X0obpOxL4Z3lO0mIWiN/1zRhbtmBrk1lJzm0DgsmOZ3iI5yNvRAvEOCv/J
V0VEOVci/iCH1vrTNDwtHy1TEdqL5tfXun+KkfWDPa5mW/dg8LbfIZ6MCXRm
Rf9tDuiA6lTBVg1XCuJrE3U2BPcj0PZcvjfNgqZm63fVoww0737Oe1mD5OdX
81SOI3WIWBRw+t45GrPH1GMW9TWhMOLH9ZsfaXh0Nq+5ZFgG6VQjaim5j5DW
Te/n63shF3mOT/0LCzdV1Th5M3pQOB2od6hiAnJrXW7/yxcB8dYG2fdkfw/6
EfohtRMxIYdf9NaPIi+lwfWZegdMw+NeGMtT2JhEc4wMNyG9QH/WcyOpR83R
+5VPH4PKsi5WY1F43s2kTjkxkfBUuFZOnYU2ibIfnbHP8N1mdvbvChp+hg8t
bokm4aBb3oZKXsKHwvDeufBu5GRcuFm8i4UP8ky2L4VNUPZfWiYUROPOjb8H
+elqrEn/L2kDye/wSAOpb0u7IF+Zv+zI43F8XeL7g8MhGwmytfdWkHgbmWaE
7+dsROfmkk17qkg9fHjqZmTZCEYdu7kmk8KAifiZgkEmPie2cGhP0FB+f3pp
pmArlF0d1x07T8HZPttZmo0Jka6P6/6TnkDIq+ZYm4BWmOpWNS1aTcFiW9PQ
jWOPwTHYbTCgRUPw+X33rcnJyP/UwPUONNT79cP/TuaD3WRspx3hn+3TEL7T
794i26s84k8tBT3RfPWDisWIXfDSXRZDwYV35akVJ7rRLDiU7F3IQjBfqcwz
Ngb23b0ibuJOo96822XPmWLEZLYa2MsTntVtU8rua4OfNeejgXYaj+zsJYay
QvGxdjZr9yrCD25l1R1vG2FeaFG3dxUFNqmxPFXJCLB800Ir19JYX73IwHC2
G+ZCgidXc4yjf+T6ce+YPvy10VOMvjuOuIb3X7xW1+GPRnPfKw4Kp1PEJdYU
t8PX+4rRPUMabXr1Pm8d02ByIeArJUcjqoPaIanxknBcT82Rh8YRoVipRZda
cOOht662JAvly+ZXqWj24szq12213ydwgdFmaXKLgVNpSZlhtiysHBodEFpS
hhQTgxcHTGhscx11mt7UiZoD9yP+Eh5xnVnMuB/eh5Cq0knTSRZqXkUs0v7b
jlQ78UVDJD5r5/e4lyv0Y6k7j24P4a/wtpG8SMI71mZl1yofGlOpjLifjF6o
/8vZX1RBI77yfPiU8QA+2wfJOm8cw6jN3qW1W7rw8/OS1Rkk/pKblzxdLtSJ
ip73a9jWsVARlPkt6MdjNO3JonQ3kPzt7NsZZViMnC9hT4x304ihvWPMG+th
4rFg8/D9OAQ2Oqr0MZhI+m67lS+NwvJwTqVle5tR90F1rmiYBpu0sa/iTjck
UZ7mK8VpjPGrPbIcY4Btr+bJ5AYKtyZVZo28W7HYP8vgPuHVZUv5Au3ibtx5
ODIq4cXCbKmTtr9TM0LL56RluWnMe9w2Xm/fiizJKyeUOUi++7nflTr8Agf9
/vQl8dF4E3xhf3N1OxZePOnvKKQgKJBOMe9UQf9f2yV/CO+8PyeuSXjchz/5
ghz2upMwnSgq5lJgYih2yyOFUhrbc42LP9/rwyIltz+fJcaQEv8tkrGvC9cm
5F99+USjSOqGg86nSvTx3WVrf0b4K9FqILGpGPncv0UudVPwscl2XK9XiYOc
+vNPz5N8ueArWZjTj1oZWUcbUk8xJ+sUrkf2gMc5/+36c+Moqo6jdEPakb89
Rnu1wATUr0bs5zwTD9GSqsMOJP5srzptw774g3GzIS9Ckgbnt3WpmmeYaPzX
wewoJwt5Vm+S6apqOBzkThDop1Gy+1WH3fNOzBZLDs2GsOApL//eWv4YDnM2
l/cR3uUHhfLbmrViyP2MSJkxhYZtnhJDvK3QzTY5UZXBQsIp79eKc7VgF9ok
u3wN2X/Wk48bfTqhnvO7uTCJglYY29kkuXzkzcwF5K2ncfN3mqIHfzN0xp9e
ziL9SNan9pIa3Yvy+SczMz8nkGqmVOjL34HZ/WG1xlbjaPoql+/MXgpT3mwz
sf00OjPOO846t4FtB7fKq0Ry/xsvKKqoVSJVU0FGxZr0p3eJM9uyGch7Um01
PsPCvNURo831DaBm1W9qraBInnKdGI5hgg763jqZMgZm8/v0RtFOCKZ7vezh
Z2FppPs49+MeODyY4apKZ0H6ppf8PuFe5FrKML3fsWDgx+tY6tyBNyELym+c
JzDyh321rXkdeAzfHb99lsbhu9sPVDgxEJzRKOBLeMS2YW+qbkMADi9eGXSG
+EnJKkF9vjs5yG9KMM/7SqE8obv4ZkUnJJ1aVTrKaCTyZCtNHWrH0QUJrmV1
JJ6p9nz0WA52ckbkBn8g+fNkf7GsdhrWOj3w+2cXqX/L4epjzCrkbOjnUzAn
/azaz9GprAn6LkeRwk3Of3kiUO9TI6Q/Zvqu/IeFMIcZbzu+ErxZ7sZ55wkN
3daEhpOtDEiyKt9IEz56fD4uoylVgabTQgNp5L7a2CcVH7WR/Z4cyBOeoeCl
Mrt93rELBpJr/P/vj6K3V0cciW3BmPUXh1UjNLLARmds7URa+MWGeOtxnLn6
7EKj8jtwXSmOmJdhQS83f8BwtgNsogEjMqtYqNfYZhpdUI6o214X/iHx45xz
2Fio2gHdcLGkAx4UDs3wpMkxi5CbsiI4/gjxA72H5326cpGzz/XjyoM01nwN
sqwIY8KKe8W3JS2jGCgX8OGtLoaS4nMnPlLfOnFmKVHDNeg57NaRnEKD+6DX
87zKZpz3j/98mPDUmD/q7RLzHrhKfNoQOUXj5TXVeyI/ajDEyzQS+0xhKnrv
PjYVwiulUUPahQUHTuljl892wKj4aP2zMOJPavzFUXadCFV7wO1N4jXVkL7+
8bdBTLZOC17up9C5ZORJT307nM7aXO5rH4fVfxcEsvSZiK3xkYslfjgpo6Ll
d+0tqctsFc4QGg/jab8lRq24tdy1Ky+CQtuj34HBr/qw+IhPr3QBC991g235
I0vhUjxb8MmAguYJxjWO8XT83SKuZrOFxuTtZMPzt9oxYmrtt+kvC1cv5Mer
N1QhY/K5frYA2e+xar4uqYuwuOcqYEXq28/S33LwZg9i3F784m6iwOLfMrd1
UT8id+pfuBE4Aanffxq5LNogmO/E+S2XQqDq8Eh3dymiWmplLAmfz/TssFlP
/q/KpY7tLRyHStPTmqJ9TTDaGGTz8Cw5X0xCZuGVNqSG8irr1rPQPfOE3XZ7
IdRNRDpiiJ9dvPdpT4BMB64XCXvG9rKw8eLE8YHwLohoBLG1q1LYJ8Tl5hsw
gItjuSerdpD7VDsfXJVTidyIct7bxKeMzm5YknW/HKPMhxGzSqTeJJWmm3su
4ebUhwV/cr7bU6/XTm9iIvVnJYOPgwWLq2quJ1VToK7xYc1qZTIPGSS8VNLq
Qvlza5gFsLBGqadF37gK1bkttxvvU7AdDm0R2dWD1tlEB32LSdTfWflsgf0V
MhJrS9j0yPy1Jnp1tiiJdzp1mns7C8oiTi0ckf2w8HZsHXNkIWdmbXok6T+P
VUttOJbT6ItbYpni24WEGO2ip0dp6Ku43L8XnYSkhNM6ClI0tO6fHf0UkYnF
B55KaigSf/po25fR3AOtQcE/E8nj8Pzw5IW8kgOEPRyfxGyiEdYxJiFztAt5
1cwHm/PHsM9ydbC5YDd6K24Es++jMB5n/oteWoSWMfnQOZLvknHNz5cmVWKt
7irrfsKnG2KXI3TWNiBKSbhAKo9GWSob9/nQl7CKM0xuO0mj5vrluYUTlTjn
wn9jOJ4G5XBwpZkJE4l/t4vXzLPQYGa2KWSuDa+mLcI0yX4/zGbyuKk3Iasx
9r8x4l+xFmu0h0tqoXtits7hFsmXtT+YPQIlkJpP7c8lvOsbCpl6O9gEuxuz
Zk3GNAw+36o7v/EJXINYLm/JfUclLdN1t3+EPyvqjcZFiH8v+Mha7GOixCpG
RYzES1A5hcnwqULshtB161zJ+299+ZyLBagMZR6Q8Cc+yJH/ZYv+C9xoODh9
gviI7jXTVGH7elwUunTh3QGSL4WyYlbPn4ARXXtYg/h6TP8iNa7oeigPGX+x
DSbvfhUO5bvrEfisJJ/fgcy3lyTHJf7pxqe57I+2hC/nrjxM3ebCAE/p7VM7
TMi8ZR59+ePGDjSmPkt1P0fqdz2/haZWBvx47kSqEF5/rtYOcyc+FHZ8gs2M
k8L3BfEBHa0GqEoOdG0h/dtUvWRCVLUaPgeHdrTW0GDwLduetLUMBqqntveQ
fFN9Xa1UpNCKAbFHz5N5WLhjNXv4uWkjfuzo3uH2mvRLq7ibdkF98C0sHfE9
TPqlwGmBxtw2qH/pnditR0G6fn/NtnwGiu4OBvSQ+ffiW/HTqh61aDM2VTo8
RWGX/bW4WyvacVPs+X6/HySe5YsCFa8UgOboF7IPJP6uoZHB39KBKKlfWrtt
STwqetcVVVfgT6zQ0iRPEk8e4eSdcnWIU3C6lS9Mo8vrZMg9pXa4WA4+KJSj
oPPl0xF58RYouAcdzxMn/WyjWxn/8QqkMBzezZD5VieVVbNKrA4TbKpDBtPj
kNP++Ch8rg4p682uvCT+6acTzpvQ24601LgEkesURI1jE/6cjwGT+0pU0zqy
vm17yj8jN5DbEGs/TerfosckbNItH//xDw/fIH4vfrj64axIE8wP3Tqg6U/h
0Zvy2NLSOLzZut/Dh/j6r8ptiTrJ3Tj/9riQ/lYWLhoJ1zWXMfEehyTFCB9p
Gz2psfU9+BH83+2U3xSU7wZYFXb1YyRR+PYpfxZG3qnsfq3FQK2j3L6t7Cy4
V1hurjVpgqit9CunZMKrEh2eDpPX2Hc8sEBrjAJnN4NPMKITTmnOiU/LxvE9
NFVgq00lVDK+RhnWU5AyjipTTKzDap4FGZ13NN5rKj7PXNIFE457FlclyHy2
dl/8lm3d0OdRfn29msbVmSCZDt1C7A0KqcolfK6PNZpIFOvEs/MKpzY3Uzjv
2ckwtG5Dj6GlQj/pH3qn86xljnQgc43M8HnecVwNDtiV3F8Gjf77//p/ojDa
0nsoV6YbpZORo7USLCj1OShdi+xF5SkbQZ2dNDY/vRXTxj0I2VOne3dpjePf
Kq+T/CsG0aQgndgpRPixk8dl/5ZeKLEvhL+soXA9x4s/urwX+sqG6o9+jUPW
UXGXRGknXI9b9FwoIvf36WzIpsFcMNyO89r9oJBh1bzVdaYd7wLN7TZJjEPY
4Sf15WcNmZNrUi4QXzAXOBrPSXxjVF5sxtplFOu9xrqwrg2j+/wCdsxRKHi5
mna4UYO8+MRNhsS/r7ZPH328n4Eapr9q2CMaA/4LdzZtrgDHEebXxWS/tuEP
1EZCKiARnS0YEUvmw9xvnZ6zxK9liwJ4yXdPB5+DSsquUNUr6qGJz93zm740
xTGAac23vvolpD99rvK1sh7A0iOtj6U9JsG1yCXBLKoREcm8boKkP33tD9vE
VVMPFm308jLh4UptbWHpR+0o6zSQTMoaQ5PhNkObPRXgvGKqPVJJ1n/reFo7
LRpd8irsc2Q9Nucxrk7hclw7VrsizJf4RZvGznhWLTwGzbauW0F8L+3ZY1mh
ekR5vfX03zuO91J7OU3GG/As7vunUglS/wkVzfaH3mL+/cbhITMajpc04+dK
KhGw7J+PfGmEt5utFv7+yYeIusLuFZY0WCsbq1vK63Df/7Z74SSNg2qrFYta
Gwm3hBZqDP8/r+m2Sr83w46U1875pN5uHfEp/zz9GB+Fe4KtV9AYGXd/OTKV
io/vbK3G1GjETSkpo6ADl5Q8fMSIDz7h3K8zZV9G5oPvv79bEX8uGjVlKPWh
/lWpXVsB8b3jhizO+jBoPlRc+f9+vgSrFA/otiHfziDQ5R/C99AjTHm7PNyo
aRU2+kLiFS/I1it9HWvjlaO3k3iZbulnTke0Ieugp4dDGAttS6rvMItaMbuD
nZ3dj4WQ3qTyr0adEN32S16ug/iX06+Hp+rfQNXAlSF7nwaP+9fI0Uwm6q5X
trDfo9CjYpzQPZ+OwDsnr3KS+ZJtpea7dM02OJwbc0tezsL/ADEEABQ=
        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81GsbxpVkOaOVlFdUR5pK6ThtJJdkSZtJC6pTM5SijhbUEHKEtlMR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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81AkDxichuyuJiloJHaJVVusIeZQj0pZcO63S6m2KjjehiGxChy0i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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk81Okfx6YsbZH8EkthQzkSYh15YydZG7W2JCvUrIiKVM4cSXTIOnbl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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c81W0b1zBS1CNKIpRZiqRU5JvRUkZFhPBIVhpPJCQjsyVJRiGhzJDM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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlGk81Ykax08SiRgMRUZcJcso5dRgun6nkkilVLJkGUMJoRAqpRBlaiyl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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk3k81Ikbx2WFzdhUmAw2Wh2otmXtEvrIUaOfRCK1kjRiO4YKRbXRMVFi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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk81ekXthbqhxalEoquFKUh29CjIYylkJA0IhlbSgkppAiJbEnbRAnZ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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8le8fxiVpkNVSJDtUKKtIl0JGUim7IRWSZIekRSmK7C8qStIuKVv2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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41AkXx7EjFYuiG7kLSah1y+2bLhZvGG2SSyWViK1Rbis1osuqt80i
eskWEym2VUiaLpPLyNA0LjPj1ky1JfP7/azUFKLaef84z3nO85w/zvd7zvmY
RB3cvFdFSUkpVRH/z/bq4Xpt3bdQ2VDl9u2pDO8upz/6ovIABn7MY3HmBPjR
bprG34Tok8aWnSumQN9UXOtW0watmqRzi+eTmPRPZ+tG3IbIMfxPXq8MaaO0
hSccWvDEpHK66QyBE+NSw73TIpiu+viiehaF6L+/m7ynqI33RP1uJSTRym5K
Gylvx8rPVbmZ6iSUUgiPT808vFee3MBYTcJK1ZhWTOtERm/t/up5JBJtv5bq
jHLg0mBro8cg4LI9f1et3iNoqu6ee8yagPvbkdixAwJEtqaXXfIjYf+Y5cG+
xoZzYUOexw8EOJfq900t52L4yjayhE+goFG6aPuUGDkbdwTHq1Cou6C+kO95
H/T/dnM7jAjMdq3tC3Btx+uGouchpiSMV85s3RFRhbXC4om86zL4Rl8628rs
wh8hUUfHKBJVdqfLaau4sB2Okhh0EmDQ609aSRphWNYRo7+SQI6Hcg6Ndhdz
Qm48NjYgsF+tPFolnoMded49Q3QCcofLpXntTciXrsm5cYCAbkrse5W0Zpjq
epWlZxG46jpfN4zFwwm6ccX3jiTWfpOJpuaVY/H12I1Jp2XwSPbJT1MXgFuX
utL7EAmNO7+kB9U/xt/c2I2GmQR+/TiT4kO7hmUnk3yVzsugOWRdmnR4EH5T
OiWpCRR6pzaLDjJ5MFmw5ax1h2KegcLOvHcdqFjszZlYQqJpft0a5t1evPpU
WXF8kMTF8mWZ3lHV2Ol8NdzljgynV8SeJuoF+No+/lszQeKKSXfDitW54Kj+
LgkMkKE8alvkGYiQ0zd7bhiHREbAWFo3mQ73gsGNpx1kiGD8yexv5eDYioh2
bS8CLe6TZvcqu8G9+aaU5UiB0dF8wm60G5ZNOTlGEhJbtfgzXP8hZC0VOMnj
RmHINnju6SbEZi0bE4ctFPQ0BsZ7WgbBeTh0V+JLgUjgRdBvPAE/JIMxpEPi
GF1Xlb1SDIKtZffzEQqRB0Ptf2rgIi5fO2Upl0Bl/I2zd0KEsJGWSEXBFJp+
VF3w5poI+z5LFgx0UNjCd42MHBlCRkK9zCtxFPH2WtsdPzTA/9epkEl9AqbK
Ts16zq0IDcrorBUSIJLfdz7+zwCUEjT+eelFoeWjRcbbmvuw483Z7a/ot5k0
YxsO9mIgRVNsyiOxQX7Ex47WBGlonEFAMAEL8wKXk4lCpLK2BUYxKFi/NL8v
V68Cx1YezSqW4Ulmf2z75WcQa34uYIeTuO1450vj0y4MP29+/vocCRoz/uyF
4H7IjPRX/zZnFKeCassN0gZgORNmNsGhYOxI5apdPoMYN+yYWS/Di47Qq54P
22B7bw5Vr0tC2+r6cJg5DwKhlvyJNomlWX7LF6v2gp8Z9vOILYWZr61/+ewQ
4EqNpb68jkQRY93T6eEezLKrsDQaIjGuRK+oDBbhOF9cvMCaQvapNcrfZQ9i
59J3SUGJFJQmF+xh7aqEmXNdpmueDG/t9posutYD0rTwEXOahLvDBWNmajOi
n/1kmJlH4LWHaIJg8aF26tTJJZYkBOcPZI3JRCDmhHHieimkrtDz7NRmY17M
Qvo9HQJXCgLXplrwYDk0239K8c/mgXcXKvEEWEXz/16YofjvYb3k8MSL8Mxk
O+2JleFuKQuZz3oQE7g+L8CHQk5oUVaEGRvmN2dGvJYREBzmVM0904fXuVx7
gYxCRhjkR+wK8C0rfrNnuAxLJAMTz8fFSN27scQymUJhV0rW7oFubJb7d5Ws
JRE/VnRRMtCBxNn8UoaPgn/24k0Og+3IdZvOXuROQt/EXaqm/BTmeZ48ubmC
h0vW1S2PFSF6u9X4JncKkuqLWe88hxDlnf0/q+WjqFFtWzc+0gEVzb6xeXSF
HoN+h/FV7dBlUj8YGin4NK7Ufy63FwdDJS99xQq/xrSYOhwuDo+2HNp3ScGH
9Z07LZoewmK9KJvtQaDGuuT87cO30R27f+BBqwyc6sE93kvb4DTdMp3fReDW
p302H84JsemoZlUVFPtn7E25KrqPaq+koE4F7wS9En5lAAun2K/FwUcVvLww
qcFYPQi1CyNOBxT7/6LzRWVQtweRW4az+wQk8rcuL33z8iEsD02FWIUS2NBx
p/9DnAAndDSUbzJIuIRFvfKTssF7sDVs9EcFn6v/sNg0qxSJRbcemSXL4OLq
+DHhkBhzdQJjwhspiGee5MfoC0AI5IUlLAVvxvTexLNE2Klt4pRQRoH5l1qf
G6cVv1g90wi8rrinilLxGfU+/JN87fjEfApXlnGcH9KHsM/ygfRp/CheNL4v
yM9ohNf+N/vbFPoKP6ffEmv1osx76w19KYmzhHNQQJoIEobKWtEEiUIb66Jd
vt3ool4d8B0nQWcUL6OlCZDuJ1x1UeH/v+ZvzP0=
        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs81IkCxaUUSatYYqJIiLS1JY/UQeRNWLStRyurB01PVkJDQl2r1Dbl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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk41M8fX0eHDj+6lEIkKaTokOiFJCRKSLawiEK5C6ElUroUckSnKIUi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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lV0XxhWhlGQolCFSxojES7mJV1JUGghJJUOaVIbKW6aiyFAiQirJ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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs41fkWxnfIrdpocuuiopRLHhkqW3kRMjNpjEShwzSajqTjMimX2kbk
flJRQggVx2WXsEnuItobW1sug1TK/v2+P90vMqrZ54/1rD/Xs953vZ+1+sB/
XA/KsFisE9L6f79v7vrysgsffjE/7c18S+Hf79eZrN8nAmenlSl5T6B6VF7g
7VsDR2OPuKwFNE6MCvf/GCWGs/yxBc8TGGz0Swt02yPEC97H6bIIApZuQp4R
HYihBJPpASMKyzUpQ55XMzrq423U7GmoLdiVbaDVh8NjqxdKnAlidUN37/hx
FDaXBA+09zLYt+GzxW3FQby9M2PFWDNo9l7XGuiagZdWk6qxXhRkpi8GGymL
8LSbu/l4M8GsZvkpV9kBNB++FqJ3nIGBHNtEbqwPd/Sd34b4Ezjt9VG5uaYX
FwMz/XQ2EUwE39hbt6QLc9WtuXIfaejwr4RnNvVBkFTqHOBDULt3/9f0+AEk
f+tbNp7FQOt4zrKBvIf47jxH4dMhAsuXZ7hmV8Vo4xs3rVjNIGq9EUdM8aEv
YVQUPlI4ofo85SX3Oiq+PvG8dYlCMwly/2VHPnL2p3xxCKXgq3Bd6wfHq3ha
LKOlGUbBJHv5DYsbQry7cKRi61oC89qYquXnB/CypSZGw56BZG20tWE6H0Eh
5VvmdGmwFobLR5pmQaPes3rEj4LqdHwAa/sAijwcQvo1GbiJZx57c8RgxzdY
Jt8isI9m7xkrbEeBs9+7slwah5d6arR29GNM+Nq5WobBxO0P61KMa8AxPdMQ
/42CJOXF65+NhWivWmUgtCHYfzf1y+lTLfjTPKPe4BAN3/yS+rJfm3HkdfTK
WF8aThX/Wtw0JsZHYaPn98EMCi7Qnasv92NUUywjXsmgNkPvoF9XP7ZeKBLM
XiZo54pY5sqduJvGdTRUIvA7uG2HlzoPMivvPQuoppBZOmm+oqsPaoMVLSsq
CKY6ztnuEnRBlaM++YfUr9F94eodEjGOnmQp0GYMVPNTtbghN9GmJE553EbB
Jn6hznW7RLzqXq4xaEOB9mCrJRmL4BFqoDh1isDtwdTH+vPd8POyUcrVIsjf
ssBn/d9n8SgGggknCqwPfdb8r3Eomwg1OGVFoX3K0s5sYwu04gbOVRbTCFtk
kbtrdAzGYSpeC5KnMdOY3NFp2gP1IH4DW59Aw3ogmBfYidZLknltUzQS9G96
GljV4cTjrsdsNRqrnAtvBzwqRa9szm8lPApZ78RbUjLHkXp/uL9RfRr2c92W
31mOoDhvfnDRLIM1/O2zjp2dSDCOdNg3RGMyQGD7PLUX/ao5pd3BBGlBH3Ye
s+tEY0h+araEhqnDB0GSTjdS3d75d+kSaF27Z8Yp68WBPJ73gDSfRDnRMaB2
EFP72VxvHwZMDFtv18lhZLX8dlZW6lfkpss6bP9HGHmE81eWMnCRsG+bRVXh
YsOjdOMZCpw0+ZMuLiKM5lwVpoYThGuOrH76RgTrddvP/XqHoGCngZ2sCR+i
XDt3BzkaQ19Ktxbyq+F5Ol9YIksjMPb742PXHkJZmJU0X3p/R3c8+SZxE6Gh
2vmP6iQpbxyf2P51qAeL9d/LZC4mGPtkq+zi3At7dmFNQBDB7s/z4suVeTii
MZsfeZdCcfT/Xunw6sCwin820pPq6z9Y8G2kAK79Gs+6Yym4/KW6wSKvAGtL
/T5/iqOgX86tczG/h/GM/CVFUj3bzn2emlwjxtBk3MpXqQTrkZljqHgfOyZ7
PPoUCF6MlBjnuQigd3POtl6e4O59B25Y0wC4/tXTyX0Eh07+3bPobCd0o1ml
Gw0IOBn9qrcSu+HZEFkgeUCjfabiyp7kXryqvZbL2S3lj05hXlGkCJ4OeVMq
NQRmz9bTVEY/CrQVTxdWS+db8OJytW/h4e7AJRHlFHS0bZMcbwxD8oW6cMWf
QQ7rQKLBdjGi5FJjTWUZPE6Y56buM4Q07dCnvoEMipcuWjvk3ouSkDdVlccJ
FJWzSjV23YNuunrPczWCKi677nN0CzK9rz1U5NMICp04dMD9PiJm31T5WBKs
mi0tj9t9GVxx8Ul3bwq5xWXLXM+JoKb8+5eZSikPzsSlycZ1wEy+cRtbmscj
romr7vwpQM7ii2NlJgRBYl6jd2QlbJ2ceFPTFBImkvRjzO/ibauhl2QTDbpS
v8Jqcz+8XD2+9UwTRA+71K2buYr0d2aDv0v9spPTWaOiL/0PqlZKMmEEb3+5
MF/jqRABbIXh/36g8fWncTfuyDCUsp/fts5jEGZ56tYDhQ7o+pRn+5bT8Mto
q5hihMgfUmyfcyPwuDmb1lQ0CLedKu9HaQJP7aAowQ+tEA6lv1l2jEbtpkXj
5n1NqNmWba9mI9XDPHlRuV4dtGB40HQDjaLzQymymiOwb7Vw4vRKebMmavOg
+2nkpmrLzXAo3PGIieg06kOr7OvKghTpPgqzaeP7SjARYbkhOJ0CO2xrhJOW
CKxCBWZ2kIAJ72Q903iIuQaltuQOgn8AJnTBmA==
        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs01AkbxpdYKRG6rGyoraSijSPKQ0guSQiVkC+mpNadpotbyYaWEG0+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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx7XKNMWoJGUdW1nnWtLmg4kQdZVi7JS1bIUfatKkRHQpUclS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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4lG8XVpbQJkshSogUpSSR3CqVFlJKthDSRmSvFLIkSfJTSYqEVBKy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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHs41IsWHd2OSuXRqfSSZtLDSXKolEfrmOuo29VRdEqFEc0tUiTyipik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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4lQkfJUuWGFRCyJcWDLIlWhzLpC/hkVQiEkLajWyPQuTTIpO5SkPc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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4lOkbtqk2Za3aRdqopYNDlnJap27lGIXkVFYnp2JW0hC2A4pUNovQ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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8lG0bxicpxOOxpFQqe6I8FKVUR9lSIUuK7EVJC1KUEm0qIcoWiigK
RfZ93ynL2PeEue8hqVSS9F7vp/nNh7nnuq/zWP6nxDFnYwcOBoNhvYDB+P/n
0RNd7FlmO6IT9P4JXcyG05OVvZNzOeiK+hNM6dOIDTmqc8swCBF1g6wQcRp3
n4WKpMzWw8tbqLylkcaSe0+nqYY25Ge/uSVrN44Zwan7I2sKIfTrg/lfeRpm
f6qc2K9rkDXRcPqHO4XMC4c0w4z6sO29tx+fGwtyGz4N3V5bi1yD14/CFWlk
FHtPrePvwIB9lfPIQgqzjt9/DQsyMXfRlHp4jgb3ZSePOpThsHr4m4ZOCsNT
A6GKn9thxZThitnHgpWyPx/HZAeEqsv4Z7dQkBKPScpSroS9rpKYbDqFaX71
X7p1ZbgTrznvY0Ejt6v+kkJkCcSq3y5V8aeR5pLZmW1UCMvdPrO37pH/q1jF
dNqSg2MfuxoSQmk4bKRvWhsWIeyzmiu3Eg1Nh8HDQS96ERfQE8SMGIPoH+vS
ayYJ0D+qquA1Q8HYcfjdrmf1KA4uuufuS2PS2Kb9dAkTIdO6m0Y30xC7rSf1
XqIVl/oedjwIp3HDJ9RCwDADw0f4/IeFaSx/s8UuLrMF9z7HuH6yYEFaJMen
aLYF4llf35WUsJE+l8d1IIoJ3eDvM1bb2BiZlzlwZEs9jHOjHsWNUAj59nbP
kaoOFLf59ahHsxAtX+hbcLsUsYmP1wnWU3A5tVXNaHknhCqeg2ph4ema3D3B
Aq/AOuMVyiNLgxH4XHwOaSjj3PXmLxeZ/zqFGKeZCijLcd+5XUpho6BFj9lI
L4zmj8/1647DZ3hltbKJD+5wZ62JlqJRPVd9aMuGRrw4Z6VjEkkjO3eVs8nz
ZpxyFEg+yiDPtxyV+fNeF9XPP/lxSdI4VHjl7JsbDYCH5effghTsS6Im/mi2
4erentjD1myMLWDvWVXSDv/OyQp5os+dkfYpzulMLLvg631tOxtt3L0i85FM
FBflOWgY0AgckQr5PZOHiFzd3XYlFGwDsrM9khIw/5/NBf9tNOLMxLZMMZgQ
fJDCnaRCwzbGsvCTWzM07+ReXunHxqo9dwtzFvViz1bj/rXnxjG9XuVkaGgN
hMyaeDjFaEx5PpSLbcpHgcnR9LwNNCrz/9lcad6JZ5nPV6V5Ev0W+nSdCEtD
rayug8phoieft+UWlwoR1iGTn5FEQ+t2p3qOZRe2J69LZl6k4SKY/TH2VgMC
e7ecq1ZmI8gvWIrf5zlWPPS4fJT44ziHosbWphZsDdMzMrk/Bt3KjpcZWhXo
VwlINeShoNbPob4mtA6dWVrtaxRo+JqYaYbylkO9dyppmvglreT6PEdbNyau
vfqXm8x3xbLVGhGSbbBO5QrcMk6h9FRaSDLdhFei9tL6wTSu7fC0N+PrxNyu
R333TVmw1e1Jbx/Jh2iS1mTiYhqClcFKYUrtKDZoKrB6S6Hrm0FcQmId7m6t
lHnGphDJ+PlZfXsPaie9TDU2jGPoUPlZvvIklHxw/Sa4jsbE5t0nTTu6IN86
v89dl4VDrVesVZeUQf5a0qePT8jzuJQ+eqMX+xWGX+fJsqBmNX7qiifx6zMd
ve6FNHYnu5iGm3vCay4iIJjoZ/BLrdqL4Vb8Wzlsdfw9G5H5al4edrlYUPP4
TF8bBc+DSleXqvXg7KKAmMeyo3BMfKyVbtSCD4uzH8dIs5F000mBI68XHtr9
JXyZFLy4hwc2DbbgUuRX9ax8FgQYe/+13tqJt6I9nl4/KPzxD4yI7mbCWCJw
5OUVNl62SC+5X9mDw9ux3Dx1HJevLuezCh1Aej5zRdZeCm29Gfufu5XghrqL
lxrRS0poZAnXaBWkZVsXCkhQuDXbxjlzNQ37V3QdSuOhYSw4/Mt2QSl2KOho
J1+hoHcg2GYpme/RYZV5z34aI4GOZ8ZKuxFxcUJJ7A8LRv1fdj5zb4HKtfa8
F8ZsGOYEeIQb1KJPZr3HhC0N2QqzIKHBVkhb6m1ft4JGbRy/kvD2MhwMH7Zc
94oCt16Ii3tZJvLvyVnYSdBI2szDXi7AxCHODzfHQ9lQWugiZjX5BLsa/AMc
1cj9X+zq63zRiWOnV+emiY6D323eUSK/D3657r/395I8Hf/0OCbmFWqdC/Oc
SR/YOmcuvTOYj6mU+QG5AzTWMdauvMtqRmU88uNusHH+7uRZe2cmEm+8/7nA
h0aEaemxZ3QX3hnUKP8NoHHLjs/uUkoQ1DK6SAjS2E5dFFrVUocdrM2CviS/
NpS9mkzcWoaEIzc9jpP7PJQ6mDf5pB5zZyordGMoaFkUbd06Uom42ZL7STcp
MPQbKgx+V+Ks/5uml6vI/3tMaw84NGBxSdpD/1EW/HtmOunrHdAO+fvRQ4CN
09cd/QyvV2N2zadfahtp6Jbm2D0l531TWFdd6T2Owwt4nK38mmET87F2aoLk
D69sKndPH4r/SpvpvxyHkpvWPt7v7ZjzFTtg6Ermx+QYkBepgb/2I7msCBqR
Ba82q57sBFtSWdbceRwCxbP9El0JOKedYOjJT+6rZNU+99JKJByylS30plGo
8URzy64WODYISEh6jaFeMWiqcnM3NtVEXRK5TfwqqP8lVbUew5EmQuO1NG6H
FQS4/uhEh67574qscXzUvd+SE1WDvE7TgL1MGn5R59dwWPRAfC7j9MUqGnc4
zIPGbDvAO/BSyDmAjUb9+EsXz7dBzSPGfdv5/+dNpFvTvjpcfxv4pPIyDUfx
l4++7GzCib3G9v+U0eh79VVD+CgT8s/DpWppNtImBVO+v/WHzLetO/6upTHk
L1x+9UEqHljJfH/3gQJ/XfhVjzVdmJe/c9RgCQ21DouWkZwsrLmvWHtKhMa0
rnu35OJGTG4w/t38gY3k+6fctLkqUaMgPzOeR2OsOT0ryKAX4ueGdw0KscC9
UI/D1oPwyuOnlhsrSd4nG5hvYzfjp0jyc5trxG/xZr2nMspxSXc8PvIhjZDk
z24JVDtUTxnSfq4sNGofQ9itSvCrFF72GqSg8nbrY83jTKw7HKYwsYzMU6FL
b611B4o2eYutPk38v/bEnuv1ybjbKhm4TZO8X6r0ttUbwzGk5mR7jPh9xc7i
iWby/Bk3hZzXVRQm0qq9FnSWY2nXV8XDDsRPj34LCD14jvqc+1T2MhqGFUJy
ul2ZcP63Ts7RjMYFR/2QhogGqEnZ95e8o3Eso0rL5U0zHIb3fTuYy4JLLmTj
ZnswwqqK7k+jIH5n/pvJt+cYk5xxuLKPxtIp7ePnOBvQJH9I6LM+8cf+TNvl
qRlw2BAmlLWSRmO2+7lpyQLkOztY7j9Bo2Cu+H35+wToNSrfVSLn/8Afk2U3
Pohr26p+zZxkI9f4eqvcwQHIxo7HSabSyN9rUy58rwYX1yeqcCymoFR5gY+Z
+xaXJtZPhMgRvolax3+X5N3YfwUHE7zYiE5un/DMaUBKypDi6A4acyfWZ2r+
6UVyiK/q2jw2NgiDqenCxMUfl2+8j6fgz/fi+5n1nXgct8w9zIjoQcV9m3dj
HsaWJNMHd5L57U2bayT5522NyKD3NAbWR3Hd+dsGDbvVAqFkPpTOxjVFBXGI
VBtcfJ7kx4YciezSD9nQUYuu6yd94mIUt1tIsgkd/UxrjWkWimfMGuOvdePj
zKyyYOZHbMh/8jjYOw9u4Vs8gscIT6p0x1n51qFL3bM3lUVhZnWcTZJBBbo0
eTW2r6Fx9bRz4VJGDq4JUwPlJO+6zhyRlbCrxBtGDfbmEH821V7Zr9wInxVP
o3f/oeCj9H5VveVDfGWOBPfJ0BCPCGqTcCiC5hLLlEfHCX867ve8MtKKE0uf
hy24wMYLrrBNB7makSBYtCwxlfCn2F2JnaSvZaPV+xxnxlA4f9TXW6oG+eN7
62LdKOQ8+pR7IKsbjK/pkxar2ejb8fNF/ZcubLi68gTj5CjE3z1YvmCQCS2/
ccMuDqI/GT+qYbIbtZd2xP19QyH6yta+No7XYEbVXS4ieqIkLnYJEyJvTmP8
UiS85XNzInua9PUzrlc/jxF/zix86xu/pwNBXIskHB6zwOG/szrVsgk+qmdX
hCRRqPWy0SkwagazJes9K4YNoXd3vMI92sG4/MXVn/T5/LrN6WqJA9AyN77K
4zmM7GONnMsIPzcY9HDfDGej1s1c+m9SLc77V+/dYELhx+sL94UlSsC86Shw
N4iGztJ7xXqMJtCs/JsXOQlvya02qV3FhG1/oLGsF8krk427Tm/JR4K/0PXQ
fsLDYjyxTyxbMLK2JphPmI25hLz2JUZVuBpVFtEzR6P0ZmvNP89a4BSWJOVK
+k+sYbSlUrIbN9ZylVoYjKLaxWSf8c82fJJqsUnvGIXbqxI5x+N9+EUb+Z4h
eT3BpzQkXdOPmgdiY75ZpH9XKm2ric/Gvc2D5/3dSZ9JOn+L+7cNevfSHonz
sPF927odza2dqC6RfsPkHAN3sfmdxJZcPJSSmrQ4Te576k7Zzdxn6Dl0zKee
5GXE/herG5waoXSqNJhjlsZ7Tskhg7FG9L49qKVwisYlQVTx6hSAW8QvegHJ
G13+HUeEPxYiYhkl9q8z+T4Z7s7oKkSlE6+DPPHD7Pc/sptfVKFSbLe66TMa
Qa1zqvrMRvh1mG6Q02BjyElbVMn+CYyyVm0uJDz5K6HBeZDZCRFvPr3jp0eR
2R7wije1HD9+yjwv7qXweeX+T4a1nQjb01acyTeOH/82ZW0KLcCoSGnS5jPk
Pp/cX3JNpg+8vtb8SWQ/MrgnaMpR04qJR4vnnxpRcHwlrHlXrgo6B4a9U6zJ
+9w8+jV5dxZmg6Z2GB4h+4m5xg+7sjx42B8//+seBctmQcFnyXVw1FYX4Q0k
+arLtNIzrsKszC7jL3to5D1ctKzynzooftURESf9MRRQz1ivn4uOMG3W0b9E
n4mieunXa1H01T5rmOQlQ3v9GDu0G7O6Mdtd09jgLtfY9GlnCfYX7hVdEE/D
cl4pbXN9Gy61DK/yHWPBsbj+gZtTBxqbpg9cVSB6PW1+jdOsDelfEsdaHMZh
yFNwrWFZLJaZNPhNEz3lPql9NxHXBoFbw1EuRB/cFqoxm3IT4b3GNTRJi+ST
/ujGk8fa4HO+6pIkuU+XLtURU5dmRAhF9TsIsRHbPWiqvCwUQUlVh3hXEd5q
KLm3N6kA2W9tFKQJj0sLSKkY7qzD09VSx+XJeYfyyzS2Xy3F/I+gI/77acwU
xqiYru2EaJGNjLQAC7mC/91ICc3DyD9P3jz9TIGzqT4loKUWSQFCZqNkf2YE
yUpxf7fDvLXXh43Er19+5W/n5GnEYjcvWovsRz1r1M5KhLbgyOF/jhwl/G0z
tVNnt1wb5DntF2WkEP08jT1tpRyC6ZD7OtLk940ap9cH1jFhEnduoekw2Qfd
l4cnVRfhwZkVXNUk/z/KNwSWb2fiYTyvmQDh1yGbTYwX00V4r7r5hDrpyybb
7E2/xnpBJest1Sf8s/tGcHfFngLItPeV9/hT2Kc0W6Wn14W+Cy/W8CSOQyNA
TLdPqxP5aqlJk2oUtvQ2ml8NqcfM8p4FhspET8IKvvfGcrBkx5+67EmSLxE6
Ik6OrWjdXZRkq0RBcUuRR19BF47wZJ1RDR6GU0oGz1K6G23fZwLkyP3u/k/x
nYxlM1xqd95/pU4hanXfgSWSrRAXdl39h+zzxiZRUv5rqxDXvb1T5imNg1HL
D1b55aF5aNZ+HznvboGIt+oXG/AmxKaojbzvFr+scq7yPvQuve1qrjgGV7WV
ud4xTXB0E5x7TfY7n59/iztyLoPzr9OIC9m/RdvGYq16WzD2h5vLyYmNCNma
PV8q6mHtfarzgwEbA3zi9EKPVhTrBqusuzqGk4ny37MNOjErNmkhq86G/cfv
J3//U4YpC+0QlgcN/gBT+p5PE1zUvl2ImKWwyfHsuYb4d9CMyeX1Jn0xpCc/
ZMeIxdPwFaHH15N8mvgUoJZ+GS1pWSqmZJ/48eK4m4RUJUrDCxT7EijoPHRR
zlSsxWwKs7PSkgW58m8BM8Z1yL1YO9/8k0KgZdvqFYTnpNY1PFlB/JKSzpgo
v9uMXRefTzIIP0gvcLxg86YUba+5Btv6KMTqDC/+9KsUjx89FOQn+bDDxH+g
JJfk3xm75W89KFywDpiylirB1qUim9pJX0eeD3jumNiLhM1nTi7SJ3n1S+Og
hGIVbDXtf1t7sdBiVNCl69EB32XNmRnrx5EryuBTmCiCRGLgErPrNBaFi/Mk
3W7GpVOSJcUkj6e/ZwxvXMZEQrz88W8HiX8C5sqCYhrx9Vqz9w9VNsyU6eUN
ES0IjM/6rk/yRKzC4uikdSbCxI+3TBF+2bT6SZKyYzeeHghTzz40Br7kXvUr
um0w5m99e6iGha67ixWn+nox1HTqZr4/DYlAn9VN0r3Qiq41ae4gevm8ZkBY
MxjNN4u/6hDeso3n3ftRvQenxL4LZaiPgd2ZvuFdfyXUIu5aaKpS6DvU7bmL
rx/RPMEbpQh/tSzk5VhZ3A7PK6LDci1kfte13c8v6kFC7bt6y3Qy3/1XXPc6
dEGye8inghqD1hXN3A8utQiSdr11ZZyCrVqfmu6WJAy1PwmKJTyzUFjU7v+8
/V+7h3KsB+HFDz/Cb+Q2Y0P3rJSBCY2HhT/C33wuxZ5UHx9LXeL3JPkr8k2k
X1w+JV34Q6N++e+UnNwWzMffTTI1ZYFhqlp94EwZlEyuTy73pfHsm4WiniMT
a7wS9EsVCO/2fHYSM22Fz8cBgbpPNNSzBQ7eE23FguxMETWyP04dizbuy/DH
ZaHPO1cRPruw3VGOYjXg51nVbwGkDyfDXGsZkS2I1imrtyogvHiNbmsS7cSl
o3Zjrg1jsHicLupsXw2PVXPrjYjef+S7h+4+1YzWq66cmY9pvNSy056+3I7R
mNYaL14W+KZFDOwIn09q2Oz8w0dDPnLUXfxHPzh5NmlEET8VW0mZij3uhO5Z
+dsb77CQtkyDe+5bBQzbRkUkyL4h9Wrteal9TfAyj915Yy+N5pqYDOn29whS
edbgeZHw3K6ZcTf9LjQteZQqQ/ZvxkuNuZ5zVmC48+d+Jn77H5YsF1Y=
        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHtYzAkXx0eyMy1WbFbYQi5hS6WQMN8KzSsloumG2qEirS2TKJXeCqNX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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs4lAkbxqlNihxaJq0+SliHmhLl8NluLBGRVauDqFRWB7QqhYucS6nF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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8ldkfxy2JZCylprGUsqsoWzfm+nhZWowuUZGRJlMRJSRJpki2BtlG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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8Vf0ft0KSyCiyiqSQkVWpN0oRT4siRJSH0EJTSkUlIwlpICopsskI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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs0lOsCxpE0nSjL6SK0uiwHJYW2shVPp+YoQi4VSbHRZXempFKjUERJ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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk01QkfxnWToppUQi+NjEL2UpOtHiZCEyNelEQLNdbLzZamuKJhJioh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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4lOkblqSIsqUtpVA5hEIOK5WbTA67OSQJFWGLbGtLRNJqSQebQ221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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lF8fxlUqSkhCqJClQrTTT24VrUpJKlmKklAipbRYkyIJZa0kWctO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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs41AkXFkrRp56UCJUlarOzcsstbwrLrrXuRKxHhSSVSkSlj8R0/ahd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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81IkfxlXSOrbVsWwNtiZF4yilS+qR2NJWjuhgk1qxixrlGNIlbLFu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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXlcjWkbbhHlizmVaaIZk1QqFdHEOOmSJnSKlEiLmRa0yNIyhlAnNS3I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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VH0bxi1ZkiQkRaJFKkQpW3VJlEpFIS1akESWJJSeiIqQRAlJnkiW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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41AkXx63IlPs1vMbS6ipFTTfk21aiFamtLYsWlTBdSMm2uqGWXAaR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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHlUzIsbxtM+uIeiVZG4SIvKEqEnS1ISqpGb03bL0L5IpA5d1dzEdHEr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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk0ldsbVh1NpEQpQyUNkroypQyPOKVfSRQadDNEJDJc+gkRpUKjUFQ0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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VG0fVlQqyk4lRNleUikp6la0UCJJXlsUkSKVJC0qRBFeUhJSKUUR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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41AkXx8dl3y2EbojtybItNkoprdJ+Q6hsGdGFrCIlLbmld1AuYUJu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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81IsaxodUR4u0mGuPUBKRpTpye+q2OFESkVMiRFINdWLIkpwS0z1p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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk81ekXvmgo3X6/xjDSJBSl4lqKijueyRJDRKlkaIylMlqIJBNjz1q0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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3dcze8fTUOlIUqRJJUoyahI6CRKoiGjJFRCO3tFUiGVhgqFNlKkPWjv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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlGk81Asbhm2dpOLnoKQikqXFEjmU3CVOaHg7SqlDJEI50XLSKjFkZEvZ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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGs8lAkbxmcVIWXYt9I5RWWqyXbYVLgQpWyHrcEbYhyKpEQROiBDrfZF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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8VWkYx1XaCDGilBSyt4mU8BOyNKUoKpGlqGzFWEcZSpJUCmnKNrZU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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Ve8XxSlJk8qsUiqpyFAU+caSUKRIiKiECk2USqVShtBgiEKRMlQi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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41AsbHTeKFjd7JUtNm0ooCVcd2SqlZeKm3MpalNtXEpKmrnItkaVI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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwdlH00lIsWxiVDneSjFXVEUoly+6BSF3ncSpSOyldIknAcKqIkp+YonCal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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk81OkfFyU6WKn9YSmiGknKFWvzRs6wP0kqpWPK0SHCtlJKuZXWkQat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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3dcTe8fL/EVhSZFSJJKkpAo3hkVKVraJaFQNJAiqZSiITIrlGiQxq00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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lQkXx21RSSNlUlRyTaSU0cKb5WetLJU3yxX1hmFS0xAhKmuRUNq7
xCRSuiFlGbLclJ3LvTddS0MS8Sx6C+ViMu/z/nE+56/zOdvvfM9an8D9fjJS
UlLhjP3fD56ReXP3ggAb3b6a/u5GYWuqtnbtKhEWceeUY0QUpBIV24xUd0Cg
OmuwmEXANyUahSWdWPhtjcTInkZGtM6zgBQxRq8sDd5pR8PXSMGE8hTjfsen
SIUwGpOJ1Q+pg8WY2dTGGh4n8OLwjge6A1yUdSvd0cgjUFtvvs9xLhsq9nUe
blEEurW5/wzmvsLDpa4PHa+SMA36UfpOUivC5l2I5PpSuKz807Mykx7MHbE6
OdFHw4m9ziZnqBqCTmWZMXUSwRtIs+EWEbLuJQhEfhQ++v6c354nhuLT52k5
2jRyKiaKe+vfQq9UncXZRsMzpNRXaaAPzycziiTmTL0eCuFDJrWw7ZROnnYj
kTQZl16g/xds3LW/RgSOYeBosPnK/nT8OPgv75BfCFiI25WHUl8ieZGwcUko
iY2fxp+Vhoqx/V4LXzOYBq103CBtdQf230pw0LKmkLU5xNW6rBF7KupMp3Qo
dPcp0g0vxbAkLK1mRTQ2sEvZ/O3tmAnJcjUhSFjEBkzp2Qtg5qi6fe0FClxT
HztOdj0aFh81tswlkc874myrXwdOj+6nPwpJ7La2vHjRvw3ZO10sdq1m8tn/
Wi7iP0HUmma/0DIC+gKfmVZWF9b+cSvl600aIrUb64PSOpFajwDnSBrRZv09
5PUupLWc2Os1zMT/7LjinXsBrsp5eDlVEBBnrV3xbb4AXmnlYw3XKZBlE82x
O8QgTz/MsE6gUff4qt6Vz42I7ZOk8t6TUBnVr9ROqYX0mrvsjH+TsFmmc3nL
mUYcvny6SW6QxIswSWXmYBT4ahZWrdsISEYXZJicEcJ4yfn4lGIKFloinYxz
HcgepQtb4ilo/mb+MetYDGIk17fKGRG40lawy1bwJ0xdZ5ZfkiWhx9u89jSv
G/fuJXd8daLB+fuAZ44CH9edYvyXsSh8Edz5nMDrQkqJickhRg82VM3r4IZK
fIy/ohLuRMLdriciiN2IouV7LkRUkZCoqCpWrBHDYIpLpbZTSDy+/aKbWycM
OQXCLf0U6orjEsL+24g80b7JwEUUvOJX68Zufgz/+6VdBlwCMdItPT7CJuwc
9pGXV6fwg6fmFweFN5gf1P4hNI9Cr5V8ZmBsL3YYRo9OONCoKqh1fXHoPvw1
rP/OjiYwbbOwMn17D1y+hO+PP0tD6qjzVtPfkiG/LGZPhzUBG9kFwqxyAaiW
oHcbDJj+cI19rLQTzuZPL50sp9A05CWcftqOXBXVrnUzJNat3G0nPNSAvFdq
x/0aSCSOJJY+kO6DsfHzz1qWY9AIMKQ2HqyFZC4m3D+QRPd3Mv9IWA5c0o89
q4ol4E7/MLKg6Dbyc82zaHcCUu+G6uz8edjvKglgeZKQy/z+YUCxHbxG9aOa
zP3J7F0cpbJShK3ThuuuVTD1nJpmJ9MVOG6iO3NYj4T3p1wlVqwQHWMEx9qO
4c3I3MiuOT/YpoSKzq4nYL4zRspB1InsnG7e0EEaMS1n7VXKQhHGTT7nu5mA
wMPnbc3jYjSqLk9v/UpAx1PFeot7NzoPUMHvNWicfS097i0vhPBlXL/qXgqT
gy9WPBroRFjLzto755n99cp8Kzd/jaEb4R4lTygc5Md9Sj5Ti/C5qaRZbxKc
yUfVU/kC3Mg15Kido1DeHKfe0tyKa6vqZ6uMKHirK6YJdz2DffOfB6gaRo+/
uycsnahH0H8KzltTJHjBPl7coSqcejJy4qkLiRPPFzz0PiRA4Gj7wW3+FNI3
R4y3S7/BhwjWAxdrGvMLkkIdXJ4gjf3gY0Ehgbz6dUk24tfYW2lyX+LM6NVI
+bZWbw9Ovo3L5OmMIeok61f1JQK4z56WnbxIoW9bql6bbRvSHdJZRsbM/Ton
8xaNZsLCWMjlBxDQKjUVdfQ2IMnKNHvTZxJe3R1Tgd4lkG9sHusbJnDezbHY
bLYZRYEW+ePfGb4oVTlevVmK8S3veTYLGb6wLeUItQwM2EXa6TD8++55SXeu
uh7p3DYpmSwSTpsMl79Xuo0jMYvPth0m0Jk1Oi4byYdtdMGdQDOGdx7VL71y
3iLlltm8n1aNYfKV7FL93FrsSaheWsLwNpEj2T3zgQfBSo7fbQcSGmza9ya/
BdeaJEp8Zn8cpf5RrfkPwPrHbrfpJYYX4nOKClFvMGl5/NWGQhr2fRuV4183
QTZigZpFF4m/ph2PuK5vRVtpd5XBPgqfP1is6DdoxmBFkQ3XmZmPhc7w4poi
LPOW221WTWCAz/bUNI5D7sU3Hw13EFjNDQtpdS/B/EeUB8UnoKlv2xWp0YSB
Uzcd+HoUMkY73rJC/BASpnStS5f5b0uyIhR+KcT4vJWvhI8J1Nw+vC+PIwJv
1aCMUReFjS8yHe7q9GBJ78j9+gka/wOhAdbS
        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlWs4lAkbx52KCilaspKJQujEeoX8taE3Fi0rtFQb1artoAivyGmtohix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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk41OsXF26rYrRQlEiSrbJnucdWWbJPuShEiUIpLUgoyRrmh8ZSUUrI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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lf8bxpVEyviWFoqQIkWiULmUSJSEVKiUUL6lkiRKyCwNWWWkrGSU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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs01IkbxseuilKYVFus3IpcSqLk9iiS0MqskqKbsBERFem0QmsrRZEV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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs41IkXxqfpMoUs7bIqcptSUnrqVxH10kVqKRuLrUmUEtuFJoV1mWxb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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk81Fsbn1BRN6YuoVsYKUtaqAjlK6FSIdqUyrWUW4lCEYmKtBoVbZJC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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8Vf8bpxQlIaOsjGhYyUqJtyQJSUVJKkk0ZJWSIhoqkTJCU0ZZFSI7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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81HkXx9FIVKJcIlvD2hoMxstWUvnkkrYe9bQRSTwUSy2PUsqTCLlM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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVHs4lIkblbCU3FKxqcglSrY0ZBXHxhZl3SK0j5bkmnsMtVMss2Jdoqsk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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk4lVsbxjcHqVPpJOU0ODSZVVJJ6VaIT9FgyhBRpDjmoVRIKfWhzPNw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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VW0bxSlTlFRIikgyRHlFKCzVm4giqWiUyljmpHoTKRmiUplSGTJF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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs81IkW9yi1GKtuEWqkbFKxakXTWF+iB+khMiVZr0rWhuTRlceVNElW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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlG04FIgWxxElRYpaZQnZLCV2UhH5hxUql5H2Woq8F3lPFGXUVGguusnL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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk81ekbpYlsJRFto1HWyZIlSnQwspVGUtYKbcwSYkyWikaWGEmUbAmR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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VO0fxpEliqSyZElCosUrpbc3bmmjKKVFhdCiIlu2NkkqFSWJFltl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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVkms41AkDxSfZkmzpKkUuabVbK5WNEkdCxYQm5JIu45KkSPXm1ZDXPdYl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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk41AsXxyd5hCRSjWupiKIoI++0aPqqi7QoV7ZyFd0sKa8lFb0ZpHGF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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8lekbxk8NhSHSlKYiYSQkEb9jyVW2yBKyNLYWkWXaDGkxCamTolBh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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Ve8Xxa+hVFLKkAxFhVRKQkIWJRpESYokQiJJCJVMlVBJJSSVqShz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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs41AkXxycvUrTSo3KJklRDMt3Uys5XYQvblnKp1bTposuTtCVdZN3K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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs4lAkbxlFJJHalpNDYmpSyTqWk7iiHpVJdhUqzWIfR7kZRJMoh7aIc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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs4lGkYxh1T7W4OK2k3KaciLJEouRUdtEiiZHPoXBslJWxhqCQsWodI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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lO/bxm2lkB8iJURSkeSLSgunUpKlFKUIlRZJi1TaSTtCaCXZKlki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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHk41AsXtiWFyr3qukylmkpCZYni9o4lKUuiULdFk+2TbBGVhnBHXaIS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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs41AkbnVy2x6gllKwUm3xdrIYtbeE5WtYqWnf1RSJJbYtohYxcUmwm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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4lOkbHmWjWKdqI2cK0UisY3R3TgezyiEhOeaQKCI7sWTLdlCyymFD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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8lW8ftkKpjOinKaMioyGS6JIopaSFiJaMlKSUoggpUshIyKqsEBFl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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41IkbxV26oFhR1nYjI5cSKTZFnQkhlNu06boTCkWy1kZJSrW6q2R1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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk2k81AsXxydRlFRXRXVlYipF2uSWW/0sXakkRYu1SN08FG7KktAkIkIU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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs4lOkfxpFVFhEdbEXWYVhsJGEKdwnZmiRLK4dCNqXdJMdiKduqhJVW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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHc8ld8fvxEpKommr0pJQ0JIRm+VkUiSFrITElpSEUkqSsOopLKyIpK9
srLjulx7lHE9z6VCaRG/8/vrvp4/nueczznvedfYuBqf5GEwGBazGIz//zL8
5MU7LlxEZNfbbj1JGvaXJ62XGTegfUFWbmg4FxVn5U8PthZD7qHvmThTCpF+
8yd8E8sQmVw4O82GBvOYmffPAxUYS9n0VUCHC4HNHg7lYRW4lnReQzCLRs7i
Q0d5+FlQ9UxN66+lUJUgcX+3QjnkJpe3SovS8BEaDI/NNkZ6Wd7VhjU0RsST
O3k0ujCXFSOaxsfFaL28XUlVFhQUtsg1mNL4NM3NVhhmwcpbbGVaE40NZWWv
TBezoVPZvdrDg4uI3NQXZiHZuOY0wvh8iMbtjevOKuZVIuTelg2ewxTOLVmo
vtSyEa1qbrsvVA5h0dWPd8urWnF5U0AmM24Yo7NTHr+SrkdMwxaXP+tpuN1b
77V8byYedXL+DMvRWO3xlOXsEga+9RdTJbbSyAr58dpErRFZ3/e9WanGxYOM
Z3xPhgrA22fY97qcAldmk8Trm82IO3Q33PEEjYTG4/26Uu1w5lfSe2RAQ/Pw
zMFD7HvomPNtXG0tDUZjuCD7eit0xJz4jkpTuOLVIv7OsgkvmJ5hziwufByd
tNtcyuHzJyhJJJ6G3LnBAP0f1fDlrqD/PKAxqjV2tvFlOTIv0frOkeR+Rszk
3YTjwdV9pXcINJrvTizc7FiNXLGkxzeX0agw1nW+Yt+MfbcsjXZfoOBzQcrp
GVWOxVx/2Yl0Cozvw9dc1jRBgCnUY3RwGHbF0hukbzVh7fOVv+0lhiHT8lVe
ha8KkGXnD7RT2CJg4PZzgonjuunGtAWF8f/CQ1m7SiC41pTntRCNaS3XPpvE
RlTKKxg4fR0CX/WBHfqTHbB/79P8zpqDSFHBRAd2JupODT8b8KChxSs5sEuj
EGz79w5rNxG8SFKhEqJesBLYFpSyjsw320a+qjsJ252C7dzIfbsf/RanKdGN
gOaL0ZYvOaip8HO6+KcNWceKn9MFg7DaGaHp+KEW6ypcY8cTh6D6ILD1tWU7
mGrx08e7yPdY7nIXUmIxbW3gvmUlOU8vmb13PIohWPPxt7kgDZEb2h3Tixrg
9+NXsZTwEMqrg4KTympgeGYh15WiMdukoZTeVA/fdF378Qoa3seEpBT7i7Gk
/+3aq2T/b8y4lOo4Ey8CV1zZSXEgPjOjwv3UgqTGeq1cKy6EHxr6Xf7wAS11
m4vm+tCQYIWyX4ux8U1ErE/4JYUfW4UCn5vUIXVxTpolefZV2H//yJsmHBne
ccOWzcXF5TVRYqWt4DmXsOdkMAdup7f8l3i5EedlAjrTtCiEP/qWYT1cDo7U
cS19ZRpCC+6o3eFth3ez/vlNH8m8xbMCH8cnoihUvdKd8NGnODXq9rxABIVK
nlYifBAIlj9RNpKHKeXL7arfKWRkqCRk8OZCiN95v14zeV4y60ZRZQ4y95lb
7l1O+DwuGlktXYUVl6xgr0ehi9N3NuVRBe6+0TaR/Er4EZ2gG5uYidSQF8Zb
xihE7Azfs8muCKX7hVwKCV4dQhLTKqe6EL1zOpHPl8z/XoZ31KUa8Ws+uKy7
woW9VuKTJZUdaMj6yVDQHwa1KjRFOYCJyHdPi0ccKGwvj3+inhGH+tpHYpHq
ZL7TLJOByXJ8dxEuyVMj8233a16Y/wSbMvSzI+bRMI2+4BN7uhkd2pniC1K5
2N7t5n9ej4lYAcvBiH0cWK18bDZY8BbSqnF0viwNfAml7IWYuHig6d+0OoWv
GbfMl3UxoeMfGvnDgXzvdoGu1RgTT29YNDoQPW1jXxYx882Fm57bvFO8NA6t
4BFaM7sO8xidKi9n07B6OcdO37IZIuvmcn4v5iLvkzHn0w0WNs79xjo+Q+PX
1fSoSetWVEHupOuuYQhs3Pew7zML5b69gVcKKDjwapWkOORitrjjSZP5NB48
y7ksvCcCykXjtb5kv4/eiso0PmFiHufAvhEhCuKLMl9eb6tHm5OGonLZEA5p
VKuaz2mHv8Tvq2VcLlTmRT8tWJ8Ni10Cz/ZNU1BpnTvni08x5v5L3TFBU2A2
CN15dzARNUENh3gIXloM7+vyqjBh9rhrw1PCd6o4c+ued07YbBx3T5n4S4Fv
7ZWgkSL0hc5Q/5HzSdu2UqC9LwR67SZSChtp6Nj3ucvRHegxfNp498UwPv2S
dS6f+QjljbZO6s+HEDP32eARkU7EPU485Ub0vvZncl9teisuVMnc1c0cgKac
6dWPheT+K8UOpKXTOPzh4aaqdjbMq+4fdSwdQpsjp9jXl4XI45YVt3s4MBD1
WLLjVAcWqF05Pt95GGkn+9rXWuTDfx/Pal6Cl2OnqXj1/rcITrhh2UXmYejO
8ljW+wA3S140yIoRvZBe081ZHA93vkTLDHkaiv/eJ8f8asXgyw25Tw04MBqJ
6h/z/YAEDd/swCQKG5p2H+0/3ILemaM6+89zYTi2qvFuOhvGq3qOt2vRUPns
rb3Uswurt+TnmE1SuLZrURnTow3Ov/7lBRpREN6iwr2t1oonPG5nRFUIvwRi
b7dOVkPvv1CFx3so3F7kcDyn8QM8WmpetF0k/P619fv05wqka0pKNKzmwjM4
rWwTtxbnpBycD7XQ2Bp1kE9ZpAT8zIE1tUMUYqk9YtERLVANFOsdXEijXaK5
wKOYBV/Wobz7FWT/UikLVn+vxbEDdmpKdlzQeUfZg3qtSD7nlKO1lgu/XImJ
sxQbYbr+v6kULn7PF9dw39WOtpPmG2SeED7czzv4xbQRk41dg2HEL97K3U9w
2FGHzrcP+U4wOXC3DdrYNZaLgik9/kPXafgpK4znj7cgecH8sPNO5HyYygJ2
Rz9A2DSYxdXnItJ66wQ7rwaKhlY+cq5c/DSfenR2tBwVAv3yPjtpOKcItvTc
YIMRvFzFiocL8WunvA3qyhF5mGfBRcI/CYNk44wPLPTJZrbxa1KYOnyyi3d+
PUx3yJ4sHKBxl3loYGRBJTiy8x6Wj9Io1c61Dq/sREfhI52aykHin93xvR8b
cXdVscvynVwkpToNWRuVQf1v8UqXfAqlnbkOFYuZEO/3TpIg+YHy1O4eO5cP
87nnc1P1aUTSVzbR8aF46aZ8O4TgK25JceevUSYUeDk6bFkuDEQaJjj3msH8
s4BOSuVAyUz7lgGdh1ClhZVcki9Wf/pcwsgIQY4323w+0dufXrf3tgpXou63
otVslyEUp7t7d2zOhoK42XjlFpKXBqucr2fGQfHHE49MogcHWBnZpufaUDEx
pvjKnELaH5HTC6NSUeBRqLpRj0ZAyvU4R9UmyKxas2qB7RCSjvwLfzS3EKVz
/cXCGDRiTz14mpz4HA2Hh+/89x+NZR3SkssL2zGSYLJGcs0QtE5FT/gW1WJ9
ROn+pWEUNAUlql0dyuD8Rf5mhDuFOMEBo0CdCoQFVhnN7qDQnNvLenWmFLNt
jVlvDSnon1CMHtzWggJTw1v7xmjsNj1RFLcuFeM3Ui0HFxM911ePrnF9A6W7
O+b5KtH4m3F18t1MC/r9JeyLX3OxcPW2aNvBSEzPzTubTPwrrUXUt0mzFI2y
JtvEdhC++k4XrT9O9ML9zU8xsp4JO6sv924GONnxJknSRK+SEpAlUgWrgDzd
nNfkvp5Qgb+SQ+HRM/1YRIaGsLt1yVW1Lmw26xV+pMSB5J3wljyZSnT8sw16
oUry48RcqbwzMYhJ7g//Q+5fc+S+hXVSGPoOv+Q8I/sR2nDwzf6BaqTXZstb
fabBMo8R29PRAT7h2tqCUqLvD4eVl6VFwfHEbSNrwvf5MWd+f57diScnVxq9
1ib5lp/rzZpqgcLfzgVe4xx0M3QSl1BpSJp9wh4iNJ7MiKbwHPiAGN5127oP
0+jQ7xp5sLQN/AVSd3GOiwSvJXEKB9jYeYwSOSI9BMXddr5Wka1Q96r1XDhJ
8mpU4vYekRbYW2uEfj/ARcfCm2bG02zwvy0fU98xDPXix9sUH9bBd9GovzzJ
5zlpblFuS7Mx7RgVbRZL5s879tmW4EW2o/qX9P/9VS+q3EaxHMIm2/3TbtGI
2Gfr/4mvFPId/5Y7/qTgarHse8eLdmTV6b+fOc7B05m/33OkW3Ahq+fH+h0U
rmbt1Tc1bEWtVoiqzycO0vZH+/gYlMF4pd73xwk0qm7e3mUjWIx7Lbw9g5UU
3p0OLnHXbcCZ6JPnxTQoPGgtkwwbbUL9KqVkme4hqL8brFGpvw/2v5RAOeJP
1/5MrgkxYOLCe1ujqXtc9Dww0k3414nPKwcngm6T9UQz9jJ0XgOztue9IXiP
7X24mf0zF67G5iqVURRS3umu3XmJCaON5oEf5Slw1NZe2mncgvSHAyOWJM+6
bdt2Ym7YB+RMYaVJGQ3eHamK3uOkv2T63RHlJ/p6tnpOaXYm7LQZtk6E33Yh
YUtHKgox7uMtKj5BISRwRZDp9RZ8qF7BvVZC/F7Q7eNaGybeOeYPCWrQaDt3
WTZiuBpTX2NlFhvScBQwNFz4qQkOMLnE3Ef6A5ptte1ZqBRy7lPtJ3wY3elX
sTkdTK7Xqds8RO9NEu9UEP/qWTXCHXYl/FJyzC09WAdGEq/Yq+sUPsV8tTij
+Rb8hbMy/hL/8+H7NzSa3IaENiN5G+NhGDFiJ/cvr8SSLoU/l7mkTxw56CDR
Foe2mtQHq5fSaGiy3e2q0QSOOvv02Z3DKPYyMJq5VYzCDxZSr6MpKERrOv15
ysSGdQLypywpsM9HmAdOsaHcYO+S2Ej0MG7D12uWZXj4Xi1mF+lzjHdFQfqr
zyBkc4TGKXJ/DmJLihZkFaCgIojDPU7jR4LLnR7JTqhpbF7tPMUBNy1Jmp+u
BYdeJbuTzJsj0h/gdrgG6Wm5o7uI/gqNeEV27WmBzVuL30NHSP5gWDatu9AB
vYJdocd/D+Oc69b7HivL0CSzPMZ/NckDU1GKfm4xUB6wUcrfTKPkp2ffpS0x
GFH8LrGb8O+v7H1L5dhm6HRkp1415CDvQBZP9Pc2dNXXD81qHYawplPWz/xC
7B9IV3HooyD3u3u2u1gxkkYCRWVIHmY0Vzvrqd6D5OKj4TTJR1qGLx+rdtVi
Y/Fa+2jC5xr5YCnTiywc8RdrdjAbhuYvmx/Xbr6Bn2+OnzDpG8nL/9MzYpVD
okm9/Cvx706ZzkZV62qSfyLOHQol+cZ1zfuepGAE5N8ZZpH9bte9TC3dUQK7
5NxY6X0EX1ZPbS+MV2HZeJK9CNGn1fE9osGCTBjeCYv2EqRgfvnsnKtB9Yh4
T+W7fqNQHNo1q4JVj18pOpNLLIbQZV10Ya5AO4raLKpaxUdg/OXr87J5LXgF
q7A0Vw7J2Vyhf1/rEOr/cO1W5hBCznopqgbWwc6kpLCZ9LEH570s5CQa4cAn
bdkbRONFolVAAclDF56bmI25cKG6Yl3/L/FGCBlvrpI4y8ULpbpVjBMtSJvT
daf5/DAkG+d4XVvARlS9xe/J+zQki9o3X5ph4eD3zinTIRpG7ecDvMc78Ip3
k8XQyWEwD/s9N1fOQUD83w05osTP6o9odTDaSY5V4l9B+lnOX9/2TVaZEBc5
a8NNpWBQmlKv0NuOpfIh00YaXHwZs1G/GtCNGJXSkn6ChyTXB6dr/lajfJbN
xu0En4xnpqO9Qy0Q55iPP7Eg51limvO4sBFxRdJ7XUj+s2psH77y8RHOHWtp
2ChFw7hWk/1SuwlMztY6IfJ+S13skpn2RjK/1NgRkieNbUIKH6SXINLpRJF0
K+mDbQuNPU+XY/BSYDbPW4IfprupGEMGxybdomZIPv8Eya+dfGxMmt9Ivkn8
m6G9RkZX8B6oOZzgCXEaFYbeNsLrO+EQPGr52pYCy6EvXNWCCYFC6tjHyxRk
bgpZxr2qx3Bx+4Fgwq/VP+wV7yuR/jnWE5i1nfRNpRCx5YuTIeEea11G/Nn5
Se2tirBajBtGs+2WcWFVtyNhhd1H5C+37D1m9f//azS2BlyswN6Fx9hfEikk
fqsRFslnwcfwZiq3gYZr3cctK60bkUc/DKdOEr8+kbl2b0UXDvj7WKj1Utjr
KZvgji4I3vgwIUz6kUtU6RYDhSas4A8187tI1vNvf8fkLQDrn2aa7AaS16/z
+d6racbfpRFdjAAOTGaiS74WNSH5jGw/yHmE7DT3+eodg9Kty2tfrCV42aO0
WjGWifdGnM3/9/8Ha+oG4oUbYKc3/+4l+yF4PrvvvNG8FTGe/tRqws8MIYE9
zy/UgFNfq8HvS8PfJm9J7vViBPu1Nv5ro1A1VX/Mxpf0nwXBu0ZJ/ono0xpQ
rGtCw3q5pR/MyfnVb7+9YT0LKU+FJSXChiA8qR1elVwC90e/FVTMCV6TVqTF
OTXAocDTwCCQiyxbSZ9DdSzwNzt4apJ+Frn3wOBLpVLkVNY8NnMj55P9C4uW
vcPjly1Gf4keJ5dX+m/wqkO61dH74Q0UZktTs4Ua2TA6bLE99y0XmhanfBnc
WxDV1q4QXEHyqqW4j7l9GfluiOcqAeIXiYV+KhrFkNM9n/eN4HXDG1pa9HMr
tJ9Kj/mTPiG00WhqXirJry1zI46S/uSg4Tat+6wUEi/MWPom5PxyHHeM3WvC
I+XbzVqsIdifoNgWi+qhpdXdWLGPxvf85BydhfWo8nyukkfWV2U4p+vR7Tjp
F2Vg+B8XrxW8BZfe64T91YNVO46QfPMqi9qU0ArNPYpNA3UkT17rrTr4uQm+
M2+aTp4l+Owezez1K8XyXXLtMnEUwqvmG+bXdsNOrKRz0cURRO7vmcNlFKHj
rMbFbEca4SNPLRYdLkOR1GDvzG8KVnbRbQlfS8Gjq3zxTTyFH7Myp2KCOlGt
Fid06ykX8V5N4vzXmqATkBudv38QdV1SQ7RaHa6tMWWySR9MDv8tdk2nA2kT
LRPPH1HomneQ565NE8ziJHZfTudi94UeAYvrnWjT8s058XYImgGPTx4P8saD
tUN53evI+yucvrikfcS54Fbmnn8UPARqUzoX5YDnuqGswR3ix4O3d75hMDEl
dCBf2YE8X3HLyFSJxr1l66TeLaPxP2kqGus=
        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs41IkXxvELEbKlosv6haRETBOieiW3JqFQuaZ7bVZqZbUqdJFck8it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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs4lAkbxgfZtB2/HZFj1OeQQ6uIMNyZ2MpKGj7RKsoIZdNBS0JUK1rk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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk41Pkflw7VhrIUGkJWSFi1thQvW3KNjh+hFBXlmA5KIQrFppIrRywr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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VW0Xxg9FkinKlKRJkiQRb9RdEqKIpJCxQdFb0WBIeEVJRGgkEaLI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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81Akfx4cctXlCYumwshJDKVZEPR/dyFGjNKKWEqJV0bqSdGzpcdbW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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs81IkaxuliZTtdJF2OoqJmLSNdD7UeFUrZTrlEpahcxohu22URdlSU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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8lWkbx01mbOVQjNSkGiSMJETWH6YcVDq8qkNliyyVaI6loZyyVLYs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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VG8bxpFKUkSEhJQSKkklpQuVlCVbpVJpk6UFWSNUIkJkTUS7hBD9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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs01Pkfxi3yi7JEF6tEEtlQViORnmHLpdsql2xRKpbUipIilpRLm3tE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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHlYjAsbxjM5lU4XOSelPrTrmC9J0oK6i5C1qLEl0jo0lqO0WkYSEfWF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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns8lGkbxyc5VZTQySqjlLIl21rrtPOTZK0kGi8qlSQmpYR1iKyOpJTD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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHc8le8bVvqSsqNUskpGQplJXdqlNJTKKBIlJESIpBLRUiFERkaDbJkl
2U44HHsk4bzvOYq0SOn3/P46n/fznHE/933d1zjytudM7Wfz8PAcn8XD8//X
ycsb/hTWPsfqprOLFwnTQPLWfI0F3agt3KPtYUUjYMBVX4r5AGNjz1+mydHw
mFBo3dKdBdFPUhGHd9FYWdCocdqpDWERcytEV1KgAjlGU3+qkbdalrGCS6Ow
UEfdt5QJRv1oy85QClYlv5Qena7Cbhf3+dO+NBJ+M6zsqzvRrie/2HQfjc3d
pRmbE8rwV9+28swKGgNnz9kH5kTicXRPprwG+X1e8bypwLdQGJU+YsOmoK+h
ONRcXQLRrUkrIyIpGAUvXLspIBKnfq+TsVhCQ9Pt3f4bo5UI7QlZ0y9Gg9rl
9F3xXS38ox941r+icP/Y8wcey/sheimhUZhiI32Z36v9i+qQZFZ2153Lhpxp
ESsrvgxhYe9mb39M6smvCio/0wGpw8MRoso02utTi8b8OyEvudRgqxON2neL
q+V7EhA7kDfrngqN1+GtIXPq82HywrqoYA0NUY7hb/57xZDbEbvdYykNV+uR
OWrMOsS+0FpT2ULqG+XRWVqfg55nxz5Q5L52Jb7qC+e2gSOcWbJKiI0hXf+M
31/fwaxEZnnlRhpZkiJ8Nio1YHqXzHuuQ+NGw4jaghf1SN6yg8+xm4JEgXMy
V6QFHsmJETaSbFxZeK89O6sNV9d+lI3cSkGZ1+yzphIDMg2re9yqKYQVjFw1
dytHt+3sKLd+CqIXLRkW1+vhKyexYcCExp3qztnadW3A+tZaMz4KG3nnuJ61
LIWFVqBChCKNuWrB712TmxF+tsDv6Vo2/IyWLPPoeIsAsYXchaso/FNT5wmz
roXJ+FLF5z4c8NxennstMQpRNq5sdTJvm6/23G/XY7BxmeWIgwLp50HF5JPP
WrBx4/cDPmU0zgnuG2xz7cLcNrPS9Z00WMEZccYhbyH6Q3Xgx2UKOsMiDowj
7eCxmLupIIJGfZxL+Ma/zeg89qFZY4oN6uyzm8ppmdjc/lenQID0Wzj+wp7M
Ovy8mJqpnETOjbJ36516g17dUyr5BN/NpT9//EtsAK1TzydJ9kN/NttZQy4f
AeE1dxyKKdyyaC+U0GqA/wk3vYL7FKRcX16N+NYEYSfLmTFfDjqlZo3tnWpF
gnPyh//saQRJ/nZYmtgGfRup0ycXEzxfljuWPl4F4ds1i3eQ/tC2AmdfFzWi
UGjo+CMXCuV8m2056ZVwmtu/53I8hQBftUNXM2rRceamX1wC6ee6epfcPXUY
48qmCXvRUN1lrXXDvhdWSo/+mnBohI4dbJ5ua4G665P4nPNsTH7I35W3pQCn
Mj3PWL2gYFNmkyGm0I/n7wUEsm3JPp2WFLtoycLT4kD/xpU0Kmfpng3qYWLq
pKbocvsRzD7skrXvTh02O6r5BTMoSP93NW3RtU6kovFbjMYI7FJ00PKsEQyt
3fnmizkQfCD0bO7xNmTpqiY/Kif4l3nzRDn8JU4Il7lGL6MhV8UZ1r9dhrS8
tfaq1jTmiEs+0TJ8hzIPuScHKAqtzvUrxS9VQPy3yLR8Bo3TY/v+XXFl4XVx
s4+NMwdmU+mDDyVYePxFiM9nAwexP/+49Cwrxk37kOWyGRQKaOEbT+q6wd3F
0+AQPAp9TB1ZpVkOr8f/lYlVUVhS6JKSZpiL1yameippFGotx9MH/zRgZaiq
qPtNCoGqQwtz47vQ8uCgSsklGox4wePVT9tw43zAk5OBw/h2m1/WbHMxRsw5
VatsaRhndY2ZLGGiRj1ZT8iOA9vE3dqnPvbgVe+OW902ozBeonlvn30VigXO
3dAl/GVj0eHruzENh5/JD33kI/sce+IQvz0L6+5IhVetZ8O/xvLxUYkOSMuc
3dw4RO6363nKepMGXJgOdbxL+Ky27a14g1EJHIdLpjwsafAwLMQ4Hjuh0587
f1Ke8PMWKjiiqR12+tady9s5mCNxIUiEXQ8J80B1rj4HvkkvtP9N1KB2p7+g
wXsK3RZMFXYPA/f96jY4atNIb971xulnB44rW4vbj3Khu3rC6oV0HwzvLV5v
XsGBi6Nr1qNH5ZDOlqVqXGi0/ec6p1CTCb3OvB1xlzgIKwpaNscwC/29cgMS
h2g4fEPgwsYaqN54lJFB8NBoODjymK8NFXwOCpm/KGxmFkZeluzCyKZKuz7C
pxM/S+xTWZ34Wb/QdLCaA/mKoGcWUq3I63ravOoHB5tNrcO8uW3g2/bUcvsP
sh+lwl14/wgtyh27JUl/vPc4fTJ/VoRldk7S6whfCqTMbgq53YylVGyc+RoO
hLmG18SlWxGmn8Er8paDkV+RKtFf+rBEZWqHJLnvIctJXRmhHuRtE17cSfZ7
e6/Dilw9FkZ3Jwx5ehJ9kxDRltzSjAO5qn6uhG8MZcQyL9a0Yzwe5RGNHEjk
Ko1v98+Br0SYvvZaGv1XH3C94t6BN8vXxobUt8KOVTZWkIQq+RWVauQ8aqtH
q6BLBTZWJChP7CX70r7hmah4JRqTZzyO3qYwQH0K+f2jAtvthZbEj1GQ33NJ
e+osA4X9S1z49TgwdciZvCTFwkz9PoG17gSPUzVykjxMwv+S6xrzCb4OtRm8
le9AaKyIz58BDsYTy7z3PixCjsV4wuRcojfx9R9jAt8hoNjRpXc30RO5Ymu9
FaVYWr7ILXABjaN3Q49X2ddA6rXl2+PRFNzL2V6zHPoQIjaTGefDhUdL6DJt
gTaElvDNrNSgsH/4WHXa5gaYpAt4DpRRyAn6o2To1waXP5oRr7NpKGefqLUt
ZOG0Xt7LOcEjuC/rVFK2qR/yMxoHMET4QdH7682mUnzQ2pfV60v49ca8BfoD
rRDXdfGa2UMj2X3Xb4vIFnh3Ki7g8hD8s0wTauxq0aDwXWlnIqlf41Acq6cG
zglTT2ru03D5fJ6uSW9Gzu7UjdE6FHiCLT7rM05CRlfQ7BTRG/UV4hVLpzvh
cIaZ7vyOA6NlPn2ame+RdyY8lz+KDZ4VLsbCO8vAfnxuPbeRRmzCF99KSSZi
q3jPvtrBRlg/bE+YvUf77GMXNAgeXQfcG7pqXuLl4fmR48dpSNyqS2YR/rCo
j/uW+oXC05Fw/41u2fjJ166+0IDGKarn0ApfJjQ3uOWF13KQ57F/rv/DTFyu
szi9j0PhqDOd2/NfEz5Yb6gU/jMMzY9rVqU15SNZOFXmC/ET31f1Ju93qEaS
BzP4MtGX5ujavcfpaphOGL1UH6Xwqu+ObeKFHgLOFvhPsHEszHd6B18XPlwf
Nexo5mLnt3UuWyWJP/r93KLIn/gBVlCV9nQNzFYHLVa4QqOzzzbttngqBEYP
MoJ4ST+dVLc9u9mNPUUNXeyfw5j90W696epcnDrlm1tqSPzP39zS7idVWFj4
+Jz9NwrJ7B38jE9diCp1PL53hPSf9yuvVPItbO1TWxlM9MYmRe+MUnctuMWX
uxS+UmAQ/6l9lYlU0bshHbXEzzGZovMnKsG700cogvibhKjPO7+XxeJ19E+x
N0o0xr+0unGNWhEhmTirnfCFdJLNFnONRmT53h3Z9IPG3yYR1vFX7YgYFHTK
tOJiQErvQHp7Ehp0lpisUaMhdXwwT125BdFCBiUeUxz8WnlL5PvRTsRUVW68
Q/ziXJr1Z/6nDASsObdqOemva+9KZ9H7T2G6y/T7Bj3iJy72fRsefwVjfX9v
B+KfBg5rxW9LK4ZNXbvWvg4Ka9e8v7fIPRvhkQkpVasJXuPfHLsnGoAvUqol
hwj+ohTcHc09K2FQI31leAs572PO8tp3E4NnTK0uEX+Urjd9KyOnBeJS/qG6
kyOQS27nbnBsQ85nqYAIBS6khrOC3b6/If4r9PpO8v6dJdk5AYrED0nuSsrI
Iv24tlT/gkQrfpZIcyXJvv9+Y94aLNgBiYTK9ib9UYxI/1nO9q9Ccub+d8af
KRif4ai80u9F9Bv7tZTJJwyMZ5tIJebhz/anM7w9RC9qYwM8TJj42R51pM6K
Azkfz+C7s6rxcvzlEm9j0g8di7Clph1YWKXknu/CwZCPWfYZ40qo/bOp7jQn
/HlbSYtufAnZT1cspAi/ZKmGVFqP16Fz8fVNv07TGHmiP/KF243vKYerkuaw
UfhXP44rX4O/Sv1abCcKpYsM71Twd4NtXNWiQvxfP989zqmMdrS0xMupEHwo
lvCaH6IKwNi5tqxHknx/cOnivxNdiI1t/ZQmwMEebfUmA6KHI38o3yvkPuXc
q9FPKhxx1Tk1UZPMw/BWQL4wfw5S0gT+tEjRSGp76LDUvwN9me/tPBZxMeic
6xByuBay9lsT/v3fP+dt7hWmMpF0TzVYS5/GYHfDxF2FtzCq2DR/204aglMj
6eMvsjA89eOtxzYaanlGukkx3bBLvnFhtxAXR2tnZA8fZSLUcY2j6SkO/ENm
G2p5d6A/KEw+5iDZD6/q+e9CKpAQLmIXRPzRHo151y5mZkFZrdJBm+j9rQ+l
rL3NWeiwuOSaSviw8/ng+tdhbVDe8UXuKWjcvxpaEOTfigCVzveKERyUTyzf
YxAfgcH0Q+IfyOdvyLsejRp8jyXW+v4t12kMXVurWrONhReMyboqwp+V66pP
ClswsWK6g9dtiAKrcrVO9aca5Bq9jioKpWHw8LzoQEI3NP0FzUrE2MhRSUkw
XM6Cfv/L+Y4ZQ5Cz+xa1cVElYrujrIUFyP76OgpG1jFwfjoq6t4TNo7Yri7+
d7oR27xLLhbbED8bbax5/lYn+oxzRwfe0Zg1xOCvP1UI8+7wXik3ou+2nVsM
rjXCqMt9bL8RjYrME3N4mzvhdW/IMdCbA8NwH0PWoSZsF9+ryJtCoVPyyNn2
kRzM+pFqcHSCgl1T7dcQM6Kf+m12PTkUCp/kP11VVogsEdenH8l+zqmJ54QZ
Ev+1oWtichsXtXjEMB9tg1xWpJapJgcDDakjRrV3Ya2twWNN8rHt2WdUtVs/
hPIWlO7NHoVIwo0YwzoWXPRmhd/uY0O6c+fdux8YyPKU3XqG8CPP1ILoc1c8
kZcnNLZqOdlXKsw7wzMZjnWsK5/J88fNUT9HKyph2np5zKCA1BcU2W6cUY2q
odwfamS++nYM3i3qdXAOPf8qajOFx8di13R9IfNZ5D6xqp3k4UZO27z/AkiO
ssp+JkNj8lrrrqXMNoiIuVXxJw0j18/Mq7qFAft/9CA1ToOvaOPXxfNYsKjI
rnB7SPJZ3C4drnwIhJUXHr1F8JE3cpwSWVuDL3q6CR4PKfjp7ViVfb8e9yW/
2eSPkfuce8WYmcrGQqUagZUkj6p3KgxXqrRiD0t3zfe6IcSGXlm03KsTCq3D
jfMnOBDxVdwaZ1aMG1fXexkRvjqod/6qRXIRVLX9xV82EP8QEyi4vbIeM06B
Hz0VOajx9zGNCuiAuJ5X//YrbAgWef1wSyH5NeGVrlge4dvTt+RPv21GeaRb
XOU5DlIleafW2tTDp1opWLl7BMkNS8r3mBN/86G0TJzguyVC/p/h/QYcsFxU
e7KCzPvbjTef77SgjJ82mCjjQPPW6y+XhbKh+ETrtuhHCpc/jA7YEr4xlQ+e
NZUyjLn8Z3nc7+TBQTJvJoDkRZdH26701vahsM7k6cU4LiqcP52at4AFm7M/
LKI9RpCTbfnQ04iJiq17NXqUyfx2erdeOJ8PQXe7uHKCX8l26idzqA0DdXWH
tGNIPqiOWRK1qBm5AmIvC8DGCrXIo6f3v8UES37Kb5oi+cp+hyuTiY6TPy2/
8nGgvMLT3+bXGzx3n6fYLET2JexzT4BlO8lx8j6r6GG4VNvavpdow97WkTJJ
oxEYljQtLvrIQuvXwDofx2E8thrPr+FthoEKy8mxnvCTHf+WVWdeI8q5lS64
SSMzV8PNnfBrocL3r+sI3z0NWj5l9aIZX4UOvbYkfCzVLysiEVaMrUfXxBge
IPqYJVt2Uv06ho6ksxvIfO97n3Rc19YGKet5K1efpbF/wxGhDKdmrJJK/i1H
8myAid3ePudqWPfX9F5tojCYlhh2QboHykZHX2gpcKBt5zr5waUelfkm7BcE
z1R8rEasUD4eB8jrj+nSCOzi6H70KUTQY2q7Jsm37QKX/F5uK8cBRc0j8STf
aM5br5x1Lxk8K9Nfh5J8c+qAQzyT1Osnc2TZp0wK6V4OWS++tkLVhW//mygu
3jJMIsVm+jEo/cNNq4uLGN8pOv9kBxzdPRKdfThwFy5yWlTegd6vs2M8kgmf
SfMZ+vO1g/v1hJJM1BAG5np93Jkbjz7zOBkfMo/i1Nk/dLubcHDG/B87gfD5
/otyGvtjwJOx17mO+I/jmYLTU8+YSHjsbBS0iYLcl0PfQ24R/CfbGT3VohEW
dOt106wSlJZIXpYmeUHXb3ipz9tOHNC592valQMvkTuBjGgWTk2+s12RRiMg
ZeJLWVQ1QhuaD7svopEwz7no2NpsCIY/et+rQeOQdrzIcdn38F5p9cmD6LGP
0sXARM334HcWVQmrpmHlW3gr6EASppfNf/GO1HcsXoz1ZnsfGDFur9q3jCDs
e+uxf2EMxBh+PLGQ5O+DZ7a4Xb1chyxFv5oZTQqeit2WvP0MSFU9qGTN5iDK
ILv7BsmHWYkKvk8Jnq5HJOoZP+xCRU1pXs8mLsJih+hNq6shc8XLVrKHjYAH
ylqp4jcxyQw2jlGhUfop1kFRrQu00rTxfdJP8cfxg5rrmRAxzi88SPhHs3Wp
jBuT4NVy7cPZJE8aLVS5LTMYjifzghcMS5N+H7hNH74SjUlP/ukHhF/T17vG
FCeXYI5OmooledbMbLRWCklHkZlCcAvxc7FMnhkrj14o9Z6wMxQn+jopxZ8Q
0wyem4HvCv//f9BtS0uh67lIWZ3I8GNSMGye3hOkVo3J0DtbitWIX18zv2jd
pTq84F5eXB5HYbS+I1fCvAkde1tcfbkUtpXbR4avaYNCY1aEcyAHob+1WZsa
m6EptFXndQAHut5Ra7nDXRB8P+xeRvJU/4HUsY9r6rD1c/cUi+jt4edioQIj
TJTbSOXJBozA++bLypMn89GbonpdkKbwP4CdCc0=
        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41IsXxudGuPkRQhSFJom0KaTlpeUq2Soh0R2SshSRVPfS7pZUlnRt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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwV1Hs41IkaB/ChOQqRkyhK2EQ3XRyN0uWLlDilrda0m4pSrRi55Ayt5NoW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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lfkbtVQqaUE1DS3XnjZFisGZ6k7IVkglhKRCkb2yL5FKJlmKGpVU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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k81O/3Vb4pQkhSVLJE9iwpyQmVNUtKKqFEhLSgTZtKKltSIZ9IsiWE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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41Hkbxl1kqaVkq9XJIkSsRWJadFtZJK2UogMdtgMZSVE2HeitLUIS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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk4lQkDxV0zI0ol2ijJFCFNipEMHTVRYoyt0oPSuJUGUe5T0lQ0biI7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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs4lOkbx4fsphxKrJTDShKWTYRGh6+mSJYkQpYh6eAsWoeOknaRQSpJ
CiWtssi5MAaNQ8IwYtSkQvRErWqrXaLf8/vjvd7rua73fe7D93N/72U+ITv3
STIYjHT6/P+NJflr3cxFcDh67vvfTxPwDFmnf1qShei7FwS5ywnaqn/Qvf6p
G5MayvOjDhEUftxq8KV8AIGVneZbuQS6nHbjW+IGBM5jVsyaEngcmv52VtiL
LNN1zm/jCF6bba6UmRBhkoi0a68SlGi8euFiPQCBslXMsZMELtcUpH/d3gbL
m8t/m2tHIBJLdv1jyod1tUxc+DaC8jYZC8fgZki7fbHz3EhgFJGis8ynFQ/1
LnHfbCJgqFi2u6sfRgO/oM5Ai2B36qg4S+4pvCo1q6/fJUiNtgndK9OEo1Ie
K8h6gv4CBc99Hd2ojrbxtdtDEBcpbijKr8ftA0+U2T8T7PEStwUON6KgqCnH
dS2Bf/eSvDVMEVyXffpRPYdAWy4t/fjCUgjOafyx2oBgQpp1y9S1C2xTi+B7
OwjUpkvfu+p1wj58d7m2L4H9juFOzfAOKBf+M+nvT7DDc9FavduNMOBpxew0
I+CH56nZberBuba8H2qjCJKzBixWGvVDIlj16kQBwaRRqGHz323gsKZKBLRe
0YT6VvbUTUSNfVkq1CHIf795tHN9L7T7ymx2HSbQ27Qk0LGsC93PC5ku7rS/
0jL7zNb14MbW1aPykbSfNUkK2UptmJfKllej91lyC9P/DkqAwM84+xjtX4z/
QOastABMxk/yB4KoXo9eT5StrsGi+867so0JtsypPnBnqg7lsvw/HcwJ9qk5
yG560YYGD0+5AKpPjqndgP2VGkzpPopsWEVgUTq26z+9x2jyeP372wQCuzlh
fR8eD0AzqX2TKo/gs+dRJ8O7HVAPdtdy8qL5hD+berYsDk+qdugdpvnouNso
Pw3pxKzF+ONce4Ik9x5Tc9kmKDsNWN+nvEV5ORhM/SeAxJ0Z8xSqp57KeP2c
ih7M7ZjiqlNeFx3JLnqV0IS0ax2azVR/3oQPjNRrkJowuqLKhGA758tIhWUf
vo4NbshiE8QfVz2REtKA/UPxXEcLAo7B8sBtx0S4T+x+1iql+v1YOv6vRAvi
LmjbVTvS/phGRg36liBOTXfLJX2CdVc938X6CsFZNPju+CkClmEYl7GjH6dF
gvKYMIJjqsREx0KEgBe2Qw50PlRsz6U9PCDEdkVFm5N0/t6YOd4oXdAI+Rcb
ZL1pf0Upy/3aOZ04dEJJ4fJ2Wo/uO+sgJSHii4tVPeMJvM6EWitd7gXrAH/l
yhAC8R7z5/5DtYiQnDP3GP1fyaT1yj7JDmSlLv3I8aHxIthOa0v6cN1GRWs8
n+qpHMJ+aFOO/dLz1XVp/n+aJOVy1rRAe8pK/doGApvniYs/H+1Gl/zChl8o
n691PazWhHZj4x3HWAatT9YyLL9H9BRhLGmHl0ICqUTmrdGiQTi35uakfyaY
jTrPM6vqwfI3x+55hxK4ndLsFxrmgbPS64gj5XdIWHFDIoIP705eWRONF6rb
rN6qXgEp696QFMoPY0TQnFHHgXakd8045cHSaazfkXkdRXUj8stWUD+wjmat
ulWAmFOJybH07GI4OGPC7UdKnpGpGvWbkMVHvVSi2jGumCE3603wUnP19Ezm
IKI77716cY3APGxhsFxAN3hBthcyfiM4nO9X9XFBD1K/W5J3hM6TvFThjEjl
NmT1V/uNrSTIrB269PjzAITZTiesH1D9w4zycsKfob8p5UxaJc2fkRve4n8D
N2f+UGRq03pd4xe+3SLE5PebE85T/RmfFOdx08PA9mDG69B6el++CTI63wmL
G1dyjag/sIZt/1mwtw/JvZoBB6MJ0h+a6QyoPoBP8jrRuXVUvx0SV0PuNYLl
4bNHmeorbimYiZnfjNv67vVzqH++HpDk10w/xvBc78T6dMprnUgwmVyKBSE3
ZTWovhGOfV7vnLtgGzR5s9+Txi/zPhF7shlG62W2PgVB65yiZ8yDQpjE/XTr
5UECrkHAXn1mLz6HR0wKKW+To855zlZVKA09+4VN/aBcBY35X4TQkL/ulXqG
wNjJP7dSshuFGsmVr1zovJLXmcMzfMTJLN4da03w5MoSk4TdQiR8/SvuM73P
aJ9Eo3FLMXod7zrI6RIEtbPOujV1QuaR3GF7Vxrvo6HKab0G1E43sS/SeHlS
ss7JtQ/QeNJZaWoLPRuvT79h2ALrB0NSo9R/SsxGPkg4d+B++u6hMOq/R6b7
tMaYT7EoRL9hbw0Bu3peTfx+IRZVx3GqYqkfWMbXePgWQFvhnWI95eeFU8X8
uJBU2CaNH++n+titz0v/fl0rskL93kfQ/pR8jJdZsbMMxjUPOWN69Hu3bPv3
jGL8e6GwO5ryUf0hMFlc2IbsPbyDs3QfyHun5Wtu4EFtVjLxDPUb1Uv8Yg0G
D0bBj0xt6X7xzeBtk0jpxqqApS4ZxwkWnqpqXdpfh8LhOtdOJo1ntzv1Aa8H
Kl/31HApv0qtY9/pPObhm+fGWo81lFfL+u8u0H3YcTFxVoJFoPzv/tYfrAax
rHijuvUA7fddRkOXggjPQt+SQxkE3lNMrRH/TFi/+0UsTfn8Wt2R9otPG6zF
ne5ymwlObJmw6fpQCDf9FM57Ws+1uwLJGunnaCjZHL/4NuU77o9DP7YXAwqv
xqspTxN7A3vP/94O1m9P+0eoHtJXjK5+E9QjsyfWsYbWuysjzenWeA/UTTzN
dlKe1i52nk6MKsFgkUi5heptOXT5eTy7EWu1Z+qnab2My4eCdL5yoWPAmHlL
eU82D6hPSuqBn79bitWvdL9k/vXyZg4fhtsuloko71FPht7s3CVGiukWiejn
BBc7PhxJ0+fD9qKL+1l6n86uOxonfQXgV17QOxpOMHyb/3eZrhiWI5JW9hyC
Ne5pB20yhSjw+rRK+izlJXK7VYEUFydbuSNqq6m+TVk65X+VwyVGMfgZ3fdi
r/Drf8o0gFvpV29BeVQWsuZVyIvBzvFh6t+h+yfydJZ/pADnrKT92XQ//A8c
wpsm
        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Ve8XxQmFyJC5vhVJocEYSi1KlIQUSZlKlFKaZEiGSipKUlTKkCEh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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHs01IkXHxLakh7ED5tXSg+7eZVKPkxITSuHyCskJJUiFTIT2mzkkVf0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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVHs01AkDnUqtVEhqbSRUiGSKisKNHiT5wqz0ohSyoYkepG30eawlafVF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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lfkbxpVpotUUKqJNZY0siZpuiRhaaBQtOI4lYSwxypI9yRYGNQ6t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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8lN0bxiUhW9okVJKt5bVEEXKJLJUkJIlSiWhB9aYkqUQiRQiRbFFR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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81GkbxofoQCuMUKRmmmSLqCgbuQZb8UbpwIoWW2HLIcKi1qbDiCKH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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlX081IkaxSVbRm0piXQppBJlxE2FjiRLq0tCkgoVGonUFiGUYgslpVJq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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwdlXs81GkbxklJVtuyKishFbI5lLeaYrpU0iKhpETWKVpElA5LESVJqK1Y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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VPsftoXKLSnKki1liZKQUr1KZatIkiRJIZW4EoUrJBGpXFuFpA0p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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs81HkbnaRSTdFq1yXeVMLU0CQiMUdWiMotqt1kKFtoh7AubbmHQilK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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs0lIsaxiftbElbF5U6JGxSbEo3Jnno6hTS3VEuzXQ5LqU6myTJrlEM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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVWk8lWkf9trHGG0SMYVorEllynoxUxJZDsaSNKfBUFGRLYNsUyhb1MgW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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk4lG0bxmVXlvcTr2yRoqSyVKLoLG2ShBZUJEUS0qIkiUgqSaulUiFb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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41Isax60lQsc5RI8sUaeLurKUNl+ESt2oqcgWSqdSUSNblKV76Tay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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk3s4lAkDxbW7tXpKkVuU+qLSFqLLp8tyQkmKSopVKFYG7Q6rhmd8SavL
lBSbSETNpqWiTFSuO8YlxjDjOpeSubzvvO/qRtgUts/+cZ7z93l+v7MkhOkT
9pWOjk78VP7tJKLRe71DLmxOcrSJXTRuMRwfry7qhLiI3f+MQ8Dkq3fH3T9K
sPyE+9Fnag0YuU55/dl1qK6u4c88RCH94pKQWJ4CB545ipqPq9FAFX07WViH
3QsydQ2rtdBPm7OVaS2GsP1zlnyYRGHoRB13ngw3jtuwuAEq6KS+88pfJ8VE
cXWKUkpAOHtunIsXH+1xFYmVfRQeFB6I4e9pQaTApLEySovZo7/4fLvoBbaN
DMv3PFAiN+4DbY4uzLtWMG5iTOBLY0Xwc+cenK3zzGVfUSPfxODnhEsyTJwK
J2cQGvy9fk6amW0HXANTVh5jkFj+6cTrbRf7Mfm1/J6orA/liy4ErEmXwa6n
a85YJIGRA0b7Jds7wPTVcwn5rAFfMPFm0Uk5Xubqj63eqMKGIZ3ocOsqEJHM
M5P1FPLWbBplBUnB9ljbLwnXYL/WUlGeIkHlTt/GyIskJCcCPQQnebBMPbV4
wy4aad9f08t2LgObp1hraUrD40yG2cFGHvqP3G4NMKGhw3D1MWTfRt57ifhq
LY39VnY824FevH995HzKcjXsr+9e7L6kFJuMfaPfBtBQZBms1zcVYI+jJ3vR
fAobHVd/fsvoxd33KwJzgjR4PLBqwClCCse5YqNlUWpUbE3eszpOhpHyruQ3
91VI+++Fc5GZt9B7fnFamYTG13a9g35xcgwa9nfGxqtw7Tuzft8pvqXc4dWG
yRQS9bz90qUdcAs0pccrNZjRbhPk6NaNC9YWZJVcjep9rlu0V6TgZbyzvCxV
ISennxU8IUHLvS8WnCYC9ayCpKzWblyimfXkPQK1YreQ0gUdKFuUX1DsQOD6
pmY941P1yEgeT7SeTuGDuZfdtmtyNIQ1JBvVKvGfB4VhXb4vgLmuhuE5SsRy
igYWEGJ07rWTzWgjQJ93cGO1daLpWETkoCmJblezTf4zxPhny74Pvy7UYs1S
p890aA8Os+uTdkCD+NJVRqL5pfjiolhRbT3F49Ez57KgavQINz+f9xMFvnV7
d9ZfYThnHlHGMf8LRhYtr1m3e2H/Q15zaKoauTHlR2N92rAxRtC8WTjF+w3J
bXxaDqbOfql3DwVG3xKxpqALlmFCOzaXRIb/0pCTtZWYzb2W3VpCYfmPm04r
Q2pwd2XCoQIVhfGEwcUOHgq8bClqqzcg8OqmVah/uwzd+QU3dDVTPqZFW1gc
bYXxj8YMsSeJrO+PHRqY1gfhSEuCz0MNoh0G6mZMKoCI0HrV1D8i73Jfl9bL
oLRgnVPSGjSc04v3S6+DjipvztJACn/QNqUCuhtJc4fMlbYk9he7lyxhyVD2
64HIp95qbBGFV6Rf/g3jcVXudW9pPGI01tmqShBtnei9JZCGLr8oODBIDi+H
F2drxtWQvXkUvzeRB//8aTKmPo2wCz5sG6EcXMrzbLZk6o9zjG40OPXipcoz
LstWjeOagDVuus1okFt93OKrxXX/tqu89Epoe/xqTW5S0J/JT29ZcQcG+mcS
vbk0RAMvebr8Roi27zjNOqWFzy1OuOnCHijWJfTq9RAQ+bpOnjr8JzhXxyKC
H1JIVm6YNmsnD9GBVlt/XkZDf/n0XybJOxBOc7FmZ9Lw96sXVfU2Ic+gnW8h
JdGcYO/rE9CKdafl7KX+U/4s6OM3bRZh183Uwos0gcyWQdME3070xPo7Lpza
I9zBrPln1nOIWu6XRJlrITtvX6af14Zq4xrNvccE/pf7sDsyoAnv9nn2uA6R
eJWudE0aVEBsKz3yhaHEwB/SkWz3Jjyk7VeyJVrMF6hSqpzuo2+iJrjyNxrF
hfXrIoZFUE0a/hTzkYTOgHLz/Rt3UTGU5KR/nUaT1FJwZFCGwRe9DM1VDR65
P9WmZJaDtzM60O4FBbkdJzrMqgOhRsXq4mQCJe+byrONO7Dxh/wVS2sJdHOK
dnx6KoJsqGDVulEC/NQI+7dXb2Ng1/gzl0Iad4ytH0AgxcoFOSkKpgoZrL+L
B6cLYDieO7rtOwoZfvtYxMUOpMoOHv7GnkS00U4zzpMHOGpd9PRKDA3ljsZt
Jz6VQRAyZvBkksJIeLJEL60WrGNPIjy3UvAxaJm+NrYO7WnOh0eHtND1cIny
HK5A+9jM2q9eUagSHTLWdgrxUp1GuIyRSKz60yPGrRkpVvODdupqkRrvkb9H
JUTt47mK4PskmrwUzlETYpjMGlUdO6fFJc5oybCRAOLt0UdHuFqwkjgJcpdO
XP4Qt/s9l4Cg0/HK608d+JI1M8fsOAn9Mf5WL1TAxiYoOecShfnMtZnLHrVB
FPL7pfzLWvjvi7rgfCAdvMs3xlwHp3yM2ss8yGqF6puHZds5JG7lOqf+btOJ
4sl0u/xQEozn8yID1ovw+UjAqG8Lif8DDAvmrg==
        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk81ekalyWNLZW6aVHIoWRJlqxf28gQY1zZl6KiIkuJ4spWVNKZsYyU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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHk8VP0bpZAtSSmvspUoUUQqpSNJSCJLyVKhXpW8tChRabFUQmUpSkih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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41Gkbx6VVki2xG6ktSsTrEIu00VeRaskplArtS0hdRWxNhURtVi2S
mCKFcohOy0o5dKLBjME4zGicz7/f85tNQhH1zvvHfT1/3M99Xc9zfz/fr+Z/
j7sekpWRkWFJ6/9ncqn2dLcdD9Z9xXtWXiCYcPypZXCUjyh5ZztWAUHYyu1n
0/hVKOoN/by0mYb5kx+3qZe0Ir7rg0GCHgP9nTFPd24Q4FuI4WfrHxjoDopU
iyo6cb8z4d7APgkCPCLMEp25WOHLDnVzJJCP1yaa09lQt6Gab0RRePmaf65i
TRi8jTpv3TCkEPXHIUOvnpsQD4quB/pSUCuz9+N+rEKD9fyOwYs0yGuNAYvL
HeieO7PEbBsDi7qiTRXjb8GyfHc9nk3DNuFTfOP8JqScER5Ku0rwsnTOybLh
Rujlzf8PN5fgbuy20UPhPBQs38R8t4sgWNFjMiU2H+Yvoo325VBQsnAfqjbL
RkJ3l6feJQq8JvWPjaJqpKe71P6tQPDvQ62a00mdKP8ydCQzmEHPINeIG3wQ
ykq3h510KCzs07e6b9yAx6fsq275E7jYaBcv821BRovA9EqjdH6Lou26kUaI
xpJsNdgESm3HKMOFQixdM7bW9AyDxCnegrs7HsL1y7xAzWIKJoFvdJ1lO/B2
E989EhLI3xrLlkxW4vl00L2sDTS0nsm3pMcI4SCs2JryjEFg+ocs4aca/Hrq
+28TwzRKxbqcenkOeEezFsU+o7Gu8L3tRLUAdb75S6hXBDML23gPzp7HtLdY
vM6CQmlkvKZ7bAnecruSVRfQ0E/uiHq6/zUMvcpqnxyloZ7V39Vn2wSbLcOO
wY8ITGVD9iqoNeHKgfWFnL0EFleDxzxnEvHtDed9tT0FjVc6C4bXp8BUr2vy
sxcFV/0zgrKiFpwsUL3g7s3AT8U+rHWoCpvUxLd6pfpNrI8Z4Tq3wjx5JDdP
g8HJKSvO27sC0Com79PmMBCFnjUUlEfjgPue27IbKXzlW86mf3iHHh2KfSeI
ATNp9PsLRwF6k1VHf7xBpHNhMg1/NYKVfbkguIrgWHZXROaEAOWLPXjV5QSX
ktp7tIvaEDIt0k1axmDGP85MZN6IqWM97gcaCI5qeo7OuHDhYa8wTrkS2E+z
PlTW1ENGUnn1VT5Botfaj9vLU2Cj2FFS4Ekh2tEnc6luDQoPusZvL6YR2zdt
OMXmQ59foSNSk/JPRW3az+tE3ZbbDxTVJNAnZ09jVyvknN1TQqQ8HXQbCciO
e4YxB6uhlPU0ZPrCdRPrk7H7cWZT5W4K7NPjnHOK7YCkXlzbIN3HmfKa8gcN
yAjLSTgtS5CT6pAcH8+D+z0rd809BG4Fv3yqlm1EV8NUXokPQeHXyNepGnVo
+c1CkCX9j17RujRWXxXsZFmrz5TRKL5WuqYQIhzbRWLSfKV8CweuWg/UYdJB
1H53J4HTHMXFz2O5iEuttOWcIFAIpiKK/ulEz/kta0bPSZCtIv/PRX0BWOmd
bd7S+x2GGZuXXGmHkZbY6VsPA+e522NzXWqxz8Df2L+DxoDnzvY4xSbIN7S7
fB9K8J1VgpmRTyWMnx52HbGgodx77qUmEaFvRYlm+CMG7JySVSEhNZDJ9p+e
ekcjalScs/J4Ijrttt245kDh4Inb3OGeN/j9y/3Ah6doaEyo6t/UuYuMF8Ul
liwKvx067BDKaoZyqNw8uTQCT1fOHEV1Du7bfhy3fyR9T/9oloK9AAMyDws/
TBI058wOnraW+jd0sr82naB3hZG6ZLMAuW+YuakSAkvJtt3jBW/xsZ9zpKKc
RlzuxlmyXwDlLq8gidRfi1Z0vOLNtOKAzz2VnGIGP8XHsZR83iGxIyApWspr
lJG8goUfH6mqPjmzz6R+HDE7rlJaAhnX+ilzORp1JqsCFvtz4F33vD6XR2P0
6S/FPIMUsPcvfyizn4K1UkCktnENWib3Lf3UT4Mzs1ouz7QVnM7UhOuxDNw8
1xu7Xq5Cjkehut0TGn9vtpmnovgOlsYWN3Z4MFDb6lJkZCDNZ37MbJ4yQfWy
ExnCVe1IW3vYrpvLYGONctMidiOqPu3SWust5eeLod5ITSdMWvMv/cWSwDoC
0+fLa9GiPCW/xYog1CHo562qQiSULvl1cIbA5MFepcK0NsQs5u8Y7CXoPvxH
tLWbGPPJWLRpAYPwCK5yd1QbLq8ThkfEMEjipcv6LRHiWlX20J8Lpfm+lRY1
2Qjh1LI35eu/BFqPV6cfvvAUqzMXepnL0DjBbNfJXd6CJC27zLgcgqajP1Qn
BDXAr+hs3vk7BH6tM+qjonyIi6zFbvkUHh8x0N5wrQZyqzZmpWtI9WGP5RT7
C8CfZ1B55zaB/tWyYfHBBkSahpuwpXw85vo6NV/iw9Y96OtsnrQ/+uREUlw9
LmQknIoMI7hzfuam63wRLE8OBf55lEFs6KqLbnENOCIMnYyW5mPKeMADsUML
SqqfOzppMnjv8irtUn8jfj4w2Vx9kuB/9NnsRA==
        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGs0lIsbxUdJKREjFLUoKhLVqXQ9u0JNpRNHSa4hudTIJZFE/TkdlRVT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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk41WkUx1VGDTUjpEXJVpYkaVPRV0luSSUqWSKpyFb2UJEtaaGRKEmy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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8Vd3bxqkoklSazApRQlRIuRQZ+kWSNHgyJeVRSJShTA2GR9IkhBQZ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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVk2k81AsXx+13upWUZElZUiG6tqTCr4UWhK6K1IOiBU8Z1aVNRYula6lc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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVHs41IkanpAulHKLo1xyCie3g2qz6tVtsyXkUnbVkrCRdFMkle06XVza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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk4lekfxk0UNbJkNDIjSuqEyja2DrctCqNQWc6kOm1EllRkIqc5zlSo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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VfsbxakMlTQpciWSIQ2EqAwLqSg3hCKSyhAJ3SRRUsZKpjQXEiKF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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHs81GkXn0QupVWry9uOctntfSvUug+131GSZN1CrpPWNZSUbiJC0a4U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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81Akfx7EkdsKWIknSk1LSo1wr+thISqUdOkRCq1zRCnnUypGjknQ4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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns0lGkYl1xaq5IKuZSsCJGkjlXNTyKKbCFNChmXEjvIJqELNYduSDcV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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2cglW8bl5QySltFJDvJaCn5SSohSYhI0hINRUv+kjISIlIhImVmRVE2
B5nHPraE8zzHSKgo8d7vp/PhnPM8133dv7ne5orRWW4uLi6rOVxc//9UyvJO
8RKMRlzUwRj55TQmUo7bS5o34MhRrXG24SCm45y2Fbxi4V1/sXweDxsTwzwl
1c4tOJN6129/FhvbGKWvfXd24K/faQ2D/Wys8ZhTdX5lCXqb3xhon6XhEJt1
3XRXBZxfnZD5L5LGn6Ruq1yrCvAccStfe5OC8ad9Tx3qm7HPQvmk1jiFCN4j
qgzuOkQsnegZU6HA3HzcX0a0C3p9q3sXOZH5kn69O1PZDitkvD3gTOHcx5NS
Bjx1mF89+M9/nI1Gy/uqWVIMsHrFmuISaLCKPHso4Ua8fP5lq6MsBz92Vecv
bGjDKa7K4yH6g6B0j52dGY/Fz4N+rV9GKCSXcZraoxow4DXXYTSUjYT09gCN
wjK0nmfwdjJoJEq7Bi8Sa0VMYbzy/gMDEF4QomCX1Ain8Zv14soUhMS4nk3c
T0XDa/7HZfPJ+efTtSJbo1FV2L1TX5BGad6EYmoaE80eCRPL13NgePX7gqz1
uXBbYK/ku4zGowNJXgsWVaCA76Xu/Uk2uNyF8zINy/D6T8OlticUgnvf/nF7
EYPvZq8FZ2YpvKr0SF2f2IDsOHMhixsDGGor04z0qMf2resSebNptKvHPSi6
1wjxZZHHFKsoxDGGlui9rcQKRffB8Xc0uNyozigDHZg6ic2ISJB9aa2ez/ez
E26VuhRuUPCevn5ZizsO61wFgoflaMgKrLELMqnDTsl1XV9caBQs2W24JbYe
S6OE7gqT/doK6lr++1iJjVtHdzqFkPn0XFZwTifDMNjq9Y61NNLOZU5ZeLZB
7flk4ZzeQTjcYh2zKS7CW1W/l4p7aWhFbTi/ML8Cxk0FKfxkPuXTbjLPR6px
53Ov8I8ECh/0NWPN+doxceJJi0YyG1k/nUVTLpQgPODdnm+bODBVtnPfsKQA
BYVS2pV+FCJj9xeWF9ThmNi5KK8QDux/xyZXSTdAe3WSoN1iDuYzp06tDq7H
zjj+MaF6DjbOscyVLCxHwE5vocSVNOar8/1W+q8R3SsnGQlHaQgrbg+7VVwJ
lZ0yFwS5aJy7KXHx01A9TIqKZ4LOURDmPuw89C0PEqpSva5+NGS0rd+MbikH
P6Pyvz5TGtSlgAGhhHRkpM7Tcd5D9pdvsXJTfAzuxB513cBPQzxO95/sj8+w
cRkzqNSlMfmau7WVrxozFmbbJepomE3fkX0bkobt9gE6nvtpnJkoune3vglM
kw+svioOWIf/nlXSqoY/Wk0VF9CIk5iyXWr6GW/GDE/LkHmZSQ3S6klMTAeX
sYdCaKgnWT2ct70F9cpj8l4MgkedXe9u8ObAeyArrOMBhWnHqws8Eirg+uh5
w+EeGoZcqgpvRT5CbnvbxpcbaWT0Nl5VGP6ED20RRWunKIR/rXjyfWEp3H/H
RDjyc7DDLvz83qvR+LD3Xm32GhqSd+6Nb1laA83yAbrnLQ3fbp473AuLoC+W
FjlyhQI98OCr25pWXNu20cSqaABM/juvK3Ji8fZyw2YX0NgtzmIH9VVgh8Di
5glr8vzowR0qqlHgbcwN9CX4Cr3jd/zIxjqIPufubSZ6smDqq3tdUCaihy9F
64jRkGd0VGrJMrFKS6xD6AAHWdfD+EpqyrBBJWRv9ziNV+lZsw3c9/GIFX5Z
RJoGb2Wo5K6tTGTue23+ZYgNYbaN6sHwEhQETW/IHSX3+fTVUsfAMjxLTdBY
U0Rhua5M9sM8JnZaXHRxa6cQsGKomUeTBcMdfNmCthT0Ew4xKTkmwnONLsSm
c3Dwc9y7zmdMGGdFjr7uplD/vjZW6A8DUg+cPral0TDQKspNdGWC51FG759E
CjkO+4JeHeyAQdfJjXUyg1Dvjmzfk1IO0xZz45RUGtaBc4NsJqNRwQq8vk2e
hhIVL6Ud0IRPBSW3BAMH8MrCSGxhZhH849V2RZfTyJlr2sdvmonfR+e8nbUl
+E43f2EhVIpmBUFjboLHosJ7o4cvMJFxK+1ugCUFN6P50oZiWZDaVRPyT4DG
W181dtiBRij9kE6xF+VAyMo1aargM4yYOs56TRSyrgSe8/KqQLDg5Xl54hTe
DOrYKhY0gsdS8DY30ceCvFuG88YY6Dh9zeOKAgfCTia0dXE5MvRFKRbRf7cp
0b62/U44ftnn34J1hB9pE9WbWgrgms44pVxM9JZhxdX/NQOef1v6rQ6R84s6
Vdw4nA5h4Z0tKyUJ3tWPXty1tQPPlwebVt/hoOePT1lFUTJU9/9IT9GgoX+o
QdLWPBcPV+wyvkfwGbD5kF7lsmK4LheeY51E+FV7zvmpVDVcF8dkCa6m0ePH
efRupA1zbA72u/YPYlR+1dPgm8mY4c6JittE5ntx5N2L0/X4tOfolH/cAJbJ
i6vWHGfgxG8/H2PyPqfZeVq2awrQr+94d34wBZ7MW2KPlpbCctvMjYA/NNHd
40+kNJgwnJ3QF+bmwPqaAY/n7jdwD9yduVqNRpbzDf+Y4jZMLm0tPic8iIBE
64zEy52QkevtZw4MQiPIPMmbWQclt9kT+g4UCrQ324gOPMMnoxZbe6Lf54Yd
fXdaF2DxrGTenIs0tHl5f9CajSiI3yFWTOYZ5d0YcEkxAqc7PNKiCF8m2pPz
ee3rMdHjVepWSkHBuUbdZ3sdqOTvVaFTbCx3iymqLOrAO69fHge0aMxU6Kfd
n2mAXta5o86J/ZBefDhPXC8fq7YahChQFEKnxCSv/G4H96z7DcePHJx12vW2
bU019ApdNT3FOPDl87vSmlSJvz37ii4T/f1lJeiQv+8zEmcfbhYkemhRHWYk
M9gMN98elZZVFERyeqb51kejQ8MoR4bcd8c9lcU/NhZC+7qr0jqivw/PZA/v
uVyLjnQX/6kICouuNDt37W2FZM6i2nR7Ng48ud1l+LER611N7H6JUeCUh/Nw
skoh/lzjSUYOhQy1JXJzk9uRcldHOimpD7br9zzub+3C4SGe0ruXvkFWY+ib
s3Az6jdJnEso4qB8YO1x2b3hUA5aEnWB4FW/WGteh2oFHNinnM4/4KCxXOii
h1Yz5CFvU9PDRqpe5rctQmXwYb25Y3SXwhblnyn83XV4Me1+1oo8L2CwkqFy
8SNu3F6St/YcwcdpE4njZVVQ637euCGFgpNawh2dxC6IPyieNV3TB+sc0a/i
Ec2QDdJKv0v0oqQzKPNpaCPuUI/5PQM42F2vd6lhbTvamvg8T7wieneXxzuR
Oxca89dt0iT6yXMwJjJ3SwF2LqRlgiKI/qR+LRt26oJ6BouS0SZ8lrVW6LpZ
h/CU48mrtYjfGnPP4BoTS66JTld6EP4Z9HXNawhEjIukyV3iDw4JSSuNGFUo
OT8kIr+LRnfjtm319XUQqFZnnnpBY1ubyZboNiYMZNZQxt1srFXadHE6rxHz
/jMVP5pLIalUWntWuxCxonsfKTEonN8W6eEUVQHfl22aar0UvKrsBid0OrGk
v/l7OmMI1gUvnynpVCJTbtU/8xgKRz3NUm4vYKHsYdsdz+4BsO5VFKg4MpGX
+I3eyORAUotrsRm7Hl9DK3tOMNgQUuD/qb8nFqXlA2mWxG+YNtJKHsOReGlx
qGIt0SuDTr6n2YQ/MyfP84WTPGc9qK30zvI+hCMW7ZtaT/w69ad8Wn0n8pfz
xnIRPxGtv6NVsbcW4ZzoYysWcSD7yCTAfWEq5KUjhf78I3kmgvvvG/FslDxV
C9d3pqE5skV0aU074Q19+GjJEIb43vipr6zDMG5VpU7SsIzVGLy4Pw4O+y5d
uz1J/E2P31CjvxR6T/b8dSD4FmAmOqx4eBrsx+IB60ieEzqioFHlk4EYRt/1
edsIfm401mfzukNkv5TYT3Ey74r1RhJ3gmH1Ydz4giiND07sb129idigoJmZ
oUBj0X/NwzdfsnBqkcBFSHCwIFrjhlliEXI31od6kvOPdcg+2M2bCl0xU1VX
QzL/DXGhiB8PsNTi+uJnBP8h16eSF35thev2264ykkOIcZI5cewwA103Xpib
q5DfL+8sGhn1w3lOpcoZMq/sNOtpgQMTOcOTqqtVORCZX/J1i0EZnPVyo7lJ
XvJdLOWh3MqCenjeunkWAxjNTDB7f74UugLfdBU9iV+M+Vxt9M/DjoVP1k3v
JPg7rhsftPstmH71F09upuHyy9T99+UuNOeO3tzl0IPyVk0UlmdCqmnU+QTR
x5xP/bt8b7Sgyz50+eUwNtR1kiQ5z/Kw9eBEgVcKjbyA20KB7lWQfdHePU30
zKXfye7rRCZMUg50x5F8NTu0/visZzVMuUzmcbWQ9/cO7FkhU4gP3QLfo+/T
SL3O2ybQ/wWqP4vHt5J9f7q+cELlVT3mmEmXR7aw8TQsfWXf+3qw9QTzLEm+
7pkvYupH+Muv2Rv55Vg/rE8wRCZrovHdreaSnxKN3v2GKjYzLUi/OZ1oh0E0
XvHIaSprhITLmTlSHDZ8N/gNH+hoxOSSVu/xvxQ0eu9s/t7diB9JJ6Ne2JA+
saxhMkKZ+JVilNX0UdI3Gqi8CrYb3sl/WGJH9F9PNqZy5mUHPNs/94ubs+Ek
m3dtzLYCFx5Z5VcepsDvNuLatYeFVUn6Biyyn8aM95IPR3ORo/Nb3s2dQs+I
z/bVg3Ew7o1/NUn8Kw7Dm8fkWGhatTVIZJaDJ4sH7Lt31OOxUJO99jcKZdKP
Cq9vYWFZTseGXmc2bCK91QxW14PxI6/0zREOzORGwhtWMHDr59/490QPD0qc
e+lh1wnf+N3trTkcVPawHKi6Ioh/dTw7ZwXpNwXZezQvn8O42ba1nYSfrw59
uXoo8ikEy1vNvaVoWBnK1Bz5wwTfveJu4QwKPuncSu0jLDyXFvWuJPg0Unyy
7YV4MfgUcr41zaURaVBkYh/LRMWnrTUjtTT4H/a8F/RlIc1gVXLaNQ5Sq//7
qDcVg0+OB33yyP+tutxVFjs1Y0DjmlP4KoLv/J404X+fSS665fn7AOlDZ+cv
80I+Nv0qutdH/Ksgd1WFb7IrfHtvfrlE+Plq+1ileXgjGAFCtXoVHExKMDKj
M95g/KZBsu8YBbF5n3wer2iHhs5gwakDFMQnA452vkjFmXZrf7UaCic3HzUP
38GC8diW1oYsGjsOinzTuP0F/gPL3+8g+Xcy9VtiNlchRj8nx7WTPlngaMwZ
t6/AC4/ROt2tFM6oGbh6eBciwch1jXYUjQc/2IEtZZ2QE9q8kleOjf3OvQsV
N7ZDyyT/XvB/HAyszrtidqYRZR9uyyeS/KEZKa47FFkCjktH0Kg/4fNDxs4i
x3xEOPaIyhN9Sb28KbS2LA5czpcb1Ii/a3v+UrExqoKO0vt1jwfIPn4zLlZM
NGKwp2Xhv80cSKweGfpHMSH75kzPWCkbPEn3ukZI/96jaXs/YDuF+XEVdfUW
TYhcY7rPMo2CdL+c0+iSGgzPDc/SvMIGf7b8nC7rJlwUv+F49xOFveraQqFm
Ibi2nlM2tYTooZWOve3+OhhqnbUPzSR9a/dJd+XaTzCK3IEOcn+j8668dLZu
gzSvZ2pE9SCCeRZ1OyjWoLW+pv1oIBshEcZqBYQvn91EtocTvbQRzVq8XLMB
D0vl330+MoD53KYZH/JrYSLon+VjTsEh+235loYy/Fa5nNVZTfB6QM5M+bgj
Hj7Jj9QheP1uY6Uik5qMIeuGleLEf3zZvwpMmVXwHfgyU6/MAWUkd/Sjfh3c
/Q+Ouh0j/YLfe47LGRaCs/VLkmMI/5d5vdmu3oaZw+vv969lw7t36LWLdws2
bE+UHl8ziLAXgZWbSH9NkXFZLHGCA2Zmmvk/1Ro4DI8NjXrTkGiy+yPxuwUf
f9uuO8LFAfdQ97H470xIxxpna/IRvJcILtylFYulhXtiNi0n92dD25pmtGBd
ruyAbBOZN+vM0o4LxXg+PZZzMo/kda4rT+fYpsGS4b3kO8G7pe7WkVrLTkwy
POhbx9l4fmnD0u6F5RCYecIbTvyzN55hOPihEL9OJTN9X9NQOOLY1eBQh4Md
b2KEzGg0q2UL222oQWfmky7zRQT/+a1qN18+Q94Zrdu7SZ7XvBWWGHrxCwRy
VEN8zlNgd1k/+jNdiwNuu0WlCJ+F4l3kfyyqQDEd9niC6D317/NkmVUpRq6u
zokl+vXncWDdMr5GJMRa+KrE09CV/qH46Q8LQfuq+Z9LDsJp6YZiRdUv2Hor
MWgJySu9dFrEcpFS1FTw63n1kTw5rq3ub1aHNf3dFx4dJs+/r0UVtrXgUJjC
vych/YifmRDpiy3CkZoarsZo0l+1lTae5avCr0a4bg0g/GvYL3A2iQWTWO03
f/oGsMDWIz7/QDpuBn8W1D9I9iFw7c/C5i7YIiPowDI2Ehyr6rnHGyBtlRHj
10GjKcs03M76C7bFnEp1J3l/yVyHkUzvOkxo3GuXKKFgV98ScDr2A5Zxye3O
JXrCJ3dLo3m2CYtcpBov13KgOdVou9SxCjL5odTS1eT7qMX7e06nIsTAIoep
SPwy4aqcsVINunSVfVYT/V6b67PoiGUzwiyLzvTmUxjyUXqwYUsWEgXX8Hw/
TePb6bBjZvot+K6Ykq8cQ2P544caAdq1KEtUeRtP/FuWYc1SCGsAf5thWq4H
uc+7NapePhEoqdCOdSF6KvwkZDcVlgC7qKHG52Vk34/D1n0xZsHf60KpVBDx
y8nKuU32hdg/Lm6WwiJ9ZUa2KuJpEXQCm2T2Ef8RN5BoonsYsMmIVv9pR0Hn
Wdr4Ftk65PE7HDaJ5cCdKdAnRtfjVbCAZp0mG0oJhavcJwthOd/ln3gw8ffJ
0FJmaB2cd/ruK3/Pht88m2dSDqV4+W6lwFqSx1jW0rWvA/PRxdm8bF0g8X+T
m1G/HV/DVTeK7Uf6Y/mc0A9i2eXYVruzYdiAgvezkI2GnpXIm3+h0OY1BUmR
XHHtlDK8j1dPNJ+goH5wd0LBpkKcXe4bJfqFQpyVvL+Y3CvMmo9tMt1OY7D9
eaWFWB1K7AR0DxO9cOozCdw43or/ZO2rogm+/weW5xTI
        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk41AsXx0cmIalUKrmhvOFehcgS+VraSF0pXhVRUolKSEiSbiTDVeFG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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs41IkXxtncUhijn21ji8JO0Y1NlHqtS1IqSbRIVkQ/FSm0SpHSpJS2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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4VesbpSIdla7cBrkpMpNURNNKJUNpEG6uCNHNFClTF0klKXMZThnL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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VX0XRSKSJETGBioZSpQpC0lIKpFSSdKkRD4popAhUlSmJmTKHBKS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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41QkXx7lRzMhrLjVSiV6U8ipGEeprlKJuulmKRsVtHyrFKGbsKhSD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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlWs41AkbxodWrM1hlVE6bCTbAeuUzSG36K22qFZUq2zJaJEyRVbkkOaV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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs8ldkXxk841EyFaqRySco1lyExbo9bE5qRLhQRhUqi4xCJGgkjNKOo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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VW8XxW+lEiWkSRIZo8xFRctQphAyVfLTgEoiKlJUSFKiQppkKBRl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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHtcjGkbntKHSKHkVA59SVOJrEjhkpatsCq0Y20n6YgYbEVKG9tGKo3d
DiObDkJM0yQ1E0lktqOmSWo6OhTf+z6vajNSFt/3fn/cv/u/+7lOz7V432GP
AE0OhxPJzv+3Tppem3b/U9SuERYXehP4BnYvD+Tcx7HMCbTHdhqnrv9wdPh4
K3qkHS+8NzHYtoY7P0VYC13ZlWmOIzRu7DvubN17D6rhWT7qpTTcNJr2VF6q
x3DoQNllLnuvv08uS7wJpTaVniOiYO/rMLqZp8Sj+t5TXUsZZCSCb1PVDOFQ
XHB/NUHHmfev5r7oBJOXoOuUxcBuYI+OhW8zStZdH3SzI9C0vyd7t64OFef8
at0YGmOhK3+1+qkC8Q7C+gtONL5dFNzk9LIGGoFbZp7MY/GbZMcfvibHAnMz
PWkrDcvwev/AEhWupAiqjXMYmKcc08o1lWF9S8ncrmU0MgThrzy3yVB+cKJp
5BIaiilnncONmiFxjdHiSFg+V2MUSWcVcA28fXLGY4Jacf5Hx38/h+9YcgrY
e7yU5WGHylIx5hn4Y5w7hXWSwa0TTRphbZBzYu9ygrSxHzuiZ3SgyKpapG/N
wLW8c/PRw23IMLOsrRkmyCJPjR3nSFF5yfB1wD8UCs+XuVTGdsFMMPGL34Z3
uOq35reoZAm+fh+Vrf+QgmKn3dWtDk/hoalhZxtHYKDdyogG5dgS/UH/pyIa
jW8CuQtfqhARXtQzQcUg0btoNO1hC+w6PUaTglk96ULtgdJnKFsV1uw7QkDW
enB6ztchI1/r7qE2GoZzE+9Kf6lBPy0WN+1n9Y5s2vaNTi3Ccv+rp7ueYHif
oOevoBJMdx42utVNYemKC1MLtVXQEbk1RVsw+G1oZC3l3QFPzkWfZgXBrnx5
slZ9I7o7Kn36DQh6Kx/3TJHlYZbW4RfLYihM3n6xRvogB4MFCxKEpygYLU5i
6sRPcJlrVceU09iojOcXPFVgFa9n9qIrBBerJQkWkxrhdtqGR20kEDxsiF3N
+vNG6ua0YyfByQ8fpKbFHcjrV0e+Pcng9/2HDmgEPUFp4zHhOMtvULH3Fw9G
gaqQCIuQNQRWtsZ9B1qfIHW5ostkgEb/HtuowbF2NN96RBneYWBvXTdvMf0Y
pgOOrtW5bN4nWHe7BNWgMCyiZVYqjU9dRcGjB1pxMLY06S1DoHyx+4vD1XqM
G9HCGCeCORv8G/XPPcOiHB439QmBeqGDfdtiJWL67s26OURQukTPy3hciTit
4kv/fCa4cdXzdeSVagRszJMtuEKDe6Ki/duIctB7xD7PX1PQTCdz2je3w/X+
/b60cYILuj2iHU4KFLg6qMOFBMUL3Ke5N3QgvUt20/0jgyCuc0iGdQ9Efac2
j/zOYGyWbsON1Q9xojN3+V47GupgznBGohTmhm81J36hcLzkM/lqcxdBkXTx
tXEKcSHVBpOVHfjP92Ve3VUMipVfjnzsvYnnZxJXS7Ip7I90p25Yt4BvQmqe
snl8tsomrsROgbrN+aG7WL4z9xwc5Vmq4ODmE0SEDKh9Tgalw+0IHioIr1IR
fPeRH/ddVAtmZ+04EXCdQNci9fz7kW6YcC0Nm7wYvOkXi/zFCkiNNvT2DRC4
9QnXSder4BkapGPTyaDCyGHh7YAuBGeeLU5wZvC1ooZJEj5HqLhmtV8Dg9i3
R3cvoU6Ay/1Um7mSwsCZSzMk4nZ82hZa51HEYJ7OuxVapfWw3x2Tf/4j62+Z
9bKLfrcwPLK+YF0eBaFclhn4pgXapul/rXjP+rVjRtwkVv8tq636psoJNn4u
Ko3PLUNCevB+jzEKTLZuVsO0FsQc9t7N6yU4NVXf1t2tCnftrAYTd9Mw8WsQ
RBAF7lmdXtadRNj/vkoW3NkLNT9Goi14BwuXcl6/fzvMY2Y0dm9l8X82E91P
9mf7tXtKvDmFo5axekd6lajYu0ksZ/FwRk7+wcu9hSPdvcPFOez75iv5tudV
4F3PfzikZJAmdV7r9HMXGjcZ3jDuZTBZ/L72bEA5+A8OCmazfceZND2v0qsM
tslfLUUTaCya1+j1w5csJJjFeo7yKairzPR+Dm1C2isNm6JdBPM4Pak6Nxvh
3eMQHredIOrXpJfiejmyjo2tzS6kMSdLsrXTRA6jYwcsJK/Z/vC6pFja3IKU
LZZayX8S/CvK09HDpBbp4esd0vQIprfe/SNMX4lM2+vuIzMZJIh2vpztfwdH
XhXZl7B6zgvSOuIZ2AKhZbPP/Fg235cj6Ux5KTbcjqgPo9h8yopsCjVVEGTb
7LvTxGD6kyGD/hWtyBN4nrZ/RCC9be0b3yZCyLlvthdIKEy/LOB8vVOHML7k
luN7GlrX7DSc7z9C9ks138ufxmm9rQ37H7fDVNvTRchnIMrkUhE7VXBRBc1U
s3k1P/iu3TG3DToVnW1MJIO/1dFSncQ2zLd4kCZOZf3+08si5LkcxsI77dEa
BJFLNP/m7a1CSKt6y6A3jf8BKSzfZQ==
        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs41AkXHqas1H5pQ5GE7a7QVUKvTc36KFFJ0oekHVvTVTxdGPcauZPY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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lVsbxsnQtBtRUSjJrEgO0enOkDGShKgMHdq0E6KjlKnsvlKRIqWE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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2lczG8XxrMkkgopStIilBbtCy5aSBSFFkVkq6Rk6R+FdkoUWqRFlCRJ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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHs41AkXRpoUMV+URF83bEmx0Wo3vEwp4WtDWRFNdJlKIluLSsK65VYR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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHlczIsaxqckLUKom1GpkEqk7cOhPKHF0sLJTZJyLQntOjXhUpYKhcjp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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lWkbPjH5TlQfpWjTyITQaDRElutYElNJWRIKLfYtRCqytCiylLFE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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHc8lf0fxo8nIzOJQpIyiiSVjJLLbKEf6kFpCAmpKEpJWkZIKqMoKTOV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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41AkbhuVQCpN0Uq1tlUpsJ1ms01Nmt9jCJHw5hERpyWFymCSqZZFI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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVGs4lAsXFaWUEJFEksKRFDEpaal0U8cnXWg+OboYFRJJoyg6Q42k1Ekq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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lekfxmlijL0oMkaoUdmitNi6T0oTyTbWaIikMKGkM9WUJTJnzJQG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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VG8bRmXPVraslSRJqKSim0glihKSkCQtlkRJJUlalEIhSSKFIhLZ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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs4lOkfxtGJQrW1GkpNOuyGsLEjkjunaLOEWoefSkUH6XIIxbJasTtR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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk3s41AkXxyVCSmxoN7RJIlEpucV+kVZvpBBZKvK6rIwi2lzjQS6VbKWI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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lPkfF5Zsa1KrrWRTjhLpdlbecuRa0UGJWkdZOTYZhUJGB1NoHNnJ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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3kglN0fxZFspYQ2Uray5lUJCYdSaZdCZWmhIiohiRcVZV680kulUlmL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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41Wkbxy1RpoVUZF8qUWpoCknnyyRcbQbRThxRURSa8zYcsqsGpXTG
nAyRJSejEIOkRNZjOceuUC/5Led1QuVNzby/94/nuv94ruu+n+t7f77fx8An
yPWUnIyMDIc5/69Vcy0p8j2tsM7oe9phSEHm4/R93/HX0F18hHLVkqB/Quia
NVuG4jTrcr0pApdXlPvYh3RD2DAS1PeFwmmD7KE3nrWw5xsFyziSEBSftV2x
5yZsrD7RR/cT+FpXcO7zf8SYu17m7VxMIeLqlkHVn9vxwZd/WOFHClLrGHqf
4jNI47efOOtHojJqyE5N3AZdc6XvR36mMLBScMPE5QWM/VmFG/NIsJS5B6ZS
X8PgUEKhxEMCK8+vqdNqVTjgt39hlxIJH5FqfmLLIIZzuUf4d2mE58pFZVrV
YCo6xIgvS0LqGqqZcLIZF5RMLuktp5D2aXRpVlYrkkPnG9NlKBRb3M1SsR+G
5tfxnS6yEjSlhhZPfqtF6WaVQXcWiRLJgYjf0nNgql9uyYkiUP9+VvlYfysW
cNisk26MfoK45wEV8bB4+pXrYEug7E1wzfERMY6/fft70zgFB/veqNDsDghi
xHpnbCmMz7/SWKA6gNBYbohNJI37J3RZi8bacO7DA1d/HQovVzkKSz3qYRRU
WDp2htHH763Noc8t4ASz/2qcJVFsxbkiNOuE+thWOW4cBY78Sk1BdDW0uzyb
p81JrM14ZLkhrgeBseVxIhkaxk819v5jXgk2m8/P+y+B4O6L3ADXfKRz6tLK
Mwjov9PeWpuQB7cgo23Btwj8VKq/I7knB55NuZ9ykwhwCFP7Z8vroGJnqEk7
kbApetiw828h0ilF8qwLhf52yVi4bh0sfVLatnBIWKssb7OrFaGT5aidSDL3
ScHrt0x04J39Y7FJDIU8tz1ckK/BV/W8prCIRrD83LwOVYmrRssUvfVJZBeY
+mg0tsL/n+ZPPkYU6k4li3nqAvB++WP8VQEB4d4jFUZVfejQZSsWN9NYPb8m
8KJpPWYMzdlymSSMLY/99WdIJyq959uLEinYhmQQYf3XwZL/rsxhN4FRQnxV
0dcZbE+X5UlrCageMvPWGhMhvigk01SOxuR01juvY3Uw7tLScmb41tfXNlRc
koM6O/+h7hgCjce2GfjHCOEhjexjOVOYVY398xrDk7nqWpZmG4lbK/U1zSbq
sEv3h1sL95NY4j5978xiPszlnlwI8iPQJpKWeH//AmwNi/O5AhKcCwrbD65o
Bkd1a0DvODPP+mPqUFIevKfmb6cnM/7THndI31iDez9qLesxYfrt8Prs0F+N
Gj9W05alJPojzHXOS0uhsu6tf1IvAV/73xaqpTD+O2abMDVIIfyhhY6c8TAq
7DeePWkswT69JU/DyoW4bvToW84UibLqHue/HwzgzE9BLSq5NMY0NopKed2Q
XjTiRT6i8M1hVp+7aQBWso/ir5jSeGny3QXx7VZMNt6/IdWmUHCqbVQ97Dk8
S4YMQ/9FQoYbvZt3ZQg+Bbe6s1wk2HnPyWMurh+aq0baHmfQ2DM4sj4jmXmf
cOnrV+Y0UnWGJftvDKLfVu2XFAUJAoP2ZnbymhFrcd+y8gsJlbyHyrs/F4GX
8s1pXS4BG98g7fe9rXB/Iz8Ua0KBN12XNhn7HPETI/EZASQKZnLlbusUotfr
SFR1DoHEq+np/3buRwzr3Ja14TSkE6/YyubdSLbmavX+SsEmlPV4u6QSwshZ
x8YlDN+T7+NKVZ9BeUE3u9iTxOi0UsKdWQGOXn/xxLeEwBdy5qZBAuNvN6rL
WYXGaEBY4eawmyiOa++OdWb2K/PtkkgogsAl8aNhA4UHaTz9GdsBDDqYeR1N
pxFh4XDqyvEhPDd1X/dRi4bT3kqRBq8e7zabhR3mMnlqd/h+/txLHLYbavJn
8i9+PfmSdbIbPuFVzYI2Jm8m0sI9I5KQxa3ZN25HIPNEQ5Fs/BAczr/f5DLM
6KnZ4Ve4IxeZ6pHJjdGMX+4iWTz2AofvGD99EEmiySoppiOwFfE6hnc/D5Pg
invWRXj1Y8Svyzx8FaMPOVlzo1mEEDsdFhs0PpjN78p364HBUv/J/DMUPPmB
q4P4PeCpi9escaOxIVF7ZtpDBF6Y1Ei6nEZLlp5MZHY3zm8wulO1kkbt4hsK
MZteQzNqfKEuR4KSmn3ZNg41CCzJWeS1jtmXheF0Ebce/B8m1GQjSJw39XNc
MPUc3fWW1bpHGJ76nNqFklaQFSsXbfpEIvAh115wUAQ1rnu0mMnXPxxye5yz
X0Ko58E5KSJR4Rx79ZJxA27Kvq13dScRIBv05JpeJ3pzli2ruEbh8qptzRtW
9GH1hNzF5p005BpSnjhG9yFYocnSZYDGaS4nUWtTAVI3q3uFM/kY1Xaw4FHN
r1C67N5X40Sg5HeDrp78FsxMupVVLaQwt33XWF9tO9ret56tP8rwVD16a+J2
J04v7dKqY/6/nvQO06nOcqxKklcKJAn8Dyu/xWk=
        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVHs41Akbna5ySWpVU0mUJMIqRZev0xYipRCpaZeQSDXablPIdaVS26jV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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs8lFkfl5Yt1eYNpY1CGqWNIZeuvpToolLYZEsokUaElHaXidyNptza
zbIl5VIZVkjjNkwuDQ3DYiQtvXRQub1JoffsH8/n+Tyf3/M553yvR9PN57C7
rIyMTDJ9/n2zda7Fhg2not0truXFaoION0bzCv8y/BC+INvVgEDG6c0tqw8C
JButi125lcAoJ7VNNT4Td3vjs+avIfjdK2HZjkohXq/n/Ye3i2DX2gjfZzdE
eL3uQJ/NToKc7FSGPaMFIxUKCaJTBJV+0+F9NQ1YvSfnt+WOBLZnJZkOjYVY
olJ9UFafzi2U0lWNyzDYGq7Ts5HAa/l7vXcHJXi09MpCXycCzwGT944ladiS
lb/kf/S8gzktPcOvGrC8tUaznc6bWpaNNah3QXrjXY55NF1vsupLWG84ZpsK
rB21CLiSoHnD2gKk5R5/r25KkLq1+XmDZQt6N8YLzUMIek8u0lHzaobZqMfR
qyyKl8f5vj9EABtBrejIJoJTh24sOB1ej27u15T2HQSv644/6y/LxJD/sdkB
yofM5lWj/PhS5Bzds+M6xcNOPXPEpq0Cmfw1ujHbKN6pd4bvj2Thz1zXZUcY
BC4Hgo/7MKpQ8sHp6RjFKxNRl6XYfxgRVQ6uXzUJAlr9ltptrUPe4splJ8z+
xedcVztHgu4konIpkoDpFD1Yc6cafTcZ3cfMCeoeRsq9MPgbcqu0hI33Kb5r
+c/19jaDOaaRZ+dBUMB+MPF5mwROSz3F3d4EPy6URnHTy7Fs4rjqkDEBf0nu
M8+BRoiWaO/uOUPA6U32/zG4E3zGb33yUQSbFNcwVngLwJA5FTtI9X3QRTqz
SgUYsw79JEv5MZcdzeAEiTF8WPjmhD1BOJc7q9JfhJnlLJt0QwINpo+FQCcJ
8fe/FxpT/VgSUfa+4hqM7frWgFB/LamM7ecPtMFE/9DROWkE7pWbX+PVCwyr
p7toHCJwjLpz76mVGPMs2eYrfCifOVqVeWfuY668w6kTlM9PRTWLBzPKYDlT
enLjZoIbX+Z7xu0ph8H+YnYJ3V8xZiejiNuEeSO5RaOeBHGunHK3tHoUHp+8
c+sAwUSY69dtPwkwK3uQVU/x/ak99MHRogOh5znSGB5BYuPSnwcmn0M3o/7O
JPVbgNVZ7a2RXbjg7xoXWUVgbxGhuoL7DI52Yba+e+h6Hb0xq7d0YGfO4+ze
S3Ru3yi6VN0Al7em/flHCSJ0PrR0jTSD9XFU1O1F/fAXZ9qv5gW2t8YsfXOQ
IEtTNJ//sgganzhsbyYBY3srk/VzM9Lyu143BFA+n3i751uXw34q45w59Rdf
rvRSinc9/LhfEziUf71/uJ+u2RbBxVb+L3U9AlGA7Hn2bD1EVRfloqlfVFVX
lrboZaHcNOT2P5S/0PHsvcotEgxGJk4PnSSoubwy3zanBbzt7zIs2bQfIhs9
OTNNSHN8b7KP4q++opF8IakKXIPDYh3q31MPR+8b99RAt9jS6AdrAh65yNTV
eoCY4c1PVtH1JfIbmp4rVkPhofvv77cQvOl4FxzMacaxeucv1rY0z2/3TnUy
xNgSvHB8E91fw2e8wLX/GkI2RnS20fyOrrjo9qizGuyiTUkXaf7amaeTvlkr
QcwfIUPpv9A83k/1sNd7Av71g5eVaP6U/SQnyqoFeHP7hG+1Bc2XR7apP9KQ
nVlw8qM2gc3aV3eVvStRM1eZM0z9/8uHb3UmVtSh9oxw//RhgjVHx2aHXJqQ
2xt9r2039evdkXXZYQ3Q7U2w5tFvTw9zcdDUTSQqmK1Ko34e3lP7NG23FCk+
DfYDxZSPwUfLnxa04oH9hvwNcVQftfjUr0qV4LksWKdE/Tii8Sc7Va0Lbifb
vJ2v035iX2jUGilBjmnB1CaqF3Nx5fawmWIovpD9W0r/j3lQedfvoRhe1sGF
4Q4EHgkxfgdrO6E3ebpgLI/2sc7NMT/nZoQohkptL1P/Rnx3bI5qApR/5/XM
Uv54oQeyZ16W4rs5jTvcaL+/Ua6fShFUQEHBZaMGxZ9Yoja+JaYd5ZaZG87R
/mTV9a49kCYE69Z42zNLiqdyw652/RYEReX/vOgKQZRpkmXiUC3URV+uqFG+
HBu81QZWdaLTY/4FXiHtB/WrKR6JxbjZfoP1eR1Bicevb03MypCkMjHhT/Xh
xo/GHit+jPiVAcZvdel5bzjbLP18D7KBOS8jaJ/6qmS8lT4UgVlapMt0J5DW
pY9GsyWwl8vNd6b5EddbftzUlYR+tzwVL8r/+fU2yRPBUpirpNnVFBD4a/mY
te8TQ2G/v7vAmfrDEprfGEbjSe5CXjrlY79aaM8Bdgcq89okURwCE0PmeGyE
BMIvRh6E9p/M8UUBXREVKBnYsHcHzVemnbYPr6oRp0JL+Ym0j4Ssi8E9xlww
rT3nqtP9p/km5/Jkpbh9y8J3hvbvSPoax5BbfGyZ/IUfS/ULUD82LR/diqRd
CRcVkgl6zjTYWA+JkZWjmfgH5U9sZbZk/plGaG+WkVe3IZjcZcBSV2pGgdLk
9dOBBGarH3rKsirwkRNY1UvztrtTtu96Zi2Sbp8W9dM821o+/vr8SjdE8vv+
OldGoMJaoKkWXQrhPrZX4XrKr7vFdL6XEFkv7uSl7af39cdxweZGKc73BRpE
UT3jIlvlb0+3oSLIYKKT+vU3/Z+mn4YJse3J9vGZvTSP3zmUaZvchVzE9Pd8
qs/bqad+Ktcf42xhkOEs1VfxrJOJlaEQonK1sn20/37N6PcLov4/rBpvN5/2
W+sidTUjaTfk7FbKcIbofoHO2/ZekUL+6n1lnxICN0zpt/7wN4rWR0oiqd5i
Rsqa2EAR5uVebaig/azfoNX/35QOOIqTGcI/6Hydw7lH2yV47LPaiH+WwEpU
rtSRJIbqjzvUuvwIbtae6+B6tSGpKeVsKdXXPq4w+fKtJnwyDREO076Rec2T
LLDOwGUXJ5942gez97YyrYWt0Dc2HHOg+vh2HSIjc/kQnQ4LH6Z5+WRV09dJ
BKj5qPOgjd4PLUaBG8+PS8AKDrjcRfvxQpmw5ohjO3Z+tnMLpf38f8hdxnc=

        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k0VW0fJSpFmqSSFFESUWSotGVKRJHCW4akSZShQaVCZZ5FvUiUCOE1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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81PsaxycRaRM6behUikqIQutnIqFTQkp1XtdJGWlSiRzqproSmhzM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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs81IkaxgfZhhQ6VEfkktun1cV20aZ6kFWuRbJIckkiVhNOxHRBWeEk
ZW0ll3EpsqpTqHUbMsK4DsYYs9tcfr+Z0ZUuqBPOnD/ez/vX+8f7vM/3eY1D
YrzClCkUSoKi/t9rPCkbY34dgnFKPCc3RQLnmtZlo+Mj0G7zPlseSCBAd0LD
4OdWZKi0b3N+IEWCZK2Vc30/YiiG02olJLa3rKC7zQzjJM2rrGOxBGWDGrcY
Tj0YvugiKXYj8Sat3P9S0Cj+rl/Trd4uwhWPnU9vOnBxLvbc+rAFCYxepkQa
kxVQzhzS6vy3HF8fHxSZVg/iU+zPl1aFkZh2oBeFdg/hpmmO7G0GCUq/NGjs
dDOMBGmjG5NkiCumMWh1fVhqEE7EWEpxQZ5xfVn4bSgzq/T6OuTY/n7FtJHZ
U3hy6qNqX8twS8m36K4NF8ybYTHPTxMI3fCKaZXPhtf7haTAfMW8ZXdF0h8c
WKYnLo3+hQR/vWCgMvMJIrmPHqvZyKFzPLHiI70Dgs4Pr5SspBhtcnlaXcZH
o4rbLmG2CEGMRKu359nYQ9UPP8sgIbTPaZK+yYR/qF/wwa9yFB6WaZ7NGsfI
UtzN1hajzHhWKD3cC00WNelDGoni2y2NfpV3cEPD291vSI5QVxpGFwag1nih
+0cegQ/bLFycg5pgYd7amEeXIXe/47I+9TYM6WuFuOySgXpGzhucH4Fp0o7k
PSZimL5snlbObofhyKaQ7mYpep662nfbMOHwzWOXk7UMk35tF1UPlWC5XEDV
bJOjujrpyEw6F9PilPb/BopB2RebNLPvB/h2k9rbjSfw7Z7OmvQnnfBPSO/c
4SCFb5AGR0V7GJusybIn78VolqSzpUvakffx1Zd7iTLcy77c+rqEi/Igr93h
q0m4rKkseLj+OsZUpKlHX8uxKOL5zPwZJgIW6l0368kQeaOyeU5pAFe0Xqyr
6yYQXDvSsCdzGJaRPz49sonETke7yxsEPZiU9K74J1WKRolvVsXdIRT/2bRo
SFmC33xWGQubOSg2n+VSgwlcMKrIZzi04VjQzJvOeSkWOGcE/up8BDKLet9J
RNBhI2yU2gRvimEVX6Gfk0PTbN15DhxiYr3PsQjcyjDqj/XgIbpvo369BYEt
YT7n5zqH8O2wq874JwK+erQnE50vID7jqNmg0FflobQg3IWDl8OTLKGnBB0p
tbpLLFi4NqNkH7tFBnWbcx/9n43iRnwEZcl1At9Fm1fM3uMhQnAso+SKCBq1
J3JOh7Dg3V63/PtgKYIyV4t6kIucSzHjFwk5XJJuz13tFeCDVE/gpy+EnVlV
4FrVXly2POARvJ1EboSf+5ZrHPT9UulEy5bAN4bVpT3VBsNrTh1f0hX38i8w
3zg9ggm3hC/3UwjYvdh8Z0TOxqNV7qe5Pgq+iFfGrkv5kISa1ajpE9C0n4tb
Zz2MEKpq9GcTCQQb7ujef86Hg+45XVUTIYq7aC7ZN3vhuNuo0nGKwCklml/t
/kF8TTs1oywmoVxRN6NTOYiXWZMt1f4k7s0Ff/K804ieG3vaSusU/sioWtxF
UeTDcn3+Y3cxjkX8i3dS7xk2s94fi1suh3HiWmcz21Ec4BWRS/cS2LfcviGq
ehyLojS3UruEsNxhopJZxEXb+/6d8VvFSFUPzJhEL9iM6NkwqSK/pnIui1Nb
waq9xDig4EXdeljATOKh4qdnEf9IFuG3b8Tc91QWEkfoZiLF/W+Nd5jCbRAe
fPGAehmJHWbFNn+wG6HMCLCJTJDBams4dWJvO9yOH9HVWilD1N/072w/8uBX
+Dmq4JgIdcL/FLqd70dLn62V60YSB5etqbbJHcW89v6rAUUEmFfd1yYcakSU
1tzoriMyLE5Opif+2oUapwemar1SsJScfr/y7Dl2Oou77KxkGDNgZL4TDYCT
d75lPlmxT8TJRwb5Lch6O0w3TFHwezyRlh83BtM0/XIfaxGMSj/0EIuY0PHq
rd17VAaXh7To6dRB3CrI5Z5YTeDP+gzNA8xW2D3kp1gr9uUurDjZEjIE+lEv
g4jPCn9nKz+Ij3sBzXHpKvYPUgQMFybg2iDY4xln7axJBA2XLntx/zYa/GTj
h9hyCL3aJn9XHUapbenebZNi6NtcWNl1kKfIzb79pRYiFMynpfmXjiEv1XH8
4ZgQdFaLIzXnOQ4c7/NpiJWBsrvgVZxfKfiqvMrIcjmqVnq+2W4yiC2ymnKu
FoGs4tsNnnI+trW6VPIV/0k4nepR3FSD7LXrAvYclEOr4As9xOABTsG7Uv+y
HDsZJrk08z4cvalWFS9U8J/nnC31fATG7GrmlJscfYu9T+3KH4DtjO2p0FIC
UU6OhSfq2NBzP54acoeEj17KFG9LK7hktO3ZZBmM5IFz1hb1cDtToGH+lwwX
NBItS3afRFZ8fcjgygmoF5p0PVnTg1X7f+LYTin4MTW0N/jcgJHVbPfFh2Xo
sTfIPu2UAZ2UgJIEygTevev/S20bB4K871KvXyXxP4otxNc=
        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs41GkbnuXb6KCirkk2KjZNsnKoVsXcaiSVSpTIITm0VlZymE8RyQiF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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c81f0bxoWMspoaUlQoiqcyKnWRlCIhyoMyMisjoyhKisoKKcIvSgPJ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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41QkXlmSMUFGZFNFeKI2i0nhtbZq03Uo3YYg7thBF4suIMsp2JzN8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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVHk41IsaHnNKQirK2u1OUTxRHFFZ6rWkVQyVZMkhS50jpc2cGoo2lNCC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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4VekbPenEDJkxRoh+yCW5VChSmRaRUR3XOpp0V45rLkWKNEedFErK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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4lGsfRkiiRFmzVLYi0iJF7sKpFLIfaUOUPakkp4WSIiFbQkVJSXzZ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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81GsbxkcJh0Q1ee1LyrG0SNJy1MVRjFKKc6IoGk22SF4lS5020sFg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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk41AsXxyVZQrdcT8iSkXu1XI3qhpbbV5eKbqls9ZBiohoisqTervCm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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk81Okfn9WPnytFRVJtIqsJG9oalLdQIaVjKulUSOWKWkdlUFZkqFVu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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2kglGsbFqXSORJZkiShTSVJqOOS0CYJ4UTSIVREJW1IlkJpQRIqW5Rs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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs41AkXx+VSltKuWuk+LhWivCpS6svo7bIkhLKlhkhtKsktbWqRTYkk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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk41Isax0VJZI1GUZajsidFdaKvtB8tWuiGkpGyZClKRLYzkWurY5hu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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs0lGkcnlTSHkkmUilFoiSTLVKmh6KIRUTEtoS2iyki17aUmkEuEyep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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8VWsbxlE6pQxJAxlTlKlJqORykKGkkhTpJJUmiQZjCcmclAgZM4+l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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81QkXxildu5SlUHoTDbJrhmwP6vVSpJHUSEabELoZM6UmpE2LvQhZ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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41AsXx4dQ7lvSptLEUImyhaJe+Y4suUioq1KELKWUvJrGRUqKFnuX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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVmk4lVsYPVKhNHBVGoRCp0JCyLQOuYokcYkiNNIgoUTHSRpMDSKcUuRm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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k4lG0UplQqIW2KRCGFTFmS1K2SVMqSbJUUKkokSnZZSkn4WilJEors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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk01YsWx/GQkBQq0TVEV4YMlSfTF42oVxcNwumkFClNnItMkToNuqYK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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlH041IkWx11SUivTi7rlulaUSjcyN2T5jpJEtSVsUd5aare9uOUtVGYk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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk41VkYJsskTdFiyUiFiOKKsky8dpUlLVqobCkZKUyRjG6GmmTJEkpK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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8le0b13jVG0laSKG8kYTGa6YvmQ1eJKmQUVpEVkIaIkkSMgpJdpIK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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlWs4lIkbxhEl24pllxSJ6bRJ0iQbuZVd1CoSKkVEaE3FpoOUv1KymlpS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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGs81IkaxyXlUimVJboo5ZLLKrQzYX8JpTGh2S50kSwdFZVdIjllShYr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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lVsX1lEdokEj1b2iQkTqqgw3D5WhPhGfIVEKyZSIOKlEUhJRJFFu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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8le8bx6WFikppUaKMkiSVlY9QKUSS0RAaRCKhYaRIRVnF14pC0UJW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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41AsXZkxS9yI3W2lRTW5UkpJC3qkoSpKQInXVSF+ihxYUXVHhk8oS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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGs0lIkDxhE1XVT6/7u4lIRSjS4UauWRWEpb2GojVmzkFtKutEkc1qUL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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8ldkbN0khTSotSNaQJJUtyVdXSQbXqCvlRwkliUYYZV9+0iaRm0pI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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3dYTX8Dj4ZEg0ihXUJJRKXwCUmoJEnSUmhpGSEhaamkpSWVFG3RkOSn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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs41GkbxydpEh201KKEUNOuonMU3xSRWkmSLb2hbCSHYpcmnaaDiOjg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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGs41Akbxh26nNvVyaHNhCaVECovkttWDhXpzaFspXKxSSpkhUWkJBu9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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk41Gsbx+WVSjmUojoldLJkCeEoyzdJaTk6DTIpS6QRUYmyFV0iIjol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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8ld8ft/JVUZIoK0nZQpFS3pIUKQ0ZJbQloWVlFJJESRFFVEKRrZAy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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs41NsariEkHUWFilxiV4SoRLVfodJzkFs2oqRiKGJ3VZwh9s7t2TWU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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk01IsDxccvhCQV78n2SnilsVVahDtKZVBJ6JW19RSZFKkYvUhe+dnC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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVWk4lVsYlXTT7OJeKuGa0mCIMkUrGpCpkMyVMpWiiSiZKdwyEwkliZIy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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VWsbxsmQkFDklBxKpVJJZnJrlohwpEIRIXEqZEqEJGToREKSJmkb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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk4lAsXn6TuID63m6XF0PLdNOSWZIt+lqTHTYnStSWllbJUN0qyFN+t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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGs4lAkbx6dIr41EaUsO6wq79OqwpVVb/nIIraXoYJVDlBRRSemgiERF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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekbPqPG2tRpRibCGJXkWMeSRHeWGJJETCKJyTJC2qaUrEn4TbRg
MJbJjHUQJXJsOcZ+OpzDySEkyTvJZEaihd87f3zXd73X+37vcz/3c9/P833t
HeJ0TIzBYKTS5793sq1n2aJEF96adX730oOAeSQ9u2i0D0wVP730iwSCChG3
9/QglhX+NgyrJzCYY5z3SWvG2j832h4yISj8K30iwn8ErCOhuwYXCU74norb
z7+B+ZzhN64bCbK8H/9x27YQf5m9UJnaQtD++pB6zisOrBR04g7ZEuz6uE8U
1duIZLXu0bVGBAy3rLsnE4VYo8vd3vgDQdiaQLH2KQ4Cb+dvqNxO4HTXqNA0
h4cMTvRLRU+C79UU88rNHyPMw+7V3fMEuVcLZYSxP1O87m8e0fghVxAkmdSL
hsyycO3jBE150YoZWxph9uqXz67rErwLzP/RaQMfBszFSpcggl/ntd6YBzZg
JcN51QEDAq+GeIO2z9OhmFoVo0Pv81roMHTXbwTDLmpklOJxDMmU83DswWmP
0ZeSRyn+mOC0oI0JKFjsyS9RJVC45ysrHTuMn2xiozzqaD7mYQ4umx4izGCE
I2VMUJEh+IQZNQCF6Qwfh9sEvOKd5ytMnmAxMFCSPUggiebuGyIRkheV+5Xa
CcbW/9F7UZ2D+Ndzby5aE0TaHZWe+LIIlrM+Dy0pv00ezlfm19yA9NLFuXEa
f6LGqX6jixD/nvlQQ36n38fo+JqL2NgkTHcRbiM49LoiUUf5LnT8ZpkvtxLE
7454nvhVO9hdtcYMWp8K1wv6nzoOQRR9teQ9j2DB5LGigkErClLLvwz+lsA0
yEPKupSLFzYs13gHgmHrjGqm/iAEvNeX110i8N82bLldtwgi9atrotQIknd7
r3PVLcX2vTnqeTSe+qroBL3INjhYtxluMyNoZT3gyVfUoGo4zW9Zm4AbGjg7
riEE86N4445Aym+ph2+Teyump7uKf7Mn0PXOCo/6tAQNzjvWX1cneJDdv/C0
rw8D/6qaz1E9lBp+ULa/9RDfzxT5eFK+d13dohBB18dky6w7zAlUnk3eVZIU
YO3WoJSiFLq/aHz9eCoPeuVps0ZnCDzUdPbOcYfQE3qGv7mH6llKgrFZdQBx
y14yRnkE9uma4/KJ98D7VSJRnOqJpy/WbXbpIfRWhtuds6R6D0qxWblQBEEE
p76T5j9mob2fsacMI8+fcrsp3plsh+Yctz6s/lF1ZfsRWr8NBsFdT+9A3Mlx
N5Py8078WvjiuX7Esmv0y1Mpf+XMtbYHq1G9uP1yix7l7/3T636sZpyb7+Rd
ovl0G9bn3lt6DP6RhremuQTsbxz8fSKLUBx0bbc7jc9meTU+cxyElspAwqUk
iu/vkGDO4UEUXHa+eZDq8/RZXX/uUB+G84xkhBEEna+WVJhaT5DLe2BdVUOQ
FCASTwhpArOyzrGe+j/S+eid0JxHsN9yhJtI/RqvM5NZ5D6A6tuuurW/UP2y
ZjQGdUXYF/SBvaKV8qNypz52tgtjX1+Izab5xi5xTDebDwLVjiNNbFqvgqYE
Gds23KiJT74BWu8Ux/X9qenYwdXUP0f9x6n6stTxQBsOiPpy+3YRVNZ2nTkl
xUWNXrpK1F56fo3O+633O9EQcNP+zB7aD5a6At6Xd8BCZJGWb0Vgkmmxukul
D7q3Yvfan6N49i3LBUyUo2ShSOwWrYds4mrRhRoh/tlksXouh0DqZ92DrBPD
sNxTmKmdSFD8vdT8+fEnMC15qSQhJAh/FvdAdnQY/ayY61nUvwe/tZwJ8L6H
oz9m3ddgUTwaPpPGynl4ZBPtP0Dx+xZqXc7240Cic/rACor/A0fkVruuEzOL
9jA5TJChdtbq4hQP5x6Yvy53pXoUzLbVjtTj7fG47lIdAmmXJ3kWFzqwyy+3
uI/y87ZIzrvqk8e4ojfBjkgj2HM7yS5pVR/anecyW7zp/r2549kTffghTXvU
5yxBXF15Ypf6IL5yVyJyZVTfgWpB+9w7IMcu155zo/5lyBy03CZElLO+rDjt
Fzf35SU6abbhel6uXrcpgc3Wn+SXBSLMFqR0ba0muGDkamQo04+yQYlPPKnf
eaXP54YkOrC7+4WrIb1vqXdSMFI9gEPhC+7BGdRv62PqRc95KKjfMZRJ8XCL
Ltdv7X0MeYkg7RK6f9Fpjb5DQBvCQp9+yLKhfvC9mVS8sQV7d7O/caP9SnSt
UkLdho32gJNF1VT/3+iN9TCP8CGv2dw7Q+dVU3Qjix1fCTlpFQ1dDarPBdbC
jj+akPGLisDA7L/+nNi9pywWqRXSQddof2w3Nd/lu64VWbVJQh87ggOKscZ6
b/nIT27fkB1O0JXtfud/03ysULBscjpIYDxUY3t4th9yKsv3XwUTJIaO/pnC
5OOjk9cm/TBar29rrAtCkzGuLJE1Re+/u/K7FyH7u3FpVZUpZz+Bco3NPxPH
+bDwURryv0xgNRDyRFmpCu4/JBz7gupPoBWsVbd+ANo87WRNyn9ymd9Yji8P
S53OZqE0/iVVpY+fu/KRbhw2cdaLzuuSckaBVQp27uyTUqT6soqbZfq7CTCh
mv3VHjrv+Ic3q3pGCCArWdx67ARB/vjPPpNpPcgdbWixOkb1UGqhssDlIywn
oc7qFMGftXdOicUIUVO2fzKkkvankAqhkyEPk490In5yIdDUPeT6Tq0d3n45
q45ZUL50G5pZv7dCu2zTbzvpPBrj142lS2eAU3ejppHiadpm515hlkl17OYy
Tde5w6dvKbRwccvpAes89WthZMzKk+EVcDoT/2yczi/JRPYVK0k+fvdZnnKO
JJhq+Vqt/+NDjMiwlg/vpP5S2f5iVaYAvtqDgyXXCE7az/xdtpeHgb82iE3T
+T32TsbLc0UH7Iz7lEf/6x//mHyh+uQWZI3Ypw/T+I4nHmV9FOdiS350kIDq
MzKsoVApuxmMWebVCHreSt54x3l2OzQKozXf0XpNfUbuy883Y75BUyyK/g8k
9RzYvKJEhIRftbWyWih+oeTxyaZKzFqiSVGL5mtSIXXH8wJkRR9OadL6/x93
36rC
        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHc8lf0fxpXKSEZDkkpG8bSoqISLjEhGSCplJEpIkQgPIkkaRmWFR1LK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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs41AkXx+fNbCs2StlKE5Uit5KN4qm+uuwQTe6KkC3lslZhFJJGqVWv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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk3s01AkfxjUKafJGKrUKFZGRaiWUntatV0mbaqhVVCS0uey+uZSysnJr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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk41PkfH5v91ZJdV02r7Doqi5wplHpJqc38cqyjQ86SXLFy5WjVUpat
FNFPctOQSpkRQ4Uw7nOYGakkj/roMCSbdtXvs3/M833m+T7f1/v9eV0fde/g
X3y+YjAYGfT37zPPcqGgVlYIHxVJ8HQBwatzmpXnlz5CNqOtd/cOgvOWHQpk
VgA//KE6dZjA0PKVo7CqCCm+S5XV1xJwRkYXbW7gojN3teEvugRO1vYk+IgQ
FtxQXalCgtgr6VunXPpRElcv7N9LoNMivf+zgwAV4Va5ba4E4bkBVrvGRcjP
t7WsjSGo8Cyq5Lxng93zvcwCxVc2SIDvoS60yPBYsT4E9ouyJ/BrNXI6I6dP
6dN5Pp0389J48EhY8vs9Y4KEU8Vdqo+7UX269rqtJ0FRsdgoQK4bl5t5/Rsd
CSzjGyf7+fkY1/oxwWg1wZKxrOhj5V3ouLr5YwbFFypxrW3ec+C47Z+aVoqv
/HpGuHtxD1QLc9gc+p6xZzr8tW4/nkbUWpw9QvEOx7b7sYVQidzfOX2VoL7m
k50aMxuM9Ru5MhSfk5FwQODHxexfmTc+ULzlv/3PXPX5IJQ/dkyrXCIo+/78
WofIJ7jlGPN03TOCEM+TBrfcHuKo5Trpe+YEV/7SeFXoXYH2sdIXy3UIIs0e
Z/pqd2LmieT4tzZ0nyf+qrLrfXFnbONZWQ2C4dyRTyfODOLIq4AixTQCM7eQ
bTJybbi9hSE2dyZYOk3OLLITQH6U82hvCNXTrvrKtggh5hTTv4oJI3h/uzQx
JvwptvoX8IM+EETtbnLf3jWIijbRCjb1x6KY313nKtvAs/GLvwDKdxVRdy7o
gLMm648gii89oPrAMqAVGcLuU307CSSNxsf5E7VgZxT+lmtKkKOx4fD6c4OI
2NvCf19C+er6S8//hBh1Hqa5j8oInTu34CgrxoMdBZ4jPILnag2yJ6L7EBKd
NB68h6C8P0CGpSqGooFKiUUK5SOHZ3pJqh/JK6/dlQ4l+Hi2M/9C6nWwvjkX
6bKGoOTel/1mH0dgIKett+wewUyqj3tK6SCK3ezW81IJ4vtKpEbtbkP/Vcem
Eeo3w7dZM9++rYNXXW25kRnV13Ig8AZXiJ0zvd85lVJ/Fj259vVECQznuNln
KL7I8M1okP4wDAfXpUc3EVy6EJAWoXgfjeESzTt6BHqbmQ59ak2Y8mTcSdhA
MLrYU72ysBQxyU3OIvp93KmBpB7lxwgLFfmpxBNY2B88lsDlw6UvSz71Z4KD
Dx1OBvo0ovuM93+ttxHkrjIYyVrZDMWAtXY1u6hfI4YbOm2GcCigK/FDEEFo
J7f8Y9EwyMuJ2153COamn12KFA0hZ2hL6tkIet753A8svVsIxNfMAG2CpLnm
rujZQnw3lWIsRfexn3nzp9uzLjy4aeKv60IQpquRkmzHRxjvBtOWRf1m1F22
yEGET9zrZSM3qT8TmJK8H+/jncettMU0f2ZJBXbLjO/g9Nqvhooo/srTu478
uVKM2Z0L6WY03wJb+YLfW3txxPnovn5/6sfOWn0Lg8eI+HVHIyfjX//wxllX
B6B+qufQ3Sj637awVy+sH6UzNT4RpwkCDVVWViUPQ7GuxI7fSrBKxsOqYawA
P3mZz96leSu67z36zGgQ6cXybe15NH9v9lZy7rcj2UaoIUf9M9ZocEphSwNi
HV6f7zKheqwweLh2YgBuKppLbiYSpKpNMSod+dB5MV6eSfk+fDJs/0hnHzIq
ziadofu3BjFnJIFVkBS47zajeQ476uof3NyHZJc8wZ1wAuPUR1E29HyaKpO/
KdA8HVzwT7dXFWCTUuznQ+fpPO3Vru7jIVDuUFujRPM6qvHNNdMrZdjoGqyQ
TPk3fDekqVXEg0TjUMZz6pf4b2UyJJPF2Bl9UceXvmek7thkekEM91Cn7Ibr
lM/w3qrnzl2Y2/5uybQXAW9ZS+CSKSHWnr+0Qv8WQZd1ZZvfvAhJFxFSS/vp
cJ+8rZtVD3QTv+Rw/Ajmh3m9qwb6UeG+TkqN8ru0bKpuj6IQTuc25JrnEmTd
2Mpy2s6Bvcdixyzq57ooo4Pe+l2wLCzBNicCNQvZsnlWIzyCvLJDKF/vPvsW
m7Pr4WIgaRdTft207He0GAvRNytvqkj9XcW0rtm9ToAfvcc+lydRvFVKvgW6
IpjE/cwV0HyuiHvovb64Gp+ZC3Um62leJyWXry0XI6HF1eFCJsHAmeWbkw4O
g1XKNFSneuVd9+nVVuaDzfycqkTnr3JU4R5wr8eCwqXLZkYE+9T1orRjmuDi
+3rgwBaCftNlGldM+qEjv/SPf/Xal35XkEYaaK4abBQ2Ehx1rgo16W7Eob4Y
2yUUb9/KfKexlHrETovqpOg+iUl/mxgEiTC1PFZpXTr1v2uTLLn3AGbdOio8
qhfDrMcof88+BP+nPIpB9Y090b63MbAVWqXbFJztCS6yOqO++9KMvBrfLQG0
Hzcfy9LekziI0Po1pdpUn6H5doELg4/Fqg3t81bUX/HTl7vPVcKGe3Eqjt6v
Rw/uGnp8j43YVp5cB/XDn83P2Wt+GkJDpuPHLPr9XfvQQD9eL6qVK7QUqD6p
Tf/RcmzsQHbd1QUJnS+oWPp1/eJWNEv7vbxK+9v+ov4Kx0AR3ok8H2yopvsq
J5iz3XrQd/JWMe8X2qf/ZHiOxvFh9/dTwSjlb1Pjgasbd7XBuzogLYTepw+D
tCusZ0Xg2BRlb6L+rjf9skhR9iZ2TbRnzv1E83jbzSBSpxVKx+2l3tH58+Zv
1uQptWM2vyLBh86XNmb5VCVXIz7dc1UgzZObgmUGY2YYUVbHTtbU0f5VjWE/
Oc6H9LOx8he0DzvHvcLGJXz06nn5tGwmOFbEz7k5ch0aPzC3fqL9zTzQpf/2
Rh+m5JxeGtHzvx6TTxOLBWBbyM29oved9FuNl5OXBTAsa2Ba0X0T9VZznnwj
xBrNiYHt1I87ylM0n/rehXVY/K8TWgQHnuVaRn8vxg+H979o5lA+2JmPPEx6
YGlmmWwVTPuWNb9boVWM7S8mB/Iv0n7QJoX/9AixKTZu3+Rxgv8Dx96zQg==

        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8le0bJxKJJOK1UkYkUaRBvkLDyKhQaEpJJSFpmCUqSeXVeK1EUhnJ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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk81ekex11LyZbKlqap7EmyVOM2mY9sV4XBSDL3otGiUoyQXGTKkntM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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHlYzIkDxlNU7NoOldSEtkyFJ4TED+8oKbJKutOpDWOQ6NhpEApLd7pT
OlylU7aD7FAx07FNNdNUhpqZ78x8kWNbEdnafn+8z/vv532e932Ng4+7/qqs
pKQUPaP/uw7VIjjncz+krqPuGY+lUDJ8coX+6SEsk/xP63AUGN3Mb3C+V42P
+vSquE0kwoim7N1ThfhLVVw/3EBCOOfVK/tZIkS3mBTpj0vRwJ66/GJ9EyIH
8lK2PVeAJ/1csUG3Fh6m7osZy0hYujL3Tar3wPvqbYa0SIY9cX7jyglCXBhu
FFpekECVM3e9NqMV/cNf2JdsFeA2jFN5tQOg2czRcimTILa5YrbCOALODh/C
Fmm/Bsf0J98oqhDY2347Zz+BWIHszcKP11G2bqWfXTcJc7vww3ZlAyir6Qg/
uY9AoO/kQRPdLDD9GoffSkgkM67adY7yEeT74ETmMQL6S3a1nxt5jhM7f5+n
9VAGvUVml0r62mHrr3zm4mY5HoVE9NbRSxAqFN0LuUMiE5eyiSohHi9xm0MI
xAg5onVry2kuRE3XVr4pl6Nlv2qkzWAHvuX8b5nNVwKM5QsK6zdVYzo2LY0d
SsKmO/try/c6DC27oV5mTSLwu0Zktt55pK+wp9XNeQ03miYrm9WKU7MMRMiT
Y8JR8o9gqg2O7xXn+9QVeKVZtevqNB/doXPb0y2l2Nn0gL7mugA/DWj705cT
sLkZX3ijrRbBq9bouhqSYDsx3ansIYz3fWF06Y5g5Cz9h3lGIjgdfO2RrSZB
SryNyUvTWtge8LjcuZ8ETZ/lYKCcD9cHwx5m7STaDW7WtQT1wevg0i20w1L0
nvpGzbsrgHGVhbQxhsB381yVgs29sAqa/ccFRxk6/TKsj4z342M5l1O9QALH
x6kqzDoBJiZ5Hr6rJLjnk7BRhSGAftYBw266BB1Xt3uvffsC45Ths1nPZvpo
3OXgoJWDx0Z3k6ZfknBMoyaEvqhHQ/pf9nvaFHDxbjhJM7mP9/bpsqXzSJiW
N/WEWnXBnGWSsNVcBq83c89pK5XhTIJ6zPNkEjv3sj1d9AZxQpjKHtOXQNPp
3c9dJ1Nx7U+aKv1vEq2zVtN5AQP4t8bm97keBCRR1TQDrX5YUuv17n8kwE8X
FaRS+PCaw22doBNIGD9szKoVoCzzmU9xPoHKVObnsdxeVGcFCpytZUg8b+Fy
zEeEsNNNNTXOUgTa5qVv5D2C3dGwu5DP8Lu3l2wey8NNn2iztD4Su6IXJK3L
qYRB/cNvZtEk3KxSBKPcQVhrdxjv1hNDfeMW7s3CZ8he4ak1f1oG1m1KxtZB
IXbBwjexeIZXNaDyUFcbFlc0LtRQU+DZuA7NwYIPxT+tfkEbpLjXI7S9c5GD
lQZZOlci5FDanfJRb5ETdlyplOcteY3vyWvaKrYNIvPsCg/37hEc2rc7P1Eh
RLxuupF9rhj31l6iHu3kYSoypOXybDlOJVZs9aqpQbeDZJnRKhKLh46vpIRx
cG2RBZP5swKfhts4SpMD2HVgv0OrjRi62wv2Lf6BD/ahzhV7OwhwlPtv5saL
wJRMHPnKGsZSK+qPEmYz6BEWOV0z+4+daAym1Ofh6dtOdcozEmrPj+fXNwsh
uqaHg1VSZHuHVBZ9qIOVGjfq0FsFGqLSpnx0G7BVs8GjS6hA4fdbkoztXAQa
FrSEimSYpeblGbdWgHauSkKjFYFbsTrlKUs7QIYfszubKsNAOTVm24leBG8Y
C4oKkGKk5OvR9Vc6QZqraKTWEKC5W7eUlvQh0Vtth/sTKbbrJzqMRTUicpLx
G6tAAZt1EYKemoeYV3KkI5angA6fVWs20QvnJI2s5j0yuOWeMDC81A3KfdLn
g64cppXbvE8VdMLTcr5lo5IMJb+46N7ZyIMX97p6EiHD+76hAMtf+BidLv3g
NvNPudSg0vzhIYTvKaYs0CAQreGnee4FH4LSLfyXbjIoLbzstDZzAMw3lXF/
F4nRxdVLOPjrEKYeWfsc2CJF7PrQ7aQ+G+/Y/5qXsBSIDuz2FAW0wnTU30E1
R46Mp3oFceX9oLE3ZCsKJNA3Gp23J/4Jduwslpv4KvCe+e5c/G8CdFZf6A3b
JAEninkm+pwIURcjqHXmIyiyO7ZKx42PYEMjiztBBJJYr8uL4ngIXuNpdzKZ
gGYfY5uI04atq1uGDtvLQfugZrh29AaGPBXh/DYSZfWddyLZHWhrdnb0b5Jj
cNrs+d6QAVAOj3Vks8Uo9dgdMT+tB7NvvwoIGpnJc2u5OLmiF92Ul8nuy6XI
bdU5sNSahz/3yULs5TK40rS9HhoMgsqtVF9fLMWpNwvbbG/0ILfQsKthWAaX
/NEv+xkpaPVwT29+R2IZ54tYxUwIw9X02Y3fxPiDp0IPf8SHZWZVznl/GdJ+
cpk8IhXitpPY6/G0BMkbj8d4be7B02vLrxsGECiLsS7N4PKw7r1fKqNUhrfF
T5fEUITov/XJJFWNgI7dfOGTyV4oFxA/znWQ4T/4J77q
        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lVkclrFExjSJhDTFpJSdEHo1IdmKypLk0qIkMmQbXFokQzRFZUkL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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Ve8XxVVUMiRkrihJKiopvskSQkoRSUrGDIUoSTI3F4WQypyEVOah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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41Pkex4XCpK2sMsNozziUts21VJJ3Bxkxidhy22q7CNVyqGiL2iXJ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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGs41AkDxal2Y7tZFVZqXaNV0s7mUnFEZUVui9XsRJRcKtRSIa1KGhnS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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs41OkXV+0iuy3ttqI8iphS2HaakPCpMYQoqYguupDrRm4bjcqlGiq3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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VO8bxpWivZSl1RZRSZQiS7cWkVSKtNgirWSvVIokEr6k7FosqSRL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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHk41WkbNpHSZ85kyRQmpWiyR30V1U05lmqUnepMxoe+JMtJDa6IOhOy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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlWs4lAkDhoXYSDm0RBFKJCSlg1qPFI1PFGlTapuUYumilnYomrXr9JWI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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkfVkKJNBmm+aw1yFRkLDOWU7ehQsmEhDRE1rEvDaMUQkxCJVuR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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k41H0XxlFkK0UKKaKQkn1LuqVFVLakoiSyRnkUIXt6kjYKrcpSIorK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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs4lIsWxudUtEcpRXKIkJLb7NLOMdp5VaKUOErtdEOThEmEFCW6kOSS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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVWs41IkXnkSki5aVSemRrEQ0lVtsvWTb5I+wpNIFrSJyabVbE7mLjVpS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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8ldkbv6V0EzJaKC1iosWWRIiv0NA1GTVDkm4ImRZDachSSNaSXSXT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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2cglW8bV9kNDSRJ1l8ShayUfsmICiWzMlJJG9FOUgqpiCRbKYXsnZW9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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41HkbxmXT9iqiYqfUrA46TkfTkbolCmGJa8MWEtKGZOS1JVQUm8No
SXQwNtWUeEVOiWQyjGHMzDoTUsn8vj/L9sphs+ad94/nev54/rmv6/48n2Ve
Zw77qKupqYWp5v/bxoGbNelUjfx9s/ZEhVGYMv0tNsxPjvneT1g2NwkKDsJy
X4sczsIb7bdX0WBP7nh/4akAPwXd7kl/RcHQlK170LYcAyJ+idYeCnLnU7qD
L2thv06j43MahT+ljIoz5h0IsXUtYjOGsDnI5WqkoBOJGe9HWKBhwWhwMWM2
4kevBjfWLYLCQTemp083Ahi800xzGlWCY1qnL2ejaZFjYd51Bcy1ptbHjQng
cinw/sATCk8XHpkbMCqAbfVIFaOQQmvv3+eJgwiprb4bPPoo2GuLzWfWSbF/
bW/p0G0Cl8yVwf4FzUjYtYf1qwGNxPF7z33SCvDwQVSFTp8CE9pB4Y21TfiP
8uqMK9sITl09Meu9oBWTGnqN4ggafUMT0Tde1UFberCOK6CwUvNR1NwoIfJp
x41qLRSG77SZXS1ox8hE6eyuOUPITUo7m51Yi5rsg5ZjWgSm07GBWQkNYDqP
aI9sIJDreh5fqGjDkjPZSf31NPxCjmxVO1OMnm0GWnWzKPCC5Qd2TRQhqSJr
mjWuyqf75xdbbgVcjKJHzhlRGDWwNHicKgSVkLfvTTWFdRfjBYHpbbA7FLA5
JY1Ap3NtgcG8VmxxZIcpnxMUvwufZphK0K3b9dpyH0FD1cdqV4EYYcY+86bd
CS7+LC5a9HsLRiVv/+0FgtiB/mlrzzK4JS7iKZkUqltTMjZ1SJFnpeFy9T7B
khDvQxVSKRTKiadTeQQzlSzNBroOgUb7DB+sIRBdeOls8qwVf1F5C7TSaFjZ
DSZ4tBciaNe3WxkfFGAhwX2Z/R/Y/WlGNkPVdw97yt+4qQNOaR7fPztMQ439
Dzm3oAaHI1mfQ4oohE6+HTDcWY+S8OUcq4cUuDWukQ4xIlx21HdsIhT6Fpam
in57g+MmTbPGuyjstN9g8MmtCYsresqqIgjcNXPZejPqMUBn6q0Zo5Dd9/r0
8n4JLPa+bvlwiSAnwKBy5upm2D4X9ZvtojFBlccv06lFsGbr3psq3pjFdXT0
AjlmsYW13GEVT2bJIdFzClGdf/KQhUyBnLgL28r7RPDd2Nld+oXCi7scbn6V
FGc8fDo8thOofX2e/iWtGqU7t+oduEbBM31qfULyA5gXhYcJ4xVgCMdLLI+I
EVPx/XTvfoLF8vZKrzEJhku7XE3iCD7cv32N6dCBxuGIy8kcVb7sH3usL5Sh
UWHZfXs2hYmAEzoToW2g+vu4I+k0zGzj/6Ula4RDVNm3VzwIvAV85dHNzdCe
MapsHyNo93s/zkjKw0qR9Xb1AgXM5MPdR4K7MFc9S3+V3hCqNBaUnzhVhNRq
4iqXKKBz6xk/I7QDcTHOMx440Nj+8yCZ1nmBLYGf3bYvpHDrm/VZKWq1mJex
EDk5FPjcQ59eMZoRezonRnKD4M51P7rvv22YU2+c4CyhMdvrMUcR0AAva8Z5
kQ0Bj+P3tkT7BYb0dk/mLqJgxpi6bFPZCX430z/YhEa7oQl3c2ob5GHXM6Kd
aLi9jPDu1W3CQL/hAcMfCByKd/bszOLBM3Tp5eUcBR602qxrUUihLKfrNUsJ
Ht3jT9VQMkwkvthbaq/if7F03iWZBOfjPt58E08wkCl4ZGdcizW+xqOW/1CI
bIznMfUaUCx+6Dpf9R8/pfu+CzJogHRTVJi6JgF9iNdnv60RbBnFOTuf4Kz+
+fBx33o078ixOsIg4PCasnvFbag7TA+l2dOQxyydWra4Gdz8j4tat9AIdc/Y
XrFahkBeTSVHRKCb5K42ymnH101WinBdGt5GwzDjqPz8He+jKJTCILfsiWvk
C0RMfTNesJtCWN2K6BWljxBSLLiYy1Wgbtt5vqXlU3xu9rK4+1iBWP/sozpL
3yBl8JnQ+h4FdVPXExpMGZR04dwvyQQ7NCqtAxObEWE4qRTKVb4vszIKd3uN
DuM44a1fKBQ8v6eu+YcMqZGscztm09B+9138loy30ImSBlx/SuPuntUdOS6d
WLvs2DWHARpLCnJbvpaUY718zvFkfQpqNUePzSwrgZLjtCtUlwLb9uTBmJZW
sGMSttZOELC2vDKJ85UjOWWD+KMGDbsdvR6yfjmCzDZH/KLyi6TW1OOiqwwx
GRaD4iSCKAf1zNVFmaiLEQ/KfBRwdqkUvlP1yb90c+TcChq86TlO7ucyEdi4
gh8VqEBp+e7PKerNWMq65yRT3aWmT9b+alcJc0k89PdTGNmY9CGm8j5iPa3T
vlxTINgimL/3pBz5lmstbKJU/ryTvpVcq4U7t8jIo1fll/V2uep2FSB/ifiO
jhSqOBTbe4yL6NliY9pWgVDPBHenA41w1n9mMmxHsMqEYxTQJcSe0HLm3zco
nJWmrDrhL0XIFcdwPwnB/wAgC9xQ
        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs4lIsaxSe37CSjSFRCUbuNOoWkWKkUDts13ZAkKffpYlySSkpoU6KS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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.5457561254434032`*^9, 3.5457561304512777`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4ldsaVzlyuy7lKE3GCmmbdzTxc5TSLiUiCW2KlDF1OhpESZQplMxH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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lGsYxlWytZAiibLGEUdSiZZbllIhSSiJHAkVolRIypI2WRKJskRI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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs8lIkax932xEaEyi2ki2tlmbQ5Oj8REpXV1a2sEx/LbKxLRa1UiIrs
VKuwJ53KrallTtOWyzQuixnDzDA1M4a2dNG87zvdXJoS7Zw/ns/zz/N8nuv3
tyQuJTxeR0tL67DG/u/jvtubEFkjwU/+eZ9/8aPQlBhzhP17N1gbykboTwiU
JrSa7rS7j7j1SzpWmhIwPFcynGjYB6PAMx4bY0nEXPC9LcqVwafjCe9cGgVD
h8z+6SMDiKU3HLjtSkGvKCf6boQA4tRGxy/DBJgjdb9yPokxM7BDV8klca/0
lPonKQtlqvG+pGEljnbfUJ8IGAA/75bR2hQS1OP22GQ7MRZP7jl3uoZEnlfG
Djm9E7K/do1bKwhUOeVM/FkgRKSl+3RIMYlI75n7b/1E4MRMaNk9I1Gyty7H
mjMAMUOtOkuRULN/0CFqB8C98CmDcY5EuGHDMD9WDJ9rq7eVFpLQqt2w7mRY
F6bkmdPtzwncz4wfnErrQn14WFPZJIFj4+fVSXcFqOcJ5K+0SfjauaicchSI
1r9TNrtZhScZTRLvaC5c76QU5qUSuKevONPQ0oE5UTez53YTqG0oZuTUlaGU
U1LGj1GCziUSJ6oHoa+IrFv0kIRXf5pLarkUL/cVb89NoWBeFeY4SclxNeew
5RdfCiYP501etmPB/WTtkRdDSmwq3t776rUUegFruYxQCvpJb4QfPHiwzVA/
UISSiHWLmur8sRWpfTWbOA4Ewr67Jj5g2orRtVO5Q0EEWNM5C41+FYOfUD0T
MUXC3e2FUXJNP06sNKgvvkSCt/FEZsTWXqzwPazU5RE46nx2m3qkF4/XGuzS
CyJhWDqzK7mwAcLMebsLeUqQwdXxvPJOrLKx9kcRAfU3ehVNgRwELnpXdMue
QDKTHj8UMwItZXbFb0EUqDZrY15BF/jmg+8Vmn1za33av3nLhij3Q/l/F2ju
e7bVo4cpxd66xyy2lELJzfcmOhZcGJ5+1pC/nwC9qpgd6/EQ+jWraaZRFFYF
bw4u8RbheWZ30adKEm4ey+98P1+E37T6qmVdJNZ4Ma5muMtg/m/Xy8uDKfi2
l2a7XD+GR3m9JVu9lLDqiPTTvcVHVr8quuEagbjWL8dYMjlee4Y6l9Eo0Dbt
/Vr3SBPu2OokhGrmGYzNYmfck8A8uSNsULM/hwU9GddkEtBjaOPGPBJV/oWF
2ZuZWD+3qdOyVom3xkYyx7Qh7Lf0VJ3/hwpeP7KNkgJkIKbYebMlFETf/ieB
Lm3GRka96FMkgYaE/GOnjYfA3Pf849zFKuxYf/VDLPMx7ItYTrrVKlyMYIbu
ZAhR2bTyVmWChqc1WW6dlfewbnY7rWAugRbpfucbXD58XK2LtB9peHaMajs4
UINPnatfHi1Xwt7STMfskQTDlmFmh7NI2Hhe1GkylKMxm7VkWw+FFqMbymbX
fujN33OgZQeJ2tT2DWQuH8MV5tzb4STObikuHzwkRnl9tEmAmMTbfaO3X9tL
ETgVFcfR6IFfFfuAcJkQDD8vQagmv4NKrOPHyeDtlGTE8aGQ3b2q30oiQuWI
b9m7/SQEQRX+oQbd+NpldIy6penfyvtxypU2zIZEp82Wav539VWzxnY2LMfu
1dmaE4gMkQRL/AXYJOPMRs0S0O7hWvVdV6DlS0rXz80afpBT6rf7ESxsArUv
yjV8e9quLrDvgnH6PKfr1wlcSFStyFI8xKP0kC0z6RR4q6qWrAhpx6VksUtQ
lKZ+0/+0/6jpgNabfoEel4DJ4fwzzvlsaI2FjG9UK2H4MjAiiyNB6tOwCdcJ
EvVzPpP8og5II46zFJcIMNibtJe9F+GgQ/ONOKGGR9nmqTU8KYaZp5jOkyQ8
50SyQ/YPwpb21XzmKImRuiXXbV63wi590bTYlcDCmj+0AzpFcDP918n4PhI+
RS5jVs0tOF95esGD5QS6dts8yJ8ZQMF8GHw7ovlv1fBCpq0CrAsZQrophWW0
u3bT83vR9Mz5gjeNROHx/O8lfn04mJBfvtSHxI4hOJj3SNFg9XGq+7UmPmz8
l5f3BTCxGNHdRRKwf+K/lLaFgSkzZ1HFNiUsuptvykVizK0IWOxkTWGitb5D
0N0D963yK6UaPaTM7QyrHXqwcGdOg7YjCfv8p5PHaL9DemCWrexVQrz72s83
4ziQBIzymM4E9mxwMbKh7iJJMu1ro0/AYuyIrvZTFiKjh+sn/1KiJ90t/hW/
EXvGHrgfFyshdzRbUH+jD2k+pXSeB4mNXcb76hvbYVAWGx11iMApwsHc7CsJ
4s3KA4MVJIboFqrbn9uQbcH0as0jkGZAWxvvMQiT8LZte7ZQSNzMGWwL6oXD
D34BLzT6bmPRqdd3X4iK3S+dFnWS6DEXzvk4yAJHW5zr+VwJwbqFlsqRNiwf
lS3w0Oh71XLbyyEdeVDHQRL+TyX+7GY0vjkzADd+1Jd4Oon3z9/lTsRJcGXp
pDz9I4mW44f0wzqFEGirhVwWib8BoDDWpw==
       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVHk41IsCnVARUupmSUUJJVkut8XUQV5NlIoWqSRLm1eKLJFeJCRahKKE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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lOsblkuRUh2dQmXpONmidTrE4c7Rnqw1aVGWMiW7ysQplSXJmmOi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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHc8lW0fl4giFZJVhLaRSEp8Fcl4KkXTSBGykqchJSNPZQsZkZGRJFsa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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs81IkXxdhSbWKTlLz7VUravJMcSumHPEpKemD1EKKMqJYGeYSkIbSV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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81Isaxm25HdTRaaPcMaQS7r1ZT1l66FBI2myV5FgyKGuYCAdtsoVD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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk41N8bVSklSRFCSCVtyBItOopKo6QMaSEVspaKTFIoxTdLsiVUylJo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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lf8bxpHKSCHZWfWNSiU7yiWrQlGElnxTikQDqYiWJElDQyqlgWQl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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs0lXkXxx3lkpE0KhYqUjJqUqS00LfIhFcXkUuuifNKSkmRTMMyruOW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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41AsXx6mriyal3PHSZisUkoTQ/Qrdp03Z3t6uLaV1cjOUDJEtJYpo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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk81Pkfx6csOzuVUhLWVY5FkphVTfJK5AqV0qGcSUu6FjVZJCqKXJUr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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2cgVn0bl1FGZDSoRB5PtkRF8vSTlTZllE1akrQklEJIKkUqW0lWIlnZ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlWk41IsXx9WN+NNeKOraUorClSzpO9J9Spab6kYRlZItiupas4RUtmhU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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs01IkDxSkqLbEqaVq/RFGSx1CpNDcTU7/y2j1WVB4xqNSQMyFqEXkM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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lWkbxyUlJVvT5C2MvdNizdSJ8jMq0RiV155KsidRpmjBpFCRSihR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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2cglW8bl+yRsoqEyGxpUtQPRUQlSUIlSUOIKIVIRaESpUKUZP0blFnI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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81AkXxilC666U3pSkIqQsttA+KhvZtqSbxDYKIYpa0kQXl0lRSS1l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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs8lIkax2ULySm6WGHlsmIrt1A49JsWKbVat0LUVEIXl0Qhm4kuHFMp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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs01Pkbx6eiRTSuv5BQ5NJaypZWybuVipJKtpVChiS3VWkYIZdK2RZJ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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VG8bliIq0qZEEkJFIkXid1MS2pRkSYSkBVGSaBFSoVJkSaEoa0K2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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHk81Ikblghdi1QSsXJGJW0Hq542ku1AlMSu2pwpZ6WIT6jVZeWeksKk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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwdlHs01AkfxuXyJm1JhC0yuURuuUVk96HQZZNLii4iJN2Q1LJ7elklJe9K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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk81NsfxqciuiXJaHELY4moqCxRPCktCm0KSUW02rpuylyFSpaLGGMp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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VW8XRcpQhpCxhERJSSmlsiRDihJCKpK5hFRoICqSQuJXKlMhEiUa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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41AsXxyckKVqkRbxZIlt1s6XbvX25cVtkvSHeqTS5Ra9b0yZtlopL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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs41Ikeh4eWOnKsUIgKTaXIoaUnbZ3PdMGk8khuW5LtLDkqJWoprG1U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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lOsbxodKkj6RFkXRSCF7KtXkUo5OOTqlRZiKY5mQMiRRFOpYS5G9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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VW0XxqVIkiSikpSSSggNb8mNjCVJkkoqkUIUZSivoYlSJENeSZTM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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41IsXxhEpS1GkLJXSLkZF6qoXpVDZCl0UikIYlaSJ4t4uk5BkqYnf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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGs8lAkbxqehJYUpqbcDsUnRCUlILmfekmNSCVG2g0Q6aTcZSnKo6KBa
rbQiZZJDy5RVUw5TDplhzDg0hplnZp5RpFcrSryzH+7f/eH+ct3X7/pfhuHR
fhFUCoUSp5x/NyvXtik+7y3I5oIVs6xl6GuqbngW3wHnnNZ7a7sIrPkp7ra4
rwuLDS4fcDKXYHiiW1clqwENpkPypHEZKu/o7EohWqBy3rjbwFIKZtrK1PKy
dyjYWTCbeErge2iY492570F/fKMSUWLEjWbO3rCjBpZG9jN+c5LD90G5+QvV
t7gTeVbB1JRhz6tpic62xaix1Um0Okgi6rTqpZ5zPLgnBGiM60hxZHuwnmJh
O+beGWILraQoX+nDYW4TYPDI/UejHmKw7hoFDXmyMeNu18cRczkkv0yIDj5p
QfTIRvufvKV4H/JMw+RKIz7xTZha6VJYy5vK6mqaYBGnu9coS4rhddVld1kd
UNOhRtBoUphtrjE/2MkHWy80dTRTDFVZtubgnFY8T9B3lerJYLltTdk/lkLw
T9c9tw4S4U7en9X+pyvAMmFm+NqSuP7buiVDr9h4Pt6xihyXghOqI5zPZuKG
51n1ozQSpleoPyzrOnHIcXegokSC0oAZJOsJB/tcbu1TTSYwlmZQFrtCiLTi
niwrah+Mwi2iPbaxEJR2yIyxXA5O/jwfw8k2aJSdMQkskCDkZ87on49fYZ5g
liaRpfyf4K5zPNSGoL/5Ij9PCRaHRMUGRlWi8eXnn9nLSTy/5jf1XkOAWfwl
uT25BJgZ16S0XC7YqdHs+fckoBTJRrDqJC4Y0MOC5yigxT1dtVGfjYH6G7j6
XYYDzctr4rYK8OX4UnkFvR9OgRu+VSe8x6/kpv/c6uvH8jJfp5gmPtKMvzsm
XRKD4qZ6nxIWj173F1pfZynwLediw45UHgKeBuzXqBdDe3V4nskGAS4wFtVP
/EVAvJWll0znITYgKzSLUOrRc8seb/gD3ESByKeBBH30w3hUYRwmFixgzVXq
Oxwy5nTtTT3aDAI8SpxlYIUveyBtTsEKr22sQ9MUGLtB88lz6YRWFjW8s1CM
W4ULODaRfEQG0Iy9IsWwezbRwnjUiUpfm10Fhf1Y3PPDtCJb6XekbpaWgRx0
Z4SlCzOwefNTX8VXEnFClTOPPz3HwALhj648OUzNc9oTemuxws/h4u4zynw4
+CX0RLTB6ajJTaFI6X/JUF2wPQ/nepN4Ii8JqMcTWl1jeTDQLrrlNFuKTPGM
a19MHmNRcGJo1XYSw7VR1RWTHDBusruthQQyxqzMFxa3gcJhVx8rIkA/ZCxK
tm5DnaHKes1rUlDbRbbpXA72TFVvajZQ5rvPqa7r5Et4/p4clOonxwOVJRf1
1N6DRetKWW8jgc+Qhx7XrwEfSB/DhQwZXOP/mckIFMAqdmuXtooYZ/aXFzcZ
N6HHpe/HMUKKsu6y46uv9oLmbGubo9uPiVlz/Rdv4cI/jOle50GAcdAqJjK4
HscHtayG3ZQ8b6Lo+PinwP5A6Qb2JAmH/j02xYZt+FZaufNWtBSlmvuwSf0x
NvJbvJrOkvBZdfXAsGkFLunF1ljokdgZ6fZhZCcP82zZe2zeSjDdxrx33fwK
TDou2+ZuTGIq187Lm+xAxmb/jiMXJLAZ2zMV1y2Ax5ZSQt2NwLcdC3jqam3g
D987Vqyv9CtfcUJblY9TtRGxI8q+oAwXxPGc6Qhf1HM4YIYClxdtNNWndeFh
bix1yUclb3tdDYNFtTAuGZnmNiXDw+GXB8tiOnDd+VFK3ygBzohprtS/CORk
emnwTRJ2vcx5Gq9boR6XOLXan8DhyMjp/LRmNBqEett1SBF9flBhbdUOl3et
Of1FEniPHDG7pCuEpcn5/OU3JGA0G+e80eFBPyRJxb5KjPsDvZfVqC24Tls6
Lqoi8JAhT36d2Az1FRP/e3hcBof4tAa3tirQPVsjPg/K4Xmk3UXV7B2oTU+u
jnEIdMZ+0hu/+hd2nTyp/XIliXmyjN5ztznQ2qClMTlfBquvA5lrfrxF+d9X
zCwochQ2ul/s3syFHbVSZcpeijchc2QB5c/Qu++rezpfjrwAu0/HmKegrjXa
JqYpkLzUWJVVy0NQoT7nUbwYfarPhh1jM/GHJODrNyUfRmxNw12nuCi9N91o
yIrA9stTvi2/slGdWmQUmySDtkVSZ4mlAGZLV3FuJ0mgqbbXzMlBgImB3JiY
iH6Unv98u5p2H3y/o5MeVSQog8FGDYUn8d+wbDvFv310QRQ2814r8oumOxjN
lIFO+pzOeHQCZqfsvKKU93dV4WmSkC6Ylg9k35f24aJQ7UW9RRO+UOT0yUQZ
MmOKt7zyK0D97tcMbj6JuXVXJtW5neCXpOcyHojxdKe34WcHHkrXZ0ftfiDB
WnuBSdq012C2ey+b7iqHPbOR2u/MwZztKZ+OmROwdq06W+L9FvH7dQN3KPPt
kl8+7ejaRlTE5H30cJMiRHZ+X+mFWuwlTogK6TL8H/PTwPs=
       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs8lVkbVWPKuBRKESm5VSoccqtpuU0hkTLSjHKrSGp0nHL5okg6IyOl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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8le8fximzrFQSkk2SioZSLjRERvoWkiSRUSFRkpW0taRJwwgJqYwG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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41IkfnkJrPdqsbCappSRyROSqvKu2smWZ7doRJaIT5ZhYJFpnpUPK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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwV1Gk81IkfB3C1GeeiQ6RayllIyVXJh0TCqm0RodoSkURJjhwhIqwiHZtC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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs8lFkcxl02uZSEotGNXWmT+yWp9TCUS9qkSGsQa6Ry7SLS7kRWqNQS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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Vf3bxREypcyFlJIhMkWpsCSVBtVDqSgVGgh5IiJJktSPzFIpwyOi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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs81Pkax5GwViQlsXY15RKiNCqST6kUdSIUNrGlXFK6yKWbu45LqWyk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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs41IkXxieJogvtbLcloqRSI0xJw9uGKKk2LdLFZSN6Qq1ri5JKJVJJ
TSi6TuMnmkilpXGbcb+MMc24xMz3OxeaX6q1pVbZ2T/Oc/4673Oe93ye9ywK
itwZrEWhUOI19V939zSpDWG146icNVSaTUJUbxMdS3uNI4Gxfiu5UpQEduta
zWoDnzbvf3vHSBix9GpHMwR4T3T/c/McAUuPmWdHch/ju2jmnb5NKthHUo/J
ikSIMBw035wgw966W55XLPnYtSv2YBRDAWbDJ9Ww0yvYPnPyGQpUwjrY4OkL
9CDHZ3bKu/uDCGiL7E9KZIF/5k4GO0YFl0VrWNQYzT4zKE48NwIUy5HWaZ9/
hrsyft1R0yE8HlblloRehPfkucaPPqtwiHg/jxbRiYJGy4YqHxIBMbh7ksfD
QeN6nilVCa+M5Omj18Q4f8bWsXORRo/60TGz2huy11XrFi8cQuiFtMDxmG6M
HSgQqwdkiNsR9XjOGyGGdFuPFiUTSHfzeDnGF4D0ZzLtGARkD9RXRUwBTj5/
UJHSSGLmuMejff4SbGgUfjOfKoWvWvJQlHofZW476Z2FKqg355uuecNB/Kbe
HR5bVSA+fHALQz2qtk8/rtZTwj42MrE4rRUxQVeqmCMkxvJUZnrWVaCae68J
36fEc5Ejc9IXHs6xW9qLpihwgtxjiIVdSMuyn5xUQMJ6sey6r28TIjKvFwym
K0BJCnq9RxKKrI6/x/LnD8F6m+hE/8c/EfO1e4PFqBL3ljq5DiQIoaYlBfJn
kFBvYTMeTm+FkDNxwcdZDot9YQ309h7U3y1fPawehOW59TlGO+pQFJqrS3go
MOxWurAxrBvrOvJLHFtkOCKha0e8E+E5J4QlGZLiomiV/nlRJ3ymGnC1H8nh
a8A6Vq/bBFv3/lFbmRyJCtWVkZcdCPm5+96SD3Ic85xm3k4T49fsnRxfoQwS
mqGjGUcIm2hDP31rEqpb22/Y6rXCcvlDS78nCsw1OnSXjOTiwFRPbsJJJZwu
RMct3SMAW87l/xJPYOv1OMatCAmC/DzKUhyk8Obt/yr06QTjyvZpqVVycIMk
R3VrbyMlZQXduUyFNO0bs2MP9ULY9Ue+TtYg1P2FFaP32hDkkDlxeJICe7VC
7+U+EcDFxdQo3IvAQjHnx4IJjf9rdN41fyVwJF/Zel38HGaT77foFyhBefwi
O82kE1rJA/rOq0j0ZMu0Yib1otRlhVmwhvfDq7nfdYPr4Newq27BaQWi4ydc
QvqFiFpvTxeHEBhnJb8q6CrBRidlXY+vCkxVwWDp2VpMsotsrDuuQMynsNNb
TSVwb6V5ps8hceF+5dj8OCHoS6p7va008zDYH1FaC4Pwki2VyUrsvTn0iePe
CEp7VH1NvhwTZ880u67swx+PMj+/YMiQ4t5FbfPvglNHojPtohz+y36QMo27
UfJ0ppdvLAG7iIflVzm1ePlXdmNuqAJXut8mXpvSg5RtNVHZNwdR8fsxp4RY
ARz8u26oHsqRvuWqiVVqC+6t/W2Dqa4c4ryzffFzm2Ca55W5liVHg3Tqgm2k
GGEDch4rQYqxQKONzeU8xFPWJDFNFGBf3pqmbSbA2INvB7azNHzW7x66Sm9H
+H5Ky55fSLgKjU2MKxpwuXl5w3/5Io6eMcP14p9IrnWgZGryRfxSEBWZUgGX
O/4zjqcoMfzTM4cFOWI4FPkW12hL8SXOvjFk3muk1Qdq9zbL8GVRZXnlgBDk
ctsHhVokLqe+CdDa2IZCygkrPyM5Cl33WZnr96P50rbfvLIIjFKSsqfnt2HQ
57zRRI4c/4C+2tyrB01/vY+5tJpERTX19ao8EVY2DVXQFCSSA9QLdboECPcz
MciNJDD2dvhLXAIPw2wbdZ+FAtk/naonzvUhfXbGkQXuBB4n0rCE0QGLk3Oc
+KMkGqrnbPr47Q4cAnu73IpVKNhAMS9nPsGTPlfmih9UMF1lR591rQs+HEFW
trccNZf1qN+2iMGoMrII7CRANd7QsvvvKnyMLrsktVOC+SJawGkXgrGyJcEw
i4R7tGPZttJqvMlZHJnwVIEW06UnMg5qeIg83myZSmAyqaVb7NUJC/XT2ww2
idFQ+sp5F8qhyHJU1xir8OkWm9Yx0oYwvbMSv3dybDSdtVV7SQ02rz9lEuGk
yS99qs5bBwHivk5ZK08nwaWerivKyULpo7d7qodVCPV++sY6rQ7J61dbJKxT
au7gqMs+dRvzTZYdHnymQts467viDB+lk7pkLwIUCFjmba8zpwu7bUbEehwC
tM/cSil/AOEuP7q/2kUgKLV6izCvA8WXbZ75H9L8gySbwv1sMYb509mjl6TY
tS7+Nu9iM8y0Ur7Ldsoxbs29b/h7K2qCl2zu7pFDjz72YaqnBJWLlAwduhTJ
HlyhOCkDlCi60vJvFea5bXR+RrxCW94px88aPzcVHzRbGySCslnlGHxABqtx
51UHtNvh7cVvKrshh93/eb8uON2Jt/sP3/FvI/Avnx3IrQ==
       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXlYjNsfH3G7cVusiUhIi5S0adF8UlRKiYiiFP0sibQRklQSUTS/Vgmt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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k41O/7xUWLJJQsRaK0SyqKFkcliZRKPpKyJEqFJKlspRCyk+wl0bco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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk81IsaxoWcScUUR1TKVgrdMx9tQj1aKJUTZS2EUzhJpyPdooybcizF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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVH001IkClSZJr6TV5qOEUaLShJSoq56h1IZ8Ljb6YCO91sjnlqyEmjpk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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVmk81WkbPmMqLbaMURRDjCyJQmksl1Ba1BgpKp2MHCRGllAhNaJSh0S2
yprSYmtDQijbwbHvS0XT06rEGE3Te78fzu//7bnua7mv+yg7e9vyRDgczkX6
/f87a3Ra4V5YJ84844WEZDAMa/89mZBzC/pff9QwXcoQOfkoJjJbCClbTW3u
Pobu1UNKZqcL8Vx988bmZQz+xnJzcVEAUU6nw1FnBl2Fz4a1Uan4JKZ3Yr4q
g1lcUhmvowSuktx34qsZPA8prni7pRoJdvfrtdcyyI+ud4z0a8PdOnZ5+ncG
ucy+4BnnejFywkBzSyLD5ahfzIp9BThiGp6btYdhbGjV3gD5Hth0RHKcAxmm
mmUGP04WofhhkoJQl+Gm10L+4ue9mPh+x/knSQwB3OPcm/924tb7PJnd8QzL
4rpHlks2IEPLxJ23lSH61/mRbru7MBL64juBF/GP5R/w3laMsXev7XUNGBav
Oyah/2sjZvsszblC87mq1Sjbb38Iw7MveYUrGLjay95t29mF+yZdd0MSGLZJ
LGQe5e1YeIiTtNOf4fwgL8b9WQuG5RI6fnNlWFhWPdS/T4jnTv8YSBGe0/NF
IlK7MjE01f/nA9JLLF9tvFGhGzPt507E3GP4rDLxaGJONWpfpkpuJr0suYsn
yxV7cHtTVcrtB+QHz1qm9GUu7kjZ/7deg6E2Vkw2c7IQZSX6Vz+oM+SvsrBT
T+uGYbhNPQoYXM41tj+b2YTebftG3awYYsRO50a9qEX43ffzSrYwuHtl/Pyo
/C7yJeJ01TVJP5dYK8nRCpT3tTlW6TBwWs6XXfDPx93pbRdSCa9I9dCX+5s6
cS80w1TTjUHdKE1hb8U92C3OzNddznChrsf3/vtuDGryWy0zGawHSuZ3PmiC
HHd2sjeP9HXqTzy6vgrJ4vKGdpYM11+FmTtOF0PU868wDdI/bEtNg2x7G7jn
562NcWRo358gaaQyCDsnRYnyQcKvnRExsugxxgZamuxMGGK7S/Z71nXgdcD4
DvPLDImjhWIB1U2ocjeSmLOboe1728du89qxo0m2b+Vx8udNu76nTAsy3DxG
88gvPVezp5p7u7G1Mtn8VDTlrceZP2qch5Y/3A7+oMVQGt1jFqAygF3H18zR
Oc9wUK/Ja2tmBpSsHFPnkX8xh59L747uwKnEWcLPPgxK8RNrW4IEeHVhmv/Z
hvy3Wn18Y+UdBHFOOc4nf6T8pD+JTd3Dct6x0CjKk+kV+QrrawJkvb40nE95
T7Lfc8yjSYDckNNGN60ZDLZ75nyo7UVAHs9HKY70tmi1kJ/ZiCin8e3ZtJ9m
nnFxL/p94Tew03fxEob0wOy/S0IaSK/cFzl29L5+y/B+4w6456QknDpH+tUP
fRxaWwQOZ6PJCfK74kcF0+sNhVjJqWjzJ75Nv7CeVGUBJvsdbMtpnidWzc6j
Tu3Q7NiXGhzMMGSZNXz5URGiT8svO0Xziw0kc790tqKkUdewivQWuug0REyW
IMDx9SdX6gsR2dxA7eRW5CmLzljEZag29j/3IOQOrD+FSwwR3qs5Fq2qsqUQ
OpRLRlNfWMsGmclrtKGI65B1gvwZv2jgN24tROc1b61ZlAe5MNc/javrYTN1
r02P8jNsLF8/WpOJ1hRlj4CfGUYCh09qlwohX9gerLWL8Nojxf5ZI0THpasF
agcZ/ps2T99Z04POQyMNr6rIr2X7K8biS3H2tI3IT4QvtbaKd3jkCTKklyTp
bCK/Y+ZceWpVB4tw/8KNxC+NM9sieXkrNszaf656L/G/6SyhtqQH/PQ1H17F
kt83nvm1ujQhwVsiqpL4SmX2c8SVL0Fq+kXPEcpLUG/KD00tffivdoGv6xPy
Y+kcLuyboTj1Ubqc3le1CbwZP5UNM5M77pXUxw7rks4vTic9DsRmqFHfhpcd
qt8wvxeJ/NtR2jWUP26yinhwFcbUP7iN/sIwo/n9sWy9ZsjNOvLvvF8ZNnzt
O3Ng1g04jF5TD1ZjONLRstn0ZCt4vES+rC3DsY+qRy8EdsHc4/C3h9Sf2RaT
gt8ru5GVvrtz15/E5+3qwtzQ67j+ZeUZHZrHztRIx+G7xzgcH1zibkp6iI7d
+uyahViLo/nZxK+sOH4w+msbcDZHhrlT36U3P4zwf4K03/yET2lfp5R8Asyb
iuGa4/DXG22GiLnSNZZTZWhqjqmZ0qP32qzMFlZehYOGYqAL+dmu7PQ9L7kW
sw/ayu6lPKdtfpjefTQR/QE+kt9UGM5twe98jRZcUfIbUtlJ+28awNfSLMb7
lAX35fTpPrnvFeWr3oV9gk9vAeEt2Rql53SS+EoWNK/JZTDc32UkpfIA19TO
vHWk/rIu9dZRC6uG9NbxMjUj6sM9d/6VEq2jfvjn4xrCD+q79WYutw9nlhdk
Z5LfY201jevftaK23jl6nPpFXlPZ7EanAKbBCyel6X4Epddn75qqxbDfKwPl
bdRvA0sOvhXPg+x2ke3x1KdzjQ4YTKt24fY6mZAtadS3VT/5R8z0QGdivuJc
2uewcV2tIfNqVF/VrTM1pH3+S6m+rK8RfYrqNZLraN9E3lgVFWWDkxTu1Up6
bQjZI7Lbtwsrbo44XqL7FKFSc91frQeWB1Q2KV5kmG3VJbi/ogvavb5nLqdQ
Prtf8p/1NuN9hEHWOO3L5zzxpScHhEiftjHRofwKtQ663jnbjoKzgXm7/mAI
DdXdvLWvDd+qd9j9RH2ipFag4RCah+Q667qXlA9Lz4u3rVWr8IX728o1dL9y
07J8o/Z1YebjsloPukdBuTvqRXMe4do3+J8gPkHRFrx0pwqYOC2fGCX/s7wr
lzbGtUBq5bxpy6MMnas7rnBTqiGrcET39kaax9/Hy+XEJdSLC21dKG8VYz3W
EwsacD0kq/SrA90XiH57RP9fqiLOdvZTHnQV0y67DCbDVGOm9CnKS/AqnsyO
YQGcKnxH/MkfgfKia6m3BHDgRibX035xsywa/hCrQ/hJ/UM3KN9v3sXs6zk5
AFUlEdkFVygvq6Ta0/gFmJLxKkqm/pLZ0/DUR7ER3j8ohxhTPv4HbOii7g==

       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c81P8fpyRKoiQyEpJkVb4NqSeSBt9+lFFWRVRSFG27JSuVVUkiycye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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHs8lAkbFdbiy+aupC3RJuV+TeWQXLJlRUrZbm7lkihSrFuXSZclXbXG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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlX04lIkaxidbUhKV2iMJGZRKmj6stHtHnIqUSaSsaql8lVSKOoqdCjmy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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk41Gsbx1UqR+icVuT0Rsp6MZYKg683nTZyaJhsEZE6QpYkco60HHQU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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHk8VF8fliRKQpIQkmyhVIrIo6goSmiTJGkhpSQVJUSyZvtZW4YoWoQs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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs41AkXx6VcmtyyEV0QidxL0mXqq15KtoRVyzZttpVLPLFi0s0lmmiF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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81AkDxl1Fot5qYkiuJFE5klXokViWt3KTiqJj28pQKlFEvYwwaJ3R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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk81Vkfxkwpr7SZolfKOtfela264zEpsoRsI6WIKBExlXoVouyGEmps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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3cgll0fVrSQVQop403JSEZCXpekUBQiWshKUikvmaUIJZFKRUNGSjKy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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs01Akbx13iyJttareUS64V2i72lbyUr6JQtmanpdymMO2FrbAZTbVR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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVWs4lIsWJt1IUqmQtlEUuuhyiDi9bpERddxOMZWUHZWhGbWLyr3YndAu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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns41Okbxqdy2lRIS23anJI21uEnOeXWytKQZEMOiSJbaVkUIiRUWsWE
pG1UKCklZIhaZIQMBmMcOiDUK3LItUYqv3f/mGuu+WPe7/3cz31/3q/K/gBH
34UMBiOdfv77Lvw12PBnLgelvGPBhToEX9wvtUqnlWD002ha+gYCka/Q2eFD
C77MbDwaeIhg59u2wIlnlZATBeXt0SVYpKSyeOpyL0pn2Amn8wli1N6Z2d3I
R5FRjo27BgH7w7GZLL0WnBFWy5ntJ3j6rruCV9yN9y+llBpPE0iMLy5P38GH
Q3SK+Fongl/NM79bYvcKMmL1zFfJBHmTc6tOpQjx/uATu5Bwgt3aD/rOxbTg
VFkHz5vqCVdY1mTW04ZhJduo62EEUpy6/foTXXiTHpqdXUGw/ECRwngyF5Gr
zjmXmRMwZDv3ndD5AxWav5+SViXYU99ul3mnFFN5T51mNxLYGLidjTpWCC2G
o8HR9QRXxP3vJod2YqKNNW1+i+CB38JhF2s+Ms4VlSt6EEjGDPWdUe2CvmfI
oak/CeySD9pYuzZDPT0/7KYjgYW4mDbHqhnLOwRRoXupPpU2ZmtbDV76MWbn
QVBVmHHY27AZi81qf1pzgCA5imO00PwKStU/vQhWI5jq0Gy/mtMBUb2/ou0F
gvpE2dAvS2tRYptVa2pMUONwTLRxuwD/dlu/zzlPsCRqvOp5aAvy+5YlPPUk
WNl53+O3LS/B/ByjpMYjCOR4Mf+cbEVsqKb/WBBBZrtxa8HlGnh6XmRZGdL5
NQKnT3pXI3ZtzS7/TVSfc6pO2+I0BB555pVL9Yh1myzfbf4SOqx4UyafoCvm
F1fpOw1g6wktTSzo87RNJJMr7sEsc0Qk/xPB+5A11usDilG3N2vHKurviZdX
4r6m81HQU1/g6UBwr+nRp4mbQnzL1NbdQfenOSA5JAgtBrnu2hahSZA63xst
dokLW9VN7pJMggxWvnTQmgZ0Xo2oWeBG8DVykFmh2o2QuXq3H28Q/Fi+qT9J
JITZlPhc9TGC1ol3wyFPhNDJitTSjiCYDiqqimhpxZ+ZPf+c8qG/qzhjfwU1
4uoPJ54lu9B5czOizmd6Y4DpWyBB86GeyDjyybELV6v2M4wv0fPqU16kTaVi
m9NFNRb1g63KV55a3QETq2/frw8hKDCZs9ul0g6fRcy4jScI/l6U3aegzEVG
sdVugRGB8owUvm0UYGE+Q1siie67oH73i5EbEEu52yS/jkCp+O+VgZP1aJhd
M7KO5qN0ZsPr2w2dWLJvsLGMTeAWoTOhXy0EO/IRdGkfOsY77a2XcZFlPzDr
Qvf3+7acWAW5XsTw96YH1hP4uyhKwegFXrOk7Z2sCXTP6LnJ1LZg/rUTW8uP
7u9D7wPrHiEMLzUeGKf5Xtk0PRQR/wQ+51s0A6jeRxNYkNIggNObFXHasQT3
644s4IsJcGGLxBwjleDjs3kLi5o2hDyU9vjqTiCrIOPcvbIenlqiaE9LygMN
S6sG7xrwxhV69DdTP55xLFt/78K3bnHfl/cICmUyC7olW1Gu5xkwRPPKPiyY
X0348Duyh3+N6jO5ViH3v5N85Ipkue60H4tzGm6G9LfDQN55epr2IedG79vc
0V6wb5nr/U39jCEPAw2vpGCPjX6FPN1PSend57vEBTjl0M/RyyDw+6ih9sM1
LljrZi1O/EJw/V+H4ZuSRVBIFlOcp7zbnyfsF9J5yn5TGXl4liBki/Gjvr4e
+PS4smcraV7Kz6Yd3FcLl9iiTr3tBHFa4nuCvbrRuSleaSmLwLfXUG/RnQ6s
jx44oBVM+2i66lDaWQE+L987YRZIYHTxgprxQAOSxHp42Vspn94uaA872Y7N
xlnK53zpfpZX1x193IaSp6wCjX2UH/Z8/9Ss87jvIYiOp3ksqkh7vmKwCiE+
T87nUj85L3a+qhq/jpEIxpsxOm/f2H6pPJcqPFcf8EzUp3p7XJcOLuAj0dw0
QOUg5fklsSYO8yFk3UfrbGi/VqyeDft1qAWDy746X7Kl+g6xFP1MKG9DfEXh
hZQ/roaW6r58vJpNF12l/GIWLzoeZMODdNaFWgkvgsMbJqNaXNvRWnugspLy
rmqtnNfY7avwHjKaa6J6ZA+sUE6Ra0KefE5yNeVlUJh0ZF96K8Z89DFIeTn2
NdXCwbod5vaNEx+pX1/uRabXzvNRKmw/FE3768Abls9fUoNwH9ckIeWLxe19
moZyZ5A4WVIXSf0QxYoUDT7S+d4z5O7EUN5sNTJ43VmDx6xohTED6mfjs2E3
i3xU+G09vZLuN2ey7IOmPA81SWaP79N5jOZGx2To/fHLGZ+mK5QPSrs+h8FU
iA/rzD7zqB4lxzVEwvEJUrNVcwNpH8xH3dutep7DYcukkxrt05edKphilcLg
g3KnJuVbYX8lz8yqBM6ci7Me2rTfi37McpOlfYqIf1tA/z+49la5kkUPRssD
DMQpr5/e7T3+9mEnWC4PZqOu0b7Xcc2EqW0goUMfO7wJbhnO745/04OujY8j
frpJMMoL73NfzEM6044p9PiPR70ykv9WImHcxciP5qEw4mBCHuMOmr3Db1fS
+zfs+OV427giqDtvKB6k95lnxnesPaV8dKWae7+i/BQ9jTIXXiyEZsx29nbq
T7KuX5AG9zLmvX4esaH7C7fdZTrk34wyS1PuBdpHqXVLuKvW0H02Fk5X7aT+
3PP4Y5g0Qjf4JPs47f/hap0u86B2bJt3VLzwB72/N2dvuJFRArG0I4Lf6Pn1
75KOMwSNCIxo5nyhz4+cmTmb0MCFc+zdmQnqp5ia/Omak4Uwvt6SqEHzGax8
1+7ynIDm4/x7gxTab+fTOsYmcfjGT/zmR/d/Qv2M/XhhC7QW7paNou8Df+2w
d3vy+hpqGPnsLKp/5YPsSMEED0e1g9JBeb9tNMEmop8HVaMluuZ29Dyx1Umr
rr/ACheNfkvKW4m476/l/9OFAdbgg9xHNG8jUsc4X0uw9rBO1T/0/cjLUkbV
cPNj8G2yTLNovpiN3dylR2vxKHbD5A9Uf57fbY+y5hYUcf0SFgQQ/B8tob+S

       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3dcje8bbhFKm1IaqKSMiEJyhUpW0iCkkqykKZJRkQZJhZZQJIk0nXba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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk4lOsfxoeTQ6lElFOcn0KN5aQSIWfuEsqpScnSQsjSOiVpIUlI5UiL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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81AkfxxGlVZJVeTY8rlA6JD0R+VA2NpqsJ3JmlCtHTXSzkdglRMvG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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4lGkbZ0nUSitsSscllJDG6qB+VCuHHGMTQnKKGZWQDqjNotaSc6mv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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c4lu8bxqW3QipKaCEjIxmlQji1RKmMkuxEyS4aSlLfQpJZRiRRUmZG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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41Wkbxw8l5VUaJMtliSwHlSxpFN+TREoqwwzeiYrWkdeUN06llIRk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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVGs41AkftROF3NkloSslVNIiydEmt8rQTrFlIyRCVFLJxNNF0SYpY9Aq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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lWkY1TTTFJIWMnVRWZKytKFBx1yVpaKxlEIj40paiCQl+0iShCQp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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VWsfxU0prgwlpIlGV8KVJg2LRGkwlOSqkAq5XEOkkAwlTUIkQ8iU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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHtUzPkbx8clRKitsG39DBK621JttO9SMZIuw6iIymWXdF+taZGhUhFZ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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41AsXx8cSJZWIqFspl0oia6R8K7pCyZbordAit0WWG6OQ6h2VUhK5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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4ldsbVZluyZUkGSqZK1QyVpYrCUlIKYRryJTSQCmdekxFlK7Mw1Xp
OihRxgyRYzioDMdxTomGk2xNmuR2T/nt3x/f8z372d+393rXu961VH0OOfvP
FhERSafP/9+Fc3UvrrDrh1JWZYlsGMHKLiUSsI8ND+X6nU7WBA1BI/pNBTxc
Ujy2N6uWYNX5q1EpPx4iSUHXyN6PoPBIyO8Js9sQvnGd3dctBIpdKW0GOf0Y
n1NgeuEcwVnHLZtvynRhtV4AM52eVyErOmPJG4Kkq2jSRCqB57yLJcH/PsXL
9jhvnSoCqSHzmp+MblyTGW354UHvzxnZv0owAM6MV7URXUsm8b/Vhj+CTULd
g2Z6f4pKI+N4Yguka5T0k40JPAbbomPuF8FtybMTeRoE43ufj+lI9GF3/Cyx
8mCCWHYzpyO9CreOHkyKXkWwfIHB8oHn9+GuXNpWbUCg7q3l2lPPh2bMOxnW
fQLn6rGf3UwmjOqk2yc1CRZuKIjW9uWi42pBmmcJASvD/ZBLSj8Cf8xevSma
QMT/inhTUxmKt38IOKpFMGnlVWP//R4spRZXnzAkOL+mM9FWqRGPbjCviK4n
cMpT7RxdzUPgjGNC7j8EjsFd/XfD72Je1/i9wysJniwt/BS6sBWcepH/nP8g
qPS5nvZkVjWyXrK6x/VovfJaDDMGB1Otb6wnEgiqhgMiI45w0Zk2GetwkSBM
o0RMNYaPwPu+jl2nCdInr0zxIwdR8HJP0boYgpsNH5VflPGxTPpjZUgsxZu+
1U2/NBV5+tUX/NUoHmd/tSLGdVh6zL69jdavYKE7ungnD+LH9L5fo/3VtVus
6bZtCB4N1npOORRffmTWdxYLcYLSEMZmAjnPIqgaDMNQ/1X2kgoCyymPbWKX
OYguT/G5doRAOCu100LAxSNUzahFEogucTH5oP0UolK7r2uwCMR9RuruzxnB
lG7ha5UeghInyayyaA6crZXZIpcJDmiZedsOD2Lhz8uFuXm0nqN2z6182/FE
jqXeQPnyK1ppnbmoB1y3CbnvNgTBqZvW/RvSh/Nv3VOvHSUQk9AL2u02iJcd
fae8KX9CxjPO3+bN8IogsrfMCGr3cEUkzQvgJWeWo6JO9aR2M/KTRx/GVqjf
tj9O62M/en0zvgNXLN9/428lyI/bpCLtPYjPgpGgSYpn++vEk8F5bVB/U7vr
lD1B5ltW5XhtNxSD5h7030v7N9XyRcNnAEY6Q78uUP5lEux+9PFboNN223xw
I9W/hEHK1/xaRKcvaXxF9eo32mKtoNeMBJvj6kyqV4svVHozGXAUKoU40H7J
h4aFbvfqhcNc5jL3AwSJwsG1+hY8SJvrawmLCXjjkknMHXG4IVa+0mkF/X9z
pSBfLAJOol2XDOh6ZH568heLmwj/ZavEp/r1Uy3UtjjfD6mEtf7fKV8i255q
73uXiBF1+Vun6PflkcwFTTYdOMzPEZruINBzWfSm9TUX1tqH75QV0vk8m72i
0asKXwxLGa261C8O9DKUprlQUL+wXOIqgdXW9XnxR7oxW6te6ucuAm9jefOa
RX04LQjC4/0Ur9rekfg0HvZZ8hJc71F/sPN3Xd/ajdO59bbVlO9p7mvOAv5j
TBkxYjdQPcmXMnY7Vg5A0rPKO9mbYE9McsVm/gM4R82pj15H+bYy+xLO7cDJ
9liFmJ10P/6jxursOwgxVra/Q+dNeLbZMc5kGB5nl+W6PiOoNzqXoBbaj1w5
06V/0frf6VYMvonuBk8/arTCmeBHo3GGsIWDX9aK23N8CI5tyXOJ2TCAJrmC
PTlxBIFhNmI9WkOQtbJmx16j+jXf0qCoPogI3zIRjj/VL/j7jXt4uLDG8ptN
Ja1fhtf5alslNAXSX3t0CHyuDlkkfeXCVvSj9wXqz1YV2Q46EZ3gmHgahW6i
/QhO7NA5loA9VpeiGmk/XAYzwltzeDBsupHdnUL5huzYvKIGmLTj9wBav03R
rKwYjVysiNnRdoLq+cCEtZQurxndKnNS48wJ2ssHDu3K74X4gqAkAdXP84o7
ke0v6qC/Zc5ivbUE0szTdwQlTyA+zvwUkE/3n5u5YeffKG4sLh6g+jPpl6yo
T29EsNbjTgs6P9Mx9rtJaSuYFuWbv1sRqC5/6bB+5gHyjhuHf6N+6Ng0PGDa
1oaD0Zc33bCj/jzt0qns2w9NL8MC2ZO0P8pfixfdLUcdIz3uBOUjTKps3vXW
a5jS0S+voP4uxX76rerlQ2SOqbAv+dLzngo4S+8NQ/dcwsyqIVqvcg0jTrsO
9u8n/NzWUP6NZVUUSmsgt6DssBblw2qfRDb31SCc3t7+JRZK52Hhi8cPZzoh
bRg0dx31D4W64Dgv2Q74rTQ9LqDzKPi4t/RMDBvDnprOSi4Uj1xybcL7BpT5
OseLmRLYM+ZOLQgYwqRJk6toOc2PwIacrfntSDXJKVGk+Vhg4tBcPI+NaXaB
ohHVj3Ks+JTNn22Y/i0qnWNJwMyY8js11ArW2QClcLoe0xozsW0eQGZK8ps0
queNrGO+9862YKnGh8/7QbDOxzmMSPSjco/PDZkIghPCOrP5H3kIvz8xsLCM
6rH3pLj4ZzY47he9qt0Jyq5yqh869MPW44/kqFM0T5fcys040g5vTVVVCYrv
UKAwsmRrG5QNvsKI9k9kZDJjuz8fZ9bvsL5B8/DgQ2FaJWsI3nHval8n0v5u
TjdLbSxFpbq3xTKaD2ND6v8ECtgI6Z1/RobOs2fUl/+6pngIUj5Qf5PiKUrz
qIvz4qE5/5x+CPXbYeaGxNFeHjZW9Bh5VRNoRxw9t+hFJ5an6oU6OtF8bi9O
L2aVIp51oiOK+pGelNpJU3ku5h5umu9B8y3plvzo+1XN8OQqmpbQPJWp+Xxa
k+L1C9uRlFFH+c0UXeIu7MQjVxvDk5QvGYNqDE6x8dev3sQOWwLz/LWuhfZs
mG3RzVC0oPOw1H/1N20WeL/pbT1F82L9RMcVsZBK5D5b6uVL/UGzd62cb98Q
dFz9YzJLCZrn9+tlujZj+s/QCBb1Yx+b7vIu6l93kncI/Wg+/A/TS6CM
       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHc8Ve8f154okTSMorSEkKLeoiKjVKIkyWhSSkQUKiPJiKaZvZIVkmTL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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs41GkbxycdXqdEVNO4chVaSbTtbinFt9ahIjWmsi2KdGKipFKSQydR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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlWk4lAsbx5GklETJkaRTUVlCKkX+2tQ5FZKyFGfOUGlRWplUyP5eJem8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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs41FkYJtYuSVspElsqkktLZqmhXnRRCFmGFSLWpai2laRoXFJKuVXk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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k8lF8bpiKJSFGprIWUXWhzIakkSRSSpEhCEkLLn7KVErIVCqlESWTN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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs01AkUx0etLUVhR4U8o7aXlSQk3yVLRVFZa6M88mhLmh5bGk5RqKNI
JOQ1u4mQzGI0mJzxnkKMIa8pFWnm95uJTHpYw87+cc/9737P/d7z/VyjwJP7
g+dRKJQIRf3fY3X/LdE70o39opjF5lwSpt4m59kHB8GTv5u02CXB7Omdc9+7
1iHkbJ32rA+BRQfuRcrXC+H2S5iVsb4UGwrr9Iu1h9D7UvdQm6UUlDVbMgv7
7oJ7qE48fUQM73E67VtNNe56G6zz+CBG9lq1qhv2A7g2bRqfvF0CxqZsg7EP
j9FQOeNVpE7gLVVJJl3RgcvtcUolMSTolTdHEl6/hHR598jWS1Jwb/rk14pf
YPLz7pU6RhLcxjbj/ardMGGNQFRH4qu57ocKEQucFMNlWSoE2Pk6N8Mt2Ajj
UN8ZzCMQ4vvw56hN7ThnutL4rTuJ6MTXufXd58BP0zz9g7kYCz8yY/xucLA0
0rGRfoSApabJnx7+LbjfEXd+IocA4+cyd76kFaHvv29aMU2ggOc44WTbCnZ4
GpU2RIDZrQ8hKwMyWsHmV4cV83bvjQuN7sQe18pxUQqJo1u8Ss9ktoJWlGFd
wifweMHqthPH+3FLVjO7JlyCnhsDL+JKBbAzShUMl5BIGh3tik0bxC3WyDhb
XYrfUiscqJM8xFhUe2/KItCQfDj5Mp2HV+Mttk/WkxAdbJTemuTC3uC9HieF
wMy0gdfV3iYs7PNI/32UwLIS1yibNRwYyqrmD1EJeLjkL8hSa0HBOTdVwyoC
f8lZbu5qfMyJGAlXkkn456ka73d9hC1jq3Mta8TgXL9n8+ZrP8565cquF0rQ
X7crmVVRhaRmm+FLMjESTa8IZMJ+hOx+m/KdvgQpO9gHViY3Imvjr0c/hxCg
x3Cvcw7wcTM+IyA6gURQo/OD+Bke1qnuTefJCJRHsx7kVA/gUzPB0f0mweu5
C13NbvXoOBfRGepM4IVKw+GoXCbyejVcTg6IEeZQ6Wv7pg/C3kEnWZoElJqs
QDUHDuqJCDd7EIhwijH7dycLIe1u74PmE4g8ZFjTM/0MdP1Su7I5ApVlBf0b
z7NACz/WPzglRsZUy/PE3d0YU1IeMh4kkeHHqviplge/nt4Ss60komxSXplQ
e5Fr4rwo+qYESobu34VbCEDpevep5w4JaukX2z+8niPMnhYvzyDBdBFQtUbZ
iLJcp7JkIYGd6l3eHnp10Agp0gvyJ+BpeHjmgm4euqPtBuPPiHGRrxFRc3oI
9w4118vMJYiOS7A+eaIPDI9VjtnpEoTrDVtcSXwK7uTTlj0Divttu+ZqU1sO
p2wra2dSjIkkxlXd+Wx0+Ld7zi1X6HXjnXHZE2y8X6fmv5LAF+pmytemZmh1
aXlW5ROIOrZqtWh5C1QNXVLkrQSE4UEawnmDiGGKWskNUnxi0SM9Ex7icqNR
cV6pGLRCbeYV6jMwggsZ9xxIUH4ZYMSnM3G72TPAkCsGU1dz20RGJ3hLQse3
LFP4UdMeVjGvHz25ynqzGRKERAaK/L34uB9cGHvnKYlTP5bNH2trQ7T/P6kH
FXksc+wZV1XpQtdXy+ED/iQq2ymc0fpO2JYauXDOk2BYzOVQt3IRq7xYX8+P
wJ0vRePvg4aQPeAaflxPCvOLQ8ek8iKMKBcoP/xbDHOm7187tFqwtiDwuEU7
AVOfuG0POvvgmy8fS0uWILlYuMdCpR06opFiL0WevzosVLOc68UajkWGu4zE
tRvOIVbvK/BpheVPldMKfn10/WDT0gVeJNO8kU0iIjhzwGOmDObv5HyfcjF8
p44KNV82gG0/nJJUTMB7/asC9/JK7J08FWTWJ0aQgKltncPFkkXV+wJ2E4jt
z6RYGXWgYXjYcP4SEg+3qQfS7MvR8vnur6xWMRga9+M9n92B6EuoXYO3GLfj
UlQ7x57DyY/05ceTeJApizjU3Az6Z+t9zxaQMKOU5F1t68OjB39sLlLsVzx3
4m7XVT4uVqVOtZ8l8ca6Wj4+JkDg2t6XUaUkeI+3m+nwe5BEPfJwl50E3mc2
XK9b1YuZ2oOxIhaJA6rHgyc6hLge8ILGvCeBpMnzk21OE/IDkrPfRhDIXt8/
nJfQBDer2qt7bhGYkP6tyfo4iMLVfk8G30hgSD/qGZT4DKMfdlzosCSRTYv8
0n25WsH7IK1IfQI9B42FFTYvMLup1smeIcGN9bcd1G27EFj+Q1qiiMSsL2JC
5wZxeEOxO3WLFL69sb+xhztgos/kd4NEVaSB9nP1V0j9nbv35SPFP2gYlk8p
CTBP500wLYeE9Y50Zf0j9RgLvKWTsIsA126x60xpLBJ8HBOZ28Vw62RfXCf4
B+oFVfLTjQq/haVTPlpZsI37UXNloBgCfvumpRoC0APoqze2KnhloffkfGMb
nIO22xlpkZi45lrxqJGHS3c1zS5oknj9OWx21DQJZ2misGQXMRZPGG04psLD
RHqmleM3AoS2xr5TOzhIZZvuqVhK4D/PaN7d
       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVWs81IkCNdzdTKnU9Wxtra1UyyqiuD2OR2lSSsmrtUwTtW0eoaRYrbR5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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4lFkcnohpVchlyVqXkK67XeS21cuIokiKlEsXt5J0sVQWq0WppRFi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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VesbPZcyRaaSNElIFJJM0XKLklSGSJo0ioarJGlARSRJqQw/RS4l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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk81Isaxkd1HOupI+Qi2XLVHZS0SfeZjjpNqBCVEqcGZyTlRIs2W2ls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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHlczAkAxYckjbZCkhzFYh2pJrJkttelxY5t0EHFRsd22JSSSCFUdCcU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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns8lHkbxof1IkmErTdWJcnKqYOy1bqQJKeQDHLepXbjZXUSUkTJKcnO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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2lcjH8bxUOIUlHSJlEpochWiVMk2dIikkSkTbTYkqQISdqRNoUW7ZYW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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHk41AsXHi2i+kqiKKMUke2iTaVeTXQtbbppketpoSy5plvZbkS2kr5S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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVWk4lAsbdilLllK0KU4h4ujISUJyp+Wrr8ZBdEInRJYkUjK2LCmKSNbo
y9E41ihHQiHTtDhJZjAMkox533lfWSpLC6oz34/nen49131fz/Pc973WI/CA
l7SUlFSopP7fB5lbGFuYOdCZO12XIKTRUh5hoPiIi+hPUe+urSShc+X0CWNt
DsxkGN4+XWJUGws8Tyu/xsyiPxiKGgRWcD2VGu89g+lA2sHcaRLpBDK5ZY3w
9paeUEuhwDfWl0u624Nfo9IiPheJkC530nJ3yj+4+dDma8BCChmGBV3Sic0Q
7f4Yc6hYjNDZ1iMBuSUwNaj9fjyThk6h3jVV+2eQ030n1PIRw0576tdjY91I
jRv3cZoS4kpgafBeBTbYtRb11aUU3KP9LdX2dCFy/UTJC/chGDb1FQiC76D1
stb2BBcadqUX7VQayhHtufpZiBcN/4qCv1wMOqEU32RWHChCfobLkz0zmXD4
Xsl076GhYvr7E5eVDVj/wrw+r4bChVffDq5TqMaXE7HlQtCQCt+nNmKRBfcz
DvtODtEI1nNWKNDnIv7ymk6fURLL3o60Oj0VgGXrTsbWCfF+5fqAEYUuLLy5
PDrXgYA+f7dXswYPrHMHDrfUkgiLL7pI0C8h7t8UnuAnRuoX/ge/7teIzdI2
2ZYzCJXEBTk9Ia9g9svmNQ6rScjna56xOtKHR2tVs/8zIcTKvgEP88hulLgq
bSAk99lAMwYHX3Zg4OCWkMlqEiymd21opAB7d9elnjcYAm/qcVVSTDmoSv5Y
ny0N3uRO7SK3CiTeL14cc4iG+0+3L5ol5yO5Q933ZiuNFdnlk0VBD6GkeTJe
maBQV/DmzLBtN+ZEqeXznYaQOxVbvTmoB1XRWltrrIWImfdLcjrfAwxHhlvp
qmE0RNMf21seoyOF8XtTMAXZ8o+v5wybseE3i9b9hBhOTEYi06Ie9LLMhCaa
wvP37xW5DB7Ut/hmxe0g4Dv7wZ6/6x6czk5+srahwVk09p7gt0GTncdnfCPR
LU6bKK0T4HyYEemVQIC9q/ErfbAE5V2X2K6Sf5qZawlqC+GCZPHSx1+R6Pfd
YfPYlA2BYI/csngK5huKSrtk2QjlXN+0KprCxumhOL3nr3BYWumiQIvEkuX7
j/1M9ONtRfiV/FtvwdvH8TYt7oBZCEuOJkWQUiP7Hf0a4So4I3sxksKcmy7h
lsdBlrue75MFFIz878+GLq9D0kGef+oMhXyVqrNkYAqMTqTly0zRuKT980Yn
/V4UzbOY7e8aRL5ObHa2UyniRhylZYJpRLn2Jh+9x0XELhPZjnoCSSVCF3Ut
Pvq7G3geEnyFsa+RYTk9uDrNm63dL0QBfUE+YLgdbFXhTWY1ActguSee6s0Q
dlLJPU/EWF/+TRx+vwH6brr3L0RRKLpaTI568NB1fePjvdcJMC8/ijJp5kIz
fIRtI9F3xlbXCH4XHxFj9nf0TEl8dlHQ8szpgFtMfCG5joDOKYNpd8caOBl2
bjE2oLFG8bNd57E8nFo0UKJ8j4ZHxwV5wxQ+vIMfbkt5IOHDCROsTecjZf+t
qTkFAjEP+sYzrCKhttT69bxFw9gbN3dU1bgXaSfcas9BiMrdHNv8xQ3o23Gq
c5VkvzETYpc/35zDxtGdx+OUh2G3ocjENb0SKp5fiDZniX7tp8eXHLqNoHFP
8tJxGk/fkjKfzNswnLBg0mETiedlm9UKZvn48fltDoMtgt3SF1dn0rmwrLc+
TQ8Q+NBTPHa4/hniHdbeXSoUQ/l0UVitxF98nJNkWgIIGN7z9Asg+7FGpqbo
essQ5htl/dSsVongkKAG2R0Sv8G4tEXgc+RWrEjRW0chlXvtx4JjnRhf2MDK
CRaBUJXL/qH7F3ILG7sjWDTKmHmVNiq9WNJ/xPqphhDLblim3ZkWwOq82f/+
e1QEvy6Lbt+mDlgu7I1cmyBCZe+t6du7OGhzbFPjSfSTFKVTlkQ3QnWxtUbN
gARPtuLdre+3oDtonFH1UHIPP/bSELN2aHLzNOdtl+gjboZ1/gEHnn/XuWTo
UKAzrFykdfsgmPZX2PlGhFT9WsuJG7WQ4RtaNylK5lO3Kb/0KkP7ybxrOok0
lGabs5NYrWib336HmU9iItNKPTisEw6FH7oLWCJU+1sGtI2XIUQ6Mnn0HI0r
g3d/jJ3lw8CZq5ytJwKbL9Ds52VA5usqPx9J/pTMmZskzTRhhGObHW1DYXj7
6Oi33wSo2h+a4cUmkJOVGTac/RqCz3oqMQoi1MVTqoMnHiFKwXr1nnAK0tVn
9LeGtYPDakua+ChCqPZx+1SHWpg+Dizc+omCfHzGy5UsPs6XXVhv8acIAVUV
tnfnOnDnxmEpyxgShhPH8uQDnmH2/XDxzG0xTjnu41/x/xsmG63kjBxp5A+6
a+QmFmNCo8pEo1DCV97b3ln3Blp5l7cZtEnypN+4/cDO5zDP3UEGxYrxUNi0
L0W9B4nuKyb1h4QIGXRgOi4WYIUhd96iTyL8C1e62cA=
       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8VukbxjFlKWsSfsnSQlnqtWbCXLKFUpYWNShKtNp6y5qlKEUR2WXJ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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk4Ve8XxVEJTVJ9UyElpZIhGVJZmpAoJIkGSYUoUxlSmYcoQyokCSEi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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwV1Xs41GkbB/AhIURvZy3JvpGERDmU9tsR5TCaVLJzUXNpt1TS4bIOk2gj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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXlYzAsbTYmULorU0Nee0I2iq2s7qVzpo/VpJEsq+fosNWVc0yIRLS7S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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns8lOkbxtGBdlPUrFOinH8TknPT4UJySmyDGpklZB2zEWWXhlbRTwjN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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k8VO3fHuWRooXKI4WkrGlBpLwuqZSlLEVaSEkqQiUqlCWlooiQSlki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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlGs81IkaxxEOEZ1OSpIoYiXNBzlWWz9SGUJtSihMKqZDllOn6GInWTql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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk8lIsaVigUkdKVdCppVRFKksflStxxQ/bklGMqkuSoS5SRrUN17MlM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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk41WkUvjXMIBkqaoSxJaEkaeyvLHVD1iGlpE0SSpMMNVlStoSyX1lK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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4ldv7xkVKCKUkp8GcJBxTkdxSSlJIycmcBlQi0uibpJJEg6SOIkWi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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs8lNkfx6eSIpfChqlfEb9Ykhpd9Io+hZBSattVupimoqwY7ZSRaSRd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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs4lAkbxidaoRwuKkXbIjSJdSolh1uopSIklbDO2o4K1UYqSlQrKiop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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk81F0bxqdo9D4klUpZMiJRliRSuCqS8EjSJtFDkqUiSyLpfVIhya6U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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4ld8XxQmpqMgYKslcRElIllLRQKJSkWQokUJI9c1UNKCMJRUSQpnH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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs81IkWRxETbeklIaKokAwbim8ktCRbrRabNB5RqNy4KYuLVN5JVOSR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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGs81IkexqdJ6pT7raV26Ry3aJ2Koqwe5FItJWaVkimhNjZKzZaUS1ST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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk4lOsfxqVC4RxLtEgpQpSk0xDqJku2CklaREpIi7RJ1jZaqI5CJR1C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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4le8blyiSooikzBCFjIroo9KifImiSCIVUdoqpSIyKquSlEghMkr2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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVWlczAsXHtl620mWcG+JZLtGLgp50qVQlBZNcSMlFS0UskZ7dFs0UdEe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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk4lQkDxW+mUlFIsjyUbUIpFXpMfB0hjFQmlSUZTMkyIZlISWi5RSpE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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs8lGkfxtF20EqzDq0tSzmWwzBCltmuEm0hJU1JYURWUlTaV15kkdYu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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4le8fVomMomwhFVFGVonKLSuVVUmUZDSsSqXia1RkREPLaFFRVhlZ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk41ekbxqmTpe0XhUrpKEs7bWi9LUWUdYQiWQ4ijTIlSYsoFYmyhCwp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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk41IsaxydH0bFkqxlFiVFEZDt1yfOVFg7dCmVXsnSn6BDti5ZjipSl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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns8lGkbHm0nbUIOHWkVtqSkKEkuSUg5DW22fCoh8cmp+iQm7Na2EkI6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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Ve33xqWJikoqUVIZGiRKRHSr8EaKzEmoFGXIlKTeKCrJ+zVlyBQy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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81PkaxxEHRVFRVDSISsW6pCSfblsjtYkIaUNRLqvYklxqTunQ7skI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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs81IkCxYcil4TKM7bc3sU1pjxSHLrD0tY2vVNambCbkqKQ2l2PtqyQ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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4lOkblq100YZCUrshPyIiJBVu2iHrrIPapHLqiJqy5RI1LElIaKJs
qDBRDqmm5NDknEPGGGMMU9Ou5N0tSimK+r37x3d913e93/e893s/930/n07A
4U3B8nJycpfo9d89f8jJcf7gU3SyVS8d20aQdXmBW0GeCJYBE3KrigkGLhhN
OW3txd6pJS2xHIKJ0He66+d1Y86uRRn6CQQPnQeunaivR02U/L36tQTlv/yr
fFxegBHjtG0XdhGsSG/uff+1D7KHJ3wLMgguVpV9ci/mwiLcRN12BUFOi7Sh
+3ov/M7OivQPJ5ALZOd3+DzAR8XVsbl0/Zt/Q8pkfTN6oqalep4EXv7jw4Wb
ryOXNSbh6RFMbzs+7XFCAsmvBoc56XT9eVlu9io+VpWFzLlxhGDhg/4RQ59W
XLH3yst0JBCqV2fJ9Duxjvl1J9ebQItbgQMTXQgsNbjzMIRgvtdV0yFtISJj
BCm+Fwg0feqXLI5pgtPfHZbHnAjEGvnr79+6C3FMitYaEwLfljVLLaKeI8Mz
ON43j6AgLgfuw0LMqxvbGpRCMHhVg9fxRIpBCzPv7isEZlbc1Pf+7ZAZfFxZ
7EzPK1da4D0jDnsnjO7G6xJ8mj4YfXmwAXbcJ8UCO4I416M8134hOJG1piqH
KN/JHg3noqsQ5dP6YsCcwN9VR+uSRw2MhxedWrqK4JSL48vyFz2QigTuIckE
9wok+7Z4iiE57DjqX0bA+OEn7fZoIXi/F2arJRLwg/xzvnOKoPVuyuymPsHH
1Bdr+wz5WDtjUM3Sn0CFVa7UE3oBXyWHftRaRmCj6ZdbCRHmTc1TMThHYBwm
vrJjeQ8KXyXeNAijfPT73RYIxIiItnzmG0MgcY9gPNOXoPiNndPMSoLtZ8ZY
6tpP4PB4Z+5ter7YztkHutRFGLilsE3xGt2vc9PewB19WJq0cGL/cYJhuaT0
+A9dUPE8PUuO4ql2MBKqaD6FVtvi7WO/EJS+HLWQWYmg0+vO7t9L0OCc6m+V
WI9QtpetHl3nDZV6HVbKRXugdvBFip9RGmsTH1SPcL5Vbv5qgrr49eJHwh6E
RNTOzqJ8eFm0K5563IzSpY1zoxj0fIz3nwTyPXBjqbC1LxGEu1oofkAb/qpd
V6lO9bNHfmXacXE5jFwZnDaq1wiVi0YnmwZwt2TK6ckwrT8hv8/crg3RiXYl
074EJSeyzlyN78EV5l2bE8EExV26TQuUe3GjPSCBfYBgxFCk0Jkmwp1ljpVd
FI9sfaiyxKMWITydO7HGtN9Nno7mq0XI6mcScp7AvmK68MqSJEwGCTI6qH4U
/MxP2tD+qtRWbRTQel4JwoSebxx8PqZ/Tvg/qrdmZvoOpcc4OT1gAFOCDxGj
O5J+7EFso67tRDbV+3xSXRfej3+crmVa0/7WPfZmDs0WQmH++jWhv9F695f7
ec0oxtHFIpdnBgRns5gZ0aHN8Hh9ssADtP6vkev4yVE0PxRHGRSPXmXj8KIb
PNQcnAwrpXq1lqU5+zcXYcqVa/WG4rE3lXyIM+2Ec/e0GaH1h0dCfgj7S4gj
upqGLUk0fzyeR6x+yEN+7YYZn6ledswYIck+fDC+cwQ3qV/VkgKliSI+tE4a
2bKPUfy33B98PV0D+/PHWSFmBMd/0+sW32jGTEvXAA/q/0Tfg/pRylIMMXe5
vZYSsMoSaohzLyYDvHRHyqk/G6s3Wc64haG3Jy3HqR80GLeDbf26sMqm5wWT
6nHvoPvhgHt9aF3EzRv+j6+J05/8tt3Gj/3KQTb0fc2fea8X5D3C/ekVhsHU
jyx5/ln5tbcRoax+z9OQoEhxLuODmwjv37a07Iqj+lpWF7Myqx572D8pXaf5
MtA0Z1FeahcEG/7mSHwIWiuW53uXiRDLszjlT/ez7o9POj+zE70wUEik5y8v
abX0HuPCLpsrXUL1F35tSsdlcwOqFVxPyRwIlicqVcnFdiP9bfPIOOVTu1Nw
M+dLIT5aX4uuoXinrn4daevvAkuVsyo5luBQbquLyXgLPhGlfZq2ND87vAtK
WA8wX2CY/t2Ifm/tG6/ZVAjtQS89T/q92ayCb29Sa7Fyzb8a/TT/z/8eJ5rz
ko8j39TerKb95FdrZHLL8+CwX5JSQvNapurc5JbJxQZt3T9dqP54elU2EesE
yOc4NF3fQmC6YDihO0CMMPu6c6b3qb6iXGQFGj0YTbn0ZVEaQeWX8UgrEylS
o2wNzWme2o8eGAy2LQcjfHughOrxfNSsSxt0OmHVt/9Q1k6avw6eOhanq6Fo
V2CWTf0u1lG+lZbNw3D05CtDipc1PSmrqE0Fy3zE6jPVa9Ru31db6LyofnJ2
bibl//K6pmmHpVkIcmOiheaHRsiScjaH+l8qfzOW1p8YUd/hEVkL+6injUdp
vYFCjbgNmR2Qv/7osepu+lwec+wgT4DFX9kvQmi/5N6xlg1WiSFrqugofkDz
7sOFVxf9q3G5ZKdsN+VDty+7QNWoCqVhxRtHKd42qzY9caAQBwV63Ph4gnf/
FqXkJhfC4WPO3k7Kv7Vy5GWVbCH2FNnw22j+qd16v5nxuB3xsph/ZtF8Mhjt
OLPWVwLm2N8//JxJ+X2ULrXO7oXdmQNWxncJZhp9D7E40w9eEqczl873mRkV
Trt+EmBbW3agHf0fUAu4yC1zrMfFhujXXjRPZV8qtTuz8lDHy4jdSv3bsO/Z
nhX7m5CXZlwsdSWo2Rhf1mYnwTfxuMkKitdSd/b79ppeMP5IvN4aQaDMDJW+
3ClCw4h5VhGdl3NVu/KZfY3Qmwgar3Cnema2tI1SPQvZPpOqNC/UfK0+rxgU
IGEh/jhN8biZnJ8ekefDk7Ppxm46D4cPeDYWjdJ+7x7f+uQg9XfI9mW/hFM9
O7JzjOn7eVw23/jbDZRabFa4TfGGzSwoG0uQoPDXlOY77QQm+T9zfIkYW2Lm
shbm0PlaxPcaEtQhP9xnzh4rim9Ph37Z2ybMfRvwxn4j5dvVRcnHqQ6DLy2C
5tE84v1p+kLpbDJC5v/xsJTq590R46VXWvjQVjgaMBFK8H8AXro2
       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VW0bxRElQ0TKG0lIkkQq1StLigxp0qBSyZSENHnRpJJEiSIyZcqY
SDIl8xTHdM7BMSbT2ftQVJqUfM/31/5n7+vaz3Pfa63fWmZ7dp+DAB8f33F+
Pr7/P0NPKYfvNGlD+uaeTXwCXHieCYyNn+nBxbrY7EdlNHKjK39khaaCzd0d
9mgujaq1Cz7VOJbhhWtC2JNBCi1+J2z+IAWzY+d/ObOJRoIwo1rzRgdOr0/T
0s8dhE/xfuZfdzZGjP/sO+LNQ7P/8fYs90bwtc+LYSvS8AgdLcroqoXKFSXh
bEMainlWbXHFvdA/WOvywIqGf9sC8+WxLLz+zn/Ks5qHbIlI5zc/ijBJCd3p
0KHRFZuvcqOmDL1bJL8bLiLfl9mblaxkQ1Rxyed/73MR99+bmzsrn4Et96yt
dgMN9tMlBoNXO5GSGievpMHDjXBFfvHfTFxxHT8cKUwh1/lv3DO7aoRoJh9e
vYbG1Z9vf4uWclCxcuVtiZ9cOJk+zm6axcKoh7vw2g4KOy9l+PrntMNmnplO
1zwKec9tdNs+doLprs+LWEZDda/hnqrLHEQX00N/3Eagseyn75BeKyjq9qWP
chR6/PPWzLiwEZhlf3SFLw98lK6axLkcDIxbTEavo+Gn9XD2Em02Vn65GrVj
Dg+xbapPtC63InSfa3u9AjmvvnnQfJ1mXI0bW3dWnovXZsefPytvgFq3eeHY
ZQoPo6o81Vd3Q756Q86J2WNoeVx6vupLEoJS9ceiV9KIrngprJ7WDHczq1Wc
EzT+DJzytnSox8Jbb2XvC9IwE9yzTqKFCZukdzv567nwN7r9bsFaDl4oZmT/
caBw8eDnihBvJr6vqQmjrMn/mAh9MujzxYWO9ux+JTLff8u+lO9tw84o/2dB
Pyh0uYo+lW4rQHrxP59Fb1GouhCVreDOwvmAWcYmS2nwnW1Wv1wXhATXdMs0
DRo53wVj0lJa8a7ZVrChkQenL5mm7MYOtDsI/Kbkyf3b/PXvSW0Cf2bG/aFJ
CjZa+yamrhRhANYxE28pGKnYZxd3tqE+39pLbCMPstLfOEbVHfgl1mTXxBkB
w8jhbaNxJWK6+5e6naEh/KrW6Q+jFUVHjNe35VIQSo65GfW4E4He+eNi2hQi
Zj851j1agVS7MMfjNykUW3kafJvuhMeKgIl/yfw3r349vPBpE+azT5u8l+Ph
Z6PPUo0LOQje++8cV1EaSrKK8SXvWjBUd2FI/PcIFm4VvyTBYUHv8oWs+Cny
f3lxUjoWHdgoWer0ZJTCuJbphin3Tjgk/mgUP8bFp76u1GnRbmyeSRu2zR1F
dtTLoqMbciClc8S+4l8acXv0nEMKGiEoXHL65hYavL3O58zQDV8L9192o6MI
tii3VTnZgu9GElFBsykEM3aEyIinQ1OU73PSZhocx985PiX1+JBrskfXhHy/
7JyfYmorarxOOaSmcZHneeOF48tWaJ3p0LM/wQPH/1HW4ZQ2zBvXvtRfTUPr
xEvxU/rvEOWa3P+BpqDY0sA86fMWf6qvepmb07jXNWtM5X01fjrWLlVOoKDx
/YHA3rwyfCm/K1TmTMP3ToPgUulqiERMq25N5mLaRMX3s1wVdrP9TFbI03B2
za03FGyDm3LK8495FHwGSkNFnNnwluB3ev+Kh9TM2hfit7rhYtI4mpI2hriP
N05vcSmB9/uK13PEaVCsnMKIrHocjEmyWXGCgqxg3k3GDjbMrqTZWg7QYNZr
/FDewcJTyRc1F4t5ODZX4Icguwvu+1vH0rIpcPh2KRaeLcU9oYGpnc0U7Nfe
n72+nYNK+5oG4wkKGckcdtx9Ms8+PXaU8wicdbxKrA6XY8+pwsboCBotonpy
mjfqsWt8bJt9Fw2V7n2tMWEv8dKx5g1jL9Fb4BrTPbU9SJp+mbH6Ag8+NqEL
drHikPkhWSRJm4ZnOL9f5MJ6yJx7mHnfnAeRqsRP9uatSC6djFA7Pop6/VR2
y0ANtlq7fg1yJH79pvvaoV8MBP0233i8ksb56olSc7FmiIVf985KIvPdeHe0
5VcZfivrvLHkUOAL+7rCbVYSROxtm7uJv5S5qOr9lX4HRmJngjF5f/PNyPur
1dn4kqPabprJQ17Lad/1MU8Rs+KRhQDx8/VNorGrFNpQMUtMcX76KJKcywZ6
j3LgIpU4U/KQhwV2F12ir3fj5Iedh3+EDsO/7NP3zXVs6PsLLK56zQVfou4e
MZSCmS65zKmYhv3P6PzXDpnwlqZ6Koifqrl8uGtpXIcDCV8VDE/RqJuX1clo
rkdZsKdSCD+F8+edrugsaYfwOstLDPtRaH26+70jNgndY8slwpcQv1vOyGjo
rUew7TvZQ6YUhsLaX+WyCsD61hkSV0shIF/2rp9eF5L5r7fpn+fBym5AJ1q0
Egq0w+bXATT4S94frr/IwEvuCp8ztjTGErYq/CNcC2+5oyzbdjIfT6u4k0zi
793HohuNeaBWmO1NZbdh7pdMwYQOGql3ZvOvCmnHnVxj27/mwxDW5Ns5dZ+B
590zQzV5NMTmG/lMbGbimo9Qq/oF4oe+ox9d+h0wpGxaJEjOnxoVf/x7fxNu
BjhaiEvQ8F4UXmBY2ogffr1HHV25cNH+ZTuZX4nG05qjIS/IPP/OPVqx2xJi
X9y1fpPvXQ6eaulqbEbk34fxNmSfQqvZG4f/Y2JXPoZNr1NYWD9k9yuoBzZx
9l98NIcxWqO4Ik2tAbybYX5WiRRUwO19a1KMr1j34DjZD62xfZtrs/MgJsUJ
m2qloLlGd1yhJgdacmBrkH34o35VJFG3HWLPO36GnOXhaYV5slBSG0bMdhVt
reFBUazshtG2SsgXsrzCjtLQiEg4UETl4eL5+VcZJK+N75RccOG1Ye2DgiXO
cjRMbAdnO9C5CF/53kLyEo3gau/l/kRPTtXSzMJrXMh3q51/MqcO7EuIDSV+
O7KnudRQqgWl95RDtkgQf32hVvz7ZhveC6dGfunkQrFt22B4Gwsi5T0GZiwa
2a206zMhNnT1gvY/5FKglmTU7+2Ox1qjuYrWhAcqGttPlhf2wS0+pafqNQ8G
mToCfzxbEOfBH1RK8jpY81dO5ggLPYGZ0unRXPwNVHs786ML/TZpTSWKIyi+
7iJdW9SOiYM2tp4qFBb8k/K43IsNHYFHAb9Kedg8ns05lt6OnVpSHxU+Ez0U
LXp9I+kedK906VuSfHzsUN9ePcLBQcsW02dJxO+26g6qujGRuck7uIrsn9TW
VkuDy+R/rJN0yikKbteXzJQyWhD8W7f7ZdcIeOe9EnMEuqE7eV5rEzlvv1Nw
vZF2N1aJGfenfhnF6/23bnKkehE96Louu5uClZ+FiozkW+QGFJTPdyP5Ujja
OG7VCCtZK58HoCG/1/r+DQ4Hj6vFv7leJbzVZeB+U50FhVZ6/csjFA4KyBVc
qGRB/lxwYC65n6qIs2tk37Wj7dBajxMvR9EeP37pZn0z5g5Px15bwsOWwB8I
jKmB3unIFNY3Llom9b/ZkPssylWrtb7HRdfVzMqVH1ux+FWodwLZb++WDbX6
3E6EJT5Iu/CbAjP28J/TQW3oWLdiQo/wXOZiMVXf3e1wSvqqVEH8Vu/S+OhH
KxaYlhf1JcNI/i1+pqMR2QLVmJQHjEyit1NHi5W/OSPYU3KTKOGXdY/2Olvn
t4MhMvZuXizhHTPe813xTCg+DB02Jedju2s0xFu0Q2hm4xV6L8m7bdqv+B6V
IeHe3ZiL6jQG0u73S2k3YI/EjffKZYQvK4vMUdmIT+VWoh7lRJ/DuybcLV5h
1fRTbCE861Sivu+WGgM3RB6EyAlREFtT29z0oxLx1GWNPWk0Ji1s3kU+aYXq
yP1GjYNE/z1GgVL7GajYt5WzUYaHDUU+S9J7mnBruc/G9bI0rK0XjVAf22Hl
disnLI/w547PRU1utRDzih99QPI0btzRKUC3Alr5ZYxoSRo+x86Z5vYnY84B
WT+bFTRm3zkjpzrTgUyOi7CAyhiy69Tzltv1IeGCq83JR2Pgs73vuLTYHv45
27e7En/xmzlye4lIG9a8D2WYBfMwfERTSbD0DTZWG7zXkaJRnHskR/5ZPVxH
zN5fVCT763lSepP8czAZh3pdyPys79h6CXjVYm111dT12+T+9Q5PlbhnIHyt
i5zlLhoGgs9p9cB0xNmGzq8k/vBa0YHFU2iEj3xw1mAQhQIxuvXt/jxUzWVI
jRD9W9mt2aizrxVLv/Dx54xTkONeP7RKpRlqhlt6b/7HI1xqbF9f8w5TMsd/
nrSgMGEfPCwS34XogkO7FHKIH2R71Y35hiGENXtiN5lnz4NRuiWqE0kySuFu
1DDuTS7eJZ4ci9XtnnvdCU8fGouKNCD+Mk+kb5y5k4dZfyndmYBWDO6t/ig2
wUVduvnq7atbUTA/Me7udh5MP4/NGJmwUa+VG2oSzsW6z04L5GKKYLju3oVY
ch/2n40KrQOzMNSpyydD9Dj82H5niUwnxCOyEizOc6E6VHWUwanHtEtvoOFf
Gu5a3CdR2vWIHj2gsl+ZQvenr0X5Hl0Qq2PMfpEyggV+CdMnP8Ri8tRMdtxi
wgP+/F48AQZUmJGWlaQ/uZze7M5+1ACb9nWJv5poNDFfnHI+V4W1wZqXXUk/
8zz45u26Wg6WfihSkV7Pg2aIMGV7tgiBHk0yzdsIX2nfUMtVzYNZnoXC9EYa
SdeFF3bxs1D5x04xYmwEZtLHknbObUG4yJ4Ps9VoRGj/lCnq64bnMc2twXY8
yBSlPPO+0QvmpF5S0CMulDMbrAVMOhFza8Wb/joezMS3GK4g+XhbqSk7eITs
70erxoLLFzGgqyiZQPJm/z7aWVOa6O/5yPvSdxTGZBNVQteycUKI8+Wt+Sgm
N55SruJVw2WZUe1gFQ2ba38+vhDowmDYVknqF+k3n06FZeIVDqxK7u8nPOz0
2UEn4GEFPETzhTkPKHiuXPz64KYmvChW5dQQPp4c3nTn38hs0j8CfGkz0nc+
dnebpJN+NoszT3wN4UEVE/VH91sgdGJHX7wH0X9fQJOOIQfCzn9b18+nIHj6
nFmQUQsaepcWb7hFIzGQ+V3iWgcuhiRWHyZ+M9TjbXu2oRw1gyuzOG9p1Hwy
S9CqZWHVUlE1j2AKj7cLX9sjw0RbxOzbEyPk/Q0b3S2Sq6DjJH1ApY7G8bj3
/Em+HdDPV8ut20/6iHmUrJZMDZKVq81bP9N4frn89vz4OjAmDq+0IH1BXGL5
hflrWDg+mCq1g/DnnE1H1llo9yKtbkNKZhwXnPB33xpUGxH/0Ey+g4+CpI71
ohN34+G1jPUzkvCASr3koORgKRy/PI5OIjxVUBcWNh7MwsRc5ubBxhFkCz9S
/3S7FWW2zbIK53jQfqC06voHDppHDb2ySV8TztW6GzZSAXUP64+/SR+gvDjd
fsiGt5+O36IqCsZrHXz8LZvg3rtZVdyF+MGevgz1kgKMnfZwSzGgYdi+dd5i
ERbufHeOk+8lfU4p6c773hxkyAwe/LGa8Nu4QtF/ZxloUc6nnp8j+7Fnq0zz
8wLU+LDypLTIPrpYHxScyceEW+8N758U1I4zw81qqvHw88TgpX4abOEnj1be
ZqIkI6jpsycPpUmLtir1NKLhnbrSe9KXfe79/a93Rw1kbyVlLHKjwLjrJOQf
XYcy2Xmuwlt4KKNXiwl1PMDPQvb2KmUa/r8m71IHGOAVBps2epJ+NCBjzo1g
IXl126VlLB4++hndMlvQDd5X9X0LO0k/CtOZZZnXhuAtGg5TpJ9aXa/JkhXp
gELv9pd3Fo3C5JyVTB040J+eVJ1XT/LN4FXKti2Z6Dyj9hQi/+9nYY6Gi9NQ
VLjq6g+Sx85CA7uXFGdjk++KuQ8J32xO3y3zprQHyS/u/XrylMKRb9O5JiWt
WPJwMswmnPjf1dXO/zrUYx1D8FviFR5ylRsnpdpZ0DDstH1D9HS6UyZ2gvTj
Q6wnolqRNNqE7nrVtyZD2NXt6yjp87JzK/0/G8Rg524bVTuSdzbpQc0uG2Ox
9oXD9q/EDwo9Puycv7gO/dR+71Ap4s/d12xdp2shMm389wPp+5K6odG7Sf5f
02Y8fz1A4Xn83nazE0z4bJfaqqxBoUP/3tXBcyy4N1a9udpHY6f/yZQT+R2Y
n6IYXBVAwWCVrLV8fwm2Dz87f5j0AbHRglNDJs34zh86/R/hJd8tUidE9rOh
1mhv0CXLwxU7n7fat6thvP2fycBSCts9GfLXVZj49liaSlk+AkHpgg9MoRqI
zbLkO/2E7OfTLKPlyzpR4+8x2CE+CsHleyIWZZG+VK0w9ZjkubXikgcPD7zB
9yOhhlkeNBiN5UMl9Q0Iq1ClFhD9erzqsvbv6kBD1rwljyuIn7Dj+nhNHPCy
g7vaZxOebT0Q/BxlaC64vXigl+h/v8UOblIVXjuIFs4h7ws7yRzR9CpHSJLq
yStDhFfalRaExvUhfk52g8emMXDq89JLemshe7XM+ZkQ4b+QoTOXLUKhpa1x
vpDcB6P8g8HCg6149O6xudJj0o+nVj2ZSkrBsgNJJ4+RfeXz9OieYUdAzy5P
S4nk4dOodAdHzRco2H20YhnJj+SwzZbfz/XioLLi9Lnt5D4d/8yFcQli5lVp
LX9N8mPXBoltPBYiMhYxaF/Cb75yvbYPOxBr2vAhQ2YE7vwHrF7lViFSRP7q
4e2E1+6YBSv1leHbgfWrDrXQEL3+9Ul9BQchtwXub0vhoT884cfq8FZoTK0o
XEz4wNA1c+GMQhcW2ug3N/5D9Fb8d15k9GPI5qdL7yL7HZHYN+VNNyGj9JH+
q3AKk0x66OkWBrhy1c4vp8h5nXaJK9hlwqNMwfcw0csnV1N1zfFWCLso7Z1P
/D1KkClz9CkDxpMhCo63KcQN+Gxxk26DwJPh5p4oHiT3jQek3kxBi/am3F4B
GuF2Ac69fm1wi2zaviaUhyTdWQazrNiIDCqP8Jflgjo/dt2pqBUb+x7oDZwk
ffvi+q1qJQ9R7NsVG0DymeNcZTrkxIRey/I7EgqkbwebHnjWyMInu5Y348RP
ko+Jyl760IKDP3yV5Kq5SBJ3kZ9Y3A6R7JWX7v83iv8BrsslLA==
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81IkbFvJrVwf9dttVm3SQol1FbQoPKUelRJION2VDioRyVCuR1eQI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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk4lAsbxsd20mQ/keX0JS2kJKVIcqskpEjZsiQqFKVIyhLlcohWkWQy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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk0lWkcRqncUk0pXLIkWySiIcs8inSto9IoS0UmbRhNRa6a0iCytEgY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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VP8Xxok2SRSVomSJb1qIKC2PJC2KLJGSlERa0IIWRYtEKimECpEl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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs41WkXNW5JhSnky1EuUSgxpENlUYqvlEtNeYTKZDRSTY9GJk5F6IIi
Uph0UC4HDSpkJMk9yeU4DufoYCK/i1xTLtX3+/7Yz/vsP95n7b32Xmvr+Jx2
85WWkpIKZuL/7+LqBduGXB/jzK1rM3ItBLaZ1oatcJZg/yxnLit6BBInbvMJ
ohOv8xymDWxopEXnSSIO1GFAjdWjXkliTHuDZG9yOZqOjD+5qUaCC68dHKIc
e9044waGJGoOsRwPJ1aj6NkGKxcOiXL1EI3KlHY8esJmm7+lcErBxronpxVf
HuumBrEpTCcnJJ6ZEIC3mvtuKpqGo//ojYr5FkTdbl0+VUxBc2284BP3AeTP
R2Vvu04gWOKgYGvMxZPnpZMnzxCwtdKy6fpch6S+qCqHVBKqK91/PLX4NVzl
SV7uIQqty2z0JoOLEa6xICO7hsBxmX8idY/zUXVdbXVJHAX7o863pOxEcIq8
2fVdZQRfJJGuEqIDBtUvrLxBo6zF3DhnshIatad4eltJtL6JMeO2CzGo7fu9
rojGDXaXSowdH6F65gfU/Wm8n7GzHPRrx9jw4mdJ8jTizppnnxWU4F+XtOEl
C0kUTn8+nBz4EIrzf76eZvpRGTJImec1wXk4XnfnEIl8F4urC0UNKFUtjtzX
S8L2zWG/zvt3wZUOsPf/hcDfVVszu/3eQfyoc3MCawSNxUbaq7d0QGamyGvg
K4XYC7wJs/ViPDU0TSjdzuDrsJLDO7i4IVD26v+TgEdh8al4s24YLNHfKruC
hqjUkN3c2wWjxLQPwVdoXPX+qv82KB3vy2T0eoMJ9EQbG/Hy2+H74ojX8N8U
rLpV630cRCgQ+JZwdtEoXJ2z4FpyPjIdWVsOlRHYcbsi8kyCAGXVJnnxjTSK
WS4bjdf/gwu7+6fuqJO4IOlPwcZXGHLt/6YZSCJn4gfF18kl2DC0adZPicRZ
nmRZwuRL9KYnn7iTRULbfvkJhT13YXqpNVXJmwB3UmGz/8wjGBVs/uO/DJ61
TNtk09k23GqwHLaPomDamVJ+UfMVeGsEL84z/7fUJ3kY5DUxvM7N6y+jcGFE
rezB4S5Y2sSxTdJoKFrO9qi3VkMveqIx6gbDf8Bc9priFlSxChw6vCm4JG4q
FTcXYNH9y04H8wk0WG6MXbXiOZbODWdQriSS1nWe3HOuGto6nwN6/EiMh60N
S9fqQlbbjpx5MxoRWgMqeUEdkIZxgMiZxoLdmRfZnSLEhJmsGR2nkU+Vze53
eI4T0tKiH81IBGX12HxSq4P15LaVF2kSaz/MlEfk8SD/vUVTKZXZFyrN7oxe
Lv4avznJziTQZ9780GxaiKRR5UKLlzRynnQ92rm+FsHJq0qt80nsmgn79vjI
UwR6CVfxvhJgf/yh6+N0DZx9qt3jGL1EHJsxXf2+CRekNFlPj1NosI19cc+4
BLWXPX/1+UagIm18X35bF95pJn5tWE5jLMCnOai1FrPOH/KNmPoe5zluT4jp
gMKDhetCbSlIKb1NrPTjIvT+gXQxo8+PByTmK92fQcnKrHcTM/+zW36z88vm
w3FZn//tZxTc05psd7qWwGKuN/feJwJF7TOOhpxqeHE8lEeTGL0ot9fz+7Ih
lmuARzwB1dzYvaZ7G9Bwd+HUIk0KVSfGYg0/R4E4aLLWFAQuvXOL5zaHY/BK
9rEj1gT2q4ZUKfr2IvLlzZpHVjTuNNbvUpRvB/9nW6UwZr5lC3W61l/tgrWF
usrFezRcKkX9rIlnWFG+aOiuPgkFX+ljT4f5GJl+++/eNTSO1+jm7uMX4ZLt
Bl3lNwRYoWMqb5bWYKf+tuE3mSTi6Gi/zTvrcP8BZw8pR+GJaXd4OF+ID31k
doKQxnxEhbFJUi1YulLpVTGMf3L3n46Jew5vWZ+BKUtGD8unGy/xq+DrYTFm
50mC7rfLy9SvRWTV+FfDChLip5Gsg1vrcDxlgWe8gOFH3BySahUPo1LOvTgn
Ai5/GIa+miiC7kuZ2YhhAm6KGgYtv4pwLSw+62gAs2/B7EC5jFZ4fFm0qPh3
pj6u1tTiECGOWJ7ylJVm/E92VOdGwWMITHI2a0iRqPOjTweKmiH2+KsgSUgi
WCsk+14bH9UDSwqV1GgIZdj35/bUQ91kmatrGAmXDA+nHUqZ+Jbhu1+eQ2D6
spj/QLkdEc1uKXLdFNrDXbS2b+qAUkWGfVsek3e/iB38XYSa3N4+gQuNgtQO
7V/kRNh9LLbjy26Gb7fqo/b7SvG+6fsr9/8w+HY8TphcE2i1jRxVGQrXr3zv
5U4JYWuQeVRbioZ1AH3OkxJAty9gVehDGrO1REjf9g5U5BSuzUhl7sGSQeel
OinwEcpXfmP8NNhK+FH/lggTJb+dHCFoBFS2zEynN8H/J6e2c7MkiiVOfYmj
jcgIKbvo+I6E+0S5hkpePQbFJbNBiylYrFOMGuhpR47bCn/Z1xQyAmS9NQLF
CD9fvlxNbQQBnnx5j5Mvsfu8bHTWIRL/A3X6134=
       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk3s0lAkDxgdt81EiiziL1RYhK+NSSvUUm+wONWxXlWXQZmOUbpI6Uy4p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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwdlXk8lekbxhkxSUhJ2qbGlihKthFdUZEUR0SFMLI0HSqpiUwSEamoNEK2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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4le8fltEQmZUZEUqlTSrdKSUNCZWWSgNJXyt7hUooQlZSZFVEw0iy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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwdlGs41HkfxtFGiSRE5dkcSoe1kV0ti+em7UAnil2UqKnssNIkuykRhUiJ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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs41Akbhicmm+2wdkWLfC5lYwtpk5DtEfow21UkEiEVM0UOySGbsJ9E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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8VWkDx+2ZdildRhShZElqEvKLSobiJlkiUiqpKGV5LUXhFSluTV1Z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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHk4VG0bR6VdFIWEIkulJB+S/FRIKmlRqDStJCWFQkmKtJAtSSVJtmzZ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs8lOkbxu1WyCmxJKkkpZCmktocLr9fJctIyJRjckpJ6FMW22EcKiEJ
WdFBlORMoxhCcsyQ4yCqyQ71vu+I5rPJ5tC++8fzuf94/rjv+7mu6/us8Qy0
9/lZQkIilD7/1WIT30cTgXxUnIqvH/xKwfyr1oT14n64jZoZ/5EkwuTx+P3S
DgNIYR/zkMylIBHWzk4+cRNTu94uH3EhsNM2SsMw8yHEv60b0UgjcNr/6NJY
Dh+nZn654kVQ0L34ieXhOYD5rS/Phe8Qgb2fpTA7+CcqgusFFa4EJBRVbizz
uIM5g0y7v44T0NzZbH92YzvU5ZwfLQ6lEG/3rUpo04EaqVtPD5ylkDWx/YBp
ahdsv6/dZztGwbXisKGtRxfqa3esj3tE4fDyPEZfUg7KDQ1X2iQSMFFYUGO0
rRYnbjz1TTYmoS1t2nlkohcy4h16OQEiSGTaf3wSa47Pvs7Vh9YSqLgW7OZx
9iUiHTd7j5wnIaF+T027goOmfWrqryYJBFXLKwZf6MYZdeb4EzsKQfNuBzOU
O2BgI/axsqDAlkzclf05Cp6jHwMfmxAQP1/VMNTWiwPcvf98qqCQxvJO9R3u
A6ME7rVCCiPTP2Rn1vOxwMRK/h8xhbuh+bJRgd0oSi+cP9hKwS/uqtQbJh/6
l2VmNOYoCL6TW+d14iG0dCTD9hJQ2DbGcknkg62sVN7tK0KJWdP9xHel2Gjm
p8ceJqAk3715ZEsPIqwyogu/UBguVXm1VG0YrtyyO+2scchI+fX1JDxDjS9z
XPiDQFnjJc6QUS9Esnp9s0oiVGYfGqtV6MGYgzX/cjq9n4bFcsbUAORT/JQ3
ckWoM/COebM8E4EPEioCgwg0DHOq9qsOIPaMK3t7MX0vzH4lM3kdBY+seUlW
BEKFbX+aMVowttPAobqdRFkdKll6jfD28M2tfE7igd0SY3ZYEUrC1od9ekhg
X6Zsu6ncEJQORaap03qFrnr/wV+bi9M+hqwDtJ5+VXcUjbL4aDnAcynfK8Lz
QwRzHWsAC+O1zDQeiiCuD5lOzGjFq/fBhyNWUVCcULA6uSIbp3RPVS+II8BR
v2+gat2BDxcuStizaH2GlFnpKR3Iywk5WLWGQs5NmSWLfTvhv+m6bEgeBeHz
wLQJ515YNihzFWg/K64t775+Nw4N9eKzAlqPzqaz0a33GnCXI7Unj95voSti
9zs0IWDJfYdlHBJ7NC/rZfD4qGZNNm/+SEE/3Ph+ymQfOOv8I4dW0n50WsJz
Z4bgzKdYnSQGAb9sl6jkWw3waF9a9hPtRxVbz02Cha/gLGfxUGBG4QyDbSOp
1Aob4tyWo84UQkkZnnlNDaqryo+puJAQqhbWNus0Yf1uqVL3HhIZ3n85vbzd
j9Xye0Z9dtH9bKX+kLUPQ3xB0vUHW+j83ZbLFXrxUJS7TOBnQOFG8N2ZkPQu
mHFGjX8UUqgPJj+E+vMg/Sy6vHiQRF5p64S+fB9iBOciVQUUNHcrnlr48CWc
f8paHXCHBDvEyl8qPROa0V/nwkMJhKceztAu6oFPsdP78BYKBo3ZMousXqA8
rvKSeQAJYyObtxevvUErnz+X7SMCU4d0iBLV4SrIsjVHSWi0Fa4ct+9BS4jm
sptxFH5+96J5nHiLWXLyxVydCPKvberGdOj8DFxJtqujkCosWlRg1ADrXfnL
OFEk3L4cOTY93gWPWC/dp9MUNiwhE25WtqHXTc5yXIqeX/IoMZKSjNHG2Rup
tgS0rUYu/j+AB4Mex3obNQrTpp9T23fXYcot/YxjMAnGouJ4Bp+Ly6fVNT1X
kNhalLt+xrQTtwtcPEdeU1hROqnz97cuFCRVW3bYUHAWjK4uIVqw+z0vP41+
P7+OkCyufwf2c2NmNgfR/FrlHZEgaMTU/9omI8Qkcj9oSpau7McO7avHTd+K
IG1eksDX7UfykUo99yci3D56NW2ooR/z+Ua9h0JFYJAxa07nPEfjmtbI37aQ
sEzflpFW0A4lrV/ErecpfHJ6zP/q1YhLIXYr9maRKJG7WXi1rR/qgh1KzBQR
xiYFcmquXajJ3DySeI3m27tbRZecyiBdyb+2bpTmzeS9xPecTij+Otjs7EFh
qZZx/rxXFTZtOKliQfd7x5BJP8h8gccD5i69bBJj4f5Jtxz74WRxvFpFWgSN
XA0ZH7dODE7kZxTT/Dss+bvXLaMybEjZZ8R8TSDGcKdYcPo1Lsj8rdzqTuHL
sZYtSsM9iG3SXeXRS2FGoVh8UZeDg8d1IlTpebgWTi/ZUt2QSCguOE/zP8tr
1ne1Vh9SMiL0vndTSLz9cWplRynUBrmcpmb6v3nb1sp5xIOEdutTE30K2idV
qxuZtchK6M75yqTz+e7Nj/St/dhzYiooaIqCVjMz8aR1A57qaiSYdJMw6kh6
1pL2BnOb9KMlh0Sw/hYZE8CpQ9rMeUtHfRLTLMlzV7p4mC1bzs2LobD9xO8e
ulcGMe0Q7b42WQTzdF3hpaxOfPfrjmS8oPAvLrrKKg==
       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk41IsexhlOOVqMrkKrSihpOVGK02spWyXJETq3qKgkS1JCQuoqky1E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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk4lfkbxlFkL1qotAhFUeiELN2mVH7TQqJSiRFnbI02REj2UooQQv1s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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk4VP0bxi1FWSu8lSxpsYQiKlvdklSSVNrtpOXVhpAipRTJLiR+kUol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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41Gkbxx16VU5RElaSSDqZ2laEvnTUJFmNdWh1QE6pJN43ZaU2kXZH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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs01IsaJXnVHFERbuHIK8ml3DxKWyrk6iV6ODreRXVMDkWRdxQlJLpx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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk81VkfVqFSI5WlTbpvl2uJSiglzx1U05QZyYTIem9NFMVNQpIw2RUj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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VG8bRlFpjxApSdJCRZQfubWIZE+2UEQkSwkpKlQqImXJliWFFoWI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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk81IkfxscxZBwRW8Ta3ZxJSOfqeLalg4rZhok1dtWvciUdUrEiR7Fb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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlPk/1IkDxociMSFH2QiFtk0hR6GpB6u2VTk7djuEkA41MkQkSUWXLrWl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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4VOsfR0Ql2W7WSkLTjRuuFlsfqVuSblq0cUuoO7qkoaiUiEgpspat
SZSKCakQoTEyTMzYhrGl/W21FZX0e39/nOc85znnvM/n+9ned66H36a9MlJS
Usn0+v/dYlGemntrE+r/Dlind5Cg/EiwdcMTMd7xo2qZ2QRsXVM5+3fR8A48
c6NFn0BYbZN/3yoPzyILGVOMCNqZuvlnyvgo+yOyJd6J4KKGun/olW6oK1bG
r0ghsNtnZEb2ivDWVVVz8U6C+hTeKNoFULR8mpLpRSAoqNYa/J2PNWk1cvLr
CZhiO19lm2JMnmTreZdBkMJRuzc4VIwSVuRA8gKC+aNGVwR6HTBauDKTUUDQ
WOS71+y/FkRukTEbjiCIV/J5eXFpD7QfKViKnxNEq560toqow7vIkSXmmwhG
Oj833nEXodzKFHMDCbZz1TLqSQ8CWG9bORyCiAPhe9SIGKzQvKj6EILn67fa
RTp0Qy9QsblJQnBE8HdGzfY2HCgQKOTuJ/jX4GlMIasN2eo3JndFExzKVfb4
8DYZfVMmusTzCK6aq3Bh0QBhx8s1ufYEB27K/fNYVYL93GsnumsJdDsSJl7W
V+J8xldP7hKCmli3rzfnFCFwj69sAp3fJ7NwZPynBFzxN0ZFIkFu/7T3JxMF
kAtaHaX5N0G686qezfFVQPFA2S1TAr26ybzy4QcYFXqmLviTzoNUrnXsDQjW
LtiZPJ/im2XMuhCbjd9jz4+OGhIM+e+zr6mWQKm2lDWaQHDWcxJXd2oVOr5F
1DpQPFKqSsKFG1kY4k5maFL93bydTH8VFaIq4bnfuDHBbZPUlWcrOXi/NuJk
zu8ESS89K+5+EqM59NocA2+C6312fb0pXJxJDp4JawL1MzvlJVXd2FXODZcW
EIQqNwhHdAWQDiK6QS70fe9X65UqbZg8yGO/SSVQ7hnX8dSS4EOu48xlXOqP
kbOfPRLKYKzkpDVkRrD/IyOxUrkVrV4MK0XKDyOgsffYP3y4loZuG/6L4JNX
1qyZzh0orXulHZdLn9XVeVucRXCccmfMK5jqudNs2rzsaoTNgoeZLcGl7GUW
T3hPYFgQXJqxkcBI/YHeK2YzJspNfZYGEJTsUeo4rdMGByeVXzFMgjrpnivO
3x7hhlUgZwPl38nASvzAlIfH888tyqb8aQZod+TMfIhIVclG+T8on5a+xstn
cyBxdPHIofqGa+p/zpzVAPdtTZ4+2whqo6wfJ+m0YK5MUFZnFM1b2xwLTtct
eHASa6Jp3vyPuO302yGGuXW6e+9xgidD6tvmHyvBlfw7jHfmBLe0nG8nhQnx
URRy1Zfi1SiftISd3AVlSeyMjhgC2aAxrRWt9zBYH85WWEjzMEnb/9AFPrQP
P00zcyVYZFYcMp4hxN1N9xP6qb+dmFNlRWv4eLnP8EyzHcGH+fNEUvadWOJW
xJr1mOZXFGZj/uUpyn4bYEXtJRALXqkZ6z/BVCNXOeZyAovYdv284CbsL1Lr
7/eh+t3/buL+Xy/e5NVKLy4i2Bk1Y3iDeid2G65/YUfzd0pvth/7eAUOHWPi
NNU3MetbgfRYAnYV1Kfa0zwpPLCcfVm6GkrplgZrbQjGg3bbMItLMeFXF+xG
/ViboNt0ZLQaQ7ZyUb2LCezZPE7LSxECr3NM8nYQFDgq5/8bUIvvObe3ZVM/
anrkuexW5iAyRGcgmvaLQ7SaUo9XCXYPrc6uoPyEBH19E0ZasEw7qzSU5sNG
PtVqVm4XQlo63cPjCGLyf+sOOXAbZyvqQvTo//vy/3SbqimBj5ThlC8sgmRP
fZVU30Y4br/kMbiLri9z56iNaQWUXZfeSVhE8J256JIktgXHVS+fj6b8LE/b
PzBXSYh4iXerrBtBVOHw4fRiPgxkWt+mbaV95LwpaG20EHrmrD/OH6bz3urZ
13+1GXdK9P2PHqP+WP5X7qd77VgrO8NQ9jb18/CX5ufqbSBuHX5qJ6j/Dgbz
lT3y8WOhe1s27QMDnTJXZpkApWHywdq0j41d5C9d0hTi13Stm+bbKd8D332S
rMsRcdo7jVB+B1waZWfYX8PExcq0agPqt7EVPzJeN0Nep9vrBcXvNbrPcXoF
Gx7yk9/8oHp97zOZpnSuC9eFWrb1SQTZnxbWcXYIoKCRkpXgQPAoMCv1rnQn
nj1Yek7+GoGEU7ilJF0IRkXI8XtUL7fAaRPfGd1QUKx66yKkfrP7FrNR1I5x
WadxX5pnDUY37xi/AVYrwke0aB/+zLVXkpnahlUmjMe5Zyn+EwtsWafuQxJ4
/FCfCUGL+QVvD6s29Nr0RgiP0nlCw9N1J9goGv8x4kj7UO/TzERbYRKqnsdb
JFP8pN2re1NMDzbfDbic2ktw0vTcuHohH5XkYvPNVbRvbgUw4xTKsL+aU2RG
8yfCbe0FJR2wZOWrjeQQvH20/tUapRr0Htx4OtGSfh938Ccpq4TXhJOzKfW3
aJ3KF4tiAc433CyPoPmvmpEy07zrBlYNasl/o/qY1hocfaHShG0XPjifon3a
nizX1pUpQg7ZvPuiO12P/dk4x4yH3vQ4jt9amrem9wYip3oc+Dh2S8OZYFXj
x8Cbxx+CIZNmcYbia1DlPzunwoNi4Fxbd9qP5RartQLjJfh02uWLP+WTvXDw
ZO+FWiia82TjNtB+fv3eYbrGUWyvc8g2of1/RKWm4tHldhg+PZYwQfV03iyU
4V3hgv2vuK2C9mfHnhOzO392wVHwauuLeOr3vneFK2VrMMasz7EC5ePDMx8n
diUGOM4zODSf/X+tSD7VLYLBEYt3u4IIhiPQ6vi4BVFTVIYCqL9/Mx39Z/OC
LsQZLn3YQc8TxdHFXObsTiw9ZWd54iHtR+PNXiF4Cu85N/bOo+cLZbt1//E1
HiA3c8Bbg/r1uopx1/awVoxNKlTfQffngWulGQMiAcZfnLKQo/4rbrz4s1a2
CjGvV4t/0v3Suf+9xKg5Cz7+s3XCqB+W6AzPL7fowTO/MbPD3ZTvg+v8VzJ4
6NFK3GBD5zmUNLZ1jy4fbPm+MDuqX4zrqP6iE2LougxUvqHnp/8BAXSvaA==

       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Ve8XxSVEUZo1UciQvoYUUlklTaZQSWUoJEmGSoRKipQilUJliFBm
yRQyR6Zrnm7IdM+55jGV9Ht/f93nPPc577PPu9f+rLU3mdsbnOfk4OAwncfB
8f/f3Vkr70cJV6PjafK74r0U2H42urfEPqFy4L/qzkM00ixbLK08GiGtY/Yn
bj0bXb/E2q31wzCSNicntZqGh+kKN9VmSyyaMXqoLEpjSv/BrnvzWvBbuPPy
lB2NoobLB49Zt6L09E5H7RMsGJWFLrxPV2FBuN7BXgk2PO+O820pL0dygrMb
93sK95oPSkv9LIBh54NHSi8oyGfcTniytgm3I7l0n8+ykP54cr/co3a8+GcT
vYubgkTNIo8XJ5owWnfv6PlxNpJvvZYMY5RBJW+o53k8jbPKMX4lDg1I400X
/hLFxoHjWo7dNZ/gF629T24Pqd9VILmpMANsU8mJuj4KqpKSlzMXtmLro7Mt
X4v7obf+3OnJpwzEqz2wPRzHxpPoD3OlRxOhq//w0MvtNHijJUQ23P4GzTPK
JY4L2WBIH9ila5UH4Z61i8PdacRtqkLqUDUO8KTqak3QsNRzitNu/o7VQhGH
r9vQaGmfv05jNh6nXoe4JiZSUMmvHxJgtICTlglViGWjdvfcBhmhCvBOHtn8
XI0GNcCUMLKuhmzJpu3BO9lIFbjDn1fDROyrAK0/Sf3or/nttz39K9hFw2av
5Glc//DGfFKOgYSHARm9rTR8ZhVXrBJqQ0yGef2LaRZWaOeaVF9sgclL/fi8
ITYEA7x/XA8Jx0q7jlvrxWjMJPk+eF2YgBvK/T/0WBR8nnWa3mwtgdftJBW9
dRTMy7Q1Jqli3KnsdnUqpLFTavKbi+onvElOZctcoiGReZE6otMAF/5RvrkA
CstSlNwsOduxXGz7tgspNGKRHFuhVga1Uwo8B5Jp6DnpuwxZN0E0Sr5kXTGN
bFGHm7xc5QgTO2Z89g2Nu0phoT9nytBQcr7bbxn5no7Toba/ayF2d9V00QIa
x296KoU8q8FCEdfjZgFsUP+MUsxDymBhHLr120ca4sVHBBYP5uCag6pnQB2F
lqmcE+4NeTj44KtEYDkN69Dz/ac18/D58KIZ6iSNiPwN2YtetEPwrMW5gBw2
5Fu93Z3EkpCS4nRjqQYNh22d1k6NJajjMP9vsQILl+yZpfK6ebhmrC9pton0
tyTB6vtuJiID5Cxdv7Fhrb5jre+hRjT12JrdliT9dE2Q/MqsgaZn1ukCDjae
2hrmKGfVwXBRTpI9qV9PLWfY+Vg2uH+IPREdpBDbtKBmZGsmZLr7Ej130Jhb
m/Z6ieJ3CI4WhdP3KbzmLUyKiy+BwdDzwfvhFJ68UnS5Js7AsukH7lIyLPTo
Dh09I1OL7V1m8iFEv7Hzrwl8Us9AkD2njIcWjcTJgfZVG0tRWPiTabCEjfw7
1kcW5afCRzq36os2DUGHQ47tNuWYk4wP2udJwVJUs8i+uwx5mc/foYiCuOMd
p87gepRaylmPLqdRWbXtTt/yHEQ7WjysCKHAsdZf/I+ECVKDNk6tIryoC36i
8PlpI/bbCdy7BzbKcp68L5VOwZ/5npdbJGioXpG06BdqhdtJ46xtNwh/Gg4P
tP1KQs7Y2K8aNgXjS4/aInZ2wNjQLcAoqA+zPuHObcod0Ot7d852ey/CbZ2l
o8uiwNOTeqhFkOhRn9IPdm2BdHzhs2whNty8ppfsSv6IbfFF97+aE32Mhcqf
M/mGjrstoloOFLbvjt5qcLAUrxzXPtYUoaD3yI2KoOMQPq88U1Ka6G+jE9fP
Jx9g6q9V47SOhnHxbyVFrlrs3uj6ct9kP8KXx0TKy8YhyGhQZpjo87noX32t
wHRIyH8USNtA9H72PSFOC6LjWy9J7xjA2QizmA8Or5Cn1LDmx0oao1+vXsm1
KIb5kJ/fT3023nz4/aNfvxrOZ+4+ChEg8+pcOrWgPA+pul/+VhM9XMoYHbu2
PQtLP/96WPz/86/lfm5h5eDW3MuZf4QftsGZm68a1oJf52Bg1GU2ojoF+7cc
ycd6IVU5+600hNLX9Fzu/IqYY8e+uGTQ0HXpFG8srsMmfTUmr2M/umZ2jRy+
lozqrID2qfU0DKNVuhIrs3Cctds4n9Rr++uUyKnFLdBPWH6a6cbGrKJ9HZOz
Bb2ZjmLHCY9Hr1ZFvugNw6SAhKrWUvJctq9EeG8UEu1tek8okPn7ude5KImB
yvGlVO8/Fux+Gx8671UEoambyTI1FJKnKn6VjmVBOLTcb8FVGi4WqckH4xlg
nPHM8eGisSP+Q/CfmTqoPX2r2SZCw51Ttp/7VAG+DUzwDpP+l1noskw4m8hc
Tm2cEmSB40jioZGh18jfzj1mSPwsPK7DoXEsHIJblu8xIvfRcH+LN18Y0dPo
QXWPPhqPGtdLmM22Q/e2clVhE+nnTFr/gcU18Eh18J0lfvR3XlVr+e0mrJil
Hip9ZMNRrPP3Ko9ivPi5VCPsA43tFy1cs7TqUR543k6T9IMjfKL+Ic9dDGoe
fGNO5sGIv1qWyq3GxMmXqSkyxA8f9hkGbatAjsYpTZEqFlbNk9DvE2/EzFHd
t/zJFHgjBnvdNjEwp38jycaKBn+ets+Sg/GQnXocPARyXommukl+CqL2MMQ3
zVHYe6TwzZzhN/jIHzqYtIUNlxNKVt+lS5Bix5RyCSa8nV2lJH+dgelfeXp/
SvsxZxkoUG7XCgeH19vDBgZwiWeXP4daG9j1Nw2vdNII0vZN9eItxb8x3wuV
BTS6ZFUZaZX1CPqSn7D11v/PfzO4TycXwYtGf344Q0PesWCN5K9GiC7Ptfs1
S/j4Kewdx+YKhDXzR1Z50WAeuDCSO1KC9SvOmjcQnvgci7apX56H11oezYJb
SP++f5kWOFYBb54erxIOGvoOgxtYkSnI4wg0tVakMXy/4YJXWgsmezpnPImf
dIU94XM4Gwjtp9y7Esn78pvqS9x4C6BlXnW4JJtCrZB1xhuvZly+1jFpozyI
vUUHbvxd5A7hu05RxYTfOpetFX7kMLCmb8U2uz4W6itMB53PEp6LDrz985kF
9T4exs3qVty7UBEUrspCV9K+MQ2RHFB//Vcu5aRx1GHG75QjA/xbWy6uzWXD
r1H22MjXNkwwM/ZMhrCxfsfGte138mEpo7O5lNx/V4Oy6Cf/ALgyn2p+Inrw
CN917tzmb8gs57qi5kqR3KJ1V4JuwLf34pz/DAl/IjU1PzIaMe/h2rjYSQqX
hEwCQ96U43Esp+/neRTGanjkx5bXYpmwmoUa4b9uwW3enKWNyMkz+HJnxQCu
mw4JxBytB1d/rYEeySdCIgMlKecK0CDpkz2P+K3QOa/1Or4tEGqZvFjXRvz1
0quamZkSXPrrqy93m0bxaPWyt6+bkbrQVe77r36cVpDZUGLZjI6NohYbZnpx
9vaeS/reRK8T7sVJOTSejihFBB2pg9HjnlHxwn6My+ap6PLXY3TpvaIyct4j
L9wWXl+HZXf85UxraHCZHymcdKsHW1QgNiiGDQ91pgpLIAxMKqRbg/DWW5AS
S49j4l+p3AGutn68XWl7oiWuHj5m3KnTawlflqtNDWfl4EqCsHbaXwpWt07H
35hh4my2jsFuhR4oS0tq7l9cjunMCiveKBrp3AN9D6hmcA1JVk6NsvFBcb78
HtdiuNOOFv+JsaHiu+qwh3IRmBkF7vfsaXCf9z7lWViPeysE+527iP/vfchV
+qYEzL6V8raknwtaRert++rwfvHfdNFXNHz3PqswudSO9L+z9TbnaUh9G489
cesTvGsMCoQ9iF/T+5aPbyuEk4mw0QvCH0uFCw1z2bVQWzhs8+kR0b+o4SZH
xxQU6R1h8hC+S3UvLumZSsZ3YxheJ7zTnlHOHHNpwXr1vukrORQaBD8tloxq
xrXmB0vHWeT+RvZ/0o38hsa1/Py6JP86LNPzORAXiYZjkdEMYXL+0QK7IK1y
dGhlzF8fSvjZbi8tV1mHuBh2Mx/Rk5ScSNvLts8ojhNkqtvSYLRbzT5fV454
qc3R3/UIb147meePfsY11Xxrznk0XvNVThRvrADnnjW2PBU04rMCD6e8r8PT
rss7fFazsGzfPr5IuTrY3j/67iapd/Q1t5HRkXgc8Iz0cSP563ehd+9WLQZc
T1ZMvSB+J88de0HatQGJ5xj81ocpDPZZXf+CRiRv2N/2J7gPDt2Vx6ztcmDX
aPRaZILCYu5reSqh0eD877vLC9J/h3mJWt/t83F80TD/amcarltv7xQMrIWc
BhibFClsVbouEry5FDHhItkGJD87COaOe44VwMDnyMGj60geiovyCCnKgFD7
aVHZaBpRcSFSAXZV6Hcr0z/iS/Kd2D7nSq4ysBMe/9HzIX6WZSVbIpIO/Vdf
tFTGKERNJtRbiVRAPZi1pS2SRoiwoKlEcT34Gp2njDMGIK6R6mthUA6j5Fpl
x2wW9rptmv378SkufBXqSyU8sAl4FOvaW4cf3zJk8sVYkLraURqjXgmewfZC
aVUa+bof7Qt2RyH+bnrEylU0uldfEbhD5m0LMyRrsISNIFZoiohSBqZ1bY8b
uNLYe43Nl5WZiS+Wx085DRG9VA0r90sl48WC7BEv0s+RlZXdDz80QlAu7cvO
EJKPHnL27rMrg+bwUY3NP0keUlBjNLQ/x3HpsLZWcXJfiaaKO+ULMO6jyt/c
S8HCv/6pvzATQRPC35flkn2iZhFHQ8B7yNmZ1l4geTK80yWqNLAJNpFxzZGn
WRiRXapuKNuG/Z9dK0IEBmBU9Gxecmo+NOY9kLhLvifnY66cmW0ZmsoSB2Iv
U7j+R8nz/fdm+Pk6+xleHsDG0G8a6MuBRI7NxfKFNHjWm3lMcDTDnfuelNor
CjoyUY8Ej9VibI2oLv2F7GvuvvdMtuUiuphK0HhC9LwsIqndKR9GAykRUsSP
PLwNvbUs8lF9PExPm/zfLWoJR4VGDFScVFCwZ8M//4pfytpW2IRS0x0k/7fM
v5ooeyINpVkrDXc60VD8p+PNXFKLa/18V66Sedhi8CWEg+s9dj8QLl5P5jdW
50Pi/uIGDPxntMeug+RHC+UZK7EWPA87IrPUlo2ZRkfh47kleBtZLv5bgPR3
jEtYy9wVUV4qKYMbaaz9cfKRzngthLX5fGv4aKw6+0Qu0r4JwaJjZ6Ir+jG9
qZo3/lYz1izPVshpI3n2jgkccpvgIS8Z4eU5AD3RdGbJaBwCnk4WPWug8E1+
Tmu/SztK1dq3qg4PQL+mtntoUzmSMg/8cfvFgovR/rYCiwhICt39tIXkNxs+
+TiJ1mrMl9TUsThBeLRA5t/XuDwI6WpYd9ygoJ1RyDsi8RUbbA5YTMVQ8OBp
j7ofY46MN1k/DhF/3T31xWckkIGOG26n3UTYeHT3maKUWyXyvR40zSrRuDAb
1Xn0QiPkGE5qv47SSNrvv8F/ARPpby/uuDFKwds4bOjDzu8I9+5d8zGYhXCt
cVbqYSbJ2YeenbGjkbFQ6I+XejsGa5wP70lkQcjEJXnV6Vx0Kdlx+xN/Ti7x
UC+3L4d7RfpkiAuNV1tnIv7b8RWcc0t+65B+j4rkrvZpTkabC8eej9uIHgq/
rQ7nvod1F+/IFxG9d01bVXRNv0FZpIXUZ9LPeO34mxrz67FZ0EzbtJeNS18D
Bw2Um7FJ01PTnvBNPqr4Xk9ZEUzvDaZUBpB+3+8dXX6/GjF+XuKtx1iI8tF9
dTWxHuMPcs3/erFQajT4yle9CLn2V22GH9IwyXnbVa/SilGDuce9qhS4xJdK
HTqTj/CRwU5pso+kcZ6ucBCph0jikt7PmmyIRy5KWMnbBOOI9PNdH9g4y/la
Y59DJYL6JnS42sn8Xow4aHmnCY0L+NwvOxK/Fb3o/aSpDJSZ09YUoheOm4GM
EZloLKxJpUIJfwR5pP42CFVArqjqROEDkr+9VLaNt2XhjfTWAyZ5FNSeh/95
6M8A7fJpROg54Wnid9ddhQxQt5pCzt8l+0oNT7+/TTTyNvyLTib6nVFNubmk
pQwXr9aY/z9PhPPcMn/o4Q+dzYlXXoqR5/asWTG3VswbvnCF24bGxlespujH
AWBUBCYJEv302w1u3fW3Hfm8O2QqVrNh++SSZ1pJEUKidOf2LyHzxVE6Wbfm
E7zkPyzYK0fuRzhkyTKHenhl/jlpUU3hkbEgf+D2CsR4x3beXsRG8hulvgt/
Y9FtturFLbKvcfQMby9/4AOJOP7BhaSeUPWdOTH1DNyxa525SfSSnO7Qbnky
DEY3+drnEf99khiiIcMVD9Njd3tUiB48NkpVpXVk4pxJ2HwNcp/dy0fklqhm
IqTh1WXB3xR++s9mxa0pwgvmvjNfjtBQYdb6KpwvRfTsXredTBqHZ4Z8FHrK
8EEnlL51jvjzy0vuVSrhqEzwaphH+Jucc1COzklAUuFwj68yDWHXpL3sCpIH
LWTL9hC+xWiUzwWfacCduRtVg48pTEsV+zVadkDp8fiWQ2T/pd57/FYOKYTt
SDnNukz4sqVIos4tGJPej0TekfqPiq8VqxSrhOHuaKtlhGez29gLRA+3QtVi
YrAubACz3/dW+03UQSfyvX+xDql/C6+ZKU8TjGRk3Xdlk/MWm65zCMnC853S
5l7k+zbS5s5PNxegb8SmtvApjdT7/dqrLpSh+MLYAqXVFH6clFb4saQFUcav
ck5pscC1pzZj+88q2AyanRv1J/uL3ylWruM7DJ9Pn164i0aEYsiuxOMM2Kpf
GmDnsuD7aUJeKrgCJ7I7uG9vprCiRXjNr7NlsLp/eVQiieSR254xEVwM1Co+
DuIzI/3tXioXH5iKZr3ozI1kHxvhVFF0XlQHdpYrPzOLBeGD6wrU3rVhUcPm
fAEZNp6nPj0k4Z+GxyZvOD52Ef64HL06ntWMHHeu0hZ2P2y2nfLmtW6CsFNW
hd8PFmaYyuyVXkmINdRanU36E6Uo0e27tB6RUrK/jcv7cdfKNyJXhYG0X5SA
2DuSD5JKpbrHy+B5tVQkSpnM65bJrJu9OXiyqOTxVDkFcweNnekpzVDLNlc0
TqNQnTDRFfi+HNsN7Q0Mj9G4tp87ZqVgPd4Kuz8pj2fjf8f2HXI=
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk81XkXxxGlyBalSYpoVLYpZXLVJ0qjGUqKEpNSlFTKE4/CjCWJIksS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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVHk4lAsfVX2KrpQirVKpyFLdq49LHKRCKYRoQW5pIxKFiOTeZJnQKGkT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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns8lFkYNhZtWm0hSWLdShJRTVrlSWstEWV1sUoouYQmUYgSyiVbk3bR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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4lF0flrJHkkgbIoUSWd4SbhWFVEKSLa9KWsRLQkJ7KZWllIq0kC3J
UoTsa3bGMkaJmOeZQbYoUd/5/prrueaZM+f8zr3Ku3hYHuXl4eFxmsPD8//P
1cqKnMmQVnwMfXV7cQwXiXXd8rdqmdh/baeQclA/HnWlbnhnUYbv9itt6QYa
6lZN7bt/F2OVxQcZn2gab+zuLBZJb0WP6B2brnU0RLRORhq3MzA6w2w0uEbD
Ol9COlwiDprRdkpOSjTS5ZWNbG+Wor66ISj7LI0Rjk5u0shrmAXyWQQo0njI
t/BehnwRCjtS/O8b0Ag9l/rO+zQT5rXhIpv2clEWtjiZbV+IuboqbbVlFML6
ZcwUTWtQVWLKv02Bgqe5DK9wYxnibtb4upH/17NfEOm7rwb6jf4pFz+z4Vqz
t3TcvxPPONuX2xVzIcjgNRO5XY6O3aGVbjMUxHmT1vyZbcVGzte5h5JoSMn9
TmO6MnFjzeaNyvV9MNxwIsc7rAaphjnVM+E0vM/WGSbf6EDDlhOGt2VpqPWp
DGq1NIMx6965n8VGTuSa/VMfcrDoeoh7w00a/AKmox812vHkwS/P4pYBbDLx
4GVENWGMzXAPy6GRusdPsrStFtPCcnHjRygUnaRTr8cVQcEh0m73Shp3hTL0
k/g6kWx+LWO8i4N8gSr5eIVqLIVB7HofCtP7v3O8DD5je8hBs1QTGoIRTk2u
1ZkwMVpyV3uSwoRv9jR9qxNL8r5ublhPY/mF00tcTJqQUJvt5biCQsO7Pr1k
DxYGROpL393igr9lYnL8WyPOCx04vVOCi208ayFy5TPmKkVe3cJPw4jukXpi
/RlB8sm3NUr7canMX7PMrBk9V31H5M3YMKypfn5o3lXYBF1uyiX712qLHTba
1YYcvj2rnqdz0aZ1VPlPeBN6rx33FtDhQDf17vlirWYcNtKwC0giv09gKLMU
6lFTsDLMLZdC37OJr3LVrYj923PAwbofRQJvBbLq06Evoai3tIKCYcyEHbvh
Fu6ckC5SWUrDvV85TO1sMTjNF4bF0ig0x2j4lFq1Ie7Ijvi/rRwYCoyonkm+
iGxv04gGsr8nQxFxdeOfkOS0fc3Aag5mBg6bdpiWYGDWWbpmlI0e12UT6XIJ
eCT3OFecTcFCNu/3+xUViMiLYau8pRHYx9lcGNGNSdrxe81YH6JNUzalGrVi
HbK3B01zUDuu87CIVYhtDxk2DZo0jjqeWGJqWIgP+d/orirCL9l/M3XGmDiX
8FR9kNUHk8km3oLeKqSVH1awV6KQE5dx12p3PfqsCp7pNdI4MhG97aRmB4Qb
tJNtNnEhdyhnaPGDKISm9DKsyPntvsirXGhuRJR+p8/OJxzMH9SN27y4A2HB
30fF59GY2TvqPHekAzcO/d414UqhNXCLJ+NtFWLZtzrCFrMREmWv4S3XBY6r
zHjvPC5eHTie6XOoEYqfdw0GLqNBvQtrsFNtg9LkHv0z+mzE+h9oc9nCwPIu
Px/7cQrOBp+vKF5sh1QLY6lSbD/cWmjp0fB68L6O7TAlerFc6iTLPZQJlxT7
w3pzOPDr+jkZmF8GdfNuM+MAGmGiUxe19ryE3LGp+z7kfWq1m26nyVvczM2a
e0GK8NMOv0r2VYLZcLd/RJTGWVevJW7nW/E53Ha2NJcD1YrUkcP7OmB4ziFN
s4zG2EEbN2meKly4qmC98BgH4krC9W3lMbBQbTTmUSd82XHniCrVjf6a2vI1
PRxYG6ZOystnYExZois+hoKgZMHypLMt6FhsocEg+1UMHI1a41uFjHNWVs6x
NLLMdPdFCn5Cq5gpv81yDipK/0gaZTShaPNMYdEUG+IeP9rV1XOQRWeHr4kn
6wlabtUWqYPV8jc9scU02lztGc9iW2FXslnpENGTROt1WaM/K/Dyn7odbwtp
7FcxKRDSasW40JqQnlsc1JhDdKysAsedp8+8PEVj3sr2scGuOihEDRekGXHR
IXxcKCuDBWexwh65KQ5uVG1m6fQVAG0O7yf30fCcoz4lLVKNNNV5GYOVbAQ8
TuE+cmIgb2j3FWGip7UhXuufR9bDXl5S+o45B3LZwRe1w9IQPl685dQvCoMf
uFPGn9Ph7XaIf4SPRtGWP7MhKdU4fO7Ims4eCkpbBef9vFGJlESzJQqCZB4O
lucu/30H+oemh5MY4ZvSkejNf5gQ796h/9KfwqbHppFv6/Jw9GJWsKAHBT/H
wjnuHSVonD8dGOBB40DGO9O78kwUbkkXkEwYQBurQPBgcjsC2hye+IpwkeO+
L/S8TwVWpV0dlSF8TMwWt1z9NxH2vLMJXcR/XGR/CIxZM1EZHeUtYD2Ie7Xz
RZ4tZOFVgJOjg9UgLog17sp7eQ9yfZOuqTI0nBN3a3reaYJrRshNCRcar/wM
Zw73MZA6m9enEUrmGdEuWy6ZCWEVSaqnk8KZjA18RolvwDzteNxUg4bKi0/l
u3za4F69cJ1wOg23pCGJZdmtmNF9lCjlxMYpybFYkRUlyNpbphv4mYbwj9fp
6aUd+JGmXRk3S8HI2OSzdWIJjkp2yr7/ToHnu1jIoq9v4bFdP0avl0LjxOKf
kwMvobL9rv53eRo3km0adgx8xLory/ymDGlMXMzW+epfgWNH95hTiyncaFEY
P7anGMVi23P+bqBhUZZZ362UhZyTuW+aBYkfazhury9Mwvfdv/r6CN8EvuQy
ym3bUVUvmXmI4FuOGN6t0HvwKv4T4Eb4H9E0/0vFbDPumJpmRJwj8z7V2hw4
3oJ8MwH1gW6K6Eteur/oJ/ArD+2S0ibr33/X/TWwCF7ujPcJdRRS/Xb8d0us
Hit7NE4ZxLDBb+z50IPbjtDxBt4y30E4Z3FzexyL4C30ridZmYZf+sXYkpw8
GFheLZAWp7Fk4tmHXr8y7LzR+8eN5AELIRftpRa5EMY1nyTi5x0K33fHfGTh
v9N8Z/g7OXCgzc7EN5ThhqtweIYZhbP5KYeUq5rAa/7rtMpBDh4m/FBXvBmN
B3Lrvc1USX65a7V2p2k6LFI5jHsUhYSHoecUTDogPZU24FZLY8AkbWTmYzME
bV3vyRE9X7ww6ssGCQYGJAakJcy5MDlWWZ8RXIcTZrKR2lJssD4Nr2NMtKJ5
cUjRFxMu4urtY4PWZuDpm3k+auS+E2PHg5FUiLIAx0Ka4LVs3s/xqgVNyPwQ
MTXwm0JJQMxw+M9m5PD88/5ZFw3LkuUlRkubICv34sQoub+cfZ1ygmDieUGc
9da35DyTBtGpN9oQwdzWG32WjdZvbgMMuXSE/TojRC8kfL04HGReGgsqqma9
ANE/HqV1bfyldtirajk0SfBEhSvySp1/C6PqDf1TC2j0jMcGui4Ig1Tu4cp8
8r3LBqsW4Tzi97GBU7W8Azjte8azyroTPz80aB2JI/P+9TTYx7sTngK8zQe3
0Pj56nVDYm4cxsx8w76tJvfpwXgfOZyAdz6J0j/liP/9e51PRr0ctoUbvDbU
s3GyG0Pc0U4YDIXoS3nReCDtMvpArQGpT40ezi7iwKRuSj6xrxUmllcMfSf7
IT6yuuu/pmZkvprW9iH5x0/cNubLrSbEPds6t6ToGyrEHydV7G+Gyh/BRI06
GsVnnxoqm3Rih0fOvrqGfpzq9eArHKjAwI4/S/kIXm+uzTxdJM+CkaKdkQ6H
hqTxqfluyU9w3E4mYD3B/+TjvzzuWkzYBN5kaiVzEHr3qpbHTCOSF5V+SFzB
BUdHcylvXRUCJQrm5P2ksbYyK9FjaQSknxil/iH+bHlrtlQBdVjNfXRgizwH
tyiP9cdEG9FznMdTOouNJctSP6ibvcFfQ6HsT3Y0LvxW+U5bP8Hm7yN9mtKE
f517xY2OVUOoqb9fl+SVtZNXeOt6akCVn14uSPT10qCC8Dy3crSecGzyYFIw
CbipPa+0Co36Un+zN3DgveLSWm/Tj1j/r+zDaD2CN+lXO5c7lMM+kU90K7kv
W0Z7rCI3Cx3ZoTsX/CB5+0p0UcyjdshO2CRFC1KQW3iu90F+A4xkL0UoDLEx
fcZb+4d6N7q+qHJkF5K82NwU/KqxDdxA/vy9ilywlgbNHfdMBUd5+yW9VTRO
dRQsq1duwCOxtiyX1xwkVnsY3rJrh5f3ztlz9sR/nyEg274YK76lN9lsJvqZ
J7Kmf38Gpi06Usd0CV6dT1zc3jVq0FCn6f2b4DHRVq9DfLgGh/h33XvgRiN+
x8bLs/a1UJzaL2NE/DG2UeVSfVwrdkfsKSvZRWNhozFtd7kMmx0Vl8gR/oQG
PxnqH2rB40W9TgmSAzA0Ocr6r6oDf8RuVv3256DqzEavModG8Bq+VOu8REP3
nkKpP1gYnZTDtWcD4PG84xW9aROcZVuDZsl+xLv3JhVKN2DeVWsbB2eSH1NW
+dbWPsUd+XVSW4m/X5BMDLlzMA0ZxfcLVxG9bTU3Lm0m+kD9NMsRIP1FMv/y
ikMDxTh1nrJ0yaKx5iu9mtFQgVmxl0o1V2hs0pH6azRWgZWmLyol2mlcZ1rd
nd/WiapMoSlvggcvGeNCkwvtaGExg5qEuHDes2eOl1omBoM0LyiuoKEx7TIW
k9aAgQef45krKeg9DdWfXFSM0h9mzJrbNHaJRY9us8oDa0OOzbIaCpPhvhMy
54k+B8TvWkjyxJGog0eypj/Duyb94hKDIeixQrg85z9ih1EPc3Mh0bN2O7nf
tp+QclX3g/0EhbFU56Gk758wcX/CQ2w+uW9FzTYfw7c4Udzlf4HgLc5SRHX9
x1rUi0s+NCHnvWYTVree8EndbGXXjzs0DLf7uEQ0N6Aut4inLI8CpbWo+1Zo
OSqzWn3qybwNxVnXNoS/QYWjrcgEma9cxvKs/T1tKKtPFrvbwUHRKWEDcfdG
jLXLRa+sIXytvbft+noWnMzuDHsa96EnIaVt2jYHzulV9w7o/D/PGNPJ01cQ
WnDdzpX006pwMZ1nIx8xzMsUtCf4D7Pbuzwv4wNetgVp/PpL8gv1wrzqn2yc
OBjV503wkVSwzrJi2QcMt39RyiR5wq/HjedoejkkLm1W1Uugsa6bKale0gXW
/Kb8WaJv+RWJi4KYLdAV3L7nyHMOPPoOBjwVysetmr2rpt6T9QfF5BWDMxFb
5hQfR/ymN1bghaxIM3arOfxNz6NhvmbPxqCaOvC0P1e9rsCB5SodXk3dSmSs
kLzzhvDX9oRS/F/jONwdik/RJvd/vt1gZnokFfE9ObE25DnRMi6yel8dLkm8
+i9qkMJ1xZyZWvVGbBxQcT9B5mvmaGqjk9wJfcsdvQ9YA5CL5BFNPxyD3r3l
ImoiNL4emb/FtaASOaKM54mpJH/octPnSr+DmuWt6WFz0j/NBgdmmlsw3PQl
hk+C8Le8PWXQ8DrWq+udSCX9i6fynz0SwoXQGbzJ+/MG6XNfjB7lr07Ahcsy
KyOJnvlv5NGevM+A0v6Fq5YQvyxgzROu+luNlJ3sB0l+JH87ymoLs4qxMGRu
YCmXxnyZWRvRk22Qbdv6mD2XgwmfNUtVH2XhmrDjU3mCz6rhWtsIrzf/V2An
HuJvZqmXsjetqMOVcwmRvxmkf2RmJs5UZKPGbMhzXxWFgZqyr9FyzQgfuvTc
U4mDkSuc4U21TVCLety/dIYDm+Bp1tlT3Wh6Kr9W6QoXa59dNdaaSce93q1V
hkMU1Mx+D9yeWwfmrnX97EYKbivMJvjupWPgvg5fKMmLD53e8LD0W/C0T1Hr
3jk2BDUvHhhz+oS/HSMRmocpfH5lIcH3oxv/cUR5HpL+oCsaz6umVIMqyX/5
r1aQfOXj0p1F+qqO93x3rY0UpDmJ00/ntUCzUjVzZT+N8iPKZ3xLKzB5stm/
kfhJzljaErmDGXB2+2YnRfA59FhAOK6lExrshW0Dfmyo+Dz/o/CwGW5jMRnm
aTSa44xuXIzPwtKePqt2oj9MphO/m/YnxFp55JZtJX68YsWn7H3dGHOV2sfI
ZaPXOHfpxSMFMLjgwr/gOvE7Xi992TeNGHjfkL6L5Cs3x41S2+58QrMQK2Lz
Nw6WzWGcl43sgox4QbV0AxcOetLJNt/qcTFqZ3rUfNI35h4bzvGvw/UHCkn/
ahD9cdXr0tIm+Sr48m/RVxSifDYGd9uloKPkvPrBHTTO5TZv6/coxD6zKFH3
yzRqo9RP/NLrgMnTzvizpzmQYgR3Gr5tR/SGjCyhFzTS7GQq8jW68VC6Ykzq
PsmnIgtd79S1wXpvuF3ScdIP552fJ6BdhJBvDEtZotcyr0X9LF53w/tH24qE
BRTu9SxoTDKrQ++HisSif4jeHHp77DH/SzgE/pz116IxHJ29xM+RgSyPHSn6
a2k01mgpUQdz4fst8vbDWgrmx1XWX6jNQtgOse8PjpA+d8rgdcFoGebUB6iZ
BFBwcPlaENBchSebEi3n/iX+cft0jjLLC1kSWS9OED+9effFDj3RDuhN+vuk
RZK8lmCyy5T/GUJTMp/7EH45065b112PgFLqKYuPa8iz4bKfNF2LN/n1vrOJ
NGY6l6nlGFTi35d7c3qDKHA6u56+5mslvv1mVU49BTGR0GW5Z5vweP9VPY9g
Cq73+6fNtFio2R6Su9Oa5A3+uTbsBe1gafAdMZHgYmZT171q3TooM4WFNPfS
MBjXSnAPKkUAtTt3DsFf3JmRlV5JTbg/tPuHtjkbNvtlPP+rL4LDgZOxN0H8
76y+fE9aFZiPX05xH9F4mchQrQxvA6t/qF9jjI0r15bNjL9louzu3SjVo71w
69EavGGYBfNhZ0FjMu8ZW/pjVyvx+8A5gjsJHkLlgupv3szE+swtzSpE7ywa
Xm3g6pfhOG+/cyfJ934if5bkP6qHYTBLNSqBA/Gn+6YvvGhGXLKyL5v40x4B
LWV05GHlrGKZGtGjqayKaMNzTJQq7NY9tZXk/SQ9R6OT+ZiyaFXdd5JGiQZ3
U+T9FqhZByheme7HtQO1No7xjTDb/ybQ3pb4idHE3L4zn7CQ9xDXIoX0N9qj
t+55AxaP2mzx3EjjT4Fz/1fbNgwuurTZO4+Dn34tL9yzq7ClS9svo5nowxUj
P9mYDCzboOyTMEohTeN+WEsPA0VOr63+babwP2lfF3c=
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81IkbHjkiNptcxSoqVPrpIkd6bDokV9g2RMqRLUnJMulOByqyZTum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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41IsexpWEZIlocpJREi14OoWJvJZyNaESlYqLy7lJZY9I5lLSQpkm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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lekbPpEkpDQt0zRGltJCG6UZdSPTJHWQsmXfxhIlSw0aa1JKKI02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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c81e8bxqUSGlIJlTKjoiSVhCsjq4hkFFrUV0NRIjNCMhIlK2lIZlbK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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41AsXx0fRMqISupSia7xpxJC6lqavNlR0JSnpUcry3q63cMkSlaSL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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81IsaxrWdtHBCSrrdi2jDcbSgxNN1urQgbZJUJNFJWcoaUqRSMiGy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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns8lNkbl6UiJKWbFllJyEpIyHdUSpYspVgyWDZSySUUCQkrlVzKipqu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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4lf8bVlEqSSUKFbIrvolSxi1ZbVSSEZUGKUJpkZKRMkqFIskeSaLI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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk41AsXxyct2riWNipSGupKKSHSlxa9JN6GFsWtNISiG9VQIkK4JJEi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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs81AkbxS3RdBFRcr9sueS15DJtCac2S22RsCW1LpkKUZK2GEkN2iJU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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekbliZhSrbfJIlzOLIktIiy3BFZUqFTSZhKpyT7TjWdg2RomVKo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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lG0bxiXFaykiWqQIpVSUpCynKKK3SJF6KyokRWSpZGmhkL3IFtJm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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHk8lIsa1rRYyzQhMukkLUTZbhktTyldJKeFwVHJvZHKlmjEnLiTSpbC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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVWs81IkannKtnZxYNdYlFWUqpVJbCo/kGuGwWcltVUoX2bCspHFJSaJy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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk41Gkcl2hpJ1G2TcnWboNSEoUc86GYRYejkiuJRVJSzmnl2GXJVaTc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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2lYTV0bTm9poKIyhWZJZSwNqLsBRbO3REpJKhVCvKFRAxIaEElKgyRJ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlX001AkXx4lNpWflZast60iRqU0aL2VUX1GhJu95qGkoMpSWyJY9rVBL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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs41IkexqfcVkRKSSRKUaQ46xr7btlyXVHZ1dK91CqaIowi1Nl0c5dy
JCOVW4UwuZwaI4OQMcYlg+b6m5+UaKnBpuP88T7f/97n+T7P5/MaHT6969h8
CoUSOZf/X1NR6Zf20dfgsh2qBm0JCLgOS+OrU5CsylxZMUpCf9zBfN1zHtxm
BHEK2mLcSMtWMsptAt3EnB6rRyDv6cIGl0vNSOCaHqazpTD/MbJMzasPX5pq
A0ZchGjzOHbt6D89IIajKFkrxKjTv7ei6FUPwhT8A97dkWARnfLLx6WlKKJu
Zptbkgio5xxxaeQg9XOlVc7fYrzZJ3hCz2di5PGAU/82GWLtPGaFTrG4Wxyo
eUhtGIPsmdqNBSw8Nnaa+peFDOHio4bPfn+LKlH81a2pQoT4GQxHknwk0Jw1
H6wRgOvVklZ2rhzeO/dVnV1PgjxXbKUX3Y+TUyFmQ85iCM4PLQr8k49bxxwH
4+IlkMun7No828E6wZgt+SyBofqnfKlSGfJur9Tp1iORmxe8QC2mDgLVVblK
h2RIXWBVG2rHhVPVoYPDpBRfDWu0uf6tmD/9U1hqjBRPSx4ejG3qRfZ5zYHq
KhF+3kwE0xw58JvUtU+5KEUF7+LYV6c3CHWkeYbVSeH6ZHLnkW9pYLZkyYpl
JPx2s/2bt3dgWWK6kVqvBNtvFtxrS2+FSU1bk18/gbiy/NjdnmwY73W3u7+Y
gO7YqAM/8gVy5sl7I8JloDTm+x27m4ollFvvGsZJcIq2jPqoc/CfPm62kC3B
mGv8mWu/loOa7bvp/BES6QoF+dpdLbg5G6qrtJVAcv0KAdWPjls+Xu1HK0lo
SDMSy34YhP4P5bRxBzGShwZDhMfK8fMj+1DfDSTqdO9xDT8MQSVUiz+jKUTe
xWv5NJU+GAcbD0a1i/BXBMVFrFCJsmvUlXwtEkOl1icKBnKxfWRyy+JWEq5T
GoVhrBas2N/3yLJCiqgPlu7D3X3Qdv72tey8ENLo8kluVSdeLBbvl2yUwDqu
Lj58jq9ZG65bklAC1+TsitJDL5A2sSjm1EHZHM9k+aXyMpQa7pinuYvEhcUK
DaoO/Ziw0c0m5kmQq/S6OmogGVcbRlqffSLhqWzrRi1ohDL7nK3pNIHxecq/
RioMwmmSavRblxAFx8+wYqPr8E+Qm2nxaRkUNazN1DreIvz6QWbVgAiUP/3o
d0ub8PvIhDdvDQE/vqMaU1YPdUXv98lfCXiWaCaqHKrEJqqd4CeNuX8LmF0e
+3pBBn30N88QokTF/vv6SiZy1cZ6LMcIPC1d/22CzsUvEzG0XmspOPom1MyO
NNimv5yOlJKgetf6JJ0sQYlNHumdQCIm9fadBn8u+tyShtqWSrB5SeEj3uUW
qO5tPK0eJIVpcaFa2dZy7Mj8O31qVoaz9UP9ikQNVp96bl18QoapsF3BWvJ+
3OGfY9xwFyM4hWY5mt+Hmo5iHQpDAsX7VnxDs15ceexrPnJchJ4lTZ29EQ3Y
EcujLR8nwLb93PnOvhnjypye0UICTC2pa/dUA3JlHg3OF2SgyatZxe5cZHQW
vOJMSRC7O/++3Xs+OJaMnvmrBBjYt7DmbXUzHPduYmxpn/Nhj6ltVFYdvG7q
he7vkM3tjqEandcPxhJWj5GGAEly83DGOAfMdIuqF3N9mWEdTBq9Huevt+jp
5MpgNS0qKNfuhahz6LlQLsRESBzzZR4fyzZ2X12yXATvZvfd3xh5UEy+YDVR
TeKWr3/IHlseuOtcJxkdImSLqMoZ9WzIW4tyfB4TIFefqWceYEH9SpeNzyyB
rH5lrvVAO5p+nL03EygFu8/M1cyxBQEWwaqXFAgsv29/szB8EM0PPWOCpt9h
j/nJtYM6LFxPiHC2eUjgwgGllL/vPkd/1lRCBUMGHk//WZLhG5gXxerNb5HA
kcxU1s/n4EMiP2rtrBQlETfrjN6xkcdSSTHTJ1A6E2LIMOEiN3rbWFWEFNfb
UyL+a18BR1VR58odcz777I+/frwOlCcKevsezu1pupYsUDsOixRPuCQtGMaD
vb+1XHbrxMxhm8YvIVLUmqj2dzs1Iy1DL6fyNoFTHr5a2zY0IWN2wqhuGYGi
/VezXSkd0HtyNnR5OIGwqHmXDZR6YFCYyHA4IkKATdE6g/lt+GthiY+cRoDS
vkr3D9NW+F8dpnq5S+HXs3PN4RXVcLihHri6UIbSgAqL74G9ULvtGsd6LYRj
gFC3K3DO98xdut4yIfYmhLLYM534ou6m4nFUihOmKV+yDAoRb2WoszCexJiA
fPPCjAMdJ/3otc8k8Av642tt4ku8f55jUKM1x4ve0sa7JA+nM9szLFQkcMmJ
btTawIXFq3+rBfLEuLBN/04lvQ0hXQ8CaM+kWK9xY41v1ht8NnT+xPWSIkQ2
ra/L70bnuWvcx09FME6pyzTew8COy3vGE0xIaF6qlQtSmiGPZnV+vEggUf3p
atdULg48THg0HCmGwpkC86DvPBzVCWU5XpHgf21u1yM=
       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8ldsXxoWu6ZgKCRkadJSkQorjMWeqRKScQjKUIiXErSiaZKxIXHQM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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VO0btiXKriRJCO0rSZJb8hWlhQ+VLUVIElGpVEI+RZItSyRJVJZs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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41AkXx1WbrFuKNltGNcJuym1bseHrCdUqXaYkSaRsVEo3XYwal5U3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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk3k81AkDxktJrQ60H3Q5UrlCQoQ8yBv6aF8r695SjHUXS0qSXEmHCVlH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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4VWkYv5UmlS1LaSxpLKlQ3EtEfjIqlIgYNUnZhkZjC1MU2TISGiUq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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8VW0XxhWhKB5EJEOigRDJkKeLFJJkShkKzUmSypSQVEp5NCGJoqQi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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81YkaxhlHSEooWaYbJbKeT1T2x40wkQ6uZUJFaBVRjSsVkVTkZBtr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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk3s4lAkbxksiqkGUkk9C2pXjJCGfGzluwlc60WdRoUaHpSLbtohKq1BW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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs8lGkbVivKl5CkNknjLIkModZVaUVNu3JK1IatVianCvkUioSk0bbO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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2lcjG0bxnsSKkn2CmkliSg8ljhsRZuiRQsptFjKUnqSKCFtFBItohWV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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lWkfxiNL3k62iF7ijOGN0qSSTNF1tKhESQt520aTmmNrRFT2sUwy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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwV1Hs41AkXB/BBlDe0Lsmbu3obt6R0Qepbcq3elDfEKrZUVi6lpMQmuYVt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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVmk4lWsbRfFp4BNKqhOpUDJmJoscQ5s6UpEoQ9GkSBFyMm2klOFkKlNJ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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4ld3X1iTJmAYJIS8SJUkSbmny9qoQGfJDqag0kFTmpFBEc6lkSsp0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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk41AsXx13Zr9srlxJFi+m6pLeLROirCF1M0aboDRFeLYob7drrSRT3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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVHs41AsadimGctLqlKSLbGV1MSsqYl6lRJTIQZapJkQ6KRERISQNK5XI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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns4lOkfxgejZEttW8vSCjlmlEKylXskZURqWOVUYSu/itJiVQ4lm2M6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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4lX8fRmVHqaSSJElRaalUbitRiVRISKVQVkiZkaRhtZCUjGRUyN4r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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHs41PkXDmVrlVWxUo+emRqX1LaFhGpfWrnEptYUuRQTIgklqY1cfglb
IVJtinrUpNxCdkbu5J5bzGhcUinm8/1aKreV2O/vj/Ocv85z3nPeC5vn97uH
7Lx584KZ+n8PG3lx5qhrJrxnHGYPCqSQtFrz+7LbQVI8LeWVaczT23ktOrge
FxYJw4MKCPzVzyXwSl/iGsdmtdkEQRjHxTDWPQSSsy5P3+pL8Ws9d1cj/zlM
4rWWJKkSjI5FjgdF8KFbeTEoI1EKk6/r3TyE5ehXj3VWsyBIuaM6M7CtG9Wn
jE4np9KQSbmnviSwDVblyf28WAqcG93KvaclMOYLRw9vG4bA86vLWGExLo9m
eQpYBNkBiZlFJtkwezqV+yJPilHBH+Mqq17jsVe1/7PFw7C0i9m8MLEG02pH
171XpGDBMzpratQNgaNPzYe1NOzl+NGnLRvhb23UsaCLYGGZ/Rdyoh6+QWX8
xI0ULpc9KZ0ergSXO/dDYAZBZnf9PmW5boRyz3rhCg0DD6UztoZt+ONQjptH
M4XfjrD9Go+L8d5jpVOfIQ3zrUpTTaUdiDjvlnPgPoWHYduu9riKYRGpqhJ5
lcbCltg7idkXkZ0SV6ECKZRGzvWurMrBAVUNPxOhFOG6VPjc1h4Id/y66E4o
DaV/7oq1VFKRbJiQvN9XijTZoeAcVi3kHH57cb6CIMh1De/I4Es0bd0V9Smc
guB4fCLPrRapbA27oFsEZsNhvTbWtXhJ25XGRBEsHrpZyXpWDbUtEqshhk//
QlP1hEXZqHBKb1paKsVuzQSeho8Iyja7Mi59pRCo7m3ULNcOuoGr1zdNQUfe
QuX5sASmaj0R3jdpxIpmmx6vbMeFX8pnauIocPdUyq/K7cQmjTkP8WYaVib5
F0aDGxB159vTCjEBHZW8IHxtGe4JajtuBxAUnxz6RQZN+OvbFYfdWyk4nXPI
HVHPR957q07uBykqgzP2DTH7y1+FUYcVadTQe248ed8E7uwTg/5Wgn/XOZ2x
C6zDjwoSTeMlFAr6AzcOcOswdckp6+k0wVXFm59yjDqxcW5DSOlqGo8UJ7zq
J4pgm/xY5ok2wf++VCftflePbLko20F75r6/5W6ka1XDMyE7/noxwaZqkfvI
tfu462g1nx8hhXvqd8vnFFvA0fJztfxMsEYHMU7aIrxLsJ0XSCjQnNSAsFuN
IHJTk87OFGSVk3+3ya9GWEGhXKo3wbK4AY37OQ3YKmrmbWwgcLxMOimFLhiY
GX+3cAONzn6dtIOFndDU3JFfVkVhTDaB41bXgO93Krg/Y/Tpry8cYd3vQbls
75UBPo29gz6ljWMP8fj1/I/P4xh8n1q3WD4Swzwk+c2ifBrBSZvGnVorwdu3
7N50DKOXweU66O/AY+Ly0GqSgujUN//Ur+1wfKt77CKjV50HBR0lNt24GmGu
/MGSxkmLqE1Vbm3InH9lvxvzn+3HLAO2VDTjrowKOyWRwoXEvzrWVIiQnb7p
YI0+jbGmBysuZ+VBvqooYVAkhc6RdO/kuTL4S4SyOXYEwe4pnjGCdmROjM6u
bqPwSsbzhAKnE76hbP1mZt4s9tRdUUMNfs7c0zTTQ+BQGRLwk/0zLJzQ+VPQ
J0XurmK/WlUx9B767HbPpLA3zS3YXPIaomdGi2XUaZCB8cmTp3vRGmRyQNl/
GN/r2IbqFPWAUzshE5fF+Mn0+PE41gsQD/YyYQlB9IPUZdFZQvTvr9DOUyGY
7M7vrFHtRlLwrLL+fhpJgZsNeXvq4CopuV6oRKHr0NSjhvIuhPLyn6vNUgj9
7Jpkf6gTbCXO8ooVNLSHb7NWezfCWVwWUjRDUHXgqo0sW4L75qViZ+beXLX8
lu3mEphVr4svmaHxUe5YzFLdXpiY9Zo72w6jSYt97tb6Oqjm/xQib0DhMNs3
TzeNycecyn+8aeb/tnWfTBvKwcm3WfqvL5PHVYHXXFJvYWdHrmX1USmO+3oq
Re9OxwYv2+sdMVKw9KpaTmkWw9jXNq1Hg4CVschLw5SPkEHNkbW3mPycrzA1
oMmH3+niH84nSfFo+/iOj30l6DkVuZ7tSdA3HlB2JvIp6KCysAVtUoydOSi7
p+Q5tBUsV/TqEgT0xXUKDwhxqTHTJfpHghvhn5d8+bOR0WOXo89HAu05BcPI
rnaYpd3edsKaBnfBUeEDHRHivY/5vWP8yGXJ1KTpV2Gl3evqV0UE5lzjXTGO
bZCx3efxNp5C3qS9R9xgCwpnG7MiUiiwFA2iPDkpKAtZkK7kJUVYUFaSZOgF
juglh6gy+WKitNxYMHMD5y2UMyxcpOh6sz3iS5AY6lXrJGtBY2qiJdehpAP6
goNLFRg8EX7OYwotElxbrmkdxxpGf3xhT+ybVhS0/73xYznDVz0vtGC6FLGN
8vaRRwj2Gk1qbViVg2KOI1/2iRQhzRFfqqxE2JA9Ub7KgIbiNEdXPNYBctda
w6eLwg6H7tVuD+tgscRQT/MOwX9Otc0J
       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk3s01IsexXFympw4TB7dSpludWVKTCSSLSTFidAp7/IoqptHpXTcUl5d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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4VekXZn5oRhhUSEQUoSnX4oiXLhIqSYVyGSEVuRQiIkqTSiVEVOjC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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VW8XxQ39hExNqAxFipSIUMqKJEQUSpIpSSqVSoqKVGQopKSEVBJC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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81Ikbx4fU5sgObYUiKrUqUWvJsX1UchQSliVehQ5RxpaEpURZSWIl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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGs81IkaxxVtbZsuuog2t5Tcok4JxW8oi1YUVjZFmEplDjm2JBVdRKlE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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk0lV0bxlFJhTJUUolSIYlCFC5KpAGJSJIozUR9QkKKOqbXFJkqJUMK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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k8VG8bJipRKBVJKEuWQtoUdVEhSotky99SKqVSSKgskSSJolAhZU1C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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs4lIkXnoqibKuLUk2WLrK5lFaS0ot6Go1CiVy2SNOmkksXKclUElZC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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVknk41IkDxqdDbKXUGFpRlH6FQiWxy75ixnbI2pIjlCa1tR3CVo5INinK
Kl2bqaYxYZRyVWJiMFk5co1hnGOu79ex64gsKdvvj/d5n88/7x+f5zViBu46
NJNCoYR+zf+bbS2culdcg/57Zzi8eSpoUeMqGFeqsN8srLo6WIUZ+/T3pXYI
sEqnhFbIIhAlN84I0CjHTSfNn1zXEFjrVNefayqGV2Tn0FmuDPU2yanHP4mx
TfX80OYFMhi3HKtqSi9D2LqwrNo6FWy+6M7aeFMEi037/PfvVWDm4K6l+Vff
I+NRta/vOiUoZktG2pyrEJ9hrriWoYSW2YvTBlqpSNDMSNTNJUHJ5MSX9L+B
tv09z5BnBK69jng45NGE0sF9Nso3CqhCu3iTts24OuST5hAsx5bMOM2SR40o
XrzIIdbk637t+VDBjBgU3PQ5If2mF8b3YnevyawAZZnppeXqKmgwLV6WGxeD
/HTJYCiDgF3jUuufL4rRWnfi7cOdMhy3jrNZ1teEI/pU/vXzcpSyyVPM/jp0
VLByN4mVqEwOnMOLfIlsbtfVRzQSVoMH+SM95dCThKl1NqqwszCd4nG/BY1H
+rpP02WwWrnpWDe7CpIvhV13PZVofFLGtA96DFHup28HkknUB6To/P1rNtwl
h90dGSQqyntM1ueUYKSQelD9JYHtnmwdP2YrDLomFxzO6UH00WmT9EhPaPSm
a08Z9GLzNYaL4fBbeKfMXlm2lkB0gHTadJ4YKmdrh/4KBfyrkh60XC9E0KVi
xpbrBJYULKiZqsqF9lwp84Q6CcKQRwQkSyAqaMll/08G1wxTvYlnYnzhNVuY
f+VJjj3/RpwEfnWrmlNuS9FRWeZcYtCCvgaP+MNkDyj9u0YK+CzkKa9cnqgg
4Vy4TKEYEWM078CbziMyJFGCfM8qMzHXXsD18iThlqBMee3Ig+XGnHBqLAk7
m5S+tJBmVLbdF2VuV6Cj2YduJn8PnWRF2+/GKtRY7KdbxgiQyWHXCS8S2Np7
JsUsqwwa4ZWX2+kE6ud+pkawCnCySJUfKyGwWEijE74ChF0nL7NcCHw/0Xnr
lI0It7l2nseXyXHiU7dno049Qstm0++8U6A1YmvJ2KJ8WPnNzmP9RsLvyIVR
7/gOMNfGVG5ky5E7Kq2Jm67HcefJdOOrCjxdbj4z3FIMju7I8Ek1Bf4tXF10
cTcHYRxat/Q1iXUCW3aEbyMs5srfB7so4T/m94Ft9QxPC7N22rqSGLestI4t
eo/vKeP+Co4CAtt422F6EOwmbNeF0HohynLSXaFeC4crxd+dpiqhFxDFYtHb
0VVxYMsqvhTCJPcNi0Ml2DG2qo+k9cBQan6AacKHnlOND2uKwG8bGJHsrUIs
1gsqHPcmMPDvC55HqRDTknfJbzeo4DLIldO7+NiSu8eRe5DAfPXXtFo0wzn4
jwTNNhmYqcHnjRLewWaH/sfisyrsiablPIyugH6+9UmGiQqGx/TKX61/DPak
rT/lKYkh7YEQCoWL9slEkzVsEuwBM96LV3H43S2KHfqZRGvu58A37h147S+8
MM7pxnb7FO82yTswnvEGnOqUIB95T7dPNcDDfnxG/LQcPik6WYncBgg/7lkx
NCaHYajeRN6BJ+B6RPeI95Gg8dP0ug0aoP3A8oyfTIlT9jfEy0yfo8I32SfY
g0Q0uzwnqK0Wo6TGXkGTCoRv6XV3fRF2cOLez14oh/9hlo+IzMacx3es3fxI
WOZZfrb4Uo+E54/5Fg1yRA2YaHVnlyLaVf02P4HAy1nXwm52vMMlanb0krcq
OHzyOB9r9gxclmI0xp3EpNBtuntjO7brW1XJ26R4munzhZqdh1/d01bM202i
N/tc0UUXAT58M39tqTWBmyd+CckyzoNmOHWw2ZLEXd3WObGfG6FaLhs5d0gO
1T+vQm+5NeO0wY8O4bMUMDYfNInR/guTEXc+hOiqED4yuXz0uxYYHygI7Tqn
QFLBvBz9rFr0OUaZJl746tOxUWelDg/zD2HLmXMkHvA5u09ad8B5ijViGyjH
hKPgaOTGVlS0Jyn/DOyBv1bieOSuB5DREvW2viDhyDySelu3CWU7F0bSCxSI
PvZDLDumBF78dUH1Zwjkm6l9fLIgH142Y/9c+5bEfnthg2t8E0JEneq1rxRg
hAdXqsarcWnHPRPTr/9ZvC154USPGIE6/gZP1ZRYnzvs4iuVIJlxdNyW2oMl
qQu0jMyKsDkqcPUmBgFhte5qm5CHSKjjyTurSQgZAiOGbw1q1eKoaauUWMGp
+UEwuxGVAb0ib0MFbL2Hf75wthaUR1ZpNklKEOurpPlp5ciOMK/Le6WCnT5z
b2ZtA6pKuz2raQoY5mc9fiOJxYz0NjdHtV4k7RUQwVf+At3SS42tQSBbs6H+
eX8TXMe87h8tkUM2cZDbEtEC2R/Dd3+kySAwu6Vnt6geN7YtnZgvUsI3dtb2
8PF6/Kk5Z3LKXQHPiyPjT4yK8Pd6hO7PIfAf8kPWbw==
       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkfPglzMlrQJ0maatCCNmup25pKWc754iPZiowOqWTQYsioCAkp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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k8lF0bRokkqShRshWJkiSVukRFUlFIyla2hCiVlle9JSEkSkIhFJEk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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk81AsbxSfpNg1Z2nBzQyIVbguRqw6l9NqT0kaI7KUoWbIloWQtJPEa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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk41IsbxadJSkm3umoKlSWUQkyS7ai08dMvkitNEY1Ubk0RKtojlKJI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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk41dkbF9K+SItKC5WSmpBihM+NwlTKNrdmlG0IKVsqJbljSzFCkT20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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk4VO8bxodWssbXVlFSISGijW5JWsgaUkIqbUjKkqJFSZZSKERJlkSF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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41AkXx1WMV5tK2VKvUnKN1aa2Nhvfrrq723LZIZbRbaZVbxfJPaxU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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs8E4oflUoU5dJj0WPWLZHH6solcopeQl7p9SMlal4pxfUrXEq1kIgo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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk81Osb9UN1tQhtEmFKya5boujIlpRyu+6QpboVTbbkyloUhSK5LVQ3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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8le0fFhUNvRqKBqKBKDulXHaKEqmUhFRGiUSlIikrDfVSRGUlQq8V
Muogex3HsTIq6zzPcYxKy+p3//46n/N5zrjv7/W91toTbhan+Pn4+I7P4uP7
/6udk6EPc105Cph+zNAqGnbWjTM/VO6Am7z6h7IYjfyMv/eqqXqYpms5xa+i
Ebu83nYypxXlnSMlgeU0lLQvyjbcbMKzllIZ5noKe/UifnnpNePXGbmIGC8u
8rq/KtjYsvAgodQ0roILhlip6bLKNgSfvtt6OIhG3YWw+4viynHIcev4kr8U
fEoi81Vd2pF3/Xdzw0sKGd+5l8rXs+G2U2ZQ7/4gdNZOizkGxyNWzf1juyyN
HVreIYu8KvFtm0nM3xcc1K84NTl7sAXVCX/zplZzcf/VryMc60qsqs5Jcsyg
UezRbzTrXhWu6O2VEw2gwOfvXrDhaSPYUrq73Oy5WNb65uhdqgrKT9R2beFR
eOds/bK3mIVriwWyVj6mEXbm4OkPp9lQ/ZGGE0k0np1v2H+Y24KMnjtOD87S
0L42OBNv3QDZqv6KhmwKwQWyOsNn89HT6bl2cCENqSW/ug6eigFHX3oE6jTW
yUorLj7YhK6LoiaqKlx8kBtrcHrIxNyo6u/nv1Do+/56wmOyHjeXJcgeuUth
obO3i6YDG3wL80MkeTTkJ1zyAlQ/YGrP8YjNt2lcyxx1LLyZidpjJq6dhjT+
sTr8KiKUjdjcUTfjfA7yKre/vJVWjVW/DWWH48h8izfdPe9Zj+WDVxSUH3ER
c9UnXXB/Myx/fHi+RpjCk1v8RrVnspGUdORB9DiZV15KhEHCRfBylml5SdN4
V1EpcuE2G6XndQ4MqNK4a1kaNnfiIxrM/nvE1ziEDiGTZx6TJVC/Kddff5BG
5AmvebkJWYhvnQyTOkEjSzD42rlTHXA63HNubQyF/KxOl+/vy/FJdP2uZbto
nF9SifQFnXjKtDs0XcOFndYh62lWONxiPa/2baLReSGE6R5Th31+T//si6XA
M5hr6KpcgsNZ8XHTATT0jyySmfdvBSokwgTWXqPBjDZalzaVB0vhbezd8jQ+
f5OwetibjvZY753/baEhWHv9TZYGC6wrvic7mzjwXFYvFOXIwhPO06ujDBqM
Ux0/wsn9v/mejXFcS+NYhvjtsU+tYD9SnNM5i4LVual8lmg9hIKzHA04HNSJ
ydcb7PyIKdnm7OvCQ9gw/WJYcnYrapW1XAe8ybx7w6tqeytg2Niz/b0VjQy7
3kDbi8WoPtTw/O09GkbjD4zDr9UCmYvcDQhekWnan/kYadBcranlQVFIG38k
q8/Xhp/8Z0KvbRgC//qXAs/FWhH7O0B4+d9B/Ao12nHxYSluiD/47/N6Gu2K
vH28GBYK1nW5XI2g0N4ksGa9fBMUcgMdj6oOwcx3JNKnn4FBqaVrF++j4DRL
tOKQTCFyfU2eCrqR82nt4NGLa+B7RfXpYz/C3/aRG77fs5Epa3Egd5jCLAu/
9zmPS3GnX2PU1IjGmNSZvylgI317VbPCDi5uzqozVLnbjK/2Iv02Ilws+dJ5
6014E9pmpTwx+cvB2NGXQroLkiArejd+00Ya1ovMp1s0WsH/VaaqbjEFv3GR
rb1RkbgTu/ZBpQINNSvra36hXdgvOsNaKElh+Zh7tEJVGzY4bz1gp0FhM3Of
6fNtLQjw2bbV8AoXfAJzNHsfbUW84vLcWWR/0ziMuU61HVD8kbA3z50L988Z
AZfcGhGRekVbyJXG8g9zzJd2FaL0nNao2AEKdhsElHbJMZB76XchZ5L8fvhu
R6P3bYj9zE4dmqFg9jQ8gePfgTu8qUSDKArJGRVxpkbtWDHD/0eN3Ge50I2j
3k9KYVTiltFvRvQkI7Jgu2sAFsT89rOWpMH3VvQW63gjeoW917sRPr6+qlY+
1d+G5ef7NLoGCD6MxBUR+SzIi5ksFyf7fOO8bnmJZQf2O03eb/xKw89ldJPl
wcuwf7Y1fw65HyP2+BvLuMdQOpPXc2INDUMT5n3JU+VI3JPh+9KJ7GvOcz9b
/lxsN2uacOEneB5JPBvOYyN+e1iVAZcDxsroT3Zu/2JiYMQjRpHMyyXmkiCn
BJzj8mEVIP+39ErI8yWNEHssyaFOctE+uULT9ggb+mOPop+n0uj6KMi4VNGI
yKKq8OFBLngZo4ukV3WCN2b+xpriQJN74LXL8XdQsZ0/uJjMW+3PD5H46jz4
JeQOTZsQfu6t1RMyKsLrkaLU61I0klUrEypevcFgq+fsYRkagx5rpba7tqBX
btmVs5ocbJLu9m8I6sTnA5PtzBYKnve0Wdk9JRC++c9B43gyb8NtTFM+Jm7u
Ct9x0ZZCzo/uiN72bvACxk9YSvPwWZbXdzeqE3zHpkP1winsb10j0VsSR/Tj
bbKWCrl/R/uBn4xWTC3983SfAAXGhshjk+nVULJyGNd9RvTpr7PpeoUXGPMv
k9LQIHo3K1v1unY1nrHaGVfI/ii57qN7yrvhevoUb4FsH+zCE71m8irwLK6z
SorgN3E4QP/2gSb8Wdk2a40EDbEmBfEUAxZU7811zHThwiDtR82V/AbYv/q0
NpWm8PNFbteIVC6Kfr0Xe0j2UdrpxQqxqRIkcc1q9Ml7uxkHxSbJZPgNR4+e
EqYJ3lM3Brc2IKj7uG6ROcFncFKt52QT9hj896EqjuzLnbq+lH4mPn3u7Roi
flnndjbosjMLqSeehoRpEv/vPuB5uKYNq28sLFPT5kL4drJzbmslLohWPhV9
SEN25y5+u94SBI4UjmkT/74YXNV0vYeNniYV+SPvByBirRi6a6QIUlglkHSK
fN5VTZlPjoXZDSL7RxW4KIu2VqlVTceXrtRjhwk/Miu/nOD924wrUdNHvFZQ
OOv5Q2oTrxwTamp7/EPJfCNe/5HQ68BJmYbh85doCGmlVAWnJ2HYnnfuKNFz
f+912iJjrfh5d5Trrk70w9dvtiWzCQYs9yrNOzT6Y4YtLLZnQ2e5yWVB4k86
+HHy6nQ6Tpj/Z2FH/GVkyxmP09ptkP/uK3I1fAjtO1cm6F9thcdmR4HC7UPI
v64zc9C7EPymRqFuR8j8KkUotRcf8PBf1xSan4ukcV/++ohifCmY/PC7gYIs
67Dx35dZMI+dHDo4RCFWjLUjzKUD7Y2K9ydShzDyIPWCcEI7Xvt12g8cG8TY
6tfKgvOLkB4dNtXxlehJkIuAj2IV9tiWu+lto7HQneI12LThu+KImhd7EMbX
uo+pf6zFwEThb1cvGh/a9gT8smDglZiv+3AujfhoB1uxV+14aEf3ne+nQB0t
7+5b3YjN6jckry7i4OsRT8Pb7wn/xS1DYkso5H6R5i11bcK3cE31pxwuxkZj
y++HsRC5x1bkXQnJH/uDgkMEmDjwLu6qawoHssUdKcdCP0J7sUe+0XUeGPzx
PmyvbAjEbGSMryN+YP7IvpHsM89fs+/+Uw6WLS08q66RD5sHCVv9iD55/VS6
2WDZjlKT8bclJlzUFOeGrhZvg442r6S2gtxHusHtTFkViuTyo8Z2UviscXrB
1H/hyKlTm61F9LNHJWanvVw5gsTdGjYLEr2P7zm2JasUwhv+aqUR/9JxtWTc
zo9ElIz8JguiJ3b2aspGT7og1XxKsk1nCHxyZefPqZdhkeu8Jc0CNGKa9ZjV
M3VgqXq18PZSqI/LnOysbUXMKSMzLw8uHr43WufPx8aEh4K/aCSN7UG+y0Km
2SgSK7O4kU3jUWnDrtNJDIzf+sqvRfz7bOQ6uVG8gNnvAuUuos8TKRcTulhM
vK9YKJxaR/BVF/SfqX0H3yL/6cNE3+94rw/eY8XGnQcD5ovLOIgNFXARn9eM
Q/o2I4+7ufg8Eh/ftbYS/K8NSyNVKJhO+TDsUvLwrvZMGuMoDcqvR3lJLgtF
12RKskWGMBa2Le301FtEbH8zbyHha791lW4yHwOeB7tSu8g8lF5mSc9M10Jo
s0/zNgsyn/Sj7plO97DD7Po8G+Jfeimip+UbW2BhvnvbL/L9iwt+rpx1rwUf
febqSBA8PjrZTx2tbQHvl8LippIhyEan39po0ITPh2wLaiguRhxfWT5JaUbO
z7hPqr3E73IYQmYjD/H1ZxRDiuSxg+/TZMyHX0Dij4XLe30aTqM7duheYEHq
/GjgfIr4Q+feRqcGFoxuq+dFRpI89c74m0hWCaQdT0wYkD5iasRIPLu5HbfG
mQN33pPz5i77J/trLfRDs06+IXlKpzj15daZLgh1hmh6nOVieLn2vpo3FZir
YdNxguQvvotRu5+J2YBa17kznuQ7zbi652tftCHQX3HFninSh1p0S//2svGq
qrnYH0MkP0hfcn9QAeGAls9Cn0k+7prefc7mIW4oLT4xvZn44y29Lv+TwShw
03NYtJKcb1z+5meNBqQn3TP95EP04mt1irZBOzpcnbPiVAdxdvZ/+3JyS8Aq
NjSyeUtjDR2v8WpXMwLSS6RXkX1RajLTYt6pw1dmP596GAWHb5G7I50a8Oh9
drfDZgrCksk3jbxa4Hdqrv7RLQPIvbEo4/6eFiQvWRPVZUn08U6Yj922OtQ0
+Mp6G3AgYvRi07VENjYU3jwfp8/F5WhDxwTzVhQdsB0M9BnC8p0db/L+rceJ
vjN8s7ooHCpao2myNw8mwdQ3D23ip5XjpVZmL7D+wc/J++R+t5sqFPbpMrHn
n+S7a8Y46DkZWjaT8BEGE7sUY0q42PQ9oSwmqB3DxXVKlpu54E5wGJfPN6L1
/LSoEYeGcTV/fLVGIn4FacXk7aZx6+jcoczNVaCqkjdVkf45kctUPra7Hey/
+asEB7jY/4jW+HSwAxpl3nsKR7nwte9IjZ7FRuXHwMPWxVysXrfERJ+fDYHt
Y8JOr2kMF9yUmQ5kQdrcy3MVee6ZmPQoO/kuRB+XCy8m+qSpbCyY79SJQ8pD
5WLXByDb633kw3QlVif74UsUwT9r9re5r1uh8sYMT/Zyka/r7PtLpg78ay8l
//lDI3HLiPRVMyZUxLPVRzYSPza8NclXyMaSV5n7JZS4cLlnXDdjVAumgIyt
xgwHakPXI/ISqxGjwSdt70bhxoK7sekravE33vlS+jGSfwtCxOdXt+LBhIVE
zbJBrEmznBxem4KIfrOQNOJP8u/cntWsaIJMf3WyfiQHxSWH9QNN46EQ1OBf
RvTQKmyduHxrPWJUDC9ufc/Fdu3iwb78VgzeV+h55DyIy2OzY2afYsJufuKP
cfUh8OZL7q7py8GLI8/mlT4m/mRgbu/KLsVxbivPgfD1bHHY2aCkRsgdeji3
gvi/ab62196CchgE3xfYOZ/kM7mlWeeUy1ETWznkSPrucT47raPHOyDNFxo1
TfxPYd2bGee8blzOMfe5ZEP05blD+xG/eATfO7hvnPQT032beO0ybzBfoXhH
ghzxi5rtc20+JcBO8LRd4DLC32wJ3/r+WKzO+5l5kuBlt0Ewx93sHp4ppVux
iH7FP5lIDbGoQNaHrXp11hRqPkdZ3X5egNNmqUsyfGlovWSFOFjU4PZI8fj+
9RSWcFg37pU2oX3uiwCPtxw45axjdv/KhOXr787ZS0n+3HpvpU1NBY79mJVo
PkD09ISap3FfF47/UVASvMmDxDTj5zbbbnDNVqyoaSH+OPlnycID9TiUbJxv
Tfib+EvVpiKOjYW6LQqJQjSC384+YpP5Aa3Gt5RUOBSWWY3mnRZrgpPj3Sm9
pyQPqUsGif8px5MsT4N/vnOQ/8lo26W39eA6ay0c9SX5KGP8GseajZ/zhh6E
3B1EbegNo+WH2pDrJZXvvIBGkpdkYv/Xt7j95pMsj/CxKO70nASrCjB9vMS1
jbgwfn4vY7duGb44GY+VkH4S0tmkJMZgQ01cXDT+OIWMXSt5o2UNSK4PWy6f
T+McUyI0Y1knCjx8fixV4SCRpbIl9kIlMvctOpz+heB7ZFfSyDsmWh1/9gbv
IXoWxPL+J4TkSX16RSkfyfdWq2YX3kxG34W43yvIPuwY2/tQQp4Bv+kFanvV
CJ7aAxe8GrswrOclWUDygE6gqIPFsmzw87e3pZD+6JfeZpKg+wS5HR3edWKk
b/udoZX0ktBz1UpGUfT/fWVIYdWWWuw/o+bOWcHFowCmr5B2C07/W/O9j0Uh
Xf3FxPpvNXjkpHpoaTwXxwoHx+x35kJkbouQLfGzWwGOohqG5VDS/VriRvwh
y3vl8Oa0ZkhtHkj9xuBAyPeXqDmLhQ8SP9z2PeTAa7da+GIRkm8U+fcN3+ZA
ymKvbuq6MvRvcdbxL6DB9uy7zjash7a754VjyjTUNew2PtNtwqCzwbfQi2Q+
+WXGyR4s7JHqKQkMI/hR5U1r5tQi7KdN//GtxI+lo1d8jWqBaZf5wlqTIZi+
cc/RDGqCS3cJpRhI+qnV3vm+WhX4my1xWSuDwgfOgaGYknrseLy+CQQvkfG7
yrZ2tehbfueC+CjJD4KV2/3MmyDkEliYMEH8QQzD3SIdOFScluRxmYNA4dXb
qD6iR0JTeRGXif+lHXXYKOsBjQLtlCHiN0xnkSJjVaJvGysyB31Inp+2F6zd
XwqbDBXddfakz3zjSkY/YGCJ3UqryyQvvJ5TofPAoApKDu3XXKqJ/gVOxn1s
ScSuvwf3ymqR+z30pQ0312Jpdi1PxIqLhYffHw6IakB9iN61XbcoFC1ymCN2
rhF8B6dsxUMIH4MOzLYdrcFUokChWCB53mdt6P/2DXRMVv2+6EQjIbpCbk1w
E8blefnepN/p6EluWiPBgl5pb53nBI3we9zjXTFNiG0xjUrMIfkqN2EN3zAL
Yq79WUmZpK/HU34HBQmfVu4J+U3w4h3PuaRp2oFXi+aGlJf2ImlZm8dGURYS
V6553b2JA7bsqpAFZyoxOH4uSKSMQsz8U0ViIbW4YCzT5qRO+H287crmiTxc
rVxZOt1O4fbYH2rmn3fwnH7loBpEI7B3/6vF9t0QUDw7P0y2H94/z101si6E
kZxpkEMy6XPlAxGOUk24OYehd+EYF1f03q29ntwM9oInB68SvTjn6lGYosoG
M+2Xp1Ul2fe9kpM10c1I+/MjpsKexnVhYamTdBfOXVo/EOPJxf8At94l2A==

       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs8lPsaxdFF7ZKUozkqhWxCQnE6RUu6iFxio9xSSOXa2VIRNlOJwtkp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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs0lIsaxl1qbwcVcpncolBpuspBF88kqVQukyglLSEkwijbnsql2ns7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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs41OkbxrsqohxSWqcNiVLOh0qUWzmn4jdFzVZio8YhOUTKYZUcc4hO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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VWsbxpFEyhCp0ECSqKSkCbdwShMSkpBENJLUJ2VMUinCIbMM0WCI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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlGk81Isax6eoELccEk4LISpTkqak7k91ZKsUipshha6Q6lTniNRwqsNk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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk3k4lAsDxdEoSllyFUpEKG6FipAzla8USUil5eJqX1B8luZmrSRNpZDI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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8lekbxjUpzaQyLSMV2Tpji4YK/eiylD1JTKUY4hzioJR1smQZQiWN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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lV0bxVUiepuFzBolIXpJYqUkGUJkKJk6JJlDIlEiSiWVJKV6S8gc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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41XkUxlHhDkZC2uyRGjJFi8zMe6dkUCmFRpmSNDVSYWxFlqIpkuzL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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs4lAkbxoeNUA5rKRWRjZLQ4ROVulFJJbssMbFCFIXUqgaVpfnSptXo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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lWkbx3SaGhK+aWMShiFKhOx+JylLRUIbIksSERmylYyRjCxZkizh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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Vd8bxUkhNEmSOUqDTNGgYqmkUgqJokGaEElCUhooiqRIKgqljBmS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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs81AkXxkcpUqrVLiqJraSSpstKUY/cck2kTG5re92ryXbZlGjeQptb
xPow2yo7hFIuSWJyl1vDzGB2ZgxJ199l2iyr11LtvH+cz/nvPJ/nOd9zjI+c
8AqZxWAwolX1/94szroe9W4QxGrrcDVDJaKMmdtCA4qgvyvKyyaDAOd0pGG7
Xj0M9CK+6TUnYfY80tZ8uh/J0by4qtM0SKm5Pv1ZCL/2nt+O8Sj42vvvv3Cp
EDk7OHG/phEw2PPhSkptO0q6DoYYVpFgpJdr5ZcCX3vUnHFbRaB4hniz4yEf
W48mOSxdQ+J/fgFC2p2PGYdjqUIdEjbR1MdpZQH8q/IdLqQS8LA8GSYUSfCH
onT6/XUa/J0Co3FmOYaKNEYdewjsX8HO7K98Ard1Y+1hdiQa769kvg+Nh/DQ
ipKF1gT05vjEbb4gx9bb7Ym8YBqap5J3RzlJcOhKRypjL41qx7yXTmEtSLX1
frHrFonzssBVM5EKBBqW/bNTSkM8xyj2lsVzFFzvzlbfo4TJRRY7+PJTNBRy
jKorSMR8sti59PUgEgOs9Yy8aGx7V7Ek8pQYAudJX8fzFBbb3leTxnei9fU9
1l4rCuZiF6OYz1KIDHXKYrbQMHjBdKMWy8EP0No2Z7ES7d+582U8ERL2Gz9s
yqMwM6ouPWQvgmdXloexKu+O8JvlCeVcnOxQDvuEEkhi7o7cVylBbKt8qtqT
RvEqkwjBk06oO9/p/nM3Be/s1R7OLhIcKfXw8L1No1zWNaAdWY51vxhd5TQT
sHnc07MytByxT1KfjbcRyJnuKWuxrUTDDjsG8zGBcEvf1adnixF0TMk2DaVg
lZb2KmxEhKL/XtXsKqAQPJa71upEJzSJ5AYrBoUP+l/S2hYMYnTGkBvYRsNS
8+tMaoYLtw/OCZ+CCTBcj/S4f05BwK4VXs8cCYywum58FVyEPHFbQEYmgfQj
Zk0dTYMwy1Ukaq1UIqeWq5sQ0YOh9Fl5ASr/H4o6GxYPqPwUnl3UGEfj7cSc
1IazYoQ/uSY7PFuVp9rx5H8iBfhhqKG0PotCUFp4ur/LI4zVJU/mqJNwoybZ
AT6/wz7DmDkeT6AxR1rFOtGPq6+mPLdyKTA0qUZn7nn4mlH2F7cSMLK+y/tc
ew97R5KcdvAJBDX6DpkMd+OnQ294Y5Mk6qp4JUObq5GtXRBTsYjEnRsci6Cg
JkjzpHyBA4mOGk9e4FgrWALBjWd/kdjzQiM0+JYcapKqgLnnaMQ7sRzNAvvg
xqtaVJZE4cal5MywCzI8Y79/YH+YRqd6Km/jZTG8c30y+kUURpelki9NWkGO
PnXktpBojR4wtdDsxvX1ajfDgihopg1sX3aoEvXfPl1f/AeB/jh7710HBEhg
x51zV/Fgpl7SLizsgJ+pV7F8DwWvT8wr8sw+VJoVWM4kU9jZVzZv/tNmWN3z
+WZ9HInc6gX18yY6UPVcvGlXM4maN3fy27X6wBb5ZM9MU6jknXoeGybE3P1D
KFbN18mebXpQMIAgNlPm9IgGw0vdNc/0MWxTrTed2E5CeDDj/ERaKYa0wuqc
Kwg4Rbv1un/VAoWWO2/sIol3D1r5OwwkmHx2mHxdqOLZM5fbdl8O3sjdkCXe
NGyV5XmxVs1QD+GEux4nEcv5PtPVRAaniGmXQB6NdyMGC5cvrUCBll/K0RcE
ztfQbKmfFImjTn6ZKTQKexmc/Vb9yPCXmL+5T+GnlPy/f9RS4G5YQq32eiVs
Vw7t853ViUnRx86ILySCYqIe1/rzIPHmxsmjCZzW7dIYXjEIzuJWRd1BGrf1
FdVsDTH0J/fphKvugbfqgObnwlaIjQq3ftek2k+38uwZRj+Snq80/rmMgumX
ROuptyLUsLyPvudQaE7ivbab7kR9/I/ak3NV/EXKgzj5IbB++YCju46A2yXL
0wqZHHYJvmdjXGj8UnFufKB9EJ/+VnTOu0UjxiXI27Nbhp8NtF+ckdPgzGWp
u12ToXYTY/txdxqS6+s32M/rwbGbF8YuHafAmVdGHmDzsdBQQ21Mj4SvzZTF
zTN9IDnCJKENDebydzknu+6g175xc1olAaG2TYSp7TCauVsuRS5UIv2HJOG3
54ToaNFtag6noJGTdS28SYRQh7cLHG5RKI7YfoolLQF/n0vSeCEBfsx7bz+T
FsyvP5YvziFRcG3Y9KJWDR4Klz0KGSdQ+ki5Yfw/AoSNtBzYM0YivShrpPVy
L3anZMzeeJUCP3VLiVqMBBN2trprc2mwJZ/sFqr4EHeZtE68prCxMfLPurUy
mPUtWbDmC4W/joZ0OYqkWKWrYbrxNxq+XnX6YwMKcM1yHR/bKcEMqf/15XA1
TOvXOA+q9M39Hz1csbwfE0+jyJbLFBwMzpU56JbAgjOfVvxOgNVxtqr0TS8S
6drvc/wpvCpiiHpjKzBV9OXOSIPqP+joPNR4y0eH5UeLrMMkokVxh1lCAU66
HrXT86CQdduobQP6sbv7wPH4KQr/AsLc0zg=
       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs41IkanpRdtthELovCkYawLrESXglNJ2TTzSWFVCpHikw3nGqxajNs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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4lOkbFhZJUUraaomyKjqQbX7IvYYcskVWOkg5TSPllJHEqrWFXQkp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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VO/fRpKKsmRX+VaEJO0qdUsI9StbkUraCC3KmogipE1CkspWSUhE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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs41PkXx2dRTNnCtlJNRSZFSy2Sbt4uu2nHNauo3Y3YqAhFpYnSZRFp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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs81IkCxUds2ViUNpI89hZutaimIptDWZXKnWgZWy037aYtjEdIm5mk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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4VGsfnRyq0+krobuECKnhjC+F0XJLoY8IdTq5Ri5JNxkPnShJykgo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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8lW8fRopKw2qRiCRUkt0vV9kqslPRUkIltJSMRCiUqChSSCVkJ9nZ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHlYjAsbxjuVSaLttAzpVEcn2boqUoi7j4RUHyk6akJpQbbSCEmEnCQt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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs01IsWxz2KSel5CqUHpURRZKiFb4eKRNEDRSUSyZWj8igV8hhSDUqa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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8lWkbx6VdKHrfY0mEwigpg4xMv6wptFpOyFjClD29RZIWVGSpkJQy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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k4VV0bRlRIyRSSkAplSPKmvN3eoiikgZSiJIQMRWkgJRSSVERIkiEK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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk41AsXx2mxVJaoCJkoS6QIheSromXKcmWpxlZpuwm3FLrKtChKCEld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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGs81IkXxodYJfmXrcmnVnchKtHGip7uF93IbjvRtlSWioxSCWFLmwrR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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lF0bl0+JEr1ljUIL7VlD+DFRkihpVYMhpGRJpYhqCKGFiJKGKLJU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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lWsXxklpQKJEKlNCKdEgleOWpE6kQuUUkkxlzphwCpUm1FcUilQq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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs41IsWRe84InJ9OZKMzlHq0AMJawhFNV+m0txC3UFCV1IpetBJKk1R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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk01IsbxmlPC6nINkVS2n5uVNYedJM1TNxKLspFF9kuJVtDCNEvLj9q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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkbl1KWNG0iGbJNcoSUFuGHKQxaSFqQvSRrmRJaNcRUKpyoM4Yj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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8Ve3bxYUylKJEUgmFMmQmyRJ6CAmlRD9KSD1SaaCBVCqVilJ5DJEy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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk4lQkbxmVyQlSETCvZypKTkBrm1udURk0RmZMm0eKiRCpKoywposUS
qSyDjKUYa6RzbMfBWI71HMeSpU/qvO8rErLVfOf747me6/njea7rfq7ffauf
8j5yVlJCQuKauP7f41Vi6WmFQqz1HOpmCii4PPVa/lLyKTi3zpusOi1C7VUr
hyE3PpxElYzbeykoGdjdPZpXg43vdbi7nxNY7zltNra1EcyZScs1siTWk6Em
c1L1UDMVOsXwCfB9bOd2TXRDqlczoKWJxFSvj4JjRh98U6Y10teNge5PHcuY
6UVe0sTPiuL5Jc3dJpffAcruUt2bcyQ2LmcJPJP5EJ6MOUfuohA7rWlS2pYP
3f1h6iE8EST3DW+lTzWhX/1zsK4biSJlqcKtTnwELFWJyVWnINoelsUya8Q8
tfxzvBmJKz+sNvP/rxBjC2ylJvkxJFSkbo+ZL4AF8/CJ/SwRSH+WanZbG2S5
X0778EjMBK4bb7/djb0cVXNTGQoODJWvI1PpmHy2Oqk+VASHW97M1B8boOWY
d7hPrDdLUG0XFdSJDs0nQkk9Cs0M3YC6rD7Q2FyX86Zj0D0f4+ckKcRuvRxa
wygFZyljG0P3TsQHTfjk/UihMODQmyYVAabURli6yyhM6OyZM1nJwxT3m+as
CwmlEEvtwpkGhBbcGbImCDhO99/VrGhGsaKd4PZuEt891x2WEXbBvODcfFAf
ifyTbelGZVXIdCytXp1KQFYi19vnLB8R27o/RLhR0HrmXB+wrh/f5f/sS/kP
hSH/h++e1CUjbcWb/oRLIgz5WLBXaAlhaZHU5lFIofHbSw+LJgHOGWpspu5R
yH8hb7C/uxbs1nn2p3ACzsOOaZdofDx2aykPMaBgm7Q5KLWyFg/nssNbywic
8WrR71FrgfWx6hT+FAF3dVknw/kuHH3AD7SLoPDo91npA8JOLK2OYx9iUnDj
MZP1bXk4ueJ67RV1ElsqFUoW5zg4OXJ92VMPAhJJK5KC/dnYYcu9XbOLQP55
+vF5yzowpL3/mqwkkPn90+k9WwWIytLeuNdbzPcx0Y1o4z6c2SOjoXRoDJ4j
0os5yQJYre153R0g1j8WycwOi8fMwNv4cVcREraUTW76yIL0xeaKh3QCUeoX
0uT/TEX/X/NFvwWIYL39fcnK3a+QSLw28ZYjsGr4TFBcdA8uL9EUKIxQMJep
eq70Cwdq3rJXBu4TcHlnp221cA8TRZkp5tbifdMSgx297fhDo+G+aw4J61qF
G/rvWzDwb9pXT3MSg9kvEn25NXjAXNO4PEL8r6znqnMurzD9g27urqUEjHpj
JfNDOpF42U+hVptC0A6W3l2Dmyi2L3vkbCICfe5jzvh0Bh49dn+v/VCELGag
vZw3F0yZxD9ceAQubjl1qtysGLWhDxVEoyK8q7/IUU7iYMRgcvXvsQRiTqyS
7JniwFitvfOfLgIaj4vezNxrx0mHsHUWXLGfDKIHjtGb0cs5Nqk7SaC7g527
JESIMk5SmaMtJeb4k5WjXD02/HNQP5pGgnWk3ftmRRfCi9+PtnhQUPt1+ab7
xfUoXCkRF1dPoF82eHT8RQ2mF5QHS90IHLmiXG5k0wnrWJfeI9soXGgeRwW9
A4rDclovh0lErkpwZSxtwvCwHu2w2A+hfvqP26IE2Pa3SfP6KAqywuAEKx8+
sEx1v/wBCl/lEjPl2jvQ4R7ISm8goTgR07B+Wzv2zYYF2vBJqL418rPgteJA
O/2OfzEJzRulhqHRzShsS0jzNCJBLTvub3uYjZ/443eNdxJQjCQzF6t7wOv7
EJlZSoGZtnuRc4iLl2Vhv80Pivm0Z4wFneKheWJKssqGRHBj4FmrNR3QiuiX
Nt9H4tp2ZlstrwaNUsr0sscEyr7v/HWcyUacyly4qR0Bpayh9MGIDuizGNym
myS6flGxv+BVhdmsO6ZbGARml0iPvnjagjMMtwEtGRJxGpMb0jP7YdZodTno
OQXLgk1vuu6Uo4qREl5tIb7vvPl5LK8EBQ9olmclCWyxyX5xfrwVrVPOekJl
EhPStvR+1xzkFzjHmaaLsGiecT1dugcNRoKvLCsKm2i+ucsCBZjzX/tZ/QkF
u+TNRZobK/Ha7q2inCOBzU7f5CMOCuG3t31HZQcFdd+/SwfJTnz26D1d0kpC
9/jblYsNjaCtNR9VuC7m4WNNUtWGcpR7HtmppkPgWnDGZZUHBXD9cHVie6sI
S0M0fRo/t6O24I7wqTh/20iFE71UM0q0/ZLjTUj4JR4SlAsEuLWQEZqrTOGG
8R6hjk0HLvh2GvoukohK0VmIlK3Av2ufHaUxCajmRd/nGvKRLn/fxVVKnF8Z
s0bqjC4caHrFpw2RiDHZd9vOuh6fnv1kuzBLwBOJ5ZVxjTDWrzxTs1XMi8CT
PSjoBVPeLCLSgQLvZy+O/RchvFB/1SGcgmNc6Ze9knXI35NtEp1HgDbl7n1w
tAubRLUOfWkk9D0ONBWvrkPljFlYYh2B/wHxf9XZ
       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs81Ikaxq1UyLWL3C/pYksUIkWPg53KQSJCSoVQqaXkdnJUkkUR2ViF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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4VesX1mnSNTRJGS5RIVFKmYoXDdwMSeM1dFFcojL166TTYChKIjdE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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4Vd3blpCIN0IRojLUmwwpMt0SQprUW5Ikc0UkpVDmIRRJpVLJlAyV
QkLmMZmPYziGKM7Zh/qFUAnf+v46177OXmuv9Tz3cw+ydu4WjpwcHBw2Szg4
/v9X+q98hHNAGzae51O2d2fDY+zZTvWE19Ccs5v6q0Ah4LZ40C6hSjBzWs4F
m1Bo3Ww/Xm3YhE2Tsa9na1i4Eh2qe+dSJsru3P0+O8NCPn/HXl7jHmiWhVW8
cqMwaLpaf5tOJxL/9X/0MoyFldX2clnfW9GU1uK+2MZCfPfN55E/PuJYX5RB
ZQ4LHuzSCtuINMg90XkdtYXCfGXfj8O3yyCjFq7F+MmCiTKPYpbre/zHPLlB
SJWCbYz5gSdFqUhgOsXdFaegean4mN3gK3Bu4bDfZkyheNewkufLFsztEF5v
JUfB+sckLfNYNjhfWvgLqJD1jO3+RwfrsHb5BOP+fgqfX40PNcvVImn3yW6z
Y+T+bWmObccz4TFk8iB3G3l+H7h8Tr8Lveu+Fl78zURvTm67t1wdboaNcFkp
spGhVP3Zwb8ZT+6LP8p8SyGjT8i6434tSjYYCX7hYKGAp37pUsseBHF/ks99
M4Zf0zzrvLxy4SKyLYKxloKeb62+22QrihJqN/6+zYL1b/mcUyIvMCW9LNxT
kULe6SPbvWQqQHsraT83QuoRkOdu3leDklWqGpmxbJTb7JFiSNIhLRXiF2bK
xi/eS7W0pFp4bbNfiKmlcGLT9XdX+Tog/DTi2v1iNvyuryqKGatB7TxPvYoJ
C9UPTENjRCoQ2eNRrfqBBduFqlyV0ERYBzHuFm+mUNrWxZNL70Gq1+DCHvVx
XPbvO6qcnApNPd3rc1wUfh6b+Jxq1YO477ciemfJ+brNsqeb6Sgpqpw6Sc7T
sIpXeM1CG5LVisH3nQLPz7XXDULa4X7ISvCOOAuK76UUY8yTEHhu9q+2EoWB
s49OXZCpQ8EGD64V2iw47Od1W97TifOGRR94zo8hYHgwXnBZPMb7VAU5N1II
HLqyu0W1F9s0tXsLfoyi3GcZ49/jnahQyeZ05iP9K2o8t2MqAkX8Eie1pEi/
pbK2Xomugq3y8PKUGgrlvY9yTLkeIcurNlFlNYUr4jUOASFlyDDye5Q8ROrh
rtDFvP8Rln+Hv0n5suAVPHw+RLkOhbH1g5ttyfk3x4qUJWVA8gyX1JQYhYjN
S84oBLah3VnENOANC6GrfH73Le/Bx7g2UYthCtknrId48Q6Jpd1Txw9Q4KWr
VdywzcSK1Ye2ThhSmG6+nLsysBvlS2dWGf9i4nLU7yjHI9WoUooQ/3ufgiR7
b4xSfyNUuZI9dvcywTH0+KY50xt/NxlnhMmSedjol1I98R6Xa85ZqJhTMPL4
Na85nQ1JMbFib4Jn/cNX3dcsNsMwyHhJsxoLhq3FgQ95GqC3bcFs5zWCN6ET
k8nenzDqzS/7TIsNvSY5D6+GDqS8kYvWusFC7/O9L53VaShwdOA2oVPw8Jmx
41V4Dd6BzzedLSlw8HRyafZdw4qZDuWWDaT+MVahStubkGKi8nztcrK/WyIf
j3snDG+sXmnVPIaU5bMxufvpuH77jWbVMhbOlJxd73a4G677POcvrx5Dxpy0
TMiFVnAP/LkjM8UCh93Bp5YvPcGOlzxiRu57cHqr8AuZEqgbB6vEa5PvRbZ/
3PYqDRPu8xc2ku8J+9nNMFPacHTr06RAbyaetJolrDtei6+Bd2SGu1mInh53
ph3uwmVbh9QFU8JHt9bk3TxRD+VnMaYSlykMb7hYHtzHQJhx9j11rzH4GTmI
qcbQIBHVrP63gIVxxp0gN4MieFHdBS8Jf3p0OS0EqRThZKiv4qw3C9c4dCeS
LD9hbyTHXsU0CtEn5oxS/buhzR6Kv7fAxsLZpRe5HpTDuV80ZjeZv83pdwKj
NBrQy5XgaHqEhZCGFLO408/g7rWk5ZoBwetXvcq5xzHw8tw3sIHgWeaKx3KJ
xS5MFjZx2I9RWFibvPhcuxU7vKfflbdRWPMp5cjx+mo0Lshd542loMOpZGQu
RoP+Xa0sCc4x7PJ9JaSg1Y6CgCKG8xo2ThQofrmT24RYgcOG24eYEF77U9BJ
tAcCa71zFqqYuFtQ/egnbxXkojLKjxym8DIy3UtngYHB5LDM/QZsqLVG5CQr
tILlFVEWJ8RGTDJveGlyJwqDpx0ZTRS2CHtYxJXS8Oy0n8VPfgrdDyc5V93I
wz2d4mquExRib73wfhSShZW3NA6cJfxd6Xc5Z1aZDoMDRo3JEWy4dL4Td9vd
hKNP9s3LexB+cN/Uvm1fD857+jLU/Uj9f/osSdxZgcTkCY2qUlJve7HfdUp9
oDl209MF2ZB2lje56teJN4yalXaED2O2q2wyV2PAZiJ0HfdxCpYnNi5TD2jB
ARlHP+XLLMxIWi5M/65Aq4KP8oHfBE9OXx8oV9Ui7UIxfSXph0y88IKCwAB4
gnPD42+zcZDvoIGbDQNi7wVp2d1j4I81V4nK78Q+gdFD4q4j4N0YxjtiWIDR
wQej+oTfNUy4FUMdaEjw/u5XFsSE4sPmQ8hrwhrn+OCvLixEmElpi6Y0oU9X
YPCBCIU/x86Vremuwp/Z8HjRPgo/5L8HKCzWgabrOb2Nm4KYkGT7u1XV0CmU
m95whwK7aMmv9K4WdHQEzQ8uIfdLTJS+qNOFdQtm1QoLI1g+8E+AOOGrL43D
WV5STGg+TbIPeNYPT+nB+f5YMm9DR+dkKj3RcYXz+zUybxI9Kb4Hh7sQtrA+
qvDuGGbmnih43axB90DHn1oy7xxBphkfPGqRrLvdat0GFjSelq68YdOKtv7f
k4UnWai5YSIVFt8BX66nzNpAJmwllx/PW1KAKLeFyvUPyf5d5rcl29qR0Oeo
YaTKRubBnJkFvX7YWpuuWcsk+1v5qNlJvsP2jDVf90qT+T/4qmLSMh2aYplN
05IE76pTx2+daoV1/DlhkbVMhLj52uzV7cU9C5PhrXQ2hoOz6mS1GDgkWog9
q8aQuuzg97ysHqL7E2X1k2wE0M65VbM8oS/Wf8puPeHnS+qVPqc6kZ0xclvC
hAnJgN1dN89VIK73+ocGZYLX1fnbyo1KEDy0O0PoDAXXY9pa8nc6cLJXtvs/
DTZZV2q5vrQeiqm+ymcWKJTwdfmufN6DlvMCVtxsCoJLrWaLUujglHw8KCpP
9G0vt47CaBPyBRJ9j0WxUegfr3l2TzuqX01uGBoehYyNTPlXr+fQ5LANG9Cg
UO+kHa58uxuP68R6/p1nQWz1uJB3KB19xofSkxq/Qt//9faH7S144pFtyccg
/qQDTzlftGDH6UP/NMswESHd776DswdUeZPGEx2CX4UrVta/niOzpdCTTu4X
v6rlUsCTcvi7yNB7wiisfjETVBlBg25sY/Yugqe+BabkP18+IZv7/eMvBB8O
LaVLP9Qy0CYv9/FRwxfIiOkdupX1Eg4WPfTlRH/OLt75mrZrECzlMwO28cN4
+4/MMK0qA0ppolpHLCiYsKmWbssmBN6Vj5Ndx0S373j5v6/aMfkq9wI/L+FD
dQ7m0NZWhJ58PdAoxgR95Zp02kQrdt74/FOllw1fCSXViy/oGIle4ejEQ+HV
FtaU/5UeaBeFa2h9Ivq//OlXJnluj3t45dSDcSQUp9ZmieTikF+u0xGiFyL9
jTNKGTXwfPwxtNOa+FeNwnOR4WVo6B4S0U8i/vSNsYDibjp8WRmNN9RIPc/K
Pt4Rloqwo407A1dQeJ2ycXFW7xVkzs/PPCZ+dlSC7qjk0wGd7Bf/RM4RvlBq
ymwe70LlF57cUfoIOI/vS/v0sA5RljNH6D4UuDKlXb1CqqAZuLX9zDcWBONz
Lk56t0JMK8vd/fgoCpWVXTfQCmGcu7G+tJn4LdNNrz5It8PhT9AF634yb4aZ
cf/atSOJt0iNP4jMi2lT1/KrrajcdbPB6wwTH4IO2JzP74GOU7LuEgMm+kKD
W1Oz67Bx5bcLRUZsOG22mO827IXPrsvzO7OGIdF7XG2rShd4GU3iBwl//RfQ
8r4xNB8uhX+COc2I3oJbHPKl8NIc12naS2Fm8ZrIgHQDWEphtw5cYuFs8fkQ
if5qOJ2YjzU6RMHAtlS5c2sdPm6XZcdVsaC+yS2KXtsM3C923S1P+HZNNPc3
8Q649pqqa36gYBaWJp64tQRh+bep500sBGk/OObI14idxVJGW0ieqA/oC5CV
zoYn74x4CvH/P+rr//ptK8d3zsT7Dm9Z+JG7q9o3LxmfO6f0hAn+XBwldNbZ
VqBW3NnG5yWF1JYTD6rF6CiMNkqpa2UjTVV5E2PFR6hoSvPzClOwEnz4euMw
DQ2obgpyIvzQJMHJnMqBp+gThj3Z78m7QIOBTZ+QKBZ34DLBh3qpcIRWbyPC
rn600iT+Nz44MeHx8Y9w0H9ALW5iw7ufu+5QQjk0qAe+TSsJv1i1/jXtbMEs
X/mJq09YEDHa7Bj5nY6VBubrtH9Q4GPpqAZa08A3mJkiR+5r0/K1Kl2tDTbX
147QGpj4VH725g2tAaQ3hnjtah9D9envtJ/m3XDrMs0RqGcjKPJg3KRzG64q
v/htSPQ2dcv93bbf24ALi0x7c5JH6mhBVcXFsDM69D6L+I+fitsVeZb14IfI
jukevXHIvB2/9rOnC4IqDY9Kypgw3HWmpp7wnwJVl9trRPwkv/XN+ZYYdGs7
BqgQ/t8zsePBB+ojdE8K5L90oeDDmNbvMe3F4x9WF6pTRhAhuc/adzYbkxwa
fL3Ez+XnSGizNjagSTvowNgo8VPSA3+GrKsxM/Kt4HYgCzH1T405+Om4RT9l
qypL/FfSiky9xXrkG3B665B8YPlhIpMS7EVA0gqn/0bZSJ0OvFSg2YX/pUnc
v7+fBTPzNjGVvZ0o/aD7oneOhde/GOo3z7WhmWkzeetfkgevWnN2bamD/Mal
/+vzY0E/XvtUW1wlri926/RR5P0KKaeapbWw6FqXaUT8vmRtkDw30adz8ds3
lOtR8BuPltlcUIj6kcdiJiVEr43FNh05WYtP9YceFe6mkPT3olbcrQC8nrrE
L0H4UfmLd9KFrQw4Mube7rMheePYWwctqhyJedIOejQyL+pDMR92deHljMcl
qf+xEfJxQ6tFVjWaf+l0VJ6m8Mvl8/ODxe2QM1BIzM8i86OmrXJ0rhK/28K9
GnoojJVbvU+PYoBrT9y5xPIxfP0fl5Lw9VZwxccWx71nQ+VtgMrlRzSMQvT6
7h9srPfzvOpv0Ykloh7uAYQPCnLs3uWndKLk0XD1WlJvDpFNS9fwF2PTit9X
+0ge+nWAZ9jzdDkm5tXkbhN9+CMkcLXeshNrDqRmhvMSvu4znaXlfUT6QrvU
tjgKh3J9Lgg0fEJmd8CnVQQPihMWU/omb2B9U6PrpDyFwmmpjljbAsz6R4f0
bSJ6KpBWV99QibjdjnMn8yhMcb8P9MjsR57Y0DbZ/9iIte7dnnE+DTM1D0rF
9Eme4PMyy5l4A9ny30z9n6RfkbJmRVMlcI0R6exPp1DEkp2vk6hDpBiHXV8i
BRXf68/nkurAp25n5RFO8pvrUN4p32fgrZDnDCd5toQVsd1ySzdQtunk831s
fB483Cs99BqWxsIjC2R/DhdR2XyaCUTWXLz0m/TT9YvFQ13OTvwU1HabnGCB
bfqk96cpDVkmAxPsYNJfZYFGoV1kv4YzNSUvKCyRPXx8m2ofSv1DdBmbCH5v
mslNEj9m1+9jzHQk53+o9CVyPA8DK82q+L0IX8Xv+V10rQCxX0WXhZM8vlyf
IVD2hYaj9Iz87h0slEdec7zw4wWiJSUmUoneRfQuGVwm1ASV7IN7OrWYuGeu
9C3zZiU6RvJzms6S+lrJhhtkVqEvJGHne8JvxrWP+5SO0+HVVHfpn6NjaLXM
WPvFsAeOEs/3RxO+Uuz0ObP/ZTfa5Prme/TY4BCS/fuZnoFId7F+HbJ+BX/b
0x99xN9nZ/usfMGG8ArWCNw6sK/V5VtRJYXDfalHRYi/GqlI2Y4QNiwSHJ9p
q78Fv2jC0dWEjzSc5ccyXEgeWrx4j/WZCen918e35rXgru4pU04l0r9E4a3C
9rUYoWx6LMj7IqbfdUYuNaAmNqzQ6A8LAQm76y4fbILZzRie9GkWLOINBb+a
VmA+lGXVeY5C7fdLDDfBRoy6LFotJX6bFXpy2KX0NU7MmrrYe5P+BNwLVrjG
gIKQgdu37lG4bU9SdnJtQYnHm7pj/zHhM/6m1+VtFR5Y2TF2chJ/7bq6STSB
jtNCn6PE/Mk87aAOm4SUgcNZQWy/Hfmfv/2ek0sbaHelLIWLiV9ZZ2i/nDcf
2RLd9dLixK/e9x3Oo3UixHlXU/JeJiIdTN8Yit3G8GL0HxuCp3rlKydPz+RB
kZFjf4vgcYOGs+jcsn6kqj2Nl5thIWGZqgrvoj9KxI95CJB8lL1jabrNC6Iv
PJ1pt1wpCF3KlHt1rBMZ5895nO5jI1+5csosuBv6RuY62WdHoaV+6lfe7i7M
Gs6G8xRR0Iz+pnthTR5Ow7tgbC3Ro4Xts3UlbThfmV1jRfBWralTE+rRiTjm
P8ucCB+WRiUoJmc3YH1U9FIHst62e+p//ELpSH/QP9YlRvzQM2778/QqxLqt
Dl7dS4G7xTDySFoP/hg8Cfxvmo3ys75uq4cTIPDxlkAv6cfD8y+eDXZ2oq9h
sLEnluilzxy79GgX/nC9lyjlG8PDHcccXSXrkGOYG7/UnsL4fuutrM0VUH2v
KXu3nIUjD5UD/bk/Yt3XZTEFj1gwt/qi775xALGK1bMzloQvdA+d1tFrwnfX
vZ3ehI81d97Xk9tfh4zWNoZ0PAW1P8vqLvuS/Zr/GPNcIfl06yrl6ctv4Xp+
q+gyki9uBb8wf1PUgaxe0fOMDJIvrtiYs81LwSc4GU4do7A/Opx78UAVmS9r
QZ1a4rfk/wbxGLVAZNpdrmI9wYeHgtTxzV0QUzNuiyD5RKT9XWOZAB0Xo1td
QseZ4JL53Jty8hNWG0S1FJL7x8U4rRUqo2N6KiXitPsoNI9NmaxJo+HJfk3J
r74jsDsXMPnnDQ0Dydcdc5PYOPBDNfSpZgtionTj6M5s/B/kEfT9
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs41AkXx6WU3dXFbdOFZN1CRVH0pi9yySUZl+zIrutGkxSVdHlb2ZIi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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk4FAobxUf3apS9Ltmu4kabNHWlK3RMJSIlVCpREiVEEfr4yL6FQmgh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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lWkbNynZkkrqkyRtMxHSoQg/pdOiVIzIUnQUKWMryyBbaoyS0xQT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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8le8fxkVJkWgnIrIVKWWUC0mUVUoqIlkpZBW+hYao7FSU7JWVFSor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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs01AsXnTzioqu8Elblpq7yuhXyqLYVkZIYvZaMV5IlQtNDEspKEhFx
VSqpUMlFXjFETOQ5Mx4zDeK6it9Dj5tUivv9vj/OOn+dtdfZe5999P3D2Idk
WCxWJFP/7zv3FeZ7Eb24Eum7cmqQglOM4bOE7f34cDTNdPEIhfV54rNLUwRQ
dJ1xS2ZRSHc84tvhUo+17dOKvxwkMbHmztcZ4wGwZ9rO7LtOo6KE8+nzoxaY
XmoMvFdNIjxQVlLkJkRO0h2vzksUorjjJQ0SAbSGDowvqaGgEjbrVereBe27
n60uHKNg4LojSMu4EtOmWYHFKiSMeyIvy6gNoF9fVCXxoOG4/nKM15Z+CAzK
5XeF0pDLF7IyNIfgHbu4XnfPJCyDHAuPjPNRsaHPMKqMxH7srvZ2laJcTnTA
PIGGoWfVPIUfjdC/ZCodjiHhv1+Grxraic6vYpnz2hRGiox+wGEQu581qXKC
JvHxIOe/aw1ClD1VyW2vpxBnKNts7t8B7605Oc/bSBz9+qL/SHwrbEoLWrdN
MHgZ/oJ3j6tAW9u4BX0iMPKP/StfeT4kY/m3dWpJfOMrR6rWF0PPKO70wCMC
N65Ey3FHJNBOPNaSFkvDfzhAZDvQjsr9Z55mr6aQpLJaOhzfA9KcJ1tRSUE7
t0VBLrUHozdiH7mp02h469nQv68UY+8f5i0QE3AI3qsTndmPe++T03b50jDO
TKhzkvIQ58I5pr+ChMps0CkVXjdoP6ULlsEUWm2WcDpZNehXm95cu4pEyuZJ
qdlaCQLSb+fVVdOIs0/srrSVwBS3FTbV0HAYUxgrjOtC6F513RdsCtlRxJSg
6jX+kA6uzf1Bg5WoaW20qQ4J1/08JUtJCLzKwnwb8uHhPLzkdDYBjVjtJ5p1
fWhjB2wu2EFDRS6ErercjWSRTXtpJIXtJj0h49dFUNLxqYloZ/jemz0wuKEH
WQqr+fXdFHydTrvrPq3F963xmsf0SBQWrTweWdsNR23jX+4nMPqtSz0XHtYC
q8MHQvuGSASeu5b3JksAZd3J35YVUNDYpgafi61oTvb+8vULiYUSyS7rCQY/
eGjU4iSFhL6ll6f1m1A1Vt6dc4JEPielzcZHhL3eL3s9LGgs1PPhZrTfx3uH
Dlm/VAINFh2OZo18jLwPPcErJZF2a9HOZd+fIkrJy108Q6DNc6OzYJ0E0j1t
D7o6abiudLKnIUXAP7rb5lpp3I8e+Vl1txCBH1k6Nxk/sLxT+9PoJCyWXfDV
zoEAb37OizQ7MWoTSb9rcgy/TuWW3xdkYv89f+9cD8ZfBGvFrdomNCedPV9R
Q2KjgayR7XcJ9LKbrS1caGhrzNea1e/At0KhznNlClMP0lsCpnoQ0pK3Ik2H
hm1j1B0PjhjFRrdcXzL3vqbUSauqow1l864rJelRcFl2aWPr7TY4ip3/fsHM
P5g4/OW+ZRGOsZ8d55cQ0OKNGpvY92JOjtf5LY6GdTTPQ/6EBLsDzbesZvR9
J50t/LVIAOEmdfmkCgpUlr3fgcA+qD8eEx5m/DyxyqrgKE+IrKuvL6sq0/jc
bLFBy0SEadtPbdx1jN4pbwM4SrWYWrziT8PlJOQU9+xYrv8SCeoXq/gqFNLq
D4RrfmsC969wh5pMElyZEO/jzrUYTTXL3W1Pou3km0OrIoR408CecPqdgrl/
k5G1vQjLX2XsJOYosBaxV595lIid9uofS+wISJoOz31WqYTPorJhjiwJ+aGT
purXXmJ7dnxeTQaJaVnDsqG/70JuLtHFIYpA4SmC45iViWkfjbcXPAlYTf2q
GCEeguC0c29sBI3C6mJdDYNWGLjbRrkzeZHWLzX+0dmBdPMII9tUCo/U8q/y
Bgaw31gaeq6CBrmy8yFHmQ+dVwfb1QZIaMeME+mC56hflLnguwOTpwevq7I3
VWDutrOb8XsC6Z6/UQudpRjJ2BZy8ddJvOhJXes3K0HMSx224b80BkWH4m2Z
fd3KDa9smKUwqLTs8yf5ISQtG5oXfJyGgpW9v4m4GSdPqWrm3iThsGm0L1G3
CWpd0UGPS5i88k3OqTQXIPZ36RZzdwpWvRr/7ZjlwcWOeBxqQOJ82NI79qIq
VGcdHhkhCfj5RlWfzujB9oIr7mLmnwwKxX5Fg1KIFc34K6do7KbiFq560g6T
c2cmCywo2P2x7fgn04dwfJtZNv2AgOLdHfeSZaQw+iu4UD2MRriLaZ3OnjJ0
HdwV4jhAQG7U1TU+oAV7zc7UdTN+X/ezoZiuKYGe9hA3sIPA8n+fe66/0YiE
iMtX9nmTSG8sDm5ukkI4w3Uo3cLkeUZK/c89fbDzSjF4+5hCVrYye0ZdhPHo
yXdUEgVLmd7Wrq09CMgfVfzQSOGoBlUeW98Al6sDf/JTSPjalOcsNhNAxd/y
w82jFEbJOzrhw0Kkh3xwi2H+m7aJ1lnuvQqUc71KXOeRcHyVIlPS8xrlY4Hf
uPMnUb7GFVefdODExKooTSsK/wN5F8iT
       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs4lIsWxknJ7vREdJVrLoV2F6FB9YpyohtDIkQyUilKTqJ2N5EukiKp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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk81Okfl5UslUprETXYIostknG+/XIVmwrrTn4jWttUWEpCihylVpFZ
OdZP2IpcybZtcjVyN8wY4+jQuh6rgyhy7fP7Y17f1/zxeZ73876eR5V1wtFP
XExMLI3+/v+NFvX0qySm4PjkwYEpNQKvshZDH/FODK28ERpzhiDphqJrr96f
uGPkcfm8HoGj5faT9ubdeBjEcnpxgiDnop7Cq8sJkOout8il85JfHZgvTOAi
5Y2GbL41Qc1AhTZRKIRYkEmAcAtBgfN3BhmFHQgpGlWNP0kg9u0h5pdFD5HQ
tUd8eCdB2J0MSZeAOigHlGsEGhCUDpo7ZS6UwnAkZy9fiyDwl+ZN8/U9ELtn
8N7/JsGtYjtXo7p6rHGQsenQJwAnKqlYvANSbTpSf7MIik7/vKvVXIBIfcU1
yt4EJ9/qDQ62NqExaEVE6AGC1Y9rOGOMLvDDDld/E0EwpbZu4Q+9BryPcOdV
7CHYq9yuUyXdi00FG2XO5hE8YJzofbq7BTW2Vv9EWhE8LBJef9UpgMFvskfP
+hM0TpnanU4sR/ERBvuGDoGyzJUjVbMFGDUYj99Lzx+m8lFDOr8ai9yytzu3
E8yLLRmnObfi4vMzXNFBer7fF7IZ/ymFltG5D+XfEuTlv/+x71YVzgtGbdZT
frQZ/02caOUj+oSjYe1FgsPRVj268e1osMhO9XSl+Obqc25cbcKPh7X7YvcS
HL/HOHLncic6XT2HNU8RlAVsttiyOw8z5Sc+Zm4mED27q/5pqRwb94Rr6FN+
XTS6aqQ8OjExNpxUFEj181KXkNFtQsMXNqvXOFP+gv5X6bheBGe/8WucEopH
d2emaFqE8oyJZdx7BIX6uQbHUjqgMWV9ISOIIGSGrXy8owsGXjZlU7kEpnIK
cYUdjfgY/07ayZHqY9yj5j5L8VqfufulB0F49PLZmrV9cKzYunbgMsH3c8sr
p8/x4bh8KHI1xfPE9l3JP2rtsNpYKG7oQ/FOXTdb4cGDs3Cu/L0TQXT4xl5X
3wjcecfh6FA/3kp0e+I0KcC4+69nJ6m+qXL2r09rPYNzrvbqhQCClREcPnuk
B8vb3Z59wyVoN6udLWloh04nz/sl5S/nixBlU518mEcuLH/9DcGor2NAFL8S
Syf3t92m+sVJBDeyCmvwo8qlDTXUf+v0ivz+6e+CQDdceSmbwNh1v4n5LSH2
PVRPYGbQeU19pqxmJcYvmm0QbKP4J0pj/AN5EPDmxY33Uf0H8uanQvnIVTqs
WnSa8jGRXyzdI0BRkYxfOcUb5tIiruTZgaWI4WXMYAI13bgxlwtCPJD2KUlI
J9BE76c0Fz7S3LI2fU6g+ppUOkxliBAd+1hRh+4vVlVy79ipWnwZYtNURPMl
wTL3rPfnIU2n+xLzOMFiuPVM5lArJi1+Xhxzo3yUsfRX+pUhXP+HOGlNgkrv
xR4J40bq++fn75oT1DW5KekVP8LUqchL7vT8M2JZLZ/MauCllhH1ivq1wjvd
p9i2DfMLYalDfgR7nipsU9IXIFqLUa9P88JIf1vZzU/BjoAdStvVCZjHLvV/
PdiMd6Op71VsCF4ripLvszogv5kbcpv6z3lA0b6W3YzrhwMFSj8Q7MiLHC+s
q4V805WorXS/88oyf/Ny6vBRc/X5NbsIeGV9EeyAF1Dqqrtg+4Hq/7F2ldqy
FoyZbeRbeVF/bHU9tcXiKYKrX//xhObdIVzx2LwWH6fDZ41jY2ieLz+TuuLU
DofRrJgsO4JVitGMVQNCjBrnVT0II/D23HmukvEXmo6YXpuged+WnkzcUgrB
FBQYDtG8CyWeLqzid2A8vvBmrzvB5Aazq/e12yDPXHGVTdfb1h56JcnzKay+
m7Nr/Z7A/KFC422mCPILk3/Z0Xx5z66r0E/gwSfR9/OyowT+GsO+Tc08jJ+J
01Oh/Wnx91xpnYMA6yvC2oZpH8wz0+PtZ7qg7bDbRyaV5m/Rm0juEKJcYBDC
SqT85D18EVJbi6mTnB0JZrTPPT/9wTTth+RnvpxGPEHrY8vC0lyq/970CUvK
x0sX5p9BLD4sUp4oXaP9EjU+U1GuVY2Q+p8cfan/1/6WGLlMuxdR1z3X6lK/
5tyU8o2xuAnzZu2JWJoXtzSui7qNEIpt7k7sNIK+xG8l/MI6Ia3emzJI91Pv
EHpEyfVjZTFr5IdfaH65Y0Oay+Mx3HdWNo7mV9cbj56n3sfkpumEYG2Kd774
soaJAEnSmxle52g/BXw+uJTbiam76w3fRNP8iKxMtDj5YO96vrhBg/pRVTPA
z1QIu59ETJMoguaSpKptli2QVFVfu0D7wgevNEN8stG87692X+q/6KisM9eM
rkHKLFVRQPcXN5LRYNwTIdTRiR1L54NZebYF9p2YzlPNX6J+3J4+nX9spBtp
GaHM76heX5Vab0l1FaJ17FXUQdq3FfLuz/vieAh/2fLe4Rjl125ksTKkA1mc
ZtnkSIo/czF4f8kdtAY2bCmmeMcCFcbVxF7CyGKx5GoO7QejvQfMbflo9Jx5
13CE9kf1Sbe5JA6+2jI9aE/xKme/tGoYfQKpXYvfL6N+CrNWEI8erYDnmE/C
h62U7/7RLokZAbL7YxJkMwmkRRfkDWa5iOj9ff2CKe0X9DDULXkQHm87cugQ
gcoG67xDF7vhHtiUvJpD/Rk30nnLPgdvjbwcXaiePk7TUzGPM1EnJ1OpRP9H
tYcT+1oeuCNDoy10PrDvxW4/y2LIJau+WUPvE8MxiVg9dj0qdN6691rS9RoG
oyybnoD1SCPAwZC+L4YU4qb7+WDrpX79RSz1z9WzB5eqfsXxxoNvjOn6gcOy
7N7dPTDT4RTOVRP0SyTfv23BReoqm0dKtH+8gs+rhrqJMKUzY7/+AYHSByOZ
zHXPUZcsN/aJRzD4WG3316wu1HFTN3kkEXimVW5iV/chJEtoEHSD8mHRUHD3
Tgf0DhdIrqB6sHXMuOa/18IjKX3xVwuCbPkc/7zhbvpecGkao/eHJFSyVG3p
++XAgAGH3j9FNzrTTBTrYX90l/91EMQnHDiaYc9HxYfukUHql38Bo+W0AQ==

       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Vd8bxYWkFFIyZKqkSUVRKrVMUSrJlCgkUVIoIZkqJE2KSkWGiKTM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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41GkfxtU7jhFJKryF2FpvRXbJVroJu3a3KB1Xqs1ZmJR6KyqHhpU2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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs01IsexSWVQWWh6aWFGxNSR3KkmtqnUqYXPURTnVIp6eFVUqEkXO/I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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lekfvRTtkigVkl1ljSimQyZJ6BbTgmypEBMVoqhkKdnK2iZr1qyR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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHk4VG8bFkKFIiWqH6lkqyQtVG7aSAiV0IJIElKibCVlCRVKtkihJC2y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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs4lAkbxtlaLSGnQmUrq0KKbSkmdU+bU4xKKOUYskokKZJcRaGooXwO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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs81IkCxZVHcodIIkI20XqUmIS0ZyrW8255JEWJPEoRvUhkQuQZlaK2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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lWkfxmnilSTjUIqmFCEkayq58NornWQvJSWRiGRkyZJ0apBTUkmR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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3cg1W8bxk9ClEQDJe0im6Z5pUippEFFoTSULYmXhCREGSXJz0oZIXtn
b+LYW0jO+R4jpIzW+/TX+eec5zzPfd/XdX3uzVesTl9jo9FohototH+fyRaZ
EGT1gL7jjVNBEAsHPtqfbnrvj2bLgFG5LRTOVxxeucq/GHx5J8UM11HQXVZ3
omaoFuc4jwhaSlE4sMXqg3qMH8rLP0UMbqKw+lPI0UO8Vagwvr7vkTgFU62X
zxavpYNW9Sfh+F4Kr765FQ786kTdvlC2TIkvsFu99LrUh0LETMwH3LYh51eo
L2ML6oC6ZtC3QpERQNb3+++pWiQF90XclGQi06xMoHhjD36ENnV6fGfB41e6
o5JWK2jJBdWB+1nQ/6nhNx/VCa3I04+MaBQiJRlCzs41MOf69lJkmAnZp70a
t+PLIbD+yUb9JgrFXfq3nf4rwWSC3Gf1SxT4XoZuMtj1DqUJtQOfvzExNp79
fDWjE1nWM4kxn5mwE6pvy9FtwiVW7/NQ3VEcuJz7fenVYhTwGxdralBImavn
28PXBwyLKHyQHYXr+Z9rIvKtQHO+M/Sd1Ge9WuFjv65K7Bbdez/QmQWu3qa3
fPLNqEgcFei8TkGyoK0+OLoTP0QGOhNuMVA2FduWsKQXs3OGXSMHKGxmT1Mw
a+nGc+ZOu9UGLOx3W3na8W0KnvivsDd/SGGu50nehxOt+LFqIrmnjtznqoWC
qG0cznCk/rDbTvrVm5M+z5GO9RJvx89xUvDZ+2Ngq3Qf7sr7S9+SYGDTRgXb
xTMJCNnZnfmG9CtrzZ1+pfEeOC7/scsvkPzfrP2T+oxaLE47zy0WQM77Uk87
bREMkQjzV/vI+UMMayrFtws1IYaR9icpZARfGHsp1wyBFoV4u2gmtlhyFnRt
pqPjeeYU1womYgtUL71hL4FP+J1eeSYTr9mS8oZ2d8Jj3Yz9cy8KZya+iKYY
dGJu8l105e5RlERtP7PjXAssYt9wnL3DRMp73cq58GJUzGrEitlRcN+QI/j7
dSNmlltXa/zrt6mcx9mHWRgp0myLUKIQ2KBaLRzUAwEtw8/sVqRe+9PX+R9I
QuBG8zctW8l7lpWZ/ApIQ9H/unrz1lJgTz85MWxQCpcB/8bIKCaOa7msu3gq
B93cvtd2yFKg1+5X0V6oR+1grCvNgImTe24dFR/vwB+vIfVoQQq1U44G32g9
WOmX6JayiQnXtZOtVn25cA/8zpF7lsLxj4l/7Ml7/qi8kXcrYSDSRSJZr7MZ
A/0PbboHWAheH3m97GwpnjN2vtYnenwXVSgZ79+McnXfq5cyKfC8EorhN+2A
/LfstmeBI3C1Eq5ZNeEMvYLYDZr/3iOjKlN6uhgxbCOvuJwpVFv4lvxdVI+M
B/R+uVIGOqttR4tOVMI2dHnB3hdMRIZzLndzS4bp9FChLnl/iNG6X5UW2ShI
LAu4soiCOV+TVphTNobGLb4qrqJwNDkzSCinA90Bo/ypHKMwv6HMoX21EU2u
7NNykhRkFSKNbimX4KDeah8TLQqWxwYfH2vpwtQvjvX9kiz0K95Js2BloHan
obi4IYWNkSt4FDZ0odVA3SkpZBS/hne/a27sxtjRI1PaZqPgGTygatZaA3v1
Pc2BliyMeWwIbVxaBemm8TzzJCaehv3q1rkZh9LmCt55efLe2C6VndNE/1Kf
nPpJf2pNv+f2SnbhZ8UBw89kHhq4jE+tZLYgwe6nDccLFoT8L7Kvrs+Ap7C7
+w8hCr3xrz3rjRrhayojX3+Q9OeaprnO3ggciLkdKr6EAlfpDcftzR8xP7Rm
ICyCBfXGFXmtni1wMZhw+bydgZCfu+4uN65AwpX/6M3d5Dz+D3pflxehwd0p
oPUyBf1XwTwHMgrgET4TL0vmhVZvIHL/SA0+XbOQcWCycKj1o60QXztsmaOL
BxjEnyQZwRV6CXiQv9duGekvTclBVk49HBfpJuY1xJ+ZKmutuceaILNhKleC
zsDMk5t5qbP1EIzkX957iELM3R2xe/h6ofy/RL4NEQz8CP/S1H2tA6m08GOP
P7EQEqLeGlhWi/RDHCZqxO+KTzxIfKrzEa5XtEqb7Fl4FqWYOjVWh4ZHK64s
lFNQ3iGoE/+jApy0+mWqT5gIs0heVxnSCpkzpl3WXyjEHRoTalbsxEiL8d4/
3cMoXprFu6S+APfSRMdS95P720rN5X7yQE+3Q6DKZgpvGWMJPHV0bDPc/Z7z
KoULtJesAJMWSJ08IrZFj3z/Lv23jvUrLD/24vKH9RTGhjPlxFLoSDzRY3us
kfgPTdV1n04T2OTifFxsyfdze9MM91jCM2BFzTfiv66l5txVNoX4lTG53YfU
o077fbxgcRN4ldbFaI+MYPbgnqu0ui78YreyXtXOhHW1ToXR5WYU/D1Ik+sn
eXFqg8llr0Q4nJsLuUn0P7PaNclmeycWjtosKdZiwV201EjHsQX829+1PpRh
4Un7SW67TDoOVBfNZ+8g/duiQXERvUt6C+mpWTIwoHjTkb+zGoO5yftHqihc
PBzR7CXdj4UPaLk4MwIBZmKmQWon+iXoo76XmTDeprY6SiEWT3a8/RRA6iXp
M22eztaCgzVK+bwXRjA3+GfJ1OFGnFbc6bqsioVJce3X3bNFyDrleZ1Xk+jr
8ctxy8h2rM/8fOiJFwNiD1TSzWbKIT/kkltRyURW+AN7qf9lQiAuf/7pBnKf
kBu83+NbMLT7/EZhCyZUTxhvu6pbhSfjplL/cbEgbkR1mHwowX8dGl3oomCU
+u5XaXcrnGiV3GaNDIhXV4qKKbaALS7IRYTORGDFtjUrDpfjYzqbeT4X6c/x
Tq7seE1Ivrm4XIj4W3hneYhfaS0EN9Kb+PvIfXrf+nyT6YfVg+yHp+8PwytR
f/Gp7i64rBp+qbhrFNVnGxcvOtGGq8Es/d/RXxCZyyfCEdCMiCN7z+qys2C8
+5WC0Z588Hx7cXufIwVjaxnu0eEucCmVDlN7GNg/vTBx4040bikWlnj/ZkIr
8Lb2GbE6LPJem198ivh7oeJzvSuZaBi5PMFO/KJQ5NElAYcu+F6YELKIY0Ig
897AhQMdoFU4RmX9IPMVpA+GTzJ+BSsH+YqR+TDj778fUwf6uN6K5NtM5PCU
8e7S68TKva/7pW6zYMfpXnknrw9SilcvyG1lIUVsBe+QcCuGjHqCv4iNYtPh
pkcqgmFwKW/t+kt4S9PwVInwV5KPWQ2beKyYGGBfpXlHpx6ybDdMfb6O4HP0
0ogZ+XfY1WXGnT7JhP+u66F6WuUQmfCYWCA88P5GTnBiUyv2WupOd+mTfH4k
etEorQMb1WKO+Wiz4CVv/tpGpx0OVU9f3MkfhqflHwIh7QgKWWnOmchCZLna
dh3hRDCe2pZ5Ex457K121Dm3BRP7T6lLVZP6BHzalm7XhB22nPKO75jw4P98
7dy9Emi9bTKcEKCgY3yNdj2/HdftTZTTmURPg++DQ9uIPrS/hJfOM3BE8USS
GlclZE9z8B9/S+HHnf+C5Uh+qvyZMuB2GwOfxhqexFQ6Vklxv1zjOIK4yKd1
hoWpoOuqmK4m/vlIvyhn9ngBCpoDvAuIPoxjmN1XlQug3XKs9nUR0XOg9Psp
q3hUxR7hapemEDUh3+uv1Qaj8OJX2oSnhvtvyrl11uBR1mmpeikGzpdFpJt/
KoK6ZHdSvDnhjXebP2aLFiFGOuZl9SsmHp9/fSVBvh3FqwN3705mQrnihemJ
yQZMhHqXB+uykFRr9cniRy2qN5SaSVhSKJcfpSaN6PDVPBJu4s1C+d8c+wf+
qdi05xB3rjoFLf6rHlYRhJdyBvmT/8dEgflwmrtpLba/9jNpCGVi0qk6yNQu
FeFUgGE+4bfD1ravvmvUoJbnaNuxZOJ/afHn5Kl72FcaZuVE9OSaKvFhXDwZ
O9Zb2++WobC/p7pLTSsGruJGh8XXED/au45j80wFUrySFZOIn83djdMTJf26
Yu9aFGpNwWuovOCKH+GF8MfdoaSeIaH7uL4pFOK9ia7y7SDSzxbpwofRSfAv
LV5vS/Lo3H792zfutSNg33RF+jcGuAacZ1fJFUD96eGQqE6iZxOuthAyH7ck
zqgkEt5IEaRZ3xeowvE9ayReNFNYxKCViC8qwZOzauk8DCZ07NkEo941oJTt
t96GHBb8Vk/bPPrQhPU/NpnUbCbnn/XSWrS/CzKqShe040ZwbNsum/cCTXg8
rJgblMzA0KcOb03PGriKms7V/2LAznGz3NZ7TeBy5CyLs2NhQJLr91/uaDyf
C/mcJEL2l59LDjdNF8P/67OVodNM4JYwf5xPN8r7I0wysxkkn1WMTQIfQMzB
nWok9aWy3mbuWmjGYWm7IdUW0i/3wHeTG2txO3nolVYUqe9UiJFpZgcO7ou9
uVGOghSHceA8qwXnRfS20v+yUC2f+VDrbjXqe5XrvjqTeRMTkza1KMJxXu1r
jj7k90d7Nu55XYc927hUHrOxkFhzavFRpwrs+9PENLGg4KxCN/7UXAn7I6cv
pZJ8mvgj56y8uBpBFo8rP3KwsP3vT2vp6C70bjE+a/WMgT9JkZZrbdpg9syi
oegNC73ihfUh8a1YF+2r9NN9BKEJvPe++dHBobz20VpRFuTDrjzJ4S/ETk7j
HplrFIQOdv7OWpeD7Yrfk13IvtQr8oMj/XA17m4yNBslPO1cd01IVrUYx2y7
D0kdodApcpU3paIGZa6Zy58GMMEUqWyTMs9D2JrHWTfIvNHWzff2rrdBu5+U
pw6Zrzr95+xxynX4IySZzJHHxJ9mtxtCNu0wLc7kOPR0FDTRO7E0735c//vi
pco48Y81en3pZF+U2Rkj+VmahcH+0BKVvDI0cM5OexNedWgZ0FjYX4BiXdEy
i4NMhITF9B2SrUXp+IW8IsKLJis3DXo5tKC2c6V44H8sxLl8KBzWzoPL5nCv
qWBSf3O66/qVrVig5ag+GKKQI3htijXUAGmNFOPl58j/u8mNWo43Yd7ezVRf
fhTnI4z6zK0b0BhFF6GnM+Bh5hsj/4LsBwPXL64JYGE61TzMjr0LSSfeWAkd
YsCdj8tCwIkO3pDG4XJDwleXq3nURfOhRonXqdcx0f/lffJ8Sht8nxb58bVS
SHwQuHPnSC2k+3uWSRN/3BlwxnNp4geonr38m82dQn3gKi5p2zZo6CerH1jK
go6SPs/gkngoOwwnUaTev9o9MzXZW/AwV7j63m6yH784tPRLqRv6n4e8qCD6
rXt0ckLcvAUZP3d7qxJeqb5sM7OIXg9/2Mxkfyf7ZJ/tynzpbCTcj1oWRvLl
5MRQlNyqfng9GXo8aziKmDjO0vQvZbCtjCvZfJ/wdvpamV86XZizNjpWd4wF
B3bLJHnZajwryRNTGmLi1BGtYVu3GhR/cvM7R/JPVjBz4tyDBtx6u0T7eAzh
k0VjCkp3P0K5ZONfZzJvm5xqJNv9asBucOuQtxcTBwY+eYuZpUCRv6XpEQ+F
bTxqbiUdLTiuwnlG7R/vyvbsuz5NR7+xHq9AIxNvuc8dzM2owZFaAdfXZB79
zmXc5iR+1X7P3JdbiwnfMdcl/YuawWOZJcXyJ/m6ONrrYnk05pRVdqaQfcfr
jEnnDuEyaMYVLFfpJ7yQ71GQkdyDmhPaWSf2MdA7fuFKuynZ5xu0R1cnkPnn
0uO+GdgBl2jrGvqiEXQoVblcTezD5DWDzfoa5L3Rjh7D5UUolf3fjb8kj/mf
BL2LaOuB3dHt/nuFR7B+2YY17Kwm1LIHcapeJzzgtWmDgUYocj4vulVD+qlD
5TbIReeh8+QRmTFdwttqGVkGkQXY1rrwMbGKCbuecQnPk3nY0sp7nYPkdZhE
ZMhJtTqwL+03r6AYyIhVDbtxoA7Stp0+W0h9ldlnJ/WMu3Gr13P5xxAWPDVf
J+YTfuMzjz3+nfDj6qFs28JnTVhZqFTzY3AEXOLfOc7crcT9TX02n5+T+Uhd
+TIhKBGZhzSkR1dTmEx3W2g+14gJFZZ5OfGznHJzz69HG3DaQa5hUoeCbZ/8
he+5dbAedDzl809/m+wCy/JyYS1sFryJ5LlVBTNfQqMZ2m1Sju3/eFMxgadk
OgOJI+zSvnNEz1XtCiKRxZgw2BpqlkV4mMd5/vlMC3ryMjYI5LHQnq6srTnd
jFcZ4h77VhL90Gff8h9vRb+7/pdZwtNcaZEBt/wKobzU3O6Jyr/6Zfu8tO3A
gEfRteaPTDjk7zmtOlmA8z4Pxwf5CA+v3J1aNp4CZ5sLc2/IvrW6lFtzsKME
yaamWU8Jn5VrXkyzcm0E89BRzcxqsj/JGvBH/0yG/puRF+IrKKh+96w/O9GB
/ju3hiVOs0hd6222bCmAA8+K4w0k73op4Z6nSh/BuZAfsVmFhWJ7wSk++/dY
rxp7O4H4Y/NNN9NlBd0Q0jJb90//i9826+3gIPmiu/bzDsLfbWxNY2rk/vwX
4tR1TRnY8kCY7yetE+1p15kLT4mfcbR+tSpIhl7hpQP55L7GE6Ny6UpVEFqi
s0pBg9x/m7DnqtxGcFWmhZmdIPukseFWp5E0LJu/03TFmPTL9k3U3189iHG+
8G4r2Tc44sNNG9WqoXB+tvJ+NAWOZaL3C3dVYUOGd8D8FsJbj+WULkbXIuz+
N3fhkxQWrMYSZfwrEbb5iH/BLOHrrzOCC30VmHDaznDoIPkZX+oh+qYIckqV
DhzEj4zrp+cNK57DOap9m+Nacn/HJXJVPdWQ53199pIk2W9DGl+6nqlC9rr5
juXHmDix7JqrfHkH2JcXv15bT8HptJ5A8Ewz0gxDHK/sYiJm/Q79R7XVSE95
zjlL9sGxfqfDq34Xwn7tNf+JbNIvqd1aNNZzlM3Zh3YIUzgmMLlZ4WA+FjED
B52JX/Vt3CLiON6IIf4RUXmiP2XuT3VbGtpx/pvo7XQ94kchVkcbN5cid4Zt
nW4+BTuFmi9VPk3I3idveP/RF4RJzbu4SZRi5G33/z73ED7+O+smOFOPiAyL
6FgZJsrfeUyVtHfAeq/APpltY1hwWSFdH1gHTs3bvlvtKez4U70zcWkr/PdP
mcrxEf3ySBnfN67BxMu/qroeTNBZ3lytR18g8HqkE2sXhf8DyUICdA==
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41Ikax8llpctGyiU1JWlLLm2DOPJVayKzsaEolXtRp4tiDtKKk+hi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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81IsCxeVKeo2hUCq80Yqu3etOXjnetUylNEoSaREVCU+SpCypJsvD
fUkJ1y0kWibh+ljHMBiFGNOMJWbGLL8WNaLFkvu8P87n/HX++X7OOcb+YXsD
VVVUVKLn9X/flBRg6vu8G1zWH9ljy2WgChK7f/5lEHPDF6Y5IyNw9VvblzV0
D3oHnI6vqyeQ4hfMuNrSgidfPpmVWcix/MSwyQbNFtB++ea/UlWBmSjak6ap
QRzTbQ+oSBFBZXbsj30mrTDJLdSFqQLq+zjmVmVCPItoM5oMl0Ljz8D4KQ0u
8mgnNUIyZPjxo2861X4Qtdp11a/TJPC+eafUfPsteDY4PVsrIXCG4nOu24YP
t6prQXl8KURWhpm+DY0YYnk6XdmmAF0nodHYmoWomTWBxjoK8LJkC9MieyDX
Gp/6PDaKKEdaiy6nA7GSqenrHBl+CxlPTlAKcCPuwUXN7FEwtfYMWFMLUSp4
F/blPgFq+sjzvg0CCDVv6T75hwRZT2w6S6k85Aw1ZTMYUpgvKNZzjBHCIl8j
2jhHjM/cj5ZZ69pwdGWMumhYjoEEQ6PK/F5IGx94nU6Vwm/s/M3dzzrg/LUh
SFtXjkfiNayQxi6UudTd3WcoB3k9u2Tb61cocYt5S5ZKcWiMnhfqLcTwxhn2
I6UYdgSjaGMeHz7rFvSY10nQ4hf6q+VaAa44p5z3qxQjxlut05TFgyx+Z0LC
76NwNIcjz/oxhNKSb/ZuBAoYZrX3KA8xlcp95H+WALu1NuKmuBcGH6jpDoEy
FLR7l7Gce+Fn+uJg4GIpHO1MOrboPkfVcd3IGzQCzX+Xj/pJepHhkXqBOSXF
pFq+t567ADNaCXvnBqWglHlfvZ+Zh1nbx5L9dQS6VdP2H100CGKZaUbJdjFa
rc4ZGVx/DQ+z6e31d6SoJpWvv+whhMtwpHXvRzEyMl2v115swImY9sy2Iwqw
ShdvJdUWwT+py35FCYFUiV2FH48Dj1eLrSpEcqg56uRnBXHwm20aO79Jjpi7
GbSCtC7YrY5XO6klg8pEWvexmjOIPJ3Ff7viLcxE/eS52CEkS3aG+g+O4JVH
8ptqChPUW+Gh1w4T8PRL6UzN5WOoOrtQdVKMl+8qRE7mXDiSHhm8yZaBsGiP
bl/JR/TlspIql1E0h049O/SdCwPVic2aL2VgXaDyjNQuIjZlIH49+S1i6NJx
n+9CuK9yT7ruIQY9xiu79WguGJeoyeMDBGIOvf9yQ6cfDj37ovQDxdAWqe/S
aepHRoJP4edOEcwu0x3e7W/F/cH0OBulHKTJ4uRlRV3QMJ8sWBUrhXp016CX
BR8T42+qN8/zLyCTSYm2bERkqjYHPZWDzsN0oTcDPhubj/nMEYhc2GeZEy7A
tmMTKlaxYpyk3yIfielBxfHHW2hLpeAwIx8sJFpwbHZPoJlMDumRIP2u9Jew
e9g8Z31NjgBPI9En4gWCnK0d8pLkMKi/tPIGuPhorHBhPZSh4rbCeCyHg/er
r5B2B8jxivx1yUxHLVyXfqjfUqWAxnLSjrUxL3DnNvdUbpIMWx9+3uFp34aI
1k00PYkM3n8lhfLqurDsc+FOlWQp/H9NrCeZ8WBTN7TYab6f1XtNljh950Bk
uMKZsUeB4rnO4J17mkDawPRlGypg4hhMuSYVwMpd4lIeLsZ0aej685TXyOC3
CSrNJIhYID/gVtSPiIzgOvBGEeDYE8ZV9mMqim3U7jCK8mhSw7dHL2EjDv1y
mC3DOoF/dG7CPdyeVD6hNBDQlFDz3Kx6MMEUhlbO76MPA7uC21tA9y1a8hoK
GD2NU68on//P59HDa9REqK5YKP+e1onM0V2mG9lSuI645HSa90C6xvaN13xe
216hdjeMhzMfog63kEdBci9mvF/ARL7uWYvBvQT0U5xXpFzgwUdp7qXXMf8H
lLDfVzqw8eax8m+6mxRITGb4bFHth4HmwU80IylmSWWbAjuZ8LK1dZ/eTYCc
c66Z5M1HTcDmzUJLKXyLQ4Ioec1Y1n8p6cR/Ffi58suy0NouHPzp3CuFUgZS
8KTJ/UM9kNSk7+y1kEF49k9m4BYhtJlTO5amiZHk+iMwamYQjP8IrtYQI/ir
nGXqW8gHbce/swPmeYY5yMVxyjpMR1lpHK1ToGD8wdZiBw7uL+c9Dx+QI9vW
qPFFKh+ms6ttUq5IcGDxor8cxHcxm26lncYisO6dRqwhrRn/NDzqyHVTIHVF
8dKAzDa0Whppe3rKscYj85To8DBaGzkhevbDOMXcNqk1/hThGbkuHy4SsLtz
t9rPrQu36I+1HDbI0RclruTbdkC9Xt+6b4cM8Q99f1L8qwY6eWpbJ3MVqKIv
ZOc1F8EyWZmofEaAoF463H/+BZz3CbVXXZZDmxrVMbGoGFUuceWUDAJzB7fW
dMbxkcogblPzR1FYX0zn+lbDlRJy3aVCgcK9Z46X5jRB8tF7IjVBAe3gbn/J
6Vro6Eu+NqcoEK9MjL1GLsPHEy76tvEE/genRccy
       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk81ekXNiaayVJZIimUpRpjnVDUU7Ykykg3S0m6JYUkGltRdmGkxVKJ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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHc8le0fxymhVEZSVpSnohSPtBQfoyFKVkSS0RSiVDwlkVEpSUTIloZK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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlGs41IsWxjUpRaSIUi6F9oxyShG1yzud7JIkx60eiSeXTcrEVoZ2kQop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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwV1Hk01QkbB3ChIaVsWarJDSHTIqPd9OUlRaWmcCwxKuQiJCJxbU1htKhM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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lekbRpImSiohEkqULDMqWeZOyVJKI4pSI8leI0ujUnFVyPKbQhIR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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lH8bxVWU7EKLPUUoNYhK6khlK3tKi5KIihZR/SSpiJDSIoRkSSRF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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk4lIsXx7UQrkqSylJIRZsK3dLyzZJwJWVJcRPJNolKbrLkV4TiomtL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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGk8lQkDxY2spdS8DUOMyhJRXGL0oqNeW8iQ6rYYe1knphTRFKJMC0pK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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkfRiqDNvmGiJAla0iWpDuh0ZcSSUMRhsJEJVmylyVTTNKYHBGq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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHlcjO0bxYcWRWlfKSQt2kmWtzpJZHsjEiIVSrRYopBXGyJR0h6tIpSS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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs8lAkXxwcRFeKtrIqlrFQiklvys+liK80mzYoucilFaT9U1Btl1U6l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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk3k4lIsCxqdpc5SjbLnl6KjDnYOOOZZouV5LSqWypSmTdG+Lji3STdFi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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk41ekbxmlMe9qkmGps2VKmEdlvkWXsIUoqmnCSvdLQyVgqjaQsFTFZ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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4le0fp22EVyRkRCTKqOzyyYikIZRCSKQkoTS0UFSyEqXISwMlQlaH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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHk81AkfliO8pdBhVSK8WPdatWTrKb3pcjVS1s5utqW1sWgTOapxW+Ql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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHtYzIkexhsqbGiUiujCpqPVslq1ieOd2lK6UPIQORk5lDDUJjXoxhKK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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk4lekfxk00uZSUVJrBpChSmCRmLDcVWdLIXgojTkV2YhSpjK0OqsPI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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8Ve8fR2iQtqzMCqGsaPFGKqmUkRTZyipFJKkolUSkKCOVyigiZG8R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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlWs81Ikax5FOpCyOppUiUo4G2crIbus3WWFIF2sdyrpt2Sgqd9WJnC0r
PlJLMa5tyiXWdeSW5D4oGdMYbC7bJP9LkpKSsv998XyeN8+L5/L7fR893xPO
RxTk5OQimfgnJ+UbpZr+vxKuHeN6u98Q2LPtp+D1T4Yxq7woZx1OQyoKefag
Xgivccvc2+MkJmqI70I2CdFsfmxf2DSJRXN340McCfK6H5Sz1GmspV9kFE4N
ItOZlcmPoKGmLvX5Jawfee5qH6/MUzA2OausGNaEjFCX1pjdJNYvH43/PigH
svBy2VgIgeSvDj233CeCYt15vjZNYezb4OmCqps4xdMalf+VQMF1WXGORieO
G7qtln0icblVUmshEcN41Ybe3jCmXrhRKz1gCNvo7yTaq1/i5K6I3/pzevCF
5aQwWpFCcpWlzJpohULk3frzMhLGKDDsriiGveD+gmYZgbMaL5xkip34td6x
Bk9J9PzmoCSvK0KdULqBlU5hu5L8Jm5tN6az5p+8dKWwp9hLj7VagPUsj7v3
nxE4GX8uKvyJBI2WXxXoVtFoaM5znM59gCk7gx22ViQMTpwW7LbogEtRj3Nk
F4nMe1ezDff0Y1nwc0VLWxqKmQpxT26IEXRulY7mDIX9w78rCKXN6K39M6S1
koRpLMfATbcNN0c3/NRSTyLIySk1OikJY4W+w2ftCMy/yDYVrpDiP9VLtFrE
NOS8Z+f6HYZw8sstnPYBGpk7rq1Vyu1CgFLyRM4WCmX8jV7sYAGShppCYweZ
/Wr96BWf0o7WpLU+5UISHmdKLG7d60FSkP6acjaFmc+lGy3bO/B2ROtYwyCJ
ecO7Z5+lPEaTu/dwVzaFFl7dL8ZOvWh2sK9ecoKCG3uAYHO7cEhJOU3FgLm/
X4f0UkINaMHDuxVLSHSqfIrP/dyHmHGPj+ZdFLwTAhUa3K7C5sLW/P2uBOz6
t+m7BophO8NqEU1SWPF6KetDYB8E5oaxOhEU2gfkP1j8+RQhyawE3jUabmlH
3t2/3I4iTurDmvck3nITV+f0tODnNTrFF6tIzIasGdffKcbpVcoB5TY0DoX5
xJdXDyJtwWvR34TGfMDHjA/GveBe9DseY0iBExj1xQ7lYZBFd4jWlS/xycd+
X4C3BFs1qkunDGn4ZbOdrUIeY6Am/YlpIAXuM71hQW49OgQFNf+1JlFcZ3j2
Tnwvvgxjn3fIoSB7LfKZMBLhqEZE8uBSGvszrdmBnRVQaBza9VZK4ONKUpIf
LcXtkhNBdAeNMbOsuVrPy1huJh2O5RGosclWHNXoQYi+kq6tHwX1jsU890si
JPLf9V/gU2iqVK0/0teIxpS01EoeiaIIy12neGJoJC0aBXxg7v1uNrTCoQzS
DcG65+sIsGzy6/Z6DMA57s3kmkYarccidlrzhTC15vNi5klwTeS9JbNihKSX
rrfj0vB9xEkI/98QRDf95LRcGT5sNSi09O1FUzK1ObqUwps4hai+kUEczfvL
8wOPhvjVpfFym3qovdrvOmNGwv/6OtHQ40G8VxyJtYqjkVJdlqLZ242F+pT7
jowe+ZxUlaHGZjxUOZNXGEnCk331mv3WLliFcz0TG0lMXrvBWfOuC5G2capm
JhTsS++lRq3Mw8JrtldWIoExkx+s2DPdmBm6/eLqSQomvKp9YQtdGPJteeqk
zcz/9tymSk0RPHYquj9PpJAY77ik+rMEPS4G88b/8OqwSOeObhFGqvQV2koI
qJ267phv1oSYa90HhGEkfrglq6htE8ORVGlvSaBhNvqvgpLGfMyYlAVq8QnY
j2Tph7pUgaM9ESxgeDCZs0fv59O9YIvldhhdZPzcePmMrWoJMiVRIQmVBI7u
UaVui5j5Yid0G3ZS+Eu9Mi12/DEWP7kdmcxl9DRZqcOT5kFKK3u+TiAwsOuZ
v43VAMbmNt9ce5nG++tXxd6/N8I46N/jm81JyOXpT3hE3oDY6+uYwwxPHzRX
cZZckSKntMXrhD+N6WjTEcPt92BmUHhuiyXD3xRbi1dF3VCJ5v04yvBw/zc6
/APJfZgLyvSazqDQaXrEZTa8HLXPlx9kdRJQsisXvQxtw50/th5cWsvo22Eh
I1K1H6o73f1ZjH/TNpbc2svqQ/H0pdDty5j+QleyP+YKIW8bJ+SPkmga9VsQ
aoQgi6Odzjch0Pnwlef6uEJMlzTPLSslsJvNEbiI+hDa+87aLplCaHF2Qdq6
apD59W2bpwh0pZvrvGIz/hu5HemfTqPo+JUEY2EfJk7WX8pm/ktZlo9FV1EV
1KwDpngUAc7qDL3vjYXgLnW9uY3Ri9yuTxeiCs9DcnHdsN3XBDQPHlUZc2qH
h92yYE11Ckrs9PCHTW1QnD6gbsXw/33oXJJzWQXiatNvGDQSmGgQZO8OG4Ds
m9LXPG0aXOcEo2CqCI9eGJ3yKiAwbapBK/i2IrdG1lDfREJtqvjbw3sb8Adp
+WiFIeOn7mXWLKU0RHINeq08CfwN0NfTWg==
       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41IsexifjdihuipTtNHU6LZRDISZ5J0tESiZaRXErXdGJulK2NtVN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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4lOkbRksKsynS2kqWTg6VU47t3QEVQsoxh3LqZFOxbVGRQglhpX5D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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk4VW0bxcncIEmlUqZCSAhRWEjSICISklSSuUkTOqTyGiJJhJIiKlKZ
MsuY8ZhnJdPe52hSKhLf8/11rn0dtr3vZ631WzdJR0/zE/M4ODjsOTk4/v/5
5eXCf+99q+GvkulotZWGOWeefm54A35a8eYujmZBaipdlk+9FAvf8U8o3aTx
M1Pg7cK0LqSXFqm5erDgtc/L7dRsOzS26iX+caHgJJPSnDLCxNnuwbKbriys
/Zr5uiu2BQfc1c0oJTZo/T0e9b6d+CY99saKfN90/qX6e4MOHHexljIUodGn
wjaRqutHGvcJ6/iiMUQMarn99M/EjR9vc4ztaag7iRYIbmvCtMnSWaNgGox5
VQdKOm5i9VQWQ0ucxjq98c74o29QmDxryDdDwWE2M91Otw2rfvAqNbuPgpL4
LnXTqBkKKq2LuGzI9UpWmlFaFlK4F9lNLaZxrVg+PGrpG0goRmw4uYCGiERE
4mKNXkiJKkwbx43BqzwssMujGsafbu1onBtDooNc9ODWdjhH75PZETSGLHMe
9pRjFeL/3PnAaByDtZmJ2Ik7byCj8oPlt5fGt1H/2mdtKXDcwHdrUosGR7hh
5iaLe9iTrOrzcQ2N/0Kmj/nubUXmlvRw21QWUndG8b3iyIO8kPwzR2Ua3kZW
4sz5tagwypSoe0zB7hTzWPFMFS5/Ugu7sYmCUefhZgtBJsSOr6qyC6JxfJQx
lBfYhixJQ1bC2BgkDqVefLW2FY0uRte9B1lwHfj6U30HE328x4Jc9VgI1rsW
8FmvDyzfO3urTrDx697Judz1rag8tnTjju8UIk7ErWloT4QE81jPlAqNPznN
V45ndMCvOTk4m28UEWFXlpz2ykf+pp9manspFF2ts9Y9+x7CNwv1NjbQ8HuY
8HhcoAyOwuO2whk0Yi7YaHG9zsfnWCejxHU0HFQlHb/+qAenjuBj5guiRyX3
VPFLDRApzjwa10SjxjTicL5aJXjbZtRdyTzvy6abJp7pgdyC63ZlS2jcXfNr
8S6PVnw7+SRyOIeF8bdiXeeKiL6yHZb8smDDJPyI0gGNN+jiaDPI7qZw/LCG
mrRKA07Jiew1PUwjK3q10C75Rsx7a3970pXGZMXAvcnVA9ArbPdqGqWheMfU
h9VVgUr+0pD2VzQSUrQeiixoQ4WkuuErWTYcO6MCvI2rIZ29z4Ujm0Kq3cs4
1cmXULHbrVOlQCOw1utvWnon5N1qywP2jWLv3rzz/Ps74OMo4iPoPAYl5SVT
3xj9SNl3Z1cb5zj6nh4dXl5VAEr8lPs5Wxp2zoFG0gtaYZhqKcxHnu9FQlh5
TE0dRs3EjG6YUGCcCNA0layEalrpqVtXKBQnlXmJ5nQhWWV/tc80DQ/r/KHY
iRYoCnJyt8fQ0JvKtMr3ioCRnE+F/0YaRh6zJS0mbVi4SWmf1BwL6b/emG4I
aofaH/Hdy3QpMOcuG0a+r8Fn1mHTPGEWosvP5MravMeKmMGBcnkWLotsFOOU
yUBp7Q9HJvHPT6HkPXfE+7DLQ02/uHcYAZVeB+fF98KgwNb5Yh8b1Pn9f5WN
MhETYZy6lvg3cWLma0FWHBhjx3nbZGkEzRPWf7mxFobvYvY8cKLh9ayWeSeh
Av9NXTmZXUPB5O3AOaW3/Xi5L4Y9lEKD+WFOL3jmFawCX7ue2Ucj/m357+m2
dzC44uh004BGi8Wl7LntpVgXq7DvoimNorJdlg6yAwj2KD2a9oiG87Ply453
Z6HMS2CtLTfRm0xRscOvUvQMP99aJkGDW9HYqSeyE1NH+dcG1NCgdHy2fsrq
gvG42/pF4SMonbBRPKnWgVbtHqmZHhYclH0i3lysg5dW4furlsQvDw7xRGY1
I2tFr0dRNIXqpBfasuWd2DuhWrTRm4L13yDeXxdaIHTwU6SBKAuK553sO6o7
Ea34ZUduyRg+qhdreDk7QN/u7qSgFI3OL/udZta2oc1n5vurNBZezVMZC5Jv
wahPWD6ekvdJHas60V4CG8by8QPeJG/Y7gZt5PyF15zx/fmQQilHb4mndDx2
8/HyXiHzZyS66yqqPca90tXKX/hodKyP4K3Z1oIFCrnrSxsoSCyPGLxsnQYv
vwz2ajny86mvN/By+mD4BM8RF+Lf+yE81hst+uDfXfJX8w0Lv7nXNgS392Oz
9zVKrXwUC6+c0jApbUd8x7/ZfAc2RAQTZ6mmVjw7oDql/JCFb3eHmZpKaWiZ
+twfpU0joHb6Ef+8DljHW0rORRM9PbU8eOt2F1xaz836Z44hOqm8tSepFB9c
4z5Zm9FQHR492qnRCv2O3/4vSlkQ0Bw4Pp5cjj9RlSFLXlKQF+1X+X6/HPG7
TssJfiT5KUkXLbB5g1W5oftYRC9mumuPJ/W2o3h/hHmvCgsxBU9qdxu0gvsQ
Pfs7nYKi1LtU38p8XLxQtd6d+NFsg5ES81cufnmzArQ9acgkzi20H+yE8/vL
AYXtowjaYFq1SbAB3nyTT585sJCZvt6y5vQA9nY9H2JMj6F9tY+WhH8Rij18
U26YE37pFFUdVKrCGYlIvzskb2vM62OjszsRqu8rJ7ZrHLdcF8nJ3G+Hn5p2
eethCsFm40p+Z7rhuNRmkw15/r1BrGVPl6ZDYnfXn4LfFDIXxr0cOt+L2poF
Z26GsSBkttkxwq0RmqseGuywoHGOsy8oL6EZoUtWyPiR8wowUAvZ1PweMRbc
0RsMKOTLWcuek2Zi9/to2xJVGk+E+AscpGrgEBDFXSVEeNTj0/6pOAtvbyZt
q11PI0rr5vw75h2IOXLrv227h1ERraPA7V6OJfonrFk7adSu2MiR+6cbL9hZ
Ad2rx+G+QLa3X7AL67yW56mrsiGxUrBF4GkNbKpHrYXLKHxKd962IqMHtusa
5fGEBVNhf65/jT34/c1e3phFQ0Ir/Z7Z0ocodbsmqkT057VtvFg8rAg7mBF5
2////tU1Y0JSJZjnf7/RNYD4oWd/v6VQLn4foKO8iN65+KKCXFp7cErJKkBK
ZwReu65wTI8ysfzeu7r561iweMzBjBJqwV+pE1ovl7Lwpbl+PW3bAdbzoTgv
hREoZm6+395WD0eFkH8Wi1hI0Uofv8bfDn7G4MP+pWyESs0smp9YAu/w41Ye
xC9WRQmPXIyZEHzEfe5RLQXlX9wbbkuk43ZK6QIuwjOORJX5AuKSeC7NFzwt
Sfz3aFhBL5iJm98fb/DXHoXzFmO2SW49UjoahDJDKZg9rXgn6F+G6jeii+dz
0Zjv5nzDO6Iam8VzQpfRJK9N4kxOTbWAa+nroxKZFOR2OZwrrrmN4M2JrDGS
Z31WSoZ8A93YujNg+b8awq8DhclCj7uhaZOw68UAG8wA+6BrPc1ImripJk70
bqwx01EwmQ+7G3Oip91ofHQTlMnKZ2LYRT7QdzuF+SP3e2wftGK6iXt5sBUF
beU5pXCn9/DurfwjHUJhY5tviuL7LtTHa1RZVlIQunwr91NiMpwDBKqekbzX
OyNoW70mHiVWbxs95Ime7lYKCZwoxf2v3ysUHlBoM+p+2Hi7EOaj1VuXaBIe
TvBqB9RW4b2tW//+t0SfNZeEtlvVIdHMkDGcQqHFNWXldiPCy6zPUZ5+LOg5
LW5eIP8GCjraD+eR339Sq+txUrMdBrcMU3oW0eD3cuHK4eyE9e29XeuvssHR
X92o84/4mbNHQWclC7R4rqroyk44tvqGf4xjwdjvleFdRg20L8ms8B2isQ/P
Xe2KetC4NfSWQSvJx53zj9tPPEY9L4eWJLk/9eG+jW91IcLzagxjNWiwuMVL
KjrfI2WLVIwj0TOj98OPjxrJ8DvC+V8zD+kjh7X9rgW0QHmfurLrcRb2L/nj
Gfy5G8VNNaP0FhqXnvb3jhBeqJ7NYkwLEn52Dg1X2VRgxyv8y0yk4BO1JN6S
7z0YsldjLz4hPMv7c79Soh5Phxwb+ApJX4jmresPqkOQfXp0ahzh04H270sb
S/D55FYL5ScUKpbybJgebUfMycNhg0Rv38K1F7Iv5SLViuEdQPpNXmbuz9P0
IzQdy0rnmaWw6nfIjEltFkJPnN6ufIHGjWW5gQ4lbWjRDYq21GDho3DUIbXF
lbi4W1RBso9G0vzF7hn9+VBzNI/NIHqaaRL41vKtAQvVcjwbCG8qWi1nFGpe
4MWGksWp+jQMj4pVN/xIh6bIL/t0om8xoUsewSe7oHWd92lfO4XQB3+kmdeJ
PuOPZxSfpXEkQJzbXboHMsaxD67lsOHmmR/+few1pDKF2Akskv97OTL7LVvh
+GXXXyNBFvzsBulp/3ZUKRVmGqYRPnEs1H2LAtSHmb1QPUBjuu1Z7H8mSbix
XMt6mOiVca1gwS+LOHCzwx73C9Ao5Aczv6IBl3evXRk4PoYjs6EdMR+7cYV9
a6yGMQqmnrBnqWorFCdDyuMbWOCYHfKZM8hGzZG8+Zpkv/oltsljp3MNBJLE
lOLFKGySXdVZ51uPLrv5lS/2syCReufJu73ReMDFIbyZ7At9ylnf0VqOzq5G
+zA9GkIuO25b/I5BkubHWR0lGtZDDmoq/dmwvy6fe7eOQmFBGp8GVybWiZmE
hcrQsBfuY4h69OF+90pzqctj4DA+xu4xTMKtQcEODpLnEnaeVyV2N+HnhOXR
HrJPLWk8aNeTwIRz30qn6TqSt+D1U5hpB2N749qLhG/810UFecR7MBvZ+tPg
4RgcPt6Mu271CudqlP5eI/fzmdqvLnumA8dEtmy++mcY8ekznBx7mnFx8nd3
+V8K86YZK6MM+8E//8NStxdDKJwTkNIxDgSXQWBCKMlDC5aEbTzpv46xbdNn
52ikfs7jD5vIxqrz68cmCZ+Zd8sOJsXWYjYsenLZKwpK3oVVkfOYuBgRftZJ
gvA0svmQ2PwK8AbKUrr/KCSeubCN27IY56i8y42j5PrYKWnn0QxI2vCvNNxO
9Bi3Q/fSPcLf/foq744NQ+LRgd3O3c0oOfur0oHwWkh/tf7dCx3wllQ+98pi
FKXuMawcvhro/Vi8acUhCtet8j15N3bg9bLrhi9D2XD+wnPa37wKW48c4RGl
yHzp5sKEEXKe5TIcN1fTyIwzKBr3aARjlfFQPNl3Y6x+/7RLbYP1zuSZPl0a
fElhAv0NHTAuWHoKFAvtVmVHfJYwsSQydOdY0hjcf99bV7HtHTLthI4dIX3X
8aHQzqnTTGj/9XzQQ/rTbnpX5eITnaj998Eur2AIQfec7hm4VcBwz1f1q8HE
zwZ9D8JI3++7rZljqTcCPa1VTVfDMzBtO13bJ038VzUlocLfhPqeuetZ5Ly+
5WgM2N0dQE1J+E2pAhbMfjUMZhx9jYwxTbN9ZN+x8in5YFDSiJlzdRuUyT6/
cOyB9c/JfogWLrwqFzKKWxqhRvE8PXAa0XJJERwBx/Mi85vXrsOelaluTfrt
on/3GGGkf+0YsZczIf04dGfTC+5D5RB9LL3i+QGy36fZV/wUj0L9ltDXYopE
7yIGUrOl3VhxYsC8vWUML0xOfti9qA/h+p6fnCUpcHyTR0lgOf79/uDpfJnk
vfmnQ49/v4bzsdvfdQgPHJQG/3pZZKBXqjT0oBqNWz1Sr81vl0NmWfjlHF4a
Ioen10yUMTG6uGhkK8mX+PJVxl57quFnEfNocGIMr9+1Ghj0MrHp3dmPDaYs
XPRzWGC2vRyG/iMz8SQfOKR7G/e25GOtFc/IBMmvUlW2uEJfMgY4dp9kihGe
jqsLxx0MhpGCcaIP6SfY09m6eVcbdJe7JweWk/3i0gvmMOc1aHDR+umE30HJ
9388T8uBzK4/n9YeoxGpKrnai6sLk3n1jZEk7+xeTs7nKGnAxZPyhwLjKESZ
5y13l8xEXlGQncggBaODOu0vZztxYIvKmkh3wjv78y/thBzBk1viL0nmf9Fb
L8HrSDb6i2P7GSQ/rms3fWtc2AYt4cwik3LStxU0DENDK8DQDrGxInmQujJu
hQjjMRr3OHluWEFDaZ6yzkm9KmT+XXFldIBGhNuX/AKDNjzRfaOXXTCGqL8X
T7leqoP97EOBqh4KVTdEdzhLdOGO8xYdzcsUeFbKxUd6tOF107e+H84Uztg8
28KMH4DEJ8XGtq00xJIb0zwZjRA8eG53LZln4q/XT87450FpuvNZ9kUyb2fd
MCXrFIxaX68PJXlYam/l/M21FW6xWznPrmHjD/f9RZ4f8xHK6aUsr0ND5/LQ
XcdoJvgdM0UcCL+i6DOzTWoMVDs760eTebfeOOb0nG5Gsa7rw4AqCnqb9fWF
fELwukSoMW0V6S9sOeX1ps3I2KkWX/aW9INFdyIWTDTBUdDuRuAbGm8CbEZ7
9rTi8Tb6AiuB8NjEQ3rchexTEjnlL4m/hk2P2Tp21MHYOjcxlszTfONUy4Pn
rRARuvA9iNxfLLbbqS6oGxqRVqu3bqAx6JGoFLKgD+JXUrdtJ/lMRVwbpG9k
QXZtkkYp4WFRjYt+uPAbWGsGj3MR3k2cZOck7i1E2yUzQTVyvh2fAhV8pIqw
fHCjhfgk6QNuUZ+1axPwxEGOMUT66pMQuW9nXXrhaJFbU8Yag2PwiuCzTs24
d8eTP4X0kYcLe39+7S0D84q3agDZv/5b/rCp4XovAjU+W4TpsBG1xcPEb1sD
bHXjp5d0shD19ufZ4TVtMBLwPj75nEZOSGEUQ7UFz7ySeYbjRsA8vz9E0asd
9ltWm+pwk77Q5nXS+34HDhQXZSeXkvfbz6U5EvME8qfEvNRXEr+oS7tVpd9F
zP4xLiPSF0OXp34R9qxD6+ZAXk3ib8WqNNckwzowzZ+VHoigYMLdpbxlUztq
s78ymsh+3iZ7tnZdUhlUBefpzJD8cLa+wcjY04by4rWeG1axgQU+nDmx9Xi1
PHwZ52HCA9snkhERmXDL07xqZUr4L9BVtn6fF7oOljzTJfOs8Jfh6UmrQK8j
tWOQPF+OipqxcF8nWqP1bphGslB61qzLMy+A/P1liw6R85ZRXxp0/18lblme
tm60+f//G9axG62yMCF54/vUI+LXT4UbJ9d3QbC3es1sABu+CR/nOLjfIUvW
d1gsg+jvXoeHy3ADKNW4hdnOLMxdCzwROVyEB/5sSclSGv8DIxTv2A==
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81GsbxrUelVeiaZE3Q0nZjy0KV05lqCyRkjjVUC+pkDinslW2ciqv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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4lAsbxqWNRLZOklAZOXNVHJIibnzKaRuiQmkXOpQ20k5pQsun+WwV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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk81GsbxmmjhUo6DUn2FopSKS0XUkfIUhgvWVJpeUVCKKR4oxKVFlIO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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k8VG0bVklCe6kkeyKylLcouWyVNgml175GWRNRUVJUUoSEIgotlCX7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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHs4lIkat6VSqRRNKekikiPpyCCTX6Eh9pTjhKQ0uReSGjQbS7qQS+4h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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVWlQk4cWRUWlbFJwBJ6AWKk1CFqbUgoqh8WlVFHEDUUQUCKKCqKyiY4F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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8ldkfVqQ0irGlRrokmlJUkmh6kJBQ2bONZMlWWt2mSEmFomRncn+D
ZlKTi1xr3Ft2ui7XvkW2jqYyGVKq+Z354/28n/M557zvc57n+zzfo+J5wsZ7
oYiISBJ9/ntr//7sY19gA5aUK3Z7WhBwi3Wbeu5wsTn8zfrH2+g4omTRNCsT
0UW+edJqBJaROdpHDwlxpe+JPfcGQb14NFchqxpSmVf/bdlH0J76jcPhx+Mz
d3kSYy2BlNNG/lBgNpj7bOW81QmmXoh3K9YWIiKRuY23maBCpVFlW0Qj+iJj
7SNtCfLEQnvfpHDBaRkelN5JMKdyNca5JR86i/kXGJsIyjJvaaaxu2EsZ8o0
ZhNo2/d3LTfqRlGy2o8LigleRzvv3LOrHHHDb4u0dQnOrP41tPl5MySXBbao
WxPIluw+sSGhHUlmNofzAgkuLj8ymLidDeV9yfpbNhKsck2rVBsXgim3IKs0
gMBcPYnR8awV/SHXNpeEEix+PRcYolGF1H0TrGr6/fojyvcdwh4i/Ebl4jkN
giE13vCZ+DqYP40OOmJM0OrvrnlPtBUK3ozPTBuCYneNq49WdqFG2q0D3gTM
zKBVBSL5kDn3SuuUJh0vfT965F0/9M+GSb0bIXi20XQ8rpePiYiHTeQogZdS
vFHu4U50fZ+0wukEQe7Yofb9U+3QO/dy+jM9j06cmMWMVQ/unpR413GdIHj2
c1Gc4RUoXGvUtVYlcMrudOlI5yFRqWP3qB6Bd9v/Gli7edCtCA+6u4Pgzw2B
WWZmvdg4JLrJ7g7B/udSZfbVTeBKZaQec6Z83H2o88+iUoh9knWK0KJjU101
sd4yqArEb/pSPnY/imIGTvSi63ft1EkOgbhSoM3HtjZ4jid3fvUkENzKvfw4
tw0VRx+U6IURKMo3Jx2rbIR66qi0ugtBimKu5Fs/NiaWWRruXU9wMPHvuiHj
HkR7rl1jk0jA8p+pa5EVQsF0rKouhPLFYOyoKq2FycH7MZG7CMTeC2Yzt7Xh
naRj3PwlAplp7qt8IQ/O/fMZsUZULxlNgyDHFizM1ala6Edw1dVnv61dNW5L
+CdMg/4/eYfq3ppmzH/4tfQfc/o98dHOscU9WOJepFmaRvfL3t1p5crGxbQ9
icMbCMIlr+vfKUzB8wCzn/WoP4Iv3Rr+S/82FJXTv7VRvh+p2fxw17MZI1GN
TO2fCQyGajT0z7aisZbNfu5L5w2CghzTGnBuWmv27wME0hNFt/7QaMZEdcn6
X6neNw0zhNbRrcglc0lnggk4i767N9vXieu+fz/Z9ZDyc0/gY11eC0FOf6P4
QVrv5/6RS7nXBYcRjqhqEUHC0BE9y7xu+LioGNY+oXhd3nceLTuN8ho3NWWK
bxylZ9za++AxlvTes4tA2MxZfsyoFU9lQlfEn6b1PDIoa3KrEXDsbv9A/Sla
ec0zRrEF6/TGHsKV4FjugHvoUz7OK28+L+1FoHd42D9HKEBT+9FqeYr/zPt5
NreWj6V8z2pnej6jg+N7pisFmBKbnbJ2oPoz1+jNpVeh/ULh9Cj1+6iPV/Zi
m05I1n2aMaP6Gq7kGZxUiIGXaFRGOcWrlOijZDrRhxirT9ykdMq3meJSiVMs
sGvmLvbTvJFm/zYuH9+J76rXXliQRc+rl3Gp/kIIWPO+8tvp/pQ1Kw+zXBvR
reR5fJkTgVWA1cncmWaMFr9MDDhEMLle64sNrxW6TRZXRs8SvJJTfHDjag62
JrMy6tbRfDngMW0fkY16HYloD6o3e+Dii7fxfHwQjdmiE0TwYCw74CBXiLgv
UeucLhMcF2HZFJ0VwonHETO6QlDgIaV8XkoIr1D2xO9U/7LRnELvN10YFteO
tcmnfE3avyi8WYxHIa+5h2kemPPV2bPBRdDenP7nNpp/ruIK+/ccYmOto37q
V+qP1WETR74+4KLZNVZn13bqh8sFe9PEitBolV/Bo+srxGr/eqDbAL7CyF5f
mn+D6TtvG2/pgtwkN2whk8BZfGY8kNELj/CBcvFUmt9Nd8xDHjdi/V9SjBlT
qme4YsTEl6c4tYJToKJN67/OdofGDy1wuH30X5ljlG+7qF51/yw8ix7+xZTm
e7jhzqmGx+U4xT8Q9JzmgWIbp2zB1lyI1GW/daD5yEyI+i37NA826qc1fqZ4
WTl6ErWpHSg6qLnIgPYThU0hd6rDBzEZ/ikTowTVdj+effyJh5saxUt7fyL4
NlBbx1JpgMF+ho4v7Vevdz8qPGXFRTlv1xTfgMAh3tztg4UQ3xLq/M5T/rVl
+MfTkmohw6mViDMk2Ltq2N9doQaWtarVW+n6Yy8GfQKMiuHU+So0jvYjk/ue
6lrvBbA+z1n9iuqjtu6AC8OhHgGRvZcHaX5UvLqfbGlWimd5bq33qD5KUivG
F1sPQM3XnVVK9fuix7bfNJKFSXGTj1q0XuQGlNWy6gWI96uPnT9O+ftFTFK0
vANXIgdTvJKp3m+CKz4EtuMni/G6IdpfxpNYNa8ZTdB5d/uFrSXlX4TBOFAj
hGD6ekE5nb+xYaTHI70Nb/wGnjH8CTQrk8Q0y9vAFF2Z3WRHoGv/1uQxqxOz
DQ0ntvxG/ZO5XXp1WSyun3Zanaf6X15VBXKUC8GwiHB3pfida3uW5OrX4IoC
z1iW8qnUvbpY5I9O6FS7iD5PIciOWFh2c2Ur2j9Ktm+nes9FLOJm/sDDmgi2
TAHtH0xlD2t5TgOGYur6ZkwIWtbNyv9xnuLJX9J7iuZHeZRwSZh5DzKuWWjN
51I9JxV5YYJuWN5+sE38EcGFyJfZ4mYt+OBQptNK+f7+R4FxXWYv7LsuZJhe
JQg4GV1/wLoDGf2iN1ZSfzGD/dyiswswY5RXtZvmr3pRyHfskkHIJXyVcMuh
9xWT9hayqwuGPiPVq6j+122XWQhLOhA02cSPjyUQsRC4TRp5IdhL/pellA/r
FtUNaR5cCDdVpi7Xoflg7+gytZeNJ1xPM296H9BRqTzhnV+OW7b1Z5XpWM5x
a3DQWC0SGm7INptRv2g1jc0GtOGl4I7pxzO03lbY2yn7FcBuqycIxfd/QSuw
Hg==
       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8VW0Xxg2RRpJHVE+RUkRSJ8l0FT0IlSRFiDKUjA1mQqZkSCQaJIRE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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlWk41Asbh1HidKxN2SItlDqIkiZLP7IUbUqRIg7q1DGhzKRjK0lFhQon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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs4lAkbxqdySotqOtpWipCIUGlTd4qSaDvKF8VOQjVsSzmW05ZcLdUY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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lekfxpWKjJZJi0z2FlFG6ITolhokjK2SsqQsjToY2UJDqoOULKkk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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4lF8bti8lW5K9ErKmJInqpkRRtiRpsYRIoQihUhFJkRRtsi9FiUL4
IWRfhiH7UsrMOySkUqm+8/0113vNXOc98zz3usrZ29qVg42N7Sg7G9v/P93L
lgolPe3B2ieXd0mbM2F5O0nLa/41LFOlhFt6mRA7ZuWXblYFo8pC3molCo73
ygqFCjpRJcjG8TmSiZVZcceFfzRCKapwn58LBXdR0VdpCg3YfMdY4aQaC9Mc
9HnJW6XYKeoQHvKbiTC32ENLe1ux6ERov0IiE3y/lpmplHeh80bo0OPrLIg2
V3vfnO+AXMaV+lMJTExrRX0XbmzHioq/f5wamOiqGA1pm6vFnvo32vHrKPRG
Vk1qjTYh7q4Zh/I1BoIoamOE5js477HW8pJiImmy/GeX2DukXgx/psM9Ab06
a5Oriv2w+3jW8HX4B+TfS2oW2lSPfL9fD578pRDPI5+cdbCP3GdM8fAQC/Zn
o9b8Fu6AzOKrayxlx2HHP7uqdV8vXLU05Le3MBEhKZen6UGHs/oBgWu+FFpM
NktZ2jRAhfmKWfmKwuibJhuu2STMrchRDxIhz+4uY8FC92Bw3+X4l1UUbO5l
V7i5vcGg3+rZPXwUPmYw060j26GgIhY1/5SFlUvkpz0eFeLDJj2lU9IUXmcH
mfdtG4CEk96riY8Ucg+08ZSe6EWcR9TCq88s0H68GEuN70SB+LXT1V1MyCXs
5dl7PB9KwWfFg6aZmDto+SP3WjOs/RaFzNxiQVjuzZHgRc/RpV4zfIDst6G9
Ne781Wa0OIU03q8n8473fyul2QjTuLj88lgW+kWPnFoX3g+tZTbhh8n+z62+
aKJpR8OzM9o1I3sp9HNIG5Xx08GRMSF77+Q41kbGjqtz07CGy1F+TQADVWkx
rMaHNTgTacd/zYxCnuJQW/7GLuSe3bw1VJ0FNk39UKrFH8rlqj8uyVNgRA2J
dgoOwTZh57Lw7RTcdE4PfikcwBJ0jjfGMxApoCTx3K0GqiIB7J77KCTLiB7U
z0hEyrGwI5NrKcR6ZDZ7HLmNwPT2B/HkPAOlh8Zbuq+gvG6IZalAYd0ORm5q
TyPmrI/Mx5D50H76lgqIpePncdXwTGUKYSI7JTXdG1H0Jumw2QiF6OOLXw5c
GoDOmFPnufcfkTj7NECwtxtBwRrBGskUjHpmM/dlv0ZkxpuwlHNMiJfInJgq
acdMafv52bsUTu1wpyU3tMFgz7+DWRosRBqJDlwWqYVyjOcc9w1yvvjqygTx
d/h4cn73ZWvCrxa5Iqktz2DY+1Fk3IRC/pulme6nOqFtnePXfpiJJ6YPkxzd
CX8vVife4B6HvE7ZaoOOQQy2P7FS2DEBO9tAR6uvNKS/vJb/qIvgb/m6A9NP
2/FDY/Bwpg0L1hF1nZpmbeCoXXo3LZ+FkN+fOcaXlMPRFJZNAuT3ehkLBqHd
6MgJPhaQ9wleSiM6UTa9MJReMH+8lwlt6hA9v6ge3PTwp+8JfgJrE4P28tNw
wbmQq7iLAbmPPvwMrlqkm155p9lHIfJZ950Uxx7Qa0oSjt2fgEJPU1VAdjf6
19/RKiL4MTAwWNw/dANf779OzZWjwDuYzzWtT0PKv+Ha3eEULlyLfbqxqAYG
TRs98y9RUFx+0Ds1rBSDH89E/8tlYlzwkGVbYR9aJwVXxOqxYJkWrSUp/QLz
E4qv3LTJ+SU60tdUoyBkkM7Ot4LCmZGuiJ2OHbjy4F3tLD8L5dOLPyVdfoXO
/0SOp+pTENi6qsRFtAHj8q0uM88Z2LImfA+XSyvchkSUawwp6DmNtA4/6UB7
Y7Rt8xcmkv3iUp3UOiDMtr9sSz153276i4bJKvwyMMsxXEbBJ72SO02oEzS1
mHh2IxbchcK3Ktc1gufaEi4qhgW/lc8Uokf7YFzW9IcvaAIu8lyKOSlknuv7
V6wm8w71XBGadDcRwx4S0V4yFM5m9KgN8nTjru9oprg60dch1yX37cthd+/F
2YFJJuymZX4cVGlGJpe/xc9UCmwOshw71WKxYCfIuiJJoadhkbD4xl6YusZL
vFBmQGBiXE2SvQ2OA7Ibr+wj/Lc6VSZk1oFdCi2LMjdQ2BW21M/yXS+0W3+4
R5dOoBRJWdE+w7itbs/rpzYOXaFb/hPZNFxO+9S3TJKF+SP1zrdU63C92XT0
UwGFo0vAuu1dDzkvI7nfNxlwFNsoWVeei/Lvoz6T+ylUtRpvyMq9BtOYLXNe
K8m85E3eivQ3oemb1B/lpwysFLbgtufsx/yyS1mGZ5iI8rfQQE0xDO7k+EgS
fRjz9XbtCuqBgXGeh0k18bNLJ3P+a2vGtoS1KfWEn7s25G0uqe3BheANxbU+
DPRK7+QYe9YP4dQnNu/3T+DNTV6dXMNW9Lv0JlV4M3GBt7xMVp6GqfWKXxUP
sdA1NGcfq5eM/qL+JCcJCquO9p1us+zARdRMTTwgfN0e9dNEpRZCMhp/I6YY
MPBcpnjNLRlvnp0WKxelwBXo/z6Q2QifXo4OC+JPodm/PocmPMI8vVWoT5fs
py7nfeS6F2g4/Sk4hzwHnfZ1VSB4yrr2vsCXnYXsHZ+DJ5824qFx2P0eisKR
v+nSpcV1qFOdWmz0lQnR+sWfhfkbEPJWcNY2gMyPdfsP/5bXkPQbenv+NAXR
wjK2ib19UKmLSzE8yILN9Aivz6cudNteFJPoYeIGl73hyswe6Kw/vn7wJYWT
/PcHRxJasT1S4GfZEhYMXBiTy8/mgIvDtTSG4G8yLGjLoZttaK9dUEsg+h5v
q74rXLcTU9WCfifWsJC4j1c06XArLtDcyhJIPtC+IrPOnFGK4I3ekxkfmOCq
7lGUPtmBWWNvDa5DRN9e1jh6VOUg5lTjb1U7ClPL5Ie1J+vATBR1qCN8L/nz
VDjCqAzST4bC2O5R2CLtoC+1ogNBjwUFRHYzwfq12uUzqwMOvJInapMoeI2y
Z96O68DzXWVCnXLEz4WUypUC6RBSuBeU9Y+JqnSalLVnC24FNB0YcWJhF+/a
GJfEl1AZqWmtpZiYj/5Q/LeoHC6vl76aEyb6IlKstc2Rjv7vSfcUiphQPv3j
tq1dLzJ1k21laJ9gV6kT6DvXgPWnfQNOtVCoayqfHcrugBG750xtHAtHrjxs
7YpqRufKvD8xxK/W6vq0DBt0g5thmJAPCr5H5Xy32nfjREOWDH2SgUltKdW+
6BqwNpautaIzUWL1Kpx14ylkJU+OrGWjIAz9couAS/h1m37amvhb1AkzgduC
/ZhcsUly2JuFgtK8TbsP0vHxSEVx4FEmYlOfvr24LBPR9xzUinQIHmhNB/5d
pCGKr8QkhOirxPND/zYmFGNzlLNLMJm/o8POnRsb0lGXnv72+yIy/55a529L
u6G+Q+avwh5yXvnNl8zQIog3crUIE31Vt/+ZZPL2JVbslY3e/IaJUkV/c6GY
HkQbenJKqjOQbugWr7urBhWbDU10yPyTTxi2q2QWYFipyHbFHuJ/hnc3aJZ2
Y9Hjk5rCeuR9Mb2iDNlucN3wzvOtoZDON6psX/sOfBw96zy+TODqsmRjr9h+
LCkWVm73ZqBk6e3r6z/FQUZ965ZA4kdGovZr22OrsSAZ/6/lOhO9WWkbLQuK
oXfu5c29RN8ZTX/N69734s+W29vnMoheGFqFOi2txqRJXV7KMSZ0bvqcvWVC
h4yzhms1yT/ZgSOGE6dJfqzLkZX8xULVpS/K5VWxuGWccMuF5LmJ86ueNsQP
wm3bpcxXFylIrY6It9V4h+yk8vE9EUwMZtGmH4y14mNNo6XRDhZeVsxEL//3
FlUWPkddif+z6dCcvbZ0o9Rr2WfPM2S/zV+OlEVVIN6wYPYQyYfrUgzqm7/c
gdMjmgA3yS9X495lfrvbiwFEBfEks2Abo3zwRvMwnGUdFEIUxxFWHFZ5j1mA
r1OWDDFX4r+NbQWWvfeQpzsjJqJO8CmRtyjl+wD0dml2sdkwwGtzbKr2YyfK
D69o2s/Dwu24ZxrsPzshXKYuIDRM5p9Xm8EtWAL34Du0H4+Jfr1jhNwWPI3g
gC8NnKuJ373N6jz+KxxKCiNFq9aQfZ6P6Pxt04HDmsdork4M5LcW6k/kdeGR
l/HB1SosjD76rpsdkA/HbYsruYl+R1pvnroW/B8CAib9fmsQ/Zo/m51D9E4s
5MT5QFmCL/9+GdPyDug9+Nk0GshEUG0Ox38kT0hVrjaRXv0J30/Sen89acEs
c5H9CMG/wHp/G1CtiP8d5nu/gYWSzk26hZydCIu5xj8jT/JeLF/vcfoTPEyo
d3Ej+/MJ+VjGX9WI8M+b6/TPU9DlyRXgO98HvdcLuw7EMpBcflEog/hVfbyo
ZgXRZ3rfnD+tpQqpg2FXPe4zYf/d4wvPMRqUE37S3+sz4Rsbt1l7bzukqnzm
I5yZ8Mk4bm4k8QJbZfnTqkk+fZm0RY2TjQbtXZRoQBEDEkkjH+q+lCJ+ijPl
DgeZx+cVH+I0mpHk6QoeG9J3nmWcD+lthPn1gPXBFiysOrZxh+hEN1ayCYdU
E77EGrzIVetIQJ37lbshZB/2bamsPXV00BK+djzmY2FG97y4lUUPbPdG0b4v
YqG6jhn05BINfv7Te/kJH7K5zSwMvhRCXEuh+yjhz+hOtcjKBwehJaIQ30Xm
U+Xga3+2sQfCxckiOe6TqMpbPi3vmI7BvIogO5JvlPesCYs2q4SP5121g9xE
/x3e31/UXY3F5yaCdpL/u+E2m3fY6n5kS4V+rGtjYV2MnOPEjwpkPWRLcyP7
nbv6T2t07AWUIs/q5u2gYBdzk3vPwWK8XswzaGFF4cYfus1HlUb4pTpKBxA+
TX839ed3LELR5OLq/+MtuyetXKyO4NnYRzhx+QQUt18u4TvbhzGG/IM/kgww
Y4JGuGXaYLmr8OVR0o/Ezbftk+kbxJMv4lfXf6UQyr7/plXRK7zu2mhev5vC
FV3Xtf2WDWhaFaf6fRP5/kDTIbHREhyespF5FUlhZcEf37HhRtz913JW6xET
rmc5bD7y9+PvSr0z/5ZSUOifHjvnPYDXj9O0OL0mMFp4oXh5WAI6WZVbHch9
DYQuMQ5wPIVBTpKFAdHzadepgYeuBbi37YbLCU3Sx0xGDv14QvZ/pLGejWJA
eL1FuaFnCSS+Se3mIvncMm75XNbAC7zQCxw7IE70YuvyzAjrVhR1pS2okTxZ
4mLyw3W6El6HXd30iV+6/VVbamg4AHVuYzMZkhdCHl3b6C7wBks1U7i6bZkQ
nC5daTzTAXulR0lTpF+PdqRZa03Eo+C8hbUGyYuz8xzbd3D3g6YyFjNdMIGq
pMJB/X/ZYFuwL19F8tB0wMOVQr0D6PR3fzhaSfhyLMS3NfIOZEJvGPuokH7W
mNO03GoQ5h/WaTuXsyBhtUFptVslIpev++lE+vTKNnHv4n8DYAl1vEzUG4d5
7KBy2ew7dO3W8ujcRfSGN2FJ8KlS6F4Z3bHWgYKcd/mipnU9sNAJOqhNvmdL
FOSJtnqNkISd3Hu0yH64H7KklfpgnTcnLNBOQYz57U6oNR1WZvfuJ3pM4KZ0
0PZoGh23aPS5X6Xk/nOsDg+n5xDacIq/mvQ/S70YB3pMLoqSDkhqbqMgk9HW
fkm6Da9Uz3myEf24lLBmTYksDaVMXtqyh0w4DnE/tSq8j/jT+1IW1CgslRJW
fxBHh8sEe1iuJ4VEpYd2IoEV4C0WXlNI/LVd7brhSf7H4Dz1oCaXvE879UPw
EfNq+Gzb0srbS+FJaYCp5oZOPHn//ER1LIVCeSGb63J18HOYVt2fRvYjeIZ9
/bdekvvvpBY5TcA/kXtIbL4KUwYRKXuPUyg9qdDN4KRjslgwtHuAAreEQ6CX
fycmht/yXHhH7nt/iuLkbIWKT4HLRX8m+MotxzmHi+F4RMtUlsVEUl/4ihm9
LiR+ZnvefZ/cP2qnVPR0A+RkTBtEGilsc67Yat7Wj2UNpzNzSf5nPyWhy+nZ
hUnx+qYp/wlkRb4T8PHsRLXqscH5VCayOXjOBzr3YKSD4dAezoTxV6MNMnyD
0OY88+nNLRZMKbncLQ4pJC/Z8BSTvMzU2SC8wHcHytsWKiMI/hr2COicYG9C
0l8lM+GrLLjUumoYFLUhW8jNte4KhXj9zVnGej0wEyp97UX43Tbzykt0Ow1I
3+d84CULp9eom/7k68LdhKWti+eYkDgb3cqIfou47i6NhAiSN57t7r2TUY8W
OPDlvCd+3Fb3TTowFcv+G0m7QvqiWHCFgpQ7HfN/JJpDBScwuT5tx5nwFmRq
bBm1zWFA1VLovcOrZpTWMwqRSMHWPqNuG28/FnV/8P5Vz4JDl/XFDeq9yKpa
MyZ3nQGPlZucT9a9gd5ojctMCMH/mTcXOhojYCj0gU+BvO/PrKDqoMEz5MzY
/XYmeOr0KS4I8OsGe0P+68ME73oZasKJ3h14dPdXOq8I4VN3cL7sUBfWnhrX
VzzKwPCKBWrzB5JnbKxX+Syh0BphWbL7VCfsB9W7/1Nn4Ryn5tVth/pRqn3l
j8V6Fh54/xEUM+2BxmfNWn9XBlqm3L61kfzbuXt9zd4MMh9bnfMzFgX4nehg
IED2I5zVvjvuXBOibmg3TRE9KTwk1NZg3YFeQ/rYGOkD+U78w/9xNOAr/4K9
JeljfiePtugSfMj89flsYcnCyl9zrlLN1fDPED2iupwFNv6gExU3i9BJf79I
l/hfYvKLM5tcq1Cg2RLzY4Hsy/akWWFeKjZnZNMVST/sepSgP3+pAp9DbO7o
Ev9QsP32xYKPBsvLrN+bNpG8mSSu89aqE0ZIa1lF+OJuOHMqwqYNkTwpDndi
iJ9aX/YqEq/H6nH2/TE3KYR8C9WwK21HqvyLvnWmLOSa3Do8G/QOShve7hO1
oHD5z1rh/wSekx5v52RvTvRgTqFG1qYAzTJGHoLLif/tp20vU2nAyHjyjqBE
JtQ5/c/pfurArdJ/G55XEH6tfVu66Vk39nNULgyS8yxV6sNe3+wGj+tOQaEe
BnJpWscOpjWieEPV3cTFpA+N6t/a++Id9I4/f1i3i4GQB8UGXmG1kKm4SV9x
geS33n+6GUu6sOhroS1bGskXa4K8+4UbwU4dPTB/mML/AIdp1yk=
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk81Akfx6UtRTlaukyKx9qiw3pstY79KBmRZzto00ZEuRaNHYMnbQeJ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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81Ikbx6W01FYkhIqOte5Nh9piPpKQ2i41bFTywipnrhWt6KJWKtUi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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8Vfkbx5HKlEJJKZVQGgk1ki0fhaKhTF1mcH+Wsqa4lnbZUiZLibKM
FEP2rZpUiHttyRYuLi4pUb5FMoxcLX7f/jiv88f5nnM+z/v5PJ9nwxHvQy4i
QkJC8fT6cY95qbeW0VwIy+RcTKgQfNeRyu4SqwHX6tclcboE96a4Nzew2VCY
C/raoklgP5SUdHotB6MyYScWaxC8GlOaYTdVwUBGNt3GkIAla+b4Zn0qPopU
le/cSPAyZW9zX1sPRC9Z7eipJDCvEvfPkuiB7WYWy+NvgmBpv7Sou/kI4J2Q
KFQmiKrdOfOwrg3+Idsz+QyCr2IXdRNmWrBHs0blkxfBqs8HPacUH8B28XmP
4M0EOjXPg0Qn65BPhIdLdhFsTvS852VdD4n9Jr816BOkxh7JbC67i0ID++XT
SgTdu5JNntpUoNBN+oKFFsED62en0cmB3Jcm5hla7z9qBopL13fgfaoYs9+b
1tMSx7dWzoRx2mCYBtXHdB3epxIaDi+tqu6rCgTsTtZc5L4UFDiqMR8oEpiM
hkw+nu0CqzAkLa2YQFORNGZqtCG4ssDJ2JHg+nuzUV4XH/vmJ38+Ek8gpn1X
3vvaAI4Vf4n3SyGwtGY26DlmIJ8bbl5H9QZdZn6eiORC40GS+1lfgrBqVbaR
aD16Hy1UUvuN1vO4xmWumI9/Wv73YaiRwGt2Qv/NaTbcpX65K7KTIPGoj/7h
zEYsEg6t5TIJ5LlZ18/wijE6nSnUT/tdvrNMzuXnPhhzVi5/+Jzg4C/T0qmb
u9G31kwgSKf1XhQaCVJohNK7VJn9vxPM8ORzojb0QcEt7tC96wQ2codLCnO6
cbwkQiY+jsB0/kfFvDP1+N2kyPMO1Vdc6/JxkvkYy1wkP53bQtC383TFhS3N
MFjFSuinPDRXmFaXFlxG1C4jQSzlqZZroEc6uEi04cnlniTwSTLlKLI64aTg
obqb8tK0ifg+kEx5LOpL4lAeqi/tv6epNuKD229+toeoX9Y82jJuUI3b49u1
9hkR1K9zdthwtAKBialBAm2CLvblitiDHXBffGR0JoryWF34Mse5HQ4ZZ64t
tSXoyDPi77apw4qw+ZfSf6Xv10Xaqq8rw0CyvMWQKu33SKCBoOA5tDf49ppa
EbRaFUiO7zgPa+fpcG2q/8Z/bdX+0mXIWlB0J2ErQcRtMyRcakdKbvS2O5R/
9zfmH7XRPIj/bXVyN63vhrGL8EKfFgidPBa2zf5HPVb35RN68WF4f0AAm563
d1VXtG3DgKts8laqj/mQZaLxpAbl2jy3XB3Ko1zlAn9rB3rsX0hNUB7lrH+f
NY21wZr7zO49i6Dg58MSXP1WbN/65rUZ7Z9H5L3briq9iAmX2XH7L4Lc2qIs
b6cuNGZMTVjfovM6q50l9bEN8XYtl5+6Ewzt9dANzu6EVu+4Cpwpj5EnR/yu
lmO/98XjiykPoWDepgwnM1xdJtH8bQPNA2WjK4yWLnCF45MsLxLcPrF1DUuB
B9F6E40HWQRJVZbnRHbdh9ryJePi1H9hU5PenIY2FKooW6sGUp6qg27+4lzM
tuxTkA380Z+h8gFBKf7t8lTX3E55SfF1zxTVoOrX+aU+NG/EYhZMfP9cjkHl
whx3dep3vvqy0FOl2Pgo8+Iaev5TZ3RzaVwxEttDr8nQvNCeZxNY5FoNuQN1
xXom1K9XrPItA0shrd5zypL2azPx59UPNIAoj/kutiO4mqeR6DDYjd+zo4nD
VYIYgTGnktTCkZNREW1BoPvWKsBmHg+OK33evT9FcNreQrc3txudew/dX3+e
wL9SetHsJBtNHk56xVRPqxfj61TRU8hY1C4gdD63Y1O7mCgXf1/QneMEEJQe
L3onbdiEnZserZfeR3A/oXU6hdeLTSISJ9Lp/w1j12SJW3Qg/pRs4iP6/ewb
5RGLBHwo9fga5rQS1DCO5sd+aIdPe0WiHuVvzDOKKPvEhVUBe8s6T+rfs1/P
TTnEIUpUrm6I+tV0qjR9hxoPDEeohtB5b2hevSw/rhM/2f30teYs5ZXpX1UH
Nv48E29vR/UXhlnEfmFwsXd3qH9VBK23UtRo4YtWFH0wGZG0pnk7mrptVUE4
uv4aXupNv8/1NucdtutG+Z5ITgDNe2Zzj6DBvA82K8I2hrRTv/zR7KijHosD
hpPrDGh+yn77Q1JjlodilvP+17S+0j3PtnAs+PjIlPovuIH6b7gkVXuqEoF7
7NNG6DxPddzykQ/Ow0z7oFrCJsp38Ki8rAobieIFJxX1CFZPL4u+md8DEdHX
YZGUn3upuLPs4WQE6+Vr+dL/Xb77eOrVKg5Sj784voPuM3lzdWWhZ/H4aJ5x
S5Q+F83meJ8/24qRdOWZAJpXq9ewphpGH+PKyr7Kaep/fc6Ofr2KOrRTLnN0
f5h/YaW9OsjG25bqlSe2EYgnSDkw5aj+CX179QrKr268JGRjP2ofPC+rGiCQ
8ncwf97QhYVquqcZfjRfXcYiHg83wy/aJYhB/dfRrfnTGy8exj54Ci3Mps93
r+jdZluJkweqwsvp/IfFJHX7HeiB/0y0zqk/6Tx4hM5zofvwyiE7fzO6D4Uy
Unxrj3SAmTM/RcONznP9Xq1jk4nwGvYhm2h9jFz7Jp2yF8h+Ys8/Rf3s6R7z
rtOiBu1PHBwGKb/g/zKu5/gmQF9SOOoven67mC/jYVAratt1ls860bwwLbAL
5nfi29rSUFm6n6X5vpP9sa0QRMm+sqT5w4obEcpybkC60v2qZDpvxVnKMn1r
G/DJV25uCfV338HLh5TG2Oh8G6TdT/e1oXqa+lrLEojkvS5yUiNoUVgV4RbT
g7pSSV+7PJqHUorvBiLL4Dv+NMD1FzrvjPIyB3m6D2zdo3ZTPfpLfVoNjB9i
45jCwkE6z+fyhcxzBFzc17tpty6c8hgT5EU7XsXq0OjGN9Sfq9rZgmXdrVDR
qd/7nebrzB5TwedttUhzGlSdoPokxzAXI9GEg4xzWsf2EzRV81SOtr3A7crZ
eR2Ul2HJK895wd2Ir2+aVS8gUDn7cEhYpwnzhHNdF5gT/B9ZNbm/
       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8le0ftjIqUUZSRlFUkhUSLkkoIynJyFtGpFdRkraM8kqRVIqEJElF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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs4lAkbxh1KiEhfh++LlkZ2VUKlFZNbhmpquppUvpR1qU1NZtIkX3yy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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlPk/1IsChi0l0YKKLEUlTs60neIYy3lVitOZJNGVi2SNIls10TIXN0vu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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4lGkbt1aRQ1FKW7SK/aKtTEUh+bGbWFHWtw7ZRBRFydYUlTSmnEZC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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHk8lG0bpVBEUZJCWVpEKpRQX0dUyhYisqSkIhWJSJRCliyJLJXySij7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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk81Ikbx6djXRVSIlfSUE1SSbRRHyVif7qkiBKzylSODildbKdKsnak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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs4lIsWxp1oUzJpF5VuQy6ljodKQ9ErQkWETeXsXdJOJSFUpLBLGqHk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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk4lWkYxs9EZgqFTBlR1pHKLltxN4VMkqYoYSypcVpsgyEKqUS5yJYa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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2kglF0bFtlCCaHyFhJKRVIp6kJlp1VJhYpSEalok15KKGUrLSKSN0t2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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs81NsaxhHV0Y1K9xwabEk3l8n9mUQ4aSiS20nbVuTkVlEpFPbOtSSh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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXtczAkXxlNCq9XERFHoXrK6WZTVMxHFKKl4c6ntMkS6UaLpslGiMFJ5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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVmk8VWkYV6OSDJpI2rex71kK46+UhGxTkhQVkmylhbKV0mKmhbqksaSr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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8lW8ftiorEorISEZCFEJykVmUFKVSRqU6pSSKSFaiYf1ISdKyCiUy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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs01Akbx6eWqUW6Ibe2ofctuZSlhPAtilJvzUZuKZfkdaRUi2Vri5RL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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVHk41IsankoljSKRki6SLJ1Li5S4r9DmkRwhlQctTlkaREQy1FBapBCn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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4lGkfHiWlE2lVn7QSOa2zaqm4R+QQaUitSoxDSl9lWSySQxJaK0lK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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk41O0bxSVpIREVStZkq4SE1FEkskVRSUJIZektihZLi5Q1JEvZKjtJ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHs41eka3WkfOiWXMzqEhMooUj0uyWVWDarBRGVKqZRBRigMI0Vuwx4M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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwV0ns41IkCxnEilYg0i42URnsUh6IaWbySTaRU5CiXxMjqiKldl4q05FaS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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns8lGkbFrX6pFo5VFspGjnUJqXC0uXUtg4VYlFSGFbWKU2SNmyf6IBK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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lG0bxsfaJmlHKZKlEHqjz9aJJqmUkvJKSaKIkC0pJVulyFpaqSTZ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHk81YkWv9ainrIWsmZCY+u5Eq/mqyJKqzUlyYRKtFBhjBpUejzRs001
sk9kZCvLDNd2L8YN172u2yVJYn6Lht4Qod6dP87n/HXO+X6/53uOQcAFt0Bp
BoMRKYm/s2fjnWD5o+3I36LSNrqDROpyvGfa6yaobHn+NmAficL5aEvNND5q
hlYnhzZT2Pvmg3RvqgDnejcZtz+mIO9x+sm7UQ70dQI9hodI7Fz/UlrGvQ36
hbxK4wgS7ncUNIlpIUbyyaesIQrTTxZfftJtwFhIXGKsHgmtPaqlC/587I6y
OfTtHxS4o5sU3hzqwyophkmIHoUzPtkpUtwmXGeqOXR4S/CZi0oMWvNxeM3S
Tb94Ag+db+q/vNCPwqBwX2s3Cv4FzG0mzgLk9PyoesuCRubu5JAitwo8a/xm
s30DgVklctd4+CDUtMJ0zR7QGHX97H3ouyro2Yhf5nAJFAbsTzd0egZ9vbuL
iwSBmpLo7JjlPki3Sk15nKWwfpOBq9e6LhzW6MloIEg89junpuRZh+rU4pYs
AxKONnJ5CyUVCH6/ODP5gsDT97KWCi0i3LQezORxaUyvKi6v4dfBg0id0t5C
ovpK17NdoiEcOZ0/YnWQxnBoBsPRpx2elmlWiVdJ1ETWVzz27UDLUtFUDYuE
V+/lZ3ahAhhzWoyc5yV4knwjJ9MbcGriJKtoDwmrPWuW5i7ykWq27FJdQuHo
tOaovXIX8rd2ZzPXUhDsHVE6UNALi9l7gTmDFBwYCkFjzVmovXZ2e8IJAufz
hqJi89gISar68kyyz6Npod1+Oc0wvfglxvoUidzZvdy5I2VwHT1Qsb+OgNqB
JD850zbcFs46q3SSeHSB/KV3sBb2+W7D5fMEcl8dvBq561cYhd++q8ckcb6y
I8XOUAiPCQ8X9ycU5C6Y25P/bEWLo9nr50EkZEfrbq0vECBso8XmO7tpzNsl
vGyYaMOjEyt7lSJJjPwpWM0aEmKrllwV1UljQ/otn1uFvQiYnk8zb6IgM+if
7mQuxLqDZ7x+V6NBF5stm8cIYaAmk98noJCoWx9ZZVyN+8Xbr1EfCJhGznK8
V/fgjp36fxZuUigrq1VSjK5Ey1FfuwdsAisHtq1UzxqEtVjRhJdJ44aWOXvB
uROGdy8vdfaTmH2VsiR1RATn7KUNGn/Pu3tZ4WEpGzbtgWy9WMm+mnSDjDhC
1Mg2rv+3Mo0T+knhh2T70ElIxbgHU3BZGhL/lfEKmQkjmrNXplDR8FW24eQv
IF1nXbOfE2i08o+PVxAi+LjjyQ4bGv4ydmc2yCehtEYmpMGJADfav972tQCC
peee+wIkfp5J4L87lwpp5Z8dJvYRsDprdruR/zMab5T9WpBFwCS36niXXCey
fdbkfp4mYaHs0lgbK0LZsfmrKSdpKHeNDFZmi5F/T47DICX+qI/jG6umQsHp
4z82Svpt4zgGq8b0IOe1djErgIIHa/+VOHcR6Gbm4j19Gj2lgQZu5zowwjdL
2PmJhMP/eB93e5ZinNc/Ic4jMN2fzo5PrYEe8+qVmY8ELjmVf136326o8G68
eMshob8uJdBWsx6p9zr8IwxJ+Bvtm7v2bRxcVN7XdthJ+KwQ64zZZwFJaYaO
JyV8fNp1pAO40ElqOrYo8Xfcbg3lhGAOYsR7JnnjJNZ2zTM/7+tG3Ffh1iOa
FCqiBjwvqeZhdLOD7JPvCfTzvULmPgqwNt1U/IMSjdb7bxN8BwexK0xxLjNW
cq9RtPsM/RA7vilgdQQRYJSX7NWgf8JB7yg9+pLEH3XtWdO2HBidHvlhZoCE
UYxC9ugxIcpNM5hBQTR4m96xd9j3wFIvTySVSaH59R/TzsxE5LZGG4kcCMSH
+da/WzEMv7XqWV7RNBLfX48b2D+EAMZMfZvqFLZtF3rrXGqH0vl1tufaSIzP
FrH1xl+gnzGuZRJLQW1cW8X0CAeWAYURrkISvOxtnup72KiO8JmLbSbReUrx
p1pnMR7/xppKYUwhffJB3z31BnxpVLE9wSAhaLfiv7H8HTsTu9fLvych9jPU
V5fjocjJ6/Pn+xR6WEztifBe+OWq/WUo0dfI4OHOzRVdmCjIE7pI8KghnWP7
UYQNGRGr5qSnUCyjmXNYRogPO12Sn39P4xMzziKsuQPiAt1NLF1Jv2FpL6a8
CNyb1zda5NJwOeTkn6QxDE49WwNFNE4rrkiuXcUH2zWHpy35D2Eub7tVuK8g
Pt5YqeU2hYGBJ51SHD42Gh/IaDak4VuWEDrvJka12osdZZL6+daFZRmNbpQp
qi5oS/jIH4w667urHzqyLL81kxRuWFW9+W2iCTUfvJcTTkj+a92jsSH7PhhV
PRI8ZVGY7zjOM8vlQWBtbmn/lMLj017DJrlcjNVrkEf+JGF2KlR9awQXqzvW
8bwkeui/CE7+ZNuC2EAnXXkHEoq6F69saX6Fcs+rK2aTaVSU2Czqe3PA/u6M
SKOSROK/Ts6Lwp7C23LsaFsLgf8DyJPITg==
       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVHk81IsenfCylIkaLYr2RBcVTxLOJVeiFekW2ZJKvDyp5LlItOuNLKlc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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs81XcYFjlZGGpZzcbc5pKjDjYleeREOajDypRrSoSypgyNpCmidnaK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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k0le/XxsmYJEqGhEJmGdIoXRJJpVGGSChRyVxKkkT5IkkqzURIQuYf
JWOGzBwOmZLhec6RTJVUvPf711lnnbXO2vve177251rt6H7IaQEHB4cdJwfH
/38+lX+Q/dqiFWJDqg3WHRQCT0gfN4mIR9moT7/jYhqMvtlfUkodiD7t+6wm
k0bUQGSQX3czQryVc5V8KPA61W1609sDmePtpy8GUuCgJVgHeKPRcu9n3a/V
NLifunS6CFWiyyxOTL9hBCFnImoaNWsA77nHLodpxH1mOrx7WoIBy1uV+jY0
tkZ8ELZQqoOR2P4lp8JoxCyadDqbxsClbFeTKAUWGN+Chb98a8KyE1z5poE0
OBK6o50cP+LjVa9DjYcpfFzw9z9DzSb8/Lbp2775ERQ8kl23I7kGKqOCxout
WdjHW+GwybENG5dt/NXXQSN5+lj/Lt8WvFJztTpfxoLQPXtBubgqeL8wj3xX
S6FfLkLgbvcnvKi+ddFkgkbovbjK4c527LkuIb4ybwReSWyL2MBmdHfseMw7
MoyCseUatz60Q6rgx6NXDAq6OUMqt8XyIWz0M1CcvMdosLbzUcUWUCmRQ4vf
j0Dri4N1UEETRFUpq+roIRhuuU3bXm5GnazCxUryPtzynkcuXSyB0UAZ1Vo3
grhrFnqfJevQ0uM52fybgn3zlnSziTgYm/d7aq6hYSw8Ie7G04TIR+e6Uzwo
FARdauKjaxB8c8+D/fdpqOkEC/TG58J/82TykTEKDxJXnmxRaEKJ9V/9/Rw0
jvnOSAY1tyDmcoqi07oRRO45IobsZuwqan3StIGCsNyb7tHXpP/KE2duvaKg
M8v0ei3eBkTkSfbWDyPGa1W/j0Ml4lzv9HvX0uivdluuE9aCFQkTG6Q/sSA8
FGvzV/UN6uxTDrh+pxAVenibllUZuG2jKj0/knn6qazS3GiB3Uc/NrSR97pY
J7msi7sTVhFDV5q+s1AgZlr7ILsWkVkqxj9IvfbpRdNb/rsL49yAn0xpGoH2
7m/Gr1eCFS5sVx1MI+WWJSePbyOWimg/KxmiYWDpWNP3+D62ZUnNWyrQ8P/o
HD1QVI0tvXvj9nmz0HtuPpMntBuhKF/vsJzUI1bK01T7BtrTMVNisjQuv1zV
eHAJA/tG9z3sKCS//z1Rv3Q8BwX2zrprJihIaCktrx7uQLXi0JqRZ2xs/TpX
MfS0DTGnd7V9DSH7kW93o2jRfRia3W3pESd6D7klGP0yD0e0E4dUN9FYhR1n
vDjzMfResk1Ckka0W6rpDqoEo1PbPOdO09jDU76e7yADwmtVlm0IYyGmjFvt
WWEbGg0NF9jX09DqHbwUGZyFz7abt2Tvo7H408TKh2Gd8L0kXmrzgkZaxsLZ
L1eZyNLmc+t2ZyHxwV4bq8/VGDTbG3L+PIXfQZ1cS3d2YLS3f8/61GGcKYrt
0Z/vwUpzX39/xQHMXfYRllDsRqFwj8ujeTaM1AYPN2o3QmG1nUTp6Ajql/B7
8Z1sh3lQymV1b6LXWalb1WVPIVgYwkzcQqNdd3hx354WdJo3yquaDSFw7JJV
cNYbmG/7a/mZ9BcyNb3wbUI7QheE3jQSY8FA9Nqx8cUfIcPYbHpSjeyDR7St
9bkG9H7dunLnQQpq0hJC+fc+IuB+T/4Z8p4l+iuEepYWYMtGVVsbNtmPlaau
HHQ2ptRMb17IolCrKTN/X7UZ57Q8C2yJvuwmw54vLW5F8NgqqQdXaARvDQs/
U56Cv1k5GUk/KIzXF7kmbC4DK7CjfFMUBYs6/909L5nQXj/jLi1F9GRkPF6h
zcBVBy1+Qz0aAm0xTxPqm6Doe0LHxpmCYavN5O6eWmjRyy6kSNBQ99XcnCVV
CsWt73KTDtLwUHzIo1VxF4YX+/Q0NGgIR3zbpVXzHuvkhTiDeEk9vaG7t5h8
wpPeg7lcITQs1mZcnapqgeSGZNWNXhRUZrzl+g90QXlpcmHSUxasTnp6jokz
EF6d1ZvBO4y0lS0SK56Xo0v891bhIgqjS28nGD7Jgtm9+Q+B/kQPxsG/7NZ2
QXvWzXxglMKbv/vD2mpaEbY5+jPaKHiWfj/DWNgMvwvnL1nH0igMOrWwqaIG
eWpS+5ZdI/79sNA//G017nL1R4VV0FjipxTef46JusY1Zlr1FFQji8JNX7XC
x4kr5Js9jW3n1B/nParHvUuiRReu0tilNHZcsbYQOsWZYuuTKfw7Olf2LY4J
sUvrY7Q302jRtbqn0fsRQbH8sgZ8NGxNItZ1Zr2AIt2+4/sOGpK2sXE2VUwY
BC3nH+dmQ26V2y1lhxK4XGiq+uJD9pPTk++QpSOYv5nq/WTeW+MdA/kXdMCl
eX0Tz58hlLD0o3TqjiH0ymNaRI6GQtzQ8D12AwI02Otnid9WD66b1GRUYMUn
/WhXEH/Z0xkZPZEMGeetcvJKNMYviMyr3a6FT7jOojfrWdh7OnIit7gFwU5p
Tpk2I3hycvS2S1odhkfg+ncxC+bxAtnWUo1w+7F5gT0fCyu8VJzrsyvgMsmr
yUPu6ar8fxX+N56BR3iqbJLU86eX5/ALmSbEsXK7OZNpdJeVp2Y0VSHwblVy
aDyNKq17XNaMMvz+s9Lsx380dH/skIzY2IVwTvVvs30UHl012iU82AmJZ302
uMnG3ys7mhr1WnHxztjG6PQRhOa9MJPSz4La9Z1Vw8o0TsrcUKzia0Sh9dtW
cU0WJgW8ZCJM28ASGHpbcZYN+yueqi+n8yD6ys3j0DCFtEiZF4VFDVjKdqzz
bR/BcY1XKroizeBfnLPwgTiF2Kzg3EzFfNh+G/hwmfhblJRx2eDieKie326i
rEv8oLeKY9OaD5hVcaf/3adge6glumq2ChnFPv5G6cT/NQqPFVqW46bhT6Ol
wSOwYFu+8tvXjV+cv+LjnYjezecqZWUrkKegkO2aR8HvMbeyoXwbFuimfikf
oMFk8wSE+5aDd0D9au4k2Z/YXtsLlm24v0T9SVg/C6dv+QvIm7XC71xED71r
BONeF63KTsZBb4fvQCrZb8eZZ5D+0opl3IlzrE4WRjdETh1q7cRDBQavlSMb
9ZqOvsr32+F4oqBwYDOFCt+DVXt3duMZLeWtrECh5Mu6iSaJbLh4uqbyiZJ9
puJPHq1vw/UDfy6EX2YjVLbGr0+yFuYheoE/wigYuEbL3/qbAadsQ9Ynsv9e
71+e/ffsE3S6hcyXphG/0TorymsfgQaNs9zB8jReL7IaPsjdgqOiH5o0f47g
0abEnhMLu6EbXP5yhkHjt+eVG6HXU9GvtJlbeiuNpDe2V0OJPycIhXx/8nYE
H9s5LyS878B198ntsmUUNujXRaY2MhF+zfRfGB8bfxae4Ppn344yh9d+S25Q
EGS2GoU25aG3aI2TRQS5Zz3xGgt/ZIPjycJwjQVkXgVH/Q5nlmMDT99wDicL
UXLTQWzHKGh7zM2eJvfzh1G4y6eQLgR7zkY79JJ+v7YUMM2qIeOlluvORaPC
c+jVRp5WxD1udMyIZZE932ZtNEP4SvOsg8sEC7P6nEvSbtcgQudaV7gluW/a
wY51uS1YK10tJEf884V6OMtJtw9+LyKsDEj/gU53PX7tKEbmAn3t4m4KCjyy
4Qq/uuAjWu58uX4EaRrNEvTPalixzQIaOyl4MWoWBM5/QiK3TlUJJ+E1+bU5
fTWEVx0VtAVDSb+bpFYuH3eFy93vlyWIn8R5UpNDtW3gV0+88yyJBR+v9f+e
eLXh7Lub1wKUWcjSXGvTvLoVfeNRRmlPKIiMnLdPILx3ccuxRXecWdj+MOms
yJs22LXbOF3fw8IOFbXfrnyt0F/7SXADJxs2wVmrf30rRX/60Xc2zTT2Vfaa
7B9pw4Ri6FSnIgW9mxpGVfvrwX2OMSVG9H/I3Dte8gEDc81LYzY+YEPhu8zo
ztRGWDjJrzZcSPRSEvA5Fo3Izz+ydYZN7nNS0O9qp1a8nBpdxhs/DKbwosW0
SSYu8NRlyu+l4f7JlSujlonAmNudc9Js2N1bflkpvQ1DHP9xtJP9WjVtnDh7
swzeVhKBditptG3KddO42Q2+mOT2Y4rDkLu3kfHasQmf+1880yb3vDs7Venm
ZAnM2/ac8a4k/rFM6a/FWBvh9WvvHA4PYjpFtiTSuBk5v3+lF5J5DDqmMJ7J
v8efn/Ory01pRFxlng9+0ANV8Stb+UeHsVAh62D/6xbM9gY5vbZlQUFKeVFf
ZjGMpw5oLvekMTynZ5PC0YWHVuJ6E8cozCTxd3GWt0K3xNiy2IoNJUGR8dzT
Lcj8vnPgDtFb3KCicOSlDAS+9a12IX4YaCmaqpHRheGA3TpGUTS2HH1bN36s
BcIG4lSi9BCsagafBLl/wMCHpyLChcS/pRl/HZ61YHStgZ454ZVxhXsqShL5
6Fq3bkE8+T6zgufuz2/ZcL7dY5VM8tIqwwCzBe4fcfzrDY0dUoSvhxQct4yE
IqBL6PRz4j/86yZd1zRl4u5X6bOuijQCqkpKbzkT/YguObPsD9Ef17Wd8oYP
EZOV+8eC1Gvg9M718sRjSC+aMWSK0QjTKZ163V2FnY2lqv3/zyuXW44f+S8e
a3qZ/g2El22lWuuGJxmoPu5SVbyCBe65rD9Uejp2WrBNBgYoqE/88o2OroSs
xXE6ez0Fjz2K3Nl676ERedA8iPAuxR7dLHzkA5iXmnecTCD8O67mUtpciN6s
7eqehJ9u/h7zeDfLwPhojfXg7xFk6m5KHDhdDFascY6VFfEL5YkJs+RWXC9j
iifZEX+MrmtIv8WAg4yCCEuEje0z7MUXz/Xgh9Lue2dfk3lkKMpfkY1EV6qz
2zDxP1GNratWMN+juMd63avnNOqaXTmOddbjXP6Azrpy8v9Dkmp8sU2olpNd
LHh7BNzfWa+2fcuC6Ngf/0Yyjxe1TV2uNaT/fabqa8m97n5d4VXxKBEhq/W0
7xM9K3NULOtklEKw2GPtcRUWZK71hy4cYEBxp77bK2PCQyHT21R4if4KKkWa
rlLw+XUm0PBkAyJURKXoP8T/3U5OSV5phfSWy+27D4ygI0xoV2EVAzm76kzm
ST4yDM3ZbctsxivttBjmvhFcPGITbauWhTrpIM9Scv+3TsQL6d/IxBpjlz1s
ExqUgPeNz8hAnLKSgDLxcwPxL5N2yR8Q8PCZQTnZp9ColDkn73oMq5Y9byb6
UI5THj5o2oxN5Q5qPk1ET9mKu8t0WxDle0pW9QkLXUYFA6MHmyF759wHGUsW
Ak2tBXycLqD0f3dnzhF/c1w8tSzNpRv+27V4L71lQfm556p+yTYILw/6rkH6
9/khbxFxowaq47ed+sl7RtQpSPd+LUOIvt63Am3Cuw6RGftKWnDz+r4AUcID
o2qNR2xDarB8LL4qWYNCnPsm18eq71Fp+dp47SR5P/fT/uPjHyCzJMTViezb
faXmC7y+nTiQtzk7aSkb41I59XJ5KeBadvJX+waih9Bi47F/H6FTX6T7iKZg
dIURW5xTi1FTF+EHAhQE7nu3OzAb8fVqWBhnBtG7vpHe/sJG5Kjsbmi1YmFc
ZF8p82A9fOb3HEkqZWEBc3ZJ64VWDAgF3rRZysKpL+75Ec4t0OFK46o6RGGX
UN+iLy1NgG1ANmsv4aO9Rq51o3Xg18ePhL5hHDClHd45fUZRKq9Z+yYW7BtP
7PdNSsAF+7FrneQ+SZWP5+sJtmL1zmfdKwnPmAqkfUjOr4XdLomhiF4aBfm3
g7+mNmFaVfuVSToLxfOFOcvlmbh2+djn+SlyPz36nKLPV8Hi9nWN8UQKwVum
pTcF/g9nF/RHbEwgvPNLOS2w7COox9te9H6h8chLNU/YkIGgmQNvTdVGEXda
3/lLL9Fvyu8YIe5B8FsdmjHTacDtM8+HzI+RfG3JyT6r8j8EOTaEybjQEPEJ
0TWt60LMFaXkrwbDWGX3NGzX9UxsOKBsc43ky15dl/9U1Ajf20lvvyYzAtH9
YtmmM9WQM3C64nuehqDV4fXM9VVoDzV0+v2Wwmr/sE/M7HrYO99f7HyCxmCN
5uB6syZ8a+ftSnpC/DI8XiPXvhx7Gfovd4LC0fa0v81vPmN9qbryy1vDWG4u
aTe8qhrdFfrehSR/T2vuVa84wcRYR8Q7ecIHnSY+QT+OtiFUf3LN8hGS3+Zz
/14WfQshnziveJInOhxfHe8fq8W0VHG9KOnPtjF4JH9bJvh3MecXET6V+fO1
sP5iB34Yizv7yLIgPBtz9e1MOWouCTRykHrDizr0Zdsq8cjthtb2x6Re/nUK
x/3qIfDhsD038UvKz+GHh2glopZJXLx/h4JbelydpM4naJRqhX4KpZFaUT/N
JV+NsizrLX05FMLn3d8d5Gfit4vn9DLC7ye7XRaZJJbhqnp13G2S1zKL7qRE
b3sPrqT76aHfKbiu3rnxnlk+/IdTkqdJ/tmWTqmVpLbglEK27e44GmI9Bho3
nzdhzrK56Iob4bXazLO/YnLgcSypkXmJxqYBsw1fZnLhsTfns+IRGlpttd9G
ijrA/46h22c+jO6o+s2PZWpgc1NW7Cjhc4MdZeZcI6+xbcsRce0lNKoTetXE
Ylpx93nsTEczC5F/xm5nNDZh9FGn1N18wj/hAgHPd9ZiSZzkrBjRe//fmep/
nzPxYEPGGt1FhF94Zj6KrWQidUPbG+6fbJz0tpJzvVsJRxeNIhbRE9Mbqem1
VVjLlaBaqUr2u+HcYV7mUwh9uicnTe5bbPfjg76HiyGnHDLL50byvmR6lLfe
DezXzGm4q0CDkVFm7adRilX/Vlw9SPyXP1HQcyapAhtOjZ6KeE78eO/zrMrG
l1DrzNwXpUIjhD4jqCdWj4/u/+q36VPQdf7sPj1XjRuRPwttSd4NnWIrCNs1
wEPIiOM48YOFh+r5dI+2gk84Z+UDLZrkyIWZmac6IaglFW+xhsbbXllD/pJ2
GFxb9LyVzD9lTrBM73wBXIoFIv/1U8gxq1j+sJLczzm/xR6DpL5FJoJdHvF4
F+OkvpXkA/lds7PqT1twmDMrvF2YDU0RvbJe4XgMLkLeBZI325QUiv3KGbAL
lx5g5A1hVGTWVjC2DQ6cBQHvtxO9/s79fravCmF7J/TYhNf/D+JL/Uo=
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHk41IkbZ9JGp/A4trT0K2xajVIq8qGwJVKZWrTl6nJkKxTWasK0EjmS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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk8lIsexicSKkunU7QcW8rS8im0qPQoQqFsFY66klAJLeKgMZY0FS6h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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lGsUx91WypYtpUWSUrJd1aD8qMm1hBvlJkIlJG03l0iFlKUoshVK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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8lV0bxSVlaCBUpqQSMiWPRIYVmR8iKqFMqTShCU2mIkpSFE8klRAy
ZSaZMzs4xoiEc+5D0kAZe/f76XzYv7Pvva+9rrX+1yZnd8vj7GxsbPZL2Nj+
/5u8sVT278UCmApb9s1uoHB4rcRqAxs6VjjJdNopMbFnYWSZCALxWOOvw7QU
hcRCw9bzDDoe9z25NdjKQELm2XuxvM2Y3+IQ/05gDJsWj3Gyv+6GpeJi4Ipv
FGhb5UpV2JqQrWMinlHORPzW58+TRd7BaWmIR6odhYLNZk7hdXR4qmaH0hYY
6LYLK3YfyoZzGn1IUJFCVzOL3XBfE3JrWy58AgWl53fffZvOxiLvE/WRlRTm
e9SUV9g24bp/tYfjABPndGyckpr7kLJdYfG96Tje310S2CQch8dcyjcVlSnc
ag+vcpPIgY3jwwezgRSu9zwwp3XREDj9SXf3Ogq2xzYW2fJ0INglf3JmJwuh
rJPbV9+nI69k/vXRIAZeOGxrnhHsx+SU2WL802FEyWro027SQHdW+fZRagxH
5MxN9gp+QGTMn86adQz4rfRZ6FQIw5G9mqKFmyicUXro3tjfhMd+1sFDKSwY
ruegfnJWYNmXhMdbPzPx68Wvv5HOnQieX/NH02cUsqffGIWhDec9vgRnmVAQ
ql22pFSpEKWm1d12ZL/QI8ay5WvbsfKZQ7+GyBhqb0SYK07nofyx0+3bc0wE
+Mh9Va1sxHykc091JxPzrqhajPyI7gdxNt3lpN4hdb8ufOmBVEiZCyuPAt9g
7qmvF7IQ/nL137FjFPRKJM+ySfeDJdSoJLaNATa27jMF1kuwM1GgcI58v8zK
uSry2i1YaDikJUpQ4Pi74XYSRy8SJ+0VGptZSHagvQ7qzYVKtvR7XQ0KYW1V
Am0dDZDiuZJ1apaJwfP0Edvd4Xhlk9AVJU2hkfcpw2+gEkcubBqcvc8Ex9ed
xknLPuHVzNzbC7UMSNjWvvQqaoHpTfXyBQEm7iQbWB4W68XgVWOTehoFCal3
/5VufYIlagL3+DdSYKdzGmze1onCrStyTctHwTwbpWDn/Ar7X2lwZIpSCPhp
aVum+wmfRHIyl2SNw+KPsc6eg+novcw9EUvWS+yvH/xXqQ7zU/Uz69ZScDzB
8ytULRBizF6jZVuIfrTMRffVVEJOAds6V1CoHZewjOdtRd31VSe7pyiMhLCd
4BPrwmCSZvGMEgV1RpGkkEMrxDPeB2//wACHS02Hxr0ubL7D2/H7NwsFAh26
xkPhaBHy42yRpPBHvq5I0bES1frfqqNLmfhs+Pu/jEtt0L/QJnjmNQsVN1v5
bcQ6MP1HrziinQmj4tbUqeBWKLcG/TMSwsKgjkJ0j2g97Mevu70k/VJ2SWLS
VbAU+bLGdzfWUPC4+aZQ5d1rDFdsbV5P1tN0f8iqnuqBTHhdhscdJvT8/2Hk
b/+INetcK5b2jaKtd+HET98muPHYyS4MjMKvK6WA/WQ4fq1KFpzaSiHSWK5+
sLQNn1XZo024GNAUNxM/t4SOdOWdiy+OsHD4vLvRoE4mknqfS77ZS0HsSn7m
QbNucO87UTcsTyH8Nc+m1cNZSJNk1JWUEX18vmLt9DIXIavuOPnwUjBiTEQ7
rGoBOzfH0ekTLCx352l95pWFihpNYyNdCqt5M7Zt+ZeOACcXTZdZFsLb3iSW
ub6HUtnMm4U9FLz9Fsbic4shZcQ1b3ac3P9qQM5Xt3ZEl/l39ZSyMJ/yeu+t
hU4cUHxk6qfJgmyYjknp41ZM8gxnF2ymYJ59WW7VbA3qhdPURbdRkPIoYWtg
9IJLJCFiYAcTbEWJKz5XvsWrF5z7a1wpnLV9kn+ssRdXNd7OyqST85ZvnMsr
r8QHxdxBkVMU2PifZ38Ke4WuCK50xk4KB7p8qdXpJVjS+H3wjTsF8dy8cAXS
/1r8SsZzicSPt+w4cPFFN7Z6ydCSSH9m2h4Uz8rKgqO99rHt3BR0r2s1qe3p
RNhtk+mpkyykbX9wc8S4HXf6jJ4++MmE9+WepfUDZfg1K5McRWNALadd7OMw
HQ4ZWk1xwxScGJdmhDzo+L20Soj/GhMsKZ/kBM5eTO7Irj7iwcDxl8ttJCTa
0LtbKkpZhoKzhovuyb39cLe87rynYAQQ/keiqKQPzXudhH/9w0S4DGtmzals
dB1cmabjRO4rqJD78JYtXPNovdKknr/G2XpEjGtw8cXDw4FqFJZ3/TfBdb8V
2TfXt9y7zUJinHZg3ZVqiCirqh5MoKDq1VRQYtAO+xNrJBq5KPSHRvCyeffh
3r3lrqujWSi5r+opuaIGtuZDb7+R984UWL7q0NkGyCT5x+oRP+Q/+Ool82At
xE/McPF+pWDvX+vJTXWhNEjvKpfZMDgYSzee0S+Cr6zIOa4ccv6wEesF8y64
iF2++UyBQvbXjPlW9l6kyW5CytsRJF9IPOcxRINf1drC5T4MDG40WdhWRMNZ
cUlmdhgDBZ9jE7TVWiDs68Jw5aMgvxkMK5d2hKlUKOg9YEHON1frvD8N0fp9
v1y5WOjuFLG2CGzC2Cilf+E/CqVZpuuc9bvQuqrm+3qKnNdgp8AemTbwXfR4
kkXyVNZ41yfO+S5Mu/byfn8+hlGV7TFuee2opXgdX+YxUJ/8ShwBFdA027lD
8jgTLl/Xf1UJy8Cvxn/9aCTv47hadV88pmFEVLtv9wkmRt28fzzlbse3W7el
80eZ6PZ9dOW+fitCd5U2bD1B8uHvH5XbeTWo0V5Iiyin4Gr1KCDGOAuWPmt0
xol/X2ooPCS9sQo0zwOnlFspmB6wloxh+4DJSw3Go6S/7U+bZK31ocHpXuxJ
+m4muM4JW40HF2Lf53nWDcIXfnN/hQ/qXcL5yKBeR6IPv0m2TCm5Fsxaaby7
QvyUTaaI3XTBCOcar0dykPVPstu41TfXI6ic+ZOrjYk5ZttE8+86eKT6OR0o
oHDyIX+0YXMXpD7zmzakjSGzw2bPpq4yFPalOsvqsuAoJW6e5Z2MvqKVK0pW
k+/9VRcyrruGPougqT6y/x61e3v2WbWiJP/QkCQvE+dXWHnkF7zHoUSZZSd5
SL20s9b1cmRiQStD4yjhh7bQZNqLhnaMW2xUqLUbwyTto4XrjTbc2G/kJnCI
Aenyo2UWxr2Qajfk0NNjwmcyZsvqI51Q+/5zmd0iC/JduV86/+tE1CeZGoXj
w/BLnms9yXMeMlWl6ZwkX8/G9crubG/GlPuF9bzpTFStlr+d2VMDkwKHMpEg
oi8Pyv3hiySk9k/FqSwneSwa8rXhXhUiJ1//DCbnzZQWP+y17iNSa9oVkrtZ
MDHvF/m8ux1rF+s51L8R3rD+6aD/rRNHfW81Wo4zITH2483ay2UIsj/OLfyE
1KNzCdPGqQCNMlfuqMUyQfu4NiwlshaZumbH3h+kEJzSGSS4NQ+8iQqWt2KY
yPumwVg+1YaU7GcpVDt5v8M14/ye5Ziftt79dJEB5pk8/9s61fDrCOKI/0R4
0MXv84ncd+CXShHoJ3xAt1F1Mm1oQX6C3ZbyXSxwTX7I3bBQhUMx08fne5l4
l8wf81i8DNOL1tyDZ5iIzFscfvKmChrHv+Vcn2AiNkFybcvHbrgGqh0ftSI8
MNjSnvOoBg4K2cGJJM89n5ZGXmIrR4/2SMmTEApPtuvWjJzux9uYkB++keOg
JU8ECvjR4Cw5unL0PgvTMl7X5px6IW+fuhhI7lO1NPHNZ+NGWMVaD9pHkHpU
rUzTMCPfD7cdX13HRJhy2QeVpA6Ecu99HrGe8LV2loRHahZ+DpxurCH5IREn
pfi9vQFOwyZii6Is8KlPr/i+7TkWAmcbY8UpRKf0fM/x7caSB8Ldy7xGMM+5
8GOdagVMDh6OrQgm76stFiimVYaOtV84+DuY2DK0aUfFdAcMBvQlax4wMHzm
4Q1X8zKktG+ZyLtEoW6D5dz6L9XIcY+7rppDeGDZoNS4SBGE5p7dUSH8HL9u
TcXMt1oIXtS4esKfCbWPA0+sTr1HZreB2AnCHzRWk0Xriz4EU3rGhj/GYLHb
aKrlbSW8x8+EzlQxodg9YvOm4wPULp2lud2mkODjxfFCrhweKV4qze8pHLkW
kME/3I2jPgy+02vGsNJNQv6gRCtir2yInvJmwWND+rkZtXRUOWSFThG/cDxW
7iI8kgKDu588rxK+yPHUmtyS1omGffdGl5YwMa7f3D/n3w6NoRHnGU8WLpTZ
bKR2tIGbfqR9jTPhB6Fctz9NNEgHfHGau8MAX5z3jvzLT8HJ/lCqmMwXmnb7
FY2LP0A99ga3vBHJs0FvTR7lRrjMThklTlAIMmI/0y3TivoE1ZEObRYCMk4/
2fGbjuS8N/3PTxMend+6avmhBIwnWehdI++bk6jcGj3QgCrjy3oThgz8ejTy
iNO6F+w9uS1cXSywmV4sOLmYg3oBSY7tZP4Ztnp0W+ROKzr/TuwMX03yRvPO
qo8NvQjLnJeWEmTAkebALePdjPPtm/yDpykgTylEPbYH7Oo5prLyDEQ3c/N8
nknBWv35o1JrCH+t6+39GF8MTcWMMJdMoj++Z1zRXypR5q7W9O8chd/HvMuS
DLpQ4vcsrVmf+F1QZt5GlT4MJvivslwcxQUdMXM2vmos+xzo8YHoeWKAMe+X
0w3Pt4opewpYqIpa23blaStOn6lrXO1H9GRQl55j0obmDnfeJR3Ef4Zn9Er4
atErWL5M14HMa0HeecUcDTisXCpVmkreM+Dfpv2c6fA29k56TfRPky/8rpia
AaOv8qO8bsQ/cqxvDhhmYaJxrE6P5NuhsxF80jyViPIKrbTfR9ZZXK7LlOpR
H7fdRruEwsqh60uZXpXw1O71jljOQlhEn6FhOB2Wu17+8Tw2BqFYncX1q3Ig
mrxNbUCW6M83j7Hsaxmil+uc0Whh4qrrlQSaUjlmHfT+CpN8n3SL2+lM/n/U
JSBMzYMJf4MqyS9+BbDumtnTXkjOs6LAcIDkbfqwddB39jHEH+LhuWmain1y
u+OOk3xf3+k8oMgoQOVE93ET4r98CkcFmUMxiAt6uX2Y5Im4sqdV9akapOVn
Kff8Q+q/48Ixf7eHKFX0bnhA+n34kvujvTxtqNx5zjdekYHJrCCJEs9iWJ2U
du1RYUI+zMA24HwlFkLepR35woCL+42Svulq3MreOrT7PRMHQnlHvnd0Itf1
xsppG9LfFybmsu7Fo+bW6BEJMq/RE3xFXfN6sTNhZ/uKr4QH5wzPtV6tA1dP
sr96AQMBRftchV7nQ46h5JlL/PKB14uEqGf1WFpsKPCU8LCF8FKvhNeVCGi0
931TzcR9h1Mxw3xk3msWaNrxlYV4V94od60n+O198ogWmbc7lvJI/xXpwvWh
dNZCLcmPiPNOVFQWNDPcMkIJrzMjKp2cVxXB+++i7ZMdpB/j5ZuLBbowcaIq
xjOMzMOZ6sKH1jRjSOtOVHcP6V9KgZKoTkL8ZcfXPoQ39EMuD7za0AZPn9Rz
nxJIXsXuqazbWYQrRWc06NspKJqJ/Uwv7oI21+6orM0s6EYaDC+d6YGw3Nfi
sFEGWk8ZaSlqNkNVP1DJo5qCjKvGyPeQbPStUzlsQ+aPhMT03Cp6HixvvJ04
TPa7eu0379ulA3BsME8cdSF8Y7Q34lUrDW6iQf7ud1nI1N6fatnSj/qNUwa6
4gx46C/wDGUnQ5DjitllwlumieUnTezyYaFTfyvCkOhx4rj1mEk7uOj3Fd3J
/qq8CfGxY22IH5s+1vybicm1nSPfy5qx8k/qSvdDpH6Ct/3ZqyNBresxVRQk
/bMi4abgjmxc3H1TfYjMq3xPpOQO8NZgfdvrddWmTORoi8mVbvwACfEHOmvZ
/u9P/15N9uiBYf6PooVsFqjFfZrcMpVgC1e0PXyfws3V+kfL5ZOQxxfHX0p4
TKKxYcCOoxgXRNxpZ8n50jxla7N/14JuEcwp1s+EW5SgyIjaR5w1K1roHBqD
/cL+R2/6OrBA43F8RfwoNKensU69DpFbrDvN3lGwkOb4fNX0LQ5F0ScaiP6u
xNU6lu9vRXvBxFauIBauSxxZYZnSiXOWegEvNozBc2eqr+SXLPhYGsn/Vaeg
Z5OkGuRYjps2nJfvjZF8uif5JUaZBo+LfY3BccSfd/3WnvH/ACnPhuxfdkw4
zy5dlWbWhW8a267x3BiDWtxp5S1BnXDl/CVe6suCt+yfEc/4j+AqKj8YQvjS
VdW7wP1vAWbLzdq1iR6jdXgWLH+/R1Th0YXdQqT+3muXzLiVINomCqJ3mSi7
3MFZkUH4eH93x4NcFvY4LCS8lr6Ex+ZvI2NJv7nm7joswp8OIZF8wRjS/8FW
Ni5fmnrxSChLbYM+A/FpmRMpifnY8GbRf+tLwoOxUspT6zpR9GDv3dy3JC/U
dsTSte6DOSNis0aE+EXyRvGfN7qRG9dg61Uzgl+i5uZNta/Ar2JoKydM+CnP
K4t/eS2k2CtS/wSQ+SelsPHUjx48/bptA1vEGJrFU/KOivXANDap2SJwDInS
+QU+uq0YbK80VjjLxGkHrkYOlzocy+2+TCkRP1y3vaDkUSG0w4e2HT9NIWSX
eUVKWzEsI8wsvK5SWCxectfIpBWrJkpO8hL/ctzQVvhAKxzeRzROPCT3dczU
cc+NjMLoT+uJU2RelHj3I2Lkcx3sC148OdRDePbeSfHlkVWwj6LbZxM9u/64
HPHJrgLaH/dntyxh4Rn954GzxxqhOa6kKWBB/K2nZquVVi9a4ns1Vtgy4Tpr
uI9PrR0Wu2DzD+HP2A0eie8sekAP9fY1PsjC0D+04i09rZB/sV/43TiZF7Ic
DMLYe+DZq/GNTh+GcJjehimrCkjdo8fN0imoWOYLmSoU4WG/7swfdtJPdpOv
NRldYPt7Q2ZNInlfNn9pOcdMaAqcCrpF9CAx2eMfuqsEq9/Oux0i9zU96lNr
XNQPS4Mwq41jFARMCq5vbm5HXc/K7aUWFCr+i/S60tCFfY6nFidlWbAV/SOt
ENOM/ZtbXW8dZyDxxJulqdyk3w8csEtiUYgSPXQhJKYTEzbbhGzMKbjPXbnc
PEXyesxL9KYWC7/eRr8L6erBvNa8b9N3Mm+8a5p71kbHD+tX1qeWjOF/3JYE
7g==
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk81Akfx0e0K8s8T0KSowgdylE5Eh8Wmx4NilGeVBOFTmVD55O0HXLk
SNkkNscmTK1ydCjHxDDGTGOanNEW63eMK1Rs2nn++L6+f35f38/r/f4sDo7Y
sncWg8E4rpj/b5d9cUuzk8rBPNS+l+4lsESHGXFO2oR7xJdgySiJI5M2G1Te
ilG4se5uiR8F9yn9fhVmPSzXfv6WdpvEo/pXp0jxc/DnBkqHT5FInDFJ3ahU
iyyTvOiRaBLNJ0sddbReomI0+2ftQhIMB02dDR/OoyxYI9fakcC1e11jotF2
bNF2vhquKsfl6SHXnfxnqGWFzTVaSWKkTN9SNVGAmGnOWZ1ACjPVD2ylWS2Q
sDnvk3dREDsnibg38uGvcdjDI5ZAi/f2haxwHt5uyBxreU7ivOuBgHGDJvAs
Ow0/8UjEFhxreKQpxQ17cUJoAA2Gxsodl1J7obudTNA2lWO57C+Jw4AUFmMF
qQe0aKiV7um+GFoJTvbxfZ4EgRPisXcOve0QPI1TarqtuK9jkG/uUgKltFOm
O/8gcEzy7TrvcjPScu6O9dtQqCjP9tr6hxTOtya+XfCmEevBbWPkZCE4faHd
shACjG3Nw1FeWQj4/Nu/ZocR0PafE7krphZ9KvO3s3eT4Kbs/pRwpgX5S9Q3
8edQuD48PbNmfic2pVk2fWdO41q/nG/v3YmxLccnDL/SOKKvLKp51oxm8JSf
bKWQffXW9xFFUjT7qD0sCqfBJwqsPYMqcMJWjRcwSmCTqGG3ZREft5//Kexk
UjhnHyEzMelE4rSx8xMmDe8gjcARgo+xvkBfkTEFG9HrB5upRpR9PDogVeTr
Wff12yXlp2BHaLYHWpFwX2NsU+MmQSmlKfILoZCyNIS3vuYRauLVQs/RBGr1
snXeGzRj6QJzU6NBEvlOF5b8eUSMqiiV4uk2CpLBxs+TakIsMOwLv9pFgvNu
5Ip1qQCZMZF2u+UkrgVv2ne5uhHc7h397mMkbqU8fpeslI/NBkZlqhcVPMWG
jWycKUfAgStkIJOE2K7Vb9mKMpj9kDqVXk+gs0Ct6uBVGXwnb2dxTlFQdbpQ
tEpcCYnmPNF3uiQ0tWyCVLTeomx4WKj+K40kR7/NrXQ7fjy4aOsBAY0Glr7/
h2MS7LM1TaXVaNQE9odmTrViyk8SdsaEgi87RIflWIG8vVs09aQExJV1tz6s
4ULrtVkGV0DgUXDZ1YdxdTj56maN+AoJ56OJ62acuhCz+Rlb4EJjxNDWJtL1
KdKK47s7XEm0ldQ0FNrLYLjKUHW5kMKdfvOK9PJ6WIQXh89UkuhumbzvrdSM
EF+LUEMfBY8Fo0K/E0JU5MxqPW1GIZblmNt2NwcuPfqy/EMEatjreyZ80iF3
Wh7d4E8g84jY48pALbYYl7M74hV+1Fed/93wAqyVD9sJnAj4JwyfyvnahYPz
1cMaWHJw3r7jGpqmgi/KPF/po/jPPGpRcUgFBlc5/j01l8RzXq9b7MEWTJJ6
v/oofE2xLHS6dL8Jvp1JQtc+Ev7MWfKwy2IcWvPzQEcPhWs/+Dq4fRGA1EgI
YntRYHgZzV7U+BJVmt0rz6aQ2P+iVjIU1YNZZwenNEsV/ui69K3PikJRQYeD
ihWBWKs8r6BxPhIP6z/7OEmC6XZn3bHsVygt7ouKoCicTpQ7ZgwJMVS09r6B
B4W+uMdm02ZiKP8S151ST8FfwM8pzKrFnD1fIsIOkEjOk7c45vSg53/bm4kL
NHK36u7//YUESeLZ5b1/Uxgbr7y/x1gC+09Sj3nlFO65RjBVpXWI/Gne6owA
ErJiQUe08BXI1E4l178oRLPNJUdTxRCL7moTnhQ4TCy/3VoKix953hYtBBx4
GQNWu7qQn9t+8WQGjbsx1cO9rGrEi5LbMixIfMtrcDAofo2XJcWrfPNpMEfT
7Le9bEPMvpOtE2tpjNfpfKl4IYWts1ZKIItGyv6B+gmLVnTnrvipdDUFXlZO
pka6CHGlSRdDKimkved+umkuxsjikoK5yRQ8+S4+pnaN0P1vjcN/FH0f1Dy2
gHr+BvleOnN0FX11K1tvZ7CTEN0rK9cxHSg0NAk/3tSTgeuYG704joa7W/ZA
gccbDC0eDg5g0Nhm8WiQzOfhuuvou+hyEjsbWTOLK7twZrJKc38wjcj6rh0j
D2X4xJlZv3GHgnfKatBR9hi/Jee5bVXww4jlnBifWI+peWF8GxMCnKNpx5f0
PkGo8hDHGyQiP2u4u7MqoGfg+KaKQeJwHJHlWd2F5Xc6UlabyHEwZ0XIU+3H
UPIID5Nbk1CXGVizOy+hLlx1YZQLgYfG/x6qSFf4xFeP39tK45cyDUx0PIO6
hd3pZYq8+9oDNrG5mZhfbNaYGkqgmmU8Ujj+AL5JPfHTTQRkRTci/Pa2wzZz
GfVAicbw1AktcYoM4rklXN2HNMSWnZLCxjf4/qXg9QsujYRz916tS5KAqXLd
6spHRX9PnfloFPQGzqVpKy+dpPEPTGPcLA==
       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk01Asbx+eixRZZrriVZOqN0qIo19XX6SoJQ643I7J043aj0I1GKm1v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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lWkYvRpt2ktNZUQlkX1r0M2RLXVlT4ayDF2SIlsxXUuWImWdyhJF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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2kgVX0XxUsSESpJSJlLJaVJ1FJPiTTIg0qSJBHFE8qQTKVUMpWUzAqh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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs8lAkXx90qJKY2idB9aCuljReln8rqIpKkUnqlXCptrpOErHdWVKx7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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk41Isax0VhSkWLJXK7dORxypmiopq+usVVVIaOmyWFLEci0mTJJFqm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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns8lOkbxic698tGshIlCqvk2CaHLlkJSXTYcdqsipzKuXLID7E2VIrI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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lf8bxlFZZWREUoQiqRTJKJdKaWeFFqlUlJIKfZOE0CBZGSmrSEKi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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs01GkYx1G5VzZsU1GKSqXUaCtt+rZJShkkKQpdFBHWPV1W28WEkGYl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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVknk4lIkDxwexSkWSbI1MZJpUjmptOfoWunTpUKlYbCqjEIlKS2pRj40y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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs41PkblVq7P22a0kWSRFcUm4oKRy4TliglFKFCRCorhAipDbHJpVxj
EZJrqBlpMDVEYzBDJBL5SDdJVOr32T/mmWee5/t955zznnPeFc4n9hwVFxMT
S6Cf/779+l+bhMZyMP404qq0PoHbyvRUecMK6GZ/NpXaQKB2wWwNI6MBZm+V
+ytAsLxkwdlRmy4sGw3540EAQcjWU1NbTW7jDevd/JVrCGITXSZ3FNzCPdvD
AbJrCRh1VkW/RrIx0N2y9uZWgsDpTWLjri2QW9rnu2gPgVh5YvUhW38czMOh
tYoEPvKJkmd0nmF41ciP5xyC4uWDa7pP8xBVLHX0vQV9/oFRtYrMDYwXhYvu
KhGk3Xn6UjeEh6QTigwGxf9C59rZzCQBVDgZykJrAgUnxuvr/Fb8/tMsPdGW
oIq19uHVpirUWtxnaaoQ6Flk3POPvw3D4feNzesIcmSaPVabCFGVOMAcvUbn
GXPedfgJkNfrZ+bkSvFMkP2q++8jve6v1otbCCy+waM8uA67WfPK6vQIZg9+
ZD0x5MF7h+LWdAOqR8H4RJj4bbwz/+34BarPUPr8VCanBatx1G/OPoLKVYl2
wfP4aLyaUvzyGIGx5XvvyrBH+Ol3zPOtJYF3d5LShtxOyEv/U3kqmUDeLMR+
6fF2GGjnTpuepHqZGvUmObVgY3Jlk9IRuo9Xc+UML7WCPUgac84RqEfu7l/A
5kPgsMi+1J4gIzSvoMS2GX/ey40dcyQYM5DYcshGiDf8Jxm8AoKWVh3XIKlu
ZGcP2b1gU71V2WOvrW7iG5HlSa6k/HofHR8v5WHuYim1XCuC2pXPwwovleLU
Y7njnlS/zr3ngsrZD1Aq7LB2UyOYnIwNT+HXo2LyU+AZYwKZb9eqZ1+vRAPX
8F8b6q8/HDAjPlsEX69og3R/AocEi6MusVwMhO35c6YRQb2FPjfpWD1ClFOV
VTUJQn/wsvuD+djol5Lp4kJwqmbf4FfbHqjVhfruaCYolBWknr3eAMdlGge/
alH80dqs6eXRMM/5wL9K/XWmx+6zBbMSuxmh7CGKT/CRuYG1i4/prM3bP54i
6OPHJdxRL0Fcd0VyAOXzs6zWfNsXEWa0FnkIfQhszptMeYoqYaqz/pOmKsFa
h+/5cl/qkHDUVm8Tk8CLYS/y8RbgXqwLxzOCQELCeea9KC58KwJKLbbT/b1a
xXsVU4OY/oacMIpvTekdj/kuOSi+0jUnYRWBo/1IxbOpOljWtkfso3kbq34b
FUn42LbabP0k3fczSZ6QNdiOnPa2UCTS58uNz9jIpqHwZ/bILrofham6+ydk
WiF+4Y20pi9BVMa4kvAXAYwZX+qC6Pu9djGp8nP4SHJwdNXwJHAOsdM8lJmM
r+ems6VpnuzqJxyv6Xcgt3KWmm08wbDPpxz1qGaIp7ifr9pJ/bVfson5/ia2
6rnV9NH/Eyw/uPh9jRAjuqLHGqepf/XZqjFXWlCkPnTH5U+CpG/SZx+8YMOO
fd4rTp3gc/gso1SpHnh+sfaq+psgRXFB9nBYA347vWggWIfge57s3kCVFijE
Rs/Uo36WqavXfqxQhuVmB8W/0X08ixVYNjq1Q9Kn8OpzDwL7EOsb3TUd0FVT
LNGlfPwiMwRVTe04+fsXjXA3gqzS/sXRnA5kJ+/YteosQbzlyUSjrCawUtbo
jVM+VZlmKx4uFeByzI/v76g+Wm5GnnJdj6C/n6W2RJdgi/PqJXKnG9Ejwwky
pH7vQ0vbW+uncPLvC+XRPgiXlPEUN2qFypiPrIQfwV27ZuNHjiKkBHVt2JZG
+W1f9PfEiodoze+ZPkfnZVRc/ldGkw+bqb2G1Seof6ICh2/EdqFv2CTGrYYg
r2jKNdPvIZjzNjq4bKT5NpCPq5Z8jNlNRfkD//WBUuamYLNyvCJHurTWUzwX
zrwILe3Eitgt3zzzaf4M/S1IcSmsPzU55dB+894YaHZ5qh6DVxamjdK+at+3
PWL2i3ool89ry6J6az9Z5q9zQoQVV+R3RufQvA7bbPPQK4ZWr/h4Fe2r8oi4
9ZN5T2huN39fc4j2pZXErJCoeHhz5cuXUr/IVL2+v2dVNtIYBir5qwnW2WfV
3mx5hpUTEXEvY2levNqbmLvq4ed6eTaD9mPw1h4d7QY2ylSN9yptIrB+yw0e
mSOAhNjSJIWDBL8PMEODZnTBtDhE2amI3qPgvmVaH9px62nDrUvUj94jK5tH
e+ORXM3w5dI8F425uB3ezIWKl1e6Ls3f8nUeMdkmTyCuWl1x9gDtX7OxjtgL
NXDaXr1g7jbqX3fnQuejnWgUXfrRVUr1tdK+Ltp0F7pP/d3MqT+ZI/Ny/zrc
Rv034ZAWSfGNLvRX6u/Evc2Kyb/QPtS29ZmRsKQHe3fvPJH/D52/qL1vXUUM
PkirDjdQPKrjzcvGwtsgEW3o3XaJ4H8+u5irDTvwXWT+KSCQoNHoHxnOQA+k
Lp/KMBERjJ+LqOcONcI9yPeuDO27DyYDHB0hD497PRy32BAc0Uv4ZXB3MSRd
K4+X0X0EWCVXjmi0IV7rOZNH+Slw1xVD6Rauhy0xfkX7Q/hJeYerPx9NtZG1
J+m9+/5jcjr4oxCNHGV33xB6v1oV45JZBSj7KXFpBp0nayDqlTYVgLW4f4nW
YYIF0a5cr95HeDUtdJSg+9JLEx2PjOlGo8R5ZctK2sczCxTmNzQhcMNOJ2c7
mm/pL0ExqSJ8/eHlsLmM4KKGWPyoOBvWmi71ttRv/NfeDVkZTTjQW6Ky14Hq
r5Z3W7e/GuEmmxgxGgQ7Z7sfaIlrRbltau8Syjc8JdRyjrMQbP2QR+703jnK
7y97XshCnGpWfR+dl2RAHO7W5sLqTmTPEOU7NPF5nKnCR83pF88zvQnkHNSX
mie0oGV9ftEE7Qd+vKuFeFMj+NMM80iq10W/kl+vGnHhXTA2I4r6xZG3+Vgj
rwC2Nmo6GtS/ge8WTnWad2LMfcX1hkKKN+Akm8PuBNO0uGxRHv19eOQQV70L
UnO3PC2hfdLjom6eUPsEFo9vXKyi91SPo++89rAIEht2B1+k+/8/TAO8lw==

       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k4lG0bpiypNwlv4RVCklSiRZZO0aJQSKIkiaJSkiUlkaVCCBVSSRRl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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHs41AkXllQiSZNqJ0pFiG2sJN28FNFFhEqFbipZIlvr0kzqG5awK5ek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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs41AkXx2exUqHRjSQhZbeyKFoVvrVpFkXILZWKLhQGrVCyI0uyVGTK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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs4lOkfxpGSpIRliZakpJTDpHaW7g5EqBxL61QitXIosrId1ZJkS1sq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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lt8fxpEGRUKSrCghIZGUXNJQNIRKZVVIyMrXLlrSIKJSUVQayMpK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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlH041GkXx2VNPSkZlcdUZDSS3uRliFW+JXrxmtekbEhMm4gkCVtttaVC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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81Ikbx8dR2c7hlSIqVlklP4qSko8zJLs5VyUJHX4VQ1JjN2m1jEQ2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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4FOoXnqIi41rrqpBQqKhuaCw5RCUUt8bSgkISWSpbZMlSEl2pRvFz
yTIkZakkhMaSLcYY+5AifKUSLlL4nf6YZ57v+eac75z3fc97ZoOD5+HTSykU
CgM/v79za88+3ezPgbTyOJ0MBwKXKwdM1Yub4dsF1ub7fxMY3xTsMRDrB5Mp
eso0eQIufbKbtJ51wMs91jK+OQT4lz83+KOkHqgqYewaa4yXleks0aoFurGW
pu8eAqzGK97BfTlA8afOJikTiNo8JNFsVwWrGQXZYvsJGMtF/EyezwOL5ubt
Sngvs7KnmCnXBrf0Xj25Z0vgn6SFvRtn2GBWV1FRZkNA37Fw915mLtxiyIv2
bCJAWS1WffSPFtB0KWR2nSZA98m3mOe1QtGPG9EmPgS4z0TWJLg0wHeJrOJp
fQLFvP88GsQqQY1h8Ou8DoE6uijv0q4aMBfrHv2fFuZf89Qi6UYOJAnslo7G
/KE/aRFcgSwQ1vhCHfx97rt+Lk4qGQ4zmtKyFQh0PXG9WjD1FKZrb79Q2UZA
MkR/37JAFvylGQoXMX+I+01B1+Y2kLipnV7lSYDxwf8PTVoKUMKkvMcUCchV
7fBe01kFtbT2JS27CNDC100oF78BHs9Mz9iEwNheYuuS2gmdAhwjkkEgly1l
/sihBTryZtkb8f4e/7k3SVlt0OPXuUf2GoG0VtVIlgcHNK7Pmc+eJOCv/73b
pasHPiVqGW4tJzBw0CHmUzQXvt12zfSII2Ahebve7nA2OC26OaZvJCBqdced
z6cFaFNj1uQEAYXxSfn3gxw4I677U9cR+XSpFtvU3AvbTuTvHbhCQCr0WYpN
fQeUDjMrHVMQz8uf7UIOvAQr05qJpu0Eqq0fHFt2hwXn3ZbNHNVD/Do6WK19
jSDJFDh9HfNXLk5+DtN1hwtFhkxJ1Ff2h0HVyasvgCr3fmJhKwHpkQ4QkqoA
07ruo1U7EN/gyF3Dj5pAT2HWQPAU5rux7eKRhB7gpK+6VlqGeNoHyoq84ECP
sbiPAfY/TVt+cc68G7yGAv+VCCZQFDliEzDDgsp/LQL0EO+4wbycSaEmqA6W
SuJhPdW0ELWg5fWQ7VYQamVAwGznW3ph8UvwMJ+gUjUJ6Fy1D1I6WQ11r57K
BmG8fkhX4J8n2KBzKOgpzRzxCOJqTmk/Ax1tiZ2BqljPpFW9eMpdSBzdkLgb
9ZJIn+K+o7+BmIRb0fGHML5pi/qTDf9A5cGFNUXY/5RaOK2RyYHZ90xrBcS7
iCkxam2UAQfmKDdiUX+jW3k78p3r4InuclYuHfMLfliMXZUCa4XSHtzF/BmZ
FzLbjr0E7U+mRqE7kc+zbge/ZvdDnrzkTMJH7FfNvG8sKx2+at288xH1V632
cN/9Xz0grJYXwkzH98fFnhsV1kPOYNKd7qMEBJwubK1Vbwd27mNZwUR8T2NE
sD+tCfhGZcx2WxCwsf+ac8CQA+7x2S2fPbB/jv9G0YdVMBpR2UtD/AzTLC0/
9nBA966RXbvH73qney4vLYJBRUF/QH7njnty/DRrQCPFr+Qw4mmnPnau/wsX
ek+3kUvxBHaDitWXV71w3qth/+JDnF+2xMMj6+qgb794w25d9B+Gk4N2DAf4
lR8vWuH8K+/fk7koVAj9NaVxHSrIf5T/yE/KW/iw6nHjSkv0C2uf1/oh5WCx
JSs3URvPm9oqfpwtBr0xl8nHiFe31XvXTCEuDNhKFFu5EPB1l/NIONUKYefk
65T8cV5GRL5c7eLA/PTQkrkIjM/vMwtnXYESK+ssm9/61VsW1OzJgvGA61X7
1LG+DTF5iWKNwNU2MHVCf/TO8gq8tbId4r/Z/+TzImBi5SwqHsmDjtKTfOsQ
3ymhecOId5VgPDK8ahz9wytYOq6q5A0kJftuNDmC8+vWc4b7sR1ODIwv5GcS
0FYhP22UW8BIRvUrP/ZvlJUksLCQCpGLwuOZyK9AqyddIbQVpP38nS67Ih6B
pUwVWy70MX2SY67j/AXo3DBa1waDAzN+fmfQT0Z+DDFVHoG6Q98DJdSbqLDv
ksItnSDgkCHKCcT7PVclZFbUgvFcYEWpIfarbr5BObEbDHxybQ2vEkhds9Ke
svYFNMV6KB7Ced3uGLFP058NY8Hlm0+gf4cGng3QlksGyZrYnPVY33Tv67B5
yxp4NCaYIYx68d7a1EWJYoOvMG8iCedJTef+fj8vDuRdUhO9F07g75vXey01
uMD79SkrBvnwoj9qW61RDpTt6yOM8b34MluDgtYikKSoZrzfgvxM8wIKDrtA
h2y0JhX56VVyHnhAbYOA/4Ky5Z2wHwdGoyajBcIehNy5hnrnLZnsdftWA8FR
peJRpqgHm6htObKZMBluyt+G/njv9ujZ4YgGWOroOvsaf9+13unY3T/ZoO0y
s1wd+cyOHPEXEWQBy2KpAj/qOdV9Jl5BugB22kbE0HG/UdfmCWfn1IDXzs8R
Z9C/+yt+pH55XgmWcx/L3uD+YU8WMB64sKC9+SIRw/jNkmKKzBIusN45iose
J/CVQv8V5v0GvNQCKJa4zxgC1nvtZd+CVya9qvsYAecVNz4uoP8zBET4G5Gv
iuEVykvHOGAf4pBOdcb5mKZ+KZ9vhJKDZa+Oo98ph0hFSX+thpTQu58XaFjv
w9fTzX/dB3H+5xrqir/3w6sOFR82sFboL1XEfr1/NdNF1naC1UW5qvXJeG8i
4p9GOHDuvHeOD+rnZsYyE7PTrRDkqtQ4j/v3nMys1WX7CvD+7nxgCP3TZEn6
cN6FLpjzTXEdYyA/7zzqlX5x4FONHJNmRyDfz2PThf4OKO5iHpRmYv5Q1fne
7VkQqvE8PB/16KYwXPF+pho0z2+dKES9eAXIiVDNHkH0sZGanYjvwVNdIdRE
DkRIxg7IYb1yRUPr2rtTwDc8gGeH/YhO1ealJzyDVPopB0/c11Kpx1VzwxtA
nZtTddSYwATfwlquVDtMeW5hH8f/Q+t/7AusbeXC3OmsM6ewvxUWTxq00rgg
7PZ0VBzxpXz4vqgbdxHKaqLXb0B9ndwrP/nDMBIO3R7iC8Dz/wHq3KZI
       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lG0bxtEqRKWShErqLSRtlJyFigiVRCIpkra3LAlFlFRSCNkVSpJ9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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lAsXx11rSSlxEclUN90sKbJU+ml534Q2KWZIknJLljbiluwp3ZoW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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHlYzAsXx0f0Std6heJqIS0aRV1p45tKi0S0aiFctNfFpSKKUjIqLSRL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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs41HkbxicqZFepXqfNS1LRhnKKqDuymy1RYhyKSFJKB+lAKqV6lW0v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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3dcze0fxosQxROKNIyKJ0RRkpIrCSEJRULDyCqSEA0VLZJKU9EQWk+7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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHk01IsflchSSjslpsUSktKjLO8qJUWSlifqKWnQsxQqPZIkJru8ymR5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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk3k81Ikbx0fajlV2RkUNWpKyLWHUph/1aTdXIXJMlJZsihQ1Ua5Cp0Sm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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4ldkfV4mKEoO0mbpE9nVkmz6SIiFuipSfG8kwqilbRYXsWmhjohIV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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8le0bR5KkQSJJIZVViUjWl0hkpEi9Klmh0kKhVCplpKIor4zMhpE9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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs8lGkbx+elqHdVvKXXpx2HVMNIoqQ35Bc6IEWSVSYrNhG2SG0OeYmK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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGk41AsbxmUJJVSWqYSO1iMhlMTck5pOJAmlLCklCo0UzYlQJ6FyjqXS
m52SvCQtdudMljZpZowxaMSs/79KkXRI5fV+eK7n63Nf9+/3LAlguAcqKigo
MKfn/5vy9ci9oTf3QWFcirjlRSKi5pcV2zx5qLDRs2AYyUCb3MvSO9yOyIXn
rPgH5FhtYmdS1caCgE1SGJUENNxSviCtE9+eLI37ViWGdiP5cqyMB6bBXttV
hyRw2Nq9hRnVi5Hc3Z1zlEQ4KyrqY/dzkRfvUjZjlQysFW/KqiW10DUJnNh5
k0D4bfWivZQb8JqdHxLTR+JqVJzzYjs+NDpsMs7VSpC9LNPHM7kZl6udF5pt
IfCZsDqsYtCHFkPG3DALCRqGrzgNt/Ti2G+h+zbHDWC88XTBp9EK7N5h9P2z
M4kFbxICs+Z1Y2xwl6bDNjGOMC6tPp/AQY2yXgwrQ4okgZZGk90DFNf/9czH
gYT9hpnXE990oKVQ4dh+PRmcV7T9q3eHj+wUalsdXYaMXkclwX87cPQ/uuuL
myQ4eqL6CmH7AuzmrOyiSDmIn6HmaZ1spAbrmvgJZVjJfzSnfpwPz1SX8ayd
Uuis2PFj4zwuaslr9/wspHALfxbtNOs2+HUuxjlpJHLFf8ap/2xFDDOKbrSJ
wAG66jrFH49gprJoZSGfgG1bmF0qrRVBS4Id1sjlUOgL+uvDybtQtQ7x+5hO
Tucgt17wacKFwfDEt9oEjMsPxLkF9WKNQ5WWvHIAlnItvn4pF9/9j29OXyRD
9vxojlfIIwgrS0IcxwjkJ5RTA8evozyZ0Dn1loR7lGF6bkgHXntcSNyrIUVM
8GTsRFArlJSGim8+lkNnYsnkYh8e7F8atfrSJPh5z9vVmNuJzPXmx8gKMVIM
mXk0Hg/zNul8ciqWwJwv5z12acKQMMis9xCBP9n21H7GG/yIG64Z3iFBao3f
b7NMeRjdFUU28CSg9Hs4HpwS4nniyGN5aT+Ctfqa+uw4MLyqyPryToqWQUq1
P7sYF3aebFx2j4QGu0S1M+oRBk5nD6SNEBh2cc/tD3uGfkdRQWrnNH+F9Cfe
9QmQTl7u0lEehFuTVfWtLB7qvy2nO6yVgFYqnk0raIc6C/dfDUpRojHrzgLb
Xlimp/jdeCVBfL4gwjmvBFXR7OPS6yTs3kc3lDJ7UOl5jjH/lAipl5PCWzru
wNarZqI9msSRx0sznIx6kHR3QifaXwSLiA4v6yOPkW7JydFbRuLFRl8Nur0A
Hz1CyzUDpDD+d6xQMrcU2usFnc5MEpq5rzmhNzhwLLLINTCWoyjNQrDpOAfu
1/I+dV6RwvquJJy6/DU+O2WampXLEGP1oaBgczNWPhD4T3kQoA4djLWZbIYG
J2lt9oAcxpayj3t6qgB6pvrUAhITdtobYqv+htoTxfpdWwkoCm/rC7a8xEOb
U51PmmUwYBy/myxqRc16w6xJCoFtZbeKV85ow9OVoxTd+zK8TltuevI8Byf2
VDheU5Fje3Kfa9G1Hni/m6FeEynGuId+ttWuHtjTWLRlXwcwwMxqjVlXjO7t
ilOCQhLCGJXCtq9cyFss51jXy/A8UHXHVc12vK0z3bKYkE33P3dL7fYuKCvp
rolMEuNihsbojNhOpIQz6EdEYqjNajJyaX2AHZUlai6HSCjMmV3PEeZg5/ua
DzwuiUXyE+5mbh0wUF98+4uiDGO6C3+eWd2J2KNp5rF2EpTWDBvoy7qQzAqj
CkdFiD9bLB2f2YGuBvdB5j8SCBPfhdXktOFiRXJOpsf0fd+/d21r4OJzqLLQ
66oEx5UD4m/8XoKpzzZeT8+SsL2hSxu/1AxfL12npRly0MZPp+/NrIJLoE+8
7RSBWbar8m/eF4DZNFTorS9Gy8hYsPnHF5D7yrwjT8sR/Gv2L0lyHg4aZnwt
MJBggBbhRVViYcTAKCTTZ9rn4ozKNfsqcXjDF8FrWxKvwro5Bkd7kHfnVEyt
qwjGjVpljtwCeIomnb+XkbhNKbbwVOHiHNWXYqIuBX1XI8/Eqw9be/y890ne
ovtA9wqPiefQ/sNI9WKiHOm/nqeX5Pci1TqoaqJhAC4qq0xVDZ6jPUdwL0lL
Drk14wyV5IJLnjH1F0hgrD03WT+SDXaEdnWrpgz2rikvzkY24pubWgcRRqDa
180Y6vWwzr8fGnGVQNT29heHY/mIPXjluowtBavceahMqwuOhFLGyYdSxI/f
SWJN+/f04qElz4RSBHpqee5pL4P3QsM6i3gSZwKu/zGoJsCx7JCHLq5iXKCv
7VKU5cLMJpT5tJXEB26ga8eeOpxX0xjQrpj+l1V3KcTZ5+jNU9NtKpBjaduZ
W8+C2rEnwSpAe44MM7X2V5zU4UEzIEd7tbIUtIPvFcx39+J8SwJl2QIRSvxp
0SN1FZjvufHrxWm+srreHxJY8ZCjgYhKGwlsTlF71lnywP9bXEKd5sFO0/vT
ZQYfk5cZXY72MpToxqsZDdZi/+j8/S4FBP4HhRu+2g==
       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs8lNkbt7OSlBZFpdINIUKY+mX0dYmkm4TcKrKmJCG7NZQhymIrXW1u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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8VW0bxUVpkFIopUQJUUIqaVhSKUOUzJVkqmgOIURpRCQiJPNUmUKm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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41GsbxyUl9fLW4ZROKlSWQtI4EfVFi2SJUYhy7DSNVlHeplApHIyl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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk41YsWlaGjbjJFplceKipDkkLd5b5HN5LkXjeiwTw0XL1UMpRcqZQo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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns8lGkbdmg3fYkOm4x8aYukVMLmlL1SQmtMklRSaycmiYjaFFtySCI5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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4Ve0XFVKhkqRJaNSg8kVCw0JIMiVjKElIoSiiyRcJDVT4KFNIMmWe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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlX04lIkaxq3kIyVJNSyyQhHa7ZrSEW7UliRJhS1p+iCcaCXSymQ5lcXK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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGk41AsbxgeVIs6oVIM6dVpOpJNE9NbrFoU2HEo5Mc1Qk1ORilIJuWzJ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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnlcjVkYx1PRMFETYkwqodIiXSM1Lb8sFUkk0aJSkUKLtJC0KUSaSokm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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lG0bxqWQ5S0KpU2WJHuS/e0UicqWFqJFmrIvlSIiO2l5tYhKUmmz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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHlczPkfx9OtpcmKQu1qlRZJIRXlFakmbGWUsKiHyuasRsiRTTp0oXOV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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk81AkbV0lecqulbKQSRTYk2vK1WUJqM6akZHVMpMOxrsKmRIZsUW9F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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk81Okft7Y2IlR+jqVzM6GTUnK9xUZpxCJHGSVHpYjsItocUY4tVIaE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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k4VWsbx1WoJKQyRYWSKCHJKfVXcaIyVKJSmkynzFSGFJWidKKEQoQi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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs41AkXx91LmEKxU7PSTVO9qVxzWV/d0bTojWcrbYqQhMqbKaum8npT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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81AkfxyeDEJuorZXsUE+xq9QmuvQRElFEq1LbISrFJtuyDSoUkodJ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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns41OkXtxK1Yf1a24okly25NWlRunyqh0IRWpfEjxUi1q2i3+oiqayd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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Ve8XxYlKIyKhASXR8CUkSS2kUkmSZqFCSoZKhVAUkUJRyVyZy5CM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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHtYzGkbx6ckoaKYmHUok+gwKlk5lW9jsek8pEirNpRIYYV1zO40ckgh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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk41AsXx90ukTZkaU+0ShqKJHxb3NKt1KUaFcpOmSG8mlSi283+pozb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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk4lekbx6WUKVsz1GilJEwhyZ5vSoUmyZ6MkKU9nSRCspsWy2GkrMnW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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4lO3bjijRpoRKopBStiQtnCptUilCeYlUWryWyhIlxVu0qsiS0GL7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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHk41PsbnbTccpMkoqi5SvYiirrlyFKSW5EWkUr0JK3q6tqXhIRG1nKT
NWvSJY0lM2F+Mxj7Pta6bprP92va7pO0/ub+8T7nn/d5znPOe97zi/sFR08Z
BoPxh3T+w7euVklmZoNYGrFvtgVjCkEnWPuOO/ag1LlzQJRHYUwyrpjWO4Lg
Eps5uS00hg8n02kn/wfDd2Mpd6oIMpc0LC81LMSC7fKs5FIx+KFKaX0/NcBk
OPecbg1B5RUXTWf9Tlz8scQ0jk9Bpe9mtPcPDpg5Xlp7nQliUtfYPh3rQOBf
cU/YNyjUt5sWONcKYV9gxu3ZJ933+5qqqcTBg4dZB5sPE7CKtGs33a2DmwFL
ebclgb5uXrzhMiEmFm5TK1tBweKsiucNu3L84zYx9m5QDKckl/RrDC7M2nS1
S/cTTHq8W7qhewC6+hlrXmrQYMSVeWu1C6GrwchZO5+CRwBj8fCVVvht2pi4
UZ5CtJl70fe2QZTOQv3mBVM4rtdy71t2Pljj9z99zxIjo+D+No0Tw4gf8S6z
dp7CyUxf+9/d+fjclnfLr4Bg7XubnuC+SsSwD0nYiwlyX2hdP2GVC9fmkna5
m2LEyym4RW7uA3Pz6mfjUxQsX0WwHPiPQc1wv7kNiGH4HK/tH1TgVf/hobD3
YoQW/sN2jU/HfkNRvK63GOpJNXqjkV3wDT+7yW01BfOjuvs+kF5YL1ZRWOdN
Y5qjpLDPqh7dpQ8f7LhOELjR2bTMvBOuKYpGNnUURH+unfd+pAMaJe7+RT4U
UtwuHZI91INQ48nt14xo6Id7eaml1uNLlLX6WCoBfeRT82kBHzsOKOiNCAjG
pxMO5OR1YdtklSxTm0aggh5fcr8BNXndEyoVBE6LBQETsgK8Wxqn1CkhUCmy
MTBRbsSjlFu2BXcI0pCwcr8cC330Q96ZXWIYF0dtz77dhWoe6zenKAq+/BuX
AztbMJHIv35Qk4Laup+cmoJ4+NfHJHh2PYFPjyN/9tgQRBeTQ4uqaNSu8a62
kxnAvPWDFYOfKNjGyx4/2C1AjOKpgDo9CrVe0W9y3tTiz3bfqx93EPxBiisc
5rBh/0Eg2yZP0G78qPqZhIvMJ70c1T0EVRqFxdUjQ1inmqbkNETD49kHtfAz
vfjB5HVu+0ChQ3Cp4dssESpjqhIuHKJht3zUbnN1C/Y3NJrW5Ej1Z0U6cufV
Y9SsdNFNFkH5/XT3JdZCzEm2EygaUSjYuZLyUGXjzNuqrA+LpH78/KKYF8YF
ubzIwOU8QXSbXWdJZSVy1C8o+coSME4rnlPdXQh/E+b8qSQx2E2lo+uj2+B9
ickxcKFgF+JgrpXWiIjaFmXLJgJ2z7zW9OpKjNnKxw4sIRjY9KLN4ks/2nZI
jqpL8xEY1C8Xpc3D30ttV9u9IqhInYpK+KsTys21b3Q9Kbz/eMwz8toYlkuM
9TZY0XA68Lxj76xhlB8I0wyTmQLr64jkTRYXoWuUvpVlEehkv+6YpLrxMmxh
xI1pCiELzRM0rYZxr7r8qOiz9N+oy4k69meR1hLz8YyeGNynieqf+lMgo/My
zMNNDInWzRAnHRFYL4vKuo/QqLvjpxPo1w9GWqF9SSKNtxEtAfrp+VCL89J1
kupf1FNRRkJ6oS3LNBmXo+G6oHm+pXMjttrd+Xo3X+pXU0f2UMYF+DQnpZrq
ixE4ZsQ9VtkAg3iPjx4XCc6uDJl4v6oVQs+IVeMHKeQueXZLvakbdVdczs14
U+jZ8/lLfn49HMfXV/0eQBDx+XT1SUMRVm1l98fzaCRl77Iuc21Bho1PUqMi
hVV5DIXcBx1ozt1bPJNB4a5j1VGfM33wYj+/zDSksdb/2Yr8WV2gT75YxmPS
uNrn56v0TgiB59Tqu1I+wd8OEwO5TxG6t5/z8zyCWC4n88isRoTPzISklxGc
4Ki3mk+1oSTo8wNuFoWyri3TW71LYL0rZiW/UIytVyKXn/rahFjKX8VHlkJa
sCTgguUQiF1C+1w3GgFkAVPvGA+bXy8wTb9NECoxmjRwvIwT9gZRIevEOP9L
YPzuVUP4IlOp/DCSRoFCvXFwCAcbwmfbPNEkcF/X3R7c0IFM157T/knSvr16
XDFzIBok9sl0l4UYkVuS25X9eqHqZshZtoKGdcTJtaMW7TC/q+pw9hqFK1lG
JiapvaBPGWtN2tK4veKYt7ZKJ7r8fpObSafwtW+ZOJwehGVFpL1LAI3erT2Z
H02GMBJ3ONn6PI1jnOmdv27ho67+bZ98JsHqH+Z3hNcFiJ0rzGTHE8xXrRlU
ycjD0u9q6XNuiXEEnmMt8p0or2vUyX1CocFmT+aP8gbom6wfrQiU3nNDq6Ow
RIRsmV/v7dCn8Z29+2i9UIQbGY8tEk2mkBsreuwgroFGevEiLT2Cw1Ey3P2m
rYgOSmleyJT2i+SpyrhlL3Sec3of/SHN9+K5MbURffh3pzBK5EVj+UTUNbNb
fVgx6DG+ZxsNnswhSVApD8b+lVYjzwn+D+eszac=
       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs41AkXx0V2pEQlq+zmVtJu7pJ0+VoV1uOVxi26kGtF2iTXSqVs9WZj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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8ldkbv92pRpOmRoliSmUQRdaxDN8SMrckhIqKum3G77ZYUtFGWZpy
LUlG1lAhl8pOZLu24l7b1dWvjO1EEopKzOmP9/N+3s97znme57s8z1l14Ljt
ISaDwYiiz/e3gpmhauScTuywVxL8Xksw4PhxopongCwr4LzWBYLRM4xOnbIm
OGkvm3/8JP1vd2rgRXwtZk0oLC3fThBbGCbIqeYjpC/fQ28zQYOSUE5oUoLt
8hVCbQ0CBmuErXY1DIf9pe/NW0MgOePSqlVcjcfr/70SvI2g4seBTndHETyz
8p6/Pk2Q8WuRNu9SC/h6UW/72QS37956I1Ksgg4rVU3BhKDw2FJHG2YFJmdJ
einqEvioqp3YyalFePNsl30WBIv2jckc8CiGxFoV9zAaX4+jqPU+uRxD+09h
1UaCbS4NVwt62qDDXS6o/4vgRNpZcYRfHla0m52W3EAQbRavZmvShjeLRYWe
MQS+uU3WnxY0wjfy9zBrVwJLvZOGxFIA5iung3WXCMqSZvi3pe7DO9/Xqk+Z
QL/7hmtidi1WpK5NXu1AsKFvzoGHV6vR94Cj7GVNUDkR6ru1sR5p6w9Vvt1L
kOInk21yqgKZ3OxPK/8gCJKUHmMdqgJL5Qs7/U+C1o/sVy43xOA0zkysv0fQ
Umbjl+FTg5zVK1eaGhO4RT9h9LxugISs8cBeK4LHZzSitP+sw6Ca7C8O9Dwj
Ne3x8UcdOP024t2ufwgcXAcZ9c4CuF6LC+XSfLqt6oZlWtowzLxZvpfyy7dI
HeY3pKLUq/9l0fd6/nmxjetbCIO/f7tSqE6gsslhuJ1UoTZtjU0PzU/lZr1X
kKsYKkGJtb8LKH4JMSP2dx5gVkzZyKAKjefO5I0xOjHyqOmUVzLBxjcFe8+W
pmCuPONkpxLB6+2FVbZ7osHOGst/T/Xx9rpp9E+xNZjDWfyODwKFbbJ1hinF
sBU1iNJ1KH7HDjL8k6vwPGTuBXUWAWezr6L/YAOOeF/HGOX/4lRz0IeIGER9
jTb6QM87XJv/0iJPiEMWHvXLzhI0H586YNX8EqGMvs7w+3T9+ZU77XQTENDY
4vCzIoHEtpvrLHKewqK4iNNlROBapWa9autzzKnr9ji0n6D0YW6KVUcjJLWl
f5rlRPe/Hw+p6b6OyQIVmXOrCda1+OvZt/GxOs2xIIvi07vYTzDuLEKuz2C8
fwD1R46Tu5KREEdsxbP3B1G8xgonQ7s6wCvLP1ccTiA3lAf9X1ogL8dvl3Ij
cMqdIxV1VACjr4nypR4EWkWFu+OZCfjNVPN2Gq0vzLX31QqKr/iSvEy0H4Gt
WYeZHF0vMFgUE3WC6in5hv+AhgiRWiJWxkWCXZkex4QBz/D1c97GV9oE+eeu
miY9eYCFacfiz1G+Jk+bimda63AidZ216W4C7afS6cXpAiyTm30p6DLBfecX
zvpZ7XAu2Rm80JtAXHZhsiywFiH3B8O4dgTyuiOO/4Q3IrPvm1ML9e/6xO74
+OutWKTfYGXMof6Uv+YypZGC5fftLvdT/hO85WrszCMRuchjYC6tx2vpSLWy
vQh/5B8fOEb1zpvvlbRVk4ce5qFdkTS/DV7dwVcNciGIXjfyQI3gt6cDjD3X
+ODyPF7Op/yPOyjsMdtUCU6a/plPZgQ684bdF6VmQ/1KtPcVup9fqWL2WbcO
R2cJff7dRXBwAfPS3NZGSLjL7O6l/um88dB7TU4J/G4VrTXWIugbtO/2LX6M
XOv6TE/aTxJq+/pLl8Uhc4m0sTPVi7oJr6RaoQ1xKTpDuWcIPPWGyg8v6IDF
mpky+1DqD45IIvNOHQxsod5rTyDra8H5trUemuq9bDeqnwSpez3VBQ2IXyOx
ttGW8hc5ETgk1QIJkRTDjPYbX9X4HR9uClEt0DzZd4X6ycHI2LK+HDlM21GH
TQQxgRHJbCJEk07wtOVhAm5I4MEvNk3QcluZLUO/Zc/Xs/wzXqBIuf9aHO3X
Oi69o3ITOfj5yVI9RernYillPcZ0LcxNlZckmxKY7LjD3z2nDWdZKlNi6g9G
wB2DyCknxPmoejKovp3v6PqY6j7D6GXnxmt6BMuVuP4jX1vAHlFIrAujenvv
/igti4cZVvyy73qa/lEyktchACdHsXyG4nOx9G7EwoX1UFCu+5G7lWDLjZY+
cU8H8tv1HkyeI3QOXfhB07AY28pFeZEU74cvMqu3JD2DtkmBvQ6tV0E2OIY1
/hwB1ndEo9QfZYoTHemJXEhNlax8RPOTuDfffLqrDI6qnyUyKX8M9fnxLe/a
8NjQJzAhjWCE+0lx+FMl5NQ7K7K3EDxvPeG+XVABZpWLtIchxcNF+9VfhS0I
77L8v8lNev6ARqLW+GMUpg+dG1lPYDAYdb6c4vvXipQnbjYEAfERTwI/CyFf
0F15IYLqR63k47O5eeBvOlhgoUr78YGL/zZMNuCh/i2fs9RPs189Vr2k2oqe
JraTLvXzt963Ea7zqtDMassWUv1GZsRdDg4rwe7trXs0abziCX2WhLgaPaFG
amnmdH79ssOrQ7sLzufPD5wJJrjQvySIPV2M2J65SXp0PS9105MPbqVouLvK
byftX3+fjdP2t2nFqO//ZBK5BEpfNpuqMoVoME2X/nKU8uG9aUp06ybmdwfx
mih+nkxb0dEDz7B6onNoM50fsTqv7c3fCOH1VMV53Jng5BGbrdFJdTBb651g
TPXStMP8Yas3D0mj00RM+a5ha7h6zmvG/h9+XWhH613yKHTv2K9VmK22MGWE
5v+Hafju1Nh2VLtLnm7PIAgpno6slitHiGbNxwoar8OsVDGWV4F86aKoMQMC
dlLT+5+NWjE51iHeS+eXJf+jdZNyIZSUz1zZR+cBV2XxvcxvT7E6fNUWQ32C
nGUeJ7NYrXhtZ57JCaT1xFQMZ2XXYF3hQU8+vW8odA0vsSptxim7Xv4PVG/6
iipZ/UHNiH5mue/7fN/YOMW83VUBcU1s2zV6n+EZJSzPzqiExicLUxc6j+5m
H1N203kBhs0CR48dBB95L29PFHbhtZJd77vv+GZ/CTXWeI5adtfyDUcI/gMY
T7nZ
       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4le0fp0RvJCFFMkqFVDRkxAchvREJlaRIXpWiRJIkFTJLVkZGySpR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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVk3lczIkbx9UL0yTtlA6lbatNIq1iRak+El2uSheK5bWObl1MKTrEdjFJ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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81Ikbx0cpJrpp5Qgt0ulapRYfFTmjpiWhA2VLLdV2jEg0Wr+VlB9y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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns41Gkbdlq0msghJWuxPklO6UC+2hvZnDYiSWqMHLaDISutU0lRaVms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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lG0bxi2RSpaXRNYoKYVKUclpT6hUlFTWEkpJsr2KEtErIZSsLXaV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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41AsXx4coa00LauhqU12XG7oicr8uymi7pSmSopKlJFpl3KtEK5Ul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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs4lAkXFz6XFGLrSyRpu3wbiykR5ZehdVlk0YUuyqeSwlbKvcu3Ma2Q
rHKpNLV0USnGNZd9Ta4xZhhmGjbMzftSqM1GRDvfH+c5z/njPM85v8s5K4Mi
fA4rKykpRSvi//ny+5ytDD4PXvTGr9sDZGCuWu/qGs0B0SmaoGXL4cq8Geiw
oA7CpoPzTSgSX1ztpq8YcxFjGTRvBnJcEDSzDLb8guJ1rCI7jWHwYvzern7G
gZ/zvt3JVXJoHh3Pzp+sxZY9ho8dHEjoJT9zWzctQmZYCHV4ZBChouvLwtX/
ROGMwLJKTQK3nX2PDaobEP1VKTjbgkRTRkvhvgsstCqP0VdqUdg1FT0zIOjG
6dlSRjYhwYE0l7MdcXwEz9DG2R0yWDqxJ+eyqiDI4rlyK0g89P1XWMcqAnVp
xJ03iSQKB+S7orQ5mPpa1KyqJkeeqfL9LP1ekB/CfqBUxPB5H9F3sK0PS6nj
akNhg4h9Usio4XViNW3xMacvUtR56ZT4SkUo+fjOdLRRii0z6x7fPURAWfXv
mIlmEh+9ZTYfp14jRXdxcbOuFLZRnaPqazPxU1FlWdlbCrqsrlThrwKsoUxv
eCVKwHtHbPspTgjVoNGG8Qox6JtdV7mP8BGnrfGlul4Gg8gNuq3WBOipLZM9
uSR4euwEbe9q+Bicoe4Ok7jkpWrOD+/EotiaxeQTGWiemRyXJUKwVt8R6HEk
2BLXk5L4oQ52L+6Tmi4krFWe6ehE1cNLa3fr3ZskKk29Hys7VoFd94jq6CfB
tDiNgF0EmId89WbXk4hmPPjUf7gV+kd6vjV/Kgdv03H3JX4VMC2TWjq+IzHF
zNNnqjYhwo5rs2PjEIyJMY/w/3Qh9tPfb2QJMlR6ECbupRXIzVW9nMYlEerG
NdSwaoW/aH0057McJ6zUHV5vIxB7T8clVDGfqpXYWKg7gHjzwP0ngvuxl1CZ
/WGgB+2LQ7eqWyjwf2b2dUuYAHUHM75LV/AXl2Fwa2NtGxyeJ3uLE4bw8287
QpJvFeCb9JFLLzMpaC6w9K9M6cGU8SnXiXYZ4g+72Dv5iPCnP5nR9UmKPZf/
t0c1ugoVRn9tyB8lEWwyz9ousg288GuZfCc5woVlCxbNiqCVLek/1zgIDYaS
zuDRatCei015TBJ7Imw1yztLERqBct4HEoSK3u9aielgHBU22U1QyNBS0+Qd
eAGW+Eq3TTGJcH+XhVErheBKdnlY/yzDth99PT438GA7v1n6aL8c3tNHTfJ3
18Nd8GqHWtsQuiknx9D9TdhQrRxTjCGkHx/e1WRRBfo9WrmYTcJufa2/aRMB
E0Pm+SOnSThws17Rf+PD+FK8IOeBDNGzRanrDlQi2SYh/VQlide7S+jjZQJI
Cpd7NnwU44Qjr8ItVIS28lr/+GwJphO2j3rsEyLoYc1mnq0URmq6PddCGmBx
42pAsRIJ44UOSe/7BSi/7Cp/uFcComxTbULUU7yKXT7ouZfChZcnZjVGROCs
eEKxl4kxb01BQWJGH/qufFke/lkKWcGcZAOvAyPmZ9nxY3LMnSyZ18FsRuQD
341rJXIoTQmGZIYsGM/P23zElkJXszP7gYCAy42F9gnXSZQ2Sj5vs+rFJD16
cG5uEO3kmLbrtxykGPmrBUrleD+ZU7RmaRtOvhUImUlyhNzXsb9V2wnCLinA
r1EOzxlDL5f9PcjfEKPCPyrF/G7326ljvUg+ZcaKiB5EkueLWMuCbvz1y75D
jytkyLcpXPmVS8B26tGy22dItB+5n8oq6IFg+3CkvkCCdxYLQ1SsBUg6t/yu
s7IE3nSb4ARGDkqb2adjOijopWl6rPi+E8EbtflGvyv0nvT9Xp5FOmyTrVo0
P1BIZ6iURFxlQXuslu9gScGL5uYbI+xC/hKnGPEZOabVt6Z5enWjfWkBWf2j
FB4rtt7Wb2lFyLnr6vsi5SDOduVkSAiQN/hqXgcV/DTdGkxzrse9K9NKUiMS
1ALn6tureHj1IGAq4qQMuRrN/fZ5QuQ9VU4Xmspgt+jQnRQRC0s+W2bsXaXA
e8JkfWBRJ97SrfniRDl0i3Ovcl8XQW/g+CazYwp+hzvGTTkXENSy879J84fB
PKLbPpf1BIb3npdahVBYsN0v96QqD2wrbpHRKQV+fpN1gVr18D7GmLBvVdyH
oj73NMN+2M7byaE19iMy9bsYj7wSyNaqvjz9UeE/6mKZv203aP9u0a9bK0f+
Jn33XM1uZL+6SIrNFP5wpMX5+BRAOzhq9nUxBXPv7HQz+3q0Le1dnPplCALO
290hfe14kiMOHPBR9C/rXHPKloCmLMWswZpEzUUD84I6xf6OkunyGRl0G8Rn
p8g6RPWOHg74RnHPIhjCT1m9WEcLYVzXlSF7pGbTzhedeBej8v6howwN186E
tSR1Y/wmp2F4Sgb6eeVJZ7EIF2qCMu4eU+j7j9aVHvt7UbNZ43yy4l9w46lb
1yzZuJeTrDGyhsSzP4x/vZRRD60Jw+E3ivofKUTVKg==
       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8lFscxoVEpUVSKtutpAWhNAqPbEl125AsLSIia7cspSxD2q6yttzU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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lusfx1FGSmYqnCgjDRmpED7oVJJQOlIy6lhHEkIcW0ZahCj7SNkz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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk01AsUxy1F9aKk0iNbIo8YyVJKXxQZL2mhkvKispQ8o/JUkteKFpTK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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81AkDxieVJWrlVUk5qmGsSkTlpfZRKyRF6HiJsNqNQjXOdEiS0BCy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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lWkblkYqxlJk+U6mskQdOyWpS2E09haRqJMiYSJhkLR8QodEEVJC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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VPsftiVJIiRUVLaEEmVJ95VKlKRI9qQSkSukwrW051KEQqRsqZCE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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41GkfxpFLkoRVWVdKG5ZK0puk6KadiorSCitKyWFLSRqJIsU0Kev0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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk81IkbnmIpbNlqS2jCTo6diEiJPIgix1JqlXRMq4t+6EByhVhHpSgW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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnlcjGkcn02XKyS2SLRFFxprihx9QwZJupEQW0zUFjsddlOjQzrUSLLC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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8lN0bxkep9CZUWiwVESpKklS4ECUJKS1UJKGSslRCpWRNEioiIRKS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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk81Isaxic3lSXRyZmWaULKNlroUKgHVxsRklNIq3YlpWuJEkpOnaaT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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs41Ikexscl6apyq5WatGrPuOTSSp3WO5TQkVKzGoaSZReHSCVFulCk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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk0lesb1TE0oltHSRKlXDehkDK0jSXVIZmnpEhlbFAol9A9qVbcchGJ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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lv0fxRUyiidCymhJKskshCMhSaI0RfSohJZsispKyyxJUUZkbwnZ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41AkXx2dTKWWotPVKRVlbyKV6EdmvemlJdNHq8iaXLi7lrsjaTSNs
tCjTKLpMcnm9SFGZiGYwRe5jjBkhq1S/y5TwMiR23j/Oc57znOf8cc73+zl6
PsH7TsxiMBhRyvh/7t6squ6m2gaqaSTgkhcF8ditlNNOQpwOU3G8eo9E3ppr
p90/NEM9KG1eEJuCXX+aY8WPxVDZ5bPgz5sEFLYOK8fCu6H9NaPctodGkX/Q
8OfAGrgzC7emxynnOZodnOudMP5hlrNNAA2d0Wq+n/Axpg+2PEtaTIJxJTdq
ZWoNDn9ztrhfTsIno+nmu+1SiBymi3WiaKRZ3v+obVaITW948Z5cAqNxmg2c
FW3YQJhvD5dSCHkYy7LQuY+aNrdhg5cENA2+C3lqHovqtznbkiwJ9CdHGQ+E
XoWbWW/D+z0E1PokjVkyAQ4/s7CV/0biSbjf8/JFPOy76qC77DsSiSb2DsKS
biQPzsScbaIxdDCiNLg3H0aFqRoReQTsPP69Z1CzEdmHXe+c1adQE7dgcbBK
Pe5cp75cfktCKzP3oDNPAH99tyHnSBJ2WUxS/lyABAaf68IisU5m1CeLEUNq
Eex/N5SGpKwipHyfBD9drFO/rLxP/zfWEfFYD3okVoEH7eTglfj0dXlL8PaG
sTCBRcPYRveDxttWRM37YLCJRYGMqHn2n/tduHE2e74skoZfxqm9rXQTmIvM
w754UGiRvSQnLrxGNW+L3jwvOTxqwyvrjd/gxMEvdcabaczjZP18hC3E1jGP
tse1JGKLha1rk29gQNAfVeBNYJhy2WAa2A7D6LP6+WkUPpn7P9INfIjqi5Pr
M6oI9DL+ct4vbMH3wX3l569TyIufZm5SiDCwKsXhf+EU4gX3CsSDTXgydfo2
6xUJV9GxhCX2XZiaibQOvEKD7+29u+KfyUDmD9cU2wmIdhyKqLPtxdIS3cSh
1XLYcXOWUBOJYNKnZHkgEHRnz0h7eBe8eso7fs1Q7vtyMjukQARN9XUTKWUU
nIfnVgbkdyC6NMz7uIKCUeh/RZEmLVjVVjq+GBT8KmtJl+Fs3O1ML8FFAhyn
6fTKpx3YmOPuG15LYfINkf4lpw6uhtyV966R6FgtK/g2Uwe0F8Sa5pLQv8R5
Ya0vxgibuWrTJyUPY07JBusluJ1Xc4IVTeOVXUvW18+v0KXF42lOkVhodK0o
SanP4qcmwdWraDQ9b1z0y5gQvkn72RqTJDTDzBKQ3A7XNf71QTkUjh9WOZMe
+gJhrcd2y4qU/XOlERqBYkSo5S+Id6Bxcb+jqneMFLfitz5xjafx3uKnBs0x
GQKGuw1JbTlmW74/076sG3/Ym+nuUSj9u6bs2GimAJZVVosoaxLOa51MAla8
xt0j6QUJLjR0dc7dscgUQ/FAWm0wn8aUdGpCptKNc4wrj7UENJYF20SNvmsD
m9myMWaaxDyfvMv5na8QNttpNF5Zh0TPX7fK+yl0L3cnf5shEBO0jpXtX49K
eb18ZpAEf3bVcgVXhj+Y49YKVxr7Aoo09ipeYhZbNcjqA4mc3N/GTNfy4chy
lv/oQeK4aYNaw3IhrO3UfbXOkOhWczeM85BiTOuWV7yqHJ22toGXUyS4NW21
23wBjeWSstwcfi26qx2OZD0i0XZJP8G6rxkuvV9/XxZHwWDp9MZUFxH+OlOc
TMgpJLy4/XPfTj6uiM24Un0lj0VTiaGVJTjJjQisEhJ4tMhhQH5KCJJVPDnN
V/Kwo9Xpgc1dxDhuaS6OIfB7KjtkPLYdiR9ZF5YmUNBRa17/9ftmhM4nxAcc
Kcw9c2gvfHoQM1i8xSOJhmemjkqWRArflQFZXyZo6NNOZXvMa6GwuHdrvJjE
ZoZ5/UWHFkzeGNzAeU6hifM6L0DagJ1uqvtf21Dg8c+3LkmUwCS0QirTpdG2
O8hST+0RTrdNVtnSBC7sOndeb0CCob2BGZFKPYc+FU3c38mFp31ggCCcQOYJ
UUVvthhyR/vCm240MtnlnAO5EjwdFtXWMGh4cQvnRM/5EyOmKb52TgTWuWfe
lpdUoEKdsyZGeR9enqXGnFYpjJyDhorYyn9FVXmmsjqw7V+PXzR9UPJUNqrX
zGqE4dBYi84GCj3S5lLbTgHStpF+bBel/+euvrJL0QluOdcp/CgNtxGe5yfv
PtR8pNRONtNgsP1MVVpqIYiVM+xaSXC1fcuKmK8QbKYbt9mQAtttx/VZW5pw
dDCX3hdFgelpHmns2gl9o+7CFVtoPNOOYhmKGnH0LWWQ9g8Ky0fsC7XkJdCt
a00qqyXg0qefeeizCNUC7YGPMxT6F/bYND6sRNXQr3qXbEiwzxWsFA+0I9M7
/0UAn0Ks3GtWb3o9TgZNhhqMk5iYmf6cIZdBJp5JNfGkIW1a066a0o6H8fXM
slYK/IXxi2cOlCL6qPvkRB8B4oRzz3XPdnTxTi3v/YUC18WquLqbh3eZmg8e
WpHovxf8mBNZhGPsj0PjTwj8DTMA7gc=
       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs4lAkbxieNQ42WzkVyZpdQzpFuZMqZ0oEtrSgNq1Q+Ce1W8kkhlYjQ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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns41OkbxqVpKzkUFdlWQg6tCCFRt+OgNkWWLbOzymnskkQOo5ZaUVgq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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k4VX0bxZEyJFSSSMZKhRQpwhKlklTCYwiJhIw9lFQqUpJQJISkiAYZ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81AkfHqrpoHJlY4W0HSuRPmHl5VFhh4QOpTYs4VW5UioUFkWaWqkc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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41IsexoVuynKHtqmjU4oWKkqLVF6VsrQ4Ua5sxS1NocXRjVKWoymp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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVms4lOkbn6xDKzZKpaKmHEoHSUglP0lW1tBSk0NFTmkqCo0VFckqp0gJ
6xQ2KbUSOWccSk4xY0yG1CDWUyq22tRS/+f/4b3eD8973c99/073u8zdz95L
isFgJNPn/+81uUkOJ491Y++td5zBEAJH3brhHLnn8JysM10vJMj8MSW3WCLG
aNj0nJM8grmH2+ESLsKrDsvNiWcI2uy9x+aFtuNC/u88rYMEZoJM4dSWZqjq
RZ5W306gpyNdoNrVjo/Lc9yk2ASMxfLrYxhVaDf46LNsLcFxt9Tjb3q70JkW
fXfSjWD94wWZMzz74F+oP2EXRr/X/PeydIsvMvf1fVRYTvBFrVI+MKgFPtum
d8nvJrjxdCpJni9EVt3jyvhDBHl2sU+DzITwMXS+FJBAIIkOeOSjXwjJnrq7
MtoEhewqTcdfnyM+aLn5WB9Bl9jTfFNAHzwPcj9tSibgkcR5zNsdSJkjV3Xk
CIGPVchDb+VKxOcW2QetIbBqvO63VEGA206Hsur3EzQYabpV5wjgyWexzLwJ
tmqLagbkGiDq1ptjtJmAuZ7M8ygpwgj0i/N1CGLVjaRfOHRBrDz4UTaa4Ij0
yiJvhggZX1Ur02MImr2UO0NSBcjyig5hcwmE9xo+jJfW42xGmYfLVoKKN4U3
64834OmL3v1cY1rf5+UWCScTkmvy34I1CbTZZqeqwzvxTZkxGnCMYIcdd7V+
ZxLmKOm1LtcgmPkB6wazbsBRlidbQvEYGhTYcuW6sVbnv79jDlN8nJpjC/xL
ELyrKjmF9uvDaSMq7n14wxzRj6in9+12DROnVMI5vDCmdz3BV7YpmxztxrdY
d+3RQAKb2t+Op0vxsHU0QnbTBoJqVmoJ27MVntO1j9h7KR+m7p9/Hj2PlQV2
C6Mpnw9q7dMqZZowdLIxPoRFcF5cbKy5W4iE1Jq00ktUT34DJmfEtyFxvPj2
Oe034dj91zlDNdDbznk1rUdQYr25odLiPjp6c5U1VhFc+Kj7w8qdtZg4y3dT
MSGYyo0TxMjVYfKu8kCjIUFPZMOVpGA+Ek7HpfGdCPYVni6J76tFwHpmaSit
N3j+/K+hsl2oTjvm9uUAwbXlK/KtZUWw3lCUpx5KMLFRXmWHOR8WI1ZhP1O8
1LRCRPv6eFhy4ffaFCOCtBkHVD9n98Lyx7WK6yi/PoefTqz5IEJPm/KeXMpn
rFVAidrGCnyfejIxrk/xnFpuWr5UDL/dixVNSqgftpzIn9CswbkD7b5dtJ/x
6IFPLutu4abH5B/BdH5Jq5bDtaZsvHINFa/SIvhtxnzGIVcetOfql5vQeZmN
3rxIqW7MLJs9zssgEB1cFKLzQIiIuIr2gxcJ6gy/2NYf6kaoiWjRcBrBw5t+
Q2F37sMngVV8YyWBlFJCa1RtH5a8yb5tfYX614lX4LQvFJMDqvWGlC893YG3
7dW3kGlRspZP+8mzDGebf+uB7X3bW5/9CArMP42SIDFm3c3udrhOsO69TL7F
lWd4WyevPUrzxWa4PkP5Wh+2qe5UN8yk+vl9Nl/x8zPs0dik+/o+wfOiBWpR
rMcw5n7eP2hKYCKpPOj5Uzf6S7+qt2URZOc6p4VcLgJP+lGtItXnxMy+SM7f
Ygz7qc+98YCg2yAwxL9MgCo7lZq5lL+8WMUu6a5OiMz8uI7UD8eDLp9ZzOyG
1J3vqXlxBOms1Ib5e5vhPd3/ZoTmUwauSprvtGJ+PeP0gl8JEntcE3fHtUDI
cjRWsiKYZN9J+jKzB3pDqQeQTxB6TSdkwXeqX+aA0Gsn7VcjVBLOy8Og2mPO
CsqPsdPzNm5sBVaJOYkrKZ9hV6MHMiWNWKbm0fR6B8FR6atvtEgxgnSbHDfT
PHSTe3eT1SvCT1xDGQM6r2nlhKzn+0eYYrB+CaX+b4yy7l+Y34VX8fdWKNC8
HYv7FHAx8wXGJd6GLymeSk5NkXvO5SBtwJyZSu/X7G9aWBzZC3FeTX1bK8XP
sPfQaGMGOIPWrqU0L2wk/mH6PzRiLPkSy8uM4r/3/NKLT1twlATu/EDrqxmy
A87o85F8u2DEhuLpPqFzoShUgNZjBVr7fiO4kpYaZ9ArROAiyw5TT+rX/U6S
I2Y1tI+lcpYGFN9xDzuHnG5oa1i8dTlLwPrZKH7Dqj5wrmflhl0leKHNvVmm
LYACzzHZm+a/87BM/Ir3XQh8NqLwlwfNP36wqlZBEwITdV8OWRB0So1fUklJ
g720Zcts2v+3ka+zqx1E6JhQazlxgiBlhxwrxiUDRlFRbjn03Dji1OTYSDXG
LOfxDGhe2q9WdV0g3498Jc69YLrfnGVu3dMdPYWiNcEFOlTfNvYKWXdE3fBt
D1Den0L5miMzvqyCi8jLSTlMeq5b1cd3udUPqbVeooAc6seNPcpl+/KQ7Pxv
eQvF23vGK8LZ0obiwHTmFaof5vdS/6AtCVA9Je/JoPmbzf1zXoRXBYqsXvyp
RPPRrHpreoKLGKvG/fNqygjKTxhHjrpX4IVfenQn3TeqV3bVWnlkQ6md42ZO
58kx73lf/0AAp/CVC9/7EkRH/KMScrwXi6b2ToP6OTtlOGPw2R0ssfquOUj9
rHm61cKkRoglWoy3S+h+dDSVfiK41An7+F25DFuCjxe/xE+U14Ej+cXXcRsB
MU1jf5Lio9EqgUxR/m9udM41aSmD4OGfTVk07zurxmTbWwqRE/WPSfsKAks4
KN5L6ofaqYjy/wQEga1S5HDVMzz0a3k3M5vgr1DLLqNjQngdGVwSRvfjzo5E
g9U+9TAqj9+uQfPyIVPXrCmmF+d3J9Uo+RP4NiWluyzi465TFaszmGCXo02C
gYwA7kP5n22p3o5M6pmN7G9Ah3ZzIpPqy+/MARX26yoU9ir4KtB60Sdl5v9r
2gDd64k/qVF8vZNmjan+IMQuvmxu8jmCNds37Tg1vxbcaV/7J/R8alRj8QUb
MXy+2l4YrqV+Tl68R4bmf4jW3eCFtF/mUi21ZrlssD3Vh2ZRfoPjrY0vmQhR
qmw3rUjxfFeX6Eq2PcWPj1ryouj/CMPU3trj2x+o5N07e47y/T8NOqrS
       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VG8bnkgkUhKSipKspaKI3JKk0KK9kCRJJZVCi6UkStZIhQhRlmyJ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81Pkaxx1KUpvLkmsu1R5nS7RhcolPSUpluyErm0uEsqQbaQnhVEoi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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81Akfx40VtYWJeSRpDWJfytJaEYtPZB8q5Vylc9IhUmTLUYocWzHK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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns81NkfxkfUSkKk1OZOidJGyiU9bJQkqd2XS8huSXaaRCFaiUJhCLV2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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3cgle0bViKhpFRKfUYkoqRkhCsRDaRFGxnlIwqVTyo7aYnMFCHJykrI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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81IsaxilUg0qpU046kqxpuzo6WZ6xhJObZJk6cq69k7iH6ia03Y7I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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk3k41Isax0fpdnJLUyQilKylY7puK74lUpoiJ7LkWipLqcaU7E5iqHRb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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lWkb1/kinWSYJKnJkiapmVRIy/ihZkYmx76kGUqiQqnsSuoUp7Fk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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VV0bxiVTpiRlSoYMDUhImtxCJdKrCZlCUSRlqBRvKUNKRamokBQi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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHtczIkaxrNyVtlx0mXarVac4lBZsy4t+4mHiqlpySUVtnvSycoQg0yX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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVWs01IkbHkIqQhfSqr/7ZUtbEyU5HmslRZed1GLdRZtKnFoVFa2yYmTY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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs8VWkbpemrPiZqSkzOSAkNZYR0ymVJaJIun6SSSCWXKUkxiORSuSTm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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lf8bxqWIhmQlDVKkSCLSvCRFSUZIw6yMfEOIaAklJVmVkKIoJcko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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41AkbhqdJ22E1TeKjk5rSRnROaUYeRca5KJlCtVJJoYOEHFM+lQ1p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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81IkfxidlETJRlEqJxrFsx2uzzh5lVo4s0VSrQytJjtJhdztUtBQ5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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns8lFkfR0St6CVspISkSCFE8aUVyqW0RUS5rK4qQ4m0MUtyLytFLrkl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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c81H8cxynJaGiJKCpKUkaSSl5NKyEpSlESJVSISEZSiKJkE5EVhVAo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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41QkUfU8mLRrU06KZQraSR6Wi7SgZpZKtoo0U2pBIsoQUxqChV+jh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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81IsaxskoIQYlnY4l1G3RlSWpqx5OxXES5aKEmsu0cWRMZUlUIo7O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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk41Gsbx1WSFielhXhxJEtSSEXJV0lITrZDoogGUSnTJpF6i96SmCTJ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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Ve/XxiWUiJLSoIxFRdSXiugmREgyNCcNhkrEr0GUoZQxNJCKFBIl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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlGk81IsbxSfFRf8kpJtCXWu0y1iiUwgpEVJZuiJ3pGyFFsoWIZUKt0Uo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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81Ikbx2elRMcmtLWxUTZyTDZHJe1nxbZyxC9Kqdyi0j1FNqJDFyWp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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk0lesXx5UMlaG6tzQRDaZUJFKGL6WiopBkDKmUuShaFfrdFCEUmW7G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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwdmHk81N37xu2KRCkiSiWVFCVZ61KpyBIKFSVJaRMRSlrsVIhQEfJICEmI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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81AkXxrE2XWwkqWxsF1Nt5bZSVsOjcW1zDVuUkLQURbtewqqU62vl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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs81IkCxb2yinF7yM7Kbksvj0gqXKxD763Y7qyWItE20XiGlSRGekpy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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekbPkQZbZMRmgilkihRSOouTahUHJQ9yZpdMkfZmqKmUJnO1C+S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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k4VV0bRtJsilLKHDKUXhJRt4o0oAhlyBhKGkheJVIkRaZSIZFSVDK8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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs41Ikadp+ohhJKCItSpIvctryKEtnUZjXdZKVoKnGi0EopUyY0SheX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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXtUzAkDHYVTWUkqsz0IiZaUVZS2Lj0kO0svpKEmdE4PCqWi7bGVtknh
y0oPZRAbGiZ6yVRiJJMy02NMpYyZ+c0DUVJNKn3tH/fc/+65595z7l12MNI7
WI1EIsXN4D92N29xTVwiAJXxIWHbNjHu8YqE7wx6kHVcK4xaLULJyb/iJtGO
p+MaX+JSCFCCID+4ohta4bS0SI334O7KZc/e2Y4nHl4Z+RFSFJ/YzXX68hzR
nz3TpmgyuG8r4lcXNiP5U1VgeY8MpefVrT7FsuBsIxwYDlKALdExsiqvAP/R
uabcNQpwNed9D83uhTf5B5/uJUKesQ2pQfEQFO7yW3k+Cqiafd4kFLfg2C12
2o1gGdrsR5cpy3jYVjDRovGJQEn5ntorKd3Q6C+ibBeL4CxVL51Lr8dC6lIj
k2NyxHeMR/b+2wXzAoOrk4NiZHEO1qvNf4rRoU2+K3+WY9/FvRZP578Fyeb1
Ds1GMfa3vpigWHMw9Mj/2bIMGT7gTJtTExOGL39mMc8r0BI662vB4z64yGjV
bl/f48cfAT4+c18izaqquqGXgA59qpJlVg5n4+w5lLUKDJzOeb1xTIAYG9fP
q/Ql8HhxiXJAvQP2L/4JGVRKwTia45qS2IFow4GnNUsIsHZFuwgPNUHDpl1j
laEMFL1xyhSvBry1l59118pBDrHIqXF5iMH+w9O6U3LQ+sMNA27N9LH6r566
IAIaqRUmdKIWA53fok74yiHC3kqq298wXKfU4c1SIi40O/Hbaw7uWQ8mXp6Q
IZdKv7H4VBNirt4aqZHJ8Eu8QaCdig/PVR20qQsEGPF7vmVVCuAnSH4S3C2F
3sJvK/Uie7FlueVperII3svrtWkzeekVr7CJ2CmHBbdrPNyVCf9cqlGlhwJD
UeuO77IUoujY2dvTRhKU3jXII4c1onBcZSH5JsMV7fW9p8l8pAeEcJa5S5F8
Jc5RK9QPlNhZK+tMlGDFbg5cEvoQh686Xrq7VYF173y0vcwF+HjNP83tshjX
K5SHy6YF8Pf5OEdX9B52TdsZvbWvsGZfcsHYSgKk0fvz6pybQXO68Ei1UIYA
y5cqpxM8PEiiWGy1l2LElGEavOgtih/Us9xVYoyQp0JptzugLMtu3ukqRfUv
LF74JiFI4p5SHlOM6KkAsjSDg3l9S/mloTJwlzZSe3YJsDh/2H8HXQyV35UD
6zMfIHaOY8p9sgKzf4SoyiYP4fpoVCXZSAnPhK6yzy4N0Kz4UL89QY44gjHb
zrESx5vrtwap5MgacCjSv14Ba88GwSttBUgXC8u6eTfhYjzoSrurwMR1Wy8S
0Qw3Z/IjbYLAlvEtSeZtV5FhO2TWXaWAtn7xAMewFYyc0aoYOoFwbkdAOZcP
m6XD8w40SjHKa9PufC5E27nVHlebJbD7yaGhaagIuSN6fuktCmht8Ahhx3bi
bdt1Kvm0FHnpkfT+N0KcX1BIbtsiwZM+t8JLqekYUiTUR6spISA+Hw0LaIVJ
Tg1FkCCDn58dhRpxDAzdO34d+kpk1DCO0J+34syfS1PT5VJceK+Wa2LXhPHN
sckxCgK81MqW5AWPQVKzsnLPl2OyX5XFNWeDppYqdAyUg5uamaap+wYVG478
GsOTIly3pap6VSfyRBZ7BBoEki3v+5JKmnBEx6lvl74MGq8tDkepdeEjMWK8
eUAC977SpNSJcgjrfF5u2KOAafvCF2M3ChB/znqvdYcCrdtd7DfseIP6L2vy
wtdIYfr6UxClMAWXN+W3zp2rRN5XJr+jpxO3oxONdVcQ8NX0qg6x4WOBmrDt
46gExicXfbG604Qa51aar1yG5O8RQd62TbBnSSeX68lx1iO6+NVGPtp/PeSw
O3FG37Nr1kRrGcxZ9o9zAmf2j+k0Xri7E6au+T4lfWLYXDsfbL2RB5JW+2+v
/KVgcbr+fenQi2mv1sqWT+/gmYlZ5PtM/J5SEypLUOB7fubeQ4t4eBKt7us+
RaAu3C00WqcLJ05yqmyypZAy2Bxmeicy/nnrU+VB4KfM7BEfBgcrNMd8nyyQ
Y4Xjbw/3RfXCrPEk++g1CUg77Rss5z9DDS9p29EUGYwm6QwGlYOvQpLU9E8Z
yEss1G9G9MAxYt89z/6Zv8jzpz0TPUNkxp266Ucy9PcMG43RhSgwzFn8YFgE
g7+j/jCb0wXHMTGZfVGCLI/q7/EOj9HevvWAVpocdtdsfmfueY4rqbemY8Jk
YO1dOTxV24hLT33Ngg/JUbGsl6/ZzcO94Q/zY2b6ZHtSHZ6XzPxRmD2xtUsE
4yoD9osBPhpXp33J/S6BdbzDDY/1AiiLbL01vMWwLb53+6y8G5T1pez87WJk
brJgRoe0Y1RHnpQ/42eg7ozvgXwerJnK2v9RCfiVy9t1zHgILXHUj58rw0G6
pUPVhR4MFrm1Tj+QYFBddDOv4g2OcH/s758tgZ7OgOOmOzzYZtSdSgqTQrXf
9vaptY9Ru76DYnJUjnyTFDtKYCdO0Wbv0DeV4P85FM/k
       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lWkf9klpytiibG1Oja1CKVK5hS9rMtZTspR9y8RkmSmVhMwhpU6y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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8Vu8bliQrq1RktBAaykjCJSUZJQ1FFBKyonxLiraUqFSyFTJKVkhC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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs81IkaxidbIrRY12yMbiZkiWRQj4rI2RSpkJDKdqPO6TYlCRXtEhWy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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHlcjIsax6do0aJNJFEhLZyUSkR+aTvpkkLa7klki6HFvtSZ6KIj3VTM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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekbpik1ojFpQcqSQRJNKGv3SZYWFUkOKSKJRHNCtIwtkq2FsqQk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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8le8btpJQoSU7mRlJSEOXtJCiEC0qfM1KqJSSJJVQUZFoyB4VOrId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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk81Ikbx7EdKCUh27GNTlu6NktRPpUOllWU2dQmOZpRZHIlJmeHhJiU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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81IkfxifpVI5SWpsa12STjaRDvX6PDkKS2rDbboU1dPx2NmlLWCmS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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lWkbPjMkbYpMEUVpCg0RIxm6fJLsbcgZ2bJOjTqIComjyVZK9siQ
irTZyXJsB52DHBxEdprmqfg+hbZR3zN/vL/39/7e57mf+7ru67qejcdOHfL4
nsFgJNPn3/fne4c8nAabIWLaNuplSWAY6OCoeqkchxreW/upEqxa7uW9uKgP
EWLdFR7XCeT1pdWaHJ9hWfSUiIYPwekY9VkF3nOI3+QssQkicDFXul3+oQa6
N0/yvm0ncO9wxA9reJAwKnE0sSPwY5npWGl04/0iVdarcFpvXRqCZV+A4cdq
nX5CoFjVbvVR4xEcZI3nLOn5YcLjMmx2EP6nalu9eRPBWTHW+nDTNjhdKHxu
4krwrvKbWh67FxViUsHZyQTTQxVG/4niwSniyiItYwL+Zq6FT7EQvNbg2vcx
BPrJ814Pf0jE4rN7VszRejI5YS7SrgL0LzXfcOcIwYHgdRcSf+vGNU5qrfNJ
gqi0SfWDLvVI+7D3xO5f6PqZ5EAFyWK8++3oerYKQXWo2EmPuzzoleqvbzMk
CJHP5QeODWLY2VWivp2A8SBlpc64Dz5XnZiXo+dVcALVAn9JQeRhY+1WJYK1
ieY7yv0GEVbpWu+ZT9DrvOyX12lVUHdbqKtXJ3h+J7d4k2c/wvQulxjUEHyL
C/aI+LUDTYUhJcaHKZ/8LOcQhX6cC5hQfVlF0PXM6PSDS/0oeucdfYTOK0p2
ZpI53QkDi/HNJucICmacvupu4yNp7lpavQMBd+WVDQmuA4h9PGWh0kiQxcoR
7rudhf1fk47t+5HgVNL9gGwvun+tghiXzo9VE+dodoEP5y2xzEWHCC5+zpfR
XMJFvG/5ZJAuQaJGqvzpEgGO2vXrHWcSzF5jH9wY1gBLu62Jd3cReFguZ76N
ycHkk8lXMbR+softrM/TbmQ2B2Y7RRKoKKb5i1Y9h7a1lrhiGYHyiufDWw9y
UB0/4dOpSed//RUnQIqLEf9IHYY+QbR9y94b2X1oXTOxwE6g/C5y6jFc04Xg
NZdLcmi/z1Y/dq9z68C1rvQXnrRfuTyVV07TQqzi7hM0BlN+Z4tqmLUjKBTo
7YnPJnibaizlSfm0EfmYp1VA0MPYuaxX2Isyj5wr6r50vncOhCjNc1HCN/YI
oXic7+0aGSnuBAkvmsrwIyiZzGTG5gkxWjPcEXyVYE8oc515xgA+WMQNetL5
VF7UT+n5JsCTetftvQEEohNeBe2HGuG+bPpIswn1W81ju71mefATCbBauoVA
93Hk28KJQgQWvXSdVCbQiTKOsXgyjOB46ds6lB+Bv6T4r/88xaZbTF3ZPVQ/
OyY/20oOgV2YqSkpoH6KCfzu1MY+7F662sX+PsHHFqP8AoNusNK5URnRBMa6
RgkxEXxUrF/tl0n5+pj08lRQezPGrpbOvqH8Kh7X/OlmbAtOWN/8zpzqO6v0
bud6pTb8cb3JudOdIPT1A1GvJAFmaz/FWlI/ZsGpieOfB+POwBf7t1K/9RSF
ru1rhpgYP3SRNcHTlLE3QyMFkLtgGORG/XNZ88uLNM86cO1TQ3OpfgJUW+Il
smtwUdL3YRmdN0M0VnxhLRNa59sqGdQ/o4ZH7qklXkcrOVYpSv3jndciXfpz
NRqG+v2naN4MqG3gTZb2wsJtcHo+g+CvMf/YBJU2mASMbWqkeTDtp5m2ECCA
EQmaGrUneDDp43hgvg/xpl8bNlD/cbtXb/wy0gfFsC0yIaEEwyt8337eKcTr
BN6qBIqXdaxrZPRgGcINhixTaX+pOeXb4uuqIHLHPkZ0B8HYYU6B7U898F+l
9qMI1UOFofH4pxvVsGTlyw5QfKt+G5Tya21Atpu+Ol+L9p+xgh/DbEBh/9kU
UW2Cu04bhcfSu+DFfz3CcqZ4NarYm8/kgt3yT9D9zQRC71VWibZcdCxVOl9k
RNAet32GOzsA9VflHuMcguKSvIif3Ljok4ysVKd6YryLs2badSHurF63/wkC
q6MPNrvWdkHii/XfsTZ0Xn1jjx6KXUIk1/J4IOVXu3Bm3CKiAbIP+WULtL+T
Igq/2/7TjRDlM3rjVwhM28t0DaYqoBs0oXGP5pN5p5vojwwBMjKtl3vTvIws
VghcosYHK7e7YzvNl6/c06ohW4UIl+O1r71E8e/x/TDX+ghpqlJhoTTfU322
GmuM1eButMF8y8/0e928auB8C4RBna4VtlTfyZc/5V64D/OAiZ3pVE8FEUaT
gT11YDekyvjvpvxOCfk2T+owXipuUm1AUOd3X/7rHzfw8VZFqwPVh2kMZ2DU
sA3PMquTUylfx7cEW9ns6oDxnIasrxOB5ruhrvq1zWAcF7xQpHyZKvvwDAcF
KNO6ZXaf4pFnGzPqg5/gopn86znKh85f/9N7c6MDGgVm71keBJyFlNBz97pR
Ge6WskDxyTSGpx8eqYR5+i2OB50nP1G74lOtAAI7+VcdvxKY5CuJOU704Ht3
+6qCRIJHX7XcJPYKUKL0waRxP73vcmck31j0wrRMepkVrdec4+A81N2D4pDd
rLkkAsv/Vubph3VB7MCE6UFar/aoTMx6uwF8azG9sjKeQEJn+7BvTSM8r7wO
59I8kPS/2lDe14A2A/6RIppX7sonhH+mdmB825IjUr/T+/7lLuURl240aVZv
ZLMJpG0q7f/c+QzuMls2XaT4ZnNfOmTJPkezlBzv2BkCjauHZXwJH4+sOCxZ
R+qPzDGtYJcOTEm0qQTTfB0NLXScnuVieOpZgrgpvU8rbh1sVLiHqiiJ6A80
76MUda7lfuFh9SIb6Ut0veFf50WTnTiYyXc5qU39c17Ouc5haT1UdzOKs3UI
zowL3ybt56GzyXmfgOaTC1tULvPNY5y8qL1dnOqBcW1MxCzZGy1h+dcXU/3+
fe6ATeJoASonxratpP+Vn8bdXsZ8iizNFeYnaP5ov+ixkGrrQ7iuyJbSOJq/
9l6ztxUr4ToZ+v0aer5h1uIhjkgH/kz/Ofbf+7Xu0t9S+U3tOMQs+uPtAYKM
5f4RO+Rbodp89gcj6h8TzfNbVera8V1XtH4PzT9Txy5v8wUBztunKtrT/f8H
ggSuTg==
       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3cglm0bxhG9KqFSSShSZmUkJTpKUiIykyhKkopIXiSvVEaDQmYaVoiM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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHs41AkXHhXFWumeTbKiNtmSbLNJXokS2k/CztamqZR2IpLasqFERKw7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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGs41AkbxufyOpTDeqshSRubnLYccghbbluolk2hpVLKJcd6pRRSDpFI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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8VWsbVU5KVJdKpTJHhIqk+rBcRHW/S1yhMoRDaS4yZSpKRaKkkOFK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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Vd0fxU1JCKWoDBEhlZAp0ZKfJopoQqaSIsqQdCuVyiskIa9IGRtU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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk8lQkXx29abJElyvKqZGlPjdSU+slSkUlJlkKypqy5xdsQY7kjEZMU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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs81AkXxodXGbdSlFzeUEs3oi2U5GEzyJami0mhbJtctiLZqGyUipRb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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8VVsfxjXc6kaSBkNuCckVzSGph6jMY6QyVYZDSBGSVEJIk0oIoQwl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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k4lG0bnqJSKftSKZQt2RJK4pRK5fVGWkibaBGJSqKVVEiJUilCklTK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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81AkXximUopBWSYyKqQhbunwy9Yi36GZZGiUb61VJWSqESpMmzUhS
YsltZrNyiZDKtSYaucsY4za8Km/1u6iELi69O+8f53P+PM/5PN/nHGOfwF8P
z1BSUgpT1P/7+zUaiXOE9ZjOn9t2UJ1Cnfv1gCw3MQKTnY95S0nM89/1uXK7
GJ73VbofjJHwjtnqXe1SiQquRtPE/wiIrG6H+GrzQQllO5tsCahYPTyZ4NWM
l333Z44HUUizkfLWdkigq/89J+cPCpuTP4afJroh/hJ12SOXxvPVLxN5Q234
VlrWxU2k0JY628N0RIyJ8M+Jg+9IROgXDrkxunHPJih6pJ2Gt9lz7ih1A1N2
IXHWewk4LXu9Y+HDBlx4l6ISr0nBwNd9XZZOM0ZiTxqPGVFIWWhQN/BLP2yv
BNQMZtJg8CuaPNUq4G5bLjymRSL2ZLxJZ4YY6Vx//7AsEhXpKqyD8S1gF289
pfaJRDWec1KvSFGsov7Id4gCBxXyorcSWLW+2XXuBgXGgWTGVa862BSdkadU
kLD6WGmyozcbkvhB/dabBPyKGZ9lLypxqWoba6MZCZl78zeDGhlaQ9w8n9yl
wYkziUiqbwGDJeBRmyiUGVhqjcsK4R2+D3caCFhrTwksumV4uUd+nbmARml1
etKTI9UIxZvN2wxJzC4JzFZeWgsr0xfGF9xJOBmLf2GqSeEW0x+au59GP3tJ
hV99Oyrf6RSJTlOYmie697dqLYaOyQShXBLZU5xs66k2qF0S+B1mUNCyuzH7
yW0ZDu1dkB9/lQZrS8q81zfbkbcve41zEgXrxMdDX/7uhS73UUar+jAmvGtH
Rh724Z6L4TMfSqH/p0KdpLn9mGPpOPfbtWGY66Z9ufhzJ/zna/KfnaBhOxnJ
07h6CUqtFqylNgR+N35/Y71ZB1hnOlrS71BIFkqd43nFqL7jy1/yjIBzI+G6
PSMNZgvkM0sDCMSM3zu80aUPudmOt9R1hrFIJXqAX94B1QuRTK9FNF5uOjpv
Qq8Oyk5F6pYDJNy90uZvV5HCKr/F5PlHCvEFMW7Np3Nhb+adYCUk8O/Lw35p
40nwjlsYOLafQNTT158itndh4LGU98mExkTs7lMFIgmY/edVWd8psB75tq4L
7sYZFVth0xiN7lNdW+IrqvBhht6mzmMkDmVHaWcQzVDjP33FNKXQ82rtylrL
RqTpKMX1dZLQerZYI9rgAUb1z3qpyglEXn5zLpzbgZ6NfRtMN9Pw4aUkivoa
ofOjdZbuVwVPAR+L/6XVjv3+rq9fKfj4dbptffDhGoS+zGA2HlTwy2P0/CDa
EVpmp9sWQqG500zwNV2CHzYsj4SVNOJtjzNCuGKE3mLMGqsmkZuklfB4Wy96
4s+XRnvSGOy3KLhSL8aGhAnO0XoSUvtdfGtOHV5HrtAmPpD4xH6aeiBWhELn
dVWpDiSmGZfKdu2Q4LfvPww1Syjk+K5Trj0uQ0ZJQWTGAIVRMsDv97NyKPer
MIM4NIIKb80as8jFofuGkcw/CZRVvVo2oNEDR8fkE3rDNIb2GemuUK9F3nXR
twdXSfgVLFTTnPECUey3/v2KPGo8TfW58E6EVUmqDj4XSSxaPjl+PrIWguH1
1cwbJLIcNgVPhj3ChheMiLBRAqGZq79tdeiBR8rurtOraWidSfr5trAAaRYJ
5e1PCAg4RcHc91LkbakJFITSqOndo5pT1wk9aZlyeL2CD5udSz6UNmIRuz2t
Ybki34v9/lyilY6/7i+7Ryj4a6g277sl70YQV5CnTdMQ1C31nDgpQ2boNf2Z
JAXeLHvDoLtFWHs2xKGnQ7GvPbc7VLcEhdHz+W3/JRAQx7bs/SqDa1Vs1Mg5
Cr5dHnq7Rrtht2r6icU7CkUiVslHAR/mvOFNhB0B8znMs02uHTA8kxkUpfDL
zsiqZgFbgm72hais4xRWOJzLLNwux6k1DXXW7GEEWZZ/Lm6W4WiFcWCeLo2c
4MmsR7HVYAUvV/+PpeJezCmV2y+uwHSkxx29pSSqym0tfouoRp6LMK7PQsGT
sFM16m077KUiu44RChk5LvyQlR04N3l8neluGr5V7JIYVxEkb+MEsX4kQja4
MVOj2/BhoP2E4AoFQYfL4kJHIfTYjw0mzxKoyefvDQ4Tw+jYkkCvYMW8HaWe
+XvE6L0iG6yJJ6F5flWXdm8XnFV9d874RMNztOA607wBf5RX9kdISNiaz5r+
WhiDqTfRLvn2Cv/ck32KjSpw/GTTZV9Nhd4Da7xZR6XQf+960M+MRsmpI3Sq
QAKNrKYOzkMK3CM+pbypPoi8ODeXbx5GxjUXC9O7UuzJy85sG6Mg2wOl8LYH
kGy1vqjcQuBmMIPv+lgCFVXv5QFdFD78KNV1+izHMtYKtfFYGkomuWEcrghP
na5aHopU5MXCXXutUTlWC3PdWTMVeZUcka6YbsRE+mHx7kESUQ8Gl3YeEmN/
y4xRdcV/mHLaKWcF9cAtvOu04ysa/wDWGc7r
       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk3k81IsaxkVpODmhRXV1k46oKGnkcOKZNIp7teF0xpKESQctKmtoIttH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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4ldkD1q0kWW4aUpZkvTNXE5Gl1GtLNNNoJhTjkcaWLPWbQYiopAgJ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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4lF8bFkohSSVEVChFiShRNyopEqWolCUiFS2ItFgSoaKkUJZSWUpZ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk41AsXx1Woaydpk4oWST0tyFT6qtxeSnLpFsN1EeWVohTqCpPJbadB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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs4lIsWxl1OVLpQyiXFdArdtTfb5PZK4+HoJtkp7SnXjorEkaSUM2Ko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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk81Okf16EQlSMphUiuEq3WEr2npkiRxCJbyZFjspOMHKmwhKxqoqRW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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VV8bxQ2VkKI5+VWmEillKkMrDVLIkNAkylSUIVJSaTZVNEjKkEqG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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHs41AkXZqql2lxSYbS68OWyk5IYQi9f2qZcm0QJIYXaIpdISOSSEhLd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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVWs4lAkbnklTSdkUUpJSJDqpzYW0t5KisMyKElGboliHiqmkqcjwJUlr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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lekbVppUclTUqImUNZGTtCjctmSpLKETQ5aUojAl/ETkVAhZEsZY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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VO0bptSXFi2kpGz5KloQyae4KUmSbJU1pUSFoiwhQlJIKYWSlEKS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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81fkax9FqK3VjVOrQSFJkGSoXn5Ol5kqTlEmWCGG6RREllTUmyRYR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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk4lAsbxjW0WU6RIk19aVWRIVHnaO4InSxZ+o5TokU+SXOyVEj6YlqE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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns8lOkbxqmtFIpaOWw6qLChQmNnc7imkkMhJMWGpZrsJoMVNhRShKVY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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4Ve0XxUeDX5MpiiQhSUhKGqySMjRJpZRGRRnK1EcyliSVlKLILJGx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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41PkXxy26aAuVLOkypNJtG0zIT96idKErSroQVpFKwgrllmtJmhS5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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81Isaxi1Nqnus3SK6yhpRH0dOWeJBKgkdkhRCIbKVooU6LdySI1TX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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk81Pkfx/0iRa20qd8mCiFEJJXW8ZoRouTaCYtyV4rJdmxlrcSSEitN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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Ve8XxZFKIpIyppIGQ4ZIEi3KkJIkSlSKRJokokgoJalESUlUKkMk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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs01Pkbx6l0VQohhIiwtWxJRN5iKKWbyCU7VOiyY0iSVUuxlR9JSZqo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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVHk41AsbdaUu8V1KKLTwaZm06PYl3YvDJXRLtHhKC1mq272KS5F0b74s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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lV0XFXozJmWIJDI1p5LKp5ZcigxFSFKG0O0lGYpUqPtVQjJkiCRJ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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VV0bxhENMkUp3spYoUmSZLobhBJJokGlNAhFSoa8FamUIREyq0ik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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHk41Isadog2OWU56SpRTpRElKXoNW6pUxIixmlRBylryi6hLBVKOZaU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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs41AkXx5F1W3JJslGUotsqSyXJVy4lmtZLuS3r0pLUiomk9FIUi1zC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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lekbxhst0zKplDBiJDtJipBckuVkrahQxpLtZ1RGkqUOLaOIyRYy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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8ld8fV0YaRhIqDSMhRKU09EaFUFahkpSRsqJIkiQkJaNoKCmSUZnX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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk81Ikbxxl+pfhlJKmpZh3LtkqptGzkM3SRFaE2IVRyTs4dV9GikyVH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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs81AkbxaeUVEgS1rrkVkahLZfeYk+3162IsVldlndJal1CEcU2iqzK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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4VesXRkKGqER1VYbIyXglUfJSpswRGlQookFKl4SUS9FgyBGqn6nT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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lf8bxlGSUWZGJEl2KEXmJUlSRpIULaVEQyWkRWmQ1bayQ99QZsjO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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs81AkXxqWSzV1TSSVkQ7lEq2yTHk2876QW0YYoijTkVklU3kgJW22x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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGk81Isax0WSJeFYxpKjwmQpN53KcvOjugktFJLtDsVRpBIOJU2LlKND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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8VXkYxg0qLSJFmrKFiEqLphKeyEUIubKlKFeljTZjMtUlbkINhYTK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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8VH0fxiWllO4ShbJVJFSylAoXJWm1JCQtdpWd29ZGixQp6k5pFVqU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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs41AkXnlLo+mUqal3brf2wrbC7hfCmQraJrljJvYtKcrdII1MkDVGb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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk2k4lYsChTWIIk6ihDZbSk4iKalbLcXN6ZoaKA0yJNVNOBF1DSmuZEpF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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4VesXLpRCoYi6laFUV+JERaY3DSIlJBVCRJLMQ5Mc9AsVqaQSKlOn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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8Ve8fvymSfJGGUFZIVCgqo95UZDRQRqKQpGgSffGNEtGQpBJCMopI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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs41PkaZ6IjOSRKKbk0plFn040S20ctg03lViOmqUQuR5oucinpVEqo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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81AkDxifbocOxLC+pjeXtcFWOPlI8iiZJKUekEhWhtlGvc1nSoUvY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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk81Pkfx0e0NtlCfiL9WrUyHWgqpQMvxyTZ0LoXSYfIFiVUjsyWcqxN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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VesXxgklIhkKKRSNiiIX4aFBypCuokSpJN2QMiSE3IarVKbMRIRC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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHs41IsWHRQhdDwrj0qhcsiRV4XlxO0UUpJ7QqU6GKlDHlelrkdJElGm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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs41Ikax12W3GISG/J0yCW1S4esSh1f1akkJbprK5wQ2ym55ZRKF/da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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4VekblYrTqJQxJbdOYqjjUkOF1CpJoSi3OH5FUrnLMDqEbphkxi2X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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k41G0X1ooiVKoXlaVSqGgRottWiIgSSqWFFCmVUF4RyZpIKJRdlpCd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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk81HkYxx1RJJUkkStlI2koGcSnpltFqcQSurWJDUlJyuTs0EqiLSpy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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk3k4lAsbxiedU1mK9k1SUU11ihJSubWhZFTKdqKTNCRbx1EqzfeFyFJa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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8VWkfv4UGrykheUMhOyFDltJXZatouRPCtSZKKkqhjAxlSdqm7Mu0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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2lcjV0bxRMlJAqRoZFKoUEqGhapVEiUCiURoaI5UkTymCKUQtIslQzN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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwdk3k41Ykexk/EqGzFY7tS2UaluJFB6ZUMkso4ppGaFlcle7RQh8d6RMZ0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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlWs81AkXx6ntptbWUpLQzUOeXfdkNfkhi5S7fCIajzvdLF2UyS1RSLJs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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVWlcTWkcDsWVhopSMpVL5Ir2pNKTSkpFtEiypAkRUknNRDdlWkjLVLpJ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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lG0bxpFEZCkhpVRSKpIQUqfKFm2ikEKFFEmiFJUSZXltbaSytiF7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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHs01IkXt7IjpVKRlGT6CZWebCXqs+W9ZMUoj7JDKVnl2YotoQjJoxXl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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk2s81IkChoVNR21SubeKNs1WahIaxb5uXUi508YWIpeixNHU1NKQjbQp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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns81fcfx3XW6ScrEsWkrVAdySWKbS4vWrNIRQhJrZbdUIk43bBISHNL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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3dcTf//L0WliSIt+aqEtJHEMw2y0pYRIakIqchIQ6qPykgRkhZSae/S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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXtczFkfx4fubREVuVTSxSCX3Q0rPT6lJG1lQ1bJE4lVapsu0k1NYVBI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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGs41AkbxpElJVJtaYvEizYVmzY5rHsaUdnCChUqOUQ2OXUg5NCBvNZx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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwdlnk81Pkfx2c7WK2UHLVFm7Oii4iSXpItHZhaq3bdZyXXOsqZO6XWkYyi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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k8VGscRiUhoiJZkpAoe6nQI0uqS8mVKCEtVFooKhUia5KQJSoiEiEk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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8ldsexneGo65EKslQuobKLXSlaPAoyTZFToMUqUQkThmivRUNlFLo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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk81IsWn+rWbaOoULZMo+1qfSVJfbmpkGVK4UbSIhpZelxZmhJaLilb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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk0lWkYv6lpmYayVFeLuDfSLsuklJ/KlDUU1SiHbkyyJ2NN1tBCWaJk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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8V/8fxWWmJJWMIhpSKVQSGUehrCT6SpFRkTS0h5VdJA1RIYlSZsjM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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs01IsWxyecaJJHycWRtzh0KhMmlC9CdFNeKUMqlaZTiYrkKELIUsez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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVHk81IsWnxZLNYaSJbJUKJLQ4zHFV6U+dLVQRMmVS1e6niWkK1kaSyUh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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns81OkbHW2qVbonlxJpEHLZLqbIcal0kZBQ27KpKbeiUomUldv6qdWN
wVSSKWpHMRJGzLgNsWtkJpNbstb2hl8pJSr23T/mM5/5vN/v8zznnOecd3R9
g93YkxgMRgr9/Pe9g3kkosKnGSuP3FYsdCJYw/mnwrS2Ff6Vvc4xNwnitGaK
chql0Ok1nhGxm2CTf9AdT047lG8nK80RE3jh8YbVXgKY2k8sPLeCYObEuGNl
twSvRU4nRq0J9j5u0jwZWYclrt/eaHgQbIjasq3s5UO0PZo4JTOmv5nWL5zu
tKPHIPLB5QqCd7JLAunjMrwXFGRyzQhs690DMiVJ+JA/ePDKUoKQIrP9P6Xe
h8mQ67TvDAgKe9Zd3blDiqwZu1Ls3AnMq6VnWxK6sLrb7+WuDoL0DQ5Wl2Ol
aDl+r1Cfns+2NbObW9UA1ezNDQOOBLX3mXcD2M/wNe9VofkpglLGrHx33RbU
XgvmxkQRJKf6h+WO18JL442qEAQJ3f16vH1i7HcrVlyxJQi1dY3ttK+HxcDS
Sxxaby/7LL+3+jkyfIy6Io8TLH0Rn8MyqcMkwf6k/S70/T9UU1b5CfF60ebe
iVWUzyJ1jkWfAraSTfu+RtN+4eFsTYYc2n9qeqYEEFgFD4SIFzRi+PyjyN2b
KN4cMi/tmQxmNze9+9GXIMw1tPCoTRky3rh1800J3AyD+27+04ojTPaCrMME
D0MEqoxzUnzsXF74OJjgtR73+paiZ7iww9q66TxB1Pvyy1HlUlTqjwnyKT9h
PMsJ7qZSaDlrXLKk/HdMVTk4xUiKuCk6S39kE+jwNmUpTZTixpTmYz4rqV5u
10an9qeCd/Tgr7f1COpW593JsnoBPsc3M5vW/9p/byhFXI2BD/scNVj0+QC7
N846CjxYWXiJ/zvBjF1JQU7xEvAkh5X07Ql8nde93GhWipJvSv5v6T6tz26e
GxvQgeWx6xPXZRKIziWoLfj+OdTn/uCtHkHrDWzljTVWYLj9uy/zLQg2Dlvo
DfnJIU5nNqmfIfDM2j1e5SjH3sb2ekOqx9gyzxt1NV1QWUWOiD4TeGhlpG+2
uIm1rZHpY3R+G9aqMuGnFgx5NcsPhxCoz1DqOc3Nw5ff9Kf/rk/wNMR0sMdY
gcFEhzkpxQQHvOfn6X2pQ2vvHbclngTSVrXoBv88TB76dXq6IdX36VSL7ZmP
kLBKg2W+nJ4nLZhZyBLCo8LP34fOezVu4ZOWiy3w06oOHwin/N2aOBDvVISj
Q+YXDE0Ibpz+uu7YiAjMomzvWiuCib7X2l1LqsBiLxIWryYwzB1U9hhvhpnp
pPd5FJ9mSfhfAfky2Pq2cLSo/rkuTtvPjwoRk9CUbED1iikwGuZEydAwqDVv
/BLF3z8lbb1nJz4m6hlVXiAoc9kwnJnQBuv/6bCT46jePruix7quoLTaxXIL
5cdlQ+0e16fVOOHux+9aQ/m65ZtadbgILXz+PT+q12zhYWHwKTHKlD+ZbKP9
GEYl61jX2TiwUJ79PfVv7+cHTdWOjRjQ8JWmOxO4cl3rtljLMPtuMIN3jiD7
xlnnB4I26L7aPUVA88dvz9jtotAudDRUae9IJSg5WW8g//YM5lHuRh7UrzOz
DupePiFF0K6SweEdtN8TS/cdozL02UmjNRIJONESg1bpXdh3rbq6nup3ZuVB
4RONKnTeSrW7Q/dR9KTJv+99Lmb9PSGupHr1vpyf8oNuNZI2S1UOUX8/5Ha1
NWXUIU1qOBzsQPC2O+eTzrgMuU+3Fcp+of1PSEYZQc+RnjF3+t9cWm8te5/3
TjGSj/IfHF5L4PS8SyZfrkD2bgOtBj6B954gJ7KuFeoRw7h4nT5vF38+LqoU
2kbM8WDKJ1stQ2uFhxQjCq+6zl0ExUFmNQmaDRBklEWk0fw0Z9kHq78T47Wh
4AjDjuox+4JyUGYzZpy62DZrP/XD9kD7Sl4BYixfTVtA8YSVX2v8XsLF4q2D
xVOXEQyv/kN7W3Elgjotan3WEzRqOE26EPEM72zVYl3p+/NXXg2LZ1YB9S2C
HIo3KKTCpSfyOcq8hJbaaTQvaiZPiktvR1yg7mD3nwTRktGW5tpmqCySGTn5
EOTNjahJnClF+auDI6F7CX6bJsjwbK/G3tNKuWm0XqbFGumj13fR5ltqV071
OPuTqmS+UIpjjCK9I4EEOccGTYpY1TDpnyfm2RCa+6nVQ1VN+N3E5YoJ9Rfr
wZRbJfdrcGZZ9ORLmwlUxOVWPe5ypOi58Y9zaP3t1+z/f6wJt5ixI24/Edzl
9zOd2S14d9F1pw6tzymTqPjvEaHmjchqEsVfw12TFTpegihWb14x9WP0hkSp
PKoKiV6bPwdRfgvF+sbK6m34mRM+JBTRfBbFLHTozMKVkq0D3UwC7op3zYnN
DbDNiEp3/S//JT6nwy06UVDlNbownfa71Xd3Wagci/XH8tJSCKZtayt4SPPw
yXh0TvMWApMkS+1hh1oI/OQ/3NxG91/L2DL4rAxrEpLKdem8vbkpFdfH25AX
ZNhwvoret72iwJtzFDDKZ/hMp3lhy7a7k1XKhton/7bp1F/LVCazLL7R/RiM
Lo2necqIUe62soxB2tZ8hRs9D5VUPA7seYqWtEfKTfQ+OXDtOIMXocB3n0c0
HeKpvvflWxkVrRBn1tYbCwgS33JGRIcaUWrdOMuZ+lWRHZvsvaIWPsmBNvMp
3uEvDrrIr0X/R/lYDMWT1Ge8kZXaCY/fIk8GtlP8PKsrXFM6z8xQR3uq59pB
A4bV5Q5cnZPLE9H6I4KKDrVeKWzf64V0utJ9Fkd8sFHLgur1V2rxlF/7pFfl
+rxOhNus/8Cn93l3q+YvSh8LMPeJ9FMuzUev5owvJaoVeFb92V1sTrD1nrdC
pNmOt6np9YNXCWRxSUaT6X6FOsZ0Zh6jfqpS9unPfIrFcd9Ou9P5Q/oFJsNZ
KViav9Eji+bbed5fMRH8P8C8z2aKf6T8cTiKtyP7cWgorGAG5W86dynnUHgl
AhZ43Sik+RFk6t0edbsePxPlh4T+P9gedsPQxq0DDcLFbv3ZBP8C9EbBXQ==

       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3kgVNsfR55CFFoopEhEJSlEfYSQsiRPqCRLqWwlKUuI4knpp4WUxGsl
QkJIlrEl68wYe6hm7h2pEG3kd95f88e9c+455/tZl7v52XkKCQgIuAgKCPz3
+zXM+6K2ezssCioiVjpzUcGSqpuxysKXuZY8WoNGq6X6TeNlfWjIuWMztI2L
+K+DnqO5Dbji3vvJypKP/A/JEbGJ7bj7m98yvYSLjiOfmmRk0nHzi27ennU0
5rxi3uYIlmLsaQjrCI9CxIe+8+XqPvB4q1vyYDmNq3OErsdQdWi2lnPY+JzG
/EUlaynxbhTmexnGFn3E/WC56A0/3kAxP0z4sxUFL41xltniOJjcZajZr6Rx
5vLnHJMthVAKvITl9RRKQoVvZ/DZKAv78ktMehiWWuOKwu8qYSgGs4PfKfQa
Z2WHXq3AvRejO5X8KCjV9pX1HGPh7lqLPUvm8DGg8alQcV46cn6XnzJWpGH/
ULQz7ns+fLIPZKgNUXjalzLfWbMYa9gm89YMUnhpryx9TqEaoRP1kXX+NGLc
Zve4Knei49reezeCKDjMKIrZnWFisPBDxiI1LoamcvrFPnVhvMch5Rc579Ts
9KsvEtiQdz4UcFGLj+as+PPu+5hQL5y3+tpRLnLNdiU+YRagxntw2nwTDZFr
BivVbWqgedAkrmAJH6ZZH+K1G8vwzucs58UiGrmLROysZnGgu6Fx6CdN5lW4
P1JBoghqsqviJTfQSDTdGnXnQiv0/NQ+xpVTkA/QzFWzbIeL07mIm+58nLHU
M3/FrMVZTuXd1Zo0lkRqJzxRakLaY4PUtdU01OpGuT5pTbBsWGRsfYu87184
bPiRA6bcxEOjmxTMEko37Tnahm8mlHKxKAX/Rwz3jvZiDDYn/+DMpeH7V9jW
+c+qkPPouLH+Sx5cDtqtTrjOwCL3VgnjYRoCITsnTC+nYG+iQModcp4Inkem
w/pM1I6ESv5Up3HFa8lPLUEmgqXdHKwTh/E4oTuq4hMTV3c0LW4ooiF+YKPc
gogaBFjtTz5xicZAAhaLDDNQcOvwk+sjPOzvbhA9X92KzPuKMckEf7N3/XtJ
c2UTGH8EDFL1KYTqXP4uKv/f/k/X25L1HOXC4yXsGnFYOCFzZzqFJI/vBTt3
vYJbmrcT5xGN/mCdR51ynZBm/Sl8epWLYotvuw7OrUagqnqH72MKnVlP3gkE
MmC7hdZd5U7D++Xh69nLq/BIMk9F7xmN4B3RETNL+yGeZLC1i8y39krEtiku
C6dTvgk5Wg9jh2EzVZ9Nvr83NpRXQeFPtsr5/1Uwcezj7SqFHD7uLLBRtb/Z
B4/xyh+bThI+aY2qUYxWeKG6JbyChyFj2eh4yTbEWh5q6bhFwdn+iY3ANhZY
64MyT5J5K5VoiGtkZ4K3qqPs41oaev82ma/R7kZxor5s5AYeri6Z1JZ2fYP0
uc2/9tST/Quy7fsZZRCxiPqtaE2DMbFP7p/QNugdWqx8hPDLOFJ491NFJqJf
5v3JPc3Dirk69zot2uCd5nfPyozGVuPRJT6fO2GX9S4gl0vjaPerTYvM+8Ae
Xze/LJWH6Fk3tgyEMCG8/2dVrccwZIvidOKz2YhabbuPse8jvhYXessdfID+
paoMeUEaGpddvkdqMtEZ6b1f9hAfk32nnVS66jC+2bcrmEPmb7aTWifSBg8O
O3mc4GePfelc0/IWGG2e93fLXYK3yQfrLQLjsc2oLmyQ6ElE7XfLUpHTuHNX
SqeO4MOrd1Mi99pzCEhGKx8JoZFsdfjFX/OK8HWDdeE6msKxX4+uOkg1QCRo
y1uhDxS4t75ZzE9kQ66+XkDkBdHPmeI/2ga1yGGY6//OI/o3ohLt/fYEFm4v
nqe5gqy/YCtbwLoUQUFvwlJGKMw1D3aAZBXCO2Qkd5L95f7kbTaxaQBfDL7a
b2kcmmyLPyLSDdpzp6HfEx4G4mnjFeaPoHxPIqiC8MX24YCsy/R9ZGjnLrSa
oaB6NvZORVgvVr+tVu+R5ONNqEHWShYbwqNXBJl+PFQYH9rz4c8bGC4xiVt0
hcanziMw38/BUdHTVF0TwXfglGUN0bPFRmddD78meFE40yrIaEC8ZaPeaByF
O91BwT71HJhJSR0NzePjev6zAycdi2FTsHWuvyeNiieqQwuZTRCId5XZMEX0
XWs7qu/1YlJ93+733GHc7ystKtxaizjhzwl5yTRSFu2+MxnCwfTeKwddz9HY
fD5m3+YADgSKB4tKnw2j8O7ltKmEBng89+F4pfMxxr6e07yNjVJpn4fC64Zx
1M9w5rYtBxFTDCOZGoKvgdxExnA78n2eJUcTvmhZ+c5+X9aAsSvFkXPDyX7C
pp1PnWuE++8DTiNbCZ8kX1jc8XyLKnmXezZaNK7rZwvxWlgwFLf6Z99NGpbb
9X3DH7WCul04k7aBwuPDcs37VXvQv0KkMtJgGK4buCG5RaUQcJoTfmoOwUup
161/7RsQtcDqdtgpCm93i5St2ckE93dP4YgqjQ8MC9OVxdWweCfUapRNQa/E
MylHrxVrD5raXZLmI2PArml3DAud8YHfjB7yMMWWKHucy0L29+gks6M0zIfl
Ata6shHirSB1TvcDKkYGx07xEqFgNddmvxLhpzwdd2yG+BOvS/RGKY25sDuZ
xG/H1jdb9Sr3DmPjczPfuxwmplr6VQyX0ti5XE5xLJiD3KTZcgYuNPZrJr89
/Pkl/hqPLVwnR2P774rea55dUKvZZvA4iAYnVkxyXlAvDkdgVu0DLpJ503im
UQZGoIvVrhYKjUfOn+QQf1lb9nv6POHHwMIbLLU5z8E/uTxSNZNCPPLzKfd6
opNpXh+IfujtcMu+YsaB6ayANkHyvlIof0z36j04hM6o2RjQoDZc1pa5k4e7
insF+6VpFDMG9ggtzYV8tjdHn/gVY14qt7y8AjWeO8QDCJ7V5Ca1zIOKcPrG
qNLgV8K/ORuVtRilUHlvLlfaQMHa5075wgO12OSQlRhdQ6Hce6O15GEmRC84
SAkRvtW+/KlWYdAJl1zzubuJflT6H2CF7egB511tiJs1F5YvokW7l1TB4fZ9
8VVqNCzCPofJSqUgr0+1tmwZja+OcZ3slgKEKj5oGp1H+Fl8wFzmRSJiDtuO
JqgQ/I3dV9+7gw3DiYjtw8SvuF5zhEu0OvB0iiWXUs6DE0tPYqqZiVtRbUGm
fSQvuBiNHnJvwlXGPiH3aPL/8BQp3ddFiHdXCShqJOebTDXKNH+LjFmV74ra
eVAJc9DPDmaAO6R0ehHB81WNJcW1UU8g3yvDHFWgsdL6iXk7XQ3xqF+ev58T
PPvxG2sM86Au6uFbKkRDkcEUfKfcinc7AveWZJDnPV50xvMCbHr203ToM4Xr
Bj/fFz7lYL9Q/oKqd3ys13a0uypXgd5lf33+xaYgW3x94t+YIkTTL6Q9yf3f
1w/YsFmpEzYmq9S4phTyHVNLsjawcEfsghNjiuiRjpeSbU8Fkh97STwHhYo5
p4aHhy/A+lCkzTDJY9bfm4+PxXfhlPSfzCNCn+B4w2u1a1sePI4luzEMCV8z
kkNXWtfhs9XEqWeJFExUAyPnVLXBmRto0a1DI35C7n+H6BbonPNTT0ugYXQt
uO7C5TrkSgwq6RD+1XvtEN11thiPb3wqzNlD43aMp7T77T6ck5G88GCc+MNf
h9OGEiKwYOryH03iF0L0U3GX3io0Xl+1zSmKgqhn4UjyeCPW9FXVjzEo3Ltl
bsc0CEWsUMlzX6L37xdU69owOFCUuOyhkj4Mo8sL/YwnmpCw9EPxzc80VoRr
nWP9ZOJho0fUlkgaBaMKF5ert6Gq4Pm4JdFjL1uOjJEdC5tm/Fd39FOwtTJ3
Hb7NgebMCCfCi48J3Q7Vlxs5uOlquL7rbz6KQ+j1IdHdSLkbNy0q+wmfjTu/
LsvpQ7xAh40Ig4+/dnUtk/atg3PyhFPiGeI/Vh+GmyTr8Gfl7h1dxC/mzDyo
k37ciW628uSpAAqbLCI7g89UQG/3qu5pkhcCU7lpk1QubqjMylK3odEroOnP
62NC382j/Fs1H4ZPxaRknufivvLX+8wFNI5JDThqyHQic6ebwsQQH2Iuhh1x
s2pRmryrRG8HyR+zH+lV/6pG5e7aNztukP4Qby4bXcWGNpu1zvAByUtpCyv9
rrYiNsasrZZP4Ydr0aAB0Y+TlxkWjS1kHj9kRWMukTytbC12TGkYA/WM6rb+
asRuHXj98g/RH9MXJbGKhbhUXFIV+pvc3yu60O9GKZ4V7ajI2030Tsf2wvwG
FvIeKZ9I8eVjq8sS/UMvenD9y5hEVScfC8YyNJKU69BVIDzNJvpbdv1v56iS
dhgOnhtQ9yb4EBsMjHLohuPxhezL4jQyi/dMbd7YjuRFi6y2r+HjwDAjOcyq
C4U/Qzz747jITx35nrylAv9kKz1uIffDPZotr7GOjbE9n59V2PJR1bJC+8vu
HlzZOBG6kzyPuMYtX9/TAaZ/Gcd5L/HHH7GpohK9+B7CUtoaRPynzMTcZ5SB
XpmkpH5H4tfCZlrLmh9jUsvLSoT0sbLDJ1eJuFRgQXpaDOsVhY5FjiVuwT0Y
19o7p3PoA4zU3zqLJbyCa6//TE83BYqzTK91fxeMIl6L3SV+OhD2Oft8dyeU
IhwDFxK/8A+kTh+pfomYfc0jukQvehF57XhiDS4quttFEbwP/N0w3rXmHryP
/aimST65m9qb45TaiSRtwbmJxG9ZRTdk1z8uh9nnHba2F2n88Be3TfJ7Dd6U
tb3pIRqpBtNNKW4svEmbcNV/xcOxAaGd/dxKBDSt0k4neVrzWFrua+u3aPzF
Tmv/TvLGkY1P/vW9h7sRnfP+JnrsYTX3t+M/HHB71ySuv8qHQfKJyAOvusj3
RzN4B3hId/azF7PugdkR1pl2fS400sSn74qXwrT6BW90C42nW81nDi9tw/wJ
A62mfNL3GK/1xGU4uLU93Oa+E4VTdStktBs4ODnrmvtZkofnJbivcqruQEvO
ysnAbRQEPkQI7z/jBPuqmwcsyH1I5zxakCDYg3Nl/2Mnkn5oOnhItzCyABde
lxak3aHQcOrDCpuCNhQN2tgG8EneENhy07qmCbWd28weET844avevmp2G34s
ch1ZLUL6n7p85q+HlfB5UrxYgfjxxQ3t+l0FrQh8pxVuto6PZbbT225FMeGa
a1vF3TCM61MebsG6bHz9FDMg85ZC93rGnIt+HGjHRp/xJvspGMruWz7nBnxr
nZVyyHzrNzc5/vn4Bt2hV9a5D1CIlTq2YTCpHO7n8wycy2mEPrA91Xy8BdaC
+tmxsyjsl7gl3H+2EXIBN14bTBP8LWav5bxNwMnvG0PEid94/WxKl3nwAqn7
x8+VE/9TVb0Wm6fciBnDPwrHSZ9mVGhv/JLXDEaJjMxQMA3D14dU9EZykX/q
x0jtJAWjNbufqZyPRPiW4LY98qSPuBnGaV6vxNP8jOQYCeJvxocTaIt6WAY5
yJu9Jv3zdnGnBunPljJLr2wg6w0UZqQ2j73CgWb9fq9ZBK8+5u8bJZthur48
uD6YwtiJr5pJ8+uhSE0knFMk+ikntWTaoQbG/LjgbtJXryZemu7R5uBbqaKJ
xd80dBCZ/ndyB3TY8d2DP4chpKf1ZHCgEfMVik3fEz+1UC4WV7bMw8F+qQMX
N5L+fSVZXvUWGym+mwVXy/AhwDzSX6abAjs1U11nDaJ/0+5O1mfqkHOzxSve
jYdkyUxX8VVV8BL1PSUvQEN+Y628/5omLPj2qbhiFw9q74dSD0q8RvY/I//7
KkPDQb9CJ726E2EHg0/I1nzEj76EuWv9GXg+URal0Usj0uSOl55EP3S2NOzS
D6AhsTRW0bWlDe1JQtfWkPM4hph/xAgD11k252JV+JhSlixO9ejEseKiCc5i
ws/xJcbTmXWIqi56LfWU5C3BszW90zWIDyqypH+S/sz8VFq6LhP+mi4pfC4F
Ed3q+Qc4XbgX/yy0d+FHeBgUzkjYNEJJVaMmU46Pa7O07XyY7fAoSsuqu0D6
mNK1v8UvnMNCw+NjniS/Kj2w51kZpEDHrT18iOTPn82Bk9deduN8bP19DuGL
c2j4nxcxlTjuE7S0uozo4yDrGffhSYw1ysz5r9+X/xnTYX+rQ/LLov3m8/j4
8nvfgg0XGDif8jwqnejLPfPJj2UXuv/TnV1HSZ6U7zqSaOjbge0nL/mZ2PAx
EKqy2+x8PXRX/OJx8/lIbv6ukDnRiMrfku1ndPnoT2m+9a8nCyc/Pml0Meej
JCm5a6UvCwfWTThl+/Lgn3a+WR9MbMwa3PSZ5NcrASsU/Rdz0B65aYHjfaJP
1pOl7+7VoiLrUu74Bxo3nQP8ZGezkJEqyFjOJd9f29KZrdmEpBMx2uxvBE8x
Cq2NR19D22Th8iGS/5pXSvn+e/8hWjzV0p+uoWE8a3vBY9LXZgvYHWTbE7zu
sxvNz8nCiS8n3kSt++98sSs//68YAuMWDipknt7+cQuz9rTCONyhvvQIH25f
X4mm+3VBR+3498uLKSSmmRyRL2BBy+34zComH+ct7rhUl7HQ2BOyti2J6Acr
ccyF5LkrJ4X6pX6/h3yV+JrLdUVYbT9KhV+mMNT6Lpbt3I6VQmOsL+00qr/M
Oqq98Q20hoRNfxQSvslezutRr0SHiNFzngmZ/w4r/TCpQMgOfEG9Mg3ZToG3
azI68Csud2fuGBehZvFbBGbYxH8crCtO0mC7BVkmJ3Xiwem4S3Pn8HDGVUrt
/qvb6Jc21OrbSu5npI2Zl81BvefLCmkjCvbV7j5W6YVIYTwNMfpE7vNgubLY
tgJY6D3jzyZ4SNZpF2MVMZFR9ES4qoQPfyv7pd4foqB7OEEyjujV7GM9WVeK
3+CL6fDU1yHyfrXC+xEWk/SULUJC8XzS01Y/miH3t6LK/bXrMT6CBZyNfLZx
oFu4dHFWB8GPlOoKg9tNqAyWvXmQ9JORkm7q7HAr4t6OTO4j+mytt8CYWcHG
GrlPXf0ET0ec4va+XM1C0ejI+q+3uBB4HD5UcP8ton+zVEa+Ez9sqt31QKEB
fG1v14sLiZ44ON36aH8RmqI7SxUJ/v8PMPUMsQ==
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlWs01AsXxqXo7jQllBJxdDmIkm7qISGUCCUcyRslEqOEKCFKJZ1kqERj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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81Ikfxh1tu25KSTHRli0hUjn68Uw6BpHJ2k7ZqEg/GR022lzl3EqS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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns8VOkbn0pqpQy1ymVdigwNpZXI5StRoiIkukgWJZQSlbSsHbIVMS7p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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VV8bxSWiDCkikpCZFKkkWkJFhlRCRUQkSaWBSjJkLiQNytyEX4PM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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81HkXx4fVVe7TFpFraJMkT9qUjy5CWjRJ0YiE0s6zdBNC1IaiYlVb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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlWs4lAkbx2n1pi2lE0LtiKLTZqUj25/yFqKG6KydVGojh9SGVA5Tb6JM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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXlYjGsbH2ScjlSnxHHsiUi7kUr5GRVRSugrDVG0nKgjKTUIhxY1yVDT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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4lF8bllRkKbuiRClCFEqJmxIV2UJEQmUpSYUkSVJpsySpVERFUsi+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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41HkbxlFCodFhaKOmqYhoy9IB+94SKZUQmXVeSZHCbiSphJUyOVc6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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs0lIsaxlV2RLsmKbdDR5G2iNKFksfU0I1VbLrI0RTOpq0tKomMUbtS
SCJUwipDF7lUxmVGFLkOGQ0zzFTMfPPNELoKbXLm/PGs969nveu33vX+TI+E
egbOVFNTi1Tl/5NsMcBl3VJM6z8oe+uthE7R6CW7E71wECTNTxqRIZ43kVn7
qB1uzRoOBgoCntLnM1ZpN2GPoDeCmkiCKVj+Tpd1Bvc3CLcpKAPQzOkOcBQ3
4fP3h3dvkSQsv2x6Wxh6FV1pZbO8vighGaZ1HxrmIaqh1iJgDYlxdi5ncrQR
ek3+0bJ8EllqTnPSooWQx9IPnp7qx9RV69UPZvfgR+M7Q0WFDHnRlanMbw3g
pNkyj8hI8Gw5CfNCe/FXpLt53KgMzmvsVi+pbIXxI9+fdDqJ2mzagRWVfIQc
ZNz7SJWDlTQeWzAowZpEvSruFRnmFB4JrPfuAa3lqPUrHQJ7XM2OxxzMQJ2N
xrL9UiXuF8X6MQNfQJB6+fcJVwXMswzGW5xLUVFCq1i9W4kSg2pjTjQXVetM
doq+KzBzj21dYVYtxvVigzNCFKAzqj/9bdGGGS7D50uTSNBzHnYE70qB30cD
nZKvSoQnXIhU+PNwZeW+fv4GEtEv3levOcAGxXh3gCepQKLvMpqjXRuWnt2f
U2FDomjfxOc/nMTg3x4zmc7sw7+/iWYvfloP/YzKf5ijJExav3L7I8Qg6D/s
1O/IcJ9sH7ubw8OOWvYH4xECasmKqnNuIdA8618g0xtA1AJLvySBCASnLSHI
l0CF3ymnG9+b4Rmf/lS8VY728oABz14BdtlWhpFhBCLJgHsr0qsg6k5eNcVR
YP31D+sShvmw7JaEq+fI0HHmEHdoawemYv3vbdtJgmJh+LDndA0qn7hRWdoK
hK8fsTV8Xg+zy083JNaQ0DnYml02qxNH+PWsBap+r82VS78m9mJvcd5JiViK
Duu3hZ3venHKPmydJKUP8Vt+Gr4TtsO5i2ymcAisup4T6pHcCcuMtQEn4mSg
KZzSg8ebcOWewNS/RA7Dhvmb0tb1INlbK4LX0gcfy4LLizlC3J6IOUttJUD5
MKZzm9aNVeanF4Q5SHF0R9nvVp/rkG6SGllbSiJq85m8gy4dYGf5lm0pIRCf
H+SekfkckmnHqAcBClz1WpEyVMBG8oYL1hJTJa7JJpadv9SKUVPHrtiZctDV
an/99EcX6HuN9y/6JsUIk3Z8YU830rV6C+5+ksIynSKP6esCYRKmaciXYo8X
jWLEE0DLbZG2yTECrMfx+eq0IgQEHg5XxCiRe941YzSRjSttj3deHFBgu2/l
3R5GNjTb6eXTrUpQPno/Y/t2In1o6qrNDTm2S36avCwpQtPrtnN6sUqIH1NP
/mCLcOvNxvA/l0ihuTzQfGamEINfCz4nN0phO89l8GbtG+j7eKgnfZXiZML2
OwsN+DgzuaWraC6BMTk1R9LWjO/l7tKl/6j4htfbbKm+h8mLcfQTd1X7he0U
m8ZcPKLz79uzlRhMDjvmeq0DEs+BweBoAovNrHd4DEnAS5hrPndcio3Vv6jf
0hHApPKYn0+BHOqMBWo+we24rhayldJDIHfT8DyBZjFyCYaDkKZEfo7XvnP6
L7Fwd7FWygoFqmwbnmkFCcDgHmh3/kSAlqJ1c2dcA8rM63zEf5MI2Eyd4SB+
BVYfVbumi8R2LZ+RBooIs1hWNp2/EODuDno7mdCBn4x3rcscCTBjqm30BFwM
bazTK+9QIF7dnWIRw4FRqFjvCFcBps6BzKSJFDguDeY2DyrBWzJ1+IdzOWZI
bvZFjimgG19aY1pRhydJVJcCEQk3esb6DPF9NNoZkdmhSjRE1VWnZql8Y8Xc
vGt5PxjaHjc/eeZDv8GiKadAiUg1i6Hduq+gpbfKxZVHYvoa68I2bht+a3E+
OttVjtzA9DyqVR5MGPG6RIYSEN/anJfYjKUOuk/TVXzOfnEMr9J6CCPC7rh7
K1DrufhHjW8xaE/lUwN/KVFx3E+pbFT9a3KYGussgVfeHqn1Wl3gBJWfX/BG
CpFFseBfdq8xOTfQhZtHoNS6Z5mtuxDf2gYNglqkyJ/0Nesy6sKD+BdOOWZy
eFkOXTAYa4JrBefi2zoSNyKrBYxMHng8YaT9JpWP0k5qzG8W4TrTxUbnEIG1
P1uqOCN89IUn/ubQI0OLkv7NvIGPaU2+epbqfs+ub3lSfLkDxzaJsr3XEDh3
UzJuvLIbD5emdb8Jk6LEkn2H+v0Zav5j1cpS+dE+s5Dp7N2Fo8mGXLWVcjDX
pq49zTqMppTBbqHRAAx3/rmk2L8Q/93Ga9IIUWKO+NygSEOEFS9v2PW/JKBt
R5fNsu0Fm2UV4XtKipCo5do+M1rh5aAItlD5q9Lgo6m9SSca7Ev2Lq6TYTzS
anmFdhvo6wiXiQYCc6/R0o8ZieC4L2iHk6gfJ4f5Ex4LexDHnCiJ8OsH02yR
/tet6cjbOvo++70S9TvcOOerXqNO3YA/8wuB/wEbsdSf
       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lVsXP2mmkkSpuCQlDVRk6NRPIqI4iUzlM1NuSKYiyXcoFSEzF4dC
JRGJQkfJLIecYwjxSbVFSjc3Rd39/fE+77Oftffaa63fsOUcPE2dhRgMRgL9
/v//GKay95/oJmhsOiO5yJTAshe/pb+9QIAmIzVOi2Bhcn6XJNpR5hbkXX+G
IHPUQ6NT9jWUpPXNE5sIbjKv7Rx2b8agc+EBvg1B4ZcFSis9nkNIrmhSZxfB
hy91JwfKKxE6YeqWpEbzlYR5Lrvaha22ea+i4gk6FrjP9V/SgLhr9uNf6P0l
JzzVfIzawfX7u9zFjsDO+q0iV7QSGqmi/ZM7CEoDUqU8qtsgsaVNJt6KICwx
rWaHRj967ee5Lo0gCO7cs6zHshODyBdOvkGgmrhQpU/qFaZa+e4naLxspZq2
N+8BWDZ7/KSVCI5PWUrlXupG5uQpmW95BEIRtS4G3q9heG5GbuYZAe/QVPq6
+R0oDiicq3iJoL8SH5Vju/CXc5QkHhO8rztw1dpcgL3dRWZXAglkop8OSlV3
4cM74/HK+wSL3m9QEb7aipVaOSsWHiNYHq4l7jxRg3xmuGg/na+b05oV5cur
EHp2/w/PbQT7Gz22sFntqOJ53DWxJ3COF/WXFm/HbemC+210zWsPTSgerMOL
8/qi21gEOUbSpW0TPEQF9uuJnCZgOuRntfg1YSZFXFZBl0Blqs7HWvQ19Dvu
TcbUExgu+SkxmVmLnZosMkbxYV0/uTzCg496QRUmgggY4VkbW+1bEBMfZ8J3
pPP61aTrF1KDgitbO0u0CWxX+1jdnMMDNz+ohulOwDaz1qwdq0NhnbS+ihHB
lcFto65MHkq8V5VXUL4sEH9dnCxeiJu6Pz5z19P83x1v7ArVwvumINlpOcqf
lwe7do/wIWSa7WuWQcA9rdnFOHYO7CP7bqqtJTBYNtwnLtUBs2FZB8Ypgqyy
o6uyhLtw+kb0hpMJBHGfMnc4rRbA676z/nYfAsnD5uHuX/j4eZ5fuC+boOLZ
frPHnVwc1MoXVdtDoPh+q3fBijYIj7prHKX7pwcNNNfP3EOQNPdgE62v3mKJ
rWLwM2jLHBDazyTQqEpNuCwQwPSv0cj1HII63bAex/o6hPgWDB2h8XMyF5Ms
dAUI4Z89VUTzbTH1iuoPrkO4yNslksYE2vZ9UVYVPJxPOqMLil9zzbpZM+5t
kJTf82mdL0GCyeX1rq3NiMp7Ov851U+25Pjv+Y1tOJgTYDn7JI2vMHoYxumA
/YaIvMZognm3+/fqORRjIJxd5rWR8iFGp1txugW2JoM/5en8K36bel0374br
jE2FeiVBkmdBhV95FbZZqK/maBL42KQ+FgmsRR8nY8yJ1ue/gfPBNo6H3qp4
hV1eBMtUZ1UmF7/C9KpnkT0OBAOSwS5Jptm42HaXX6JA9biQ09usyQPPYNhz
hzfBSYdYk9yFPXA8eytdOZbgk/b+uQ7/7UL2tOXScKo/podkdop8KQLWZm/u
pnoTyDFfJvpykZLQY/g/yr+eDC2ml10L1Cw4D0Sonhnl6ka3GPfAHv3dxKL9
pThl6yl49+DHZZElbS+ovzTKD1kfrcbd1Z8tntB+jLS/x5a5tOORzFoRJzqv
rhCLEkvfNxBY3jdyI3Q+xrsudthz8eeDiLHvFK8QFfuxsEPB0H8pr2xF+SV7
gf01Jioezv+oJijI0/W1R+tbs7jQCFWxLaB6DL5z0XxWLB8jD6KlRvwJIiZM
pVvcniNo7vH8ER0Cs4migYuyAlwe4erbZxKs5Gq0SsQLIJvOKVVMJ8Cw2YTB
mnZcrsyq8gqmeimRyPzGqAZH9eqcd5SPwilV0kqLmpH25lRixhGCiYRv5TpB
3Wj8uiBJ7AnBr6ShabFNfSg1ihb9eJ3g2nvmRbvXTeCVbVNm2tK10GjStdEa
tFoxB31of6wTqnE2dTkoCp2WCaJ8jgWr9ORkG8IyfKsEhwmC3ii5vRQqgP+I
IvuNIuW76KatWbUVsDqbbhKpTvlRd2L7nvRSlFaPBLKVqT6dI0Ps3rZCsD1k
lrwFQaArRpoetmPq0dRAA+1HMSY5Ic2uAeN//DA1pvhZFvUlxJqUQs3DOtxx
M73vgLr6UNYLDHTfyZhD+ebSbx24VKEDq3Qmp1Si6HnuPfnf7GK8C+5/KrmV
QLdljdhxpQY8Vp+cDUvKt1bTXNn2WAhZ2MR8o3hpnz9a5VdQA27OtlAjPcqf
hQ7jCbs70bT2xOZ9VJ+qDx/umujjQxA5vO4K9aeQOM1kueZUXLCZLAtaR+fv
Y21oPdQBTUH3pTw2xVs7d3taPx9zVHrHlSleR2aZPVH2r0XFl90DMaD1xS72
9xqJg9uanu/XKT9Gn/jOlfvcgIAMT4t9+jR+qk/OrqYRS4Uy8hppfwfTjPtm
TPlQYb+aI0H9ian3ofYp7wn2f02KGqD9qfk9kVwr2YXzsUJ38+8ROES4mFva
8cHXVMs3SKN+98njkCi7HoEKW7h91G+9dNIHecnNyFVo8I2m93GHeid3O9bh
86LsfRJU7zbzgjnJNgIYPH2XmU/1t577SCKlm0d5/OtgF31v6kdUpV2LbiFj
pGneD8qHsOO3gzedasGLmxvV35pTf2gXDSs78xAd5wbKkqk+ZQt3jhsvpu+B
d6/eXZqPkT8WsizIANEcq6wZ6te1LrP+8+NrGz7lbb3bSd8HhtNQsu7zHIi7
c87dovkD/i5SyiyqhG1f5PdyDRr/WMNVE3PDM/djP5dS/FhC47Hq+g9QPOpR
ILWJQKy+8IshqxNCvdOMCjr/EJuMNRx2Bg6L7LCqpXjlTFawRWY3Y1PhylXi
hgRa4bm539JewSnAQbjdlSC/dmVq1JpqOLElHAXUD4LunT7O7WnGZrvF3Ie0
vkXiidckwmvgkPj+Dyuq18LPEYd3svLwaRkL4pT/b2VuBxhH1oAUV8/7k877
c3CU1YqwBqwiS9svUPy13QpKdg1HQOesQW0UrT9aRqAds/oOXjE+3nlKz/sU
vh7zefAMwiGRj0XpflammN7b6gKI/Va3r9hA8C9pbKm3
       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c81P8fl1REkkKDUrYWFUnyVBpGw0qKSom0pFCSrCRZKcpMEhJCdtmy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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs41Ikax6lkklCb1q1cyjpHp5LIvS91kmQlJWNpbSRae5SSXLY1MkkX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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs81AsCxT1uiRKSdG+R67kJUZFW20lZtytye2mQolWhrtaukK6Q6qIw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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lekXp5oISYnS2JOtUorI0tdYb6IoS6m4DRWRRDGWDJKENKHsl6mm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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8Vf0fR4MiKySpiCIhKqN4nreUkvSQFJUURSXJqogkpKFlFaWipazM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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs4lGkfx0cJtXJKSKzRW7Yi1JZZo/rmUC+igy06IJVS2LANObSiHCYN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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs4lAkbxqWWTbVpOumg1UH6yFJtKIdbNm0OHVaTECVsFHIIU2qdoo2x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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns8lGkfxidl37LYrEgqixzKIKGo5LKdqLAoh0RshiU2lUNsalsNSpJy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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWGkgVG0bJpKoLCkUhRbySiqilKtoIRUlJZVkr1AJUSlbSIQIRSUSFVFp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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk41Gsbx0dpjqUiS9K8eDG9OmmzjyVfSdQp2bKcUKSdpE1TqtMroRKp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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81IsCxSnre3Kl5UrZSlOWNkuWyiFyS0qLUB+9JFv11KhrqWvJkq1S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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lesalVDJ6SjadZAkUsnQJVNqCVGZQqWkMmQ6IaTQ4Ny4JE22Sule
UadBkakUIuyNzTZuw2Yb0mGHtzrCRqHhvPeP7/f98f3e93metZ611rfK87iT
t7iYmFgyff7/dlP3N26/ngexwrA3hesI3CcNb4g0m5GI4qbxfQS7UWs5NfQG
7/5qsfA0IbjVWJvVYcDDN0V2zdQegrgouV1pbTXYofE69JgVQcLGRWV2VXxM
a2+VcX9EUHBYVT+noAfmzOBa7nOClv6ZS+mhdUicOjXb6ECg58V6Y27bjWQn
s+zXtwjEcElO9KkZo8aqzOITBO/4SxkimwzoWSlo96oTCD2GhXsfcLE70tv+
ijlB9H8CJcn7LjCed/KdSwjMcgK48V4psN8/LuO0muCq0Kj/gjwbX4YSLoyC
QN8kv3KwuQYWk9VqQU4EqYFBvbK8UshEnRf31iF4ocPy6lhfCMOfpzXe6xJ8
io2QrIsuxR8mZ4QG/yLQrWBkXXbk4YSkTsPrvbSftt5v1qs4SHH7U/LMNoJR
57TTR9JrYDsZrxFO8SjP6e8KqY6FIKRe/bYqgcR0kkusVTf8J4rs/VoIbjst
T7VOrUXE3ymm6tYEWb/qXTMw70BbCHNsMpzARkWh+V4QH6GWwuSK6wQRugp/
h9/vwMcDbIWmfIJ5pc8CuDKNUNQ5nRBtT3AndaJNoP8KNQP3csZov0qmVm9/
oAWRIql1lfS+tHTRwC37Wjx+77pNjPJ7VJPdJW3ShPqNc6MmbQkul+uVHCgt
wfwfSd+t6fkNothba+RbcGHrMdb24xSP8Jw+48X1eKsmnPE/TPHYei9wOu85
qmKKcm02EDCj1ZT2ebbAtbVLcT7lb0fSTYGaKh8Be2rVfgQTzHFc35YWyofn
rkk3uSiCmWsMRnFHF7T3LDh3+AZBVMl2Me0vFbBYKPXypAHF13Ojn9z9dihv
m72r7EVwL5Kx934XD5a7SjK7vSne756utnrKRlTBSzFfug/pto0fF67LxqBM
/jyztQRPT7goSOe20+/F9bhN4Hc81GXtpkK0zZz0jdMisMtZkZD3lIf+8O3a
su6Uj3aVIIdl7ZDyXyp/le6j8r3Fzlen6/F5+JdXHyheKov6lg5+rsTo3XjJ
j1sI2P5PvJn8Kkw4j3fspPhn5amqxZ/lo7FieK9HFsVHJ8Pvhl8Dcg3OmFnv
ILBX943kZPBxMYW15lwo3YfQJP8+1gtIeyff1FpP8FKr2dk4qxWmGZfKjl6i
+19lsJ7h2QRh5tyTCscoHxnZNtWDLKx1Z+gNGxHUHwwua7vCRc78Y9bltH5G
t0/evbhWJGjcyXz/Oz1fq5deOX0bp+0Gr2dQPYzOTr1tOV2Gpao3GoM30nn6
Z2KcFNNxPbuiLlWN6ik43SfvGh+7tZcxpZ7Q+U3Zsfv16+ApKzx005Lg1Aej
UbVEARZd31Z3sZCAn3pw4W+dAowywowETNrfT/OrgQq10JX7YupO/UH+0cIE
TmgRojsPPDDTpnr0XZX7eFUXGk3E68YKCIIlzkgJeln49MAs+fVWgsCTJ9Tt
5tWAeWhy5KQFrSc85MaTbcfb3AL1qJsES7iamyRYfDRXpJ0qpPw8eNzXkHNW
AGnPvgAxitemZm1JZZdm6Lf4f7FzI/jdKKTXmckDj3f/aVUEwZ7U3pWvXjTi
SsFFjc0UL1mPK2cnDlL+tIxsVlA+s5ISlASbWjHE+aau7kP3d7WDoH+kDG8O
9GVEGxPsj0s2fBmYiYIT4vKlGhT/ZK9AW6963OXaFwzTec2Vfkm8dLETCSGL
SUYI9SO77Mjlrhzc6X2hFUHrKTHPDtfa1aDhbVF/EcUzN2KNR2TiY+i4fOf0
ryGYVAE3W6cPGaccfsRTvwy0sp7H2tmJI1tXimaoPsK0gs4dd63FgHyJXi3d
x8+T2eN5Q9UYf5KLCuo3Q9mC3T/jqnG1JNgnnuLX1bCh8d2PBrjEmWrs86T8
cHIu1/1sgP5f3QrPjtL+Nrts8PjKgXiuoukc6l8q5+sPxswtQknh0iNVegQy
Xzb3euzlwUmi7JlqGIGtu/CY6OFzWNlqirZSPscjCw3/m8CCgrRj6sgmgkM7
7DeOf+Ijcd0Sw7B0mif61nxfRi/+18fncHlUn0s2uNoY85BkfVaumOKj8qlr
7f7jT7C2x9u+k85/7NUYZ4V1KxYorlkUcJ6gcKFPDIY6ILtSeSQzjqBNa2iP
TmETBsNt2J8dCVy/tV0991CA4aFHuZUvaH5EfzV4HPIc3zQDb93VpP7mMGDL
nK1Aj9HsM5gRdMpEhCjeKkVnaLCmFfX3TpHyWmk5PpJc+2K80whCdDyHRaot
OGqzb0UP3ZeHZmNjHndb4RZ8166b+lnEbt0JuZkGFMfN6v5J/SIiVqomXfM1
vM/oWFyieAXIRv9x+Lcq7DIR9q2kfOgWOqo7VJQgX2c0e5r6mcjPfOqZXyUS
Mts1Rwzp/IYhOyO3tIGrFrxlVSLVy6+VX9mZpYiZ4HJy6X3nFasypS+yoFlN
rutTvZcFrw6oEzUjobX9dJUHQdCVz5IbwMG57IhKeZofO8ZSpsJ6OsGwfein
nEtg6fzovOw+Nnyiiuduo/vLlCrT0bpRDfZw6uwTWt9szpbzUru6YKJW2RBO
89OINbdowouNAfHsZHFTqs+C0KkJ3xT820mdFU3942txygJT6h8lzxYnTNF8
kBi3N4t43YztfiqzXhSPJH5QWdqTLohPDHskVlO/q3yUHSWXDi3/wcWmNL8f
iF3z6VfKwbolL0YW0P+NgaFl5XNID4KkHeU6kggaVLw5jtYciNXdGB+m+vgx
/035S38OZO5HlOfT+b69UZReMN2BFVcSu+Np/onZ5huU+cSDoS8ukUTz1d02
9PLejDaMJ0p+0KR+ZOngrJT/nQuhDLNPlupTqXBZr2QWC+rbK928Kb63hXO8
t5wpByfr6M1DdB5hpUWndGsTODtEOVU0X8rdPr4c0bqG5ZHlxz/T+3t8JKTn
K/BQP8OdWHqK5le6gLH+EM2PVr01847Q/GzuTuv3YWN0QsX4HNXfP6VTuk4=

       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VW0XxpFSkpAkEaFBkoSS1O0tiZKhVERFkkiSVPTKlMpQGRo0yGtM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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41AkXx71dKCvd18h1beSaWEqafBVplqKi66Ta0k2hfctWdkNNKeW+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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41AsXx1GJuO5kS125lP2qdFNafdMipeJmjWKMytw22lwVmdY30kKS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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk41fkbvdUolVJGi8pSI1mKaqiUnIqHkqmfJckWilSMGbvp4k6WDLKF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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4le8fJqUSUkpaQopKKhTNm0hCJQ2KJEpL39JAUcnKSERDGUkI2dkj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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk41AkYx21o25JSRqsyi1RShEYK+WozJJQ0SdLuKEk2shoWZRqxriSJ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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs81IkaxienkEtJCiudyiWle61u8uTSVYQTq7SzjFtKVm2mmlNMCrG0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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns41Gkbx4VVWzmVNlJySrasJq9FKt95hYiSMURKCUm1OjhFL6HaFCHK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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3kgVW0XxVG8SVQaUEQiJWVq8FLvIimVFFFCKnMSQigNkkoDkbFIg7FQ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81XkfxWVJKg96UEllS2ouyVDqoUO2VGNLpWmkpK64KqrBkEpXJKkG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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81Pkfxymp9dNvh8FSEbp0bofNkbwkTTpsVqXDlqP0azT5YUmOpE0l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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8VW0XJcpQong1qSgUyRAKYUmTUgoZS4TCRUqmovJ1kUqlUihDhqSX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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2kgVG0fxhGlFCqFFksqkkQlqR4XkYfsW6WEsj4hypalUiEkKVJpJckS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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlGk8lAsUxpmUJG6L/ddiCSWFblxx86iIEimFFluLErJGJSIu0mJJRmVX
ltAiicqWnWHGPkzcK8XM+76KK0Thzv1wfufD+XDOc57zPwqnPA6fpQkICFzm
x/9ZKFdaOsryA2SmZB9b0gkYS1TZ2ck04+acmpwUlwCNs2fT/T112GGWcCyY
Q0AzJsczXroPdw0XzHOLKFCTj9yxuQ5bE9Pt6D8J3Bhuz1fv4cBOdzS55iSF
5iJOZBKjG2kbXCk/QQqJmefmV5p0YOakl8TQOAlD18PzepkVKPpbq8zgIIHg
qHJH1e+V2O2hd2KbKoEc7WyBtvB6SK1qV5KXJeG+vPzuFdceNE1pM+qsKWgW
67qcvFADg+cLlSIMAgLTRoGLHM9g1mTb8OBGHsIOyuQdLu/Esbf9G1UkKTSo
pHQoa72E/HKPUy+aePB2vFrH5LHhUinr7eTKn69ru+9lm26onyvxvcrXJ3H2
8eVS8yakh2TU0vsJLBX3WLP4VD+CvuUX+yaPgrs5ddq07wNWsnpjxW7x9xMp
5/plohT0u6YdQWoExFPuuAtM90FHZqhGyYqCeurd0GznKuhSB8XfJBNYI/5l
/trPBjTtzT/L+EVAsjVX2VivHV/DGcbnz5CYDx+xGLrXjmWjGcqtGhSsTxXI
B2S0wvdb4abTV0i4TUwoqMl1wG+nQZh9Ewl12RFX9+2d0A2nW9JkKFjSjWob
DRlQ1tFOadhNQq3vaAsniwPxQaU1sYtGscJy9e5nygP4g9blnXd6FEevi9nO
u/dCuKDg+Kw5Bcdb49KJMqno05ccDr3Ew1v/N6G6XSz4ftaULgsiMdZ2jS3z
uByX/T43S58mMEDNDtmf74PPc1P6/WMUWFxhtzd34rHIyi2v04YH251ffdTu
v0Da/etpcYU8xCn+lLN174Kuw19df94i8d2ZdAsyzYVQRmpSYjIPgpyJwJLC
AXArlPaa8ueJib3tcDjkI463OBw/pzOKzsn59v6yWghlX2BV1BJQ0V+6O9ru
GfTriub+rOHBpkS+eba+Gx6vD+lphFKoqTn0QIzFRKttwNP9sSRO5BQzR1LY
0KmYbn2hSiG+udbBIrMS47x6G6FQAjdV4n4IDdchRnjsulQ3gYXk0h2fg9og
4lLxu9Z5EtZ3ErO2TPYgzfjdDqtavj+S3oozhUwk1Ardy7tBQuJjeAEtIQvy
Clltt2J4GE4lfl9qy8bDdI1Us7UUzh+IlnZ6zoGkvf+kiS8FX4Oq6RX0Jtwp
0LIjWgmcZ6TMBl6rhNt87mt/Ph+RTlf3Deaw4WngVX5hP3+/cb9JnNN8h4d6
s1fY6gTW+WwRNFnWhbJBK/+hchLB2uOtiUQMcrwIOseCB4ZgQOR9VhniFlsN
JloTcEkrfoX17eheKxzAW0ziH8ZhxkD0A+gWtEVMOPJQbVY4su5AJ0wzW5xb
fpDYMi9VbaneiQ2zIYe2sUksj4+eOTrWA5s46We6LSQ+39xzuqmhAxWbrt+O
4Nf7jCK1W2L7EC8yGP1gzSgmF6ms9lNtwe1GYeqCE7/fr5M+lOkzOCzEjHkX
87Bv47jCXHonIq6ZPV11hET+/FL9s3vKIWDmbhhnRCCJax79WaMWnu/em7/i
+7HbvL5EcEUX9PKOrS6TovDrk9S7LLdmLM+tlHDcyte/+IThnHwxdvyqrDKc
4kFAPtoh6ZAyYh7B2E2RB5e42BnvwWZst86wY+4ioWejo6ZV34HXA6nOYdEk
2M+UFjaursZURBa39C6f18JXl7YbtIFRWsvlJpHIpa20uplaBVn/QMWRIAJD
co82r8puAe1BRNJrfRIbphwGbaNa8K9qZ+iPrwRqxn3UFZXZEFdcOKNeSuGA
DndF70QXGLxw78xbFAqbJUs/3mvAO145dz3f/3yvsHtG441wb0iI0lxCYsB9
4xUllX44B35f6x4yiraL355eKujAk8G9m6tFKFis33vN6kc97EXmPJjTBH6o
7lNnEEWg5bR2j/XzkNrbnleuVY0EZuVYsiOBX2FOZ08GN6L4Em3qSxEBy5eu
Cadk2xBQks56+orExes+p5fksSB2Ain1L0hc/stc+9uREnzalXxG8F8ekm76
HRcXYaF7awRNzJhEoUSh8lcnFvwCmfoTkySK3nZEOcVWwXuGRSP9CUT9FGYK
+35AzHvW8MsAAmNLPex7bKvwlG5CynkRSLdOWxa2oQ1OnqLs/g4SGQvUwyM7
2dg/ZD9m/p7PyyexiA9rmKg2sTEaeULigsUWLmHNRvBcw6fWPAoMY6PMZUs4
MDCvF08THYWfdqaXxKJeZM1mv9XMoKCUYSnlqdELhjV95cUzFHaqsbaYBLLg
rOKr6vuIRGSI/I6u7AK013ysb+Hfo4WCUWNHfA9cmByhD7oUlmskigaL5mNK
NE5vhv+/SoSfyPullyLJZa3o/DYCnn+b+SeFxkLuy5E/bvB5k29f5fD9Rg92
PVBwSuXzwOhne/x2rxHNB3r3R64j8R+WNtfc
       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs81IkaxsclqSi5dVmXqY2IDRESHtKRLGt2OpUioRTl6CJyiZDSKqeU
S1u2BhUrLZr2FJHT5DIzNGaWmdGQzMxvfjPdJYrYnDl/vJ/33+fzft/nuyz6
ED1Gk0KhpKjn/zu+Ttv25RgHBf3L+vpOkrhRvPzzxJleXNLjjZdUy5Fswe/m
yhjQu39p/ZFGFd4mf10cNdCJTCtLxwo7EoYVZqI4SxYuLavw42sqMeEd0vUs
oQZbpMc/bs1QYcVQwadEAw7sXG5Z9juR8NGUZOzPOgILt9LEayavoMrYu9Fo
VAinQ/OSPtnJwNky/ctnQyF+zSw/XmtHIJ1WuS3P+AVk4iKzsBI5Vhn5twqi
hrDXcjnL2OQlcutPui+gS9AUatScUTUM5tbfNIrEIvCdppT53TJQzu1wWFTc
A+uqkB0vlAoUycXpOoG9uJbOM1mjr0BL6vZtQjs+zHaVd+2Zr4D9fBf7qDX9
MLUesfW+IIU/9+AGdychCgXV/xW4KjA2sGCq0bcBlcGbde+EqZBfWXDzuwMS
0EjFkkJbAu/PFNI2pwownF2XXP49AUflv5wlhufxvV7cDeqkCue5+66IVw4g
6aGZ/966YQTQamqr9wiwuJQsdDhIoPYHprmnSzfaFiYy99FJsMoMPRzMRGB1
aXI/PCBwqKwgdJ5GH4qDIjwecQikBE0Xl8e3Iyo5fsPycBLT7xOro+JZyPE1
GKdtVcKiQcww/4cAG71vLPHQUkCooV+6IrUftNMnJt9Gq/M1nKKX53fjscnV
L0VmJGyyB6aP5vPwLaGpM5ajwGCouP3gVibYRMGdWatUYKylNt7XZ+PqjGk8
bUaBeartIqm4G2Kf4341wSSCCuhhq6MlsA+fm6A1M4zrddmFipdC+NQtsNIo
J8ALfWX+ZDkfRYwB6YdJOdippaoaYx7q46Xri94S0Bu5ujSpuR3RovpMXyaJ
6svF9MrPDdA5pLslwFsFn6cUsh5C9FB4nNM8GbzbuXms5B6EBlncdD2pQLhG
TPifb7qwK6P0l94rJG7qMTTKdB9h8cLXF5UKJardaicZ+ncxmDebZCeoMHZy
5NjY517Ict1uhVMV4J1fGa/d0wOhQ2TAhICASph/TsNWCL08ny2xap6BLkMa
JRFszA2NjJQKFfjjZcTSRpPnOOJ7XefZbgKLwr8MM9d2YI/XGN1gJwnveu9d
huo8t29eLOeHkDCwH/XXkTEx3bPwlZa2CrSiTI+oJWI8+7vjMmNCitZ32Z0G
sl48S6QavSuXg6Bax0V4s7AUutEOPSRcBj+yByvbYHrgAuO5oxKOJyyY3E31
mO2TbO4UrEJwdl/xT6PPEWs5GCGUy2BPlRs4J0rQljZ7dEKo7gPjZ2sbdiNG
su6K7V8rQdtZJ5AcHIJ1aoO53qQUrt8sF6a8FqE/Tt+ZHUgg1OuKm38FD3X7
x1zz7ilg1eV15k1jBxicT694MgUevhvLcqzqgv9YwPW4ShJN6b05+xlD4LdV
+dEwhKLtHOc3Z5+Cnlndz8wlEZkSEBA/wcXRU550SaTaB/8s03y/uALrNJ8Z
5jercF0r6ruYJSIEjS3puFMlhxu/5Yzb4m4sp6aVnT1NgjJ35AtVeRguGJeG
qf1BLWso83L9E32XM05Y2KgQJNRJs/EQY/JC1KVV7QSu7wvZXxfdj5zb9I03
wqTIr299cOKsGLaHPx4+qiPDZ9rmDkaLCK6JT2Ja+TJscpx2necshHuab8lk
vxwJXpsidoxyoJqpN8+xInGRvUn0hNmKBO03be9slIhMOxeo19AEW5e5pbKH
SmSI67QwJUZgyY+tVJ4cYxuiVcFaj2AQ8YPV0yklOg5HCVqy+2DK5fnutJGj
Qjj9OjyvD+/d9/02sppAe3BA4IBsABLHmbB07kskSYxm1zR2I/tei87vFAWy
krKyL77j4n2eIS1nNoncF3sy5+aI8EkU6uM4R90frVnHT00J8Ta3f2hZFYGv
+azWiz3diJVc26BwV8BzwThb74oASuotu5Bbap6ex/I8pb2IuXatyfMyAeM0
8/OULhaaQmpKTp5SYh1ncOEEi48OjjPPTc175NcczlNBM7Tn3FU5bFcidL94
ZRvBgbF0de36Y2r/JM0Tye9wsIaectO+hYRfnrnGLfU/fbjvnPCYkMI+Vfxj
mxMbB56YBP7VrEBkAWs9sVuIgJk3W63+TYAy9XH8j59zkOPyH7n/rFdYEWM5
vPPIc2yO3Z3m800GmzUGK0P+vocDFqaVe4JUYJtq935Z9BzaWVxLV2M5stB0
J2t1NU74hWxbVKJCiyQ31s9tAGkdthxXtX+2uQhDo6wH0ME+Y1SYOIzRleOd
zuV/4UhIUCedpYBLXElhr/peQVoO+FRMonZdFYWy7h6aktdmtHupQGp6/BT8
qBNtLUzrQX8SXwOO6vZH98H4Lvfxg9sEmuWWpauX9UHT/ZjiwQoC8+lzyrt/
56NG92F65gcFrkylnL17uReaRKf+4CMC/wNcwMXW
       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lWkbxkhllOxSJGSLNNQJg6tspUwInwhpUUayREWEb8Rna1FGx6SN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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk8VP0fxRFRSilUKtlSUUhISaeiXSkkovJoURElRZJUaKGUbNlTSZJ9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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs01IkXnzJJ/fZMkxKV7MqqySMSIfGZltqSrcRqtjY9yOq3ESo5v4gi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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs01Ikbh91CGSmFlHRRq1gbSWkrn4TK1pYsRq65VJKyWxFzUsgtyboW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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx1EZTTFZEqGfpckyZbsI3fGRVEKilGViuC1MJQ1XpZSdapQl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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2cglW8bF8pMRqQlCqUhFYrKTyoJofKXQqFBUpTdlIRUUkZSCRUqshUq
e2/nOEbKdp7nUHYJ5b3fT8+n576v+7p+65KzdTp0mpuLi+v4HC6u/3+rcei/
rM4qlBvePBn1mI3NpYIit64xsITa0dDeQYPb3KNzojcGTztMvN0UaeRHvjSP
NaxC2rf9nYHfOahV8+/T/F6EF0kZ288fpZFTKPntXVANePq2rj6vRcG76AJ8
HVrxTzRiwztVDgZ9z9+2D2YgJEE/oi2zD1ztRf02zJ14e7dcmGslDclgGQ/7
iUa4PEn8uYXNgfbFG6Knq+Mh1Z/E7iD3G/laud5RbYc76/dPpeBBRDNGhK8v
zATDI3dd02IanSmMafuXeTAKTRloP0FD9PBOv21zWtGUcXiiK6QfvX2dkdNP
m+H7Qo4V5zuA/453b9KQbEVOqZN/2wgNmWevnlDdmVB94FKn40hD+MtcrudR
lXAY5Q7oKqcRoOfVpxWcClWdeUnDG2hEmfuHm0hVIjb6eYmUIgVBu8fij4RK
sCfS9eAuFRpc3+akGInmY/XW6WMxiyhsYxkKX5XswFS34ejsTwr2+67tNLKo
gIw3p+IhFwc22xMqr3/8CkZaoZMWOX+HxYmLHquqoJQl4BPyiYKJy7DczszX
YMY7/7zPRUO7ZPsWi/AEaIZb8nlupnGiR86x164Np2qfesULD2C0RL9lfRIL
qq4jZb2RHJjOmqYVWzCgraetv3SSgs7m9I6CmwysGF3WH+FJI4WpcNRZ5RNa
L4l97NegEdfsa2Qt1QGz62bfEl70w9P45Pqxh+loEdI++3SEQrvKumQuSwba
LCNWZKtx0CUrHXrBOwNbij7v4tMieDjHvSiCzcIxjdiQ/zo4SPl29KSQxBNY
cCmJMcVp2Adv+nNMpBqyvlsyM/ey8e37/lHlOiaWBOYp255kw8RM87qJQww+
+vKWGW2iofigN0upJwMqPgMmq2gKD41i2eZSJTCNutlfHkLhVfjPotnuLGwe
TBRcv4+G9+IyuCZnoe71OLeiCI2ECNcUOf4yHNwZYF6jS96fFmUSrdaA6qet
Bnvk2VgrVe8a+rAI0nInehRlaKydDvvZc7YVgjmrFL6c4iAjTNbc+jQLfNuy
F3znGYDl1JmRBQ7lUFeRcwu04oCrsHdc3u8QnnU+3PNRjkbeq31q53izMeoa
C3E+Uk9x2Z6hlnRsrY7WuDRAQfpQl9nyxrfQ89aIn6dGQ3NPrkTVlwbEmeUb
OzVyMO+g5V2N619hnee0ZRkPB40+pxsdxRjQ9R6fsmPQcPj2S4XObYG7lVHY
EREKx3+9uxb6oAXcv4ePTmVSEN0d8Oy/mXv4PiQ2NUL45evnwXCuq8WDny1X
wuQ4+PrvQafQrUaUHKjIzL1BY3BxQ/WWNywsqaRX1aoNQFjoeVHg/CacnOdQ
JbKFxrzWApMOmRYc/6L/tugChfpy36H1N9owpuItOSo5ANcfu6pXerfg2cp8
15RCDtwDmsRM7zKQFpH5T6SIhumMldzdTy2IU+z137+WxmTet1tnlT6Da76m
QNIo0Qs77/kS6u8x2pc/bixM+jWqZrVjbhS6Iw953yTzj2I2BplvzoK02Wzz
/UgawR8XP7miW4/bPxQGnzbSkH6a96k1KAXPHjcYBh6nYa7n9pz2rcYe3506
PyQ4WPLb08tQvRbXhRpd+G4SPByYx9D1rYdryXDyRm8Ohi2mdMyVWhG5hCqI
IfiPOFTO7ZDdiB91h3fozLIhW8pTEC/8FFntexriFtEosH59xkqigeCrl9UT
TkE4YoVE7vwCBHtleGm1Uqg+FiK+w6kMr4JKJRWuUVDZKLRg8UATIufaLnhL
5sGMMbV5tqAC9fe+WWpdZiNA5PHQvrCvWGix5677th4o3/bf3RTfgNeh5lxx
vEQfxjemCqR9xVBb3ePe1f0wFb/80ke9Gv5Vjllt+2mUp6VF2PEwIcVyf/+u
iQ1RxXszYXgGRWF9Mav1hG9Gu/lMn6aD9abv9ysQfVLP/pcl4wNKMzxsswLR
k4Oxs3o3QyHPuKfhuorGRxXhe44y7VC7anCRtZ8DZXbiZHNgNm4N+RRctaVR
/drssadaHV7w+9JzJNmIvhqilBRcjfe/NmSFvKEQndRQ632pALzGGS3UeRoG
Ux7QfVyKYb3/eh7kEzy2b1zYM12JHkdp5/IgMr/Ncwty/ashE3uwqYTg7UT2
w8LXH0pxmt/d5LkwBxvg46zrX4mkS1my0nwU9ntaqTNWvMLk3rTzV5bS8OyR
u36HToPO+X7B/+tv+PbVx+Vq6tGxk/nebZr0J4ij4q4Qh69zgg9UEr6prP1P
1Mo3BkkGlSV9mjSG48Y8uqQbsYs9Lefkx4ZuywXeu6cqcH1H2/03UjR4o08m
tnjlwFgzfKywhsKhY1M7/zkwcdlwjsZ8wn9Z7xuJGnOiIN+lJ9ssQPjCZX7X
MbUdOaLLF3QSfnQ+ujDwkicSKhF/rSSW03C8s+8e/a8CKdcjxKWusEHFvx9z
2VuDKYO08AZnCgs3/tUI7mEi4xF3/4qLA5B/Y5KQ8oEBnsSK17kH2VBeGShj
uL8dRwTePMu8Qc6PNGmOj6mAfE94y+xcDtIH5dqNVzXAfFpW7RiZ1/ofB15d
jCbnKdvMapB5JGwIrhCSykPXkjkZ8/iJ3+oae75enoTh41U9LUSfvSfub7MM
rILK7nXqmUfZaDmoOmeVSx1kj8qqhZhTUNob6lTwgQnp6czDu5JpUL33qw42
RWNYund0gsyjcWAgbCa/DqPLRwaTYyh8k+T9nD7RjJ8bDpzrsqTgaL5D1NQ9
A/atDn//Er9zXpWt9dw4A11Zf+abLaExunTXaJvBVyxdPtng2U8hatuc4D1x
lRiUe+tzk/h9sP1I9w3Cj/HaopUZ7mR+qwsUziQ24kpxnVLGEg74V6i/mggq
gYVJkah6AI3oDbXLVYKLoDj4q70nnsZlOQPOUsUY1KktHJcWoqGrE7igq7AB
L9pyylK3UnCfV/w3eZgFB/Fxh54OCrI5hbIsYQYGX9j9GnTkIJ/7j8sgXYxX
E65Jwy5sBIYdTxRxY2DKeLWywQKSH0If7bLc1YCtCy1GdNzZSPJpvlp5oRRP
l6/cphtO8D5i2+Vn3gjZngK7IxQF5wPX7CK73yEp7WZ7H/HXLVvvRNf9a8cL
A8bJsgYaa04s01zjWI1nfh/+Ugsp9E8bFWTqlaPv/uymrXEU+mwPNdzLLccx
nq9dzwm/Pmm1P6kKq0VdSVG5ihgN1Wtc6x3ra5CeFCBVZ0HjWV7gg7FWBsR/
CbvVkPtU0/h/D1i2YPTnuYsnHNg4mXOm8MueWpgILo6zkaaQsDC8d7SsDIuN
Ii6st6chfyLut29nG27w5S5TO0j8cPvxdZ3CWYgy5Gy5JUHyl5zk7g2FaTj1
Xf9wuR2N4jXXQpMuF2HymXtUCNGj2Bkuzeyo72iOyLmwvHEA9emso/3uYbhp
ntSd/X/9L7djdfDG4YvNYIgP0dvT8WNaT3uyMeekzCUlaRqCzzeFtTgxIKpW
suOOKxvB2kdeGp3+CNEHLyofEzz9PJztOff7Jwx2lRgm/Cb4GTn1gWtuFQb7
A256q1EY3mSmMhbdBLFw5j/XLzRWynpOyC1oxQon7uDPPzlwHn+44mNcMYpC
FFrSA4m+6Lm47cxNxX3Pxa3i5H0pCpnW8YuaMJWjO7LyMAfWH57mWp9uRlpI
82LlDwNQlOisuFfNQudBY5eNpjTqj+rouc+/i9UWDXl/SL4Y7rBpy1JgoC62
/7bjPA4itrc1TApkQKDY6vwk0SN7fXhob2UgSlZHePoR8aPkP8eUzOpxKFxI
35NNER4XpBXlliI+tieCO56CZcMeN92MBijbePx5eorC5Lk2zc0n8yGS723V
RfyIt3ihsmwaA7cF8kvTYvvhzcpO46whegxeOYspCi4TfXcsyfuOrQy35f9L
gcNZ8065vx7vm7t/6xC/jT4tC+XMVvAHZYa2kno+tV71acophOjVbTZJJF8N
fnjuWr+lDEF+t55sKCb5w+7ygpCgW+heqfryI/EXeaXAF4vfVqFbaBlVWNAP
UcFv3jP383GGO/iujx/pZ9qvmL+ED9xD9UkGlziQEtPUTNzegniFubeG5hI/
opJr1loVIzqEL2HOMIXyz511XEaNiMmRvMu0YuNLvu+im9ZMXLU0Fl3QTfyv
cPO+aJXvSJ57XOKr8gDU5p35vqizFPceqhbU9lCwTX/OGNJmwS2sI0/1EvEH
fypqeXAV/rxce4WHh0bTw6mKc/5NiNY7VruGRfqfRuXLLGJCs/Fjh70GyQMy
Rzw8ulpROTn4ZJlrPxIyrW5eFs/CxR7TH4bKpF6zdMt1c2uQtYQ555wNG8NX
WTeehFVDXVUkx+4gyTuzfeeeL3+LFxGTmcenKZgKlSjacXIwdH2kZlkKhceu
7/q/ljLhPKWQ6kn2E3MfhfGTcoVol6cCOYkUtMWVq78d+Qyma80wD9kP7JU0
FN34v8JUoE9zLLwbJuW7C2fLyxAlMpta6E34FDQbw9G8D6n8bJMvRJ+Nx8cX
fBiohuFXp1xtoscfjpv8unqgCZmsSL7cLFLf1kVWQvKF0OF9J/mJzGcPr5Tg
LccKRPiVzgx+pvFWVK831bsAWnx/72foUQgJMDjq9roZZn/Xtd2SJH4St3Zp
+nomIocOD0qQ/Mz0MMy3mmzGi1pXplvTAAZflfOeCcjAI8rgzsxXCj8rxN96
fc5DhuLt/ohTJJ80SF15a1CMQxALHQom+Nsuo89jnoAIl9UlGQSfItvuql8Q
rkbK+WsHJ2Vp3DmQ531OsADtLWPXSt9SqNK6G+at1IT43lMrM1ZQyJt/zlVJ
sxSdwmJ6Bwje7Wtc6941F8I9Z77uGpLHluT9WX5PpwEJNM8STQ82dti8Vnfw
KMPufYue1HBzEMAZW2faxoLna2vVLnJeaVmH3ryodowmXrjj38zBiXHn4qfD
DYjeN/nqfCcb6/6zczu1rx78pnfPZflSkGr+e03EvAmVLlavs7b3Y82m/PTJ
N3kwtPb3VvCnEFkJhfWrUiH5+/51WZI3OOzl7wRnypDDQ3+rJXnWV+n8mVuB
LfDaIJO4huzr3nptIysSb8JvRZKQJHm/rSPjIJ9LPdIejpq8us3GwvkpDpdH
CkE596wWJ3oT8fzKji1TSTDIWK34gujvkn0jZ/v4GzBzSXQni/Rrcuyo1hLT
TDzw40nob6bAFTyu7eh6Dh2ma5S0SR5UjRyO7DpbjzvmE+2NYv3YW7W1xMKH
iUM9zqmSZSTfThp7fxCvwYtrv0aWThB8xptOpM0G4cJ/giLq5H9m0+4XMhOV
WOMo9vOeDY2rMjUmD7cwoYutjbtDB8D1y23xyi5LlMH2EUX2pwu7AlJ3ddZA
R8hv1qmJ1FOsfXSvdR1EJlMjT2txcMB6IDJ8sASM9VK3dxC+vfXY0HHa+CtY
Nn5fGZcHYGtVm7GuqxmHLG782fSE5KOl6swjtcXg7ijtHe2jQFkyqnQESzF6
iT9yriTJW+OZjNHkAghE8lfMbiP+XBl02JduArKEQn8eYOPq5xr1ot5yuK+X
PlJF8pTs4ZPdM7yZUJmS67P8R0Gv3lxwU3kSPETaXnUcoLG5MtGrJZcJ+4Rg
PWOiX5TkKd6l/imIfZ7OKZCn8Ur35dUTm5hoH/rgIpBM8kXI7TP52y/Bx6+8
gZfg0bK17u7ukRIIeen5KV+l0eIjtMsmKQ/DCfeaKzJoBI0vXrJmTyskXOL0
A0ne7jrye/nuvXVYvOvEOm0G2S9nUk9r9X7HSYPSOpUrhP9xq3mOvizFn/vD
ORIGFIJPD62YXf8WXzLKVguTPGxUe4brU08NYq1WrM4i+4j1HPHKuWq52Gph
J6TmQ/in3HK3lY+JEpHBRdl1FKwV1jb19TyA85vL6U1kXusGN5aFM2oR4bbX
4hHxg3FuhwCPoibkxazSdFrGgfxNm5nv18rRseplnbEMBY2lwsfifAuQQwtP
Pz1DQ7zVJXErzcCv5OTGNFWyT03XSmmwa6D2sEZx9XuiP6lrO3TLWjFY0B3H
q8iBpkxoWfxsC96v4uN2/NYPYYVNez+KZKJ/Re2P9ZuJ3/7VsJM7wkKXmNGl
gEtsRMhNl12dqkS/cXWGLdm/t+lPeQn8LsL7n9cNjBYSv1klqvk3mQGjsy90
dXYQPPLvK8/28sbmG/rW9Yo09P2v3Kppa8AnG4dh+RMcBN9J23govR4LH9ek
jmlQWLmx6q+EIQMv+wrZDQEUWJaTH6LmsSARkh516QwbNbcct6RpvQSLNezs
t4zoW+sXJcOILEgln6M3q/8//zqtHrvYiPLEH2te7uBANIoxUnU1FrqhGyf2
riH9d/hsGXUhB4FMbcGPJC9qN8m3P6/Mg736CKP3BMHLwGuN1NFmNOjsFl97
fADScf7jBm4pEMzmCu///32yku/eNGXB8LXCUjOyLw7/834sL5CL/GiZVm0y
P86gaUReeD7ZG93m1RN/vcxMFD5p3wgv1Y+1RkR/TM5Wewim1KNYiy9ibREb
2vryWZ5lLDzjTRNzOsqBdxufrcaOApTGjc29RvK495L0V/pmPmhmGUlvJ3hv
MdNY+DKpEdvXNZRxNxI+h8qb892xQ+tKTTkXgnf5s056WmuZaDH/M/qB+M9F
v66eO6fakHlPJSZsjINdQk4zX/aXYjbl48n5zwi+rl28vNY+BfpB7D5+HTLv
Cel1Hr+LYT80NC79meyfwVcEWnXDUafxjF+J6N+2OO+Y8ZYSHHrw+D4viw1V
7cjkhUWVmOHa8q32OgeLbCu8eG82wck91vmHFskjy+/cLtjxAb6eLEENkme4
Ho0elc8vhF911oV5JI+Wjy6anS9QAutyuduXt5I8zX3Yo/FGDCY8Im3vrSP3
neOKjY2ox+BMd9Rwax9s95szPS/VgyWRmVzhRPQ06PdmboHvONqRUTx3Damn
Siw2QesLQm5Mdwp4kfu0wn+MLryCs57hRflE30cUJC+UDNZijqCA72aiJ6zh
5/vvqxM/MvMyf+vFxlvHW322N5pAcQWulfvdj/8BJNIQhA==
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41AkbhpGUNm0hZhHqi6IapYRSj+orKo0OKslpRTllE9mpxpIV2iQp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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwV1Hs41IkaB/ApcrC5lHVZFevQHCSRqYkHX9atRuiMS7qzSeXEVmTlYEXo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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns8VVkbRoqikjApDL5uOAmRxmUeGU2i5DYuZVS+45RriKRGSRozMrlH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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c4lu8bxiVJJWknI2RFqZSo1KlCklmiRaWykoQkZFUSoayMzISiUNYX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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlWs81Ikax2en7FFHknLLiqVISURpbfkRRxuS1KyQ3K2GosimVGTKJLqt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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81Ikbx4dkK7FU6BBybVaHItloP+rn2vFLKVlXW1PRbBJRqt9Pjh9J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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lWkfx73SOKJoLCNtIoS3miIl6VsRKiK0kLJMljBUMqmEiLI0Y9+y
taCyRJKtY89JOTjncHA4otUtZkqWt1Lee/54rud6rue+7t/y/fy+v1Uuvtau
oiIiIsn0+fedfsd2p75UB45bjc2TMiVY8JWllDrWiVf+T1ZYWBNk6ZZcjfHn
QezRjmqjCwSDER1KPp8F4CZ6px26Q6CrqmGmur4FY/X60RP7Cdqv141OL+Gi
cK+TXNlFgsdVkkRsgIP0SBF/cT+CL/sShNz827jgvvpRshpB9lC/SHaXALrG
JhPcywQfC9rrg+2LEcQs1vHSJPhV7e2h+uFqGIcek2frEXjcbV/JKamAVGeb
wf5fCTIWq2xi51ZgnZSgZ4kWgeJNm7k9jEaclxHdV7yN4H8yTT1n2tnY2Hhq
yPkEgfGIiULw6FOcTXij89Cc5u/lzPukxwX3mVm9oQfB0AHX5DmjEvi9cmz7
SuNPel7pCnLjYozk1o8EETxinBNEOPOwSDd465tQgom6JBSq9yOr6eIvO1MJ
lBMTK/R7apBnnWjoqUuwrf+eQUy4AHwXWf06NkGOl2ylz/sEnPph+nanKkHk
xZN63Qdf4Ieqw2iQMcGODR9q2iMqMSlrXFyuTc//pewnzi6D5+L83+fT7zvz
wmwvyHdhlnuDZxhI89d3dOhj9CCLJ64SnENQsFHZa013L161CJXaEwhi/xYP
anQvR7N3z5mKNbT+Gq9vBtFCGi84UHaA4G6r/vIGVheuLdQizU4EAwscrDhv
OpH61D2s8gzBiay/2KVBfGz1Zfh15FE+5n/4J9VwEPx7Sg7BTJpPgqgw/koT
KmPH+9OpPh3z/hZZO78XnfE5Pk1ZBHt7VC5o6gkhFjVv5D3lJfxPCycTox4s
mhiNd/AhUD97/7XG0QqMxju5OW0kCEzsUMmzqUfpH2mccqqvouqUGMu2BHJM
iRZrWn+JoYJVWmc3nnPcPZJTCGR0ihar6TSDufW2nK0B7f/vhkKTMDYk1lq+
Y7lSfhJek7WmPVhqyn33+CyBuYFWSNJwG7Q+ZNpLHabnVfwu+kTVIT1gx9Jx
Gj919h+zRF82Btp8NtfZE2iVTseZFJfj1qBGpSuN/y3fXsxWrh7+96YVM2l+
oqV/vqx70ImHHVlDMvsI6oPOpWay+iDlaP3b/TqCI0G1gYd3V8FM0WjDBZ1/
9TAuTdJtR+7PmZfSrGi9Iaqz2mcb8MQyIsxFnyDlRvq2upx6FB9zaojcTDA+
5Cub2SzAgornaySiqd7re+VchU1wOPPym6UZwbvg92F2fjxsS8OWo24EZpf7
vzAj+gHNzBg/DkHloOXbhpf90Nfe9EvfVYIAV+v0lxIsBJ/jfV4HglMTl2fI
FAulwrqDcTR/q77DJQ/5RQiS9dxzU4PgYPWutEAuG7uYQ8JhF4LtW3p9F5nW
QqTmmG4Nza+9O9ZUwWoQZ9U7Nc/nExw/sVlfdl8fRiYtI2oLCCwMT6/QnseD
edfc3Epv2u+ixmbFVYXwNgu47KtO+Sm17inSeIjTRvL3pmm8J85aRbuNW5Gz
nm0raUewJsNY7H3sC4iXe8THUD6DpkKql53lwS87uJoTRVC8Tjzmp1wuQrlH
Z75TvxEo5Kh5cLsQGi6m0kv5791jNOR9iQuZmwnTwwcJaj+Ml7dWD6Dl00jE
my6CKLe5mMaPDQgXUdBT20Qw6/bG3/NbJ5octF/0HiUYyc/dkOVeCgfv6rvh
1F+MP0mflh8thXfCbv5hOk8ji6d2Xcu+h/PKjna3qZ9VRple8fJ/gSG9ZA8d
R8pL0/MOlwN9CI5+N9ZL80vsDpPVnHkGM/f79n5G1B++b9aPX9SM4djxypl/
/Sr6aj+WdWPbvpXHF1I912TqRFlEViGqnc/iUD7/2Huu8evJdkQvt7IuOkD1
u9P7zPklEyoLzdO/U34szm+S2viwA43SBvOP036VDCaGSpyg/mR3rPMwrdfb
MNuij8HHssmRIdEblKdqrUH54adQWK5uU7KHYMbybUG4WQ9cXiXXfE4jkCMt
WYoeXHxMT1Csp/oz9Iq1+mRaUbg/a1m2DcEuyf3nZ817YV+jGx97juCSybsD
LZkcaOfx9jo6Uz4NbpltlegHw+3L2JMWOs8aTnNxjQI82b6pVPk5nYe2w4ID
1Sys0Ez/dM6Ezs/XBfITSx7Bomz130Lqv0NWl9ftCW7D6umuL620Hw72jkoM
eSZs1ONja9ZTv1y1UPbG5RhsCfccY6rQb46k1MrR5zifZSiwd6D1f06JYO7M
gpapiXYH9dsAjl3Sga81KGpey3q/lvL4Hx3NuTe1yIubTYun/RvQ3m9/cVKA
SzPSDYnUr18p+c5WtfCQs5T7JDSSIEb1/tFFBs/g6yzqMUT340B9WkTQj2Lc
ZeRvXE75qPaPlks62I8Su8Z4syoCk1v7HJQdueBdUo1Kov3zmStgFH5mw7tg
bO43qt+QxKt/ruXV4Kf/OuUVUT8p4ZyMKxiuxZHiiiYhzWdd+aHPQr1uPJ6W
yvmJ8qz0zPJtqxUHNpOF02XUn+ROL3NfksbCx6XfM/LoPvvVXFMqbKwB0d+3
M6x3UP8uK/Nb6MnHYHHf1WunKK/7H/wcmN+E1cy2uTHKnyAu4NBC+06M/vVL
ZQi970jo/XdxUs8xz5V8PU7n5UrI8kPVXi3gW2VM2W6nvDrliiataIet7eou
N0+6jwXXs4QvmEhZXMu03EDQKnFR+v7WOuwSfkuWpPtPZO3U8OMVzsjo5O9m
UH3i1u966hTej8KlddkpSQRF63LTwibYKC7L0wqg83aNdX1xcEAVxBg2/Cl6
X4CMYWTyej500/5kPs0m2BKo4Wi0mYUf11ZJ82l9qV90q15LsyEcC7QZ3kv1
CVTZmRzZhzWaJzOYFQQKpupS/Y4CxNgKN9nfpvt84iartK8HHwMVmgRF9P4f
qreapDuQEeR5Uo3yZRXw1u5nl3KU6AY8uEH9/tTOwKhxHhtqPOWUYPp/xN88
falkF6rspB1nEglCGJMt4pLXkWPzI+UTrS9nY4dcyJ4mjL8eCdhA99H/ASC3
v8I=
       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8Vf8fx30LKWkgGiqRUSEZKcULpVCkaSaVVGjKyCY7CamkSIiUUUhC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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXlYzGsfxsPbjpJBVOrQQl7J0nIV7oQkYcirOLy0ncMxRIVU0kIL0SJH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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwdVHs01AkbnmTpguTayEglq8IqlK+LRxsSSktbuqg5Eia6bBHrUqTPotJE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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8ldkbV0REoSw3jWg1UiSTNV8kUdbGeimSQk0zI7JnhtHVQgxCptXY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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Vl0Xh/GqaDCUSlEoJFQoUnh/eosUSSVTiCJkKEpSKlSGDBkis0SI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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81GsbxpVkOaOVlFdUR5pK6ThtJJdkSZtJC6pTM5SijhbUEHKEtlMR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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81AkDxichuyuJiloJHaJVVusIeZQj0pZcO63S6m2KjjehiGxChy0i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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk81Okfx6YsbZH8EkthQzkSYh15YydZG7W2JCvUrIiKVM4cSXTIOnbl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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c81W0b1zBS1CNKIpRZiqRU5JvRUkZFhPBIVhpPJCQjsyVJRiGhzJDM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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlGk81Ykax08SiRgMRUZcJcso5dRgun6nkkilVLJkGUMJoRAqpRBlaiyl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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk3k81Ikbx2WFzdhUmAw2Wh2otmXtEvrIUaOfRCK1kjRiO4YKRbXRMVFi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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk81ekXthbqhxalEoquFKUh29CjIYylkJA0IhlbSgkppAiJbEnbRAnZ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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8le8fxiVpkNVSJDtUKKtIl0JGUim7IRWSZIekRSmK7C8qStIuKVv2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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41AkXx7EjFYuiG7kLSah1y+2bLhZvGG2SSyWViK1Rbis1osuqt80i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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs81IkCxaUUSatYYqJIiLS1JY/UQeRNWLStRyurB01PVkJDQl2r1Dbl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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk41M8fX0eHDj+6lEIkKaTokOiFJCRKSLawiEK5C6ElUroUckSnKIUi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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lV0XxhWhlGQolCFSxojES7mJV1JUGghJJUOaVIbKW6aiyFAiQirJ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs41fkWxnfIrdpocuuiopRLHhkqW3kRMjNpjEShwzSajqTjMimX2kbk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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs01AkbxpdYKRG6rGyoraSijSPKQ0guSQiVkC+mpNadpotbyYaWEG0+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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx7XKNMWoJGUdW1nnWtLmg4kQdZVi7JS1bIUfatKkRHQpUclS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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4lG8XVpbQJkshSogUpSSR3CqVFlJKthDSRmSvFLIkSfJTSYqEVBKy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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHs41IsWHd2OSuXRqfSSZtLDSXKolEfrmOuo29VRdEqFEc0tUiTyipik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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4lQkfJUuWGFRCyJcWDLIlWhzLpC/hkVQiEkLajWyPQuTTIpO5SkPc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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4lOkbtqk2Za3aRdqopYNDlnJap27lGIXkVFYnp2JW0hC2A4pUNovQ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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8lG0bxicpxOOxpFQqe6I8FKVUR9lSIUuK7EVJC1KUEm0qIcoWiigK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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHtYzAkXx0eyMy1WbFbYQi5hS6WQMN8KzSsloumG2qEirS2TKJXeCqNX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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs4lAkbxqlNihxaJq0+SliHmhLl8NluLBGRVauDqFRWB7QqhYucS6nF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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8ldkfxy2JZCylprGUsqsoWzfm+nhZWowuUZGRJlMRJSRJpki2BtlG
KIZIROXa14hwy3Xda7tEqFTOjPmFX00mpTnzx/N6Xud1nrN9Pp/v+zzrPU87
HRMTERFJp89/7+9LPDsdmh7DwHHFPsnvCcISu5kewiF4h9Qyx8oIfBKkohZ6
u2CdtiF2fDfBtHJ9w1TfMPgGXMWnNQT8e9n7Hj0RoiV0cPfJ+wQKqQdrVxE+
cr9ybPKdCGYi90h46+Yj64V31VcNgiYjz5cJMr2oHD20uNGPQJ67hCNfXovq
Uo8fVI0IbHPYxSyNHvxoa/BTxA8ExtIWJzS/xIHjm/goaAP9fk3MJdbKYQQG
Ff9e2kTwyV1N4NzVhUiN9TrJbgSVWCXZfL4MOx/nB8XoEGSMxjJ1dAuR6Jl8
/Axdf8+GxYf2MjwckfKZu3ecIPHLxPant1th43vy4BUmgejeWuZodh/8z2U/
MjlPMF93We/ZSC8s69fXHHYh6L/hmtD0uR+j5kaHGBkEyyNr3oUr8JHe5Dnq
e5jA7Z1LX7upEPUtjoJ1VL/YC3a6j7KKcTQ/QnudNsFVb+09P4uzoaWdV/gr
bT+VvHVhPGwUPq690sqjBEN2r7Y+GCxGh9PYjVwtgvIdr8x1Z4UwPqMabhlE
9WjJXDjhyMHBzcv3/2pHEBRW//bZmhF4yyv9/bqXIOXjxcX9zQNI6ln29cQ5
gmOh0Qav83ox+b7DSukkgZFpd0TLH8NIjGr1crhJ0JjHYIUdeoJBftW1484E
V2BzJlaRi5+0+Zp/0vOUdQlT03d3Ikc865e/aL9/38629aQAxkz1X65p0jyE
ptwt0x+Cluq0rU8owWddq7eCyRYk8kVZZqYE4uqaVlVPBvF76D8NAeEEUXHh
c753BvDg+IzMrkt0vbp15XtlexD68alMjC+B5Y0f31jXtkPe3NCqxppgc7ON
kumRfpy+r2ISE0zgrdQXEznXBdnkGHXHIwT1U1ML2wuFmBtpHHlWTuB0nPl5
6GM3FsZO5ic4ELjuYtQM6JUA73nvo6meWm7tH3IKymBx9sjwHT16Hs3rlqoC
AZbLSlRzL9L8p5/UCajgwv2PEMeQXdQvgVXK3fYBNJdfP+xyjECXmfVE7oAA
/YEtT5ICCXbKiAfE5T8Hy6LGn0H1DMuUSE61FMBzdVpsMM23sUidgVz8EDLS
XTRES2keNeXEb39fAaW6+MDvaD5zHZZtrNW8iRyd93PRNJ+O36hN/lzRB+7J
jSov6HpDxvNaUqwB2Dd0tL1IJfj73Ix0ydwodH/ts7ueTVBY/yHg/EseXOeu
LV+7h+Do705vtv82gPiWYMsP1whqZ9LPhp2qhn/yfVbPRuqPRjbL2awVYa8z
/Bg070NuO5QOFHLhI3XbNJKOV7TZNBSR1A2uj2JlLvU/69m8YYc/D/sjVP8q
oP7rfGvqemq2G1r/hD8c96LtFY0/hlaxoRi5ZtFJlyDt3jvzsogucOXmGp/a
E6SOSefyVHrhufBd2U6q76yDv2Hq+RE8K7I94H6b8uN0zM+y5lVwvMxw8KXj
o1Mavt0eMA49TS+1F9TPtYVbx+KEVdBhvM4MpP3h22zEOjOLYPnKRW4z1e9D
ju9YjIEQC16n9P6k9bgiLMFChPMMVVmcV+ocAt5MUePgRgEklLaMjO8lmHOd
8BNdyQVfTmbPRcoXd4XqDH2PQXyu+2HF8ySC02GzgVtPdWK0NfPmJ8rDkc5C
P8ZtARJvCd4cpX5MNiyLtM8YwpK/N0yHl9C8+ldOWTTXQfFIYVrkFgKVwoXG
CzXdKPJjFVdQvrjHp5y4P9eG8pvTcUsZBGqxUmLWNtHI6ej5fzTlWfFvid3R
NoPw3Kz0j9NVgk0P42vPhJdhnnvdWozms7QlVTjy/AHm4ivXKdP2ezPtTZ0Q
QoWfXjdfRPXg6ybou5Sjd971nATtVy5dyHec5qBMIduYUD+3KxQErm7nQ2xk
pFH/DOXFdwc3hvV0gaNdunTAlubTUWoyNGoQL3M1JGZu0PxOHq8Kqu/HbtEl
P5UE0HyyTf3uJyUjonvRVVKd7l/Za559iY39BUrmrpto/fiKNAzr5iGrYMeQ
Oc3vvHO7/4umSgRM3Il30icIYVqZZC7WQlMyfdKT8v1KcBLWWLVBKSnErwYE
W8Zlze6LCmHGqVlcSnmltmx2ydItd2Hk4Xkigdars13iaTOjXuzPs52YpPp/
8g3f8Da0A9mB+iZZ1L8gvnJz2+F2mFboqVmY0fGWTinSfbl4GedW+YDut0gY
pf0ujYub2meW6vzHA727K1V8y7H1lMzVcspfuS2M2eLfRrHYd1Y9KpPq/+df
jrzlQkxN8GMe3iN4vCKnQeyjAGleDhqnKP/XrLV//013A/wNPOvUttH7Tq31
2IfoIVSKP5+ST6d6nDPAjfgi3MVAgzqdn/U8JES5gg8n2ZXybZRX5S0HGG5b
WtEixRNbT/m4qYbtz1nkoV+h+Ub4PpqnbQ9frUm8BYVCY71lVE9+Wbh1Y0we
nrxOlvejvE30ZpgYqvUjaTe7aJ7qVZYkwwy9WAPX6TA/QutbxD95pUfiQ/Tk
bDOqNSSQcT70+EVAL47oB5QdpPW6alwn27ytGRXBMR0C2j9meOKYR7UAzLkl
7Fh6PpGpz+pLTXjItZJm8zwJ7Cyno/cd6kfBW05NLOVJrvMd9vSBElhFfzHo
o+fztmp3One0GPIBtnavqV+bEqbFblW24FgspyfYhPIu8sro6louAr3cDLVo
/Q2PNUupZIzCnxdXPXCFoFcneJ7FasdUGrNAlNbHrvz0VQvuXAxOeGV9caf/
D7Wf8i5I90PS+lvVfHo/jEnpbN7b3IL+7Ad3osxp3gbSYjOtW1FwVnKkhK73
v9WDE5+a+rH2wzCRoHxmqdqndy70Y0ZqNl4qi85nozLUc7kOW62m9UDzaSyr
oXat+jnqQ8Ik19L7c2zdlaNqscNIMb809pXur3R8LGh3eQU+DjqfHab6Kgr5
PjvsubDobLv6xoPmL5XRzOvthSOzIio3mvKbHedSWSmExSf2IfFCgn8BYfas
Ng==
       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8Vf0ft0KSyCiyiqSQkVWpN0oRT4siRJSH0EJTSkUlIwlpICopsskI
18o1sjeVMu45l+RJhKTf9/fXfd3XPefc73l/3uuz0vnUfhcuDg4OB04Ojv9/
arlvvJzY14KAAN/QkEQapTlUzbFz7QjeZcflKU9DczYw7P7jXti9ORqgO82C
4QLL3FXTJTD41dY7wU+j65vQaVf7bIzLOyS9XUYjJ82qcNSgFXETXVWtLHJ9
4eeLn3MroRzNORLqQOMXtkom1b1HxXrbzqkJFpiDzjJ5Zk0w2BUga11KQ8O4
6racTRM0G3Tvi9+hUR23d9Xlwm5kpNycYY4OwzTdyfNyVQ6kqz92yBrRcA7V
EKV5P+LIGlnFr8VsaEWqnM7+U46xzP1LzybTOH1T+8nkcDeE/onn2RxPwyxw
KoTR3wuDez/eSVWyEZJ8l5ynEqnPrPtCgynoM1HNX1iB1W1H2801aHA42XWd
tC/GMrmfSQObaBypTFPt1nmIa983qwavoeG27+Dd183p0Ow/7BwjRK73G2Du
v9eHboG5cRQP4SbLl3dwQTfUExIjWtNGkFp9K4preTiSi1OcHAm+DM+fTsVy
tdBbn78qNoyc15/9pHlhDa6f4fdfsZyNn/mxQcd6mjBkue2UhxqFvoJtkhV8
HdhuskF567dhMJ1ev9UZyEakXe589i8K04ef3zqhVYbMDHen0940nt/mGPnu
0Iv6oqwWhhsL/fIhXPmSteB5IiX04gobMWbTRvcyGFjlyvvlWTuNLKVbjNCa
JmjI87LPXaWhI1il6XuyFqr7jhYaRVAY8ZR3/Spcg03KTb8sb9BoWjwk8zM8
E6+y+QvOn6eR7GLO+0izEeFexpoXkyn0/96qmGv1EltL/rQPStCwtsVnqqEV
Lv/RZ1UfUrBx1g83T2KC71XQn4JPNEr87uzi29SGH22hRb/Maagq6M7LB9Xh
UqLdJGVOwTjhiY6zVzME7nMFCZH5cqwJ59U8ewV/VptkbyZ4+nNXvFibW4JR
4blZA8KP+iF1auXDTzj7Z93m/r9DeL9lwU7bgTbscBaayxulMB4w+6vHuhba
0c57bvQTvlrI3k33TcYPhatLosQIfgclt0jufQ8O8bV8VSwax1itezMNW3Ah
k5v3rx2Nwhyu4pBjLUg4/Ptz7ziNd22fdPRcGqFL3T2jV0aBu1zKN1i/A0lc
GxtdD9EIZfs0cQl0wHy0XfGpMhuCgpTVNaNyXI5bYZtL+NP4/Oi9u+xa/Nlm
EChVQqElfOuplTw16Kkd0hBNomCYZ3WGK6MCpVcXP3HRJPzpvSbTON8BKkjf
8UIbC/7GlR97Nj/Fyhb+r0YKNAYYaz+ZnG8Fxz6naU8bCopmpvNVfH2olTuw
XGXlIHomuT8GEn1xBY7oGLnQUONjrfwS3oa6SZOl0yI0Qs4eNu7I7kDTyWcu
eX00hIf8T+1Y24HRlcWl9VUs8HhZK00/eI5n+/unr2ykcZX7voirdxniAgcu
5F0jeGVmyI25dsDqV8rVjlAKnr/2+YiJtGELnZHtm01ByaHd231LKwTiPHyc
7rKRP2tbsp6zDl8TLOSkllDI9+25L7koEbymDlk/BAl+Yx9zs92bcGJJg8Ha
EhoN1M0rSxO6EWanNJbqzMYn5Yndoyd6sNkx9/6A0ig4EtONK/96ILHavmzX
ShrKAzfyNtQyILdDwVeL8MXN4Paa6JFmiOm5Lyx/z8aumG9JhgPNiDA/5j0q
OIKQ3/fEF5xvhKLv9t2LPMj7W3gt/5T/CsbUu3XCW2jkuwhpyNjngOFw13VU
mwZTwOlp0v4yFGb8uSU+RkGdTTWfyuhF0FP78psWFCxC//0gKd0MnuxnahFR
LFySL3b6q1mGDLPx01xEbxFbkhaGuKVCjH8i4KU6jYfbBPPPxySB25j3lqEk
DQfLuhd749oRd9f04eZMCl1i80MXelpw38LGknuUxmPJf1dc6SP+O67+KqaC
RsDNqEy5nFoMnrj7z7k4Cqax8dqJ3jVI2y25yIHMI3LVu+pfJk2wUnvMr/KI
ja0fvivOZJHvp9zOOmiOgEPoQEyE0TncL9zq1LmKRvhFH5HTr69B3LLxkAzB
s3+9z6tR7ggwNygEPCF8u/371GtPKgFshTFzHV0aE1a7RN2P18P/Fa/69zNE
r6b0UlELM+RxuzvMkvutoq8WLfrTh+etmRqdcSMY11K32X/iI3aclNjwI2wY
yY6RD2Q4e1B71GZi4W82lBWqFsRK9WGr9qtTAkGjcHyjyytg1AthBcf6efNB
9OfVNY6lfMbx/ftjVjeR83oNSvTmvoFL7duRPjIvw4Iyi2jnCkj6a7kPkfPp
V/X5xmzoxrIaRx/Zc0NQWOgrElrZAwEvIckrHmzIb/JuOCTWjSTpZoVyHTYy
XjhpeyfEI2YgaoWjLPGn4yU/V9uWILy+X6OA6DfK7dOZcTLfkePK8h0+xO8H
H2ypS2rGc/FbZg3NxG/yInkiHfPwZcNDyaEDNJ6uvo93yi+RvVl81TAvDVM/
rcqunLdoGTzwRuQjhTbhpbV5uhUwCpq8tJU832oZ16tDiU3oe1Ia67qawlTJ
K6UezkZc7swPUiB+LC1UnTgZUYexJ0LbChRpWNwYlD1i2QKrMqXfRrUsPA1S
9x4oCsREaJu0A8E/8o2l61LpBvSXtt7++ozwb6r+i91wL6bKrorUyY7Cz3fB
TyGK5HMR/1i0DQvvGAcqPHXawOjid6qfYEP1KOcDSd4mBCwZmK5bTIEv1cHr
a2Yrnhm6u0UQfmqIt2zy48zE3JbninuJPi7LDm9TP9SKmy81z54xZmNoX+y0
yM56HBqP+qbTQeHpFd/bP/Wfwvbq650aJH/5GXOfuK+WQ0g6bMnkXQpHTY3T
ynR7sC55l4BtJMnrTZxdzhuy8WDc2d6D+LXwiTx3dcUG1GfHNT2oYoPZr5fh
4VwD5dzj9n9vsqHwUr0npr0Yc8kjwiORNPRsjC39FDrRsm5V76KFFOQXKbZ8
D7wB3rqMFY8Jn/25RLKTxFqhlv+vRPww8Yt472JD3y6Im0bqNMeyoPFwp29c
HAPXXq7y+Zcm+ZvWPdVSWYtwadMw3gga6c7Bw4e5PuNx09DE6GIWRvhglvqx
Aef7j4orplDIya66o9b4BhsrKysuEL1f+TuZl8zTBiWx4z6PVWnwbkvtMudr
wKbLdSlP37MQkzXm16pbC//cWyuoQgp7la9xOHPWYrf2Z7Yh8ds28deFd3Z0
YNOOsGJDgo+93sKz86Ll6GWWJNwmeWLDszNrd1UTxnLNakrFWDjy+vMagR6S
T2m+ha3ZLFh/DNjb+V8jJBq94xN0WXATb/ewS3gP/WVCLfKkL6y/43RAtKEI
z2N6DGoX0Zj7Valx4GIWLvMN8glyEfxT4mozolpxx79UIGkXC4z0KKbMyR6I
7kiTeOFHwceaZfxdpRvbXbe+7b7EwnoHHZP1PJ0Qyd3Y5SnEhuuUU817kwqE
XdjS6x9Io8awtXh1ZjMGqRfbZx6y8MJUP/VZSy2+MVIC4kj++jspW9FB2TDP
18iIH6ewf+qN5cJcoo/F2/q+8LMxRqcweBnNkLBuMJcKZGM++vann6+bEXrI
74CfNhvhjE2fvS+kotRI4XER0ZvFXJK36O1iCHNw32R8pxA+sHz0EbMe06p6
ImEEX8Wkoycjpd7Drz1iZvNmCttbDy/7UJgEVcFYcajRqNwT+rtduwJF7rHs
TcY0Zo7tc8haVwfPumuOzlMUtDu19hlMpyK9a+i86T80Ynpkz2fT5Vh6L3Rw
/ATxx+qgS3L6wWj/tKBxXI7Gj7XWql0BffCbdQ2cHSH99kiBwKeJOmRF/ljN
WkvjtS1z5/iDMux6V59uN0whYOzbX36TWATX3IzZu5rG6rV5ncrOLWh1XM2Y
8acwo1HUmBXchk1ldX30WTYUKZfaRY0VCM30/9hL3k984KuawWgnZNNu3FWL
Y6O6L0hHkFWB/Kq0FYcyaXBuiVt6o6QR9v3LnvOSPNRVSwlUSm2HRUxCjfxn
FhouM/UGLtfg1Mp99qqkL/tMLFeL/lKIJTfPm2zZSfxSg3GuZC4biZaVOTsJ
vusdH+gd02/GlF0Oh9ITChcC7neGryP+Xq0SYnCeAm+wzR2VkFa4V96w//uV
jfrDB/YYh1XBnE9P3qOLRsqy7bF1R2pgEqXn9nchG4Oasb8fFlch7NgpS7Vw
Cjv3tB1cxF2FOAvV4Pu7aOyVjlZ44l6BqjalZi/il32CN6NDCluR8DlPzn6C
RtlEOofJZC3ANrl3RIrwq8Au1lO/DZPutnunJAhfvNZHO3ok4Xpr9zdbgu+7
ZInSyf19GBh/I3+xkY2/izkn/9XIh9R4Yvm8IY1DIhxc7e5MeMqoSvWSecuP
LkxdL14H61lZswVHaFBzlx947HuLS166ZZ1ET9RdhVn6VQkk9mwUHn5NgalX
8866hAHFCxa73WVoKCh2tiwlfWnXoi+/V7mS/9d3d+Ktbcdt+7czuaTPJP9n
0XrsbQcaeiv+jTg+AhubPWe/xDTAznj2ntR/ZL8Qr+9SlilBso+fSNRTiuwz
udkT84+wUipxcngdjVdbrkdKKhP/6m1/Yi5Mw3gJp0qyewtUOYfiEk4S/+/L
m3vf1QCm8XGz0gwKyTL/6WflM7Au7eGWNe40avnrvF031iJ4Ju9wgR4bF/Jt
fSLHmDh4evGsmS4blRe5F/uv70FcubDIyqU0pt9a2ZgI9ULihVnZx+5RhBy+
lvhQqATNGquyvrmR/lfRd35eqxWiWkvNK/nYeLThj0JJXAcqzgme6CB51Led
l6P77Htocbw9YED8ULrIyuPNYybm97gUKJN9c4YZ3519oxsGayNUrviNYJPe
2JALXwlOeoda8Xyl4FVFlT3vaEHe3xdxMkwa7K2O23ua2nDEb02Lw8Awhn3X
ZKfs7EFK0B2x7lTCz/z06L9RWbB9MuUIkg/bLzdYiws243yf4ZLvN8n+FBAY
ImHSDEf24fYCgjcz+e39u4VVmLfg4/9G9Jy/Im6oaisT8l6nF6YtIXzYVJ3U
+aQZfqFKqkoEr5c7Peq8ouuwYz7hxH0y72mdCO0Fz1Kh+2Mq7Q/ZN+94Dvt0
Hm7EnZaIqVMPWIhUeeb5+1IrergfC9iqsNF1IS1rX1ADHlar81udYWOvdZva
kielEMh0PLYghPQD8ZDNTr0duJn1oWzMjI3bKRU/bfIIfypL+I4uGYX8weHs
vI1F6Bh9xBlF9Djq3ri4K6Ab/spy7i94iR9Mfn1whPSlpquduxVjKByLeiVi
W/4B/cL1dnokz0sOJ21M4qpC2tTjyApHCgKcmcocSs2QnFMXixdlo7FRdVnZ
216y//GH+/ymwBDbzClTXoWT+DKxg/iDKXPFMptDBdDlq5DdTPYPi4sv61x6
yhAc8iFn12MKf17tzpM27MLsp4wVm7VoXJj1LPUf/ADLxUO/VyvRaBG2+rBE
uhOfnv8oMJlgISMys2fGqwC7qT0DKwieg/FPJWXutGDogMu1r6Rvi+Q/LxoU
r0ZkyrF+ifvEv3/MblfrK4SkicYYbwXxfw0rlXfX8vHa8XjfejK/7S0Mnzvi
OVB4+tNDk/S1jJxdX5vPduCn1zbOHIKvaUj+QP3CPggyBqL0/mHhwyI1Zw31
DtiuPLFrN+8wmlJknR4lpcB/vQB30jzpR4sZsuxv6Yih5C7Ikf19u4Sx9o7q
bPg01Q6fIL8zJvY3rvmTBRGpDQsGVUjfDtD+e7Q3D5HXk7W67pD+WF+jZlR2
D/LpiXIBpI/Ovl6wf+2XHuz2uTazR53C7mfT1T7DzdhZxfpQ+pYNNeGr2jxl
1Vi+MkzgLMmvAF2fAbf4VqjG7R1P9yT9zTv3rr5XC5L8O/Vu1bGQPBszb1TQ
h7iwoQqJPDb69ZNDV31vxvVanglRktf9m1MVo1WSUcz89TVvG/GLQM+6Sx9b
kLFeIFOnl/jBPZ+BX7ZNuK6uc8vVhPQV94tzzXMZKLh46NtBkg9TvPypH9Oa
EaiiIwOyPye7JZ4KsWUA9iaaUW0UMoLMGvnMGzE2XD/O68iC9NQWSo5igCX/
/vfHIdIXK3cOukf2QKrwnurw+6+kX+8/Lyj4Gu/n9HO1Sd+06hRMr0xtRWnh
35EFpE/2hG99697fDOXuvBS/o2SebXvSajW7IdgkIRe+mo3IvwN2B+QSoaCq
6ChK+BlzmQguNRP/nAwW+y1No95KY8MPoVZY3Al8ZLme9GfpCp33HJ3o4dHx
03GmEMZhnFXW0gnFTqXWoBY2+GVtdwRK54Ln4vxsEOl3bqVNbncfd6A5x2Li
xjXSry4ZGbgxiiB41sHiFNnHLDS/qRoyS6E4IMyxg/hxf5Xj/j/i3RjvHvwa
6zKCc2ZNJhoc3ViUeuSHI5P0QdUJj2+PP+Kcy45TvKYsiK05f/u4fDWOjM10
L/Ygzx/R7VB0yEeDQ+cl/nIKK0PyI6TsW7E9X9yEacjGzyPFb2QnGFD60Buq
EUz4u46ZOPY6Byf4YvYNV1I4GDYmuJizHT6WisfjlrBxvcgqLJJVDlM8jkon
+cW9/IVhX/4HLD0dfXsD2e8M11Sp7imtxngl18TZJBpGDsWcdSeZ2ONqt/Oo
MMnPwzOJ/72rxfzs8n6BaRrz0ue2Gx0og/wxlsEcycflUwttOuar8Y3j+Tcv
UZJPCeWjCdyPcKEk8lIZ2Wf0XgTvCD7Yg2O9Tt3fXUg+TDo8+xCfCKvQTypu
G2gsfSFn2KjVC7djHaMVOizMle8sGo5txTuWCv8w8Rem70G5mZACPMqjdYtZ
FFbzTlZuc2mGjE7wubiNw2gwtZ9W2tAO3gCjg5MzNPwuKbprZ7VD7N5TpmwM
G+M3DF8qowK3zzzXUCP7pLDdv3PKL94iNk+9vZDsL5ueaNXwXCF6F7tg/evS
CF6J9L48VNSJ8ocPYjvMaWhVilZpjXUi/oZh1IFYNja4pNOD8bWo9Ra9bJNI
Q6la817z5RxMFVu+Vpgg/D+eUaDlmwn+oB+vooh/Jb93XfIimvSD63H/dCsT
/MzdbxU8qMcBtXOmcz9YSFKNC5fQakPA6ULrZUSP/wM9YwtU
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs0lOsCxpE0nSjL6SK0uiwHJYW2shVPp+YoQi4VSbHRZXempFKjUERJ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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk01QkfxnWToppUQi+NjEL2UpOtHiZCEyNelEQLNdbLzZamuKJhJioh
W7ayTPWWsgtZ0rW77uLau9ddfj+T1skt00wz9/3je56/nnOe8znn+9E+SXUP
pMjJycXJ7v9py23RqI5jgcYWdb6CEO0ln2/sjilHjW7xSeJnEtdKB9ntV3+D
o6vXnwlpJHx/VNKt3clDcnTVhnK+AAcvUonTKQ2IoOyYNfqGxBbq+AFNXRa8
9nFtfHKEkGvOPHzAIg6hAR38L2vmYO15/trOWRZIamnI+wsi2I+//iH5zCgu
FU54pV0WwpYaZ51h8j/s1RrOfBxGIiv/QXL8skE0+E58zbORgOUTqN/jwIOc
+7MQa6oAcr+aumBrOJLisvxfqs3BclDBUj6KA9Kuj6RrCuGsXsezZ45Bc37x
foizEG7MPRckG+vxTLpkv8USEsZuc+G6ukysVc6nR0yL4Lxkvd2XigGIUhTj
OifEyCwrd/yOOQl+qPT21aV8NIXkKAntJ0CLraCHhc/imac2d6VRD/5o50Qm
L4qhdedUysxsNx5GjvaxWRIoi94H6CcMI2LRpMxmrwSpwY9e3pP0Y0W+i3ZJ
uBjtDy8VO61rQvyFD06C9wSMDokVzvsxEXGjsCo8RwTb4s2bokYG8Ht6a3zW
9xK8D86i3D3BQU5M58nrzSJ8OrHRv/LvHGxpZ0oeT5KwStznRz8zA7dbb3Yw
7IRoHp3YTXHggt0eG2OWLQIrnUVe8XyO5B3BFLVI2b41VlVVaX1Yrt7VYxgh
hgrdji481oXKGl/fVzMS8K8HrTp/nIvR69RSjXgRLLiaHkPDbQifaf1Hk0ag
hXZrTyG7F6n9xbtflEigghtB8uoduL8z6MLqrQTcG22PirO4oPG8KPoLAvAX
eKpvH3bB/FFeUfRhAraVcYyQ6WaQ1j/2mkkJXC/4Z/uE4wBOL2fPJ06LYaj4
57LuCDaMKQx+/QMx+NvkXBIzekHTs+S9KhXDXvRxlTaXBf9JLyLEUwQ3b/0R
m3WlyP2s5t/QSqLniUJ1sFEfXK0YdR4+EiSaKq/++XQerKMlX0I5JNpr7Qze
6NZDabDCbN6YxCqtzmt3MxkIurmN77OGgI2ydIhty4DyvQrGGhkPfWJiPSwZ
yOvc4OUqFSOV31q7Ku0ZKniTdUeyJci57O3zDckF83GrNEBBCINEU9MOnxIk
R7adSGgiYVJZXW7iOYI675iDrzeLMPVbA++cBg/yjXTqxiIhZqgP/ho8zAMn
VndDV4cAScoGcuUfOHDLnn1C3SQEpXjz0j0+I7DVM0yklIlw43jD+LlHI7g4
bbHTnCPGe8txpfKcCWzLPPMd7bMAR/10WIVGE/hV3t4u+4wA6m0Pjg2/rENo
hHNB1t8y/v7TYMfnYvmH/uv5AhIXO8/0fPylHouGOprStSSCYyu3PPfggpXQ
yKVmCpFqtXapnUcrrlzReBLgTGCpp4vZZC4XF76i6ZwYEiK82sTcXziFetHA
PFn6Apk152OjnMYgiHGz2t8sQJTL9vZpg05w3DuX1bVJUG2iIv9xCQ32v6zW
+HbDHOSqU1IUNhpBrTjneYD2HISXN9f73RpAxbpdjmepYsyd+uOk0fZx0Fbr
o1JHgIuB7KBtgTVodAkLMt1Fgq3bdMR5xxSeF8crOm2T8V83NHmonIU9REio
aqcQY7MLRO5/J6G04YWjtpcAuVY1mlH7mnHLvn7Nrg4C14quBJpUNGFnRXqQ
Rg+BDLNX6ldvM/Gy1lL3hViEvtrXW9L1mBAx0qRWw2IoezeevpRahrtnCaOF
RpkfYw4YjJQOgmdjXdceJ8EUqXpnmOzGCm+/wBI72X+kh9+e2c7A7CczN1WZ
X1bo/e7lp8KFef7eslvZs2jUNzCUpz1Fie9XT37qIlDYsOzkKQMWkug1CZZv
heC8edHqPTYEhQP2qkvsxMhqC9slNzAKxcUZ9wVPWT+7PDg9eBja8/y0p2Ix
PtEfbNL26YbGw4KwjRQCDsZP8oaVujGVb7zeWLbnzjpfy6L97Rjdc23RyppA
6WLA3Jj7NCzsk5cHZ83gpyTm9MhkDQJoBd+rrJT5fX+2aqa0A6Mcu8CtegR6
tHk61QlFsMjwOdDUQuL4Dwf7B/s5SKxiE1NvZnF3KE/NbGES9C9a7wwbhYj2
NV2lsoKFwwmuka6LQrRsObbagdqPv/SaDpUdFcPsrEfYq9lytMQe1Y+6Q+JD
o3uKx/Zu9Ok11kl3E7ifH5iRdLsPTkorP3dFS1D8ba2ZU/5juA7OmxY5kLij
Jn+be5yJCiJaR2tA5o/C552b6JO4rFfiEuohRGBchPKKKgbYfvLzpy7LfGDR
W9/yLgO5Tv6pqR9lfXOKerr8fXTvuke74keimV6Qpzk6jl7FI/6vVUR4Wywc
6XK9B+Jp0vG2mySU/6NKnjPPgrRYtUCTJOH44URiJK0X6QPrFdMsZT54d5Pm
aMOGF/frkpX5YjDr7PfOfKnHR/l7PmOfCPwLk3HBaQ==
       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4lOkblqSIsqUtpVA5hEIOK5WbTA67OSQJFWGLbGtLRNJqSQebQ221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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lF8fxlUqSkhCqJClQrTTT24VrUpJKlmKklAipbRYkyIJZa0kWctO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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs41AkXFkrRp56UCJUlarOzcsstbwrLrrXuRKxHhSSVSkSlj8R0/ahd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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81IkfxlXSOrbVsWwNtiZF4yilS+qR2NJWjuhgk1qxixrlGNIlbLFu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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXlcjWkbbhHlizmVaaIZk1QqFdHEOOmSJnSKlEiLmRa0yNIyhlAnNS3I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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VH0bxi1ZkiQkRaJFKkQpW3VJlEpFIS1akESWJJSeiIqQRAlJnkiW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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41AkXx63IlPs1vMbS6ipFTTfk21aiFamtLYsWlTBdSMm2uqGWXAaR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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHlUzIsbxtM+uIeiVZG4SIvKEqEnS1ISqpGb03bL0L5IpA5d1dzEdHEr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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk0ldsbVh1NpEQpQyUNkroypQyPOKVfSRQadDNEJDJc+gkRpUKjUFQ0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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VG0fVlQqyk4lRNleUikp6la0UCJJXlsUkSKVJC0qRBFeUhJSKUUR
kSzJvi9jxtiFwpwzo0gRUn3P99e55jrPdZ3f85t7XXHklIXLbD4+PodZfHz/
fyp4Lrj1PSMFGvHFDXcX0pBNDYl5asdC0r3x3zqVNJLOns7bdDYMl2xSGe6r
afxlVM0c0GhD/47Ziv9Z0Ng3cvq4/6IGzOa8T9GpoVFs131e928upMayWzqP
02D+/XeJ+B02RoI8XIVnUXCLnaO5RT0JzlrOzm3/kPMKFTuaFFLh3GXp+Y2P
hu7CdgufJRUo2Tf7aMhWGl2nv+v1S3ajUuLwo/v6QzgYvD4+ktGIMX/PY/Ed
HChWvQ3QcAnDl60aZWnKNETuNy2wli9FSLb1jmsbaPSVb7v0gi6DRvmR9IsB
FKp/dKvcPlQPhRnVjoHFXLgHndixc30roviCzu3i0Qjj+7riw64uTIevFutV
5GLNWrv9rg+aIde0y6b7FBfPA+q56wSbMfmTM9ZVQUNiFsOoTaMOR4pr20w6
OfAV+jBzYqAAuvk3iiQLaLy7XpyQVNKCUMaK7Pu3uNCtqWWNby3A42ZB1Z3z
aXjGPrhz074F0jPG+lY9FNbv1HrT4FYNXcuZO7kdNIaX/roB70YYf7g6T+8p
BUHW2hLqfRZEul/rFu2gIbTfoDs+tgnCqkqXf0RxMbywM1r9dDQ++g1OBSjR
OLRJrP36mUaoBoQq9EbR6PRhePWer0WqUDjT5DQXOuXaxrlyOVg+EHnV+j8a
Z/1+ylcfboHUr/2rZh5ycMS4Vn0tOxdLM53c1XbSmOYyl/xxbEb4sIOw/Qcu
ig0GFc8tzIWtqWP9lAeNxwKlk45OTBQ71YQIkN8nI2bbafhVI0GZ5Z1axoHY
NfqP0ul2mLloea1R58B65Zw3BWfqsL11n8+dHA50xTRY6v+yYPd0fqFowSAk
NKma6TW5CIg8Glh5mUb5pKruM6cOTHyciXVgDUJ6/eryaLoToTf99SRkB6Gx
cf1d741dOPxyh8olgWGs8ToknPCGgWSZ6LnKIWRffwW1l61thlXgretmthTM
Zw59STZ+BBtj+R2hUjTWV7VqVtiyQau16267RKHf5cpJAYtuJElHKq5MHEKh
QkxqgVwdfhYNvVN/R0FxTEu/R6Qdupkse5Eqgh+bJMXlXXlY88200PgsDX2m
dpWnFgtZGqsn/6yjMWrkNBm9Mw+ja2xyhUYp8I1eOrTN8gH8dPP0tgvT0Bj5
2vJSlonAV0s0D18ewIJEiK73qIG2SUaspjgXL9XDbu84Vw4Z3srl7Zo0+LwM
8pL/bMXsGUsl7goapccFDGzYbTDwzNCrOk3DK4k/1fEHG8sCrLT6VLmYqbYK
vi3WAsXQ9RyWPhfWv2NcDW4W48by/jvJB2mcWFmjfOF1C/xarxUFd3JRzdQ+
Up1VDf9enz0qExQCGyOfCrVWQcJ4i3grHxdiWoItlGgFIieScme5E7w1m8uK
C7bDRyUrOvwdF5MTv+dK19RB1bTl9aZ7ZP/XvevPxZch/mPfimXZNGITli+J
/V6BxpYRBJB9GI1bfdi5rAOVi/lflAQR/ngmb8r+kQUJcWG2A8GTqn+8rH0M
C8oMp3DmF3J/2bU5+3TOY2bt8yaWIg3biNTjklIsDM/pcbJ5S/TnzX9acuUt
mFewYTi1mELxAr6Mnpr3eJkhGj9VS+GPEM+59VAVIiLV4nPJ/ZbWdRgudn2E
Wp23DsEbiR6aD3MZH9iwz7kXXizOgcjXd7L2v5qI3lC/fn2mMNV0JiL5BgPp
dPe0nwwXo2HaSzN0cyDK3/ZYcwGN3Ycnbnx3qsJ6q/bLLt8pdAqZbu0paIWF
76gP88gQ+usu6OpUdWI0Su9gsC8PJ487jRnvqIGy9z3XrW8o7OVTOfnKJg9J
bV+Fk99S2G3eLR7vVYlw/WVbI1bREFjVctnNsxEis1Q/jBM8032P3+5awIR+
gpZEL9GbZ7GhidM7GNjK83PxkOPCx0vU36ijEm6SvVVdgQQf3UaMgCcvkbHS
NHy4jsKRX+r5q84zcd0/ZvL7chrGc24Kuxt3orPR/LLYM8KPdeuWrFnbjY+3
Tgra9nDhuGfqgON/cXi+ffjzfBkaZS1VUiou7fiWnTYgVEj0/krkgOy1TlS/
yLx/fj8XVPymN3Nj88HXLevW1E0hknf30sKxfPx2CE08Seb5KzJ4JuwKCw7D
Qi6v5nARtV0mOrC6Ac5ZifILv3GwOWEoNtyuBWWvJK7mEjxdaVDX0+xnQ9qa
I/jQgQdLK6edqlfYUJ6ZEREsIf6VOWD/+WUdZMXnNzmlUah9Gjr05VETRPhX
FNzQoVC/J2POvOVdsLzsW1siNYxXZr0la6gudG8sOvFQmQvlLfpD/1xogmLM
958mbTSe7ohrEqprBueOrNKeBVxInsgJbbWqgLAby2CnGoXnRe8S+8qakOSm
+MBUjIPp3wuf2qa3Ynwv7+Ktf3kQEbH4h+PcBpMTU2UtRA8mhF4raZuyERJm
39bwgMLbb+tez29lY51Gx9oxioZh68YdHb+aEahzzFzgMIW746JMpVssmE/v
Hfc4SaPop/SZGIqFKyUfF+WR+Z4vCrKT8itHpXiF+7QAF/X7k/y3+dehVrPW
dOMBGlleRd5Th9pwJ/lfyxWeXMh4OF6/mJ6Dh3scBcuJX/ON9W/pvPgYYg/S
JJ6NUxAdS0p3SesBIyjtN2VO/FqyOmuzOZvwLW91YQLxW5drVp3fGbA0tW1v
/j8ffft7BYSq8MIt2DgymOBJaYvpkjUtyNLN2Hx0EQ98zccWpYxF4aGCVKay
Fo1PgWkRr/a0YTJA/pmXEg/OQXMd02Sa4dmrKHpziPBdtltobHMJrAJ4ZQxx
GskXsx9/82lEw+7QvbfO0zhqqbGLJ94Dye69HYwMHgxuPnLLGMlH2jsnrZho
Gtmp0nu4PV2YObhPsOM+B26f59uqfX4L5R8dvNF6Cgl9nCf3XrDw009JeVEn
hWn7V0EfbdqQkN59/815LhL1f5qVXWFCyEH/Hu1M4erqYNdb6kX4qHZddnU+
BcsliwZKTzEQEr4pYiST6GtHDqcyrQRhA3sGReMprElF2Xt2Cd7N8dvyXyiF
W1XjShpVHShaUlNTV8LD31OMJk2JZjhb7gmpmM/F+rwu9qrVneibL/q96jkX
yZuCC5V+M7F4ZdP7n3wU+tSpSHn+J8h4Nc73S5L4q0C64sk7LUgfr0mOmSF5
x/ysgMFIGtSiFsnLCtFoCl/z2udMMyx2vz5QQfRe52FhdJFaM+RtVkV62NMo
7Jy4fa6JjVFRWqL0E9Frhy3epvoZMF5uu+eWNA2Fwri6y0PxULddM//1Ehqr
C82c1vmzMNo1W9M9nwu7jMfxIe9JPmvWm+rsIed/bDn962MKYv+eMBMn569G
jMjeDwyGvpqhjNxKGuGJ6qXfv7Dw1mztpxjin5/1T696vLAUG40q21vCaUQP
fXMclGLj3eF/xHVniB8sxNXJfWzsvFlqV8Ak+5WcM/Upg40Jvot2D0w5YDQM
ekjXseDXe+XLTpKHcpW3jT4orMGnp3qzZEY4qGR6BsasZJL5PMOqj3Bx0mZr
YxLhj8HAN9F7ThRK3d8U6cl1gqnWWq+/n0KS+YT1RFQBNgf7iHp707ghpaE4
/rILEiXtnI2ZwzB/oP4gXz4dK3w/tLryk/veeiZzR+ce0uNMeoZJ3pph30gr
sivH0StRPYFiFMaVvRRfyjVDQto57GYKDaNW/eVHVZtg5Li94PMbkieP1jYY
qLQhT5u/XcSBC7cvxc3if5vgvll1x7lmLmSnzTYoOOVg8vGjIw/FaETW5WVN
fWlCcnSwZ1wkjbRHJ+ePFJTinUexFdeIxuwbCa1CqQ0ouPiSlz5E8BfGSBrN
fYKX3Xt0vRVI/iv8MTq9uRN/dF0+i/O4WHDx5rMk1VJE8/Z6L71OI0fkdUan
VQfaxUc9PIYJvpz8fPgfteCn6jUBfS8uYu9ZRY+VFEHdimGobUhh4GL42MZY
NtaPFi7y1Sb7Wcxhj5zPRFu6a9DlXxQcV2vO2bY9DgqHA+JMid5RIk9PJIXW
wF4gMceQ5NHJzmzZRo9KuN9JmrvUmMbml1n5ctNdSGuZd0BXjYup7jOZn9Yz
0Be29nQe6SfsPOlNJYopaMnY3cQleW1D2JeXMmI1aDGVeqV3lUbbKT+nKYN2
DI3GqbYT/X+tMxpe4V+BWH3vXPZXsv84noplwBsoHovuKNAm+WPP0+LF2wrB
72zidquPQuwA89G4Yz3ys55H7CH4uCS5XSDqLhsbgs8e/POT5N3JVdV2K+Ow
Snqew9pJCsJFUbkM8r3ph0Ix7WwOsktC5asvFIPnVrFktSsNg+GCDOnNRdg3
1CyX3Ezh44Tq/Vziz4bbVm499oLGdc+UpY6htZCtOsrvH0PyoMAC6uESQ/Ci
JloFSJ5ZE9USpToTjTMv6Z88dRoDZutbp6eZKFz+WWf3ccK/IttHlxwZyCu3
+FH/guQFFv8GzawSGLksy0nxpOFA1RxZXtgMmj16VoXg8X79aZb1q3JMOF+y
TGZxYCXV/qNDvA68nXK+v8VI3huS6Bcv7oBl/wuTSJVBhFw50LN4OheOE3ot
U/okj83MC9PpZyHV7rPyxhAuHPh3VUrGtyFX/2/VnEkOZIz48wvWVWHm/ons
G9dotI+b6KdvL4aM04rH+30phKxvOuWpWwfFwvOiW8j9FLoLrtM2pTimZqwh
305jwW4Dxs+zrbD7x/35XFEeptXC9NJ8nuK5om6+9RySn+2yrVj9zzGqn3q8
j/QRVsl2zUGNalRYeHY2mNKYVfwzQ+chC76izcq/13EwdLh7XEKyBTY7vjL4
fw3ChlFK9THaoFIvvoZhz0P1vHMdW+5lolyZ+zD3D4WSWd4l9MmPOBvHynyv
RfQgft/wv6YNiKvR++8cwbtI2Mw2YcM0HFF9b+szl8wT+871oWcG+FJ7svrJ
PPM9maaq2hWQ4qTkWhC+K1yX2iGyPwdhldvfMUle2+I2rqDQVYvHyYobx4LJ
e3mpxMLhLCxysPxxaA2NwEDa0V2uFTlq9SrjI4MIjHgoZipegd0R0RmC/BRe
ny8xybJ4Ac/kuOsrCV/uJkZ8P1fWhpGuiCHrOh72nDgQns1XBodt9cUU4Rcj
aaD0rVoV9FX3bXbkJ3lK5f5wSn4HLPKTP4qd4KJdfptyfEAHVps1HT1uPAC+
EMbCt88b4T0d0r/hKA3v0tMJPmtLYR7dn23WRkGmQvTP5e48qE7H3ND3I/P7
mjTatlQiX+VmVEEc4VtIUun5plx8jR/ZyiL5xDDo8d3d2Qy8Pz/KrDzGBavT
6nnq9R64T/27/934EELOLBBzjWJApkekTYjsQ8LZrPbU3GK8vlAebiFA48kG
/W+zU2rxY2/ChB/Jk3PGvytv0GMibt9iF8V+DgwYeWYx0S64wIlziSV4kp1t
tDM7JwhfFj4cvyJP9GaXbt+hVAZ6uJYXBVxJ3xNhNwlPNCFHOXbaKo+Lm8kH
t7TYN6IoouyabQaNnZpqeoeN2bD5e8x2yf5B5KjYu8iv6sBbLeljJ524uKor
LPzANQcxuTXvrhE8TmoenFfJZZK9dc1ztaCw6Pc1t0d+XWjM6KgoVB1GZJj0
Xi2jp1CmTUizpCH4O+jS2vlsiO27f2e+GQ2rFL6gZdqlSL8wpRvI4+DaIcMx
IxE22rkGKZy9XLyrF/LrSKrE7LxdzT4MCt9+jUvVZzfCfXIxV43sy/ptWGar
fy3hubVpWxSFxuAHL2R+MbG7zP/8/U1ceC8rvGeRXwrBN4YVHaUc9Ak85809
GYTaGCmnaOJXQuVRE1urW6HQKzGxQJxC9ynDhOR6Nhaymp6uIn2MGZToXvOJ
+G9dzZ4wK5L/N3XZOGi14NMCCwVTFgW/G/J30n904lDa8zN2gWTe7TqDN4Pb
8UPbbdQ3k4LXLkkjX8WnmLNxXZHjdoKXqFJUTBYh8nTX9qlUCoW77DNVs9k4
fK4zdL8yBQ292XsDDMvw5ir0ox/TcBvC2tNabbCVNHE78v0zCnvFr0/WtcDt
Q7vKnw0UGqgp5X/f9EDmUHnpHxUO+L4mdlonPMHejyW9/xG//IgQ/8dvOyDI
i1p1t5+GzCy14ja5Umxt0vjit4v43SlLztzJVqx4FOPr9ZHw3abVpIT409LN
2l45WyjoGz55b3mUgWeI/7N9mIO4hsAbPnHtmC2532KeNumTBoKspyNd2LZ2
WZ4u6UtXU7KtL0j0wOXLOadNi7jgil4cLz7JgE7Rj3O5vTT+3Mz4M5leCj7h
3XNNSD9PmpWe5nf+DdxsSm74/iT+8+Q3X775W4zbiVi9kKPhnG5248rrHqwc
88jfHDcIkZSy4i/ZrfAPKjQZf0H0cSsjzeJKK6wvesxYkn4lyBQezdtcCm8H
/+qoGzQCOALSy6vaYJSdWn2hnoM5F4QEK8dbcYg5sq7oAw9Ft+NTgg+247WL
kIdyPtlfWdgJFdNS6DZHTg4Y0AiR7O3yUGfj+nt5yXLS11sSO69Mldeh87Lr
4nCS1+qNlS5r5DPR2irheyyaQmJV0AbZm2/xiHW00GQzDfdzEj5NiQzwHbcT
+kDy4F6m6llr72K8rby4k7OXxhztiWOpfzoRE9FtlULyeWJUjpf8ESbueOk6
XSV9nU8iZHBrWxSOLPvl3UX8713HBd7tzx+wfFonsI1L/Lm+nrF9rA7Ulw1f
akNpHE4v2l5KM9HxojmlW5OCgmGC1W1eNRIX8GIjHxB/uJzoaj+3AS8zG17p
cWg4JobxbfhyD5fM7zmbkb5+QO+QXLpvNfjvGy11qKSwYYtqxMnOGph5qzQp
5ZDvPTucl/2tAxK2HRlPbpP5rl6t4g3uxC/yt31fQcNSXvCH0vp0yLh5pluS
vNs3nuB++dxz1O6d/SmV3L+70Dr724NSeHiwjs0sohGqcs2TYdiD6uXmm8JG
uPg07WFgqlAHq0rhMCVhLvrsn+RWHr4PzpRtWt9ssj/DiMNJVD2kdH0Lvyty
wchcLufpWIo7+5JuRvCRvtQmPLfX/zUeDjRI626h8T8+CSTB
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41AkXx8dl3y2EbojtybItNkoprdJ+Q6hsGdGFrCIlLbmld1AuYUJu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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81IsaxodUR4u0mGuPUBKRpTpye+q2OFESkVMiRFINdWLIkpwS0z1p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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk81ekXvmgo3X6/xjDSJBSl4lqKijueyRJDRKlkaIylMlqIJBNjz1q0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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3dcze8fTUOlIUqRJJUoyahI6CRKoiGjJFRCO3tFUiGVhgqFNlKkPWjv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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlGk81Asbhm2dpOLnoKQikqXFEjmU3CVOaHg7SqlDJEI50XLSKjFkZEvZ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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGs8lAkbxmcVIWXYt9I5RWWqyXbYVLgQpWyHrcEbYhyKpEQROiBDrfZF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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8VWkYx1XaCDGilBSyt4mU8BOyNKUoKpGlqGzFWEcZSpJUCmnKNrZU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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Ve8XxSlJk8qsUiqpyFAU+caSUKRIiKiECk2USqVShtBgiEKRMlQi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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41AsbHTeKFjd7JUtNm0ooCVcd2SqlZeKm3MpalNtXEpKmrnItkaVI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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwdlH00lIsWxiVDneSjFXVEUoly+6BSF3ncSpSOyldIknAcKqIkp+YonCal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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk81OkfFyU6WKn9YSmiGknKFWvzRs6wP0kqpWPK0SHCtlJKuZXWkQat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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3dcTe8fL/EVhSZFSJJKkpAo3hkVKVraJaFQNJAiqZSiITIrlGiQxq00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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lQkXx21RSSNlUlRyTaSU0cKb5WetLJU3yxX1hmFS0xAhKmuRUNq7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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlWs4lAkbx52KCilaspKJQujEeoX8taE3Fi0rtFQb1artoAivyGmtohix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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk41OsXF26rYrRQlEiSrbJnucdWWbJPuShEiUIpLUgoyRrmh8ZSUUrI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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lf8bxpVEyviWFoqQIkWiULmUSJSEVKiUUL6lkiRKyCwNWWWkrGSU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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs01IkbxseuilKYVFus3IpcSqLk9iiS0MqskqKbsBERFem0QmsrRZEV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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs41IkXxqfpMoUs7bIqcptSUnrqVxH10kVqKRuLrUmUEtuFJoV1mWxb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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk81Fsbn1BRN6YuoVsYKUtaqAjlK6FSIdqUyrWUW4lCEYmKtBoVbZJC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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8Vf8bpxQlIaOsjGhYyUqJtyQJSUVJKkk0ZJWSIhoqkTJCU0ZZFSI7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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81HkXx9FIVKJcIlvD2hoMxstWUvnkkrYe9bQRSTwUSy2PUsqTCLlM
CeMlFQmp0EZE21qKoSHXzLgNRpJa9bvIJbu5bDy//eO8zj/n9X2dcz7v7+fo
Hw0+4KcgJycXxsQ/ednBjyZfXg6C1eA2b/LjKMQzWYVqhS1otjcoP7Kawmqh
huW6ZV0YyXJLqByj0Os4WaOxW4qyUyaJnoMUXBxMtgR8eIGv01dnjjWS6HVp
OuXq2oMInbTknUdoNAq3ZfVG18FhCquSi0mI3K9OKdn2Y+VkEPvbRaM4dkPg
cz6yEyotBlo7bGkM68VZBBo3QUmtvv9QM4kJ/rv6qbVi+Ond5DmoU/Cm1pPx
2lV49CROuWo7Ce/vhHY9gV04nbg47YYcDeFE9nCasB4ffYdb2P0k1HrfjnP8
S0AvYhs6txEISzdWRUAlrvGljwg2CaFB9v7R1Bx42d3QMwwj4C64OZsv7cbX
NOXvzDspaJ+3DzrjI8HgHfODETIKUsPUII5RP8J9va50hNPYw51ReK0jgUgU
yG7JoDD/P27kQKkMBuOTod3fjEJuq8/bGp9kmDY0OFzeQ+AtdT2g1qMDN/k1
6q2xFNhmzQ06BQ/AjWqUVeUSEMcUb9qRXYisr/yO58kEVgcHKp10FWH2/Ure
13SmX6MEhdHydiRsqWbxNzP7mMrLdkuX4SRHfbbQkUbumkF+sWMdzMat3VVP
MvWaenUaWelYbXVCZ+EIAZc/trRH5ncjrUQhLLOAxs3JvMQF8zqk5z8JXyYk
sSTEf/Y35xp8dMq/eDaYxDPpVklO1Gvsb7NTabMcRWxJ2KR+dy2+RCc1mVQy
73Ms3DVWJ8FpsmN0fjeBWdb7JFtJK/K7jo6IeBQMs5QfWv72CgKd5TZTKhSW
/PzY87G0EOp7fY5z4wnIZYfuSlD3wsOWuJKJ9QTc5jebHI7OQ3wqEV4UQUBQ
aKaUP9eHiacl72xMRxGYIpPfrdWDoXBvP8l6GhW6chlaB6rgZTl92ozF6C3L
2amwqRaDX+Wnat1JWDVu2mao14yi16IcDYbn4WnfK+01HRi8PnDIqJXCkPPe
OiXbUijuGMqVr2D2U6z+zIojxbh9/kXn+zTG/6XcH7GrGN6suN2tmYw+DmPL
xo3KcZuvWhwxSOCMsb5pp3E9eD0FEr/LJJxjW02NPJuwTTt27cACicJVheVL
FV9CVcpz6+8h8eRDbZxckxgf1q3lKrRRML5TL6eU2wsr0aDkJzYNtVRuqNfl
TPgJ/p2l6UMgiE888w7qhYt+U3FkNYXicfcFjUwZ4lsmY6zsaWS9PCu/NPgp
eog+VvcQgWa50A3ihwPYzxo44OtPYzq0cvmjpUKIPAc9ko+SiOJfcNpgU4ob
KRkZBsy8T4SyEYuAfqh2vNF2kdG4qm7yWT9SDHW+4ofjXKY/eX1ep7QL9/at
KFPspeBbR59PeSVBdoTk2xOKNH66qlDfZdgH1423rITzNHgB9h4pPVVIevGs
IHsbiWs6F1MON3Tjs1n0g2+GKVRzHlvIjonh/3q/hmIJhQvPZwvOxTSjkhdZ
dteawnvnpBbBAwk4ZUUWuQsUGrlx6TsDJAhZaqtQNEdhxvCF5cR4HzTblfrH
QmjMlkfdHWIPIlPJ5JO30yji3WrvV/8ths1279nZJApRzubnVlhLwcsujJqu
o9Hz5lenvkAhsmuIPTkWJEpve+qwtTsZPTZK2CNMvcKUv80RMa6e3K7N/oHC
SOThgZ7rbzAnYtWVlzA8aF+Q3Rn6HblfztZ3b2J4U/n+9LmWVqyN1Wwf2s38
55UxetXy3Tj1e+sd+V00lBLyYxq7OzDw5srxjVkU9NgPqzY2NqHQTZd3Xkxi
VdiNSDGnDosXpi+1n2X0qb8esuU/15CgdfGWmyvDf20Ot6g9C+3JuToVgQQ4
VZUPRrT6wN92/O5OMxpWf9XoRrI6UcbZFW6XR0Er+JPgywUxku/fvlN/hILq
nPm9zdtlqOmIi9w5QON6oshmr383KvcYK6gwfr5k4qX1z8mN8Eh0e75PRuKs
UlroZ3sJZL+ui/8zlcKOd4sP2e4rQpbrf/3Sygh0Zf956WNUGwL6XuxNdqQQ
6+LvKZkSY7CrdEF4gEJgm0bGcS0pjmZaN7y4zfi/wWZvlz+eo9TRZFx0jgRv
2Kk45l4hjOTHLljeJNC6IeOXWMV6VFQ1licy/vYkeNFM0Ynn4NuPKc9oksis
XWMWOS9C3hUyz4jxp78rVjx21G2EmqOlrd9Shh+FEs4hj0b8tZU3fWkrM49v
yj3TLili81lBH1fRmFqs7pD6fTXO8exkicYkOIK+Ath1I2auINkpiAY1/mnN
QkgvrOPsD8570OA+Oh3dat+D2Ja6invzzP2LF/xgqleJxYZ353V1mXtjrHys
/5AA1vqKc1udCLDibymf2fUSXK/t9msbSAjWzFS8up+HjL3WUiU+AdPlBmOa
rVKYfbIZ02H0UgukzTqjnyKEjjdnqZD4P7V1xoA=
       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVHs4lIkblbCU3FKxqcglSrY0ZBXHxhZl3SK0j5bkmnsMtVMss2Jdoqsk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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk4lVsbxjcHqVPpJOU0ODSZVVJJ6VaIT9FgyhBRpDjmoVRIKfWhzPNw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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VW0bxSlTlFRIikgyRHlFKCzVm4giqWiUyljmpHoTKRmiUplSGTJF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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs81IkW9yi1GKtuEWqkbFKxakXTWF+iB+khMiVZr0rWhuTRlceVNElW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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlG04FIgWxxElRYpaZQnZLCV2UhH5hxUql5H2Woq8F3lPFGXUVGguusnL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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk81ekbpYlsJRFto1HWyZIlSnQwspVGUtYKbcwSYkyWikaWGEmUbAmR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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VO0fxpEliqSyZElCosUrpbc3bmmjKKVFhdCiIlu2NkkqFSWJFltl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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVkms41AkDxSfZkmzpKkUuabVbK5WNEkdCxYQm5JIu45KkSPXm1ZDXPdYl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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk41AsXxyd5hCRSjWupiKIoI++0aPqqi7QoV7ZyFd0sKa8lFb0ZpHGF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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8lekbxk8NhSHSlKYiYSQkEb9jyVW2yBKyNLYWkWXaDGkxCamTolBh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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Ve8Xxa+hVFLKkAxFhVRKQkIWJRpESYokQiJJCJVMlVBJJSSVqShz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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs41AkXxycvUrTSo3KJklRDMt3Uys5XYQvblnKp1bTposuTtCVdZN3K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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs4lAkbxlFJJHalpNDYmpSyTqWk7iiHpVJdhUqzWIfR7kZRJMoh7aIc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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs4lGkYxh1T7W4OK2k3KaciLJEouRUdtEiiZHPoXBslJWxhqCQsWodI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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lO/bxm2lkB8iJURSkeSLSgunUpKlFKUIlRZJi1TaSTtCaCXZKlki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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHk41AsXtiWFyr3qukylmkpCZYni9o4lKUuiULdFk+2TbBGVhnBHXaIS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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs41AkbnVy2x6gllKwUm3xdrIYtbeE5WtYqWnf1RSJJbYtohYxcUmwm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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4lOkbHmWjWKdqI2cK0UisY3R3TgezyiEhOeaQKCI7sWTLdlCyymFD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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8lW8ftkKpjOinKaMioyGS6JIopaSFiJaMlKSUoggpUshIyKqsEBFl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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41IkbxV26oFhR1nYjI5cSKTZFnQkhlNu06boTCkWy1kZJSrW6q2R1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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk2k81AsXxydRlFRXRXVlYipF2uSWW/0sXakkRYu1SN08FG7KktAkIkIU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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs4lOkfxpFVFhEdbEXWYVhsJGEKdwnZmiRLK4dCNqXdJMdiKduqhJVW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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHc8ld8fvxEpKommr0pJQ0JIRm+VkUiSFrITElpSEUkqSsOopLKyIpK9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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs41IkXxvELEbKlosv6haRETBOieiW3JqFQuaZ7bVZqZbUqdJFck8it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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs4lAkbxgfZtB2/HZFj1OeQQ6uIMNyZ2MpKGj7RKsoIZdNBS0JUK1rk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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk41Pkflw7VhrIUGkJWSFi1thQvW3KNjh+hFBXlmA5KIQrFppIrRywr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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VW0Xxg9FkinKlKRJkiQRb9RdEqKIpJCxQdFb0WBIeEVJRGgkEaLI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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81Akfx4cctXlCYumwshJDKVZEPR/dyFGjNKKWEqJV0bqSdGzpcdbW
WJFjlpIc5Rx5XLnStphhRlSSdf2OcazrUZl2nj++r+9f39fnj8/n/fmuPXGW
dUqWwWCESef/W3P/X+sknHa8WddyO8WLwt4nYVklqSI41JqdN5NQkIQyl/x9
SgC3BFW5ggAKOs86vn8V9yvGlvvdCmIRKNZeCIyM60BCcfC7u80UDsjHlPLq
uIg6M9SodonAoVNLFhLZ+WA+uxKcUEFgcb7ow7RpGWLkG1PUvxBodLbbLzPW
hYoFhcG+n2j4PVNy16vrQlpLeb/cOAWGjPyIkgMPtkvlVHdokpCN87fLd+6A
Zsq16RlnCgYHbhwuPtQGu5WvxIb7KDTurNFR0q9DlcxQu3sYCdI11E/+CB+y
I04WL0spGGk/NWat4WP5sntTedcpeH7oXLqhIBvPZ/7clnmTgJlQbtbQthmj
51IND5aQSNJL/Bir/BwK55jJnPUkotegzLH2Kt47qkelWBEYnkmcnktqR+n9
GW7AjxR2CY6d8zrUjQQTm79nrWiE5Vjw7TpKkGF50d1xhoD754+LJCYCFJ/M
JuvnpPqhlz25F3MQcsRhhivVr3P+UOs2G4038vZZgxYErus2GStK8rBbNzA2
7gGBwOc3dP66LILKlsR7QnUadW6GTLFyEzxY4qc1OSSod0eDHCsbETjo2rCM
QyL0xMmk9E+dMGBGkF6qNCbuJl7z6myETq+W5voqEmYSyYPC5+/x8L1rQU4O
jbupEfpyEXwoNGdrXMqlYBvnnXHGvRVeviuytZUodOS6XF57qASS7TE/zIsJ
RKfXMsss/LExIEeSxyRQvcjwkYF8F5p7+/ZZdVLIfcMd5x18BbZvr/8lJwo8
ncsGQatKEb+5lXbuIZDetys49UUXyjllQcQIBe5Al6g0rhkj+kdK5YdIsDYk
csKLuiFiRJDqz2g81vdxGXnSA8Up65OKhTSMG9pyv7vdiKDrzNzQfBIR3yyZ
okMqkS57V2SuT8JTQ4FQtRci80auiYEGjTTr1dtLdJ5Dz2Px/UI5EtZjXkrh
e0XQyZjuLzpPI6+Hx35A92G48mhDlCUN28j4d+IvddB2i9tTEkAi3Vwl2nDy
JZYcrlmvSEvzEPSgqSJeBC3OFbewbBoeXM6Pm6U8FDa4bXf3pbBpjt2eMSnA
/751LsMUBT+xbeT8sXIwzFKVAuRJlM6/3zRZ3YqV30qsOzUo/HBZQObL1sPU
aMWWff4kHJLS1k8ff4JTbT9/PJhCIGrp0y9btRtg4BF/dd3PJKZ1iiNEdnzs
DD5YQsVTYL/ddfOWSS9iOCrzTRM0tNcNLnrd0Iuo7XviD8zSiObljesbxSON
71KWbkvA70o1a9dXIWq+pvuwq2i4vhg131j/DtY+nWW3t4rR36p+h7X/LT7v
M93jZkfDO9ZcpqSnDe7C43orqijQWjaM0aomsCZYEq1HJF4uM020TKrA/c/1
31VOE/BOVgugpfn0MpmdmugmsSl55bzu+COwlbdZZd0jwDUy9sj7tR7GVa8O
j4aSsF/J3BTl2orToarmMkspeNMKO0/ntoCzTe+iWJVCuvCiE9OnDOErfGTW
kgR2D7HbRy8KMNL0B1EoonAneI9sh1wLDiUw0T9KQmU0s3L31TLsT/XsClQm
ce5xwxVxfB0CKiI+6duTkDmZVqSb2g3GGpX/1nbTeN1etePthdcQHK/24FlT
SPNJn/L26oLXb8TU61BpH/GDI7JafcEzdSxIMyQQ0+JJn+8T4sJJFweOlK9I
9fy2vJB6sJeezZo5S6IxezDv7Jc3oFpWGRDhNFSufnId1azGiVrHqkpXEmnJ
Jtd8R58gykpmrCCfQNf605ZVVjVYfCvekPUNCd2v3TY7lgtxae7whhK29D7r
ZpRH1J84whPmqJ+mYG/xRmOhQoCyh8ir+EjBRk/D/MWjWER7xwwr7iWQoKt5
zMmhF+OWi5u03Gjc4BftOfO2AgdaJfz/zBIYaG3+9/jyXjg53pZVWpD2SaZl
g71xG2YXbZ3PDaEwsGX+HutxB2Q8Qz3rKym4/B7eHzQsgjHDXfGONM8hw07c
6AcNEAn8F7mkkMivHLyiR/Lh6TB35slyGldPLV7CXdsOi3/dzOyR8pJkkv65
KKcWAdZyCrutSSTsvPRLfSsfgwkmyes8KETncKZnNHm4Y1/PyFAncabmrb6t
UT3OhiE08hcpL4HvzNImuqGqJvd9ciqNo6UzN3f49mDL7Uyj34dpDGUk0Idt
OuFfqvthII1CjWJi+70LIsQoy2YWbKfRz71rsyq2ESEDkw6xQqk/Ws82bi7n
Y63dkdRJ6X+LE6T6ap7rQdGOp2K3ISnPQtmclWwBNia3BFYGSf1XFeSqdZZj
+PTDsXBVEoykiMJqGwuU9ldETOoSWLb5BWtfZB8s/8j0oG6IYcBuVeMpt2O1
7bYQq1sUkn5SU7uj2IExrA7+7T6FfwC6Pcji
       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs81IkaxuliZTtdJF2OoqJmLSNdD7UeFUrZTrlEpahcxohu22URdlSU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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8lWkbx01mbOVQjNSkGiSMJETWH6YcVDq8qkNliyyVaI6loZyyVLYs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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VG8bxpFKUkSEhJQSKkklpQuVlCVbpVJpk6UFWSNUIkJkTUS7hBD9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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs01Pkfxi3yi7JEF6tEEtlQViORnmHLpdsql2xRKpbUipIilpRLm3tE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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHlYjAsbxjM5lU4XOSelPrTrmC9J0oK6i5C1qLEl0jo0lqO0WkYSEfWF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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns8lGkbxyc5VZTQySqjlLIl21rrtPOTZK0kGi8qlSQmpYR1iKyOpJTD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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHc8le8bVvqSsqNUskpGQplJXdqlNJTKKBIlJESIpBLRUiFERkaDbJkl
2U44HHsk4bzvOYq0SOn3/P46n/fznHE/933d1zjytudM7Wfz8PAcn8XD8//X
ycsb/hTWPsfqprOLFwnTQPLWfI0F3agt3KPtYUUjYMBVX4r5AGNjz1+mydHw
mFBo3dKdBdFPUhGHd9FYWdCocdqpDWERcytEV1KgAjlGU3+qkbdalrGCS6Ow
UEfdt5QJRv1oy85QClYlv5Qena7Cbhf3+dO+NBJ+M6zsqzvRrie/2HQfjc3d
pRmbE8rwV9+28swKGgNnz9kH5kTicXRPprwG+X1e8bypwLdQGJU+YsOmoK+h
ONRcXQLRrUkrIyIpGAUvXLspIBKnfq+TsVhCQ9Pt3f4bo5UI7QlZ0y9Gg9rl
9F3xXS38ox941r+icP/Y8wcey/sheimhUZhiI32Z36v9i+qQZFZ2153Lhpxp
ESsrvgxhYe9mb39M6smvCio/0wGpw8MRoso02utTi8b8OyEvudRgqxON2neL
q+V7EhA7kDfrngqN1+GtIXPq82HywrqoYA0NUY7hb/57xZDbEbvdYykNV+uR
OWrMOsS+0FpT2ULqG+XRWVqfg55nxz5Q5L52Jb7qC+e2gSOcWbJKiI0hXf+M
31/fwaxEZnnlRhpZkiJ8Nio1YHqXzHuuQ+NGw4jaghf1SN6yg8+xm4JEgXMy
V6QFHsmJETaSbFxZeK89O6sNV9d+lI3cSkGZ1+yzphIDMg2re9yqKYQVjFw1
dytHt+3sKLd+CqIXLRkW1+vhKyexYcCExp3qztnadW3A+tZaMz4KG3nnuJ61
LIWFVqBChCKNuWrB712TmxF+tsDv6Vo2/IyWLPPoeIsAsYXchaso/FNT5wmz
roXJ+FLF5z4c8NxennstMQpRNq5sdTJvm6/23G/XY7BxmeWIgwLp50HF5JPP
WrBx4/cDPmU0zgnuG2xz7cLcNrPS9Z00WMEZccYhbyH6Q3Xgx2UKOsMiDowj
7eCxmLupIIJGfZxL+Ma/zeg89qFZY4oN6uyzm8ppmdjc/lenQID0Wzj+wp7M
Ovy8mJqpnETOjbJ36516g17dUyr5BN/NpT9//EtsAK1TzydJ9kN/NttZQy4f
AeE1dxyKKdyyaC+U0GqA/wk3vYL7FKRcX16N+NYEYSfLmTFfDjqlZo3tnWpF
gnPyh//saQRJ/nZYmtgGfRup0ycXEzxfljuWPl4F4ds1i3eQ/tC2AmdfFzWi
UGjo+CMXCuV8m2056ZVwmtu/53I8hQBftUNXM2rRceamX1wC6ee6epfcPXUY
48qmCXvRUN1lrXXDvhdWSo/+mnBohI4dbJ5ua4G665P4nPNsTH7I35W3pQCn
Mj3PWL2gYFNmkyGm0I/n7wUEsm3JPp2WFLtoycLT4kD/xpU0Kmfpng3qYWLq
pKbocvsRzD7skrXvTh02O6r5BTMoSP93NW3RtU6kovFbjMYI7FJ00PKsEQyt
3fnmizkQfCD0bO7xNmTpqiY/Kif4l3nzRDn8JU4Il7lGL6MhV8UZ1r9dhrS8
tfaq1jTmiEs+0TJ8hzIPuScHKAqtzvUrxS9VQPy3yLR8Bo3TY/v+XXFl4XVx
s4+NMwdmU+mDDyVYePxFiM9nAwexP/+49Cwrxk37kOWyGRQKaOEbT+q6wd3F
0+AQPAp9TB1ZpVkOr8f/lYlVUVhS6JKSZpiL1yameippFGotx9MH/zRgZaiq
qPtNCoGqQwtz47vQ8uCgSsklGox4wePVT9tw43zAk5OBw/h2m1/WbHMxRsw5
VatsaRhndY2ZLGGiRj1ZT8iOA9vE3dqnPvbgVe+OW902ozBeonlvn30VigXO
3dAl/GVj0eHruzENh5/JD33kI/sce+IQvz0L6+5IhVetZ8O/xvLxUYkOSMuc
3dw4RO6363nKepMGXJgOdbxL+Ky27a14g1EJHIdLpjwsafAwLMQ4Hjuh0587
f1Ke8PMWKjiiqR12+tady9s5mCNxIUiEXQ8J80B1rj4HvkkvtP9N1KB2p7+g
wXsK3RZMFXYPA/f96jY4atNIb971xulnB44rW4vbj3Khu3rC6oV0HwzvLV5v
XsGBi6Nr1qNH5ZDOlqVqXGi0/ec6p1CTCb3OvB1xlzgIKwpaNscwC/29cgMS
h2g4fEPgwsYaqN54lJFB8NBoODjymK8NFXwOCpm/KGxmFkZeluzCyKZKuz7C
pxM/S+xTWZ34Wb/QdLCaA/mKoGcWUq3I63ravOoHB5tNrcO8uW3g2/bUcvsP
sh+lwl14/wgtyh27JUl/vPc4fTJ/VoRldk7S6whfCqTMbgq53YylVGyc+RoO
hLmG18SlWxGmn8Er8paDkV+RKtFf+rBEZWqHJLnvIctJXRmhHuRtE17cSfZ7
e6/Dilw9FkZ3Jwx5ehJ9kxDRltzSjAO5qn6uhG8MZcQyL9a0Yzwe5RGNHEjk
Ko1v98+Br0SYvvZaGv1XH3C94t6BN8vXxobUt8KOVTZWkIQq+RWVauQ8aqtH
q6BLBTZWJChP7CX70r7hmah4JRqTZzyO3qYwQH0K+f2jAtvthZbEj1GQ33NJ
e+osA4X9S1z49TgwdciZvCTFwkz9PoG17gSPUzVykjxMwv+S6xrzCb4OtRm8
le9AaKyIz58BDsYTy7z3PixCjsV4wuRcojfx9R9jAt8hoNjRpXc30RO5Ymu9
FaVYWr7ILXABjaN3Q49X2ddA6rXl2+PRFNzL2V6zHPoQIjaTGefDhUdL6DJt
gTaElvDNrNSgsH/4WHXa5gaYpAt4DpRRyAn6o2To1waXP5oRr7NpKGefqLUt
ZOG0Xt7LOcEjuC/rVFK2qR/yMxoHMET4QdH7682mUnzQ2pfV60v49ca8BfoD
rRDXdfGa2UMj2X3Xb4vIFnh3Ki7g8hD8s0wTauxq0aDwXWlnIqlf41Acq6cG
zglTT2ru03D5fJ6uSW9Gzu7UjdE6FHiCLT7rM05CRlfQ7BTRG/UV4hVLpzvh
cIaZ7vyOA6NlPn2ame+RdyY8lz+KDZ4VLsbCO8vAfnxuPbeRRmzCF99KSSZi
q3jPvtrBRlg/bE+YvUf77GMXNAgeXQfcG7pqXuLl4fmR48dpSNyqS2YR/rCo
j/uW+oXC05Fw/41u2fjJ166+0IDGKarn0ApfJjQ3uOWF13KQ57F/rv/DTFyu
szi9j0PhqDOd2/NfEz5Yb6gU/jMMzY9rVqU15SNZOFXmC/ET31f1Ju93qEaS
BzP4MtGX5ujavcfpaphOGL1UH6Xwqu+ObeKFHgLOFvhPsHEszHd6B18XPlwf
Nexo5mLnt3UuWyWJP/r93KLIn/gBVlCV9nQNzFYHLVa4QqOzzzbttngqBEYP
MoJ4ST+dVLc9u9mNPUUNXeyfw5j90W696epcnDrlm1tqSPzP39zS7idVWFj4
+Jz9NwrJ7B38jE9diCp1PL53hPSf9yuvVPItbO1TWxlM9MYmRe+MUnctuMWX
uxS+UmAQ/6l9lYlU0bshHbXEzzGZovMnKsG700cogvibhKjPO7+XxeJ19E+x
N0o0xr+0unGNWhEhmTirnfCFdJLNFnONRmT53h3Z9IPG3yYR1vFX7YgYFHTK
tOJiQErvQHp7Ehp0lpisUaMhdXwwT125BdFCBiUeUxz8WnlL5PvRTsRUVW68
Q/ziXJr1Z/6nDASsObdqOemva+9KZ9H7T2G6y/T7Bj3iJy72fRsefwVjfX9v
B+KfBg5rxW9LK4ZNXbvWvg4Ka9e8v7fIPRvhkQkpVasJXuPfHLsnGoAvUqol
hwj+ohTcHc09K2FQI31leAs572PO8tp3E4NnTK0uEX+Urjd9KyOnBeJS/qG6
kyOQS27nbnBsQ85nqYAIBS6khrOC3b6/If4r9PpO8v6dJdk5AYrED0nuSsrI
Iv24tlT/gkQrfpZIcyXJvv9+Y94aLNgBiYTK9ib9UYxI/1nO9q9Ccub+d8af
KRif4ai80u9F9Bv7tZTJJwyMZ5tIJebhz/anM7w9RC9qYwM8TJj42R51pM6K
Azkfz+C7s6rxcvzlEm9j0g8di7Clph1YWKXknu/CwZCPWfYZ40qo/bOp7jQn
/HlbSYtufAnZT1cspAi/ZKmGVFqP16Fz8fVNv07TGHmiP/KF243vKYerkuaw
UfhXP44rX4O/Sv1abCcKpYsM71Twd4NtXNWiQvxfP989zqmMdrS0xMupEHwo
lvCaH6IKwNi5tqxHknx/cOnivxNdiI1t/ZQmwMEebfUmA6KHI38o3yvkPuXc
q9FPKhxx1Tk1UZPMw/BWQL4wfw5S0gT+tEjRSGp76LDUvwN9me/tPBZxMeic
6xByuBay9lsT/v3fP+dt7hWmMpF0TzVYS5/GYHfDxF2FtzCq2DR/204aglMj
6eMvsjA89eOtxzYaanlGukkx3bBLvnFhtxAXR2tnZA8fZSLUcY2j6SkO/ENm
G2p5d6A/KEw+5iDZD6/q+e9CKpAQLmIXRPzRHo151y5mZkFZrdJBm+j9rQ+l
rL3NWeiwuOSaSviw8/ng+tdhbVDe8UXuKWjcvxpaEOTfigCVzveKERyUTyzf
YxAfgcH0Q+IfyOdvyLsejRp8jyXW+v4t12kMXVurWrONhReMyboqwp+V66pP
ClswsWK6g9dtiAKrcrVO9aca5Bq9jioKpWHw8LzoQEI3NP0FzUrE2MhRSUkw
XM6Cfv/L+Y4ZQ5Cz+xa1cVElYrujrIUFyP76OgpG1jFwfjoq6t4TNo7Yri7+
d7oR27xLLhbbED8bbax5/lYn+oxzRwfe0Zg1xOCvP1UI8+7wXik3ou+2nVsM
rjXCqMt9bL8RjYrME3N4mzvhdW/IMdCbA8NwH0PWoSZsF9+ryJtCoVPyyNn2
kRzM+pFqcHSCgl1T7dcQM6Kf+m12PTkUCp/kP11VVogsEdenH8l+zqmJ54QZ
Ev+1oWtichsXtXjEMB9tg1xWpJapJgcDDakjRrV3Ya2twWNN8rHt2WdUtVs/
hPIWlO7NHoVIwo0YwzoWXPRmhd/uY0O6c+fdux8YyPKU3XqG8CPP1ILoc1c8
kZcnNLZqOdlXKsw7wzMZjnWsK5/J88fNUT9HKyph2np5zKCA1BcU2W6cUY2q
odwfamS++nYM3i3qdXAOPf8qajOFx8di13R9IfNZ5D6xqp3k4UZO27z/AkiO
ssp+JkNj8lrrrqXMNoiIuVXxJw0j18/Mq7qFAft/9CA1ToOvaOPXxfNYsKjI
rnB7SPJZ3C4drnwIhJUXHr1F8JE3cpwSWVuDL3q6CR4PKfjp7ViVfb8e9yW/
2eSPkfuce8WYmcrGQqUagZUkj6p3KgxXqrRiD0t3zfe6IcSGXlm03KsTCq3D
jfMnOBDxVdwaZ1aMG1fXexkRvjqod/6qRXIRVLX9xV82EP8QEyi4vbIeM06B
Hz0VOajx9zGNCuiAuJ5X//YrbAgWef1wSyH5NeGVrlge4dvTt+RPv21GeaRb
XOU5DlIleafW2tTDp1opWLl7BMkNS8r3mBN/86G0TJzguyVC/p/h/QYcsFxU
e7KCzPvbjTef77SgjJ82mCjjQPPW6y+XhbKh+ETrtuhHCpc/jA7YEr4xlQ+e
NZUyjLn8Z3nc7+TBQTJvJoDkRZdH26701vahsM7k6cU4LiqcP52at4AFm7M/
LKI9RpCTbfnQ04iJiq17NXqUyfx2erdeOJ8PQXe7uHKCX8l26idzqA0DdXWH
tGNIPqiOWRK1qBm5AmIvC8DGCrXIo6f3v8UES37Kb5oi+cp+hyuTiY6TPy2/
8nGgvMLT3+bXGzx3n6fYLET2JexzT4BlO8lx8j6r6GG4VNvavpdow97WkTJJ
oxEYljQtLvrIQuvXwDofx2E8thrPr+FthoEKy8mxnvCTHf+WVWdeI8q5lS64
SSMzV8PNnfBrocL3r+sI3z0NWj5l9aIZX4UOvbYkfCzVLysiEVaMrUfXxBge
IPqYJVt2Uv06ho6ksxvIfO97n3Rc19YGKet5K1efpbF/wxGhDKdmrJJK/i1H
8myAid3ePudqWPfX9F5tojCYlhh2QboHykZHX2gpcKBt5zr5waUelfkm7BcE
z1R8rEasUD4eB8jrj+nSCOzi6H70KUTQY2q7Jsm37QKX/F5uK8cBRc0j8STf
aM5br5x1Lxk8K9Nfh5J8c+qAQzyT1Osnc2TZp0wK6V4OWS++tkLVhW//mygu
3jJMIsVm+jEo/cNNq4uLGN8pOv9kBxzdPRKdfThwFy5yWlTegd6vs2M8kgmf
SfMZ+vO1g/v1hJJM1BAG5np93Jkbjz7zOBkfMo/i1Nk/dLubcHDG/B87gfD5
/otyGvtjwJOx17mO+I/jmYLTU8+YSHjsbBS0iYLcl0PfQ24R/CfbGT3VohEW
dOt106wSlJZIXpYmeUHXb3ipz9tOHNC592valQMvkTuBjGgWTk2+s12RRiMg
ZeJLWVQ1QhuaD7svopEwz7no2NpsCIY/et+rQeOQdrzIcdn38F5p9cmD6LGP
0sXARM334HcWVQmrpmHlW3gr6EASppfNf/GO1HcsXoz1ZnsfGDFur9q3jCDs
e+uxf2EMxBh+PLGQ5O+DZ7a4Xb1chyxFv5oZTQqeit2WvP0MSFU9qGTN5iDK
ILv7BsmHWYkKvk8Jnq5HJOoZP+xCRU1pXs8mLsJih+hNq6shc8XLVrKHjYAH
ylqp4jcxyQw2jlGhUfop1kFRrQu00rTxfdJP8cfxg5rrmRAxzi88SPhHs3Wp
jBuT4NVy7cPZJE8aLVS5LTMYjifzghcMS5N+H7hNH74SjUlP/ukHhF/T17vG
FCeXYI5OmooledbMbLRWCklHkZlCcAvxc7FMnhkrj14o9Z6wMxQn+jopxZ8Q
0wyem4HvCv//f9BtS0uh67lIWZ3I8GNSMGye3hOkVo3J0DtbitWIX18zv2jd
pTq84F5eXB5HYbS+I1fCvAkde1tcfbkUtpXbR4avaYNCY1aEcyAHob+1WZsa
m6EptFXndQAHut5Ra7nDXRB8P+xeRvJU/4HUsY9r6rD1c/cUi+jt4edioQIj
TJTbSOXJBozA++bLypMn89GbonpdkKbwP4CdCc0=
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41IsXxudGuPkRQhSFJom0KaTlpeUq2Soh0R2SshSRVPfS7pZUlnRt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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwV1Hs41IkaB/ChOQqRkyhK2EQ3XRyN0uWLlDilrda0m4pSrRi55Ayt5NoW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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lfkbtVQqaUE1DS3XnjZFisGZ6k7IVkglhKRCkb2yL5FKJlmKGpVU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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k81O/3Vb4pQkhSVLJE9iwpyQmVNUtKKqFEhLSgTZtKKltSIZ9IsiWE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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41Hkbxl1kqaVkq9XJIkSsRWJadFtZJK2UogMdtgMZSVE2HeitLUIS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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk4lQkDxV0zI0ol2ijJFCFNipEMHTVRYoyt0oPSuJUGUe5T0lQ0biI7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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs4lOkbx4fsphxKrJTDShKWTYRGh6+mSJYkQpYh6eAsWoeOknaRQSpJ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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Ve8XxQmFyJC5vhVJocEYSi1KlIQUSZlKlFKaZEiGSipKUlTKkCEh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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHs01IkXHxLakh7ED5tXSg+7eZVKPkxITSuHyCskJJUiFTIT2mzkkVf0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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVHs01AkDnUqtVEhqbSRUiGSKisKNHiT5wqz0ohSyoYkepG30eawlafVF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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lfkbxpVpotUUKqJNZY0siZpuiRhaaBQtOI4lYSwxypI9yRYGNQ6t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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8lN0bxiUhW9okVJKt5bVEEXKJLJUkJIlSiWhB9aYkqUQiRQiRbFFR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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81GkbxofoQCuMUKRmmmSLqCgbuQZb8UbpwIoWW2HLIcKi1qbDiCKH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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlX081IkaxSVbRm0piXQppBJlxE2FjiRLq0tCkgoVGonUFiGUYgslpVJq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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwdlXs81GkbxklJVtuyKishFbI5lLeaYrpU0iKhpETWKVpElA5LESVJqK1Y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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VPsftoXKLSnKki1liZKQUr1KZatIkiRJIZW4EoUrJBGpXFuFpA0p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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs81HkbnaRSTdFq1yXeVMLU0CQiMUdWiMotqt1kKFtoh7AubbmHQilK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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs0lIsaxiftbElbF5U6JGxSbEo3Jnno6hTS3VEuzXQ5LqU6myTJrlEM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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVWk8lWkf9trHGG0SMYVorEllynoxUxJZDsaSNKfBUFGRLYNsUyhb1MgW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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk4lG0bxmVXlvcTr2yRoqSyVKLoLG2ShBZUJEUS0qIkiUgqSaulUiFb
ZE22mOy7sTMIJfM8M0iUFkvf/f41xxxzzMx139d1nefvfBY5nLZ05OXh4bGb
w8Pz3ytn1Ot9hEsr4sJF/FqEuPiQVH9qiMXES9Fd18qTOVCWun1N8EME3JQP
pImo04hlqOgd8+6AS7XH7S49GkGCa3VucKqRbzVfTiWMgqj6ej7LqxkYTdIW
zt1Lwz57zsLBnhx8FJ2ZvexA43zN+4PGLvUIXHLIwyqaQl6/fcrxmnTUNdWk
ntKk0T7iFZO6tgKD1pFxE940xmoSLEf3v0XuWyur2VkKglsX3hPjbcVCXxlF
3wtsMFPHHFeGpyP2mMsnRRkaGY5zp5f6tyIYsvdXKtHoS3i5J5RbD6M4zoP3
32nwxAi8C00+he4x915/FRqiUTlTT090wFK4U/eRCwcj+R9fGVkxoKdSemfv
HBo3U1t41H4wITEV0/u/ahrG0SeDZfMq8Wfl3dJuJxoerqs0ItQKoHta1/uz
KA2/wt3P0ow7UWeaWfj6FhdrePZNS59kQaO7esxemobJUtZvJ8kqZJldCZg0
prEvtEj2/ZJMzLfZtv+IEA27k56D6ovz8eaSiJ/tRhpeHb/fCmalo6JYcZvD
YhqJ67l8WU5MHOR0jHeWU3hYttHi2RcGttvvkPcroLHJydlDos0PcxpCc5rJ
+cwv8FxdXJYGfn5n1lUxGp2DBafWBxcgymNwKi2Pwv3Yiff0UBMqcv+kmuSw
seBxXkv80jqkKQdff97LAXPmL09eegq8PfQeLVtOQ+qQwR8VvgwM0c5Btsto
BDNDtXumymHaI6YY4EPqt/HU0rZk4uKSBcETYxSGNgXwnlzDQM1BxXsRR2mM
Hq6ZYnLeoSRWyH30EI2ljqO3Jo62YsWP4zGFbWwYGzxoDottgrBR+dbhNaR+
pdLM4KinSLESFB9bQSPXZE7wk4kajBcrreP1J/9/qDlcWaQBNd+h4xxL43ZN
/o4p6Y94sfsA/dOHA8vJ0qC5J2tRd+jvN4mNHHi8Obeg8VY1fPyjf32WouC2
evHGpX4l2HMhirp4jsLbJW6/5J+zsPL02X9N/lLoV7tuaGj3BBFaIonPlUn/
lW0S3NbXw1c5bElCLIVuWwafznQ5yvht0xT7KPQ1VvGOWJXhwWpmdcgMGzw5
8xnXLxkgR/u4+fQiGmaWXsc/jHWCqXGp57Ihjb9Bbw+sjWBBcLmT8y35L+jZ
vNvw3D8VCNTY/vldGg0jxoK2vUNdaAq6FiqlPwS/OdYHwud5gtd+8qfcEhrp
GhPrfls0gxWUd+xXFAfrxp8pGCuxYFerq60jR2ONmu6rTYKdMGosCF9eQ8Gy
TtH63vcSdI6eKHUToVHmm8Vz+nUnimWWSPj9S2PBFf2t2zfHQNGx7tuYGg1G
Ye6Z8woFEJ2X4yjOS2PIxOhoVOhH3BPfxDUd4oK/JKE70qgW46oFW0dtKTDJ
kBh/qsd6f02lq+cpSE3Y5Lvl1GN6TFxqazMH5gbTAlaaHZC8M7BSagMXoTU7
9hYOd8A2JUIow4mN6aSwSotMFpSNpfUWzFA4nxYb+WJeGzLj9AU7c2i4ZJl7
hZxshco82aejoJEj3x2ibdqGDm6zX635F4xZmEb2ZGXjnOqf97qHadySFloZ
pMiEyyEfa88TFHZkuz2x4W2G9TPZ7YKnKUwvX/0vz6lmXBipvP7PIwqDvafd
f9z5gJi8nZ21qyk0ZI47rBBuhrHpTS/KnQOe+cJ//HwykbPwTfHyeAqu/ufz
Y4br4TXwdwstwcHXvicJ8Z21uJh0vhsrORgo+f2t/24F0gcCsJlNQUtN0Uwy
oBOW0q/FE/mJ/kx7F6eqVkBHNi7mdyENPSlJ55mGWtjprWONGHDAMJhQODMn
HioO1TckJMl5hsK0o+yrcC0g9k/TUQ7+faK7JCy3CdJLI41einJgv/qMxKUb
jciKcP1foxeFuXsbOrlnmhB88LTYtzCiT0f7zyRE5uDwQ7nWxEs0XK0j6qfa
qqE5VzJTiszLRgX9c7qlNXg67W3/huiJr2ztnLmk3sG9a/z3HmAjfe8SDf4T
hagbe1h7aSUNU5o1P8+tGQe3JVxfXzCEudKlh32juqB5UjJ3kwUHH09PvKy+
2QTNkrbh6J1cmN9ZulLhDBNjil1b1tay0WkhNZdq7sFjjTuDn75S+KWq+a/Z
x/cIof1npeOJ3vGvlesYq8HGmHl3cjU5WNAq+OXdikxICMfWpBI/Ki1XmFsQ
WohPQY+1BxbQ2BV1q+rdQC1c2A7jB86SedypM7vsViP4w0YnnJI4UND1mPBc
0g7HAq0Wiy5yX9/pIxe7KvDyXCrtVsyGtebxYRe3ePC+c4j3/EXB+pD+9QNF
megef/zzP/3sV3U5uGGmBX1l1PSJT4NY9iPpmbxgG5x3PQxaQvrNVblU1DLT
hH0vI1aElQyB4lbbqL7PRruF88J5ZJ+ELfMXtO8rQpivoKcw0bdjPQ8Np9i1
6OR4fllL3i/c9jdbYm03FHwbdBRXcTH2OPTTjzuFcL7veJhPnszH5bGivXsY
SJ09rCRnR/zDanuSomcZmsvUXuTfoqEwWBd6IqkZ3SqL33nKc7E1k2+ZEtmn
Fx949ft2cNH6feiVf2czRH9W1MsGUMiWU3evcOnAsuTPXz8dZ2NFh63wIqly
ME7F1Swj+lxQ5tr7jL8dm8OyHZsuc3C/kzmTVdGMRItwpUR3NkxXvR2ILWOA
J/DjFHf0v/7pzb59l4vt3fUDMtdpKO+Maaw5m4fQ1VcaDYnemNlHeWnWMWGZ
7Rj55gUHqpsHWzrt2pD12GnLiTM0XtgvHNBmN2HcgnWv6j4H+jmZ5qnlRTjQ
eyO60ZTo/eh1vi0ePfDQqMwfT6axOHyPY3FUGxKGP+YYk/3OTQ15Fr20FMoB
7hFFNjQO93+2T5PPwhL+fVkjJuQ893oVPAqb4fLyW7dU0BDmGTNFRC8zMRQZ
WeVE9Njr6H7DTvdGvJG5+OdlJxsv/O7PF0xOhO9tfcsaPhoRj260+OhWYTIg
q9VLm4Ozd6KWpTV3Q7jVekQlj9Q3WfrEwq8Lq55VxjupcjDMofl1bVqQmz7f
WWiKwizvk1x1dhtipl7Ep96jcC2zSVv6ZytMitcV73cnfOQdpued3gSPL34F
3/1orAqN7jp6rhuH5b+UPv3IwfYPgnISGW3gyDYY2BLeahY0mjO+KwOuC1yL
n2+jUS1U8IRL9O3XAbdtEv2Ed3a8iX4vkAjeoH8FuAtp5P2OqWi+3Itcg+u8
Zt6fwKMY3bDa1QVsRvppLeJP06bjrhoG1VBrNBlpfkijh3PJxDe4B71bJvuO
fWLj7k/TnRevdKIo85JC2xbCd+XPjX2GyTxvcG+0sqTxM01GQz+xFzdNG0Q3
tA8he32r2j71ZkxP/DN5mtSzb//0NFe2EnPnh9pcIN8P35lXuCOcgWIB/9Dj
xJ/0RiJ1BtflYmvImnPOPyhsEpwKzHQthZjB1Nruq+R+yiOpU4wPMBZzT5YQ
p5GgZHq4VfgdqCspOccMaPiItazM2c6EjtfuY7v7h2D9Y9CsLqIKTE6N1GPy
f85fjyz1K36Jo0MeOTKEj7w2bs3ebFyH7SWGlltJ/wbZZRE6u99jck7/Wkui
R2YeZZo6jm3gHXrgc/oJqW/hNi9O5Tv4qU6cqiD7zGNketshpQqZV+X/NDwn
/DqzVE7duxTiExVudatpvIxtnK8p0QrVyqIPuqTfJVMrm9pta7HPbFHSkCuF
qmm5MbGd5Zj76uqOKgEOVkVk5cWwWChhl1RGPhhG542zjvPca+BUs3z26DjR
sxdllyy0QvBObNfFUVVynscpZi/VGWBOvBILIf0V0vZKNfcvxeP08++/udIo
nJkvtG2yCkYWQ7Jn9rLRZvbwyLL0LhxyfKw1aMPFcORHt0nzFtxV2tAxGUDj
Yc1XFxHDLqjpVqf5XxlCmZvrWtfAVhR+51++uIrwVLhFCvMFE1K/BJ6w31Dw
6aBLtM17sCg+JSU8nwu9wOAdPPLZOKheZTdF+FXIZmb6vHo3fg3ZdszNIDxk
qMCS+tkB6kBDwF87Cq1fLtudW8yCzzKjsP3FZF+lwwK92/JwzbFuu8QjUv+3
0/pXyitg/+ZC+psICsrchaMbZlsRZHZcvECL8MTVXkfDr1XI0Pf6X/kNwuOO
uznfcnvRig2bVUWGESiwrIf8AHKOW71PJn72KL5y+B+Rt2AYbviqTniUuXX6
2F4u4Wth3m2PzQkvVe6stzVgQevTSMx8wrvKNZV2jinhyBz8XNVK5sVaRLWR
z7YNFYKSGa+mBhFU/OVnUd8HsLx/nMsn+x3UVzijfIyJsBGfVWV1bMR0brt5
U4CJEavRkXbiH2c8/ayTBliwqsjurSPztSwlXrLLmwFhPQWuTDuFqdUR90ME
uuCa9ij8VisHsideebok9GIsSMhtAw/Rl5WRvoIXOjBbFj8ntJOLYh3RlJ7J
dly/G5bBfEr4JWc60SfoLaJknss0uJHzCGiETzTVoZY92anyi+yHW2WccgYT
PqpnnaL3EL4UH2qZVUuFuGZ66YsDNHTMnn44/bISbh5rfxuIkPvdFb8tySIH
vLe23ChqopDW8kDlpXUv7BqT61uI/1QJROQ8jWagIaPKpXSIwtgGLb7YuU3I
l7t4cR65X4bVjeU3HpXi6cY6Pw+SB6gCXqk8yXw4xYV8st5M44jWr9086m0I
VFew8mEQPimKC88Q7ADPFGNTQAUHVfrjtv0fMlCo0rl7jxHhlV0Sh+d8agVP
+NND46LEH5sT3obaNsNBm7NKtY3CqDAVnl/Uhah+G61S+UHwDEQGUzpNOBnh
MV7PRyGkhE01dTFgcPmhqI8s2afiWfvQgWREbDSV/Erq/35N06BIhglXZ1ZG
E8mPcVMTJ34zM/Gi2+hBNun/jtmKkB/CbXi/lH2YJvvRzJV3XJtfjaQkvZpC
Fvm9Y3elUvak4E9diKmQAvGLuQOLFIIz4KQpH1pOeMVs+g9tydeCM+MhdwsJ
X7h/CyhbfLkCwfy1VyeJXzp3HvyisaAQ3yzSkyhF8n5GwtfGuBKzR6t19dMp
xMjoBUt0NWFRef3iN10UeMbdD4fzV0PaYWm7JslfiTguOi1eBcXorz/DSX9b
V3MaelyqoH1ju5H5LKmny/zEDRRjY6KQt1kW+VzKwVS7vwN/zh94EKjJhfDy
FavdTD5gjaQC9z3Z3/7N10Y28lUhpjk2+STJP+e/Jh7ak1wFX4atXEs+G0MS
a8ayxZqhuDChK0WC6EfRp/8p7e2A1NPvVtniQ0gJPm0T2tIO0VIHAcftw9Ay
H8i5e+gV+DXt5LbsJHrLSB37VtyD2+s8j/8IpaHWHtqWVdGKGG6L5JZ04kd5
u26cm2SBd/+j/DV2XJy/+2CPSAILo8ubVnsLUPCAT291NwOPN6Sdfz5EI8Ru
jmbMnVxE/DPAc5PofZ2QzMH5nAKYyjbnSfaSvPR88evsf3twdkNyb+fFIbyO
tj2QOtACnZUFXUc+k/kty78kvacF6y6LrJEh/Jpuu+LNVttkvAn+X6Ye0dfh
E9n3PQ98QN1hlr7zUxqv8v6oyep2YM8rT+Fre9ign4n9c1G4BRXcjSv6iD7y
ZC1+fEz6ILT8zO5/I/5qqf7RV7CsG1sdRMKSTSjQPWszJA41w8rBv1vWiIvc
JcqNy7n5UP3d0ee7j+QxJde0aadqSDiz3NtG2MhNO3PS6gITgqL3BmYqaej/
NMkS39eEVXPua1yxJ/tWFaY8PVGHX19tleo3cCB85NkTpYQ8sH82ND4neXlB
lsjn+NVPIHpXIjSKzFffsEjb3YMtuPXNbjZokEKhRnLFkDIDqkd73opnUHi6
xbqugJmLNZvFLvsT/7G7HGx4rqoK8fGppd0v2RgTcB/QcmrCzi9vZwOsOdi8
8KhYj18+rlbXB5YzKEie+aC2c3s5kgOe0PuHKZikJEqcNepBPGNe8fdaLpbu
CE722d+FYJsWvxc6xD+urf62qb8Fm4ridkZokfsbrtyVNFmExxFCsRoh5P4Z
rzbuO8+AaBI7Zf4yCvYjDoHixtXwOzvRWHqW5FO5Vwp1d1qxIEA4QTuN5Kc9
oyP7LqRjRUyhyH6Sb5m8VT8ERLohVZFYx9fLRhnFGvBQLsfNSyOm9iQvuB7J
TTgjwoCVWTKz1pvwemzdj5LhElQWun8xFOLg/Klz8SaltYiI+JTh68lBt5yY
l92xFnRZXZ1wLqGQ5dUiHvooBzl8YVbPSb5blhhdomn+Dgajf1svriX51SOu
j5e/FDz313gMWpPzLY80i9m/B/ncwL7/ng8Ip/+5qDOdi7ddpySLiV722060
JS/OgXN2hcpDktcc2dzC0HetkPPe71JK7sP1SEB0R2wl/NZfscp8SWPsqES4
qVcH9u+IU7tbOoQdXcb+d/fVw/R4ctj5Ohpp6m0uKZsJXzdZbg1QZMNO6N28
32UkT+vULekm/Y1r7h++kVaI1ofCj0Lc/3ve89pA4mYRbj5jGSb2UXD+s0An
+U49erjpLWkn2WCE9/Rs0QrEEo1nJ7SIPvyjoTJ7hi5BymBuangBhfTYZ1Mm
hA8Dt2+9rU941rzjy9Xv/l1wev03OovFRgkjvLbd7iP0Ip59UWpgQ/TxUZst
6xrg1LexokqFwtmOR2fmeb6F8ZWVe5rI+ZVlRa2U5J/DI7z35yPCPwUed9T/
urTgaf7+kG9E/w1ua1imm7GwQFGnp/sKG5seyc6eNmfi1aIt190EKXBe9c4c
CmShUMJlQM6Bg1z+xsVPpJsxU/D6h3cNDcErujL3+RuRWOg5I+/ChodNWjfD
5hWkBtp924lfWc+9bmrIjUXuRdYubaIH37PXRNkSfbl6KS358H3ih3GWHXXF
z3FO5VfMT3IfPidzLA+oscBdbh+WI8KGLr1LendnGzYfl2ZQd8n+qHRvmW7K
RVRb2tVbRA+Vgz81X37fhPVd/p7bSL7vP7h5XfSaUvRuE4v7Q/qr0//Qo9+n
C/vsf+keXEv44evr5HlTWUjexFNoIkBja+2MTFxbGXjvCiqvmsfB/wF6SC9P

       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41Isax60lQsc5RI8sUaeLurKUNl+ESt2oqcgWSqdSUSNblKV76Tay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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk3s4lAkDxbW7tXpKkVuU+qLSFqLLp8tyQkmKSopVKFYG7Q6rhmd8SavL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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk81ekalyWNLZW6aVHIoWRJlqxf28gQY1zZl6KiIkuJ4spWVNKZsYyU
dcaWkmQJTUiWgzh2Dqks8VruKJSi7n3nj/M5n/fz/p73eb7P8/1+H0l3X+uT
3FxcXMn098//idjWpLyPjRBDvJeAFYFysV3fQeNOqI7Oyg9ZEyx/nJV+9qUS
iqNpdwXVCQayvHgs0rqQcfuC2mg0QSZ/RZnndzYWRSst3On3YgKD+zu5WGg8
KewkrktQy1/aY8u4ARurPoV6KXrmaYn5WuiPKhn5qR303NNchXaXWnSMlZp+
Uyb4F8OBAf2XmBrbkTVM45VNGJoN69kwrFPI9j1DoDUeu10pshsSpb+PiHgS
bDf40nviSx3cJDj+OqoEnI73f3p9qMeLV73eC9oEN6JXQjSKa6H+Tilunt5z
zcsndnpVIv2BsIyVPMExHyPm3MN+XBRYkP7zDkFs0z1dhmQ1ipI9fztI8e52
DvYoDA3HBcfxjda0Xq5fXC+VZV/DXkbLcS96vvJDyscO39eIGjuUZ55PIJLU
2HByayeOnPq5eX0ggXN+L0OJl4VqEcXFH40I4pf4Dz9N7Ma8bGN6RRSBlOWM
XrpOL+rV9atKaP6Zv6QG+Y/3Q/F5nlbYZYLiIGO1Mk4aCjMD+rGHwOrDZq9x
oQaI7rtnx21I6zEq+bhe4xm0LmmLmSvR/g9HbV17vBO52TOPP3gQ7CmRMXNb
YcE5c1fIDw4Eot8u+ec7ZSMzhOm/jr5nmx6dcX2Mg7/Hj4qWVxJ804orPRrZ
Bsv5MCJqSTDyIk+lz4kNjtsa1bJTBPs9j3bYag9DLtX1yEgCrW+HzrYakTqo
bcqx01YhKOIUrn6368bxlC/L2n4Erl0S/xFfasGn8+qLu+0ITvStXLBWKUMs
Z7n6wX4C9t1jmTy27SjfJyeeZE5Qdsjjj1sb6tASFW/icZDA/2yOwtuZeiQe
WAjy1ad8c+OM6SW3Y8dmfg+xnwimbr8bXLF7hpdzSW5Vhyi/BGLyHQVykBm0
682vDNp/U9kVf91ebH/WsPryEsGwTc/F4jddUFk50CMaQaDn4Zk/mdKClJ8T
zDm0n3KPcyPnC6oxfd+wUVuB4neYO1O+1IuA3o1LOVkEYVZ3KtY+ZePrzWpc
sKH9M2DIFJixIfeZyXeD4hXN63+oxl+O88kXuQIoPvmB7ECD8w1g+d6ev2dC
8aaz7c9uGYbriVvbJx4RhPe5HFyKLkNvh/xMAeW/33n28CexIrxU+lo3u5dg
a7yyrqtLK3a3GcWFuRO8vXPr7LvnLWDy7j1sdpQgOjTIfv6nLmQXHeOs/+c+
TN7Ze+oxzsg2WnEov9f2zTx+r9ePa7Z2x1x+p/oJenZB6F0btvmMNz0/RvlT
y2MZM6AL7rThqFVJgkOxceVBgY0o79OYDreg/E+IMHJ43g7edAvrcKo35UtD
zsGjlfio/uRssCKNn2g2a8s0xPdK5dh/4q24vh7mPpEP76ceYkkyBLz2Z9ID
B7uhyho/tOEmQcwZScGM029QoGodzpVN+XlqznGxho2t19PrZmg/I3bvMZX4
Nkh1rzbrnUGgwXefM6hRgdaajuoKiqfKZ9Wop7cd2jyv5z0dCZj5Bvcju5/A
7Ckfp2MfwSzDMZx19xX2txi6JVP+d1RFL1a1dCPxyRW5Qqqn8fS8K5dzmzBl
5Sr75t8Et5bXj3P2c8BkKHC35dD+e1vWppfkgGOjJu9E65czmTcI7mnFyNgX
Hyfqj9NCmy25lfoxcWpvekgJQbvG6VKHzj5Y5pvHV1O9y6U03W827AAfuyKV
7xeCq6+kxTq+N+CVohZLh/J33ZxiXp34KyS/3mJ2jeL1HlqImSythb3LHzbH
qT9B7aYbn2QZekLe64lS/myx3rNGYA0bc/GCOYyzlC+b4pVT/AbxZ2rIBqk0
gnw1qxrB0BqExn5aNKB6Sd3TEzKiNQT91zMZ8s/o+9XznDdH6xH2EpVZVB/F
4idV+rk5uHDO9V4hnUdtZKf7asRzXBY+q/9Vk8B+u9x5KdluiKsyJotcaD7P
97ZD8q1QrxOR/OxE0Fa8yDMj2ot72cuaIjS/XIbvmY2SL/B2Q1u0E/U3e+Wr
3QtSTeCNfz3mT/03dsRQU1/lD7TpnhK/SP1mXXCSIK9/MYITXApG6TzfGuu0
dZReh+TDW03R1E9DYTkdq9ABiSYpaRfqV7aZwrtWk0Zg4bvzsu4wwafLKJyc
ZYNZp3k79Rz178xfuqZ7/4Ks1E83Rik+iZciP5Zta0Oqu63/GNVbe71g6T6X
EXzd5FC67W+ClCo/PQ21ejh79U60aBDsnEwT7jIZhL6NtfZcKIGKgZSPzL5h
zDwQssiqovluW4oU5gxAS2Aq824h3X9L7AALFguucoe7+qk+koU+6xSlNaL0
wwMNbRBM/Ouv3IObOmG/tjY4y5Xi7Ul2zxIsRF/GSmk/5ZPE+bgD/OWdSCo3
tpil/GPLP7/6YlcTdgsXBl+n+26riY9pjH0JLrKDzBPo/Jnielu/2/Zi1O3b
DmYigT5L3WHtfAJyB4T2rJcmOLJT9KGSdQPst+0yiaLxqzsPc67ca0RXYvaa
BWPqxzLLiBocQLys9IniVALzKjPhlDEW+h0lHt2h9zwuE47nsofRLCOa+F+6
f1qjff8nrd8E65jwiSM/0v2U9f1pQGIzeL9FMn43IJg0+I0xuNiO5fDQj+uo
/3htzBHae5MFLebSJWF7AhtNVe+h7B7cvfy2XtCHoGXTmmmc68QPwbk7r/lS
fjRX/PrrhxJ45D6KkKb4/KQ+5zcmt6Km4O+hGlMCPgWzMNOhblyzOhDoF0Bw
WvZLbqQP9X8+5pM11J+Zsu5c5f6PUDSpkhZF9c4lbxyRFFWFo09Zr0Xp/nmx
gWnevFyP6YDNvpKUj1xSBVrC9YMQSZia20j9JNBY6K1cbht+u7PLPo/uj4zE
cIkq6qcbry74eNB5xtY94BJ8XIxE3sEKZzk6P4uRxri5Tgxo1sQdpvwwXTEa
3dL0As1NO1l7tej7hzb7TSqWg3n1dFUgxVO8Tmy3jg4b9o7B9RF0f/4fPBmf
XA==
       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHk8VP0bpZAtSSmvspUoUUQqpSNJSCJLyVKhXpW8tChRabFUQmUpSkih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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41Gkbx6VVki2xG6ktSsTrEIu00VeRaskplArtS0hdRWxNhURtVi2S
mCKFcohOy0o5dKLBjME4zGicz7/f85tNQhH1zvvHfT1/3M99Xc9zfz/fr+Z/
j7sekpWRkWFJ6/9ncqn2dLcdD9Z9xXtWXiCYcPypZXCUjyh5ZztWAUHYyu1n
0/hVKOoN/by0mYb5kx+3qZe0Ir7rg0GCHgP9nTFPd24Q4FuI4WfrHxjoDopU
iyo6cb8z4d7APgkCPCLMEp25WOHLDnVzJJCP1yaa09lQt6Gab0RRePmaf65i
TRi8jTpv3TCkEPXHIUOvnpsQD4quB/pSUCuz9+N+rEKD9fyOwYs0yGuNAYvL
HeieO7PEbBsDi7qiTRXjb8GyfHc9nk3DNuFTfOP8JqScER5Ku0rwsnTOybLh
Rujlzf8PN5fgbuy20UPhPBQs38R8t4sgWNFjMiU2H+Yvoo325VBQsnAfqjbL
RkJ3l6feJQq8JvWPjaJqpKe71P6tQPDvQ62a00mdKP8ydCQzmEHPINeIG3wQ
ykq3h510KCzs07e6b9yAx6fsq275E7jYaBcv821BRovA9EqjdH6Lou26kUaI
xpJsNdgESm3HKMOFQixdM7bW9AyDxCnegrs7HsL1y7xAzWIKJoFvdJ1lO/B2
E989EhLI3xrLlkxW4vl00L2sDTS0nsm3pMcI4SCs2JryjEFg+ocs4aca/Hrq
+28TwzRKxbqcenkOeEezFsU+o7Gu8L3tRLUAdb75S6hXBDML23gPzp7HtLdY
vM6CQmlkvKZ7bAnecruSVRfQ0E/uiHq6/zUMvcpqnxyloZ7V39Vn2wSbLcOO
wY8ITGVD9iqoNeHKgfWFnL0EFleDxzxnEvHtDed9tT0FjVc6C4bXp8BUr2vy
sxcFV/0zgrKiFpwsUL3g7s3AT8U+rHWoCpvUxLd6pfpNrI8Z4Tq3wjx5JDdP
g8HJKSvO27sC0Com79PmMBCFnjUUlEfjgPue27IbKXzlW86mf3iHHh2KfSeI
ATNp9PsLRwF6k1VHf7xBpHNhMg1/NYKVfbkguIrgWHZXROaEAOWLPXjV5QSX
ktp7tIvaEDIt0k1axmDGP85MZN6IqWM97gcaCI5qeo7OuHDhYa8wTrkS2E+z
PlTW1ENGUnn1VT5Botfaj9vLU2Cj2FFS4Ekh2tEnc6luDQoPusZvL6YR2zdt
OMXmQ59foSNSk/JPRW3az+tE3ZbbDxTVJNAnZ09jVyvknN1TQqQ8HXQbCciO
e4YxB6uhlPU0ZPrCdRPrk7H7cWZT5W4K7NPjnHOK7YCkXlzbIN3HmfKa8gcN
yAjLSTgtS5CT6pAcH8+D+z0rd809BG4Fv3yqlm1EV8NUXokPQeHXyNepGnVo
+c1CkCX9j17RujRWXxXsZFmrz5TRKL5WuqYQIhzbRWLSfKV8CweuWg/UYdJB
1H53J4HTHMXFz2O5iEuttOWcIFAIpiKK/ulEz/kta0bPSZCtIv/PRX0BWOmd
bd7S+x2GGZuXXGmHkZbY6VsPA+e522NzXWqxz8Df2L+DxoDnzvY4xSbIN7S7
fB9K8J1VgpmRTyWMnx52HbGgodx77qUmEaFvRYlm+CMG7JySVSEhNZDJ9p+e
ekcjalScs/J4Ijrttt245kDh4Inb3OGeN/j9y/3Ah6doaEyo6t/UuYuMF8Ul
liwKvx067BDKaoZyqNw8uTQCT1fOHEV1Du7bfhy3fyR9T/9oloK9AAMyDws/
TBI058wOnraW+jd0sr82naB3hZG6ZLMAuW+YuakSAkvJtt3jBW/xsZ9zpKKc
RlzuxlmyXwDlLq8gidRfi1Z0vOLNtOKAzz2VnGIGP8XHsZR83iGxIyApWspr
lJG8goUfH6mqPjmzz6R+HDE7rlJaAhnX+ilzORp1JqsCFvtz4F33vD6XR2P0
6S/FPIMUsPcvfyizn4K1UkCktnENWib3Lf3UT4Mzs1ouz7QVnM7UhOuxDNw8
1xu7Xq5Cjkehut0TGn9vtpmnovgOlsYWN3Z4MFDb6lJkZCDNZ37MbJ4yQfWy
ExnCVe1IW3vYrpvLYGONctMidiOqPu3SWust5eeLod5ITSdMWvMv/cWSwDoC
0+fLa9GiPCW/xYog1CHo562qQiSULvl1cIbA5MFepcK0NsQs5u8Y7CXoPvxH
tLWbGPPJWLRpAYPwCK5yd1QbLq8ThkfEMEjipcv6LRHiWlX20J8Lpfm+lRY1
2Qjh1LI35eu/BFqPV6cfvvAUqzMXepnL0DjBbNfJXd6CJC27zLgcgqajP1Qn
BDXAr+hs3vk7BH6tM+qjonyIi6zFbvkUHh8x0N5wrQZyqzZmpWtI9WGP5RT7
C8CfZ1B55zaB/tWyYfHBBkSahpuwpXw85vo6NV/iw9Y96OtsnrQ/+uREUlw9
LmQknIoMI7hzfuam63wRLE8OBf55lEFs6KqLbnENOCIMnYyW5mPKeMADsUML
SqqfOzppMnjv8irtUn8jfj4w2Vx9kuB/9NnsRA==
       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGs0lIsbxUdJKREjFLUoKhLVqXQ9u0JNpRNHSa4hudTIJZFE/TkdlRVT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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk41WkUx1VGDTUjpEXJVpYkaVPRV0luSSUqWSKpyFb2UJEtaaGRKEmy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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8Vd3bxqkoklSazApRQlRIuRQZ+kWSNHgyJeVRSJShTA2GR9IkhBQZ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVk2k81AsXx+13upWUZElZUiG6tqTCr4UWhK6K1IOiBU8Z1aVNRYula6lc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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVHs41IkanpAulHKLo1xyCie3g2qz6tVtsyXkUnbVkrCRdFMkle06XVza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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk4lekfxk0UNbJkNDIjSuqEyja2DrctCqNQWc6kOm1EllRkIqc5zlSo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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VfsbxakMlTQpciWSIQ2EqAwLqSg3hCKSyhAJ3SRRUsZKpjQXEiKF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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHs81GkXn0QupVWry9uOctntfSvUug+131GSZN1CrpPWNZSUbiJC0a4U
2vgkVkUpJKNFhAk1mozBYChJGW2/SyU03fX+9o/nc/54znmec76Xo/dbtHuI
EovFOsScf+OaXPmpwUghWltdFtqPkzAvsTmtXNIGzZf8pqFUEu0jmWvHpjpw
yzzCNs2WwuS7nausTaQI+8TT+7WDgtoD5VIVFxlijpn1FzvTCIw1C503uxIz
+62LZzUTCJYbTEmDxNDSIqOM3Jn8vb+e80y4C4+5OWXeXiRGouJrAh7egtlA
lMHkGwIZxNh5sdZt3BAFXu3RJ3EiJPLeuSdC1IQst3SkSRTOPHHiRn83qjcv
CExuo2C1dJjDqmnC9D3zhsQwEv7qJlndVvfh6LDQV/UzCXaiW9iuCBGWeP/M
X21FIfi94Qib7MDx1JQ/8xwolJp4jUfpi+DlFDY0+3sKdayOaMtkATx4w3PT
w0mceePcNLC/CLNV3g4+iCNQbqWoJEclWPypI6Ork0K489KDaukiBP/WoC5/
QeKD09jl6J31uE5NhM6dT2LPmu/8d9UN4Mtz73NyGQ1lnyijB9aDcO/KvS/p
peEu2aDcaCZE9WIXtsdHEne2vBBWmwqQ9cTqjFIECa4so+zUpXrcn5h67W1A
grVzJPLLtyPQtXk6vsiUgBmvTSWtWYS/LgjCGrZQeKke7aWi+gThd8vDUza9
gm5a0NHKTY0Qiv3Df3QikVeovuZdRDdsD+ZOqvVRSF/GJvu+70Zx8rzNih0U
Kn5K8DLJb8HyUU5U3xkm3wdnOX9W4HViefc7AYERfqv2iONtrLfmaFiqkeBL
RIF+NV3QKZ/fve8NiSLD1vzrq4owXHBe7BxDYKqXq+Xb1wl5Xm62MouCQHuj
7xZ5KUw0SReNEgI3HewnDofIoFbn9vlgGQ3DJbq//I9dhYoW/UdOIgLKCVcD
TZzv4ooPud3MnkQI7yxld08IfX3xBTUpw8/pBQkGK4ugXdLSkpRAINzKIlZH
owmP3AyQxSHRk/jfhl0xUjTtX+53ZpqCYWQqx/JmG3hVBkY6OSSmni9KC93T
iM3z1iSq25FQfDsSY24jwcx1H1ak5VBYuF99qONpP0brF/UbFdGwHsobVlnR
hZVxdSPTFRQGxuTzdx/ohrKWb7mikfEHq2CDSFOE2NcRun0fSFwPcg2KS+tD
kY299eIEGsN/K1MZZweRzVME3PKhkfHPfvfwc3dwxdEym88lkd7iuMxjSIry
pTnbeLY0Rg4qSrhcIRSdKZe/MPNyk+MDvq2WITZ+T43SERrLhDkZOp5SmH3+
eOWhI43184xbrl0awqKysR3NTjTWuvMW9zYy/JyWEBr5FN7Yxk6uchPjaAk/
/uQ+CvetNlUe/rsLxRZfzjb9QcGVVbj1Gd2O5/tkuj+spMBnB8Yd9WHeR8G7
ZC6N5yXX7Ew77yPPuV/dj+mn9y32LRjuglJH1kXDLArWqcrhzam1yA5ipxAK
Ai9ZLTci2/rRULQ3eWkxw//WBVOC3hwk8H/6XdudQDGnXH7GuBuVJH/ZdDnj
P4uVbrFf2zAHF/8z/ZSE14F14XqfehDd6lHaKvpX35WlO0xkmBh+FuF/lobr
FKd0ZnsV4s9f4v3YQ8D380WLFYGDWPtVsiUgmvGbpWn/Ky4fuxMC9zfICCSF
PB9xEwwgVNvNns3Ud22nsuNNr+BW3ZW+yQsE2kub3//zXSeKzV0012+ikFza
YWfEFmOGq+Z2iR7zf/Lxv8Y0xfBOvDa1nMErXxzQ/J7xN2u07NDjYBq7J9w3
7FQM42Ki8xrDhlfg6q/WEd+oxfj0Rt23bBIE9TYyd1AK3fQhx/ZrFHQ1NuQm
hwohD16roa8gcfyk3oZVsc1YXegwv9qXxOkZc8pkj2UYNzKP095FQxxV5V7A
4NOTL4dATGKOhrExdUnM3D/g3fGjMGRcePN4WgcWnrieob+NAtdI9G7F3Aqo
ZsYku9USeJixbcGKZwPwtDC7PfiMgkqtp9hX+BgTe2t2zWL0dN46UxG6RYon
mvURP9AU9kh6/MKKUuDUqvVpkQ0B/zqbxefnVaM8oXCJIYP3oYy4ilT6Nqa2
XjPw0CXRoqmqfdlIioVFzpslUxSCKiOSXvZ0oz7XTtVCTsGhUFZqvK4HA6NZ
j4zeUPDXOaYUHNqORr5P7vgkifwJX0HXzxKol2ytDgqj8DUryWBtTC9cj/Hu
CVopaB2+emD+XQYvA7ar7V1Gf1UD7sLGJjhGO87CL8z+TQpYJT0lxgnVpHPl
v1Oge12e/JF2G/YzQsNFzD7ufeE5t2pjJ158fJx54wCF6Tt7LUVzBjBhcmfd
x1Ca4UU7qTFeAkHmpgxffwrRx1sPtU1LUTD4Kb2G6X/3jpNcL44U2daPC6tO
Uii2227KUWrFNge/mUNJJAyDPOubzAZx86vz9tpOGt61sUMGeWKszyQ4ersp
tI+6rD9m04ulBYfUvnjQ+D92Vc1/
       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81Akfx7EkdsKWIknSk1LSo1wr+thISqUdOkRCq1zRCnnUypGjknQ4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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns0lGkYl1xaq5IKuZSsCJGkjlXNTyKKbCFNChmXEjvIJqELNYduSDcV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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2cglW8bl5QySltFJDvJaCn5SSohSYhI0hINRUv+kjISIlIhImVmRVE2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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk41AsXx0cmIalUKrmhvOFehcgS+VraSF0pXhVRUolKSEiSbiTDVeFG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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs41IkXxtncUhijn21ji8JO0Y1NlHqtS1IqSbRIVkQ/FSm0SpHSpJS2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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4VesbpSIdla7cBrkpMpNURNNKJUNpEG6uCNHNFClTF0klKXMZThnL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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VX0XRSKSJETGBioZSpQpC0lIKpFSSdKkRD4popAhUlSmJmTKHBKS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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41QkXx7lRzMhrLjVSiV6U8ipGEeprlKJuulmKRsVtHyrFKGbsKhSD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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlWs41AkbxodWrM1hlVE6bCTbAeuUzSG36K22qFZUq2zJaJEyRVbkkOaV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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs8ldkXxk841EyFaqRySco1lyExbo9bE5qRLhQRhUqi4xCJGgkjNKOo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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VW8XxW+lEiWkSRIZo8xFRctQphAyVfLTgEoiKlJUSFKiQppkKBRl
SObKnHm4hmtOyD3nXk2kJNX7vH/dP875nPvsZ+/9XWtJHvS0dpnNYDCcZjEY
//8tXbFPWux5H3ifvLzWfYWLeN2Get3BGvR4HBuM7qXRrur5QulFD26Or+ld
EDkMlbF1HzqpTCz80v6heIzC3xtWYhszWiDGDGySsBtFk15qW+0AEylSrSZl
P9iwqaByTbzfYZ7ithrBBBrH54o1KFc0wSFidVJJDg0RzvYL0e9YEN406Mu3
iYPkx/bcjIhuMDTmcTq8KaSF2MjGrK+Abn5idsxPCl+lFGJj24vg+kkz7pYO
DdeppbYWO9sw9MUrV+vMKKQj/r1Jke6FihjSpowo+OVU+S6/mQOTsr0KCbtp
HHmdVFC6i4V4k71JEs0cMFyiWuYjDX/4Ty4QVKARnROptUGjHp0Clyvsi2jk
Vvw4cHhHF4y3ZMsNZY6CR/2rlE9LFfokpQveLOMgoeO8SO/aMsT3pdnCg0bL
oznrP5q+gbiGSb6tP41Ent32p/TbILI8ePyqGBdKBhLS0n3PET4qrpeymgaV
7zKbmZmF6j9FZooraLg5Tye812vF2N3DSUIcNuJutuwz2dyB4m+/9jKYFEqn
vAOshfIQ6BGUaKpFI0r3U1VxbgYeU6ncgWkKjH2e+QMPz0Ai3nrTIkkaglW/
pmNOPgbbJWPeHxkak3JfN2iuacXVnKs3bD0pWIjKFLU9YGFeL1dWuY6DnaoO
hbrCTMw/u/nzdRUKTQX8eZd1asCa/8xRLoiGrLPhpRL5Tgi+EMjm30bDGzKP
JPZ2I1bbQ/9E1ChGkPHFb08tkgYGMgrI/W03ckvUWtaD1U6TaZ4pNLov2bkl
BHcg5qB+RrkuB3l+p2cW7KxAoEn6kPR+GrordtLcJzHYV18o5kfux4IuG51a
3QevU7lln/+jYHlfqcTgZSX8Vs7t7/1L5kGvhvn8bBlOyCiH7mRRKJnMl66+
X4Elf/i37Mui0VQ12pCu1Qoe9+g807cczM7exF/zjYku3aHV5ZJsVG5fHFmm
34GOVFp+cAsNv4wk6an+Sih45vFX6dF4pqnotObtS1xeI7n/wD8KvPtf/Qvv
KgefrHteQgOpf8GUy+Z6JkrHv81dOk3jvne5aLdIHaIP1jxJGGfDVdf5xm2L
PujM+ZG66u8oVPTqBNx7CrHVwK2sSYzGYNouOFT143jI2QsHZrh4cLC2qjy7
D4ZJ5wUZbDZkvg75pwb0oFe97qXUczaS7a/bROiy4JvIns3azIW8e0fA48E6
aO32YTSr0DC23Lqm81U2Lpvyau0l9ayQ29hWvTwJLNEfLEqeBq/z38BdWf0o
3egsusGCjZHNA47LzNqw3VdvT7gDB2MWsY3vNHrBSK81kiHfE/kb5jjBrEGu
QbEDaxONqeqo/qDnFagv4f3FeE8j34Mtd7akC/Zn1Nsfp5L6+q8Oy4vnYjDa
6k/TeRqWXluje91S8b2IG3pOggbDrc4zaHYX/vmpONe0cMETk2nD+daInMmV
wb6F5LnlrW75Fc1wNPT/HGrEQcaxD3GTbxpxZdJXBck0znMUVIuS8zETIXM7
QJj0Z73Xhu4f3QhUqe4PS6QRP2Kk5dLYA6Z09t37aRycmjMUqCvQCAHGBvP9
4TRC75ZHed7rQGW21xsesm9vw8zkKJMeJKy/4ihdTmFecJpw6N+3qM7JOGJd
TOHy/LSJqllMGO2IyU0QIvfrrY7d4bXgU7AyYspzELnnqkTEBBPtZ8/8V9PP
QVvGaMuOB3W4Z9+tMrWQhuN2vcPXiitRKFRgYneRwnfH7PW9zUyErIsqL6mh
cN2p59JrN1LvyuFzrktpbLJO/TWy8RnWPuRbrCFFY/x9+/7vY30YlfIZ7iI8
VLbvvtYl0wm+ls+6jBIOhCyG5Wcfb0VWaN9cwb80Voaz5nwx64D+1MrJLe8p
JGjsFhpPrID5mJeFkzCFqOEsrxOZuSg0iRjSeknB2Hrf8FRDDuZxFRwMFtM4
FhmTmX65EbN3frvybxcN0fPR1pJ36/A3cWWT/TsaCbTg1lG/ZqT7/13+MYxC
WY7Gb41d5H1ec6+lVhws9JuZteVxK+wk3rax7xG+ps1i2eSy4CCYvv+lIAUF
0VlmAjWVkG+7P1qlTcPs4d1xKbVKuN1M9PQwp9G/JX50u0cL9s54dxfocGB2
5Fq/iGkPKPHbHSvnj4HjG1U7c4SFcQFJSZvzozh8J6C27V0Nhuttgq83kvlp
2Vxok52Ozp2XxEU30ohrNlU6HtiE1syS/rhKDlY4451wQi2MCtuy7o/QKAtx
XLxcpQI+13cHHbf+vz7cEnGKqsW5cdusbcvZUDOSaeBJ7IRaf1PYUtKP+Kjw
I1sedkDwYamq6WUaFyPvN0jvC0PkqdCw7pU0NL0f+FeHdCHNR96uppOLKZ3H
TjtL3uBrD09PJuHxrXbz97GBFZC45ZrEPkr6sTYjyaf3KXqafVOriD5pGHkK
3E3sQou71NZFCyhIaSZ3L1BtxatdtcaaRG+6/DSkj19qR9iUfR2XwcWRy7MY
/qxQHBHbtT6KfP/z9Wn9VQqvIe4s/rbjFgWtTQcWTEQ0wP96C8/GdTQKXr3T
LErvAd82Xtf2ehpZF5xDZj6wsFhG7uKiCBoOu2WohKFWzPundVDtA9GbCi2x
e4/9ICvC/zd3LY3Ah892qXGq0XMitbVsLwes4WXq5w71o7gix+Q5uc9IxZpw
ll4bUpu+qRhrjiJcqzlxm2EPnvXz12pKjWIs/fbCC8KdmDpulRcXSeHB21OW
Grx1SEnymBBoJftiM/Djz4XHiFpkO1xGeOHMvjWx53gKggesfc8uoLFZ7ds6
gfA2NLkFaJ8jfA1b62ry7SILw+CpjBb8iCwDU9n6oy9Roinxqu8ThYuvvOIy
JaJw2UW0rp70J2ys3d9HtxJhexSP2n6goeLaJJJN5yDg547bQpUUWgqtXN6M
Z6PAonutGy+Nw04+3HqeCnwIXSE+mUJh/dVJ/ibrStyeMFaP9CL6uhIxIeiA
1p2nkqp8bEicUJujM/wQaxuOnv1H9jkp5+2c79JNgE2HrVwfjS8DZ5ZuFa5H
uDJfz4VoGhLbeksLtMow84JZFDebRs7JjAyf2Ld4oNntXETqnylU0GtfUA/W
0CBfA+lfQtbItZGdlZDp2yt/ivBM91NSypHOQzC8e3zsFOnP6MSbfU6mhOci
Ca10FBv006GoH5qN0PURjdaTpeH1rGcr9eE1PgxETMwiPM2QoIJfPKpCgWJe
8TcOhfYb53wiQ0pRV/rFbpLoU8u4UK/3n1jYLv3+vYTMf001I3z1MRZ8VkU0
ihH+r3VTMv2bW4YjEo8s0sn3ok3kik6M5OOE8i+FcLLfozxm/tHv+iAV4HFa
J4YLZ5dFnXnUPeR+snm0l9RTWmJZwsiowPaDnNyu/WwY6/DM3iWVjXXB0qfc
yXkCjysI/e1hQSDsaeYlVS4KlKv8Bt+y0NGmULk8kIY83/eaw8nl0D9Ylrm3
ksZC1UD60t0enFYd13hGeKCtNK/5WGYd1JdOFPV3k/6VRB941VuMjYkrFbbZ
Ev91qiY+O6UI5hn6LXIfKXBsVIpbZqqRNufj7YXBhE8R8y7HvmqBSpCOzfFr
ZF8k1a+cdq9Ei73qxqiPpP8G1d8/bU3HUZEfi0uJ/zp+O4O72bgc58/TfWmm
NAzlZRKYIkxobz7+9BTRI90lAgkp1pewUelhjaQ0jS5KY9qv5BVMQ+OuWh6m
IbVGUnZjQgHG7OjOp/toBPv7bNe51oqby7f5h4sT/1WuuC65tgoJPwP4G9xJ
vV4SU2lCzWhUejjh+5SCvLiBna95Gh5E/HxNCdCYo/xyt85HFu4aH91hQfYx
7fRP9r5zZSgo1MtnVhB/vcXMxLwlCmKMW8/mkPNImAR69Fo8w7+fd7Q9JyjM
lPou/HysFbGlz8+bSXIx9qdGVlGsHAvcFK3SmTR8iyJjRi604eeOkUTNCXIf
WfH6+UVJ8HO3WPGH+AWZ4IvQUG2E3RbpYQcTGsum6n5qWbVBoPtFWMZjNo7P
klVLa+tBQKYpj9gi0k+eJX/kfpRCSdNwZcNV4jfyJG/Z/S2DXLy5mkg8ha6U
jHPJOm+gSytEh5I8cCvI8Z5BNdm/2kHFvTIcGHJ+DLRvqEfT+iVRGo8onFSJ
5cm16UFjYd3bqDAOHGJfn1lUWo6tdo05W6IIDxasEmAE1yIne3llRDGNe5sP
XRPnViOusXebrgfp55GlT1XV2uFaMzrcyUP6V+zpeiirF4flV3g9TRmBuChD
wdC8Diqls64cJbyYS52cIynNQqoE3beT+HfRKgerTZuq4eCRpDpfk4PH2mMn
sz0akO1e2StE5n/1hSvan0ZbwOPf5V5B6mUETZ1Yo5+L6iXbvowRf3Jx0qCy
40YK9icfyDtL3udzcuv8NdEGa/3AlRNErx0CahX7zWtRvJSt/Y7o/9SJqOiG
jnx84C0L8/hMYSzm/rXqd0wMyZjZW5P6+GJvSVpplcNwTtH7LwZEj5S2Nb41
YcJ4N79Vy8RHlH4q/awTdhnXGmpjSglPHovedlzkU4ZNiy/elCHzuf5kxNzM
LV0Q0V8Zey+C8FL5dojsjnZMf7q5VquRA6XticnGizqw9jd7hEvyifEbe+5r
0RQ4/7fo9PI1NJwMz9zyotuglbHlicwQjeorh0Y2zHTgwcf9k88nuegaUl9g
NJaFr6mvC1y3E/8e8mGJs00z1EWc3dUIr8/8pALKefvwR+vTscjbHzHy36tj
ypk9iKo18nXx4yLuX5JwKF0DIbZ+9iPy/1OabZvHVJPw/L3ksNb/9XtKaZt6
TTvq1iYx3CvYqHM5dENtXj+QLKKVpzQKr23KG4o12sEpeWL1nxLxy6tk6lIn
q6D2LHd1SRvhlcKcyXffUmG/11hagPiLmsnYNRrMfBhKtb9YuZnwgWl6cZld
MdQdgsNOmlPYdOB0C4uvA3UXnO8MtbOxy04pRd+SiYWrDHiXnh1Fjb7LOu2D
zSieu+BInwbJk86GSUHhTbjlJjltG0fu+9HfwYT3tbAwDoqoGqAxJuH/Y5S3
Gyca1LlDUVyE5W+s9bqTi/ONC5knQXjW57ZQMqgICqsdrF6Teeqt/G9ZIrcS
X53PiRvbk/m6y5rX/fM8Nt4cZliR/k6tua9t9aAFfTtc2Z7/iP9we//xfHAF
PrqJdCwRpWE6+1lP+bI2RLn4GvYu5EJctl7/yY02iJqa/NjkROZT0Vrj8rJX
4Fdu8bivT/gxuadkefFDfJdw3vCI5I0V98cHg+8Wo1cjVLae8Fb20530tAcD
aDLwHhEWG4Nl8ZODBT2VWNp0SnT/PJJn95x5FDFViD/llOaLejK/85wL9TV7
UPg1+Zh1EBtZzmLOq/1roTHPSO4q0UuZ5KlPL7fWIzDUKEP7IA2eRyq+vEva
IFF9TlxZhEbIq2MJ+utYSBwzcyvHKFpOJUne0MrG2tjsQ8rqJN+Ml8mJWPbA
PMhl9/huDo5MDk87BJXinLrtjwTif3V2Cn0+kd2BJaL1IoYnOHA+cPNO7ZZc
XHLTsjbgJ/Up3slBJxPiA4/ar8TSeGD9kJ8vrwFTG9RlbPIIPxQbvHnta6Cv
uaHTSIGcT/AIf71RHZQGF7277EL013bc79+qdwh4pHLj3AWityElF796dmFg
uuxR/Vwu/JJ+96kqMfGCxaEuCHOQ8lB77uXqdsy6lz2+wpYNRvSLz/reNXC+
mmZn4U5BsFj47uzoOuSY7YzyTSb++drayiTtJvAJ2s7YdNGwWXdD8qHWUwR+
FZa7oUn8Ft/Sw7RhFRxfMbtqM8jzrLNfVFJYULIqu/WLdwyMymWbqvWuwYnm
mCSReekajjI6HZCFpEhREe4PClSZmo95XBVCrRR2mxH/GJXfvPFAZC54tqYE
/iXvC32Q6TriVwvvOAfjbWwKZk6v/D94Ev6H5NOzC0YRL+syvOROKzp79d9t
J/yy7FX2XLupFYefPRKqiKNQf+3B75jkTqjMCDzobiX83y6v+nzJa8jT0y3N
5PxZ3Qa0dGEKmmZ+StgJEn97xrpI2jgKjpIWofdkaJKLxzMLpjsJX90UKFcu
eP+79sylvAR2/xbWooFC5DI7+3kxTFgHTvgkVFH4di7NS7m3HGNP3b05zRQE
vH6dSlfvwfya8g6FzCGcL/g0wfunCbX1y6dn9bNxaUnVmtDRPpQAO8y5HFSE
KTYHvejH2QrLN16H2JhizH2jtb4U07sj7//mI/nC23y3XXsFBFeP308n+ev6
tna1o653UXB23+doMo+t8Xblw6Ik3wcMJ+wl/ibtu/T8K6H1mJ72P7nmNxsC
0MmPbOmAmdoXia/ET2qE5jovftqI7w0BwkvJ/gwubk2Lz7oLLe17xv+If2N8
Xm756sQZDDbaNn0l+UBeZp/U6/hcWO7Su/rOgkbsyL0dske7sH5d4MA54vcT
pS61yan24S2TbXkpiIMz7gWrvBezsHB7SfHVm2S+vM/K2++tQ8L7pqIj1hQM
C51GhmPKUbNdh6FC/PDs704dnD1MLNPK5Sp5UuAJ1Xj+YHk/ju2od3R052DC
WaW6904FknYftsogfPZeb/z0sUotrIMvLvyZSuOyY2XURaM+rKzvXNi7iuin
bqr4cFILQsLDT9q6cTCdv7RPb00LpH50G5xJIPnDKinUuLsAprxf8r4RHg/i
gK+k9l1Y3poRHiV5nVFwPv7c8iCEsd37fhI/naA5ucO1lQnEONic7CW8KlQo
HdaqREPw764pNQqhl/YojB6qhMvaLW/UiZ8cXOKfFP62DXXmFekXFAnvPjoW
+6zpQuWNuVHPXTkItnuyZHFwI/K2KvvYOXJwUSbxjLPQC6TQp3k8ltE40Tmd
fT6rHSE/jU5yX7JheDE5UCZxACSMSH3OpOEXsXki+SXx800tOQvSiH++mvw1
50kPPnk/mG6T4OLfDcmQt50DEJ6w4++s5UDwUFKBR3kNTqyLjuOdoTDYNntx
o3c2PJ7c7NUh9Q9cnIgoY7Qh7/f1FzcNOfgfo4YBdg==
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHtcjGkbntKHSKHkVA59SVOJrEjhkpatsCq0Y20n6YgYbEVKG9tGKo3d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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs41AkXHqas1H5pQ5GE7a7QVUKvTc36KFFJ0oekHVvTVTxdGPcauZPY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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lVsbxsnQtBtRUSjJrEgO0enOkDGShKgMHdq0E6KjlKnsvlKRIqWE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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2lczG8XxrMkkgopStIilBbtCy5aSBSFFkVkq6Rk6R+FdkoUWqRFlCRJ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHs41AkXRpoUMV+URF83bEmx0Wo3vEwp4WtDWRFNdJlKIluLSsK65VYR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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHlczIsaxqckLUKom1GpkEqk7cOhPKHF0sLJTZJyLQntOjXhUpYKhcjp
HlqZcyItUyqMTKWaStuMakz7LL+Z34w6tquxtN25fzyf99/3+b7v85gejvz1
mCqFQqEp9f/5+t8XMv3NuJiWd2k6G0gQprI3bo24Cyd3CapvPpVgqj87+OCe
SlBok26kowxMhH+8uLQe7mqjqp89SXjnL++2rOahWLAt6325CK4NXvNlx3uh
OjA0vr9dBIvWhZknXjNhNnHfJj+DhHslMTN/pgcTq1L9aFQJopp22SY5M7Dz
jx6918dleHRJu2GRiIXkk0WaDb4k9JK0vKnyfhR67TgwmkBg+OcjQ4tV3bDw
FQVaBogR6Bj0g/HnO5Rqt2RHDQvxSR5x7TmzHdOzHx5tmyYgX1b6uZbChos3
sa0gVYqgvHJu9lQPDPf+41/JPgRcfr1ecN28EYZaRaYpc0kwLnwLn6qvxdiL
9GajGBLnVcUZ8cM8BIS4MdSaCYjuOamllwyA/kkLA0VirFtuwJ582Ishnxpd
SRyB54dC701w66D/geOQZULC5Yu658icegzetJq5kU0i5MM8em9qD3amUtfe
IUUI063JXFHQC15EbowrS4RhzQL3qiN8/FGZrPhbX4yxOSpWGw250BuXXBrc
Q2CxY/etE34DoDr5nis6LESaTqPFsoNczLbuCf0YKQFh7CORL+NjTePXdrtp
IW5JVf7yZ9Tg7WaVh+1Knk5umjcD/dvh0D/kl+UgQalgTlZ68xBSBBT7iRAB
3s8r3FH/sw6EdWfejsskiGRXc1ZJP/IjA9PGfxeibqbq0okiBgJPLuqhuMnQ
Mtrx1MKNi6M+TtQhLwIaBw7Hhmt2Yznv2VWrKgLFlsErH/ynE+FPf0RdD1D+
18UND45E9mBNoSh6MF0E/hamoe27JoQnRq+jCqWgyVNqyhy6YKr4GTNQJUFL
/MfM3zQ7Mb66eK67nRTWwaciL1Z1YCfTT9g3RwINh21RQS/70G62fm2JrhCu
AW1GGSeaIO/LUwmyIVGna/TNq5aNfoWZHY8nwZbT52b9Wc/D3jM2l4R9Inyd
2ZdpLe7A+dyZIg22BCYD+2n3QwbgVBFUwLMVIPAzq0xh2o1Bkd6b6s8E+JVJ
EyUBPNiYHhlbKReC5TEjd27lY3f6mvXnbiv5eIxfiHtYg8lpMW1fLInk95LH
3Sfewfj+sLDaToRRk7jCTBM2FvvcKJF9lyJt7A7N5mwdYpj8iuhFJB4F5nCC
LN8gyvTt3fB8ZT5e5NUKMxlYaJrumGAvw4K29M1sPhuikLmtxqpS2BXSbj/K
4SJfvdC+rk8CgYTZnxvdjI30a4PDCVIkrtqucr61A4t97e1u0gl86j3muH7L
fTCsjvX8lyvDpg1WofQDdXD09JoUxJGgtN7s2rD4PgYPCF4Z9sjAsOik27U9
QU1heNmdWBn4vral2/Y9gZS1tnFjmAyZZ3NC07j9UHmSrGZ+VoCWeVnzU+rz
oboxCfr1Mmh82/xLbmwvXHac0tK/QUA32DGkfMkgFPRH4QnJIuTnbGCld98D
dYTi4dklA6HVfHhah43Yc9p10VpSaHhupmfvq4Pt3l2vRGYkvhel+Dl+LwXX
L95+QYgMFAOn4wdsL0Mjz8CjbLYc44lLZddv83BOUzfq1FsxFBUKfr0vF+dj
nH7UHiLAOF2xJp5diw46PdfeikRMu06vcW0DHrgwOYWnSEzvjtzafagJm2mc
7cWkFGVlg6UHFwxi9IH3JuYmEVrUVOoKvRjwy5LmXLORIZWmFuQh6YKi25VB
NZJC3XKug8qbbuzQMXrFiRNju3PiZe34Nqjba7PLr0lxq/II90jBHSjs9H5Z
IpLhk9am0xp/P0Xn/kDmxFql/4u9O43NeXg/Ovu6M0UEWsZXjZFsFjrTfkzu
NyZxtMOg4oZJH/SXJVhaUIRoN58ed5vVDX/Gmbtb9cTo16k5U+vBQaJ1NlXf
n8Bk5NShiS/vsNDEf6SREOIMM9RlnMWBQ6z74iV3JZj9Ne5qE6Hk8y2rpWNI
jOJZNduqu57ByG5XVSOHBD8pcPmKuAx0KiI8p0ZleDoROlKu3I/3Ouza2tdC
XHG4fTrsBQdb0zctJxokoOSfv1qOXDRFTI5+eS4DyyvaJ8G5CQatmat1tEmc
5LwcWd3Jh545a0/EexGo7vIGxpxWVI9NiqWEFBuzmDSNl+/AT7vVGZxH4DtT
z0y/sg1ng1c8pttIECpY7/kzsRnzFu3mm/RLELKllPrJ+gp4SWPHP6rIQadw
JoQlPNwlClp+U95rXWoxoy2sAuLjeiM3lPkZ28IanIzvhD5Td3ppjgR1Ot5R
+ivZYLdfiUiZkmLu3gL1aEozThp8ML74QgpVRkaQZruy38ys0hZ1iJFfZMvw
OfQYARfUb02ckkHb1UMRsp+Hgw7ef33wEWG3c2TpatdakOVtVwUFJGosTFix
dB5Glz1LrB0SIj/raoNabA3C/jn0+04Gif8BzffUqg==
       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lWkbPjH5TlQfpWjTyITQaDRElutYElNJWRIKLfYtRCqytCiylLFE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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHc8lf0fxo8nIzOJQpIyiiSVjJLLbKEf6kFpCAmpKEpJWkZIKqMoKTOV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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41AkbhuVQCpN0Uq1tlUpsJ1ms01Nmt9jCJHw5hERpyWFymCSqZZFI
ilDRtiXpIDWichqKMY1pjGGk1jQln99B0qcUYuf7473ef9/red77NgyMcAtW
VVFR4Sjn/1vXpvkD4V4PUrLsQRebRNAKQ5ZqRhMqBGot0edJ3Nu+10Cm6AYt
YYkK62h8DHnvfeyTGDMGosofelBwqWjbqzEshvN9V9ON1RRCjM7ZFsQ1IaB8
r++idBJXXQ9Wv2y/jdqkW0nJLQTetm3X/sX0KQp5VlK7PBIBvFNz4nSzEe5Z
yOA7EYiM7zuul1IDzQkNtX4mieiaxxFkmhTSrIrUtYdoiNMuN0tjxYgPN7K9
8ZmEdd/Cw/fCHiKSEzNtx3QSPf9j2kxLlOH7w/dY2ek05maqLx9w6YFkl6v2
wDsaFmnB7EDyGSaGrl6oPkhB0ecXkxjTCbdFk5sOOdHoYgiexLt2YGlIr1ed
FY2GBW+e2WwRwmIme9w6iIK+3p69w6pVsBc2G5uMKe9NrvvRMLsdDnSG5dZv
FMzo4WWDA2IUqV/9XS+OwqZLetfbkpqwbyDGJ+ERCd2NWPsXrxjq9X/8qH2Q
wK4ui7HG3+Rg2w9pFecNwlEm2ix15+P4karLojMk+gzfKx63dyNIkMU1zqVR
MvF+WUFcDU7oOjen/EoiIXakkWv3HK8XyjN/2k+hulkttUGjEz2n/bd0r6BB
SjNf++3pxT0PNuufSzQ0v/Xa13ILYGucXt21m8B3sreFbYN8GHcfmFw0RqJ8
v/9EsLkYLmmjvqv2UXjwvEdb1eEmAlLC64VFBOZJdsY/oVuQVbqE/QuTwjyn
0szRr0KcsWM0v/ibAletrnhdtBRtvpyJkxUU+gZk19xOSsDew40f2UFhVxrj
O1cnGXodNvDdX9AwKhn4NJX+HAr/EbnHSgrHbpdN6Wt1QfjxfoqtNw03Ty+D
mIJOOCZ5Wv5dSOGut+KdvVktbBqHsxPNSfDdHUTMITEiF+97JfxKYfrLIwvK
taRoqFVUFZnTiDxRFpAzuxTvGkbYasUErHI/Tl4OegLOtQhPJx4JlTMZyRZz
gjHa5rHiv8YE+N0q/ec/tCA4cI0Pi0Hhda1aNvtxFahezvHYRSTWf3vnvN+0
GSWv2wN7X5CQ+C+zvJLdihVdWqsN35A4Zh+mf7yoAuZnZ8xeWE0g33BpyIpW
AV4ym8JvzFLyEZuqufLYS3AUU+FagTReB7txU2qKcT0x5eGcKAJdEt9KWZgU
5q3f99+cT8MqM0Y8ChHeLFjHWrqVgsHo8yOLBmVg6Ef/pBNLo/tx6zbZCBd5
Qxt8awgCZpmKoSXVArjw2MtHNClM+rl2j8V14aHGxPU/3Wg8OGU1W22+GDo/
M9VnKnkNfxlx7uC6RswN5QW4hCn/KXy5RrrabYRxA6s2lRHo1vh860qkFHJm
UwqpQsMxlnDjbriLdUknX13kEVg//3gF278T2mOZsYZZNIJMS5nejDrUCrXq
ZywlIRB7sIeLZPDe5izscaXBij96MfDkVbi/mvU5NZnATL688HKAGGJJi7Po
mZKvRq158p1tmPr9P8GqJ5R9v08Mt8itR0n7uL3EXplvIe/d9oRQlEz2rR4w
IRBy4+YnY24TMtKiHN6WkWB7GefouHRj1gHThLpGGvqOZ2OcLR/BV99w5sBC
Zd8s168dA0+hK19rMXhf2Weo4LRqYSUmx4M4X6YI5IUOMmXRrTBs0Yut1KLA
UU8PMzjdhjyOY9Ww8h6WiWL321Qe9Cy8D+w4SeLR/oZRFasXcNAysbuwicZk
9iPb5FApNM/rtjOX0yBES66MnOuBSX5+i/ZnGouNrKM8WVL0zVwny7hL4Yfq
hNvl/jUwkx+hvFaTSJbJTb+8EiAypKSjeC4Fo3/iOlcdeIpuxuiz91dIcEK3
xQePS1C9Zq3mmECZz902/zyfW+jObc/64w4Bx0N9P2zd1oSWraMKg0Mkgh8v
fHTHV4BLpzr6G3dSYBSbv5qx6gkWzzkXu6Zc6d+VHRnqmZcQm2XKMwghwJm8
9vOxyQ4UJS7hKNbTyLeuKis1agJnItXS8YQyr0NDNhe3nMPqPwt85nkQ8A0O
avLs7ITft7n9abuUvO08dV6nTALLedf7L/EopLXox7hvrsSv0VL7qUECuju0
HiZ7SfBBNpFTU0ThgzA0wmFrOzaEjs+uZ1Ngig5bq31W+pg/WFyZT6OI3vM1
RyhDXuMBv+zzNGzv6AYlsHsQdfRiP3/pIByeKiJEIqUf95m/qTVV+iTHR+qU
IUDT6vQk+WIKDVYXvrhfL4BXHGtafCiBy2Y+rcszinDRv9+uNYxA49ttzQkh
QuiU2j3f3UlC3c7O7mxtCZYpRgU2ZwnU+AQ30nEt0F2i/unpbRI5dO59uVE7
dKRRWbucKIjyFH5qgZ0wmciu5NYpfaGezym8wYdlyua9czQo5DI+muls5OOv
zgaL36Yr/VbBGD8akgdrhiUrw5vAvwTc1yA=
       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVGs4lAsXFaWUEJFEksKRFDEpaal0U8cnXWg+OboYFRJJoyg6Q42k1Ekq
lJIzZ0jlMkma3LqiMcyFDDIz7/uOUjjHV5Ry5vuxn72eZ+8fe61nrW21J9Iv
RFNDQ4Oprv/3zMwohsnGavyce8H6t0UUjjWWMI/I6nDNy+wOK56C339+iCv7
6kDZ/J3rk0QhzcutKUFPiD92ZennGJOQhSUVWXyoxU+dxVO9Okns81aGfB8S
4cRSXhyrX461Innp9s/PYbJGdGGxNwnP9JgNslwOHELoTvoZKgTsOrFfFS5D
vX+n+eHLChx5YHrQ20qCk86jlqfsFeAZa/gnRD7G6YRUj3mfKbzq/zr/PvjQ
bApzLgWFednBExYfF6HQpOLisZkEMg8NcmXHmqF/e3LE1tVK1E99FG13QoiJ
syWlTj4EWmPjypJHquEzn20/JZ1C+KoHF8yzn8OlM0+79ROJ9wlXQ+N3lyM5
SjJ/qoEKwQWMUfn3u3AQvGywOafCe0mdQUnWA0R+Oa/lN0uFbK/cYNv3TbBj
3lp94BaBNmH+6S0B7ci2ZdFHVHJojMT1h8a3g7bJW9NpogL7medI8ZRaCCJX
asgcKQTsL/tloV8e6rOvHw4uVYHn6T3nXrYEN+njBwIT5chu9zC3N2sAs3fU
dZUjgfddahR0EV8ciz7ZDakQ/m52WCAlRXeh5sNbHAXaXO63Hmssgyxobm+Z
lALTEt2N+VUo7KvhnvehEDuSnnu9V4BP68jYOToEmDlum08uaUYLzZ2bNKxE
fIzl0bLJ9ThdW/5PRCgJ3V0FMecDXmBnaNAbVycSwzq1dR2BYpiknvNu91OA
6XpW6vqrCFqqOe7sL3JMX9b72LpDjCk3VnmW9vQgtpE+07ZUiuPBcs6ymh4M
P4m23/zXa1hu+PDqGYdAAFn7eYOrEOlFEbNN25Xwp0mzB/lNGCNvW/RtIWCz
vN63g16DUwhkdY+jwFbq+Nt/EoE/0E1vpan52rxYXlLyBL4/4z48Y1LIiOMm
PpI3wmBvn/0DOonEI1z+8iA6Bs0kg6ctekFztnThVvFB5vYbLbtOYREv4Ga2
rAGObJbx0TQC1Uky3TyGCEXSqhI/sRLtK1pyIgeEMLfXdtr8VoFjhvGsHeZC
6Kw1Eth9UCBYJezR50rg/YUx56VKia7HuhUHeRK4PL3cxVbPTU+kuKUZVMLC
9OV/S2MoXHM19E3d3olXK2PDrpqp/bDSXfdjWDUG3urXJAVS8J1ZrpfDkcIx
PSA1ebAHR5cepqbNUuvnadBps1COxAWWca/chVAMecrvzFaistbVaI1xK7Q9
2vW2rFYgfKLbMIOqQZBT8cs+LQpzv+2RP09vBae05pech+r7juukXdnWAta9
5RkzbiugMS7g+p3cnUgZ0v+4V62PHam3b2fAQ8Rru1eG71EhpmNJ6rjKBixp
PqfF30hiR8pkqWZpE16Z7t62dRoJiwVDa116umG707/r7iQF3NbHXoueKkBC
LxUaZkCi6ovsDP+eCDGHeaY/ggh4eEvCzU42I9M/gkHfo0RF96Wuq0Wvscbe
xmo6k4DR7kBPh7oyuFf1jjGdVMhnXdmmaShGYVJxcsIKAhsOeGxX7itH8Vcd
smquCr7SnDOvU/LRwWjZoMhRYdINXmYF7y2mr55XFaHe51DWWU0mfyJy6UGD
lXkqbJ9O0iLzpThvFPhy4gQ5Nt34FtF0sxE/Bum6QbkENl/04WaMvYBWxrre
N1wC5gto7DMr36BwnE3j8T0k6ufvfl//uBIxC8UD97spJF/r1lpDa8HfO8yW
TH6mhHnAhdpV/7yA79ecd5yLJC7Kvnsf4jXBaFpUM8eIwBvzWM21pxoQXxfi
wPAn0OdB7NgSLcBxU7JC9wkBE8663z6W1yBvXYNV5g4K/g46TxNtq1F9UDR5
N59CsJ5FzX1DIVYYC89MsFViqOPsLsliMWJjYr4bqf1Z8ZHf0BX1EBn8fv53
KxVYi2dd+l2jFr6NnBFDdwqMhV85ZkvEyKoa6Rv/qxz7g7s6C7SrIUrT57rb
UshModLzvrbhUUsNa2SRAom+JjcjygWYZNX2UNJPIGR7FclOEINWbDGjfQIB
B0dDhnygHQYDKOEvV+eRPiSoUEgwXn+hzLlRgcus2eHtvOfYKxgkvo2RcDhU
MJ9mXYFNww2dQTcpbJx0JarXSwT2vClXo9lKxAqyxRZjbagdORuaelIOWj7n
f5nWHbj9u9M9doUcZcHbBCusWjGx+5J2g7MCflX6IW+cJfjjxIwU9iY5jD9E
jRb6iXD4lkdEkjmBbdNujw4bNWEoh9dWU6KEy72fhtOfi0HxXdpa/dX/Sl6g
HWbfjNHHjcsaigjEj7N+Z9YphPP91B5+EoF8vfXzEouFKOBy+V1qPtXjC7ce
KCqAjnbU1IO5KtAyAjk+WW3YmxFhxxArkKVRv8p+Zh14J0cXrSkm8Tb69fW7
uk8R65E8Z30RBQO36Kuj8i7kzjLNYkvl+Bd3O8ch
       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lekfxmlijL0oMkaoUdmitNi6T0oTyTbWaIikMKGkM9WUJTJnzJQG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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VG8bRmXPVraslSRJqKSim0glihKSkCQtlkRJJUlalEIhSSKFIhLZ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs4lOkfxtGJQrW1GkpNOuyGsLEjkjunaLOEWoefSkUH6XIIxbJasTtR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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk3s41AkXxyVCSmxoN7RJIlEpucV+kVZvpBBZKvK6rIwi2lzjQS6VbKWI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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lPkfF5Zsa1KrrWRTjhLpdlbecuRa0UGJWkdZOTYZhUJGB1NoHNnJ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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3kglN0fxZFspYQ2Uray5lUJCYdSaZdCZWmhIiohiRcVZV680kulUlmL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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41Wkbxy1RpoVUZF8qUWpoCknnyyRcbQbRThxRURSa8zYcsqsGpXTG
nAyRJSejEIOkRNZjOceuUC/5Led1QuVNzby/94/nuv94ruu+n+t7f77fx8An
yPWUnIyMDIc5/69Vcy0p8j2tsM7oe9phSEHm4/R93/HX0F18hHLVkqB/Quia
NVuG4jTrcr0pApdXlPvYh3RD2DAS1PeFwmmD7KE3nrWw5xsFyziSEBSftV2x
5yZsrD7RR/cT+FpXcO7zf8SYu17m7VxMIeLqlkHVn9vxwZd/WOFHClLrGHqf
4jNI47efOOtHojJqyE5N3AZdc6XvR36mMLBScMPE5QWM/VmFG/NIsJS5B6ZS
X8PgUEKhxEMCK8+vqdNqVTjgt39hlxIJH5FqfmLLIIZzuUf4d2mE58pFZVrV
YCo6xIgvS0LqGqqZcLIZF5RMLuktp5D2aXRpVlYrkkPnG9NlKBRb3M1SsR+G
5tfxnS6yEjSlhhZPfqtF6WaVQXcWiRLJgYjf0nNgql9uyYkiUP9+VvlYfysW
cNisk26MfoK45wEV8bB4+pXrYEug7E1wzfERMY6/fft70zgFB/veqNDsDghi
xHpnbCmMz7/SWKA6gNBYbohNJI37J3RZi8bacO7DA1d/HQovVzkKSz3qYRRU
WDp2htHH763Noc8t4ASz/2qcJVFsxbkiNOuE+thWOW4cBY78Sk1BdDW0uzyb
p81JrM14ZLkhrgeBseVxIhkaxk819v5jXgk2m8/P+y+B4O6L3ADXfKRz6tLK
Mwjov9PeWpuQB7cgo23Btwj8VKq/I7knB55NuZ9ykwhwCFP7Z8vroGJnqEk7
kbApetiw828h0ilF8qwLhf52yVi4bh0sfVLatnBIWKssb7OrFaGT5aidSDL3
ScHrt0x04J39Y7FJDIU8tz1ckK/BV/W8prCIRrD83LwOVYmrRssUvfVJZBeY
+mg0tsL/n+ZPPkYU6k4li3nqAvB++WP8VQEB4d4jFUZVfejQZSsWN9NYPb8m
8KJpPWYMzdlymSSMLY/99WdIJyq959uLEinYhmQQYf3XwZL/rsxhN4FRQnxV
0dcZbE+X5UlrCageMvPWGhMhvigk01SOxuR01juvY3Uw7tLScmb41tfXNlRc
koM6O/+h7hgCjce2GfjHCOEhjexjOVOYVY398xrDk7nqWpZmG4lbK/U1zSbq
sEv3h1sL95NY4j5978xiPszlnlwI8iPQJpKWeH//AmwNi/O5AhKcCwrbD65o
Bkd1a0DvODPP+mPqUFIevKfmb6cnM/7THndI31iDez9qLesxYfrt8Prs0F+N
Gj9W05alJPojzHXOS0uhsu6tf1IvAV/73xaqpTD+O2abMDVIIfyhhY6c8TAq
7DeePWkswT69JU/DyoW4bvToW84UibLqHue/HwzgzE9BLSq5NMY0NopKed2Q
XjTiRT6i8M1hVp+7aQBWso/ir5jSeGny3QXx7VZMNt6/IdWmUHCqbVQ97Dk8
S4YMQ/9FQoYbvZt3ZQg+Bbe6s1wk2HnPyWMurh+aq0baHmfQ2DM4sj4jmXmf
cOnrV+Y0UnWGJftvDKLfVu2XFAUJAoP2ZnbymhFrcd+y8gsJlbyHyrs/F4GX
8s1pXS4BG98g7fe9rXB/Iz8Ua0KBN12XNhn7HPETI/EZASQKZnLlbusUotfr
SFR1DoHEq+np/3buRwzr3Ja14TSkE6/YyubdSLbmavX+SsEmlPV4u6QSwshZ
x8YlDN+T7+NKVZ9BeUE3u9iTxOi0UsKdWQGOXn/xxLeEwBdy5qZBAuNvN6rL
WYXGaEBY4eawmyiOa++OdWb2K/PtkkgogsAl8aNhA4UHaTz9GdsBDDqYeR1N
pxFh4XDqyvEhPDd1X/dRi4bT3kqRBq8e7zabhR3mMnlqd/h+/txLHLYbavJn
8i9+PfmSdbIbPuFVzYI2Jm8m0sI9I5KQxa3ZN25HIPNEQ5Fs/BAczr/f5DLM
6KnZ4Ve4IxeZ6pHJjdGMX+4iWTz2AofvGD99EEmiySoppiOwFfE6hnc/D5Pg
invWRXj1Y8Svyzx8FaMPOVlzo1mEEDsdFhs0PpjN78p364HBUv/J/DMUPPmB
q4P4PeCpi9escaOxIVF7ZtpDBF6Y1Ei6nEZLlp5MZHY3zm8wulO1kkbt4hsK
MZteQzNqfKEuR4KSmn3ZNg41CCzJWeS1jtmXheF0Ebce/B8m1GQjSJw39XNc
MPUc3fWW1bpHGJ76nNqFklaQFSsXbfpEIvAh115wUAQ1rnu0mMnXPxxye5yz
X0Ko58E5KSJR4Rx79ZJxA27Kvq13dScRIBv05JpeJ3pzli2ruEbh8qptzRtW
9GH1hNzF5p005BpSnjhG9yFYocnSZYDGaS4nUWtTAVI3q3uFM/kY1Xaw4FHN
r1C67N5X40Sg5HeDrp78FsxMupVVLaQwt33XWF9tO9ret56tP8rwVD16a+J2
J04v7dKqY/6/nvQO06nOcqxKklcKJAn8Dyu/xWk=
       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVHs41Akbna5ySWpVU0mUJMIqRZev0xYipRCpaZeQSDXablPIdaVS26jV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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs8lFkfl5Yt1eYNpY1CGqWNIZeuvpToolLYZEsokUaElHaXidyNptza
zbIl5VIZVkjjNkwuDQ3DYiQtvXRQub1JoffsH8/n+Tyf3/M553yvR9PN57C7
rIyMTDJ9/n2zda7Fhg2not0truXFaoION0bzCv8y/BC+INvVgEDG6c0tqw8C
JButi125lcAoJ7VNNT4Td3vjs+avIfjdK2HZjkohXq/n/Ye3i2DX2gjfZzdE
eL3uQJ/NToKc7FSGPaMFIxUKCaJTBJV+0+F9NQ1YvSfnt+WOBLZnJZkOjYVY
olJ9UFafzi2U0lWNyzDYGq7Ts5HAa/l7vXcHJXi09MpCXycCzwGT944ladiS
lb/kf/S8gzktPcOvGrC8tUaznc6bWpaNNah3QXrjXY55NF1vsupLWG84ZpsK
rB21CLiSoHnD2gKk5R5/r25KkLq1+XmDZQt6N8YLzUMIek8u0lHzaobZqMfR
qyyKl8f5vj9EABtBrejIJoJTh24sOB1ej27u15T2HQSv644/6y/LxJD/sdkB
yofM5lWj/PhS5Bzds+M6xcNOPXPEpq0Cmfw1ujHbKN6pd4bvj2Thz1zXZUcY
BC4Hgo/7MKpQ8sHp6RjFKxNRl6XYfxgRVQ6uXzUJAlr9ltptrUPe4splJ8z+
xedcVztHgu4konIpkoDpFD1Yc6cafTcZ3cfMCeoeRsq9MPgbcqu0hI33Kb5r
+c/19jaDOaaRZ+dBUMB+MPF5mwROSz3F3d4EPy6URnHTy7Fs4rjqkDEBf0nu
M8+BRoiWaO/uOUPA6U32/zG4E3zGb33yUQSbFNcwVngLwJA5FTtI9X3QRTqz
SgUYsw79JEv5MZcdzeAEiTF8WPjmhD1BOJc7q9JfhJnlLJt0QwINpo+FQCcJ
8fe/FxpT/VgSUfa+4hqM7frWgFB/LamM7ecPtMFE/9DROWkE7pWbX+PVCwyr
p7toHCJwjLpz76mVGPMs2eYrfCifOVqVeWfuY668w6kTlM9PRTWLBzPKYDlT
enLjZoIbX+Z7xu0ph8H+YnYJ3V8xZiejiNuEeSO5RaOeBHGunHK3tHoUHp+8
c+sAwUSY69dtPwkwK3uQVU/x/ak99MHRogOh5znSGB5BYuPSnwcmn0M3o/7O
JPVbgNVZ7a2RXbjg7xoXWUVgbxGhuoL7DI52Yba+e+h6Hb0xq7d0YGfO4+ze
S3Ru3yi6VN0Al7em/flHCSJ0PrR0jTSD9XFU1O1F/fAXZ9qv5gW2t8YsfXOQ
IEtTNJ//sgganzhsbyYBY3srk/VzM9Lyu143BFA+n3i751uXw34q45w59Rdf
rvRSinc9/LhfEziUf71/uJ+u2RbBxVb+L3U9AlGA7Hn2bD1EVRfloqlfVFVX
lrboZaHcNOT2P5S/0PHsvcotEgxGJk4PnSSoubwy3zanBbzt7zIs2bQfIhs9
OTNNSHN8b7KP4q++opF8IakKXIPDYh3q31MPR+8b99RAt9jS6AdrAh65yNTV
eoCY4c1PVtH1JfIbmp4rVkPhofvv77cQvOl4FxzMacaxeucv1rY0z2/3TnUy
xNgSvHB8E91fw2e8wLX/GkI2RnS20fyOrrjo9qizGuyiTUkXaf7amaeTvlkr
QcwfIUPpv9A83k/1sNd7Av71g5eVaP6U/SQnyqoFeHP7hG+1Bc2XR7apP9KQ
nVlw8qM2gc3aV3eVvStRM1eZM0z9/8uHb3UmVtSh9oxw//RhgjVHx2aHXJqQ
2xt9r2039evdkXXZYQ3Q7U2w5tFvTw9zcdDUTSQqmK1Ko34e3lP7NG23FCk+
DfYDxZSPwUfLnxa04oH9hvwNcVQftfjUr0qV4LksWKdE/Tii8Sc7Va0Lbifb
vJ2v035iX2jUGilBjmnB1CaqF3Nx5fawmWIovpD9W0r/j3lQedfvoRhe1sGF
4Q4EHgkxfgdrO6E3ebpgLI/2sc7NMT/nZoQohkptL1P/Rnx3bI5qApR/5/XM
Uv54oQeyZ16W4rs5jTvcaL+/Ua6fShFUQEHBZaMGxZ9Yoja+JaYd5ZaZG87R
/mTV9a49kCYE69Z42zNLiqdyw652/RYEReX/vOgKQZRpkmXiUC3URV+uqFG+
HBu81QZWdaLTY/4FXiHtB/WrKR6JxbjZfoP1eR1Bicevb03MypCkMjHhT/Xh
xo/GHit+jPiVAcZvdel5bzjbLP18D7KBOS8jaJ/6qmS8lT4UgVlapMt0J5DW
pY9GsyWwl8vNd6b5EddbftzUlYR+tzwVL8r/+fU2yRPBUpirpNnVFBD4a/mY
te8TQ2G/v7vAmfrDEprfGEbjSe5CXjrlY79aaM8Bdgcq89okURwCE0PmeGyE
BMIvRh6E9p/M8UUBXREVKBnYsHcHzVemnbYPr6oRp0JL+Ym0j4Ssi8E9xlww
rT3nqtP9p/km5/Jkpbh9y8J3hvbvSPoax5BbfGyZ/IUfS/ULUD82LR/diqRd
CRcVkgl6zjTYWA+JkZWjmfgH5U9sZbZk/plGaG+WkVe3IZjcZcBSV2pGgdLk
9dOBBGarH3rKsirwkRNY1UvztrtTtu96Zi2Sbp8W9dM821o+/vr8SjdE8vv+
OldGoMJaoKkWXQrhPrZX4XrKr7vFdL6XEFkv7uSl7af39cdxweZGKc73BRpE
UT3jIlvlb0+3oSLIYKKT+vU3/Z+mn4YJse3J9vGZvTSP3zmUaZvchVzE9Pd8
qs/bqad+Ktcf42xhkOEs1VfxrJOJlaEQonK1sn20/37N6PcLov4/rBpvN5/2
W+sidTUjaTfk7FbKcIbofoHO2/ZekUL+6n1lnxICN0zpt/7wN4rWR0oiqd5i
Rsqa2EAR5uVebaig/azfoNX/35QOOIqTGcI/6Hydw7lH2yV47LPaiH+WwEpU
rtSRJIbqjzvUuvwIbtae6+B6tSGpKeVsKdXXPq4w+fKtJnwyDREO076Rec2T
LLDOwGUXJ5942gez97YyrYWt0Dc2HHOg+vh2HSIjc/kQnQ4LH6Z5+WRV09dJ
BKj5qPOgjd4PLUaBG8+PS8AKDrjcRfvxQpmw5ohjO3Z+tnMLpf38f8hdxnc=

       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k0VW0fJSpFmqSSFFESUWSotGVKRJHCW4akSZShQaVCZZ5FvUiUCOE1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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81PsaxycRaRM6behUikqIQutnIqFTQkp1XtdJGWlSiRzqproSmhzM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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs81IkaxgfZhhQ6VEfkktun1cV20aZ6kFWuRbJIckkiVhNOxHRBWeEk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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs41GkbnuXb6KCirkk2KjZNsnKoVsXcaiSVSpTIITm0VlZymE8RyQiF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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c81f0bxoWMspoaUlQoiqcyKnWRlCIhyoMyMisjoyhKisoKKcIvSgPJ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41QkXlmSMUFGZFNFeKI2i0nhtbZq03Uo3YYg7thBF4suIMsp2JzN8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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVHk41IsaHnNKQirK2u1OUTxRHFFZ6rWkVQyVZMkhS50jpc2cGoo2lNCC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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4VekbPenEDJkxRoh+yCW5VChSmRaRUR3XOpp0V45rLkWKNEedFErK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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4lGsfRkiiRFmzVLYi0iJF7sKpFLIfaUOUPakkp4WSIiFbQkVJSXzZ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81GsbxkcJh0Q1ee1LyrG0SNJy1MVRjFKKc6IoGk22SF4lS5020sFg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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk41AsXxyVZQrdcT8iSkXu1XI3qhpbbV5eKbqls9ZBiohoisqTervCm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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk81Okfn9WPnytFRVJtIqsJG9oalLdQIaVjKulUSOWKWkdlUFZkqFVu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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2kglGsbFqXSORJZkiShTSVJqOOS0CYJ4UTSIVREJW1IlkJpQRIqW5Rs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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs41AkXx+VSltKuWuk+LhWivCpS6svo7bIkhLKlhkhtKsktbWqRTYkk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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk41Isax0VJZI1GUZajsidFdaKvtB8tWuiGkpGyZClKRLYzkWurY5hu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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs0lGkcnlTSHkkmUilFoiSTLVKmh6KIRUTEtoS2iyki17aUmkEuEyep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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8VWsbxlE6pQxJAxlTlKlJqORykKGkkhTpJJUmiQZjCcmclAgZM4+l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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81QkXxildu5SlUHoTDbJrhmwP6vVSpJHUSEabELoZM6UmpE2LvQhZ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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41AsXx4dQ7lvSptLEUImyhaJe+Y4suUioq1KELKWUvJrGRUqKFnuX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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVmk4lVsYPVKhNHBVGoRCp0JCyLQOuYokcYkiNNIgoUTHSRpMDSKcUuRm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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k4lG0UplQqIW2KRCGFTFmS1K2SVMqSbJUUKkokSnZZSkn4WilJEors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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk01YsWx/GQkBQq0TVEV4YMlSfTF42oVxcNwumkFClNnItMkToNuqYK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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlH041IkWx11SUivTi7rlulaUSjcyN2T5jpJEtSVsUd5aare9uOUtVGYk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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk41VkYJsskTdFiyUiFiOKKsky8dpUlLVqobCkZKUyRjG6GmmTJEkpK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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8le0b13jVG0laSKG8kYTGa6YvmQ1eJKmQUVpEVkIaIkkSMgpJdpIK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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlWs4lIkbxhEl24pllxSJ6bRJ0iQbuZVd1CoSKkVEaE3FpoOUv1KymlpS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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGs81IkaxyXlUimVJboo5ZLLKrQzYX8JpTGh2S50kSwdFZVdIjllShYr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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lVsX1lEdokEj1b2iQkTqqgw3D5WhPhGfIVEKyZSIOKlEUhJRJFFu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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8le8bx6WFikppUaKMkiSVlY9QKUSS0RAaRCKhYaRIRVnF14pC0UJW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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41AsXZkxS9yI3W2lRTW5UkpJC3qkoSpKQInXVSF+ihxYUXVHhk8oS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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGs0lIkDxhE1XVT6/7u4lIRSjS4UauWRWEpb2GojVmzkFtKutEkc1qUL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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8ldkbN0khTSotSNaQJJUtyVdXSQbXqCvlRwkliUYYZV9+0iaRm0pI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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3dYTX8Dj4ZEg0ihXUJJRKXwCUmoJEnSUmhpGSEhaamkpSWVFG3RkOSn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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs41GkbxydpEh201KKEUNOuonMU3xSRWkmSLb2hbCSHYpcmnaaDiOjg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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGs41Akbxh26nNvVyaHNhCaVECovkttWDhXpzaFspXKxSSpkhUWkJBu9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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk41Gsbx+WVSjmUojoldLJkCeEoyzdJaTk6DTIpS6QRUYmyFV0iIjol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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8ld8ft/JVUZIoK0nZQpFS3pIUKQ0ZJbQloWVlFJJESRFFVEKRrZAy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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs41NsariEkHUWFilxiV4SoRLVfodJzkFs2oqRiKGJ3VZwh9s7t2TWU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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk01IsDxccvhCQV78n2SnilsVVahDtKZVBJ6JW19RSZFKkYvUhe+dnC
SySvvBjVI1G2JJqMdWTMWLJltu98W+RFyVL6ze+Pe+5f99xzPufcu+zgSY8j
/6FQKOfk+r9nmGSu+xrcAb/dAZ9rv0qRlsx0f5wqQBunbPFXUzEmz659d7qo
De3DhXUDYxJ4lkwtmOluwGTEknlR1gQ8rFzDyjzrEMRb1LeeKsPOMWdDsqUK
Jd9pxnrjMrh/1DN4msFH1I9Fm20YYnz5YOVkvIOPGzZuUTfvisH3WWqh+w8f
SVKz2YF3ErQLzWLrHxViEJoxVTdJkGqTL2dYJXDgjG/U8SHh9tBEJ8yXD7fL
z49p+0nR9oVYu0nYi/gEpnaDjhBMx58jy8/z8fi92YzqNjFcbnQqNTJbEWhR
1ZXtRSDuxX81/4qog7/F4V9vBcrAqdcyWN1VAIp+CmM6ncTh0d81E+K4WJi3
S8nfXIpAD/6CHR84KE/2fJtwkQBbddYwe2M9Tpu75WupyvCI9elU2UoekiPf
h9BzpVBhtWu8lvPjnEywnXgmQuX2J9yFFRysnhicJrRlSPE9WRCwTYD5Ix0r
+XclCM22uGAZ0A1Nl7Rll2NFeBWXein/WC/+Cf9tHuuoEH16jDk9SgMwbf51
vPqsCCv81y/LKulFRZfpvoPrxKBSi9W9NDhYu2rxwWgxgeLicg/126/xtF6f
xlggxPcHAh7BaYOtxtz3y48QyBHMGEwpPUJEsZva3+dJqELQvmvfS1Tc1/Mb
DCeQQj5uXxDUBdOmX7hZTAmavDUnMp0qkSsaPX5yVoZQ/dT122/VosPN6N79
HhkmtWts2uhsiLwu1CWVE6DetvPZotuCvOX0gtPFUmzV8Fd/WMqHEqMig7wu
gWDRLW0fiyaYTNj1K/KlcLda6LiUwodnv/+oS4MYcVRukv35V/C49u8Q75yc
Z85286ArNRgO2BPvTJfBWt003M2+BRTOE4VjZQR0lM0OuK54giSHDfPsl5Lw
9G8N3LOqDTd684KaXQmYBua7jk6144EnY/bFPgKpj9hSd8dXIPR7aOH5Ugwc
WPJdymTDtMDaOSiLAG3WaOFYTil+aneYXrWKxCTj483+B43oDAj945wJgW2V
/ZfWafSj7/XMoIb5MO56KZLVtDwYpt41dqkncf+QfRw9pQOp8R5KF0gpeOUH
yqaZAwhVbqicdBVCMcljv8DgKfiv00YHwmRI3ZkjeNjfixVjoqRd8ULQ9H7P
v1yQAicTlcdfJ0icEiU+SyoVINjZx5inKcHYC7WQrdc68XCrSuafjWLYUuG0
U/wc7h+s3LanypDZGjuyOHIAxWv+vO3jIIKOrs+4Nq0Bs3UxHw7UESgsU7Re
s+YeCPuPdUN/kXK+RWKtlscQaU74eiuTCHf8XUdx5DkkpdeTz5jKUOdypPnf
9Ae4LrjjfItBIm7Qoby7hYNhsy9+JzcRMGi5vUUt5DVO0H5Z5bREDKblfMt9
nu0QL36S0SmQosR4eqN9xG20/nz6bnUziSvqIYfnGXUg0tNnJEyJgJZCs/Zv
H2qw0yGtzStRBi32Hb+6jVys9q+yLHsqz4cqPLcweghrfubXQHl/3TPFwtbg
RNDPr1Hr+ULipZV+a9quJjSe3jxU+5HAZu1NLKKeB+Pn0Xs5WhLsjy0spLfw
UKWtdLZzSgwnl8EIk3gudFU61tnclKL383X23jMdMPfL2J78RAKrlPcndl/n
gpHgnsu1JzDjNdh1NaYXiYKE4OoMIeiquZfEOU0YLd8/P2wBAau+6Zno2FdQ
oJWkzw2XQNPIl738WQOOvdm9/8wyGS5uG/Xdxq5A1Ju1/UffybA5z/BQ1aVu
SCw3sELkeyisrc7bLWrEalf63HtSKdRuaRw9MdKLH35zrqbL91+ymGWzJ7cS
dlFdW9UkMuQpSSPL29noMyyzitsrQ2Bhutvc6lQ0fYn8o2iUxNFP9IHpQwMI
u3HVonT3MCgGjjd+5BZAS3tSqBpLotVO4RBzuA+sK/dyHsWJkR0jNA/V56Kh
Y8nQBksCoTt+RHQqt8Exv3QqTM6fFXAnKKK1B3rDLVSdZAkohvY18+T/S0sN
VuhzEePKDr0VPG4PXrl/qqfai+HgwOpcvrAHdi/U5xTbilBjazJI0WDDyXey
kzZIwLtLVzKqxwMjhWVdskgC6tBx/lOnbixzCGqsoIngXECNUW19iWKK8ado
ZRmYIVk2W851Yn6UQK9WJEZ1kZkj/OpBGfKlSrxl+Ol4WgO+8SH2YaSPr5fC
dqr7ckdQB7RU8qYFkRIInZSKYr69xGwmPVrFWIbEYO9m6pse9HXXjzyT9w+H
69aM216DWgz9o/E4iYuab/WzfLvQXxs3XuInwVI7yoUzqy9BJz5rXEf5LUz/
5lJIdi9cVS9nn2EKMUzVZPKyy1Cp56ZQ9FmGb2unCsssubj5+bu595gU1GCj
xJUG3SiOvnJ4XbcQK2za+TaZ3cjntfWfshDjf7N4weI=
       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVWk4lVsYlXTT7OJeKuGa0mCIMkUrGpCpkMyVMpWiiSiZKdwyEwkliZIy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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VWsbxsmQkFDklBxKpVJJZnJrlohwpEIRIXEqZEqEJGToREKSJmkb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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk4lAsXn6TuID63m6XF0PLdNOSWZIt+lqTHTYnStSWllbJUN0qyFN+t
RFKfiha3pJhCXUYxmDtMtmaGGctMnrIk874vTZcsU/jm++M85znPc84f5/yW
s3RfhPcBNRqNFqOK/2dapNV9pXQRfrz9JM51mRxbfS5n6s1pR+buvo6daRQC
I92s7TP48LLZTY9vJJCRFFReo3iGecrnVvsr5OBJlcbaX9vhIDBpZtZS2Ls4
4swh3kvQjfjO5hI5OlIGbM/IhLBMZv+y7hwJ/ZYXVfR3ndDa9cNCaRaF5MIA
lkOFDEuqZTucuRT2ubfZrghsxUl+ddTzYhKRxRUWTRebsGqjh273dwKcBzf6
Us3ESNQvNmBNkhBxwxs/TXTD7lT4zMVtFAoKEl40JTaj+OObcm0/Eu+8vL6p
y3k46jmUP51EwKiI4HqzhQgz1el94kgiIzRu9PsEG2Us8WTEFzkmBA2HL+WW
QWZts6NKjcDeywK7Pal3cfuDccOqSDkSfA23FK3PRHw/qRXrJYcHDR/42nUw
8qO/PcoikGOs9+7bgib0f74YrD5NIEbd/UF1dDXmK46PGm8gcJ+bcdbILBMn
fljH3egjR2/VZFORZQtupwfmWvmQKO7am9e1uhVLDHXstSUkHA9eizV4y4em
7SPrPQ8J+F8bef/ssQht0a0hxAcSCatzFxSO30Dyz86TDH85arzWDgz/0YzZ
lo2LXZkk8vpr55z7TYjDY/HqM0dImHILFQcW8sBNCxmfKSGQp2e+xbymDv2J
ouby6wQmPK8MNHxtwnDSavtUAxKBHZNRYzli2IVPGKuZU7AWVzL/9UKFl9kQ
N/4YBXpHyZ0VTWW4F3qze+s/cgyorbvgntCG+G+Dt0RpJGjLP/M3trBB/Lmj
U02dwEP/ygyNV504d/PgJ+kjClmh7UZ3jrbi3+2hI08HSTBALTOGGIMmOpOh
QhL9/slGT8/XQjzzR0PJcwI7LTLXPl0rht+9G4mp9hRG4WIry32Lu5acHeVV
JGpNJxj7AiWQevsFXvmdQs3Sa/krbtWjjO32NZFN4GTF5jPzRthIZ/06Er6M
gCI2g3vYsgOOXxPPXhJTEFO9sicDtRhsmBU9O46A7o9bhj763YcyZkdh1ik5
ZMGCmROMDrza8ymsLJsCW+2Y8KRvCYbDxhm2bXJ82H08vHzNK/zyT2DOIJ3A
95CDhhUpDeD0u2xmqpOoFNypZt0SgWr03pyQQiJF23buFwMhQuOvPnY5TkLq
f/aLXo4IFsM/a8StJOE17mNha/UnZA9Y+81i5WhNfqQjo0nA9HX8VeFEoZoX
3GH4tRRFPKOf/DvkoOdsmh3l1oipsJoq8W+qeZvMuVslbaA/KOU80aQwpzal
9GZZJ6YX7lrLPkiBsMDFgM8i+BDV29MiSBRt99krEnfg+jf7yGVvKOj2Mn3d
FjSA8TqWEasgkJmWuzxkoA1K4VjYFmsKD7ke5E+WneDdajnmJFD164dMnm6v
w/zpmbzkLgJO36smphN4iI5q8QiSEkhqV/gUn+Mi9VpS3/lgAj0G8X/pPe5C
jt7EeY1kCi7Juj1XonnghLMie1R8vDB+gJ186i/Mo71mxkzK4aXp1rbydzbq
896fHdciEO7kYsLwrEdMfah11xsCDw61vO/b2Y36wJLGI9ZDyFo9lzriKsBw
UE82LUq1n4RbKd7Fh+FS3ch3ZiQU3VfWG5qUYP7lclZGsxx7Be5LTFdJsDnw
RUe9BQVGO+Va8boeBWc5ihQhgbGj+p+URbWgffc6ePoIgUvmb9uMG5sRH7G/
TzeBBL3uePXj851Y7nNrRKOOgo2PnkQ3rBajJTe7nH1VfuBQEksOVSHU73RR
gB8Bw7gkfc9ILrKn1hpE3iNQPFJDLdopwtTdSX6hhkof/5FMuWwUgHlG+d98
TxKd0wUVNY4N2B0ksAyikYgzbtLiEa/gfcWG/zeTgHB5K8fS7CHsJM2L/K7K
8XLk9vN3oyK4tLSyS7NIZLOXRjNeV8PqIcm6fkmld9r89BjPUujc1Qh0UfGn
IEuPE5LOgYlgOVtho7pnnDJfq18Iyb6MDrsCEjXXzZ2z2oV4psfabqPiU2f4
LJsslhSX9zOnDm+nMP/vZUcKr0qxLSrIpM92CHHrFwpIpQi+z5I0NOkUlJqb
4tMPSxG7MsUh4K0K7zTm/sEvKj/JmRQ9vaGqXXLyuAFSOBQnTOcrVfyOOhEy
er0b9M+L9fNXDsFqaxmLwWvESV+W+R2VPzk0KSRpH9/A8d5xZnuvSq8rHlcV
nOagMrnZ29RN9S9y17SXuApRdnqDdfBJErPoG17t29kKJ/fhEfuXJISCTMut
8/JQqhXgXpAkh3cNI1i5jY3siMFza3rkiDTr7UkKk6Ho0lgW024IGTUxTq0M
GXTSs8Y8TIdQqa3L/+zRBJ9T8UyvTSTmubulnnnahkND5PoRBwpldQJO9gU+
pu4YHdrAJ6BTpBmRkSeBa9+2FZ16FP4HyMziqw==
       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGs4lAkbx6dIr41EaUsO6wq79OqwpVVb/nIIraXoYJVDlBRRSemgiERF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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekbPqPG2tRpRibCGJXkWMeSRHeWGJJETCKJyTJC2qaUrEn4TbRg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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHc8lf0fxpXKSEZDkkpG8bSoqISLjEhGSCplJEpIkQgPIkkaRmWFR1LK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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs41AkXx+fNbCs2StlKE5Uit5KN4qm+uuwQTe6KkC3lslZhFJJGqVWv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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk3s01AkfxjUKafJGKrUKFZGRaiWUntatV0mbaqhVVCS0uey+uZSysnJr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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk41PkfH5v91ZJdV02r7Doqi5wplHpJqc38cqyjQ86SXLFy5WjVUpat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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8le0bJxKJJOK1UkYkUaRBvkLDyKhQaEpJJSFpmCUqSeXVeK1EUhnJ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk81ekex11LyZbKlqap7EmyVOM2mY9sV4XBSDL3otGiUoyQXGTKkntM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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHlYzIkDxlNU7NoOldSEtkyFJ4TED+8oKbJKutOpDWOQ6NhpEApLd7pT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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lVkclrFExjSJhDTFpJSdEHo1IdmKypLk0qIkMmQbXFokQzRFZUkL
IRGXsnMtISZy7RdRljopU8oyFHPmj+/5nt/zfed3fuc977LO1cvmGC8PD08C
ff5/55XYT1tMJWGOJaRyTZ6gZ+/4l7g9PTDMsSb7HhJIFpdf/1maC+bC2Nhs
A0FaUr7BHKnHHW5t1tY9BMnC93J1OE14H6uUrelM8PLmARJanAr9Y+Zsddqv
/9SD2qh1HTBhzy38ep5g+azzIf8V5fjssHX9W3UCnvQUzXcpHUicf9cscp0g
WsrWXUK0G7/xFahK0P1FlKqFekw4iBq4JntnH8Gd8CsMd+8mcN0EjCsO0jrK
93xUUyMuTPKECu4nCBBJmpcXKsZCf7oeW5nAXi2xukS7FZpjUvGKbgRaL0eO
q+dw0SBgkX0ogcDk9Co5R6VmqLNKJtItCAL1ZFs2Jjeg2WrHX+X69DzLvllM
9VTAJjP9UMw2Op/oB4fO3jYUWAiOnAwisDHnGyjd3g6dp4YOrscJMlglJ35b
bINqgo24mBNBYYjS3HgzB4PNFmXalwi2dDOyd8d34KN1elnqnwSfzkVW7xHr
QwkvK6ajhiAsSWBASa0EW4pEdvbR+a+n+LMX75fByuvR3bjNBEH/WvFtTO2E
QqydhkQiwYd19coOGc+QmzMjdWo7Xf+8tc0ysBpd+ZYiC6D1VZmeOv40+Lq6
xC77laB4oNhOWKoTAh98MjPdCfY2rQ4xzazFGT5HxTdGBIwSRRfmxmrIPpzy
EFcjiHRrkLl0kQ3PErmtVjoEETVjYisl2iA/IaZREUCgEzwZ9z6yCpMtGq/E
NQj0Q18Hypm/xITqpO2PlB88MU7fIp0DkFipc9xgPd3/YZjbQGg7LufVveU7
/3+/7Auz/hzkSl/NC/Yj2EyY7t4FXdCsHdWy8ifo+vy5iN+eg/MWT6ImaP3h
9tKdWm29+CLno/LwFsH3yyu8p491QvbnIGZFPEGHYdzJO2rPkHw9hFljQJD3
dYVe1nwlBhx2z2vS+lNz6IPChVdwuvZ0ldkowZD16WqdqDYovVyS7BpI8DC0
X0jajIvTiumNv4dRPDJyrOV+6YL7avMxpi/lx5XHowsaLGw/evvEbUWC3OSc
8yFfO7G52NZglPJJeu6HZcOX+qFqHWYs/YKu1ytbmeBRBrk+26w1FM+4/v7v
smaPMatWfTF5A4GmaaF5yUwhdncWvBam93vlnGTIz0adUFkf5SdO9SQZNulo
l1MI/XCL210qFI+zM/xDnp3YUWHIUTpCIP/Pxd0DH1tgUhCm7kz5Vue7VvNL
dCP8l472Su4iqE9Ve3x54+/QGb5WLkXx70ITeVKTCZniHmcByofoIXsTx4wm
LCxGs3zpelPP9IR4/gzMrQnMn6P6FXqe5DEdkgKPpx7P39J6X4YCe1dqB273
mRF5yudVb4RWOG1qx9zMpL9lOMHBNQ88gwprofjiwPjMVoovb7vdntYqsGQM
1PhoPfLpcN0Lo3wIO2nn5mwi8HQRMS1g9qLmp9H1FhT/M20XbPMOteC8d6Wl
3DGKV7j6XDf/A/RzjseIKdD7t5iW/1rUCt7nO/LyvAgUIzUkbDO5ODp8cnCx
kvrL19Z4u5Mv8TTIYGiXI+W/lHk9Z1M1Yj8sKeOn/NUVizCrpPh4i+01U9lN
wE7NePNdMwJDCQl5NhSfC7G6rDiedqyt+KKceYLqL0CzTSWW8rGQzQl+ROAt
wB7sqmhHu6WvVFEk9Rv53hs28x1oCZYWS4wm+DHVM9twSxeehngJDwbT/f+W
Y0qK+iNqr6+XMu1vlJSj0Spbj72GO43bdAm6mdrlr4q4MDuVJCWcR/EKkNDn
K81Cpn7riPBGgrHeeRPJ/X1o8ReLDCoj2O/8Rmt6oAXGF6YP/+hB9cVrdlOg
OgRH9QYP7aL9JwbVAvYXN6FurnNK154geMk2z8T7Lfhox5lqtCOI0j3iPGzQ
gU+/lI8WnqJ6ZSy/eWCoEQpacbe+G1P+i5x108t9BuFSDr8HrWuGjRmR1lzc
NFjGdWHT/snnShWdOGBd1RAUpPofqjirZ1qShN7YtfH3KD94XPJk0vxdYHh4
2FaIzpOWkT+7ifkCNbmXTvpRfrEzKmU8isIRPXKQuYN+r1q77cz4ZA/WFO5O
+EL9jGs2yNjr0456829TtZRfPdtdNVVnSiDBOLBFSovA99D6bYtaPeC8k2Zu
pv57vSgjaEGxD3l97gwZ6gd1RXbdPzQ2YNi7Rf0ozYswcYbGM9bfeBP8R/dJ
qie2jqJs9NmLOFjlmH2D7m/BtdKwFWjCxY+2yjFG/+fdPhte8VLIpR8IOEH1
ttHynmzWOjb+dprLcKP8qdNdtPNnNELUJUJvszmB6/RaVt+5QQibVaZ//Uz9
PimtKsXzJYYO5/gaUXzFFyOzhz+1IeqWqIIfnbe8SV+/eUMZ+CSUf2uk5/kq
IflcwaAbDePvui/m0rzKn7J7OtEMM1P5QE9TWgdc3rLhbi/+VVmV15hGYOj3
vuza4wYsrzqrbW9N82/Vh13NehGo28RTf4Se5xvLyVmu4hlCJ5NUGDupvtfx
hATf74VLDvdf0wI6/9KExc66Dvj5Dd0oPk3gs1QwbY1VEx6Fx/T72BL82Xza
aP9sFySUUgJ8kgmU3dbVTdzgwlfVK2LoCv2/IktwtRUHPreCDl/2of4dNlY4
jm48Ut6RtCuFQJaR7B5zoBNRuQ5Bt6lfZu5/O8kQbUFYokJ4tCtBadXr+FnZ
TGywEz7yjfJl60zfX/ZkADLaC3+ETtF8fHI6zDSxHV/OiLeJRdH8tedsU3xd
iIkdPTXL6X1s1dJ5v3TmObbbvNrcTPkcedfm4UBSHboF/9GVoPn8wO1J2PyJ
LlyIXxTSpP5wZuXywKCRXPQkZ7XdoXpibE+ZfnM5HpZebwMi5QhkDB2Zv6r2
4ExH+JByMcU7Y0/tK9lmjCzj/FFqQiAVx2tF9Htx3ayx5j2L+lvV3VNlV7th
qm2cMx5B82XiTtVqgQcQjXS3PkX9/LFP2E+l7HYkGBYo11F//g8QWraU
       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Ve8XxVVUMiRkrihJKiopvskSQkoRSUrGDIUoSTI3F4WQypyEVOah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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41Pkex4XCpK2sMsNozziUts21VJJ3Bxkxidhy22q7CNVyqGiL2iXJ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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGs41AkDxal2Y7tZFVZqXaNV0s7mUnFEZUVui9XsRJRcKtRSIa1KGhnS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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs41OkXV+0iuy3ttqI8iphS2HaakPCpMYQoqYguupDrRm4bjcqlGiq3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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VO8bxpWivZSl1RZRSZQiS7cWkVSKtNgirWSvVIokEr6k7FosqSRL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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHk41WkbNpHSZ85kyRQmpWiyR30V1U05lmqUnepMxoe+JMtJDa6IOhOy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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlWs4lAkDhoXYSDm0RBFKJCSlg1qPFI1PFGlTapuUYumilnYomrXr9JWI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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkfVkKJNBmm+aw1yFRkLDOWU7ehQsmEhDRE1rEvDaMUQkxCJVuR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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k41H0XxlFkK0UKKaKQkn1LuqVFVLakoiSyRnkUIXt6kjYKrcpSIorK
Wsi+jjDGvjyyzm8IbbbQ+33/mmuuueY3c865z/25z0a7C+YOHGxsbDbsbGz/
f9VWsFjjm9AC9Rci/htrKUh+0k8wcWqFwpOa7xLNFHYa1Equ1W0Dq6unsNWM
iX3TmS2LfI3g+bFkkm7LhIhdiu7Jq3W44LaeU/YoE87SbFr3dmRjd3+t4uJ6
CmG/Dpy76UFHgWfl/PRFFvqSpPbrHHiDIn+RV6KKFGxiDQNmr7fjQLXNUViP
oviP+qrItQ8xF5uqR9tKQcRmydx9yXfoPlBncXiaieCR9f88nsqHPL3/P5Vn
FJ62OoS01Jdhb4bWg6RHTBQEGbNZ07+ArXfv089KI9iUG3phe102vnxUWm8X
QGH7JjVF2+FyfA6L9/78g4lNMTWKovMlcFN74JeVQSG/PmPBPasZtIOTp5T2
MDEpJ1rKONSLddnpWryZYxijfz3dcbUQp5eV3VnJR2FSN1ZAtYSOBV8x31cz
TOycEPd2EK9C4qsFfYt5CsfPnP+6vp+OzWPCb4R1KVT/fljTdbURraE5S8qP
sHB0hMloj60A/zeB2UNPKQysVM3M2NAJS4/LlzfsY8J8+4pyv/gyqESOvWx3
o1B8bOuRjW8/wtanYsSslwm9Rf2XGemZOKhVuPjLiEKgrGlJW1gL5Jxt+HVK
RmDaEzRgJ0HDkMSE5+E0JmhvJlRvWLSDGTsde2RoAM6Za5t8XfLBtjh+yIb0
u2h+fY66ZTtu9op7KWqzUHBE00VZkoYOK/1r57aQepYd7cpuocHwDm0VXwuF
zFnrkE7tBghs4jxz9Sj5/dDHeYZ6jVj9rU5CyIYFcWm29mmOZpj3ceq3uzOx
ucNpdap8KxYlHYJO0ZiId73O997qFhRFeiPTN1LYNRGcF/ibgeLQfR86RUbR
5z05+5W6hSuSf2LKyed5DypmaqxbcYOP+is/R2HpXp6mQwp18JTz/PngXyaY
4nsUHe82o1vT1VG9aBgrDye9N67MgbDoLn/FEAps+iaCUmsN8d9wxc9h8jyP
JS9MxpwLsXLqmuyVv0xoFM4+PbamDoOWuVIT7iwsTpo+f8vsgkcZTWLo1BBE
Zg0+1lxoQmV9r6doNoVktfPFd8XacE3ozVC8OBM86VE35HwbUfx0Zo99Mwuy
wTS6ZmcPJo8d3yCgM4qDAj+V1qu1giFok0dboLBSWH774uo88JWsH9yyhkJK
ztKFjN4SaPGOpO8cojCozTCpt+zE+Lh7sfdZJvoiQ5JHDz1HdeeYTpEwhcoL
4q9/zXfDch21buQa0ddfuS2LS8sR8x9X8agQhapC6amvrEykV0b68qyg0Cf+
NXD13gSweSYoim+j8HjhX7kX+1Nhsfb1nlyiT+fdXsnJ2z5jvidL00qewgVW
fPhH2UZUjhpZsAsxEf7jYPUgdxnC6J3qp0IpRK9esbL9ER0RzQLrNIpHsCtU
aDrRk4HVLtMeIRcomFZsmilZ2gBui4flf/OYsJ9Y2PfwZAP2ivgv92JROKPb
ZmP/tAOz0lGOUu0s5FUEaV7/E4/HKTsEj0lQMJqQ/Ghd1YXNH26OnExhgm2f
ZnBRQCY6Vs1Pe7tTuNQdfXXlyXJwH+aIv76DzDNcaWDahganhaatjBQKq8PS
WOmJrZj0uW3eS+o5FnCx6KFkB0Z3ctz2+TmMYpp3uPLWxxD0bIxOIH51g2Vi
vP52PQr6bL2aV1IQvLCUM3agFVzO7PEGtaT+4jVx/93vwqeh41R5DgvhwenK
blxNyNdWvp5vyESEivxR2tosTC+ZVXZeYGJxo1x5chkDu0WNrpiB+JO21rY/
U23IYfxKjG4n+/vW50docw26ze6dT95DQSlH4JYs/xd4n1GoTppjovttnH5U
LQ0bAqonOH5Q0Item72z5B3UNutG/JAk9TYK1SWv7sQGsds7XgiPYiHYjtf3
+FuYGfVOqP8ifsye0qyeU4ZOwaN5/v5kX5dIGMd1PUXC6j1/zwhQCH88dcmt
7h7SN6jn7yLPk0uL/3zCtB4KEY7rQ+VYeLqP9eCUZweuj30+nL+K+Emu62xr
KvGPrNMbVRwHYVVqs0K1owbNUUYL6aRfbO5xF4p3uGDXA0U+XbJfGiGrrJqT
GdAv7J8LEqXgIGHR0rO+BopR3cJycRS6Ll+2qC0vgX5qpN2q5xR+5rD8BVSa
id96XjXVIHz5e0VGYMMXlN14Ebq9nokvzlXKnIltWFHJUOb1Ivv9xONnRGAl
VlPJolyER+GCPpfks6px4rCn8vsHTKSareh4tKIJY5nOp08Sf/BZaTIlbJaF
aEtRuaYNFEo3/kx2malD/aqy5Aouwr/YT/Xh39+iUeJ306llFAp+J+qq1lXC
O61e4Tjxj2qxUuPJ4Q9Ycey7EWOEiUjb5xxiliWYWR4XsNye9C9uk9fBl53Y
r9DxRztnGKUCPefKNdog1X8ibvwZC5FLjxnLOnWj+n1u4JOwUUi2FXzXftCC
bsO4+837mRgz6F8r2tyNP8knpiR8R9EubDieX/QOFhtVXtWto2B7nnuBrpKD
DyLdd/efJLw4Op/h/rsbDwbYxSeoEUQfEtulTfzY+CBHgrgCE1pcXiwdtRr4
BdPat1myUGwwt2g8WY/AW2EX9umxsJTtrEeFbikeLd7X0uoh+6Whq2/HnQO1
n7ZfNxM9HPhiJ/PU4wMe8N2dzuWh0D207NSYUz3m7uSqiRHeSvb/8nQLioN9
Nj1mSIbok0t8bMPO+9jyJkd+hLz/Uqlnpr2Tga5AnnjGfyxIqgy6C5yho8zs
pXenDOH5ibsnjzs2Y65QdX+1MgvVP50rfju3IN+aNd9xmoU1Y/LjV8n+eliX
FPnZEb97+Wd7V08DAvkGxW4Mj8BSpGn3ZGIH9nsZVGpqjiGvfucTumwuUvOe
lUeR+bYPPTNY60ADr8a+GyLWhNcCMU8+/WBAPJv907GQEaS8+OQY0FkH188N
FuXjw/DiadUpk2Mg5tnsP0a8LKSO/x5Vb27B4yMjKalnR3Gg8L1w2flW5Igk
Wcuks9DA7iNGv16Nd5fU6qsIDzXD+bRoW3pwivP3vd7NLOwajfTeMtyGL4W9
+qfLWNAPbyiMW94Cjp6/vgIcRB+ovz//vBFsvC+6uTyI/782/uQyXweZoMHa
ikgmji/1NlbnykT+k0NJhsVMZMqfO94Ql4I4u4aHA+ZEbzc5p2Pr0zHskj17
/ACFZ/Y7UryC2rHM/qtt/RkKjdPttz4VNiMlcfmyNAcmor89Do3laMT89/f7
9CaJfqX0WOGen8GQd5f20SR8eN/V/rG2BV5H+lpEyf+ZH33rKaVRCvYjZ0qV
iN76kg1N6/rqsFT03aoXrylY+8SkqG4qwWjQG+btNMKDqBPF6+4UQZx9xZMB
wrdJjqz/7LPf4uFWy+hKQ/L9ifHlbmtzMXM7k5/vPvG3rXecr4t+QdepQL7K
VUQ/ZhMxGj4MaNjec9b1ZaGbaaPLbtKINV8yov2+UlBcOXD4a0QrBFkebbd5
WNDLqjp50K0ZgzExqr7E/2nic5P0sU6UvvKXF7k9iugfZ53rvmQR3ezquEvq
O/ljoGOS8Kgr2GR3VTALbq+LoCBeCtWQDSLDBynMCH+LN7LNIvuafVOK8IfW
kBx0YaYZm1lRpcWZI2B7pHH2iaQ36CGlfkLE3wxSJf3OJH7A8vzd4obchHep
AnYyi0kwvBf4bjPhKd1KbRfnpi7wS3bJ61dS2N/BEeYoxkC8sU0ti+QpXpVv
rRz/z8/BH1njuRTWjLY4BWl14dnJDJdJUl+Y+tDRfMdKRIlYCSjrjWB8l6rm
y5pivAi+nOS7SPY1Pzy7IM8ZK3mvHKyWInlBAK5sEx24+GjJbtVXw7DkbFhg
5Xfi6aT6CoNQJtKfSEbONZYhT/gfz6Y6Clax2g5Biy1w3SVf+fMOEyMN35Um
bCvx+UXQ+Ws6FPY6Ll25s+4lLpZc4B7cROYXnuu1pbsO97VGJATyCd/2v25T
etYNiyGn0HaKhXKnoF/Fo3Uotm43TzNgopOPyTjm3AjtkxJ3f+8bxaGo+hfO
T1vAZejYPbKbzHdwtxq9gYFwGluEnzjhB91huNXXFdpK9ls8ST22/pNx004f
8atb9Lsfmd+wtlPZ8W3deCbd9YbnNsmXWc/4pf3ouPh+tWwhO4XlR2aNB69X
QIf91YOtFoSvg/++/rspHpZXfI8oED/a66es7bmuCZHqjIaQOxTMs32llt2K
x+W2nx4MMu+9nvGaDRerkCIWcdL9JZmnvH/3VdtGqBU0Vn+uH0FORUKhqWAr
+lV53AbuMiEbaKn03JiOBxOBjqp9FBj8iXTVb/nYwWKY3Rxg4kF88RmXRwyE
bJsWjQochZy6dMWxW7nQDDl/6IoxhUWOO8XT43QUxf/30ILk1fiQk0725V2Q
9XP1nrKhUKOqF/vaoQU/N8tknrEewSvWMfNT6TXgKY3Kc64neWFt6jvnxkac
cbN5p/Wd1CNlpyJuXIZzpfxJJz5RMNyjuXR8axbOs0zmnhB/95EoTloS2orE
+rKuvLFBfFRcmVcr0ITXZWrRj09Q0LrUuHNnUDP6Jvuzn4YzwX87a82JbwwY
8Szd8M1gCGHPXFITW4thVM7SP/eMif1aZ4YZpgykiUfWzZP80aid7FcSUwfB
xdUiEdUUXI5c5RzeyEBgWvi40wgF7mx1r4g1CaAF32BPIHw925pUs3FrBcJD
Sng1PCnY6Y72H69h4Hgx92q3ZCZaTd7yvR2mgRMXGoMJv5W8hRNWp3RjoamK
l/frEA4dTeSR3EtDu4bcw4GT5F6L1fByuUiHalfNVJwgRXIw/4W0gW7YNauY
zmqPIVw64H3GgRTEmHlHXiXzVrk4m2m2rwCHG/i5jLJIno/6JDQ70ooHHGyb
WjmHofR3rjVmoQkrohaznhF/D38dYjnal4kDx7+41WpQEO3/dCuHmQWjrYNa
28h9mpGR3ssg+n9y+qdvkiOFWfoBf/OFZhgtn7oZS/xGI7Tm+X7RJqx18NsK
HtKvKcsRNudaOLW4GqgPjEDEHYYz2m0kp845WMlSEHgW+2cNNx2TK6y/aQWw
wDYd7KN45ybS21zKFMm9kD3M5B5XbsHU5/bINDI/W5Oxh+pnP0NwkuW/N4qC
WNJmet29Vigpj3s5kP33GOW+vFzqBWwGt/Bv2Uv0EyDDoRCQi2PzzVcEif8V
B8hflTGtxo7BuJ2O5H4Nd+DSE3dvwXbzho8+60bh4pB2tUuiEfG9bBJrYygw
297sXiX6GZbD8Q7pu4k/JFSJVYimYVvfUZMn3cSfzsrwLVjogvcDnzwb2ef2
st2uggZfwPrTaM7bQ34/LN+1uakJggdM+G+RfGdKl6lR20Hy+r+bL2kdHgX/
9/J7+W+aEGRk3lZ+lwXBMwVvxV43gpV7rLKT5Nvoj8JlMRyZ2FR1WWrXKXIv
aHl3K1n1IMct6/PvQJLnVFJTL5XTMd1fdsewk4UD8xb0Jz87MPaeQ1qycwBh
h87R7td1QubhjzCxoFGoHc6ujTBoxS0pGtdd4vfdCRWWF+07sDOMEjf5QvK7
1uFDRguEH0G17Pzk3lUz0R0oIjzMOefd3FTDxKYkWde7x0rx9fkb4fv2TFQx
M+luiYRP2w7q97sPQklQs2ttagt6O01zTdxHsGrYcECNakeeEOv1jt5R1PbP
BpxKa4R56stcnWTC84VTOnX2XRDa8I9KIc8QfmhvN7KwakH8m6MiSjIjaF+w
7smrjUOiDvc7TaIHkbRXbFWqhRB6V3+OYUb4q9+74ytnIopOC124RfRUnbOR
+5POI/gLeaxrIfeOv8DkHbonDQv1z/iCiH7nX6lYrwtoQ+K1J1gmOIZMDoWK
K20pcE2oml+1j0K677nvG+qb4PrixJD2RaK3XoWII3MN6KMnVQyVk3yXtb27
I+kOzv16dTmFzDvvm9nyFSElcIq4N+2kTXiqKH3xqiy5n88wA/OlWTgc0Mml
s/E/3POb1olLYqJ8hZf+fukWmOttefKmlehrRjbJL6wKk/NS3L1bmJhdkHlx
bVUTHgc9Wgg3IryY6J4r3hKAzj/f7SzJPnsL61+bSWlFd8bWGXfZYVQHb+/s
U6jG3SmZsTSSl4JePuVKzOhCQr+mWVcgE82Vi/ySl6vRVjoVIcLORKhAxCnu
+BL4Tb/wiyb+fVa6R6BIvgas6PnLPo0kb91vP5pY0Qj5ToPDbJdY4J15OHjj
RAtUqiftHZzJ/PoW3U6dYCDSCYkpHRRC2Q+f9eyphedHc4f4AuJ300f5pPoK
MDISOrHvKYXgda7vMpc9RKnZdW9t0q9Vu+5Le4sV4/SJDEfuTiYe35PekfO7
CcY35MUTyP3QnveqZ6qtBCbaHTc20SmIW6nqlMSkQ0ThwO1uwue8rzlySTEd
sMrS6eqwGoWVeGjjdZdaBHAoHVPII3z60dJbpNyMbW1TpYZNxD9WTcd/2lKG
1apB1n8UST9NOj2EEhJB49B2MyP5nzkupT7ztQHLOsJsb3BQuKVXcNpXsRX3
rp4+PhbPhLAr69f5v3WgeZl6CZN8+iPcvHb7/VYckvtXQJzwtniWPV3mTiqS
1VV+0tQpHK993Ww/14qUepk0a3J/etwp5FDNTUexySMfR04Ka80jhIrcG1Hq
bBC28h8WbrFzd/Ty1WN4f9xBfX3C4xa9HlWHdzhgoBzFP074e1No1NftHSQF
b16SJ/4XfyOUx+ZmNSKGUpUyyT391CHIMHyGhkzpuOWBnSNYqjFf1NzWikZl
CW7Wy1GYFoYtFm9Iha34cg5ucl9lftiz2Ve5FI+3cZZsfM1EcaPg74tR0aji
oS9LJnmveKtZr0/nc1R+2sk4p0phfU16RI/7ezzkc7vsrkLhx+HQrs7+JlSD
m+uNIwsnWZwck3zNMH6ZTEvRZcGYcjEU/16FafP0xaSCEWwzfbxFdqoRthWe
duH9wxA7q6Toc6IYb+Rit9MnyH1kZP/Pl7pH0LPidU9TIPmV5vXIX7QD6UuD
ps5JD+BQnn/8upwCct/8k7DDnfA748QurTd5WBNQUbCR7MP/AN9iELw=
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs4lIsWxudUtEcpRXKIkJLb7NLOMdp5VaKUOErtdEOThEmEFCW6kOSS
yD1FuuiCQklCxbCHXGaYMa5F9V2EcsrJpfOdP9az/ljredZ63vX+lo67r9Oh
aSwWK5iJ/+dSlYDtB9a2wUyaztZRosE3ya7h5UiQ6xhYZxRJQ5Pr4sc9chvK
fpuTfaIIILLRQd+5FUEFDg6CKQpjmkFD5QeroDL9Ld/yNIlCSVaZ9Ytu/F3c
leCmOwiPD2znSKMmzOjj3jFIpnBvvMQgr70YnLECP+tfBFy/+wQbeT9C7qKx
LRlFBNoeNNtLZM2YrDpVGtdBIfui+lPO3ndYUi2pEntRGC5PqxM6P4PIgVfX
OIfEftnheWtmdcLs7YE7go009MZ7i4SbO9ASdPLhTblBWCiwnuRE1KNwp4r/
hVYS2nYjT0f9nsNG8uxojy6JqBMc9QGmfjaqQdl4AYVEzxSfoYwOfLz9yLja
nUalXky0mI6GWuRm43PWBGRV8vFyKd0oMW1cnlxCY7bfprw/R8Uo8NH2q06m
cetNXVPW8lb4+GaoyKVSmBEw11eyuh3Sr3aTzpU0Nskiy3VExZD34M3OmEdC
7ZfwlAfrGWbs4hpzp5EwhbBSsbALc5RVis1mDiIt+E5jf2ErCib3G369T+Ga
x8173n1SbFqzJ/BRLQ1O0U69Qk0pPvBVpzy30WB5D6SLJ4R4kcqv3zaX0Wu+
4qk413qEVBlPeG6gYPrP2XmDsa+Ru07X4FYsiY/7RzNDLApQGXLAfbSUgF7i
0eyPKSJwOFmxy8xolPXzn7AXyfDh0Mhf9nsHccrp+L6Des24s6t8w8lXFJo8
FdSDB2Tg8X7fzf9FwzvzcexxkxY8qW7wnc6joP09mfNx8X2E6Gxyn1tAQN6P
9S43QobwjMPuSvqD8Bq43zWwpgXy+XRhVgCFSvOrnFBnCYbORL8x49M4q7hy
tdBVhC2Xl45176Eh+BFaMqLaDDVlt5DpTL+5eKjP8EozBNJH+apJFHojPp3v
c0qAyomAEBdHAn4Ur/t8eTmu+iutU1xM4u22PI7JQhnO/Nv+boUPDRVZ+9d/
PCpBkUf0lwQ2iZ1KFS6hYe1IczPKT5mk0J3aGLpjQQum7TikbsGisVVreYjC
pVpM5YjydteSUJm9sKhNrQKtWYIL95aQsIoZ/Zxz7gK0eoWuLpYE3pydN2/k
nBDDvUa9H5n9WEkx/vOcnuJ+zMk/NgwSiHbU7XXoasKJCu5Jr0sUtvocchup
aYHwfEP/Hl0agfX1gXK9MlT2nE5W9aChlvftU6xcHa672SZ26VKQFxYuusVt
Qf8s0+j0GkaP160/0g+L8Vul1WXBBIXf2/VdtRybEZ1v+ZeNHI1rGz0nhCUS
lK1ceGZzDw3zcqNSfaoaWj9q1eaGkfi2oCz9na4UxIvO+aKDNGzi9e4dti2A
VliGgW4JgWMvFUxtat9hfMnU4MvnzDzj6V3ZlhUoDzJ9vHAjw1dlxauZa2/D
czj155+JDM/PDS/993oryhIaNsbNouHvNn5l63spvMMHnKyKaCjN/MHWUK4G
XG+ecUwiYSHQdBT3NOPKurTEYUMKQs0VpfKjzYj9ZmWdwPh/zmX/LBuhGIls
u1JvS8bvSepqngfDIegN/lBmTmDF+aysY1l30Oef8GtbOgEVfvzSqBAZJJVG
+5OYe4uC5tw4Wi7CURsuO5fhu8A4LUIxTID+63sczjJ6xs8nUq5pFCNV6KJk
OEQgqPDZuAbZhtllXmz10zT61QyVh+7W41pR+apVL0nUr9J2Mk8SweTn+NIj
YgoBAsVDF7nN4HG+59ilUVha3rBeY5YEKfahVg8ZXkNrXv69wPo1vijEqfge
YPRyfaVXU8bwnXkq7EgVhdVjebrLtoux+72JwaQnjeCEB3+kUI14mh19sieS
QsqLn6L5a8qg20nG5CuS2G5HB2Rp5EKosElj6jSBKK1WSap2A7L3llwOtGX8
dkIzzOeCFKty69Yd96bRsnelq5+kCT6Elf5de6beMcphW+9Ccpc0oXYp849v
2GUKFmch1+XMawtfAtr8/9CHx0Vwmf/ky1pnhscVPUUdR28hIfXhibhwAmZf
1P3PsjvQZDskko7QMGMtM9zl3AIqZYt6lQ0Fkuu4jD3ehM8TRk36Fyk8yF/v
NMXwej58Qe+/3CgYXc3+rWVfO3J5moZ3b9CIH8sosMjJhlJhk9j2OIGIczrG
SUQTVJVbe8eDKHSkZ/YofX4H1ga11/tiKPjs9l/p/FCCguDI5EVvmPvciJqI
57dj+FNI9c8gxu+16jU7bFuxqF51v6U8jW5i8vnMehGyeX4q2tUUaMd9Jubu
lVhdlqljZE+i7fPY087wNyC72ZeeHSTBv5DsqXusBaPBpZ/GOinoKfI2H3vc
idpw8c5k7iAGU/YFeFlLUby+b9b7UBo+E32B0ujb8IpQfjgQR+CrXr+BVKka
6wtX13N9SUSrX/aSi2iD8W1+Yrgdjf8B3j/LVA==
       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVWs41IkXnkSki5aVSemRrEQ0lVtsvWTb5I+wpNIFrSJyabVbE7mLjVpS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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8ldkbv6V0EzJaKC1iosWWRIiv0NA1GTVDkm4ImRZDachSSNaSXSXT
yDIy1z6um+zEpZQbd1ESJXUSNb9Raiz9zvzxft7P+znPec/5bs+zzuOXfV5z
GQxGBn3+e9v7ePvfH2iB2qvb65eaEviUvLxy6KQYIfN4f4Yk0W8pdm1eEg+J
Dln+XtoEbxmH5VIk3Xhw6aXM354Eeqz0OeH8enBKhrRjjAicJYs7lE9W4FPr
YW0lLfr985LpocS7WLPKVU9oSMCtsUyUWtIB01Qul29JUGbNDpyWa0OKm4bW
9e8J+FtbxthdXOR+YKxQ0icIP5xW4J6njdyAcN7UOoJGxZpDBUYpqO1nRhiq
Exhu2H+N49kAC5NBQQGtlxi0mWtUVGLl1d2fvDYTsMyGGq3vCRCwnZFccJDg
zZou2wVl5Shr0R5ZTtePRWzcM3flY0xoFpcvPE/w16JKjYXuIvSrD6XO5hIw
HiUynhMefhPZ+otofZrArr9iuA2228QguwlUI8SvHK2LcaFRXbZOg+CD5fUc
hcUtMEj32j1O8XEbCixYVXwo5/q63bWgeMoWKN252Y1Yh5ma748RuGowVy/v
EqGwp6eh4QI9b63x6ju3BFCtmtYx2k9wO3md4fZQEUZy/QMkVI/xk2F/9Bnw
oW/ZLqe5j4Dn632KPStGQ2r1lfccAjs39ha72jas8VXhmFI+9R5GTwpYrZB+
/TH1wi6C/m8tulfFPoaU2ZO5u6IIAufc3y2ueITec5721+wIuodMX8tw8qH6
PjjKmeIJb7Y0n47hYJAVpiazgWDWVZzmpNyN3zr2XhrxJxi8lv2TyrIudK+Z
XLHMnSBxx/PTFqlPgZCLDJsWAoVfmK8W8ishr5Dbx6b7VVWySr6M/Q7bZ9wD
m9cTaB7XlS399ikUQjxqeeUEzBD5h5q329D62HzrsT0EN+0Xvglt5WNccCGp
ikXwKWl67grmYxxe9cKnLJKg1Voj7UJsCzqI+U/NlN9NMyYlxvx2OA17K4/Q
+nklXNfMY0JUDH9NnvEi8A4IL08N70X1Unznl0jxJHhMrd34DM47xoNq3hJ8
TnYzOL6zA++Kp7d+pvqeuJUq1Rl/HyOqkuM3KH/C6KyA2Bwx6uSL8zOK6X2q
3tgrDfViRjuBuTOT1uv65dSHVWCukLOhU5NgeFvhxxInMZxiXIYWUXznmH6j
ryMFCJaZ8FwUQBCnefDKuK8IfUUNWv1pdL9IfeVwiggTzwL0bQop/1K/ChMz
H6Li/FGJDNVzrDXnqF15O2oNHSoVHaiezSF/vzjbierLrBdy9H4WybYmXf8k
gxfQNn6Q5qOwQ/+Y2ugdnDr0klVL8zt4Z/+ScelSfAq87ZRL9VDO7P7qtqsD
8g9KC/Qo3vpvNNjNik9wI+KO8fU7lA+tUzoD1x6C/7sJZw716/L2aHu5Z024
/EemXKMZwbSyWbOIJYHq19FWzq8Eq2Yca7WZfASbqd1Qpvdh3Ghtsw32hp6w
aIO8GsFl8Xqdv1XE2HFEx/uHUIKAvMHifnYPbtl/UHf0ofgj7QJ982oQpj9V
X0LzfKm4MYGtLsJLnRtRieEEA4KcMF/ZJ2Bkv5+zP5lgqZtqMuOtBAmVDS4H
7hJ4zp96oOzZDlaT+Vdtmj9JUzzn8BcupsKV1Hg6BNFfZQ/x9AUokkQkZFP/
3pQt7Yxq6MVE85xq7zjqPy/953J8Lgw8utPGNtE8TBs7v/QTY5PKQHZMKfWP
Nu9iLRHAe0aq8qMTwXbTm6ejjasgbnuq50D5fXdOFKGvzofCl07P4zup/6Wd
XEMvPYLI/BfxQV+C2CsP1+TLNCEnVEZltzlB0zqLb37M6EDw9p/DdKwJHEZ9
/FixN+GrPC/qKdXv349t2RMv+vGkOMkm5xmB1r7wgLjnfYi8WSnc3EyQV3qU
c7awGRfCpU+co+fx1sb5zffoRND+Ky7+ztQ/VRkj26yicWqCGe1N+eeMK4Zm
/t6IUp+tLY60X09ktMieN2sCWy2scWQb1UtW8ZN2MQ++1z2sR3QJrqZLf7/I
OAdFRo+LrL6l+a6ssqqME0J9UJ3X+jNBncLhQ01jEjzi6jT1RFA+ahJXNNn0
QUF5vcVkEeU7SVJ1P18Ia92a2bvXCE5eVpRXShyAA8s+xDab9tsjxXliTQFm
vz75LtWFwO0bp46U5iqk8S9HHqD99jd/KUmpqwjDhzIvmh4niNwxlWz1TojV
R2zWR8TT+iztB1MFsaiTXSwTSfFNVCzaL5PaiUL5f27spP7jXZ5sLlzehAbH
E4H6FJ9Lb71x7Y7HWPaCuW0miPqbwXCNT2rES6bNYjadT7VGe8a6zvShy4/3
h3s9/d/7e1NnuG3QKk5hqtkQbFjwTjE/ohnvFLhHbKhet3ctfZS4tRchLucy
tvhRPZb5xBjPaUaGVbF3N+1HCv86/nR8bw+iS5a5u9D+E2A4mf/6iwiznrrJ
KVm0f5155VP25zP0Oiav3tVE83TgpMHphF44z+rMW3mF3kd4cb7Sh3tY4t53
K47OZ337hapRYWJ0/+j+vx/ofOr+lXX10r91OLE+LirHhPpjj9g4K14EB8Ow
eoVUAg+X0KUjWgLkd3Uf3BNM9bhHhDn3BuAha1Uv30Hns5Ur83p8H9S8RidT
cyifSnP/PNsggL8Hu16D5jPIzDdcWj0Cbw0WWO6l/DrLhIZJvW8CJ/1s32cr
im8FU/RmVxZGo417hdSvVW7CDk2VHhipqLQ3xlB9+dUjkysbcbehRHBEj0B0
1NRCVdIC5mYOs5z6f1DXSbrYrxSjO+vmDdO8FZrMD+1dVAHdsOpUtY00v5ku
gR6JNQhafCk9n/pxcGN44kdmEQYCgzaq0/nUmvdPoL/RfVim2RmkgWBoy5k9
mxK64XTK/F0o9RPD1rNd1i4fW6xkY+3pvCnz3XqEaSyBn0B3Xno+7X9BV68X
nv4L6yJEAZPUb99NjAWS7B5MxFW3q9H5qGeYua/hkwDshJn0dke6PqC7NEqn
BzJ1SrE6NM+ficlDrmw57A8WxPzX793+mnbJkX6E+GDe+Z69BP8HbdqnFA==

       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2cglW8bV9kNDSRJ1l8ShayUfsmICiWzMlJJG9FOUgqpiCRbKYXsnZW9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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41HkbxmXT9iqiYqfUrA46TkfTkbolCmGJa8MWEtKGZOS1JVQUm8No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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs4lIsaxSe37CSjSFRCUbuNOoWkWKkUDts13ZAkKffpYlySSkpoU6KS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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}]}], "}"}]], "Output",
 CellChangeTimes->{3.545756132676382*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sinelist", "=", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"sine", "[", "x_", "]"}], ":=", 
     RowBox[{"Sin", "[", 
      RowBox[{"Pi", " ", "x"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"ListPlot", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"MidpointCloudList", "[", 
            RowBox[{
             RowBox[{"sine", "[", "x", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", "150"}], "]"}], 
           ",", "\[IndentingNewLine]", 
           RowBox[{"RandomCloudList", "[", 
            RowBox[{
             RowBox[{"sine", "[", "x", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", "350"}], "]"}], 
           ",", "\[IndentingNewLine]", 
           RowBox[{"LeftSideCloudList", "[", 
            RowBox[{
             RowBox[{"sine", "[", "x", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", "150"}], "]"}], 
           ",", "\[IndentingNewLine]", 
           RowBox[{"RightSideCloudList", "[", 
            RowBox[{
             RowBox[{"sine", "[", "x", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", "150"}], "]"}]}],
           "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"Red", ",", "Blue", ",", " ", "Green", ",", " ", "Brown"}],
            "}"}]}], ",", "\[IndentingNewLine]", 
         RowBox[{"AxesLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"\"\<mesh\>\"", ",", "\"\<value\>\""}], "}"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"PlotRange", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", ".5"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{".4", ",", ".9"}], "}"}]}], "}"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Axes", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
         RowBox[{"AxesOrigin", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"0", ",", ".5"}], "}"}]}], ",", "\[IndentingNewLine]", 
         RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", "\[IndentingNewLine]", 
         RowBox[{"PlotRangeClipping", "\[Rule]", "False"}]}], 
        "\[IndentingNewLine]", "]"}], "&"}], " ", "/@", " ", 
      RowBox[{"Range", "[", 
       RowBox[{"1", ",", "200"}], "]"}]}], "//", "Parallelize"}]}], 
   ")"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5457336497953625`*^9, 3.545733697964895*^9}, {
  3.545733732301421*^9, 3.545733732572435*^9}, {3.5457359006195917`*^9, 
  3.545735900697592*^9}, {3.545736217393748*^9, 3.545736220451353*^9}, {
  3.545736675584589*^9, 3.5457366823550005`*^9}, {3.5457367279850807`*^9, 
  3.5457367308866863`*^9}, {3.5457367973740025`*^9, 3.5457367976860037`*^9}, {
  3.545737492441101*^9, 3.545737492519101*^9}, {3.54573953832343*^9, 
  3.545739545192805*^9}, {3.545740559263691*^9, 3.5457405943627987`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns4ldkXx08lIVMnU0YoKpVSQqRc+lYkTRlyq/h1QUlKZNSELhIhQ7mm
IpdRh1LRkXBUktDJ9XA4xz3t15iSpIv7nN+eP97nffbzrmfvvb7fz1rrXeTq
bXt4KovFSqTPf++pe2VmqnwvQO7Z7q6HRwnkjV+u+iukDZ7jHRFyDIO+VF3d
oZ56tLuVKpY/ITioWunM1NQh0aP+b3YpgaLiNKsZ9oVo81qSsO8IQciU5N5X
AhFirIXbZmszMBAeSJUeEUD/bvup53wClp+M3sXFQlxQ75DPZAiym2xOPf7e
jsQ4+125HxhML1+0WyemGorXrcT6t2h8v3eO3FcOeiRbW6+5ENxc8MNdKUaI
OB3HqtRegkK5jIuzj+WjvcJ6sN+dftdP4NpY1GLyRVfolEyChVbKNStZfMj0
Z7HDkgkmAjrSEu6LEZqrdc/In0Gtt2+bmYoQ09cLe8sXMwjqnOD4e1dAuc7G
+lQogTuv9q6ptRjKllmcBmcGKXsRu8WhBUuqrbTSNzCwVFmaH1mcjw/aquqL
6Pmt5ZGvU4Pegm3Ge8RJJ2DXpDPKG59CIHE7VkH1Ndll2qvrKcLglDBZ7V0M
DpoPFD7IL0KrnZHCLU8CJQPr9ni3KgwsGDkzM4ogqSr4zq8xXOidlXp1+zBB
T5C+ZGFMCWo/F3oreBN4mQ5rTuQ0gGex3eNcI0HQYoWnLO1mCBwS0s79zCCZ
eTu98EQ67p1SnQg+SPe7Nmq5yfkpJvuMl6hSv9S3TXO+MymC9KPEHF11BqsK
9uq7P69CcXKw4GMi5SHUZ6rRjFKE7Rw8mn6SQKrv30dzEuvh4xH+1+dYqn/L
Sml1+xeYqLiTP0Dvc7wu55PylBYoGIb77VFjMIJFyb4dFVjsnG636DKBskNc
SvYaIZyOWh5a/pXg267h2k41MQqitrf6BDDgXj20YiurC3dlCjgfsxn49HTw
xdJZOBdZ5BhF/U+7PWVyzecyDPFlNob6EZQkvlmrm/IKCrW/DzidpXqbxZ8z
HnuBeBlW52NfqmdqjeaCB89Ry26tL6VrH0nTbrHsA7BLDpwudyWwPG9p61nT
AjmJVPRsPwb5FupWAbZtmF2UMC7nwUDTZF20VtczjMe0Bbv6ENS/MrDvHa6H
3Rf25ZA6grPfuXvn+YnRV/w60GoNA/e84ofcjkZU34kOFPUR7GT/3LQmVIjS
xZ3FxxQYmJhIe7rlVeFDXIHEMYmgzzXD9cXaInimfjghpv4Hu36x8DIQosKN
2638D+XfcL/N1t2vYLHmWsNqf7peynw4ubEd0Z0XhXqxDMInzZYbHnwOY6MH
E/t+JzCt99SOUqnFrcPpUrcyCNLHEpNOJIignMpzdTzI4MTm9hff7tdj6rIF
zgte0nx+Gd4cayzG/t68vc/sGLwxL1z7LroFWhG8m0OTBB4lY4YdSVV4d2Db
wIc4mu+uj+laik3Qid+aOdFB+8G7ZAuF6nAcVrOf4XSA7hdhYfY+qxzr9Oao
SKjf7B7xjirtCrSePq1tFEz1V12qUVb8Bo1PyKyrlB99eY0Nb943wM9LwU61
nSC67l6q3ZYysN33zn90hmDmocKn/sl8kOQrkw8u0PMcJ3n8d0nINeHJi+l5
fXriqVtWVYN1PuTwNKpnUHP5sZq1KfDp9pYsp7yz2GHzS462QHreMwNzymO9
c09Nx4VG2Bb6644O0PhP3SkR6QUoF36alfVfPcRHLXzKrkMrQ47E0frlB1Qr
5Ha9xi93zS1+o3zNtX118OHVBizTyFA/2kUgcqgxrW+twibRCs4/0QS7n316
vjHyCdbywq2n0/0Gx1m/FNtXwXtzb/bxEIKc3Kj7N2by0cIJM5dKo3rKlynm
ylVgRDr8QkAYjQ904Y7VCJDx9yz1Bnq/rBUWO3QdGuDgEtjX1Emw6UD/kMzq
S3C/8r5gO83fyKf6j2SmDNMM9RRPBlL9K/PukLQKxM6V2+5I9Qqaf3HPyd9F
tC93JQRQHnU0PFwuVtZhvfm3jVuo/yfYD9Iy9Utxpttk921aH4WXFzg2DfGg
djtiw3rK407f6ZqRam9hzg741JVK/XyrbMU934BvLekZxg9pP+iZ4qbn34Qk
dxklJxFds2wy5q1ohLT247RaDkH3b05Du6qEEAVGhepRf5WSX/OMPxaBF6Vh
EX2cQFNkV/bStBJLdocUF/1JUM7RyRAZN2Lzlq8ns4cJRqOCBAYKDZTbrlO9
AqrHTb9JldJmJMpn2gX9xGAiUV5G4lAHU251RuULAplRidXjQ5Vwyf7R+57y
J1o53/DXjWWw2USc59L+9XLZQq3ReY2o3Z+bu6+cYGTJwyNqzVUQZC36mppA
eXwywfvjVjXUlyfnrab5xZnWC/LU/kJJs643l/J0jJNiwNnaAo1N33xjtzHQ
2FHGX7GjBa/PB3K5tJ9z/Wflpcx+idQwXmwTrccs/f/dEAxXI19iW+hF50n4
qGwKJ6oImwqTgrfTedD15qv24EQtgqcZxO3PofPTnyQ55ZSh+/FF4QXK//Fr
H3uOr23Beamguf7jdH4Nmgt0H1WhL+E3o8c0Pz+lbjfzIzVYGbItcdZryo/v
+nOGV5pwW+bhdxfaby5/iVm1KkmEnP3mP5m6MJh1LPSeomwlpkfoKw9RXkeS
T951yi+G0j2dWIkHgfVI/+xRXTFGZDuv+tL4ouv/Xnmyjg9P7xhRDNVnzwV+
npqgEsPqndcUKF/LxAvjVbK5sPK8P+0HnX/2O9cJXPktkGTnZ143Y1B26X3o
WHYzwkRZ7tX/EpyR1rsfR/1qvm8+FJ9LYNMWbl56qRRSvUqhqdQfOa3AkX3n
27DqyJx91zwZ/Ll1sCLOtgwBNrozvKkeh/ydbtvxGtFqJTupQutvJN40fmea
GGvGI0cHQhnYdNidsrRphset8EsDg/T/xGt13dzxZiyxCuHIqjJIKrYv+Xyp
Gpnydv1q9H9gkDV/T1F0PcasirRMuAQDdf2rDQ5UQLN8T+D1SIL+xdalgS/5
0DmTVCNP+8uvnnU7srnNuNs1vLpbmYGrkqFaXWMtwiODT3j9V09v1z2xnWyE
wtjZG5qU9/8DEg3JnQ==
       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3lcjO/bHaQS2hRFCG3oixZK6EQhfmiKQipJSdYkVIoQJUnapE1RSbvS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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk41WkfxpGkUoQiDGHIqCylQum2vCQkoxjbeywxbbJWskyUZRwjKkK2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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs4lFsDxYkiSRKpdAq5pOKckiHSwlFRKCSS3KKSSLqJyiWho5DcRcol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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8VekfxigJk1STCSE1aVGiTZYHFfPTRLZoHZKbZCKGlMSPRmRJkrGT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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lO8Xxoe0oCRfkVYpsiVJScndIjsJRRKyZaskayQthJAUaVGyp6Ky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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk0VWsfxw0ZlqgUuYk0XBo0CEkD36KBt7jIeM1d85LiquReySyUkilU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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81dkfxm+ZQVGjCUUhRgtpaLSMwkMhFTNC0Yx9iOwiyShbI3EpRBlL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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lekfxs8UKqlmZEQl2pXIvueuFDFMhJIilTKJyQhHaH4IZS1FklMj
SdmyTJYKIUu2sp1zLIeW3/MqypkcS2NI88wf7/Ve7/Vcz/e5n+/7ue/v6mNn
9p2Yw2KxrtPnv3e5yObKG9sBBKst/vbXpkGoi92IUE9JRKBeLjv7CIGPzZWV
jrmduCb5d8RuLsEbdpK/vTcXb52G9qQtYxCeurRQz6sFm/b16rzNIGBttvNr
XslGfLOLiwHdr2TxJGdr1isYL+B/WZVJcEk0sPvbdDfGPVMuj65n4LpQxIiF
NaP7yK37e6/T/dI7oj+PHgWnQlSjQfeX9vvedpPowF9bFKwiJgk2h0arpgRX
ITnx1mjkbwThckLt+RM1uPJwZ1VxEEGSktzSoZhuHLPP0vx6gMEUT+PLZ68u
CN4/tuucIfjg951LQlopYg53Jq9xJ1iqGPnC0YeHFR4thRIaDKrSRqfW92TD
5GOQpM0xArmO8rdj5REo9rBT2Ef1OFr4Tb7sEeCtxrXZBHcG3tYYGDhzB5l2
ekmnXQk4+bbtC5V5OLD90I6vtD+s1I7QhPRXiCqKEPmXEtg4rWpUOdKBUCfW
6XcsBrPKYoqdlnzseuaUl2rNYHnzzXm8n/m4N2ya56PLQD/z2y7DgA4423/x
cq6j/V9lfG+Fwk38olvZ2Un1bLG4UT4z3IugCZtLssEM3vwcLGz/VIL0yGXK
Zb8QiGSlnV597AXPzTTnrhoD9bXlHfNvPkAY+5jBInq/k1bub/Y31MLWW65N
IpwgL6jw6+ZHPKRlKrQb6zBw3G6nw0+pRab/wtqdIQRF87Lcd4114mbXTIEs
Q5A2xVdy9mtCYEdijvMfBPYnMi5UXGjGlvPvoxui6fk/5TSsNuBiWIk7ZC/P
wNejN/TRoi5oqf/RFyfGoODgoa3q29rAKT0p71FDYDXNWfJqtBUq7Grt6MsE
h/cc7pb2bEGi0AlyRQQy/3/H3xfPhbFWrfrehQzC8udu+WolQEPMUwsjHwYV
iRKlsawe5M4GGZisZaAB0eNfv7yAapiTbC7VcyPer97YsRFKTY9GtqcShAmO
cx+xu5EssDmYR3lp8694nXWiB12PznUsCmAQEWWiamnRCNZyH8moW5TfgP3y
64vbUKnX+p79hNbbnbJ+hNWJkm072/weEny/boESz6MdQ1+9ZB+2EKibpAmP
dxSjvFFUGkL/R5uqTriRy3NoK5pxHM5Rf4hblH8e7cTys87ys0OUZ/UE+7SC
RshwdMvMrxHUm/aOjx7pgn682sgIvW+3750MiSN8tMkXC7Op3jkp59suJTRC
UFeV35dMICBjEbFHKxAgEe+g50dQbrXpp+C450jae3bHCD0veMU2Nc1SNiK2
ifr+8+fv8dM6eW51mORGFflfJGgRbd3trNOOuKxnjlU8ggEzY0+G9xJF2k+O
zNyneqNm1cYfZeHwaYMNupQfN8kFz6dbu+CT6Jh7RZKB+Y4hcy9VHiryogb7
qb/nNPFfVirUIOD5lmqpUAJTLnv4hXE7uH8JD5a0U164/k8LUvLwsFZOP4bW
i46Z7DP6mYtSqavHOb0EZSHb298v5mGjR9isMq03/kn6sH1DF27vjZxlPlNe
57388dqSlwjZg43DNyhvMrlJsumd8A5VNC2k/vJZey3O9lwH5v/j8OrEKEHl
xKfWy/bNCNcxNxzPJngS4NntPtgKnxx+QU4T9ed2abelIXngz0hX6h0n8NYy
K3go3osqTYP7XXcpXxlywhS9Tlh7HRp43E2gG+q2bqyxG2+ThwL15jNYWbHW
9PWPTRjIjx4WJhG8cJ30luFWoJ4tdWCdF8HivXZTWXdonn2cvsrkEujfcfeQ
D+oACfzzoccwzY+jjRazDB8FLRdV0g8x+JXzeCa2j4dy49G9WSYMXEyzLIXK
fQh+oLin3ouB1QcjxwH/ZqzJsHfwpXwKrFVW61fVo6jQkzkdRiDJ0Tw4LtOB
rtiwjO/GCR6YfILZWQE09Wt10tWpv3/zddP49gxLPi5y6D9DILbq+VSodjV4
SeWLQnwJJowWXB+ZeIXB+bM+nGoC4Whudol1D1Quywvy1jAwmz06lt9VA8uN
cyfrA2g+mLlL9rj0IGOF4O+8UwwOy+Y5Wc7rxuqTQ+4i6v+CrqHW8fx0OEhl
9BXTvPywbJnt07kN8I7/IdCG6g3hrT7Q/2cylHrEYuopn97PnGcqf+iB0XJH
81ZlBhknmvJH9zejXbDwz5o0yk/63WHFkwWYueZunkP52fOxe3YjPw+ZmlrN
g/R78fmIyJJTXVjg2hfzwxjlY7k5e6j5Obab1Bp2UB6VtA21bsmVw9Z1gjXj
TVDFcZgyyHiG2/Xbiq57Enh+eixWZF4F/YQcF/ZZWj971/8i5vExnNuyJ9SO
wWd2itinbTkYS86fSKHnvbsUIjod14O0OuMDUukMAo+RhMv27agvfG3pQPPN
JdpBLUzUhvf3pf5RpfMg4O49mTDTe8gfV/Pj0n5c+aZzStm4ApwLmqnilJc2
CYWykek0BFwM74+i645ivhG9fSU4pczqW+JB5x0r3fAniRwIXxyarDtK58Ng
7Bwrt2r4iF9U/kD9v0t9o6ylRDsuHNuwz6uMQOr4xiKb8FpYVg/ayNJ+W/Fk
zHab9WDdzLJKgSWDsRwFrdSgavg/Zj/Q9SG4HW94XjatF/s3eVqbJ9N8nK+Y
kR5VB4ndgd/xaf/cNmQZ5r/tpPPvisHIIEFyWmGTTmAPWIPTpTaRDHb1rrZ2
nm7C60yV2M0PqB8ueOQu0axB4m+t69SpvlG/Om0jdR5kzrj+HqvEoHyu/lVz
tTZkr/x22ofOu+CpnYzumRfI3JF6xjyR8rE5kyQEheOJ3K8fLSgf8ZIZF1W0
GvFObFw5OIVAvL/hjn6qAElkyFA/jM7frn4jVaYb/hKlt24epPmkZnmV95KL
4htlsnUODGTV5jYpPq2FcoRisiu9DyeLbVMl3giI204cTCAoOTctkrLpgdUc
qa+RvzD4W3uDPMPphWTt4qp3TQy+FwrPzlxoQq9e3BINOk8S10rfPVrWiLjA
q1uX0jz6F3loyjM=
       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4lG8bFZKkooRKRYmK7FFURyql0KIoWxJZyhYtPyShskSKZE+2Etki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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx7WMKSRJkWUsXSqTupZRqvFpbKm0ISGVjMZaISM/EqayZCxD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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns8lNkfx2ejtov4bbkVlUaRW9qoZOVjiyK5S8JG5JJ7LkW6KCqVsjWy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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekbPpmUbJEpmZzJHJMSkxkhNXQbTdonlaKfpWVSiBip7GRyypKU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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lP/7xanIVkop2aKkiEpKKnVK3zZJkrIm2fORvZJIWVJSqCgSki0U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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk4ldkfN0k10jJliiwpNRTZoih8KNnG2ggT6UYkJgxpNMyUPQYZu1KR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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41ekbxk8iW4pIKUtUKJQZxt7cpBmmoWLKyJaKElmyhWJOSUWJZixZ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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkbP2FMRMkc6zed0UQjmfAVFfLzifIZjGJUxpY9ZmQZ8dlSWoSI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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8Ve8fJ8pIGaWpUmlYRSWy3loSKiEpM5GRjJBU4iuhXaIUlRHJJiRl
73ld4+Iace+5aJAkK+r3/P46r/M6fzzn+Xzec72Nq6HdPC4uLktuLq7/P62p
aJUFRqG4GPm3lXmGQuBJme7nru1wW51kuffUIKxZas4PJhlIH3SQ/3qEgpSO
08sQnkwszF9SqhlOoenKUYl3cu8wk3HaV9ebwqdSRmHF62Sc2y4bk2pCgSF4
T9brWTOucM96p3X0gytZwJjPtQd9TIUGiYLPUJLTuOur24yMVQ33NR9y0LRw
aRxDMwNTYSvj/NwoWL9d4DzGKgdn/xFauiYF/9i/zYlTRdi7fjzH6yoH5lez
Qt2EaRi33j6ywYaNrmtJ2tqlnYh21rCcLzKIDIn1p4wG2+Aa82RSrP0LBOO6
Hy45Vo5aHrHAc+fYMAzuuaV7uxO6XYrXdoVRGNdfMl073YnZcx8dNey+4nFR
sfLftyVIOSA9e0SFDcvgykDRTW247p9uE72chShDW29NsyooxpgHpC5h41zi
ZU2drQ0otbzvKLuQDZE7mQuU3RoQqqoz+6mTA6nPlNk3fSakujVcrkh+g9uR
qrQhpwpk6fnZrbFgofNB4OMpmXZMtBmfGl7+BaMV+WkfrtSDGaHhEytHQZLd
cr5frwoRjnnt35kU6nwiascW0fFd6aXATm42DGJfLJb+Qe5vHf57hSEL0QNq
3dkvi2E3McdrI04hkU/qytK9NWjuSfOstWGh0u+ywvKEQiz9vuOH6jdy/9iv
+S06PTDpCKZsbvdD4REmL3s8xcyZmA23HSlEl+RJSOfW4P64aIai3ACikvVb
Zi8x8Wn6XDNDvQ1lruZ5Td4t2M1MlpdQ5GDmrpLFI8VWnHM88LKpjIX6mPC1
IqwmBC4Isv15awC/ezP/zb5kQFHJ6EDsP4IXU923HtMt6D159udTBhvUsSNm
grta8cSNo6q5lwLX/IXuLw7W44Bw5/d3d9kYvdZ+7vjtEqjInSwMW0DBpmdL
xA8zBnjvu//dRebfFPxDPOxQAvaoKl99p07h60Q6K2BjHX49+3UrXJUFXZf7
xVlD7ZC9yUsXv9eOWPfO8YkPdNQiQvF7NQe3uecPSi5ggi877bdlcCc0D5fK
qN6IRrWxMI+BNYXvZckWac4NSDr5X0SsBAsR8ZNTl30+wcTquLHJYwqXrbLO
Mrqz4bmq0Ci0mQ2VQvunU49aoG4wfMi8nYNKgZnR1JlWaAn0SC281A/+z/Yv
//alIdTJSuD7CQoXrLINEra1ozJksVRwZh8e0q1y1orRsE9Wg/uFAwWV1CW5
PIO5yK+yerJ+G+HL6R023gEFGE+4OxmbROF1mAeXXEUFVuquUTTcxkGjb3yJ
241SeM165Q3OETz5JcRHdt6B4lSEvh7hq8io57KPYemIfrExzUWHzGtFwBYF
uwy8jnnDV76WQp+89dFtnGqwfhv39ioRvltqcx6+78XAoqua8ZUD6O5dveZR
VS2atWpaDRvYyLjioRljngxV1jufuf8otF69p8j/ko6vl2aSnpF5GRdutOT3
oOPmmnYrkQgO+AMzGlzc3uPxyuPp68bYMKdylklejEd0OO+3CUvC/5iV+9IL
0pG73DTWK5jC3ZrDL/qjmJBbxBXrs5acr/9M/dHVCkgxfXfsNeXAdPG8Y7cm
O3HpFH7bBnOQekrv6O716RiKntuouZGClu/sbKpjOawnTJ8/3zMA/wtmHwLO
BOJRmL8+/2kKBwZ5xR8XZWHH3EJdHl8K5ZEX+FyKGyHvFn100x4OhtLN/Oqj
GUgr3PY75TAF2wd+Q3b7OhEw6EDbkk/4dia9cFKRhoVeBv1GNf2I/vXp6FRL
Jhxi5+/5d5+CwpeDBx+z3sCHLhqjTe4nYmxWd6S0BvMEegSYBJ8ZyT6Ng0OF
mOfS8Fi9hI2tnnofVFMK0dLW1RwUxMbDW4KrI27GwtBisUrfTQpuVN6EWl0h
DsbJyterc6BjdEt5VKsevWKiKjcqKRQ2nSvlFyjDNaEdlAbhV7ed2ScHpRrc
uwEG7QMHNB0br1ThBmzbfXJ83Qairw+Hsx+F07Cie19A6SD5X5vSNal9KbBr
8HvCMacQ9fTpqJ1PG+72tq1t5RrEp5c9cYdet2HL5onT9tJ9CMsZs5jT6ICc
qqmcwzs2ik/Hib2yeYG/ut7G2QTfQttaY0OfFGPfM+W9IWDjotyKIY2dVWiX
bFBQ2Un23XakTOKoP7oWxi5/SuYTkSe669QoAw3vXtiukeJg/kqL+X0HGzBs
2PGMaclCcd/uY25ajRgx0MunDpJ9GZx+teg8De2q8psfdlLwnI2uko+vwPUZ
y7QLBN/ODXIWz/VocBH0SS6I7IP/8VaFuvQEzGbbHvHTIni3q/p2PbkFn9c0
mSisZGFAYF/93hNlSBqudBog+xtN0eMpWFyNbt/g6lGCb67dryQUrjGhG/Vf
huRW4p+94hE03ghMLnulGmhFzt++tv1rSwvcVsiZ5RO916oVsvLqooPuEdm6
KILg10KsZlVtG2QOnt8wdI0Dk8ZVf0N86xGbeO0wbwUbQnIpZ3xfVyJNKEhu
5wPil2jRFpxXilKhqMl5qygUJxjdD/ZsQ0iJ6UjKJDkvIv6aqRYNT5iypceK
ByD5+MD5H9xh4L2aXcBL8O3/Q8KZLvkMoq80f9fbUTBYFBflcOUTVr6l9g7a
cxDm8PM77Xsdcle+j9QK4yBbyauov5wOkdcSY0HaHHDJqf45MuAAQa89IvHk
fvb3ajUmzNpR02MqpRQwAG2F0DeKC1vxaYnt0k/7yHfb5CbvjHSMvVHned9E
9GrDqPCv4QSw6TpS00RPbKwcTJX7OsBdH/7elLsTKdI8NJfDNdhXJiHcM84G
qzpki8o8GqrOSj8VzmHDLXsz/VgXA9JDz4yjeHrw8zcfc2xbCyYesRbJHhvE
0HbmzvsZqbhSxOf4S4rsUzSuYb1tDwYi//N3lfyCFaHW+rvnKvBOecU6HwE2
ZKrFXALnVSJDOV9jazQFOZqacpdUFho1fVLSif9N9NBLPGfbkbdvnfIS5x6I
iJsHMpVicXPTM1uK8D9lzMYvM6cQxm6p/y4Qfo5nLnl3ZqAXBZbzbPon++C8
ZPRWwHsmovwS1GRtOeQ/xvZ43MjCvM7eBJEiosdC9mv1P7fi+YjDI/XPg0iU
GVqpjBxkP1cJTE6jcN/raubrqU4slQifSp0m/EsqPh/d1QEWc+S3WQnxp9Ls
GveX7fj2YVht9S0WLh2XFT/v34B/F2Xp9EQO1Pev/uN0oQpry17ZHTnBgf83
kR2XOzIgqlv2yZrkiSEemw9JVxh4k9V4UdOdAy2NxUtY4zcgJRWSOWJG4cpN
p1/Vnk0wVGbEFRiwYLmB0tb4mIvNtadX1blSYIo/nj4k3wyts90dnsfZSOEe
vu5G9PiYfHFUZBuZv+ymZeYhD5C4INx8hOTNvBOTjGNudEi8z3m+gbcbzprc
+5940cFvtK13o0w/+ko8uh+YxyNA5W3Xxe0UsndfH7UMrkN0ucyXckUWWnMF
VAp5mPi6wCPIpugLHp1y7eToMJAfLraEvfszkirydsgc/4CUD7fY3rFEH0Vq
zM7Ep2OZd5vPjTsU5nQ1nxfSSiF3Jr3NlODTf0vuwaMDvlB1Oa44TfStSTBt
j0VWClqpp69srxB+u1PsrZNeyDI93JtC9OjHE71VNOFm6EX1ZXD6WRDqv6cW
3diC0Nj1a9/KsNCk5qmlc7QU1pkzVHMbG7ffvy6Xq6uCt2teWxq5/2Vj5wVR
n3NhGLh8jcVVgre2j4rChG/y5ZuFGlM46LNwat17MQldJc0ChYSvBo+DD1c8
bIDdn7CnoRdZCJodF+rn7oKMaXOHWxDBy/0hie7jNPSuylvrc4mCfucNttri
Mpz5pLBWdgEHnnUh4cOsYjRZDEZcf0lh19i+qHdH6Lg2s/JDQSgHS9Woxh57
OiLtv5+22U/yY8m1vHvpXZjk4zv9Sasfe2hFv995V2Cx18DcMpIfg1QPMg/O
ZOHyqim7M/UUMuTvbZiaX42VWct2DnazoZDu+NBooAzD9tQE2BQEIz4VnQhk
Im6T+brKhgEoX3DZZqBGxzHhVNllXQR//g5ywZxiGKWPT7mMsCG5y5DrzrE6
+P8UDuAa+n8f4BZ7f/EFhrTE7dacorDc/A0j63sTUlZsk9KsI3mPu007cmkO
+jxvRy/+zsbJxPrPvO+KofOmQsm6gOi9+8ubdcoxKP0Syy9I8lv34bkbMgrE
rw/1Lv24awBmKl3TMzfaEbwj/E7kdbLvzWu7nG49gsGb6k0CZN9j9kGPrta0
441Ftq8v1wA6XP0U37rnYlFy0rBZFoXnGxfIV403Y71DptdXnyEoWN2P2t5X
C3pDPm+dHxsHfnw7sdSWDlbE/ghpVw46UrX4zrdn44mSxMDsG6Jn+Sa/hl8F
wU9kL+uXBfHb5SK/Uqs+ov70+cvuE2y0Wqnw51TSoa2crfIkvh+3c5dd0NFu
hG9NgpMm8dcovVKBv069CG0+nW8Z8RWJ3nPX9jg2IsFrgBl0go2ItsCnHmPV
uHRR++GFdOKX2b57A50fwCada4zHiPgZ80DWwbBcqDzXaTj/f3/r1uETFe/E
o+qvjoyzFPwct/2p/1gC/Z9nlIoCCT/eNdgujktAXl8G70HS/6ZWz1k/bMkB
gyro3GJAIZQX0w7yrXjpLnUw15jkGWVLnl2MArQnFR8XXsFBsezwiskrJTDh
8ajPekryZEmIqaFrM9q6LwWsViN+Fm0cGXK3CoPheVIzJE/7PzkblhB2B70m
g5aJhJ9yd58IPvNqx2nB28G7Yodg3TGReeFUL35Pd0koPCU99hmDrv03CXTf
7Fd8F4i+asi7VG+IQXtCqfddknf5N26NSjUow8Ts4suJXBQsd8yPn+KrxVaP
uKGurySPPejt7o0h/vd8w4N0kjcdZieuHTSIhq3Br6WWJG8VBNjtZ1R3gtZX
qiDmwwbXKfuf1EtnSG1vnR9D/NDXRSYud6QVPyubyzcL9ILL50Ku489IzAjs
MuIh+uMw/nZPWfwL5C/xdVUn/N7naHHpln03WkS9u5qyB7DqjG9ORSMTkSaq
d+OX9uHQgR9XDV90wKtG7cI3lwFE7LkV++BGBUyG0m9Lk3nW811O9xdsRXLB
HfYWExZSedaejXxRDLe/wjy3VUje/cOlUelXD/oSxzeiFSxMXc04k/r2HfhE
RCfuSlC4uHDrqViSH8oWpBRrdvajNaFUfiCmGutT1fMlL3BgbT5ZmptfAwmF
Rfyeg2xIXXOIF3WvxaF7PI21qSyILlOQt7jUhSMG+ZN14eR8q74uzevN+Lvh
ZpP06X4s/tdzSlGSjth5018ESJ/TP2DlPWdcgqF5zITuf2zsEA46e8CuHV7y
Sqc6fPqQnXB+0cLsDkxtpunvuN8DIVtJh0hZBmKl5VyL3b6Q/LJEbcb6Jtw1
HacMCF8cSjRtZUOawXi0W4grthc6y/6aDAbnoNGPe6Eh6Ut3J2tld4mXYOGx
4zFyniRv9M7L3/C1DT5K/BHckwNoVWvMbpNphm7MH7286yyUfX2QtEuwDf1m
nyP6+Ik++Zim5Z/KQY/aPxUd4iebt5XVXbIvhmDIoSinb2xcmTESVE/pgMTY
mTg7+QFEh6Z4cozCcfQprafzOIWsF27DlQUMjAjcqU/dTvQtz7VjN4uOkYDv
Pv1E77Ye7+lWKs/FvBPZMcp0wqfpP6KbgmlY/FxmVLeGBf02k4rRj0VojJpM
WPGDwgrNWI+qdyUYPezjcdSW9PMVdzo0K0NJzq3s9SF6lWRn55c51IHY3Vq7
Tev7wMXbFrBrPAZLq7INzcg8is+7MDi3ypGf9GxSgJ/sV8XZaal3IXhFuHO7
xykYa+332Wj7EUz2nYhnX4hfJu4Ze+jEwBRrmv0nsQ9Tywtiqle2gRnifHlm
bggpYYfcjTLq8O8HTZrnKxvMoYT+VwkV8P/4T0if5JdaC/vbyfbtGOW77m50
bxBBb2NeGKr2gJG3ei6A9EuVdXZpeiTVGh5VVInQYEOr0Tl5rDQZCyrj90jL
Ez08KKsYpd4Jm+CWa3y7BuGV1qbtp9GJ9c9Oto+c+ga9iRMxItUpCE3wE5bU
IPpgqaS/ca4Vl8RzfJapf4OcYnizXns11B3/5hsS/704P+4Nb0oXknUcAw4Y
DeHoiuvDHVeKYfsfM2gR6QeCHgZH++y60B1oxDYR7cGuztXio450iG0P56zS
plA/Ur41orgZXLWPpoL9yfzs//sX2lFH8lWWeGYjhQHz4Ixpv3boDvPsvPWH
+AnNRP5S9H3IBH8sW3COwmy8gZPT6yqMjiiKTa7iwKPldvT2/SUYNEnpStEj
evdqoaCYQxH8O8dXGyqxsWbbotf865rRV+F6/88XNp5fpolclyjHm5CSJaXk
vDE235rW08UwUT0gl7mVwsZrJWrrQ5lg1N7oEzIcQv5pP7OdWxhY9bzgS/Bn
DlQkxOd322Tj8gm+aWsy39bMqAanhg4kTAqFy9VyEJ2z+mzdphboei/XKf3I
QqLVx6HEjnJExbyhFRK8VU+8jFmXzYS4ypZl7kYDGB953Oqi2Ahh21Un6rYN
wHLk9wHT5GzkyTGblxM8Wisqw+FmOm4raR630Sd5oSuXfmf6LRJapqs7iN82
3FAs1GxmgEZ3KNqd2g8xof/ORsZ1YqO92N4nh0gfyTcfXRpQjsjsc1mGr0h+
tLhZ5POhEyHsO3e3rxqAEWO+ZKR5A3Ta7cxeT7Dglr6s1yDuHvaIC+U6kLwg
mWx44ntrLKoXX/+0yIsCNZh0PYC/DH3n1DP2UBQ6+3zKjz/oxhhN/8ta2ldE
SPf++PvyA1xCTJJ5SX92zygoUhVtwvhtt1ltsn+ZxJR2T6si/NJN/+xMI/3m
/rSr5e8uBD4WGB7/Mojmk8PSJw0ZMOW5l1ocOghnrsLHXV/K8GI4PIdB+sTa
kQ+qYkMt2H44bMHeVA5+xXvsN+9nkvcS7f6kz2gSfbY+U7kTf59KP0xl9cPh
gjOd+kfHc8eOhcEf2MjKWB3r6N+KHc0nnRzyBmG8YVAvM60Br1rOrgDRj/8B
qaQmIw==
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8VWkcxlVDEmW5SiSkRknTtY4JPbZRNDXWUlTGUqZpyBJthKHNlqVs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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk81Wkbxg8vLUYykWSLkFPekJSldEmTrWzNSfYtDFKZqZlKWZskpuyS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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4ldkbPSQRFU1jUE1uuUQhSlGtboQolcrEEHKZMCRdFFFySf0qJd1U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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lO8XxpGEsvSNFkWyR1S2RLolZCtKGxEVUtmKLKkQIQqJSKukQvYl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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs8lOkbxq2kDDpIDkvY2YqKDSGVuiQsoaUkUQY5TBSSDsqWNoXa1sgx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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4lWkYxoUkRaTQZGkjYcRMGkpzY46YoYSSVISjhKFkmqbsZZk6lhpU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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8VekflhRqInWjqekXFSohU8NMY+aRmCyFETM1LdeSiWQbEU2iKCVK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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VV8bJZKxUBmiTBmSKSUqWSVFIhVliAyh0kRUlCGVEipJpqTIPEVR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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81dkbtkZDzEhMiWgbpNxMi6V6JFmiZMhISsMVMcnaolHEkCypbpab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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41Wkbx5FCKadRGJJjSSXbmIaxflMIkxkhjKwnSy69JDpEiWSLjiVJ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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lXkbxk8zRGVJcxRtw5ul7CGvqcw1jBQlKqTo0CFJRLKUyVJJkoSK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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3cg1P//R4UiTWSUVSKVCAn1UCnJyGohoyHtqKyQkQoVJfFBtpCRvbL3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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx1UzKhUi+5pkKaJImManhSaRLCVJFCqDQjOVGiSMkBlMaTEY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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41Wkbx8/I3osUImQZgyxFUxOpvmgTUyFTKiLVUCEaJilEIxqhRSRb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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs8lGkfxieHpUha29u0sp2jIsnYFda1qsVKGxvCymFeyjGxnSiSQ4UU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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VH0bxseSJZJQRCs9tFmytXm6JKESQhKyFEKWCiWVKNRTERJZEokk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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41ekbxmkkRVHnNCWmpLGUUakYS7lNYZTIlpYpilPSYufSLpMlCXNC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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs81OkbZWVtTal1KYVI5VZki5aUw5SElZq1LrlWbCTXDBXrUqEkqcTY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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwdlns4Vekex3eNnEIN06TIuOyaRicpDQ3JfEPCQ3FMDTluI5SSUm6VW9oJ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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k0VP8bx22VrcUuiVBEQkUovEVpL6mQhIpCylLWdqRUhK8kSUJCytJi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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs8VPkbx6eySutSpNiMy27bWjLZlMXSh6JcSgqR2066KWkXUaQlqVRC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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns4ldkbJVSTInIrFKUYJArjNpZynakotyQ0zsQoEg3dFDIjJwkhl0gy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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8Vekfx/nVWCLKXqloMOqqrsjUUJ8oJgwZezMqSwklKVS0aKxFRVFI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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3cgle0bPoo0KNRX9KUolBESUqpLJELKKNqiz0yRlJXISihERiWprJCZ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41dkfxyUVmiQko5iuilJmCDfF/N4qGVvTWEYmhUxJClmKpEhlC1kK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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs4lVkbxrdESChla5CRKHTQIFKXG8mIlBxSkpEkqhFNySmRHCJGUYQk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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lWkbN+1SkaRkIkb1USRENfhRJ9SYxjRUM9nKUupYs2dL0glZMh0y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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3lYTe3bhuv1o0iJBkUqzYQIJcWVkNCEKDQpKklSGYqSJuVNoyFNKjTJ
WzRqnjXXbjePu9bae5dINAgN3/r+2sc61rHXetb93M95nfdmqxunr/zDwcFh
zsnB8f+/yVLKz+L312Jcbyo9f5yJgIX06a3vK5AZN11dLUdi0vPuT1eTTMSZ
5MTMXCKRe13k2vb8Rphsl+dOJQh4HUw/9m1jNoY/iGprqJEwKS07fNc4G0Uj
2WWS6iTK1qV0vvzzDjqj5zyzr5FINc3oKFPowtH22SdG1kxEbsgwmzndiI9C
qbLaqiPgOBISN3XmASbLDdxfWZH4WDSS73nnMxxFBKorBAhoPLAOeL+uGJEC
WgnyJgSKpf+xC/jbilZpA91135kIS5R/+9J+AITqahOZe6PozYhyfD1Bg/Br
05fJWkx4Sxm4bHtVBf8D6zkanxEIvXCEzimQiJfDWk0q90lI9xiTdtJNUNn9
4GNwLgsBvGFL18RLEXThlYxgPwHSf037yh1FWBv9SZjPmARjk3Km1e8M7Nty
OylHh0TDaTGNFbJNoHW6KGdmsMCYXR4gx5WJLm5hjmhdEubsDXaJzm3Qv7RN
/qQ1A/vW+Ie/v9WDqiutDTx7mGBI9FkkD5SjxF/264cbBHR6Bn6n1XbhdNbO
SIV9bEzXGwvK/VuB4fYXUs2fSHhVR1tN2pVAd9WVeSdrAj555s9qV3ZgLjV+
qcqMjYcHttuFN9Lx0U21WWJ+CLkWXz6Ut9FRNmmgIlPLhuYuntijEh9Rf+mb
WZoJidbV0co/MtMQ9sRZ5YMnCVeHHKffK2pgGDP0RMmKiWj9II9l+wcwYzUv
n8MgoHLiXJ1Wbzvs7d1UzC4RGCVCjkgn9IC1KbLIJ+cL+MOXn6zalAD+iz6x
Ig4ktvWHuhQ40lEgsOeZqDwTRrt/S8ZUVuLzKt/siGAS+1zHzHl0GlERXG89
msAEv749rSahFZcmRf7GBY0gpzP4TeOdfFwalxo+voyEYV5ItFMNDcHeQjHE
Vib++4c7RDqtAl9Xz2g1aFH9py9ZbiDhC69degLXzKl+VpXyN7FvwsBl92br
8yMYUbYw7W2iY4/4R4OU8VG8vGg5nNdOx4s3iwve3gRMGMYXm2uywSNYaBR8
gYTB0WxT5ro6aF4PUI86xsTcz4TKXbRuOJLrVbK3dEOTP6AwKqyN2o/SlQ9r
mVBQFsx8E9yGFT277cl7bPyzxc/EbLgV/q4bQ64NkxivNLimtqYfRssSF1nO
Q4i0uaNW879OONeFbVW5TCKz00eqpbgMg61VSicSCAhXnxwccO3C06kHyRoE
A2khuyvGepqQGVzAa8nNxIKhwh25zApEisrwepYQMNx5f141rQObpeUzZ7mY
eBhly380qQPncp/e8DNgwXK1zDHXqdcQcA/gNKW+z3CmT6zyRTkWvR9NnEom
EZyxp73XsBBaSkTxUCeBAnL9cMTPRmxac86ssncEd3lHPds0c7Ho9nddJXU/
oDs70oW/F5kpGzWPMsbxsDXCwdiqEQWHhqTMqPOZ/fTJebe9ffjlWslZGd6P
eVnp937jBXgjpFnxTzkJyZlU4RzjehQc7uKwXslCkkZ0INCJ+IH1UX5Ko5gv
5XCc4WoA+1PGbO0gicEbEgKX39FR2X5g1lFxGGVC97M8zG7jZ7GhnowliZgl
Tf60iS5sNbga9KmcjVbbGDl5xSz8EpVoXhZGgqNg3LxtRRF0hvRUvi8S4N6U
58dtWYDUKcVqj0tMiBRTvX2nDaxli/pGbCbkyG1TZy+0o1tP/dB6GQI/RQz7
Trm2QuVQuERxxDBs3uy+u8KmFWYarxT7PUikHHmenbyBjoUIvQNnxNnwcklq
1k2lo3Hc44eUAxstk1875GmdCFdclHWTISGyquKW4jQdhkXJYWVTwwjKmmg5
8rEeOiuYF+w3MaE5+q9M1LtQ5A67cF05R2JRW34d1/ZuKC636bU9OIY0/udl
Wycb8EVnoXKa4gdHYBpfPE8UHntmv9x+lYTuQFnyAfMm9BQZ1mn8IJEv+FXl
UF8LEmffNsTxsSCyPT2l82Q9VL+183A1UTxXjArbe70DMcv9Aqb5mCgTIJ73
ODeg5dmiy8N/CXwVquhoXmhG45vA9y88qP9XK9i7ltfgo3CG0x3aCLyYTZy0
8Afojs67oHGRROT+XYNxCr3gPL6lIqyGjdA1fyr5RUvRIZ7uqzNIYFpU5Vif
WD04U9nxHk9G8DbPtGmbYAuuMLjvHns4irLYS8svBrzB5FigvrQZiU8XMguz
GP24Effz15shJkLt5o2OVuUgJqdtvT+1n4OjOk7Je7oQe0O/z7aYiX0b6jhz
flPfs/jHLUl9DE3qybf7uLuQlbvM3oJan7+D9uKvojzcv6RqNx9FYh3fraUV
6u0YbbeROlZLovb3+vWbg6tBLsyvMqkj0X2ftj9vVS3ML9m6Bc+R0HRb6285
k4F738TUf5lS5wm3+uiSjVj0cn+0S30EO3J97N6294H3KlMy1XEYB9X32fpR
/eJ5TaE4J4eFJ2wP0eSJVjRG3tlw/giB/g8mkfaLg9iv0OP59QwbMgmT+9uY
PdD0F29T6h9BhXHDim1bejDh0Osu7sNAQFXSku3eftRe0fJ5fJqFE1buyXWP
O6B97v7yhRgWdIRj1JU3lcN3rkr9O4uANv+jWKn2NqitWM97VGgMs94H3u/8
1Q33JLljS18YYAiLjf1Qy4CHouW9OnsS+nK7U167daPA+LAn0TAGV3lPJ26R
BhgfZT8qrxqB+P86aNL5n7El9MfYBMWT08aWsU8utiLw3TfHSxoEvMeupfB0
N8FhnZzf3QiK/xWdn6YCaZi0KEjmj6X4/Wm1yqhVF0x5ac2r5xhI+ZygMFDY
jk5Xr764v2zEPDy/tYWq37mmfVXy8yysWm8edkKwC7fjXsp0HWThcZDfwauq
PTg3ztgob0bg1yalG30DrYiXlZ2WzmVAoT9XbWKwAWlNj/fwuTOhk+FVzrdQ
iZ76y5KG8yMY/CH+58t8HUyDpS9GKzFR68vp+b2SytP7mde8qxnwHLnrFbS/
CQVlN9+lESTSFb23CjqVwtaZ/OnMReVnT3mNRAMdcf+8FOAMI9Bczl45PxaN
bT+8XdyofmV4K4r6xwfDXE7qiR7FJw7BlbYqh29DVFtF0c+CREBSkdrfjmq8
Op7zSuc6lYe84u8YHrn4b0uIWrQAlV+vPG+YDqfDZchpSvIgidX8GlZP6b3I
NWH2b61ngvtxYqf+oUK0Wb+Wrk2invdh75ktHXXI2m8xv3aRhM7n+98O36iB
wuJlBzwYQYqm0oP9OR+QLWw9ICJLQkVnkEvsXgq4V/LqCOpR75NiGS2k0vC4
4xp535XykxmJxmjOT+jPm/Wii5C4Nb1eNEWYDsEQzROvKyhf838W8Ia7GivK
bX6c4GSidfiKwvX0Thzk074buTQCyfD6lTvFg/BI/WZOMZVvPBWk+6IhHZoq
GkE8VF5ezqDfkaPWa7LBroNZMYK27f488o5NWFMzdFKFg8C20tSaCPt6jFT3
qx/vG0GQg6Mi18Fq2JXur8l8QKAsT/G6igMNYjMVAmKhJG7YXD1e+7ofD2gz
g8QVJrxSG4seWTnjgobvLlOq/qH/6X398qMNmUdFjTI+s2Dy6aFpiVwW+ue4
u4RiqPN+WHzVR5PPUDCMKPyziw3Jt2KCqRs6YGpfqZVozMKekreOFmvaYGIY
eYt1kIk9eh+L9mxuhphali7bnImnPGOsk0YdCLx8jpQIZEBLgHY2XJmGI8el
k3xtqLxKP5IkzheF7lWlHU+dSSiNbNhxd1MvnLa96u3bM4odEZ3saPVWDKfR
lmTPktiptMtg9lsZzvkhLm+BgNiuWT1LMzruiYy4elQy8fUA38i1lbXAzs2n
lrQI7FSQDdl3KRR3k3Y3K5wh4Rvc3BBj04InYyONKYkEHL5smS6ub8Z8ya2I
xSQCDJ3mlkC+XNzVHXqRcJxEfGlqzm6557h9LzdejXq/ppBMWvbQZ8z/6TlG
u0hA8b5s5NqEEgxMeX0x2EXlu67qv8I+ZVjMLLvNe5yJ7qDq4+qnwnDlQNJI
BeVfWgVP/72wrAt/1yr7r9MdRag+80CSUSn0fxCfeWJJ7Ok5FSv0tgvB4sQU
x2s23NNdp+5w92CvaumO2d5upFcd112K6UamM6fKvslhcBhYVo1ORGDrlrmu
O1T9znM/WX7mUhdy95REm5gzkB+bI5oT1onmYw9dea3Z6I68PNRxsABXl5KW
rlD+nh8mrFT4oBKPYmsC3P5SfnrBYrRUvhM7DUVjqzcw8NNJcfDSUBnygyKu
9lP89+fV6Jf5S8NOkyUevUIWvFM2r5Z1bkXcn6yiv9wk3Cffny2Sqac4U866
LsmCo8B1yaCYD2jJ+1vXT9Wf3+uAbVJsPbbKFLwqLCdg6Wt2vUemH/WlA8sP
3uvFU+WM0/tXdoJ79dbwQuFhNHktO7ZPnIaAzFb7qECqfoZky8L1XlwiL+u2
UP07nWCb7yFYgShLrzw5IQLxG2ULq+p8YH+4sz2Wuq9V6ZY49IWGtNl2vrk1
bNhdC45Q4MpCiY0Q4UTVy/D2ZEeObyLEV38t9vOm8q788gvJznZYtMgbqlYS
4M/11tOaLYdt45HKu7Ys8D9Vp/uNtqC0XD0rsokJFw3DvU1WbchZP3reK4tA
/tXvTkFqbfAo3dB11I9BnTfZQucXkVh0Orz2ELUeu6Vx3dsUT9brjU/c0iSQ
bDCjl3itFdaZmvGWt5jw773aPuRBA0cFl8Aq/1FcZ7/9vawnBzIbq3qPUbz5
I/Cw3fs3HbUa9zg7lJnQPuRVZyvfgqtBh1NPUnnjZOgjsmW6B00Mm2PPQ7pg
9/O00vLvHxBp7CBkvoKEs97iih/NTcjROEOfovo/tHDwxD7eWnytFvm9s3UE
+15MMTt7ShGmp3/rAOXLjL3iez08ijDhTNTObSYxkVe7zvpFBxzEzV2r0gkc
HmM/FlccoPz/7bSdyQie7/gx2WhPR9HXBceN2qPwzp0fWjTrAscjQalv9n34
89Tod49PFWjuY+FcQiy4VMVYvLbqgeHYDrqoyzgq0mkV/+p1wUpNVmkv5Xeh
bzZW7a/sgmX+G2GONiZkyla+qLxZjpPZd6LX8TORFnR7+IZoN1wrzenB3QRY
0atyQoqbYep2anLbcgLtPw0XY/70YEeXnJDSMRKbBnlzhDxS8TL2lzidyo8B
G9G47xJVOKn7aO8nGtX/rVqOBU5VqLrsnX8mhOqnWD0f9yoaXvLHOBr8j4nG
CoW1rqH94HnZUSQdRs1Pudcn957qwoduX+VVX5h4sPk8+2I8HSyaxUWJeCYE
PTJKQ1/UIe5jnPA3igePEXrKorYdcy6GfqW1w9AMOM3lOPsMfB+Cbq+g/JTV
mOuUcKINYh1XgkTVhvG1MMqd3tAFZTYvPeYwxRceffehjn8h+2ej42+KJ6ZF
EeFhLR9gYB3G6ucjscFzDbaXVOKeu+OKk+0kBFVkEzysWyF8frfqxvNsmAd+
2uGZ1Qo5m1vjy2IImH3i8pBQasLkaWvV/PgRTG89L7Y4m49RR907wy9JBOk8
69xV9BnagXvYXjxM2EV7kUlCzdDmKjkVHMbExN1zcSlTbQh0G5cneileHXo3
p3a9HHv2ThT7qZL4p0ZmuIdF8ULt7I0Faj/zPhoc2ZPfhA1PfKRuOlDz7abJ
KpXldVi7xWJ96mEWIj89c3c/WYpDHBl/a8RIKHBjepGVgvmop97f9Kn5wGHd
33ThOjBYj8U2r6Guaxsk6Gfe4n8+4p0+1Pu2jFrpGWXVYqdc5Gz0IhOOw6LR
Z4he8D/Iedqyn40sncoor8BP0N2bVLiN8hEFgaAxL81MyAq5Jdq8IvE+6vGd
GqVatIaKb9MXYcL3llOd++Ue/O+45YRGDBtFccHyr60/4/h8xZv3lH8e2dbk
9VroM5p9pXaoGpHYeyUkRCuxDsXSjpNz4wTcA/l9l6S6YeNRdcDGnIDC5a7y
Nt5qNJ3fPMwsJtEnEvjc4Wor8v+rMbtzlPJzs+PTx0dS8C5it1UAVS8GvTgh
5GYigluk56oOU77jfPZlXnwFyMemL0ap+dnW+sOaTvtuMP622SqGD8H55gMX
B6IZasrG1XQGE18Om5qwI9pQYsch1w0CWXXPCk2l6rFu3cP9j6ap5x+Z+fau
IxNKy4xEzBxJHJw2Sj24qRLm9/0Kb5HUPGLQwVtF8dBQXeDxqXAmLM9NdtZx
FOJn9k4fHUGKn/Or6s/n5aPh197E0TkCQRNn0iWmOtHx894an5ZRFH2budL8
pw1G2iHunNZMrF7e6xoZ3oJndXOszLtsmJwoFz9fkQS7xYfxizbUeh4yZwo9
KL4M453mHwK+Uv88f51fiGiOZ1qOy6nzVOgen3SGDm6XmJ/jjSM4kV7eqr9E
g4fyp/J3yWxkiuh0fahvh56UwKGvbQQaQ/7L6vjSjtSGaVfdfMpPbx6Sc1Su
gpbm7hcn+AicWOCg54XlQ7U9SlBuB+UHzIubxD2yofuBbmGnRuXLD/r573rN
YO0wf7J4lgmx30a/yiifP8Hpbup6lI1s2xHh3Ik8iF0pWYqn+Jq9dvtiMG8M
Yjz5jDpMSAi/zX7NjuuG6o7T7zZRnsjfevYt5+k6JKx6m17RSaIl7VH18KNa
fJScVCZNCaTb8Yleoeb9p/eedvI5MtDrdbpd9XorFBTmRKxuETCV6BvXel8B
V5+tb72p+cswzKZHQqwZvjkcWQGU/152ajZ7Pt2MwSCnHedzWbD00VY/oFMO
4X2xsYmPSQzeXIw2HM6EwWsuvoQAEhp/wiZ8jDtBUwwsEHNhQXAhRJLQ60eB
5wNORWpeN3zGKRlmnAOi1o+/m6qPyNtNNSUnqlAiMGp2ivLdbYUDh7SJWsyZ
aLv1ULx5fYNV3itKQ4y9dOQdGoFVDvVFHnfbcVL6bCx/yCA0FzbTu8TrcLvV
1vVvMOWj4t+fRTA8wbfV/OUfaxJlr6TmOQJzYb4ked/firqOkFlzzCIcq5ze
iyRT+abZei3CmfEGxi3Xt49Rfp7XOa2sVZUHE6OU8ubPFK9cImqHSzpA/zmj
3u9N4P8AH7YipA==
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk4lXkfxu3RgjkjLaNNGTKKGmSbbiJLYaRCKLKHlBLGy2QruxYuIyEk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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk41Vkfv0KUJSWRStYaLZQtTfhYSllDM2OJIVmKurb2URRetDB6K5eM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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk81PkflqRDlkibxraS7eIntFlH9SjtlpxdsrGRo1wxKqWWFHJEUtGo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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3cglf0bxkWppIkivaEk2aMyUpe8vUJFVkNWsiIZSdKShCKjiBBSSUj2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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnlYjekfxjspkaaEksRgSJqhaRGGcSsqSqRS0jKlhBapaRNxtGgRkiSl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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk81Okfn2RTUmG1FuWolKtdWkIjb6KiVVLa3IayzlBUzlb9bEQnSUKO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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk81ekX5jaKoUVGdWdiRGWkLGUvHqlkJEpCo2ZKliiXMEWllIgryTJR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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VO8bxilFkpREFAlFZSmRpO4UklCREL6IKCSioiQ7ZSlCJUrSYivJ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk41dkfx+/PlGVsydYikdwhJSEt4t0yFRkjS5IaJGsyys+aGpJMlgpF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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwdlns81Gkbxse0SdhOzmeiRGLtLjm8uqKpHEqSU4vNOpQcN9kMS1GtFNm2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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lekbllQS0lCZn5Q9SiayptwkThMzjBpFxlZKCEVIKtnaVFO2GY4w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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8le8bx2WlUtFQKEpmUyVEfFIUQpI2QsoopULZEqFvKCOSVQoZ2WRv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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk4Vekfl0YKN6RlJJORJcrU+GWKxnySpUihVBjLUCQRYqxDISlJE9eS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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk8lWkbRpYsH1KiRcOgRGiSLF+5SFQyYgghy8kSaTJaRciak21EUhp1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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4VXkXPrlM5klRDdVU4jGh6SQzKSp65Tq+ITJIYkwql9yVyJ2SM5TJ
pYNQhtQZdEaEQzXkcpxcD8flkEuZvcvkGvOJCt/v+2M/+9nPb6/1W+t93/Uu
FVc/m3MSDAaDTZ7/v9e5GlYLvqzHhpIfpHMiKXg6rgn3jehALP1WeLiewiDL
Im1/oRApKvpqYb+R86TGzdHHRQjgdWdyFyiItVWTGfrPwWQrapsHUnhcrhls
PNEHzFzMYlnTeHJdvPfQ20Zk+0lqul6j8KpLXzyglYHWkSXDJhcKMk/KLGtH
anBWNusP2/MUFnzOvmOf7kSqvc6udc0Ubk4s7VfPaEbqpSwH3h8UqJitOYNy
vbA5bPbDDXUasgblLKlSEYaXuyoC+ij8PBgv6PmnFx8zt0gWWNLQ0N8SdaKL
hxC/XSmHPCl8lZfvp7vQirzCNKWMRxRmIl9vmn2UDJ6cjXwMqQc+x+WOnBbh
5dP2Qo40jSWBcmBOxhB0Gor5shpv8IvibsPFzS1gBffMfiikwLrRtD0quxre
j9OZEb4UBHFmq87e7saLwQmTPiUamzdt/WdRXIG+VRIP73lQYAxkRFut64W+
7Aavb8UUvh4wrHFK6MaDqCu2x3ooGP94vrZ+UYyNx65JR4fQuJmoF+5pVgWP
n4pNDhN8hOIlGTfzZmw7kNR49A6FhOmYlfLUTnzkuspLCymkXeA9Lid8juor
ewwEU7A1YMvWKHThyJr2L5OHKKS7s7Ji0jrxKHJpzJ38z+A82zakI0L4PWZ6
yBsK8t8Ez+9tDcRnQfHaAwSPe8fepaWk1ELy6MXuDMKvccQDxv3BAozRxYMR
pylo1FVtnDNuw39O7FErv0vyHb9Zo+Z8FcoBJycsSPydR/w9s/YvEbnd+Ne3
l2m0tksJeMf7kcAUXTp8hsZEqRHzz3dCtJ+7eCqnlEL0s680VUMzsU5dQvI9
if+85w+h65X7sBnxOBhP7svl31nd8LoWIwyTr71DKDzz48pGpw4gcSH7hkw+
DY5DtOhDYg16TybuLPeh4Jiuop2U34srH7W7kw1pHLPW3P1MXYw5XeUQf38a
vyu6JQwbdWHIWCg7S/Rmf+ZBou/uDNzONDfuJ/dHM4PcNo1m42yBo2DDLxQm
3q582C07AKnh7D8jiL5aE/cEG7K4CPeYsltyJf/Lzu//vTkDIfdjsgdIvLyj
OEzf/CbyOqy2hpJvj+r0MHtOL5yaQydv6NKIDjq6rV2ej4GO718H3aDADL3k
prvSD62FC+yoTBqW+7SD6v37EKdwZ1WUPQ1/5xMqd5kC1Og5WbDJPFmfyHd9
M58P48HWulpS3+Mvg+2n34kx7GVe8PA7kj98Qu5oSjg41v2F+uR+sdnP5sKM
Cjzp19xs5U7BYfnyvTY+HxMBHfm6LArt9Q0TJ036YNmif8Zfk4a8g0R52CIX
gcv1yqNnyPxKVsyJ7Zux6rf4oZAUCpFr7NaOSolxeMvnoJvvSf9pTj1rTzWB
0/JjGYvUtyaSnfftSBUeFJ1Zf8SbQkNhnEKJO9G337hVshsNp9xiGzvtNsgE
Lr5OfUqBE9eifOJJNQoMgniT5yhcd+3a/oLfhgIrvUvbSigoJ6WXTf7dis+x
6RwPkv/ixr5FzrUuBLn7uGiMEHwj6/PaHTmYyzqZWkr0ojWcHs85WQ6pg96z
mm6k/t98dBZXCrE0JalmRPj6cH5uemSsBQZ7dTS5eRRmvRgM7Sc9CBm8Pn9o
hugtX6rO6Jsa+Fdnqn70I/GVxRH7vstBnaJ7+l6Ct+nndkWZ5QG4Gl3xnD9L
Q0J3Y1O8bj+aFBQdtW7TKOVJVTce7cYYt/uY5n8p+B/eP8h1jkHdx6IkY8LH
ZMLstceJ1ZCYVnokIPO9P9LU5ZexdnzSHVfm8oi/9CqWjZj0Y1mj+uivtjQW
0hq2Wq/lQea0jEkM4W9MY+knx7pK3JCYerpI4hlDqrrgVSC8zjR0DfG7Ofn6
Fkt0g7FVIdVyhcxrjlLz13JFmJtRfv6J9H8xSaumrKMZw76J9R1ZxG83/Q3d
nlvoXZ8uek7qK93p7FWyrw9/nVBymPlEocSeFcsrE8KcPdCmVkPq4w71r3bm
w8bus2Hlr8RvLoyNqe1rwlgc8a40gn969Q7DXSVYUOOU9hD9RL8b5UxpD4Jn
Kvv+vD4N66xPug9H+uDUJ7Q7IEPjUMAOu/dbhNieWXG+spyCyhut0jtLzzEf
GJbrcJHgV7bPotirDqahUxZxYRQOPh1P+vtJP5a0ysaiAmhM7d28+sCzPnjb
xDFTSL5cCdF1b9N8RHp8N8MmfGlXvKgq/NQLpn1Al58GDWNDRR0rKxHMVQ+y
v5imkC3ldcgKXfDuTA7vWiJ42WWz60xewPr7lOD76RR43cvmjT4v8SpX2lYd
NBifblVlMljgN77ScyB4CdpMjrhHVuCWvunlRMJPtKKXtFdDLI5wH/qbkvMU
p8bp+DoeevOz2O/IPjCsVa47sLMbV8vcJksZhN9ij6nLO/rBLSo0t2TTCBOZ
57dEtWDCyCw07x6FLLy+qqtUhYkrsZMTZJ5mpOUSdo7WoFa+LHrvJaIHZmRa
QW0dCvpPBcwTfzT9XjY3iuqEj4GvK6eV+MX9DRUXTPLha+45GU/w+PeLRZvK
8QY8HW3KfBRLQfbfD6paC7XI1pUcTfWnkCeKcI53r4KiXoiQRfQkocMXuJwf
Auvc2uoiHvGHlXR6+84c7LIIOa1B8sn0rUsqN3sOJXXqtCrZF7ad/6hczW6D
7ZENEy7PiN42ZSbLN/CRMvPXVss4Cnpz46cyGG3g8CvbA28TfzCbdnUWdIL9
QnPc4DnZN9ta7wrzmzC4wItdSSDzzfJ2LH8lBsTSZe3aNIpdftxsUfICvPHr
3K4MChZ9Ch2etztQWL4od7CagsJGybZKjhCiLatkwrnEr0b4y8HhLyGRd6WX
/5qGxTlmqktjAwple4bXkP43xk21XttRjfW3F3xVSL8P73leM/q2GoLmUsUK
sk9M1Q2s9guEWHHbaWVdRuq7q5Ej6hxAbtHDVbt+pvE0mdcTf6wbzC+0i/Q+
UvgfNmrIWQ==
       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c81e8bxslICwkNUcqIFEKp5JJKycjXyiwlo4hCQpJVUSpJdoXKLDuh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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81GkbxmfFG7KrVErJik0H3pLIFnUpskjlkLIlIedCWxMKUViHnCqH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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lekbxqVRKhJNUcqW7C0USeUiJSMiMpZIqSmF1AxZ0pTQVLKVRLaK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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk41fkXvmnGpBTJNpaSkRb7Mkj0KstktCiUXyV7I0laJDMoSyFLNI0k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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VH0bxoVoI0m7NUISWcru0iaVlGgnslQkWlT02JJKWlSUCuV5EAmJ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41dkfTqQSWUK2W5lU+MlgKPtbQqWSmH6pmJJQImuWolS0yFakLKNL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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk41dkfx2+LqCxlnxBKwtwyaDGFt6WkLFNkKeuIQhEhahBlb8HMTVOk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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4ldkfN35KWaKNxtRoEbfNUpMa4pMyTUUz3KkYWSZbUm7ETLZEQ2Rp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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VPsfxoe6tiRJSC5FtNlSSaJH9kRJkbTZci0lS0VxJcmlRUQqIXuF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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk41Vkfv1Mj0oKi9A6iZG9IljTVh5gWFIMkS9mHLNkqFVOhcCuJ0oIS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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41GsfxlGRNclBSkoIJ4okUe4U2VvsWTJoO7xZOoRKvSIHU6QFKSSD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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lXkbPhmfIRmypogGrSo1SBPupLQpIRKVfRmhhFFCJFmGOmSpQwuf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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4lI8DF8oMaSgqNKyIRAP1aRiRyKhUSLK+NI1QCkURDWUlRUYhRHZZ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41dkfx7lpmaxjVErJkmWiojLZft4UssREiyIT2VVCCoOyp6ahIhNj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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk8ldkfx+WnKzFihrIvJaGUClH4lL3UJKaimkSJLEUjXWVmpAhJt2yR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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4lOkbnrAbGbQWlbaNpFVt0klk61baotTmkKyUapVjDqVCtc3mUEmk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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk4lG0bxpUWla0iJZUkEdmSVDgjCtH2UqishRAqJEq2V7wVyhYVo0XJ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk0lWsbxs1DHTNlcVRCISFRmbroQydDHFMyK5UGlFQ+R5IiCZnqIDmE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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41ekbxg9ZG8lyKGt2xqC0WAbd0aaSGiY0KTP2n6WiCSVL0qKQipJo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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4ldkfVypLkSyFkiUJM5Ut/YbGR1IprVcbRRG6opRSKLpadEdGhOxG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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lG8fxa35ZUtSWVKUJCSFpNKhkJQsSUppE0ULpUiIqEiLpFCpCJWU
LfuSfaeZwRiMZcwzw6BQlMryPu9fc801z3Xfzz33Oef7OconL9qeFuDj43Pi
5+P7/+fIr+0Wy8MbMdsQMV3cyoZTkPHOSelK/BpVihVRZ6N15WqPh4wW9G9Q
fNxD4aCZcelPoRkDBVt2N239y4b8B8aP9jAarH9vaO46RuB9h0WeoVADHmxw
3se2JRDRdMJc1KsFJzP9d0+d5uJM7u30aZ8ymHm6ehms5GLLqrErz+7Q4Deo
kq8W3g+jIwMKH+0f4nXk+DjnIIGFFfsvjkq0Q+4oITT5uQ+1S4QcvXn16HEV
v+tyggMu5ZjyvIouyFMf8b/eRiBpeIfgLVsGWpfM0JLjOJhzPRxnFtgBzbKL
Yl8/9MPD60fYE9tEWFmGpp12JzDovnFT0OcCFB0QF5vmI1B70HKWY5IJv/gQ
h9XOBHZ60PRv6TTA/LhBy5ArB6UDt0TGTe9j5XTNt7wjBOZkVXYui2kF/fvK
bQkzHNj7Se189K0DCV88n9RwBqA5kDwxTqfhUvBUbQKXi+kZ17I5sS5ISKhd
n/eThd1df6/1K5fi4n3RV2W5BKwLAj6m1bTi8T7FeR+3cNFmb7TtfG8nRvsc
Fx0o68XbqNMMH4ICRdNU+potfVDzCSg8mFkKCx7npr8ogUD7wEucC4G44JK/
/qQjAb6K4hyZqXQ83TG9oLeAQOjKDRGtFcW4fkJQdmcyAdOEUmrubSaUFFlW
B4PaQeH5U4aDomHfXSzhfIqAOWsg8GJXGZJXz4/NLmIj6tyLE8SXZmhtsbM1
sOWg59hUlL5SI1q11fa+k+WC77Oq+9kVebD2HF1h0sWGSnxuk//hJnDv/f63
UIWF0kabsNXa0TisPCYeRN4vZc9N1Y9NVci3iDmydAcBqYROpQzBFJQ3mNYz
7/3//bv/7I6+AK2nt+/qk/pqVHhsmVhZhrX3JnjUZjZiqq9fF2muw8pi/vk7
vvVDfnaj3auxFnAtBq+vkST17Oqqs+EpHVep2pdraRyYjGrLebMrwIeq5zrR
5PqjczbnUQHJs7UfL4uz8YJ3cySEvxNmetvv5Sj1wIPu/GpdQgksyt18V5sS
uJ6507jyWBYcgq4r/GdGYBkl+YygdgF02+fTNOIIGBnsUbdqeI3D7k8fKfoR
KL9szz/s3YH6mqICvX9sBAq0mZi7XYbDrgPrnjgRGFtYdE1rfxfGi8Qp0hUc
EGlRW4e3U6Fepjb2NJoFod9m2+WcK6Ae9ZRiksxGn1XmIZ/mHHz+97dG7BmB
CufTiQPqrRjM6LphG9QLJfGkzcNvaWBWKLZrRHGwL8zcUeFmHZZ9WFDIkiMw
0u/481ZANUKFZ9k2O9gQ2J5IPexJB9MyJqKYXF+WpzH2TrkLKouX8Wsf4yBA
w3mq3ZGOiMvzG43UB1Huy33/IowBSwv18UN+LFDyr4ZZvmqEbO+ir+5c8v1a
+549XB4Nm4MxY0sOEzDhNhWpvv+E0uUCkYErCTCVUoSztcpwrW2JcWA7gZXn
ZjSZbyigz8VEZBzhwNxiG9XmYw8GkqUePNxDfq+rmelYWIXe6RADWdIfF6Rs
xbqEWlEjt8k/nzUAZ7ua9unWrzD+T9+D09sHkZOiWsFLmTCKffBUVXMIv9gp
4ad74lCfGvw5142Avkq03t/HdciYUn9v5k1AUt7vomxoC+zuNs7feWMAXs+6
TQZrKtDHP/P47iMO+g7VuB/0fYs+8xf3JEHA56jG7ZJ9GZBgaF80VCT1qF+c
ZJFRin2MryU3athwk78l/T6vGyaH99Cq4rigpOXpO66pRZlhesxENgcRZlN9
S8UocDONDjc/PYj6wlJewqFOLEhXMQn+zEL7H3otLaYN26o6C5NiOTBK8Jr/
MTgODodlC3YfIHB8leX01ogcTASoX/qYSOBFjvHOeZkUpNoEZZzhsmAiGMn7
2JgJFanVZyPuE2gWnd51y7sNqv3Tnu2XCaRbSYsfd+pAv6BLW6gOF7IvGomd
3M9QG1ROU5tlY9mnjqwoegUafH6k+j8m/V/V7Mu3kAK7UL3l30o48Kq2jTPP
JPNbO2/rolAyf6Vt1Nz3VkD+2O+B+n0EUqiv7A6Qz6+VDVhQspGF4yKXgvUN
mxAj8uSCvgsHDuH9K8/zKKipUnJ8GMMF94zOoYliBgbrGhZJUgZgrrzgjVdr
Lm64xdqaTrIxFp5iU7g0A4Hr5HTPNpHnz1h/daY5Ac3CLN8q0o9+e36ccJii
YYPLcdULW8nnN6R3RW6goF44onulBgvM1YIuvMIqtMXu0TunRd7X/oYk0awO
sPn5jorfbYO2tM6o2/sG3PAUEXCy58D7bPM0HaT/eG9tJ2RZGLc/I8DHq0E1
ReZytD8BaempOQ/NHlzYpcaZ1z2MmAHaT2mlr/ixyntj6/UBfNTxGZyYoqLL
m+mX6s7GROGJ/Ad2dITuTV4bv5oFun3h85aNLdBQcRR5NsyDW+adTW+zKdD/
em3X/XoObk/7C6e0NeDprgf+XnYEZBj28R2/ylDiMCR54iiZl+aqefENz6Ci
s3fi3n4CdDeXB5FWdIzrJOfLzQ4hjxY0QCTkonPAjePyncCt1CzZ0xtbMRv7
b5pt2Addw1hfyTv14JjkK635wwZNdt6lbYvK0G9emDLe2Y8X/n7GHntzsH3U
e781OT/sZA4/UvtCxXjt6i4hPXL/Mzd8KYtfQ9ZFsVSYzC/qomsS+T0t+JJ9
t+ruV1KP659E3uXRIeVjv+Q8mS/aCU0eMT8TcOHr+o0zpH7tRk3bqx6XYbtl
2FvRn2wESEVV+5bXwqeunGVJ7hcRpjy3ypqCT0Vf/M40cMBn1Xs5tqoEHkq8
1aaSpP98l1pv9WVC/Fqq0+J0AioT5z92SJajdNLQvomcBw6hX7I3GnSAtfLA
t89yXJTKar7mOKTiGa+SeWULAXGxjTKDA/mgUn7cizIg4PDqzG5lhypQL23M
XRrJhq7qR9McZg3+6HFfDLHYsBaVWhIulYv6z7k35obYSDemVRX2UMERfBae
ptePUOOlN4Mz6bDeY63///uuNH3ItLFjIH3k/dD+jH4osWMPnZW7j+/f7XYN
nSTnu+I8xnXLarD2vaXzneNgR5Z7dsjuMsTa/XZX4LGR/CQJYucqUHqu6dVR
TQLT6Z9eMYua4ay2PvspmS8yxJGMIG42Uq9ejUgn9XDk6kHhM0QdtK6VDraZ
cGFi9IKmX8HAbFfk5jcjA/h6SnJ+1hbyPjxzLNVWk/vvl+UY1FKxZInSz9V8
w+AIpUTeLqFgxWJpauGxPjhrr1D1el6HKzEp+4zDCDgdKE4Qj2JA+qFb3qMN
A+A7yywXGbqCcvF1ziPk/mN8rprBmyvxQ2HRqtEUNpTDxaL+iFShbsSweCSE
A6nJBIsRgXoUK9a+u+JL7u9wgzu6pwKm2Q27Av8j861NTIFl8RjavOTyIgcC
9msvRMhubcLnDy4BvuMc+CRFZuvKNmCXqFgE/SPJX/L/Hf3n34mTxDWGuT4V
fWW1I6mGr3BTbRXvNMkHeQ8frZjrSsS8P+ySmd0kD6knZce5hUMk3+UVl9Qr
wX/9vLEJyaezap0Ruf04e5lRMLSHjneBv32b0kh++XqQ2/aOgtr4ruO3lhCY
ejDJ6QvKxfS393uDyPPJl3/0LlIoh6r0uFUaybfayo+tX6c1Q2lus4DiOlI/
bp/ym50osKa7O8qIcSFiE/RIK7oOrZdsWiXjSJ7uv/+ni8wXs37TN9sL2HB0
VxK9LteO0ESCtoPkq21WQX9KmupRVnbSce0uUr+7evlHqstRY6jgpfmB/D8r
IuYaNDrhEK8gKKDEJXliXpZuvhsYNAfFv+T5LzEPWZc/ZeLdI4G2TaH9ULGu
35LB+QB1jRseH8i8DJCS7PULrsCIk+TtQ2s4cNsoniq8oAu11DfHe8f7oepq
M6u6pg11Fs92GItyYJYXEPc8j+SPt5ybIoZssNfu+bdIphXX/xIN6/UGIHu1
UT9N7RM0I2e9VsQTiJpME/qmUok1FX/Hf+wk85iy+U7wkRhI3+P+vXyI5CMr
D9EPOQ9xd87Veprk72VRUdZy47lYzxuTbyD5z5fJYsqF18JDa+bOq78c+F1N
en7tOg1VeXSf00/IfiGvdmWRJR3zdYgFwer9GExJrSgOpuLlzwclZvzk78eF
40Xk6Dj2oSuQ3sSGHDFr2cxsRx3vyo8yZg+WPI3o7HJthXWa7TGWPRuaU24s
yaR8vPF59LqD3N+PNaodpN2IjVdjZ+gkfxS2r77g8YaGMCU91lRCP+x295dt
96VD8/UkBkd6MHFPrGthfQVCO4QCDrwj+W1XeqUkrRvf5zO5Ft79OJz461Lc
sVpMCs+rGbAk58epmTtdt6jwYu6Z8rhBwEXwgW5RIgNjmw1t40jeGHvcxxTO
KsZW6ZEMEzJvfUyZp8KS0sHHmQvu30vOv0DzdRXdSahVsd8gsofk5Wpa00a1
YuwUXLx/tzap9/YMYsatFB8aE4bNaglslnxce3O6BWtVxv4LLCJ5975hnK6m
Jw78tP5tQvqBj61nfzIrBFwJ06LFJO+PtdywXkzk4Nm+tcRtsi/I1C1tvure
ifVS19osng1DfFVymf0x0n9xC8rNqkk/c/hTctPo+Ot8QEdFdgh8GifmD855
QThFlV3y//V3/XLJFu2BjxtDU1VrGFJM2mCBWBX+Gsjzksi+1Tjds1vDowFx
IZ6ezscGcLJ44qXBunZcqFnk+6+qDx6clZvGlBjw0BSU01DhQbvYVLA6sRK3
17XptZD+GaKoPDvypxjxo02a/ifZiKh2Lsn69xYrvUfLdUjeNSlmStfM64Cf
YPY2eyke7J5sDgg82wxL6g7xQB8W7LTKOgaEMvDphWhgvgUBgSdF588foOIN
vc1Nxp+De0fjJXYtaMHTlOrZQ5akn7kdBxbTWyG80aVNV5GHvpfGo9//S8S0
xevEYTLfJnST4nfsp+GsRZ8bdSmBc278nnLlbZAYnXxgpceFWljLZYnbjbio
dslqFZNAkRHvaDanDJFdzRmxJWwwKfeD0xRrMKit+d5MhoP/qAka+oOVCHBN
8cs5Ss7Ddbqxt3sfoPxiZEgl6R+jV3uqnXXDsE23QuA+OT/rC6dD7jozEFbS
XBFF+vX2/XuS+yfrkP6BLd+8nuTdLJZT/sF6bN+2aP4FGQIGfyKu8JN5sbBU
5gDlOMn3TRRfLrsGTPeLyyKTOXh987LHwpv1qJQ8KjTnS/Kege+76g4aJNVP
6V4rHQDtUwT/4kkGks+tG1bWId+nRDRm8YlUyL5pf76V7ONfdG7O6w/uQYxf
dMIgmT/HW96XTyxsgfjWxOtr2jhQWpE8K8DMh+y0qkFNMdm/T7VU5Dl8wbFu
/s5icl4GBqfp6S6lgyhcUU4l+jGxq2JRo3oGdngKfH1Onl/8yfLfGzTbcXeJ
84yuMRfnrhvIy801wywa6drdBH7OTAc/t2Di8KWpbAEVLtKOn38v8rALxRIM
z7feA2DoC9+0cirBjM8xMWUyD2zv35NI96+GPJ+8l9EsB+Iad7P3FrTi8xnv
UP/tg7C+euazfkkG1KSfbM4nzxcoYlPgdqsWA9VKb9ea94MWEWjkdYOKVqG+
07YLyflgRHVb8i0HReU6wSZZBLa4mKv9muuEtP69gudGXGQ+F/ELr6GiqUxQ
hCD7+DvPUAExhc/Yu+lJd5AhASXCfejPdDBuMU+JZR4nsH+Vt/1oOA1leuGu
6b9ZOLe9XMTXugEhF2dq//azMTLv74mk6DIcLnlZkkr2t+72NTt0HrZjIPJ7
QALp5wjRn6o3UxMx27lzp5AP2U/L49bmnKxFDM+w88oKLgLO5FiVfGvHr6fG
PwNc2biQVXZoiTYF6sPeTirLyfuNbO0qnXqB0g+haCf1tjlWay42NAOHrk42
ueUQeDs8stTiyleordoS957ke4t6+wA9BzqcVmc2ENUcPBOd8vDd3IE9HqU3
NLcOokf5TIREbBecLHO3TW/kQGXR/kW6T6mgJY2dWKbBxYNND06La9XCwEky
9sUYB0v4Xs1rMWxHOO+Du5daF6K0jNZ8yqQh6Wjpl3eZ3QilHbW2LGmC86q7
QZFHCOiuX2DrzKDDO4vvuUQvqR9V4XdTsUWQ8OJ74BBIYHblwmO0x0wUyevP
GO7rwHHpgpg17BaoRF4UzCB554WiccJ7rx6yPzfI/rEdgZR+RS1X7ws8Zmqi
HJeSfak7LO9zaSnuhIXM9ytmw/6R3sz4yhZ8k1mhuL9yABEzmmW6alG4qvbt
ZcgJktdsm9O3hrSAr7SYGZLHxfdKV6Wv2eUYG6SVmWhxkHfrhJm2SzVMrAQr
xkl+1Z0xb01axsTlTad7TZ0GcY4jYHdFuArr7MrfynxhQ5AIEpAgefNl3BWZ
UBMWSvl0CwItC1DU/GafP9n/9uYfULbnVcDEbUK4YQ/J42IN2UF/8lG6uvmL
jgAHx7cukk8Wa8O3cRqllDGAI7mO8XLeHZhx+L5TwHYIYykT0kGnKNCNLj1n
wyPw6W3qfubhbggwJhMg3417v3rmRZiUopauoLCJ9H9ms7WvqkcN5OMN+yeH
CIRiaiy/loKnEYwUL4KFHZcU9jb7MdFTVxOj96ML5610G77MMiCgtMTKuIns
21UP00TmWqGzYQ3Fp5+AanK1/FR4K3iash2JJA8vT4xwbKLWwrfsx4UDDQTu
aZVfzchiQrloYIu08xAcHq8S+rGtEx3RjcZHv3LhMX+V/WglHZXiO0yF63vx
+nek0q96Bhb8SDxF/cBGzLVvnge/0JBTMb1wyx0urI/cNn/+Nwfq5Z02z8i8
DEz40iG79TK0QrTio0jeFc8O0/6TUIqmyn/+bZMkHzsess1yzYGrUnY/L5nk
nbeNve+ik1Bm+23VsAmBdV3t/xbbtcK8ZLmzDNlPjAoccwLVc2Ch57L2/3yq
IlHseF6hEy+7odh1ahDpA2nedKlkEAr397lrkPp9KYT7ck1IYllOFcuyUbov
QM3LJh5vpEW+i14koPerV0ysmoo7dZ9Cqmo52Eu7+FB4cTtePTMrkc5l439a
ihWY
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk8lesa3aIIHc4VuegKaTAlGZOWSkdIoZQMIdqHEkp1pCi2KamUDKkO
JzLEcbBNmYcM2TZ7G7cQ7e/biUupHDl+5H73j/f3/t5/nnc961lrPSpnAhzO
rqLRaMnU+f/dT9uaE6YxgitmTXP1x95DrNHuZuUAFxXdLxiRQiQKhgay2p6w
oZ3lmzy1V4BHN8tjNIbf4Nzvavn715KobP69t/1SKx7bpb5Z3UOgj2VklTE1
gI9kwY1ZHoHjZv5/H+LxYDmn3iEbMA6P+/N+GU/7YDnYcslGVAANF5uMroS3
cPRejqjtJmC4HOgeENqHe8cjpb3yCdCtrMs6xjjo0ua9VBLm48aMwrSnQi5i
XW8vs06RuDVf4nn3cA2sGyMGdS1J0OIqFoX25uHv7ZNfP7iSIN0k1mjktuJ4
gsmJbV4kgic9X3VnFKBwn3Nemg4Jzu5V968eLEfyd6acjC5V77ymW9m6HLg+
rxbe70HCQ68k/JRnDLYGPisodyOR0PLDc+JdITb36S1tvkhiISCV31T4Bxbs
FoLvulPv1uV4ns8bmN/7xiRWCeA3E6qY9awfUcbG42cCSfhsU5u4UFeGQqmz
o9m/klBiB4ZarWXitBp9fcVVCn9m/JrHobdA85B9d4Cqx1umX+NEV2Kq3Uno
FwpP5jUH+vKlXkQLya9otvAR+GWbmVPaMLynTh7cLS6ATobaEjOXA/VJaYU9
5wUwX4x4Tn4Ywec1K09+ejYOTfussuLCWvC4eyXc2wikSq8kcPRaMfG9O2oy
nQCnSmTv7jV1CFi7v97pDgn97Izz1pJdOMthfJX8m8BD259jVgYGcUvx8+Sy
8wdIh+VYJIQ0wKdpyV/tEMXn8e4fT+36MaCZlzoRQWJjjJZbajcHQvlzDPU1
BBRqft0RqtyHGZ8kDaYtH+tz9WMnrrMQ71ar8OkagXFGpOLklWJcrXsv9dKa
xLkm2RPR14ag+lTmtctaPvQse8rHhjiIp880aa4WYFF+cGx0ZwVWVHTcdPeQ
kL74WV2dVYVAA9Nh55PU/PJ9N5gvN2Gf9k3/ZBaJxyaTw00TQ7CKMA3bXjyO
TXOMatXVkYi4XNR4xoWaj+tatvrbIdxj/7iyvpaEjVD0dcNHXJhOl3CqFPnI
2iSjLGfSj5SbhwxYQQRUrQ5l3j7yFtMLlzY8cBBg5ETKrrAsNnatn14QixVg
fGBav6foNVJHf9RKCgsQ/5dtp3DCINIGVFQPVhNIjy1Q6OS2gD6XJlN/noR8
rS+TmdoJ7fnA3+z6STjWTIFnwkPlqKuejwQBnqEdTaDTjsULH0tpTAova3xs
V/QraGw3yeDZU/pUdwwY8mqBRteF3DYpEtPt4THFfWzM/vrf+642JHSDH7hs
+dSMHyljHc1JJEolhme/x7+Gv5ySs/c9EjULvlrzR7lwHlIJMS0jMGiXLps/
zEWd6vRizH0CJn28Lytp3XDYYDP4jxkBC5Y16ze5QZCVjJ/l9UnEWtg+vP3u
FQylXocetyBh5BouXKA5iF2MV8c8KP55QfduMBX7cS5b5EhvHwHd3Lqi6QkO
Il6K/RjxFyCYW6b8L/cSnPRboI9QeGkrBTVD8vnIUXozrnma8tdSantUTD++
hkdKqkYQkG4OtxuNrUNXk/B3vTECm4OVnPrnuPhHt1H0YAIfCeVxqTe+puKL
ytDqxBMksuqZop6eLHiebJg50UWgIKlWxGhfOwb4gzoxLAIjcbbeq/vaYZEp
hMtnBfBWZk8W6b2B+gUDi6BqKk/cLVta+X1Q3yC0sofKq/gzYWMvJN/A+aqO
cuVGEmV7x7b9smMUK45c3+D0UXg4hvlsZCVCW5P7to7ys1jxA2f90R70nax6
aLyFxPjZlMnA+w1QpR37vbSN6jdla78KNxGBSRMK3VTe+Nt+THIyYKEu4IVR
ej2B9WlMx4SLnXioNSEpn0zCTnGP2OK/u/DNX43n9Q8J80SpuynStVjUlvEw
0CQxe344NFckD1O1/tzF30g0XOvWyb54D5WxfzamU3h8zdveWYmxICox6BMb
Q2DpwTpxptEAfnl7a7bJjA+Pu/F60Z97cf2O0lBZggCzn1+k0XL+hOTuCA/J
KySOvPLKl5Lpx9GXs0ufaXw4RTfYT+gzwaSzLPxsqTyNF5fOe94JP4unhlIW
BL5tFX1hWtwNWVVmAOMBHwuRDN8NwkOoN28Y+6n0PQwt/7JPOziMHRV/pjvf
H0erVvllWYNerEp0nzB/RMK9wLp5MrEXH7xfx27u4cN7MG4X3bEDA2otyYJP
1H9pp08LylORzKjaWUzpRcmwao2nQT5IOIt0nKX49z3wyWVLB8RDZOsu+1J6
/Srj8q2nCw0cc4aDDwmL0o6jHjve4qJt4rqBJwJs2xRVVpXDRZGXqaxIHAm/
Z11ts5RebegOEiJCH6Ac/iV4gt6LLZzGEv1XBNiHncx+/LsWuYWPjxXLkzh8
mE9XPNIKWSdf1T+ySYhI1c8sF7Bx7Am/R3GJwJ62avnC0k6EaVV/vPqeQJ5U
nFz1xm5UjrtZz1P7SOzMzo2H1NjoDS+bDiql8k3uUb6hYAjv2lbSgqh8CjvQ
FqOrzEVcafOOEBsBNpVHzRU5Z0CfdipI+xyJdrs7L/nF/XCucdr+spFApmvm
I7OqCqh992eLU3yEuac39BT0o305K/NiHh8N7OWjB8QvYatDpUsYpQ8twQ6f
8pYaDB4IZZ/6icpTun2U6uoRnJrnJQsoPdKyEv/KCRnCF9vwm7kUHu/gig29
VV248OhWawClR4mPIZtCt7fgefvW00mU3+XjGiL80kpww7GkkEHxvzlV5baV
ZCe0XC0fRgRR9TXnIy8PdaDm4fpWlQ98uGb2Ps1zbALjCftOHuXPDC/vO552
XSirVFtIEidx0uRZfnNIP3iqZV2czvfwKL3ySbShHfYijkUD1P6/ZazUvqu4
EkeM5ySi7lL+kqt7En/nBiaCVn03pvrzsA6mM5/n4dL5nfvTKL6O3HQUPVY/
gHUfFVqe11B8Mvad8hPUYEqmJKb0DIls0UKPNtdRzAxnZxT78GEsY39Q/z8j
OEemGDXxxpB12Vt8zKgbqfPB101FBPgfl6rFkQ==
       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk8lWkbRqaMLCHF5BOKUU5FKNXoEiU0slS2bDGVJFuRT7Jk4qSF7MJI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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVWk8lWkflhpNkaVkSmE0SjWSYyJ5cZmJFiYKESFroQyhySlbmZmMMJWl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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWGk4lAsbFi1IKkopItmSStakuhUV5YTSQkSFdGwde1Ikh5KyRIkSIrKf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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk41ekbxu1ri0YjJGkqNGUpkkwztxMTicgykp2xDGXLaFI/oVC2RKTI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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs4lOkbx5UlWimFKAkpZ1rE6PRVSpoQRWtZQskUcqiQVH6U8+okYdNi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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4VfkbRwvTNZSUSFQSES0zMbR8RFqezIS0yIwkg/zIlpFdMeQia0JG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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4lf//tlMooyFJS6hQCpXKLcIno+wQKkmUIlEyoqRsyl5FFBkZISt7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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlns81Nkbx4efCrW5VVtyD0XubZsSH1GW0a+fS0pWDEVbq4jtQpRIpJTV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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns0ldkfxg/GJQnluAyaIZHLmJBKbg8WkpSplVQjdyWFyag4qdwbjaRI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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4ldkfl1Io0ZUpuVP0Y6LBSI2iqc9NQ0Yp0hTV2EmhbFERJRUppKQs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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8lO0bxW1FStZXIhIlv/aElOogWVLWROVFSLbKEkUpWSJJlJAkZF/K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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81NkfxmXVChu6kMiy6LJJRaui9VCj5FJqkZRr2PnpRm6VSy2JrM20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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk4VXkcxq9IkkoJRZlQ9AhF0TDpdS0tljJGiEiyRihrZUoqg4yIiSIh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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4lOkbVlLtEBF+bbQ5LZXaKEuJuW0pv01ZK4SVWuscORRRG0IHmhxr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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VO0bxmWvFJUipRT1SoX8ULRcIiklRZElISFZSrKllOzJ8oYk2bOV
LUtISJaxD4axhpkzY4leCUne/M7713w+Zz7nOc9zP/d1Xd97h6WT3nVODg4O
sxUcHP/9LuWu0llYrgbVn7jVO8iE+S2xoIP+j9H4wuiu/lUC4akL2QIv3mBb
wPlwjSsETo3X3NiyPxudYcLtM2cJSE+fdjh39C0uKlN/6e4hkJRY5TcY0geO
vaZRzjxMTOtqpqaufQdlkTVbLeIJOBe+MKLpDuA6TWRB8RALF9/NqK/TbEMN
ozKR1czEWNN8QfvZNpx6HhVh7c6E3vonr2TWtWC3ek1ZPYOFcNuvRFoKHZWv
Eu2plGFIXOHqqEInVtbr+HZUMODOka5daNKMq68Sgh78zUSegYpvTGU6soke
4TZdAqt4dje39HZAMsIoUqyLjVLmY9UHzX1YNAuY9DzMQI7IXhen621Q2+RW
J1U0AvdNPBu+TNVC91Dv7qFZBlYnCn39U0oHj8Kb1cfsGTCXNriRv7oYjdW3
dt7nISD0WsYk5U0nSmRXqbsUM6CiEDTzh1WN7k7Oc7sSmTjhs82Xt6IBw80l
n/IdCBwUFmAMLTTCKpJls1OUjaP5dZSWv9pxM/I7x61RJqy3zPHYbaFB7c52
0aQzTMRofzdw8ilHRjo91zqCiVufp6RVb2XDsU5g4vcDAlt+z1dRHWj4PV/q
IO7IwGyoQZRbyjtYuEQXvU8lENwtIHQolQZPPiE9o7oRSKdazdYM0FAX0hxx
4w8DtoPoSdjfBMFcDsuA7yzEZ6+5XZBOAa2gvanJkMBW6YYZXkcqEi73zgwL
MEC/PiOnt6IHu3fs/k0PZWPI5oLC9qk+RDLfi3pWsUHV73N9DDoCncdtMsrI
/tIeqrfQioSER/zYQWsC5Z8Lrw497EChv4X6myAGvgmu/F29shcK4p4755xY
uDthfPDH71qc7W/bSf1FQEC52XjvTAfeKTf+HD9MgDIavitQrgWux9nJKg0E
+Lkf7uAOS4Fi1Okw+gECh3qO1qcI1WOAZkTfM0lAWLZS7qVAH2zdswT1+0bJ
fRnM/rRvQsyMe+L+TAISm15yFFKa8czSKC5/Hwsx3wMv/f5Oxer8x5zlhSNI
5H8cX9UZBUvrLFb/JQJyTV6ntVtrcPzHVt/GYCasji/+/PWjHV4tk8qcO0bw
lzKDK7Z2ABE2x5lVP1gQKCjff/1PNfiEBKTrgwjExB5MPaPbiaXinh+fTcYw
dbE0YaGqCj23r3k2yRGYVPhH7PBEK4qDeUN/b2Sgr3UPGMqt2BDKwcFXzoRA
6tMvm2zT0cNrbzVzj9QnvdhikZUBhmAmX4wjWa/opyta+Auxq//ZaJMPgboI
7ibZjz1Yq/h1wjmTDTkVp560aBqEDPJF/Z6wEeEyEDx5uh01s9M8AblMVC2e
LbjH3YUZ64EA668sPJ/lORKSRO4vP3Lm8TgTJry9HlUvC3FNbTlEuJKAr0HW
0tSKJvAIbl7VfZKAE7M34a13N3hLuM5xz7Mw8LFrR+yKKnhcsvfJmSOgcGZw
OHCgHqnZ3547HyP1cG2kouIbHcdiT8YZ9w8h59DIg30T/VjcM1BunDmGbeWy
bY3NvThw4Wy6reAEHn6iWgrLuCJz5+kcgvSrh2cPGInrNyFEUfJ6jiwbSV99
rm906MQGRQfFY54s1OZrRHuKd+BoN5fGg2UCeUK0U788kjBVYRTqeYG8D+6T
v0rRA/kKh7spCixQfn3ZGP+0BqcGU/6NayH9UL/FtjSlGfIenj27P5P9NxGW
Wc7uRBdFne9gGxNf1P2/Olb0YZud7OUPNePg5P1ZOBZXgmNKzzWlk5gQssXg
tFAX4jguHPm+axytDTfemih245iMWlTZMAOJuU1ndn7KQWXP+kRrLwJxXh9H
9bPa8SV8nHNXMwv8ZzzcFl5lQyTpa1y7JQH7F+oXlVEH37gC/mXSb0sYHvUb
gxqxMLJ2ywolFlLdJK/9WVePut3aozKRpL/4W1/XVarCpF+JTiyLgd3mDtGD
ju3oK3G8qjzHBv94ubqIQiFUsv4RjLlBoMaBebEppAx2AVuTIs4RENVye6Sh
9xkxGFXiG2FC2lF2MjkvDw4pOp77yX6bnW7cGXqnHkKxRq1zEgRKorVEIukF
kNVWvTFN3s+kx1e3NsFWbG9I38PYzIZKX3Qw/4UuQNGV7/sdUj+/xVPNwlrB
2Zxn7JdKrp/Wm23p2gT5zrCe1igC8tcUr1NKaDhcXZh23pSN+zJ8dayuHui/
yuW0fdwFt8KAN+nhL3DyQP/dQzdJf8mxsDBa0wmbrU1pz4PG4DPNqy/o14sj
e2r/EX/6BWPianL2XiV4/WpAjzXDRKCTlJe7Uj8yPu5OvfybAYnNZUbWGWXI
C3ecqQwl/VZmiHJwXyoYOwufYC+BSM4dT/zX0qDfNkjr8fyCh6buAa6PaLAK
OflGl3cMgS5Vz72Du/B1zqw89z0Lm+r5m2ITOlG4YLKv+ikDahLOZnc2daC7
aGI64H9sPIsftznIN4DiikOUb0qjGG73vT1SHovVmmG3ssxJ/9W+py7Vm4Nj
nDukCl4S4KjuIgY9/JDTJeFXYkbA2LCk688BOk6rcZwOJd+3lHq/8kQCHbti
FDifkOeZbKR4mjGLURHkTms8QcAx7X8aFmU0REttc+hTIPXOf+C7+o0XMBhx
2nn7DIG3kn3atpOd4BDhukM1ZMGai9vtvGE7hL0YgR0Pmdj0uVt+T0Y7Mu+3
tkaQejuh+T+2gVAD2q0aztj4EqjKuGZrXp+Gb/1r0/W1CNi2HE4ej30JS5t7
F2OsSL3qW+9/59SBzCN1c3VPyf+9di1+dH2NYPnks+tIvxq2+3u0d/Un5O+x
G1s0IM8rdanlUXYB/kgFldixybwNCF8cOv0Coa8zHBnket0b+cPsmO1gP4if
fXJlDPJ+XBX06R74F4Udb+H6Cr1mN/FPgh2YZQ4qq+iR/pgR+Vi4vBP7RjJL
1suMIm+thddfnxohfVlQMp9C5klgPOetxRywHlgmVaSQ+33qSORYmuJieLSh
MtnPEpJbr/wkKLBh/aD/0GehXlXY/fIfGpaULi1/kB7Frcy3EnZbi5HnIOC/
TNZbwmgvreBQMqiD0mLUW+R69VqzndsGcHEi1m7y8RBm4xykFtMoaBY16y61
ZULKWDBmRq8EZ8Y3epVVMtEmrRg9n9cPgVUrzRwvjoBqu0tJk5WFU9sfcIaQ
53d5PZlZmtCHJNn7DT9j2GClFSobOfZB9n2IYkvxBGweW704fbkbe19uDNve
RsBrA89oheEnJHmPNpdnE0j5dPOqamcPNk5Nr57NHoBQt6+pm3Elgkc553RI
fxvzDNL4yEgBU3/tgLMxeR8jnVeOGr/GSynfwlySr0rm+TWyPjaArf9xsEZt
FG+9HeUTZJtQcutsxKEEFt6fsg1L9OhGslNAuCfpJxI2g9dWXW+HmcINmso6
NuTf5eiq+hTDxdS5SFeagE+U6cVY6z70nfR8sMdpGIQwlXdmHR2FDrefqwqT
PBf6brtgSwso3HwPP6iR/u3eESCX2Az1f/4t92IwEJN7eyK7nwrbS/QtTBHy
vMtKpnMe7QgPTtZq5x6Cq6L4RwP+IjS8aJXL+K9/ji3bzS/QoVz4KTTLjgVu
p1Yc42jGq/4P7R/bWJA3l9cI8KSB+5oPc2gVG/ueJu3QrGvED7+4iVGCBZm1
TvJqDDouUw/Yni5nIOORUDvl+We4fNS31FZkQ/RGUmimXjWcvLQKgsKZ+HGh
qV33WwFobt4pofIEcjbvkxVb3QuGrpUjJWYYZRHz2oqNNBif3TzNLcWCqb5M
wjmDTsQ94EwJlyH16Soqv4QyDKgk/itdw4Twub58lQoK1Duj/tchwsCO3Ndm
yVKfoGy6cup6NhMXA+8f1xHrwRbewDefLzMwNNV0csGvD/PHUxNfGTEh8arU
UimuCHSqj9VTdwJ3fhz31u4cQGZtBP2O3QRWFP+R1tGqhr91QnL0GJn3nB4q
VnNVsC5Ms/OuYiJ8oXjXcXYazgslDG42IXkrPMHmTUUdJDSjnW6Q9fqj0eQt
k9QF9+q2C8GNTCiqcmldc6XgeU+G2GfSH0tiDHmPDlFRdD5ZdaBnGLIl1LnM
7TREXFPerFPDAofb6gWVfxzxtvxq8DpSf9SMnbVV62vglRgr46dB5nOkUOTB
1A7I/9R8+dR0DFXdlg55f7dBtPZJ9MONbGzR3Bbfub8EHiqxST2k30w7Kg7m
JbZhPEq4wk2ajRW1w8OdQ11Y9fmOysHWYfA/kd6mlkvFa9exa1db2ChxCITn
5SLoafwu6iT78+nmVs1OMSoEd6/xL2tiINx8plRDm4YdtOZpV24CNJ9kje3N
FGSb1uHMawb4ZzaF6CtUQPlwsKLhT7J+fQ4Thxao4Er6VhRcyoIEZ8HHke73
kIrriJzcQmAqupwrznwQ0jutkhS7+0j+SPeO3dsMMR2x+WvRLAR+UXzF8aUe
lsTnbq67pB4NTUKiFHvwd36UXCSZL8NF/tz5/3bjzn21nIpSBoQuavLlciah
58dSpOVlAvOud5Tm46gQfim4eJHUc+CLQhe3yhKEp42a0/tI/1bj8henUxGa
9h3aB5lINdL3TK9twre8gw08kmz4qqxU3KpGgdZsUPpWMg/O8tqqiIeR/B49
p7M8xEYVK73VrNIDi2/dchLI+4oVfCNfda0LJTbwrRRj4J0hj715UDWkthsn
WpHz3ZjSoxufo99iVe2DSe9VZB74rZi21hlEiV5GQ4/EKPhPx2UlryqAcN4J
5yLV//LixEvx0SZcGTYmgs6zIJRucuTRmyQIJQQtk4/Qk+MZ/HpNPiY3M0VM
SD5h3660P1zbB5/0CM/zB0g96ts1ZmnWIYN39vbjcyxUH2LeHd/UD0HFYK4v
m0bQbBkSfYmPAraoy3bnByQ/xs/9xVo3CO6E4jWvssbJ+UE0jqqbjxmPvXVZ
ZD9JWWzVD7v0CRO6aQHDAuR8K+ti4HHrHXSt5eLqyTw9d9gwc41OOxQEFtcp
2LGx1itvragvDSUVQslrn5Pfu8K5rvtGL5pzzUblQ0ex6Htd0FioD8vvPz2O
CBvG+92Lud6hNHi5bzUf3DqOhTrlHc7jHyB6wOuujSaBpSq+nYNz7fh5+m6U
ewHJp89WZYpq1YHpcSU1NoUBH5e/1R+xKyARf5hLOYfkiTVLDxLlWrFbUDJl
SpLsP32/LGWeGAgP7E67Qs5nYUmGKns2d+AsV5KImOQIJM5X7JE7WIDd9+L8
xo+S7/+sv8BZ2AQuVZOsypss+N7W7Sjc1oI6WmaLasUIODrs16Txt4J3eOXv
ejJvLHNPhdXFUhDC0Ic3yduJQlohglN1mF1yuidHzr8uicMax1sbEZ+iLsBh
R+rjqBK3vH0j9uuriieJMOG8aseKSacW/GHK14eXs/CwcqPe2pxEbPv3obcI
6d8GZsd1PYgOnO58l9DdwgInn04c76VuGFzXcTMZIv2jft/RF6xC9L13Djei
MsFifugIKm1B6lmLcrHvTFQPB4XMHxyA4RHTb6WeDIwFBYpZB1VC68tGF740
kn/LrE/qXo+GUYjN8nuSvwu3PaYwDJswz9S72iXBQElNv8yOkTqcSqmPrz3F
xPDpV2fW+CRA1ISmW36f5I201uEuCh07rY5ceHSYiYff+Wnr9+dBb1okp5ys
53sxr4NmWlUIzIiZ2rCa7O/Sn3Ok1OAbreOizc8CdcbJUO1dGZq3nBh+bcUE
ddFye6xvJc6pU90MSP3LrotZMHStxZ53yTY3xUk+fWa2z6mlGd0nzVXT1zGR
Jxfef3Z9F6hiL5+JbCf7Veelyk1KJ676x3y+1vAVNI15BQnBGrxYf//IAJmX
8tUDcQrrGhH1I2/68GsWjJ3u6Xk31ICYp6bHk3zn5R/mPOHeifPcwdNlJP/J
iiR5pO3sxw/TOVcey1FkHM7+0XT5PdKSn9guG5J+aKFt8yuuBmJzAYdPnGNi
+woKJWZHDfybH2ne/EaApXO8bVfcZ3x7+dea/84vEbD+4sDVRNA0adY/bQnc
Pk6ssR7qJOfImVTH0S+gRLRqTf9F1l+vR+LnY5Knnm2r3CPxDhsHUiTvhBHI
4H8R9miqCq9DxO85kv7DkV0tIyHjDyX5NHVJkpddvI35DZapMF5kXPG6y4D5
3fKibUGhCCgK2CphQfLMduvFfLkGnHD2z2rlY6D1p3j/EeUO9F6Nkpy+NIoP
Mjcl79gVwXyQ/tI+hID0viazKrEWqEcW22bqspEXj0v26h/xtJ47YfUSE/LD
xp3UiXLEfovjyAwgsHB4Z0LcmSowHtIOXS1i4vyk1obao+1QF7dcCosbxaaC
gKHWP53IaDxRHVg7gqUH5ZI9F9ohDXfvEC+SR2yU9sn6VKD7452o8QwCqZtW
r5U51oc/+2PsY+9NotksePxfmWZYRD8wnZdjIrHwuektTTpY4Q/9b4QwsGrv
V/sj3+mQL7ahGqgPQPt41KV6wy5EVhukm3iOoVRw18ZfhVTonNM0GuEehuKb
CJ/uqkF8Ujrf0F42BtWbzOf9U304/yVURN1kFBLpK526Sf0tvNwuNbKFAdv0
zJ713S2wOkO5xX2IALGfdl/Ug4YFVv1ek1MDEIhbQ6+z6CA5o1LA+NsopilT
dSnTrZie3fLnzRQTjD1XTBu39OEvZ/fjIe7DeHvF98Z0RDaOpK2x5IslYG79
bcRvuh23BR2/skn9q0SI6Z592gvB24X2n1uYUI6M6fw3oQ6OulJqfMoshLj2
xkTZNcD8TLVj2xQBHkqT95YcOsxW52Q2KrChYCRp68/Xjq0SWmLLfv/x4okD
H642oPzS6te/4hk4v8Z/0z/kfBCYCIWCXjJP90mLN7sUIHafquSRBSbivxe5
r82l404eL/3EinG4VEtuEN5QjL6BD05+DgT8by4tj9n247uFweYfVych7ay5
OnesGMmF2yil4eQ807sqb6sFBUabuxryeUiePSfylNt+AEssT36d6nHINyov
Wb1ohFCDZFSqxigECNkMo5r3sPz4yljTiQD3zWvOtPg2JFEHgv8cZeP/OoEN
YA==
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8lXkbxm2hxlZzoo0USaJCCeFCHCYqTNMiGhSFd1JatBhEQ5ZKEZoU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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk8lGsbZixJlBxbCG0ijkg5UrraOJRkF58ikSURDeq0IEKdipFQ6FOH
kJxUZC8xtrGNfQxh5n1RDinpNCX63u+P53f/+Vz3td1rPIPsvGlCQkIp1Pv/
TLWRkZQM7EFVvTLhMcRHJbfLXlDbgomJRP7LbSQs3pitt5UYgOyH9+4ZPjxc
3DMvfyeKjQOzI1uNPQho3hqbMd7VhYlRrb+EavgQvJXazUzvATfe36z7Ax+J
Jg6n61dVQSuwU0H7BwHXpuDW1/5dKC0e6K+04qOEkXdKq7IZ2gV74x7uI2Es
PxyXEMSGruNltqsjHzVBH8vMcuNwXNllarkHCXI2sMpxVwNMJv031OYQMNbW
ero4VYGCajd5YSUSojayv5y8yIF5ydc2lggPNJMQh2ayB0Uh5vZ28nyox7Zu
rMzgYMY/5+C9JQS2SvkIr9AvQ5imYnvYahJHvM2W6em+QRljUq5Ng8RwuMLt
4+Fl8A9Me9nvQ8Km2F781rcedKyrSVKZ5aNhm/RmHb+H8MpdZcs/RWIuc1Ym
IK8Cm7+pS25YIFAWqZvj392FNJuYmw8i+RA6Y1RhtcMAD0/K9Bq4k8hQN33e
Q+/Gllf5m/7p40HOO33o0dZBxD9RW1vQPwzawpS8T0EfKvw8joyL8jBtWChn
KugDfWBO79oNElqqGy1DueW4s1blput+Ev9eik3Rz2Rjgr2UsShFgC1ppv7k
70rc8+YuGDyj+LsbdV36XSsiVgs1X4sl4BH42dqnMRtC/YUmp82p/QMt35+n
9JGT7NjRZcTD8qmt/eZyPXBlJzjFiPCxRMs7zymgFr+1rpfdvoeEkJsyMSJ2
HT3OSe7RbiQYH+JMox50I/3MRp/PozwY69Tquji/QOqDSxaZ+iQSGhONO5zr
kPaSw/DTIvGjVFSnfksftESEg/rUCVxi+03bHGlAH6OzJ6aaxLFUpSO9yqVI
vnNtgkbxZe76eeTZAy7GLuPb12MjMD5Mu77K7TzSbl/v8jpGQnUyf311aC12
hF0sVLAkcaP6V7XElV3ItLJWlkjmQWiKtyp2IRlHZdcFPHYlkUzfb0o/3AWj
zUP6TZtJpCxUJIYf6oX2gh9LKJ0AZyj/ymp6EVI17Yo115HwatIdpz9ow/df
c3zmmgkoPWuWt5kpxmKBpEiLAYms69Wvk38pwIcYuo96MIVnQ7DOmEsXtozX
7I47ywf91PxkQS0biV/GCoSjCIymxeiE/VYLq7oIvfiflF6lO7ax2Fx4LDxR
Pckchon1XRpzpgadOTufFlD7501LM05XtGMwoEJsPJKAG3dOMatjCBl2mmVr
aSNgKTIsfV9wkCD5+9MMNz609OgqXZbF8PDWP7xpJ4ni388GkkfrwU6Zk4tJ
ofx3cEOo+s12lF06d5lG+X0qM+/9mrJuLITn0HNuE/jO7JRUienDpV3RGoG3
RkE6ZamJ+3cgR14gZreLyifNc1eyOAPi56X9Oo+TOHNI1+P4rR4Yt9jV1Qbw
cS45UWlEmIXxk5cFaqkEdEtSWC1ve/Ff08XL0Wt4yHPfVzUsKEeWkpr/mCGJ
Pfl1HAU+E+z1DMelFL+O7WYhtFPdeFG2Wc3bhI80k68OgvROSEbKfz0fTyDg
z3+itQpZ+O72yX5jI4Gs21buAaod2BloVUToEJDUNczJ1q7HoSsNjyJKSMQv
dRZO4rLg2PfNcCaIgNU6Vcc+5gBWGt1VjvmThxV1T6R7i9hwMrAQdqT6Sy3U
O5RLcpASa6nO9BzFzoLJlZl6HWCkB1cn5xOo2ejs/uRBCVzyPXq4VH728quy
bMYHYH6xJbVuHw9TSifdMy/2Y6D++KxAhodR9cHycGU24tmEkWkBiXO2EoP7
htvQw5bOm/zKw26GtbbGi3Y8j4sfdkok8HYg0VFLtB8OS8IcVlL5y3j60+O+
bT/+PiiZJajlo4w//fqCNQsm82S5jQGByn6vT3uusmDXL7bipxMBm9bvXv/s
fYyqeMneKMo/J7bDP0+yFRbJMZ6rT5Dg3Hsh+jKqGPVt2/uCAyg8Q2JW5T4t
sHJOuNP+mUTR1UdFuY+LIL58ztYaJDSK33zw/tGFi/7G265t4sHiwDLb14qV
UA4pLT3zngD9q3zk5IUWlM8Z0zgaBKZqVGY+vuWifUm4pb3PCMb25K6p3NmP
XMN+810rKL8oOFwokOiCL0OSxvvER169yKcZzjM4RlQvzaDyJKXRmGwxnYTd
Oub20Y4kJu2QlPu6Dzpibedmw/iIue/ypTakAXqLCqE/xvmwW/uIsd2tC3f/
etgo70ndI6bMtOVEO9z2Lnxg+vJRZ91MZAbWIaBkaJx1loTVtjAnIrwdN2jd
gnMDfOQ+175/yHcQqhfI2mcNfHiIBD8/EcrBoxrZaMehUciUvHt8vyMbCr8p
Lj9gTUJAZxW+E20CL7DMw0uawEF2cWSIwhBuKr2LIIIp/8/IFqkrD0HN5fSg
ehgPZ8R7f/2W0IHRONtVpkcpfaI1Dw/NZ8NYNf+4MtVHGjfs3VLJbPiy7ozN
mZFoGv2j6F+hJlz7XeqQgRcB2b7l6VH5XJzZny160GgYckkSPhkrO3BQnNhf
qEbg46jSWv3eJmzUEpGXYBIQzP7lExLLhpBi607OfSqvV9pC3kilI/mK1bwx
9Z+HzLzFCfdSvKoh9OT9SLzaOy7a2c3C7GJV/DJ9ApFi9wp/OCcg7ZSblCvV
74NZd9+uZrRDhfawNNaTxMKIXulTWjeGJH58dlxGgHlr6OeNqJcYWWs42End
S/anN3uCLjOx6VD3Au8dgeL1Mkme9Ey8mQgKnfclETscXpHWWIyK3MWxqE0k
bjVs/eM/MV0Y/qn+bH8/H14a2wS3A4axhvf3gvD3EbjZzXJ9E9mI2O6d/tKI
D/E/Li5R2sKF3ydSEJBA4c0en13tVApxXS+OojqJxvfXwho291A5eVuzSpFE
9rrP96++agLdZmnYgReUfi4uwx8HBsE8MZ186gkPnOmzRxefFiHCYaW3pikJ
TY2jXuSxTjB+ZuU0+RFo8tP68qWcCYWP5PZmTRK644TMiuIBSLlJaBuKkljT
oeJ9YkcPvpe6m9r8QuJ/Qv619g==
       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4ltkbthSSaCqiNGEUJhkhqTR3SbKMLZGd1BSmkDSJSimGaox9rZB9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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lf/7xyWhskKTRDvhk0i+kheiiKxoWSFkKw3KqlQqKzMjUmYpI5XI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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk4lWkfxw8R78gWKaEkg5RMpGHI19FiCSOGRAvFJJUttIx0shRFNVO8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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41ekbxtGQRiXZ+klNIiKRyVLDuI9dUbYGWSMZjKKmtDCWskdMDZ1i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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk41dkbVyka84spo5REYdKobpSZiA+KiUGylEFTlGuJFAnDcFtMWlSE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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VPsfxgkXJTuVdG0pZS9FRY+UFiktSDdLqZCbJVsqRKGNsiWVJFuy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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8Vfkbx1VkiUkooywTYmiTS6MsHxVR0bWFUBFmaEEqW+K2iEIabilF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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk81OkfHzl2KSorlSMlWYpyG9rmTUQtTTnK5mYpIZuKdIeSXK2S1C6J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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns81ecft36kSaTkNr9ChlhtSkR4K9cyRrPVkBDlfhk7JZeIpGG5tHJt
oqEysXRixDlyCdFxDschJD1fixGJtZ+i37M/vq/v6/t6nuf1/byvr0fdO/SQ
7yoxMbEr9Pn3fchYQybrbTsmYmdOjaYT3BJf9HHorof4fOHZoDACtXJzvwyj
iyj+y/De4WME6pbGWU1PRGB4btF6lxmwH8YcdV7pxECe+G6LywQ8nTltN2EH
7DbpyX2dSmAddTbTqrwTpqWZr7nXCJRW/Vl9ny2CnbYgCQcYGG4a/8bFYQR9
8099ncQn4K4f7P24ho/k0eUSUxFBXHBGnp0DH2sM0+5OZBOI8m1bdVI7MVxz
rof8RLCq7t1b6ehaaEV+KqbkT1AbXMOL3CKE3s52LY2/CCzFdv5lin5UPFuO
CZwlkPAfeW+wuR89Bs+7WWsYpAXl7ch/WAt1Zp2DTiCB2K0SGz39cqTsPzvc
6kXwUnzyrfBBJ97nsoUxmQRTUZLT+/26sO9OcDznJkGR1p5ancosGGid7PiZ
8vN743oZ+c2Pofo0avPFOwSOze/8RbN8+FWf7nH6m2CM43+T1d2JBn+/60o/
Ejh5jPV5d5egr6S29rUnwfiJse97qoQYImOBi1YMzkee/jTMjI/3DuHF0XME
8eS1vlm4AM3hhgZenQSP2NYKI+FdOFJYUNzwCwFHZ/v2dSkPMGro/LlJKN2v
3c7NVzyBHE5p8E463+ngpn3h9lehejEgqo1+c1oFwtb4EaTyeja0JzF4Wbi/
wyd4AHENIgdJTwYbfgmWaixio8Qj76oW5bd5bhUrslWEieQI6T9OMdgTFSQj
V9aFkupc86O5BNcYY5Vdi/1otKnuqFgiuH+mQ72SNwDW/Dd3nryl+G1bSutb
K8Gd3zpZdpxgjeTs7xrXH+FQYMKpuAyKf7tP5ziXh6XIJtuRaoJ6Hb/fjEI4
2Jv8IeCLCDp/nalfeksrBpPtRWWUv/5WpflGdS50w7a4K35P8bi3OJZc5CNE
j8eKFhK4j+9RZWVysb5oW8XuKAKG/fQ/x0LboaCmOT5Hz2f03/sqfucgdnqx
XX6fJzj4xU3yT8djeFZsOuKcTxDWwSnbv5qNcY+pZB2Kf66K28x6Uw7dq2HS
k9Qfnjss0teeaAdn4SVmLhKInxGpTltXIc3qWsgyxbfabeaVvXs5ZLI9ahW9
CUrVFpLsLIaQ2pz4m3cV5dsvZWC17WO4SycGiZdT/ymsSOqbZWCn08bJOKqP
z1t+su7eEtjZi3paqD/047bbeT4Ywu7DX2V4hTDw+O9LobnuIGRF9+q2WTI4
khPha52QC/P1R3Yw9HxbwPLrNzRPG/ZtERnTPHG8dh+oihHAQWN8/irVZzTQ
aWEmlY/HGvY5d2le0pY/1DXfFUHlbXrdtx8z6OtSO5tZw0bYjByn3o/glWNQ
9gVjAVTSPBvmGYL1FaykxR+HwYk7WzlC57liIbfXtkyEp9ayQRaJtB/+fHX5
Q1M1vEKt32f7EiQ1lC0vhnRAMt7EoZf65fTGr2qtN3Bg6D3hahJOcEQ4Y1dp
0IF6MpOZR9eVLLsCJNIzoJhQpx9J8fhtOmc5trkRX9qPpdVRf5tWaEvX83iY
ZI1oFE3T/lEuXd646xGcuU7xlbQfwg/stonJ7IWNjmHpnTGCQJftMa7tPAwp
P+vMqCQw0Ah2T5GvhpsvY3nSh/IfPZw+mPArJn6LdRNSvt+X6Q1LT/PQU+Wz
tZ3mSzPrpIKZbA3+ls8SyFI8mje0M7IiqiF5Ju3ud/Q8J7BmMa84EvzEaSUj
Om/j1qUAp34BZiwC1Ctofl/uqpHs0OXgB40nggCK9wRfSvCDfC+Mbbl+0y0E
2xqaUs7H9CJjwSr+WRvVI63T/Vo+F/rZxsdXfqD+GTVKdDHno3JW7v7/xgk0
8sUN30wLEOQwpenbTrA/eHn8E/4A/L8wfNkXykAnU08/zaIK76aNpOzpfFka
K18XDAqxMTW8o1GRrp899omfogC2K7cfmE4S5JyTZHvUP4K839LXh1Lo/sh1
Vsc8Bag1cy41k2BQ5S8etmh0HUrp7AoHyo8Ke2FRSnkQwgy5FwmxDMbKL88L
UhvhmHghJyyYwIUd9e7b1yII/rETHY9gsPSR8Nddq/vgPHrJKPMjBpsvKOTZ
Dw9hs42yyps8Bo9t9bp6rTqQEPoqbt8lyifvz6TlvT+j8SfXTwopn/yZ3I15
qf3oXCbpgUoM7HLENuqF1EG7We+4SwDBkHDrp+PxA8j4+N1K7DYGRVVas6uy
6rGyJukztRACwYFXNltU+xEv0aOoLMUgYyjVoLJTCOljX7Y7yDIQu97n5uVb
gDATWfW1FJ+3UiWp3sbBvd3ftXhRPNcGk7mD8zzcnmjgbBgh0PlO1q6tphlS
NhMaHlSfQcvxj9UthQiZelHKqDHQndsW0ttWhevTz1oKKf8FXy7l33YfgYn/
ebZWOv2fmuBBhFQids3On7Cj+EY5nbnSMgOQ6uCvTJow2BFx811qbz8CVZVN
2f9l8IdR6MW+tCEse84PNrUwmDw+fZgXx0dR9vK0HvVXnJ37ZcmgPmwRX9dQ
/BnVw/vowbHuVLCUWI7H/+37Cyo+Lb8UImtet20rxTd2bot8yU8PkabJr7GJ
JFhRfuASZDeKqef9tbEpDMyezNwPye2Di0R+bJg0g7V/uOS7qT4CTE8f0kyg
/Z3O0gy+0onnt12fL92gfoidvKVZxIOp2uHoG02Un1sJsdXHuOg2lzafof0t
/uubuYmuYbQobyi8wGVQENaTeYvVj/cS6zTOyTHIY528FG3Vhaa9uVcuFBNk
DvUMcqO4WOt6U8KV3kc41x6GvE+7DdWj7jFTtH8L7E45+k53QoHsjzWh941/
pkzvQ0cAnw+f77k/TGATK+O8cH4IXX2udfdKaN/2/ejQ2FAFL3ftM+ZUj9Ud
6XypF3245LCL2z5D8OLW7I3sYgHkCypZybQfeRYajlceDmC2X3vpzh4GPMPL
Mq1DT/C86WAIO4f2RXO32cExHlbNLLh682k+25yalZkBxOtYKKi8IPg/pafT
Pw==
       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHk8VO8bRQttWlAqiUglUbZk6UgLQpsWSUJE5VukkIikaJOKSmWnZI3s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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81GkbxsmGiiiHxLIVKZXjYschl0QHKlIR0TKdKCwRvdZam0OUHJeX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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lGsbx51S0ZGlUMlEJSIiopWfJMkpIaFIUzg0ScryqgjH0pAllDdZ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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns0ldkfxit0G1NSU6aLW7lMmEruaR4ZJKmlmkmUxiWZUCREJSWSkqgh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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k0lA0bxpFKCElSSvaXSlGUii5LlEKWQsiaLCmlspO3jRZvi2RJyBZR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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8Vfkbx4WZRBmpjBotxl4qpMLQR5NGJVuWQvYlolAK0QwliRhFllLJ
nquyk8jOze7ebJHlnu+lKUmWKMXv/P44r+8f55zn+3yf5/28v5IOnseceXl4
eOLo5/+rTCS/Qja7D8Wb81Y/8uWgPvEuKmLq4Vgc2CdcQIGf4W3qoNqFxPgH
e8c2chEk5H0kKmUQq9yXGnZOEqilBQQVeNdD+pyTC99hAqPdR09FNpViOPQK
zys7gneWMulOv7XC7VqD1uUqgiCmt+xi3n1oPmk+MOhAsGO44nepu40IbZ2N
sDMk6P1Wusr/RAlsc/rXDfjQ3+vMuEwonUOc4092ibYE2569U1gfN4CAX8wy
lRyHMPlhIUbIsh0r+cw73SUpHFrnPPVx5wvkfllyKeAhEPHrTxgT7sBkmsS2
JicKIpcS1fJcu3BR3DnE2YyLfBO9LJ76Duibj5+5uomC+KoBPf+oHAjUzG8J
+YvgpeNxDU5sN76P55gddiHw6GoXNTbrRWFvu6jybS5GL8/nHM94jdaxgHXG
wgRhDfMdzIkO2Lbd/ajWxYH4hwh3ln07ku/oSCUvEYSwAzMLEpthyDjh66dJ
MK7sGya5ogsqt/f5O0RS8FL4NySlgoFvYtvHHnkRTN5McMvdkw8tgcv2Vgfo
evrJScK/EQaab84P8XHByt2Q9Dy9Ez8cD8/5b6egavmX56bdbDTIyPgfDCTY
ombtscyhBtrNASOHLAgC1q8+qX1/AIotqYeE8imsF/kl710MC7LefMrJ0gRP
TbbnKF0fQOCUTOYKg2HwtMgr58k8xUnXmcKPdD12G3Ta+3/vwdcND6iuihF4
SUQrbjcsQv7RfU9v0vGluYaLC4SNHHXGxqEzBGcOnSvknWhB6d5bHz5XcsDD
mQ5cLemEbxeyZiXofkYbr5meu9MAt9C0+qWfuShMXTg80/IGyUvreVVPczDA
VzBdsTsPO54+E7PXIPDasnaN6GQSwlWMreKO0bxoeGRtPlkI2aO1njOOBPwm
PEOCrF5k73OXTfo+ihl/xhYjnlo08/02emEXwUS572juMBsaVs7T+xMJihkq
Fili1dh2ZqrR5DiB5/spnzd72bACfwJ/Egfaf0hoR4VEwmPgWVmwDUFULE9G
36smGB/VP69KKGi7hD0va45CJce19eRJmlfT1S+DBVIxpWKpdILmZfTy5qwU
dKAuw/3fI3oU7LpPrVVvTEfUz7LS/XoEpdeqw051t4Gkplc/vEJh79Edz9lU
L6Z1BBlbyzn4Y9VBZx99FqYCbPUl9SnUxItt+3uwFvIN2Z/l3tP9dnFfkaPM
ROgN9cPh8QTJx1TrNBILYdkwLLKZnkeqTnNQfc0bdJz2/mvyFge5duYVPQ2v
YFrFDnlkSSAhsatw13gzdBs+GRqKE7DKGBEGcqXIP8X9diuTwHJaKVtwhIVv
AiqLA/JclFr4GUVN14P/ierc3Zt0/TWLFsoY1ZB1qJ8dOk9wRO39n7ke9dhk
pp+vs5z2Q6Cr7nRsCVb9EJESNKDncaRsdn/8C6jG+R20pvPz+mDYXpteAsHV
KRWDJgQJJxYLJ+27aO5Eff1ofm7sGbum8OsgRAeHqjWjBnFT+KxU/o8+7HOz
8QpVpvBP7NzjL5HdmG/ff8cnguZLo5yTwbLGSxv2ggvNl9LjgESfr0ws6hq2
GfMS1BguGdSI94M10qs71EUh4ep82SX9Yvx8weJglxWBQBXj9c7qAuQmBMkK
KRIoyl31nIgrAmeoZNs/3nS8/zzeLHNuwF3l2Z+m6PPqbWjlvWrfi7T02TNb
O4aRPre2IX6yD0ciF3vUU0YQV5f0IUFoAMRpWXrsZzq/ZKrya5keJpMHt+6i
8/teaG2yP7EJ0VUT5uIeNB+1v156Z8ZCstS7oKgmgj1ClfMSix0QaJvrdQqm
YPRFSbq2uQEOPNvdChco3G6Re/p+kI2vcp833bhIkKS46K2/rBtZIqfbn7Rw
ECaf5C5G+2Z2yC7j4Z+E3v95lj3zPtICVh76TPe/zSL4CUevHdkbNeLaezi0
VwXWlCf0AgaX9wwYE9g2nxZhjBaj1GXlLjMpApWLRtH82h2Q0K7UOc1PYOOV
prv/ei8Khln/XXxF4HNz4jeTH9VYZaz6+LEbwcE/vi5IBrNwoy3oYZ3UKOzU
ZjZkKzQjm/qw3JjJRUTRu9rJA68hlhyZt1ySgyDzXuu3mxi4xBSak6Tvj2OZ
s/nauZ04JzQixeohYP5kUf3Pcya4PpJYlCfIurdT1LTvLaL89ggvzNLvbzm5
fnRrxmRtjKBwNYWVKewCm5A+dO027NcMpOc12v8etTcUU00sPpY1gY5IXMF5
z1oY1/EqxdN+HVtaLz6dw8amgfS3enEU0pJ43YRKuuFaR3Sv8Y9C85MbS1i6
BiXhL/tCJAgG7sSk2V1k4vdWkxnzxxTq7P+Md4zuQjpfJ+XQR6Gl3E1U+VoV
bosff9YtQ6DN1DEV6YzEf/pa2WU0b1mbtcRaA4ox5G/rpphEUNgxdpbd2wjv
8LfpsQoEnOUXShbvVSMw6VGcBh1vR/CXlvBtA6g8qhkXksvFKzYzw1K5CeLH
laM+hdK+P6bZcik3A5+LQotTnel5umfj2/OlDZy6tBeRtL/DnYpaxeUb0dd3
KWWLEEHHr6z9Z8vLoeHZ/CBTn/5fZa+VWUMcvh5crGyi+SjXypFbW92AeXtD
9ZwhgkOXbwgfYL9CkHtFGcuVwnDF5vvNVZm4fiVvyYb2Wa5D+gvTDbQfuIsW
rjH0fWiudSzdsBxhy/ZJV0UTOHlk7Lp3rhuMH44Klp/oeVD85XrbwzTElh4X
dKF9Lp1+WBKKbzG6XZyn6fEwWlg94e8DCnE7IobxgPaTdN5QhNI6JiqVmje6
RxKsDdPiHMjpwfvoZVmVM1yc9d2xQTmVhZ3yWzKGSrmI1cv7u3uhH+b5WyWH
MYS7r1eYnNvDgHCtg+l1c4IrqbqO4+pv4aNplL+a9odAav6gb+ItuDC7Hqw7
QdeDVcDLW9qFGvEzEpn1FE70f9fZHd6JcZMInQJbLk43GjHVVrQg2OpKzSlr
CkqzyS2xEflwChsv2kGf/3/fIcCV
       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk4lekbx4+ijbZDzZSsZawRM9miLyojhGkkypSyhJDKUmJQktSJJLKd
sp/SYilXCR07x3ZsB3U4y/tWmlGhKUXye39/vNfzx/tc93Pf9/fzfO9H5eiJ
vd4LaDRaGvX9fzU2at0RuoWDmEqdkOkpAqXqxfo/xhrhpdHOKH5HoPHwDwPF
Xja2WrlExjqSCHYfKWBHe+DlsKjU8jCJp2X93cZJRbBtztdac5CEgvGuZemc
djSlJxdyvxEIyXF8rL2yAZ/z73Mqiggk6EY1WvmWgMtzNF3pTyJCdWgtzraA
P2UcqEOQSD6mtyC6qQspxQLnFmcSJ2b821QCGvCcf73z73kCo6LeHg33dgQs
c5e50kXFn7zCL9jfiYEY/iPZUQJeRqkae3OfIrgoW6i0n8S1oL/fbu6pAxzk
b6tok/A9nb0l+PgrnMydlq4sFYBlbj3vvP45gm3keV6zBH458H3fEb063DtZ
S6RYkbBNe8LeLeZi/yUbF/UpMapDAqeZi1tQcSYkXYFFwstk4nz3iTbkFCU+
7NlD4kxcgd+H5d1Y5iVqKX0iQsCvk5IzG5th+6HT5rIlgX/3fK7KzudiyuPN
ps4bJNibVzrTjdpRaHPiltQ3MXZlMDV9tPhQSPgUoBMoRLBO4bk3ohpcWcnV
y9tEgqZYZF+f1I19DfOjUrEEhvjHrv379T5SA6tGNb1ICLsrtsV3V0Oz4lJj
9y+UPnus37o5sKFs4mj3mxsJj4f08263byFhmZQB4UGik3vo/EUdHrazeiSE
S4RgXjO2udEygPWyf1xwJsRo5f2+vHG+D1m79ddnbCbgFF6XFGTwEkQ9e9fp
BAF81XJmJB8/xwIV7ynrxwQWbaw2abjLg7VV7hGeugiSgznuKmE8+P/lsvOr
lghb9t3KCF3Ihdqi0hP1UQSqOTJPTQqaMJtfnlBP5f8yi6mwwqAPl5Uq9HSM
CPieHPj43LEN8Zs/ZlbIk7BhMJbZ2d6Fl0zvH1kUb57xH+ws9vDAmlQZ3ZMh
wkT65BPpyofYOLCFnreb6lfi1I4Vi54h3u96DHMHiSG65bNjBtWI9lZ1/UT1
Y8tPQ3Hnh1tQnvZJ4sRSKl65MNPLcxgG2xpXrHpD8WbiVxF3lQPRd+lHzOVU
POPHu65ZPcapMCiqJFH6LVtop7eyHOvT70sYrCShfPGAQ6l+NzLfvZPNvyjG
9x/LyQ0S9bCt9S7L9CGx4tywNfvYCFKdJeqqXan/F65cL7Hvh8vx1LG9SwgI
dyA7JqQVSpPKo04Uf0FaaXeeSTUhwpxfHF1PYKyr56/jR1l48axE+s5ZEtGm
/a4BGt3o7vt22UeVhFPURMHS9zXwMIj/UjdCIDz87cQXDONwNzPdKlcMem7r
+/D5OjjkBrP3W5LYW++YtbhYgPKam43mqkLYiKoKjVidMFKsC/oyI8aP5jB3
2ap+xJ8LuVVyU4SEryOHz0R1oTetzPqXrxR/91MWyH+pRnzU/NIIWap+C8dT
GuvakSD4bL6GOt+9slL7wfYW2LZmTOgQVP6vehu1Z9phaB+ntviaGGe6WVt5
zg8gxeB7z1N6GHi+VnK36kPviOS9bE0RtoWOxKkLhtBVLF5juo/Ez4vn1QK5
Daj26UtZ0kDAuCVs92vdTpx5Hz0UNU3dT51oLYfIfvzU6Uo3nRXhzDcvf/vB
WvT6/EpPFhLoHIk1FThw4G5tzNBfQ0LRRffmoOkwlBV18tfSxHDqDebO0dsw
zZOyuk7125cmkfdnIQdVRWnhZlwx1jeTJR9bBpETbBniaydGqtG4YllmH4JG
BJasIyLMWhxk6Eq3wXnmsrCjjEDYGv1F+poDuCzTx9rDE6Nircy6V32vEHkk
LqJYhjovyEB6k14njl5cLSefTcBM+g855oVaMJFaXq1OYoN9AislbggvKtNt
W1pEaD6ZKjE11YinH5QO1jRT/eXHzhwweok3bztX/5skRo3+/kxtRg++D25w
MKF49le+sffg6Zc4VacGLUUBKh+qLrVY1w+f+Wx+q7IYNuQht4DEHihrfhYZ
scTw9NNOfGE/iHf0EJVaBwJ0EuNmhhwU6jKM3aj8JL0yF8umdIIm4dfFohGI
2Vrwxe32bWwjj0mvc6LmA00u9M/fbiBPZSbsPOUvMeGP0qf3nYcBIRGRQc0L
ubjauR0DfRBUrvM8FyiGsL1Ee/XdF1iyq8TGRoZEV7bV1ahyLmKSv8hIelG8
sHM8unvY0H3+8Xgydf/GrsVWzEd2oDarVOXvpQQmTHM/BJ/KxZw1v1XTm0S2
4bYnfuP1MB7bWtD4nkCrZ9lOL20OUuYCKt8fJ1CfU81RiR2Gyp31E2Y+BHZm
2Oqr53XgHOPmHdVjBH7vOjrUYsaD/G9jxdtdRaCJva9s+t6GR63POWo3CDB3
zuZFmgyAda7WSkcohGFZRJvsRS7OBkxlSL0Rw3op/dAgxWOQrX6y9FsxJMXj
VmFKHSiXTvlPejulp1qO38HyQRiu0mi4RPFWPxvRKh8+CB0dNze2hQjb735y
VXbsx/xmF//7eiRGY8iayno2DPnt1vYvSPRNn7Ws6WtEos/1sdMdVP1uHomm
FkPI3sVpfiAW4c8QX9atyh5Y5VVllsQTWOKmHbo2tBZOjzwVr24hYfT59oL8
zA4w5TytJHUpf1m+v5SuX49TSYEMBcofuRGJq35mVoBnE5N8cZrAuCD09dW0
WgRXSZm3v6D0tlnTlDmchoasVbN8aj57yDH+0Shlw0zgJ7eBmr/bae82khuH
sGRyojX2lRCk1P3xStNXYM211dEWjsKl4nJ5oaAZhkGBzSv+I2CR+sCp9Eg1
qg61+5pbU/7qtSHSvSkHYwZhHXl+JHrligJIJhevH69byAsnUFIU+/JU1gi+
K23oPar5GtWLGu/Iu3LAmF990N+cqq+J1JoU9iN4MsMukKr3wD1V518HG3D0
Us43hiYJyerI/56ubsCb1QtiBBSfhnbS1vG+deClqo+fpfge+SlJso7S1/TZ
7cxnl8T4Z5FC7+91A3CmJ2TeeEv5c0D/PcuqUryOVOdY6lPvib2TTWaq/Zj7
eS7XlNovx+vzCfRvR9gmBVpHoxj/A3TGtSI=
       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lWkb1jE0kkiFduaTLTOlOEXlEka0TTWWVERlyy7EWItKaqyNDC2y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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VG8bxhGFUEooS1FJkWxlzaVFIluEwk8U7Yu0EYpKiwqphCTZSYWy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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk4lekbx4VEm1Ep04bKOkKFyQy+NJoWKZwQlWPsWxIVSbZSOdlGkoTQ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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk8VWkcxm/GMg0ZlVI019oMQsoSbY8MZUnW0aooZY9SslWSUKRGmEi2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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk4ltkbxxEz9WpRGdllslUGCdH4+VomlaQsw4wmUdnfarS+hYnQUKiG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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8le0bP0ZRWRF6G0RISIRI6kuhlN0gyZ69hWRElFVUklLqlZASSVKy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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81dkfxskyimrSTBtlyxZjaVL2BxFFmSRZI7KVLRWRStKMiphSYxlL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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs8lGkfxieHikpMJatyWgppcyhi5aK2kp02p7RZrBXFS1IreSMUNqlE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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lekblqWE0jYqKYe0WPJrUcjkRkqjwkgok4kjWU6y01FipozhMEay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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k0VW8XRoUoCUWGlBTpVymlCA8VSQMhhQYRqSREZMhQSTQgJGTOUEim
DJGuWaZrvMaue8+9xiJJpPjO99dZZ613vWefvZ9pb7S8aWjNxcHBcYGTg+P/
z8Ojh57zt9FA2aYX6Z7FhuJC81H5lU3wv9a48v4HAhwzj7tH2VEQeBfcss+a
QLYrNdXLqQ2RpTy02jryvNOTZxfViyBcXFAa505A3mLKUmRvOz7eTnWcOEeH
rVILXb6kCkrKA373tQlMenk94msow8G+Nc1SPwlsmLFZCCttgM/k9TP9DQTW
d3wa13Lpx9Omqw+5LxDY4rVt0DStGpx5J31F/BmwUB/lLP0eDn+ef5wLZD1t
s1fm2Vrd+C9vf/41la+wrhlbsk6mE/71EyZKi8MQDDDzvPkoHeoFffm65H2X
7VZwfnalgd/efUY2jg0fZ5eugckUXFjRnvPPlcCCo2tBUXoLrtYrv9MSIDAb
fqtbQroU2by/deNHCOz+Uch9b7AFb3e6K27VZWKKvrZ187F2OGftWCZylQX6
gRf/uUiWwvCp3F3/cgJ7YqrKR7QSEXVMaesXfQL/vKRseA524WxUU/eWV0xo
+tz48t/0I+xY3BhLP0fgaHNTonFANWQIS2V+YxaMDZVW/vasRuGchv+IFhNh
fbxe3h9aMNO0riRXkg2xSzs3r1yg4JfeQ12qB4EA3hnVywEDGBLoUjDUHcGs
yJXYrwcrIfJ84MCGHeT//3XMyRvNg6rFmoi3LgTKp9+2S4r4QDDT8IKEJQFx
Ef/xQ6O9ED+5jcckhQ01BxHB0Wet8GnadLcp9ys4BOINTq+4jvWajbw3yH6q
zXWuom+sAJtLsvliFoH3mixmMb0b9JUhT/pVhlFhLqlVZkFFXNm+GDHKIIgW
5TNJuZ3IjU5wS3jGgpgBo+hGXwsUdD5tiuFngUszRiJ2Sykk4rh8lf+ReJEL
NCvoysEGR/rK5ZoEpPRVrc9x9eLFm5sxHxIYeGr9QKi7hIIT3+mXr2YyccZz
mW6OdSv4Eh68KxUYhkvoj2Wsg50wprzR3pDKRNkP4Y1rLCswWf3b9pIdC/EJ
XhOlZ8LR1hI+/+0IAVaTMLHAWw81vROYPErO94qWc8JIGp6Wxrn07ydg4Xs1
7HxSBV7N62TdI+v1uVzy5eXNFsjbPzgYfZ2N+Gfmpz8vj0PiNlnvEA2SPyeS
7LNPXsG3HUKKfhcJiE0El0ZHPoSI8eUVt8j+OWcW95Q3dKKbvvJ8Cw8LEasN
Tmfql2M6b99VyQECJ03c4rI8SLw0VzZVKRCIzDVdV8DogKTQJ0/tokHEBx9L
6L9JRblbdM3JFCZalM1LTG8mYo4dc+ORHgHNWfFJwYA0tJQ9SYm2IVD52Hrk
cXMjDpVq5XuZM7GgLVLNYJfDixqi6HCZhVFTo6fuK2kw2MEXmmX1FdlOGXuL
tFMQ2ONpZXaWwK3WsFz9DQ0IFFTk9BUn8EvXeOTg2i6Y24V12tNJPGna5U0U
UXAu+Wis/H0CtJSQV9coDSivVBwI28uASs79TX2GnXBdquVqEESgmmWdOiyW
A6nBG6lK5P0MrrklY5t70HC+V27NIxYwVq3237IKjD9zrE/KZmLyjeQlW5Rh
LEFEZ2sBEzLrxi1/vG2B5ct7ylIybPzof39LK6IXIoYTvpZPGeAILNmovTUG
MpZKlQF2BBQHAlScXF+jQrDPvN6KALeCqEidYifcpVZGha1k4rG29NsgGRqs
lvFeeFpD4Lm5aXDMrY+4Xvpd/8ACgfi8HVs17Orgn1S/GPEfAU/xGd8Gu/cw
5N25oBJKvl/p6751ngKN079au/hYCKhPOxGo9x53m0SrZv6QfC/Kd9lQUYy2
P67zonQGRvMqTP2dOlAcYPTZsmYIa6tuRK/qpcIz5xjj3g02pv381vsZ0SBe
Pqx29vUg5EusHoantIEjIiuy6S6BO6s/TUh/KcCKihoBvUcEDtfOqX6jtsNn
eEjJvYTUB7XkRuOzLUhZvnPmpTkL03cm7x8I7EDRg8Ecj3dDOOfYV1kuQkHp
l8IU/VMsUB6Kbn/0uxVvOJk+to0MaK7I2PZ14xfISp+IbzvJgpsE37zGbBa2
lo16v31IoKdmyu5wbD1k+VfJKCqxwOnw+1Sc2AdYD+8rDpEkELZ6YI0VXw/W
n51OGNVhgWPpVe3S2zYQKjglG0/yId6crZV2j4bpHYqfdvKQfjFcLuXMqEHR
6d1ZT5NJfoT9MlILKkKgt3ZanQrpP+NdEd1yrRD4rfYm/DEDwWvTpRQCW+H8
cyTxOXk+bER4Yc2yZqy5+WWp9D0WAiMHwjeUt6N/p6VO/l46lohXnL24sR+r
hq/nO1exkP3DQyAqOAmqbpdnvW4TeDFUZ/9rjAZqQ4/j93OD0NjmuZzjAw2C
rK6NkXd64R5wT2FNdisezf6US/BgwLZWWtkutRx/Rpa+ftVK8qtTu7DxVCmK
rq79cMKTgLoj/+xFfRpG2cfLJcaYEFwSS1dEPirPrRLT9SeQH7l3v4xPNVRm
VfrP0VlIVXbZE8nbgwzjX9prt7PxsZG9KXLZe0SG1qqfeU7qz8PEO7x+7+HU
62uUYkTAa6lT79kMCqKUX5gs9yH1prq3zNeuC21+n26voJJ465w0sRqrhWWE
m+i0JhPGmwJ8NE9X4VNk98uALpJP65ISxhM/ICviSF+lGoGZDZbz0+O5UPmo
riosT+DafhmmLskPPjfHnqxrZL+ibkVzP0lDg1/bpSOknygybtStmeiAXs6g
tVHKECorkqaYY22Y+x3bFJ/Ri6XcXLkhBpXQv/Ryj2AQEwEZH9hTc6V4RlGv
SPNiwmT0ZOcK2T48X27a5n9kDC65x7KDeivAgeBTg1eYOPs+9M/cw9fY/Uq+
6xvJr7q46qiFzx2wjq3aMrG9F2KPvKtHQ5PQMnI50/sMgek4ziX622jgVX7c
VGY7hMvRF3+2ra5B8sf2Y86zTByXSnr52vQLvssEK0WtJPVqd2x983wh2Kfe
LM97SWAqXDKMp7QNFcmrfK0b2fA6qvbKjdYNCRnFlE0PBzFtxi87sqsZyQct
qpxkSX19P90b2taBkytqx/f0MBG75Z2zLKmfkQP2/Qo3hrAn45DS3IFqjGco
baqKJP17sSC9NrMb8XvbXwssDOO+J6+cum4jnMqSjosPseA0VXL5anADjvKK
b7DVY+LdS54gn2Ud0LR4qtUVPASfvItPauK7YBm89KhQ+DAKrtHpqceo8Hgj
bdDMz4D8lvt7ft/9gm126rHtYiTfSwwMZYt6sHCO69IS1T78zeQ4vnkjBeeX
/y3+5UTmBe2K68/f5cDG7bD4uTIy79x3uZJrVYmDAU2zSq9Y8JRsPGXmTYWt
7zdX50EmbMymNoe4l+DTD6oO91oWxh0Elim8oMBzn8i/CxkEkm4Z/qiL6sSZ
KX/romQ6xOf4bxa29aOVMyLrb3ofNJo8J8T2tyGxkvbCTp3Ep4NLya+2Zjyg
v5womxnEhtnj9soHW1G4IC+T6ssGxzPdOd54b2QM+MZsJfVC6FLk0QCZVjzx
z/p5Im4IKz4lXzJbVovg0JWMiNMsBPvBUl80E1k3Mt/VlxAoXu8luP6/bjDP
+Xx/u2wE6nuPf+w+X4clVimqch5sCG6X+9O+pRyifZqaWrFMBE/qF16OqEFr
/89NMYcYiM0QjuHuoODsK0re72ck3gPLC+/bdqDjN88C13EGKNfuNC3L68Qv
+h0tdWEGerZqfosf60NLdM/8R1JfeWtXLZde/wEMs4l3amSedHqW/C2gsh1H
nJ7JGC1loPwUz3NfmxZQar6zQ2dYaKAu2X5sZx00Hj78+AYk37eFmZwbi8MZ
PW4l+5Pk92tsu7tES7H3xD6elHAmHCIj7TfXZoF3xT6eHCp5fuGaefuvMvx1
YiuvSiDP/2z3rpTsAIej8VIt5jDOJub6Ch/+BNfqXee597Lhe0jOZJVgG9iF
QwqLGYO4LGXf2cbZhrOmwqhfR+r1aoU6Rf96yJSqXPdTH0J20G4eX5UE6H+M
u1pygIDOuvxnlAdU0NYErpD7Q8f+11lNvQrtWKsrwc34wcTex8Nvd5f3QJNT
7sDXBQZ2N3AUPhOpx8lpl0e+3xnw+da2z/h0K3IU29Zur2HBd+rY3QinVtSo
qh5/IkqgY+W+D4tBjRDbbaG4tYn0P2+OxociNfg785Oalkvmr9aHtfGpNVg9
ZXVbncwj6W6XMr4XUDFzu2JDrhIDFU4LS4PGu3F8V5XKtjIWbGm0vibzZrjp
2DwoucFCpKKv8s9NXZg9vXtI9R8bbtIfnxlPlaL0zWarmVME/lRHWFjcakfe
qugod51+xE8c6RW2J/1B8G4lNZuA9zGnWbmLVbjIstY4ep3kd3GfTCOFhlrd
4oI5AQaa0tYmCvFlI3uu/9ZLAwJLx+T5MlzzMGWkr8S7moC7zs+BAO0+NCWE
CRto9cF28PpgSX8ehC5c6fS6RYBH64VObCUNKzQOH7EwG8aw1gsDv0+lUA2M
WD/hRiAisGLc+2Uhpth3AmyNmTAQ4fsp5/MGgXpLFttIPUvY63SVa0c9HHpr
CFoHAVv+4WhT3X5spX6zKVlO+un2r/FVKW/BSCq0Mybv4/Lzeb55YwsOSv/Y
up/UFzMWle+PSwuEN+5ZzX1lGJrpp/o83B7ATm1z3CUyv6Ys89aWPk+FZNlr
QaF2Ok48jar8Y1iPK/08DTsdWLjYXRPsfqMVdrNbNExJPPcIZ1mNqPSgJeiF
siWbBZP58d3Dfu34laFm+Ep2FHkFjLFIk264HV+tJ7fAxqfofwF/MtowO8Je
L76UDZrylMkuVGDLId5ggdcECs9Yfci7lghBn7GqWHJ/2u/R25d6OhNms7xG
QrYE6vMvim5x+QriBvXv0FZyPqobv52NpWKN0Z0rhfHkfESCIpYvdEF8psMs
leS35uDjZ7u6OmHfb6V1gIeN4DvCab/PlKDM+u2qPkMC9OtDgc0uFMBnTiN1
ngmpJ09CpNbVwfefj9xEKAPfLksJ7eMm8TKosVef9POTqaKrB5uryXyZPqvT
wUCxREbwkcUqUK2a9hX+IOAQKM/ZdokCUb0Q6JB57dx05wlboQqo65bO1ziS
/DYL3XTwUjZMLhTyHHIgz7sq22Y5ZEJPJMTGzYSArHD+G9sAGjQ/TNPyT7MR
ZceMWnTsxX5Ydd8NY8CsxEXui2Y7vvv7K4dODsLh6yUO/+T3MHmqL3rfjECB
4ilNwR3hYO0bC10k83CT/TWbtOJGaIQvl8k5SUfEtvUcOqrtcBjPD43gZCLu
sb6kK2MAnX8Vd+keJfcrxZ9Dlt19iA9o6C/azYSQ3Q7B3a00lHHkx/EsDGHy
+21dsZfZWHiwRMbCgoBuYqaOcEcGRs6GjLteIsC22BASSe674lJWphE7SP1+
m/j6wf5kmCi/5HM/TuI1o+rUk/TPOKRfWDaYQuCpXAUtnqcTP7ZnnnEcZ8LW
9QBL3KMep+gFD/6f5y0+0Qbk8vOgJpjPMWNP5iHzC/adXAEweO1wOJnsl09K
W/jPoTA08PR9bibzwtMcYc6wI1WIXKbbNBbNgq5uY5MV+yOeeUiWuf0m8/z+
xY7p7bUIan0vNX2EgfOLs1xGe6rxprme0nycBUkL1dRHZyvheDC9+5E5mWef
GKXn8xTBOV3W5gj5/XoVHv34uW5wmb0KsXvCgPmMT2Lk1hb45zv1zH8j6zdt
oewXqYIOb/rf8hMsTHpIhJ7QyMKfb0nN9XxkvYalSz//8gH3lLHbMdL/Jk+7
GtzZVQUh07WTq/SZiLki1VLdNwBJqzoEBJN5JuDY8+e3GqFLIRrvqAyiUK3h
j5hrMcwz5bVlSH8wqPjZa58QguKCi/2PLhOQMW2U/DXWAZs+l+sjjXRYcLql
JosUIvvraM4d0q8C5i+ZpBvlIvma8xVLch9Sk941/u9wLYwd0pb3czDhZmt1
bP5QOTQ3K7T8JvOC82pit5ssFcpF5yj37g2BZjezceFIDYyHZD2qyXopijSH
lL/tKH5Vf90ikw4jLVfleN5mxPLOXGAFkf6n6PKe60ErxAqpVD5nJrlfa5Ue
0Q6CRnPr1noSPxso4SExt3PxV3DGzYvsX7Ff5kO9nm7oqbreXSVP+tNlBTnG
dCkcBCTuqxeR+vZibrnR9QxwGYu2pIuR+OMWerH5aCFOcgt8vFnIRLbG/K4e
QzIP/6E+7dlFIE6xXVSH0Qxpw9yqtZRBXG1Kz//bX4Hn8Wsjl5J5Sr4rVKKD
6zPMA3Oy68h90nu1Avcd4x70eIVrR1uy4am941rFHio61xRRbF6R8xFYw+9L
oeBUgctnf3Kfn/2kMX94vB14weE/NjMEv1smlqHe7WD9J6XJJTOCSckEFdOq
cnBUth4v6WfimseP54nbOsFwfFEf9WEEx1/cvRBwpwI68XGd691J/KlIn1dI
bIPQB/fCphkmGsrfXTCY/ozgxIX5i+S+pPs29Ej4dwr43Wu3BJL5TN538cK3
e1T4GcwkrSXr2xOTzCl96jPWtikXaXgTkPP0sTbI78GWzdGlEmQ++JwaMfTv
FxXLgzzsIlezQKceLZX2fI+Z7YvHHYaZYO+i302T6UUYXcMxWJDcx24+cNJs
68MCT/RisMsgIqi7G5zGKzGlcrCxXoLcT/UCPH5vyYZq/Q6zTJLf9I/SZjZf
KmF+58rGgMcEWv4YjK95XICzjbrsR2Q+j5+Wezk6RIPfP4lY2qc+ECFG2tPz
PThoxNPvmD0EhzALuwWFLIRmzr/P9yLQ3p5Ga9evxeMJg/AwG1LPLXmNn25I
Qk6/1xcBPZLv6g8o5lVUOIfPLY3wYqHPcLBBlJx34qLmvvafJN4O7qU/qXbA
tJSH/Cjpb7Gs+cT9lhTcfu9n8o9JgCaxPc6fJwfZaarHvt4noNQXezckjtS7
FhMLb/9e2A0Yiy2L6YGCJOd9NdYQZOsa5tzud+ONGusJf0cvbB8e2jn+kYpD
2uPKqgsEHhddi/rI04B8EwWFQ0EEVrNOdMu45oO/7s/ji6SeXShr4p/pbEPM
rX3OPQJfEVFzPm+dOBUC+RlFqnxsWOyZHzBIv4fkaOU9C6T+DBcL39is1IIt
0nxuFvx0/A+EPhUx
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk4ltkfxiVCaJEQpVCmJEsKQ9ylIkOjka3JVhgukshSaCERkVDCYCLp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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lXkbxlFJKMtY8tYpZFCq1zKacI6rN7vUlDXRKAYRlaxTtohXKhlN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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lekbx1Eik8LIUvJDyTFIVFJTvkSoMZJJNTnZ18audNGmSWKYLGGO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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k0FX8fFqUiJVla6KfNliRtKB5JqFSKJCTZi1BJKiEkRIRKIip7yE6W
7LJzuRfZ3Tv3WrInCemd968533Nmzsw8n8+zbTO1v2DBzsbGZryMje3/1zuD
F/iovoVQbalNWlBjQvfvelU2RwpGBGy0XYwZoMzmdM5EfsfRG/o4s5uBvIqu
esu5KrAlm9JL7zPBNml0Qr6iEwesnIXelzPhHTid5PmOAsfBY7zSU0wIEvPJ
LWk1CL1zieP9OiYOc6pwpNJqsdt509vpCjoqDPyaVGVqMWLQYCrX3Q8VkemL
T6zKsfmFx6S/IxMPtNYmVJdRoLGUe07PngCrWlLkmi0N7qk98ROZQ7BdnXyo
Jf4buG6vE28UpONOrN+jbJkW3LZR/ExTG0Dh7xUB3IFUsOkaTcRfYsBfUsHj
YnIpGjy2pcZoMVERNtkccakZa7Y9iqK9ZkBrc9Ds1JEW+HdfV/vzeBC8XALv
NTuboWy85RfjGB059M5dNrFtEO2zik7ZyMTXJ5PLRW2/I9+Y64IaeX9JsLWP
sUsALsZxrzmiR8BWR/L1xu0NEEpczB/8049GK0c5a9829LoVaRiHEFjkf6PZ
wV+LvUIbLh66R8B8oX3+qnoF0m++4PD5wUC3S5leq1Y9xBsi6kde0vGlxdZ0
Mr4LHrYBnOvO/0B439e0uaZuWFzT+KtIoyNdpqZ92YkyJFjKnujmYUKFvvp3
svInzGuKdcQaEbge+/hZtz0NHe4qf3f10RHBy/m7eHkFItSCc3i/MPDl0vo+
++IqUORuyeXU0HFqyx9hi7lmOAU+Vg96TEdgyIMOjj00JM31R2WsJeBec31o
PMkHej9Z+4KuEPBfwzzupluCm2cv5JgnMaH/UVA1/3obTLcmcrvMD2JJe8xZ
3LMZm1dz6dSqM2BwOjxH5mY7bDn7HIpiGFg8HiP55lQJhL2irvClMHDa04T2
U7QNrmcVG8fqGOC1U9K9p9aNDzmSO/KVCWiZ9WYUKJeDjeOO4j4lJjQ1wr4x
5BoxyXvA8cMuAib5FpyxT+9D1v6Z1Imr5Jm+N3G+IQHJX3f1w4AA78rqk9fu
pEDHb1Vf3nUCc8/yh/VkuqA0pWG8L3MAdq8vGVUcbYWji1TZ30oCza5Pix/v
70TEO3vLo9uHYF7h7b9Xuhlphkaaa2oIZM1KKZRwN0Gi+nNvcC4DysxG75fz
NIxOu8Ss0xoE28a9jxwK3+KQTzaH4GUC0RbzIe7dFbhQo8C9jTxzs9VL3qug
YXJt0kXlOjpctQsZugXfcWDBaTLtxQj8vx9ynQppwd8037PKzf2Y5fATrf/Z
jtM+fC2LMgwITtr5vLvWBdqFmhVK5PulImfEr6t1YbbtTvJdxX74/yvP/mmQ
DZ+4k1o7nhPg47K6bxlfC6vLsmqcP5h4s5//KOevTpSsH3JV/T6EvJW+O2wM
c+EWp/ju1U8GJo/Jep9Sz0a1VAZ1cJEBkzEpH4Por5hcYdn7+SWB6S6C0NxF
g9qPTSZi6Uzk2aTsbhCMxh81sYrwOwRGNTXyO/NqcYtuelb6LgPur/5b7nys
FTc/WG6uDRqCIN+JVkXpPqSwDvOwzFk4e2bVSi/FSmwqnc1MJOd/7L/3+vfD
2rGhr5HTYIGAmGhZrtDHZnCurq6oVxlEsF7R1SXHNlhHBj7FHgK3H/Z0/5Nt
wt/eaF7HAvLMLfmZrbQFvTW54Q/oBCQ+dJ+XTn+B+TmzeyrkPnwed1mlqEDF
Ck75p+lCpB6tWtNgHVaFOJltVSx3OoLsxLn2S+SDcjvv161QAnln2W2ypTvh
yPl5OG6KDoeP7P5pnB04Q1fmYv8zgo6hS2Hmd2vx/g/nqSs5JB+PZoy53XsM
sSVFvmFjAuxWK3NCeXsx5H7qEkttBMIUtvCenHoYWy9knJVnoj+6xiRE5z2W
BAsU2LUJjF/mjOz8247Haptnpuz64XD5l074xbdQ0KoNCif3+1yT3KjG8ypI
vxyT+BjGwufbSwXQpmLt9Zwn+4QHUf1Hx6U/uBRhV95zvrchYBBUw9Y22o7p
VWLje2YY8FlDb3AbzUNSbuwLt3sM7DCJuzpzvh17mi3UNdUJOH7fXJy0ogWn
IoRk+9pIvufSdrDPdaBzp77tlMgQKgwfWxTpdoGzvNDWW4cB0Qy3r5dSErBC
5hK32kkCN35MwflpN3pZ3E3LpIahHCH16HByF6h7Ap7ybR7GHq4tFOt19aCq
P6g/fJzA7BljofObm2Ebtb77wBwTL9Yc/vM7j4KMID3WEDlfk4NO9e3lH9Fx
7ZXDxCMCaRZKeh0fWiAzF+qtxTOIttO71RxVSD2QNNzEEmLCyHaBfSi2FOwB
+5zP9TBQtsATTr/djMcKH5yuWvVjUqTt69vjTdBL5f1WvXcQI5PbaT4aHTBV
SJSPvTgI0RfZvC5OwWiwOxtpfI1Av7JetFV2DUrKfvpO5jIxXvnft8q9OZh0
H/jjHEOg95brTral7wgPC3J4uawfwWUGWrGy7bD0rfNjqRIg3GyLg0LJfbkt
/Neauw/6p+vDbqflQvh9t5hCFQMxJ9tn13GUQ/2IZnPZPOlfpx9YhkY34JNB
gXVG7ADkj7FqMirKUKVzdrRSionZvi1f9EN6MCc2e2v6NwEHpWxq/OUnmDqx
cWjCgsCefVJ9lh4d+NdO+EddZsJh79W+Yf8uVBSFtngt9sDh9rGAo3NZyF55
r6xxP4Gr0zxru46lokQmvq7tI4FO+SxV7w1fofvJ6noqqb8ZJeu26B3vQAtx
5JGEG4n/r8AdfAerEchRNMhzhoF+4V/ruKnvUKrx6vd2XQJTE7Pq+oVU2NzT
KKqTZMGvtU7NqYGGpW9iI44aJJ9C2C1iiymwGX7e0y/PwMb3Gs/yz2RCZZ6j
e5klgZ2l+wK6bmTjxPqY7i/kPq722P2sIKgWh4JmSkWOMOAkf1T7xgQVvUtm
bb+SelHLZsO82UvDu4WzTj/d+yG6QkmSmCe/PytSh3czA8vvjnj8q+oA/3rt
ck8p0n/N18Wkkfyaf8VslLKiI3pDUeApahuWVtmInosaQkfZBZkcwVxcOD6U
JnqDwIefXp81Zynw8x5rOyhKh7uPUGbfYDyyKXfE2f0JSKvs2cNP4pvl78p5
/uoQ5k4ZvNUq/AKP6bULO6gEyh8qahUJN0OMWfnjTRodSYENht2PupHDOhxF
OzwA4abA2yoH2xBtlMDweTaEGd9SX7GKUnzIG1bwkWQghRk0nznUDP+71jV+
WxlIMg67q/qmDUaGoTz3xwcQtC5Y5MjnZmw1iuVR7CKg7XhctKqlDLdHRcPq
/jIwOGNQuI9oQQknt0qRCQtGwg6qXk+b4K6xtendHAFBjZupljsrwSd0wSHj
IqlfP/VNbphQkFWnwdy7mgFagCH/48vtcFqxXrv68ghkU/V5BDIp4HLPidJL
G0BasX/rRG0qUgVdbwdNMaA9EH8mTKoU2xcC2AOWsVB09GLBgTX1iHj93d/H
ZBC92eHU7oQOHK+3+SJLI/mnfIpyNoaCFcySq7vODCL6hKu8YXQp5JdvGZVv
IPe3TLLBpKwYp9ldCmLXExhaunX0ilwrbmdbP5Um/bsmXM3jZi4F+R2xB12f
D8AhKHf1TD8Vox4/QqvJ+VhbKp67EkRBA/XRlYO8TDgdamq78eg7ZP1e52yP
7gHblvkHJkN5kBAMUKhYQ6A6OH7KIvQLsCrNbKcZgfDgPu0VuzqReqg5/41I
J6pdbmldFv6OUZ/IUaoKA9xuW67O1tJQMnRvXixlmMQvOd0koR7PEx7edK4g
/bRss0XZ80J80w85uHIzE6L1x4MzXWi4OJvdMDo6ANkri6/7tmVCr0FSZG4D
gY2F3uzqBd1w89Yv1OvthcSVtD6PqGz0l3OqZm4nIJTFu8wvvBQ3PtrH7dcn
IO5Xjau7K7FWuvDZ/SUGdBW5lu/n/gb6O5trdsJ0rLJeKVUe3wbJaO2EBxcG
MbY1q0XuSicid/0IJnxZ0D1u/eVDZjUOs0qZcmwEOpTfWk2KlmOSYrvkkk/y
89v4J1v5SpglGUSFk/vCm3g/3HdFHYzzK73kQhiIFA5VeMXVgcnkF+aSVQRa
aY8k79R3YdFybcCRhyxcGwkV8qppAvvi29xoMj/5cHDklLx+gaHt0bYcpD8K
Nwwf3iROQW1uRsF1ZxZ2SInf+sXZBTPGLtOtvr2Y7KS6//nUiVM3I4wyfvXi
7KezG0pJv0hNujFVtmwQ5nI20vZ1bdC2K/LoqmBBzS9KIM6pDZF3t9sGJTIw
59/Q+Sq+Cj8U/eoyjjFRtVGkb56Xhhz1FQpeuQTiBCsv0j5TwZfNVLrLz4DD
REZgStBX8N9jH59wIPOe1Oly7gNUaCuI/bgYT+DC68zHKiMUPNz4njqpSM5z
oX5f+3Q2bCX/G1Mi/yfNq8Q8dqkWchM2xofH+sEusCxobUgDNhqbfdx4kwXR
9nUuPnPpaOO17ZA7RYBmtN5sXqAFNG/Cyp7Mw6G3b2rI2dWi9qiXzVNXOmbz
aksH7SnofigiNLeCATZmpOc93QLoszZFK9UTeOXD7xBS0gVXv4O5kSeGwR96
N05soBzhn7hk5p6QfFlw4X2EDsxwjO2VGxkEK70lQpzMPwPibpKPehmwe6On
GHI1BSoxm73tnhKQ/7cnLsA+FPW3E0f6ybxkbZG68xjzPTqHfqt26ZD6HGi4
Cj+bcSnMbGC6gomI60pPukKK0Wxmy59oTfYF950COj/DoZlh4BBK9hHBnzsT
Nj5pBOvyK+vxMFJf5txdF/Q84WyRzS5lSvpBlQKfyo8CsFxuWKhSCKjYZQc4
e4XgUW+8Nf0cmUcOfUx5eLkba8UtS+0KyTwZPOCv9TYH0qpiIYo7CehIGNYm
urZD6kraasOoEVTQd4lNTX6D1IJ5/VVfAs4+H3mVNtLgb8wf7TpGIP6ZPvq9
anA24uRyqzYWRm0lHxuwtSFwzblZigcdE9qfshSOdMDn0EpDTbIPJbXzHJi8
VYeR0vTT/LvJPG0mFHPYvhvn9p6/3uFF5pMvY+7mt1rx9sC+YSrZT1X464f4
CgohnGR17xaJnwrf1M6xBz7g/29x9TnynLVbXH37gReolSF+vCX9+qZiURxF
qQRWZ+ou85L+7/TwpOAbQSpErz2aZ8wNkP2rek7zaA1k3kwqvxJgItpG+0R+
RCcCTSv5arV7oD790UGfpwXfC1p5OalMaD+7n/bzZzWWK5mJmH8hILnXPSOp
rB3P6dcLY5MGMOMhEi+eRcGRFOLCfU8WNqUsj3pu2wRohe04lU3O0/zgYX3U
I87kDTNvEwtVPs4lequp+HOuHLGNAxA9bCJeGULm04MZ4wkUBmbPvxG90U6D
zpFlXNxn6IgZ8ZDQGaagueLJjLfxINScrQnmsnZIOCYaKcuy8ErmunqfEBWq
L/hLKlcP4WzuKV6BNir+edbF8cf3Iq30oNSwUDs8TV5EZPEOY1rY5rfIQjUk
fl/Qdw1gIOiWvVfH4FNUXYwv17Ei+9Wdy+48e0ugfPIxf8JqFhKyMot9FdLB
pmV67kA+gbdpiYs+tQWwbk1c40/qz6LZWoa7ZDx4m7KXGzsRcBnvoFmPNUPi
XH/8WDsdks+STSzeUGF8/869yGUMEA4TpidHa8GW3Pz508EB+KXcT1AUb0OY
1EOBkUcDyHu4b9+/b/VoHC09IFk5CJ9NezxLZLuh+P2If8ndYXhpTTuFS5SD
Qq9tinUk+SETZBi79xlMqgef3yD5MbW0Kub34W4ERSXF2c4MoqSnayWrOhUC
fMq92TQGJOK6Q2dvpeOd5PmeyUwCshquH+ZGYvHi38Ole7IEBI7tP9SZ3Iob
zZ477IqZsJauUutLLsaPzD0rEwgCE8ebLKr2dsL3+Of0KyVtOPbUweltTRFO
Syd+XkPqGV9DNV+QSAtU/kxqXqkm/e6a646qtblwGmqR27+DzL/v6kV3eQZB
TUQi3cCQQOrB5qw/+jSsX179SThmAJrV1+xMd2UhXlrg4Hky/6uOOI/fnaRi
i9ZsvsV3Mm9tDy1ufF4GMcHSTdQIAmdyjQq2HyiF5ae0gL/VDPjqbhWdn6vC
t6fK3vNKLITapz2xjW3Ejci6hf/+0vGtNjlxnOc7UvcXb752nAnboQUtQqYU
Bd8E37qR/fdA4Zf3iiLN5HOlere+DCHb/uWl6pVFcHGdETAl+4JsopOa4pF6
5B6/+DaXxC+Vb12N5uVSeFnuHzd1IPPKCyfP7W7l2Hnlo0XnVwbkt3jHjZ/P
RExIKMdKUp8cc2uCzySVI+dwarDq//V03cv95g/Ifs7cl3jahIECKvVkT1Q5
tL6leOh0k34yIPt6R0gVIrmrep8lELBUmVyoI/l8+mjFwrUHA6iIpXa0XSnC
mLJRmeFWAprNx45ldxRAj9HUqEXqAb0nWL1lZxsMsp+klPQz4GojzDhk1wLd
Q7v06lro4GVpfRqTSEcLMzG/pJX8n6iiZBXFdJjtcGzoIuejmyUw47GBhjKJ
Za6bhgmwlT5ouOt5A6y83zR3sj9ml+xs/ibUgQDvpG27AgbhIJz7xa2TitaR
m28/ZDCQVvHa7eu5Vui3RMrq5dBhIn/MeCAwDQkVhNFBsg91cLEFyiZkwrXk
wScPsh/I3uvL88zKwM3FA896ZJlQezq8JTm5CXNJ6ttkxBjo9uv3kbavB+vV
huUq6XSsG/rYK70sDqo2PH1uZJ+Ye/Orw+haGngr28bjV5F4S/3yc01ow6Ec
Ue8FbwKiQVmvYjxq4fxxYcUekg9bPzea36S0wmFxA8/18yzk3ZocenrxK86p
q6bGjjIguzu9o/1jMdh1vT41kPnkmvBE2eutHVDSvsTzNYDkv/yP7rzzFeA6
7mmjR/KjXkBYxZCrE/zyvya1tjMhIdG+ebE/H8Lq/wq8RAnYePo2FbeSfc40
W79oiAXzioCNo2HvYVqzZ2uLPYlvmFaAQ2cC8iTljftI/J1pW51PEtXoiZPm
kLFnwkup0eqxcwnUPGvy+dlJvzUzUpjYSuYa/+nFhw/GMKPxLKMprwE52RPT
S4kshLHtUtYtrcLuHlUbygIdimzhT4rQjtT8iJ4A/z5slP7QVUfmSbaXm3X0
9hH4H+WHJrA=
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlns41Nkfx10jpdyy5bLYdiu7KmxE0tstdt0KXRQpQiWbFiu1iXLXZV2K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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lWkfxk9arEkmUVlrRsgpypwsk6skQhpjKd42cYRIKglR0pmcwdvI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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkbPyolS0TfJC0jocRIi1LJj0bLaBpKU7ayz9jiDE4Kg1QmJKaQ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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lA0bxSUVIkuvsrTInhStVDhEpV57soUklSVJRBFpkZIkSVIhCWVp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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk8ldkbv4kQyjIGiQnllxhakIgvUVTWyRIpzKSiIjW3hEqKMLZspUwo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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns4lOkbVvkpsdUuihxWJSs5n5V1kw5TQsiabE6hsh1QtDoocly0jtvK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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs8lGkbnlRSKvYTq3JIByWrjSmrwmWaioYvomTLOlUqOaSECjl0IGpJ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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k4VG8fpiRbUVESUaSiohBFbrRZWmQpWuQvhCTtqBCihYhQIrKlKJKy
Jvs61hmDsQ1zZsZSslWUeM/76Xx5rus8v+d3r+vsLpk5LODh4bHh5eH5/9c7
LGPRdHQeLp1ib9umR0Au6k2JVnI8Sp5PLjB0IBC2q5cIWZWKJEV6Z5ITAcOP
f3IudNORfdvPefTJIEbPXtX0safhXnxAwlApgYTvhJDspU64lwaFNxd0Y6wr
V2RzMQOSMl+9Ux4MoSAkOoL3dgt0/b/K+wuxICD+Ju918lcMLH+z4tFlAu9D
lGMOurWhV8xy4JcFGxld3kfFZXpxpDA1Ujl9AMzC8epE6zr8mR+hnx1nQVDM
QFtlvBXSjNe7pU/2Q0cuxMyWvwEKniLcMC0OxF3PLB9KpiPvy6O7t9/24qn3
tqfNT9oQ3N1ymRkxgADRCZ6gtRWY7jn2qv08gUHt9ODiukZMLkx78a2BhU3X
nSUSyltB12myvNg1gGbbY7L5Fz4jwb+74b4E+R5Rnls+RhfDLqPn84qdBHwv
/b5i3HUTe1acef3YhoCVc+7DSHo+BmYnNFe3ssDc7su79lEx6o5fEXiSTEDl
WgBxbHsvEs95XO2eHQFP4Vc51uk2pNiM3t4yyMGYUwZj+3EGnnLvPCr6j41v
U8zeNZs/wY73ruQeBQJ0SrVq9q5KyBcy/P0PENhfGFe4jFsCezPvI+uMWPDN
tdjwldOD98WCEuwwFni6iEMaKxjYfV51qfHSbjAnfY6fL/gEOZWYq9/ukPM/
nX+xcE8lnKnCjsxFbIT7CZeZHOrAUcm6Op2lndjSxbe/Q7wDnKmzz32aexH8
U5OPq/gVPsnpfBeE2PhNW5oSMpoHtzdmNW+ECLjnm4y46OehQx2Ky0tYSJWu
3zLs0IruptN9XcMDOFwrF6As1IVGh1nRg8adSDhKbXt/7gOk1jjO+4YRsHX/
oaXtm4MjRa9en3Im31PTrzgiowFG9KqhWysJiBhkrjS51YowwSuGCTH9+PZn
8QoPjxaohvp8zS9gouiEZ2ndzTZkGfI6DZoQMC3L1nYrTIf+CknO+1kWFOJb
tYa3UmAjY3PlmOsAisSqG3pXtmPWd+L4LzcC6nnrFkbVVyIq4At/xz42xLvy
fsmWN+DJw5T2hGkCU4xxycKQj7DynPP7bkve9wXD5OLWerzy3OlsxCJgH9wR
5ZNfhdS3qRqaH1kQEvneJX+zCqwrcRY/yfObTmY2lB+iQ6zduVitkINlvLIn
f+ygYuxLuE+xBheyFUV2F9LocAt2L9W8O4xtPZXKts050F9kaWlsR8B6yLWF
5z0DJaKeN8bOsfDOPP6DMR8VzKU/F0bLstFcLKuf/ygbd+d/naNYErjtoF1+
pKkQZfe9Ms2XsLHUqX1WfrITx0u6tuYoD8LisDpfgk8LPGQ9Kl/wExDOrNt5
g78NlqsTb/yOZENv76NH7249xjW+Z4KLSHx3h4/KL31Tj/WcziTpVVyEGb30
oNU2ICasbmKtEwv3ZdZP7xynYdr7ikzeOQYMdxdderChHDoKeUa6hwmkOYTL
dxW2wkDCb1I8lryf7IkJv6gqpN2TSMkl+S3FaVKbW9MJjlqjT2JiBwQiTyaJ
fSjC7ANTXu1YEs+7GZTk1MdQzfo0JmZB4I/0zs8951qxo6lDX7SM3N9V/oaS
smow7gU1jjL7MVs2pNL6NRdj2huerjQkEB5j73TqDw1vcopjTCy7sPyVSNix
PQystYxI1pxkYeNxT8uZD+WgTTTIXRUmwFA+b2Z0pxz0no0bftuxIeJ6WdNU
uw5+dzOtFrewoB7U9HhWiob6ZG5oqtcQHubL0Lard0NNWqxQgT0IJ4Wzu+if
M+Cxu23Z1uMEBPM6h8ltYCfYyw3qWbgm3RrzeBUdRymM5Rez++D0MGzE+lED
bAyT3hy4REB/tRb32VEqWl+/bb6oMgC+trxlh7VaQEjMXqJ+GYD7m5jChaO5
JM/EjmcSJL691A5ZyNMRObHeqSiUA8WRisWbXKiI9UuLfruSCZ6z/IcLfqXi
jr681EtSP8aacLd8PhHeoaaBO46Setaiv53axcC1wOIyYQUuxPTrp8pmW5Av
YjJbzM/EFc9zQ7ya9WiUDOi1Oc/BxQm21AelKrQztB33nWLDwECUEk7yyWaJ
x/TFj31opwrq8Yx1Y5+3+bbhK0yoxtlam//pwEzz5bNvq/uRle5xb8eGJFj2
dXeZWpH/X/P66JKMZnzeEAqLj1xInPEasFtTiQeKb5VKOCzstZNv+z1Gh2+m
+nab9G70ZvjEBFxux8YNc6tjwcEB2lGZ5U5dsFidMmIgzIEXe7eTWjMVjcYF
Tw0SeuFx2DSi90EdduQtnt5O7tsufqUnL7UNXfekpF9VDsB3j9nqA9dyUVa2
NJ/zHwGKFt05400ZouztNBPVWTjh+sDO+3s5ag6v3BzAQ4DnhJzWkkvRoPgR
AbIXCIyyXnFO69JhlhznHbxkCHy9ZcdShqgouunpUmpF+sGlZ05i7mHYPXWy
VsqegH+0VNv7fw24kHxalBhjIym+8ajtLgZuZSzwYvIScOzKyE1yqoW8f5SH
mAYBpsytOfMDFLT0iIe8IPW2wOU6bWYjHTPXJxc6iXFR4ta+dHdgAOZK7VYk
knqx1XVyS6BPD1Y9CDzp6c1CgqHC3w21dnAwyva6dZbAwOrQ7T+XUiFy7+op
ma3DENCo0hUT+Aoj9u3X6xkseMgpDGWXf0XSLfoG6jwLhgO9p+LHalB8sR2J
B9ng93nvtUuVgYfdgiVa88O4JsTfJidZgQS/nxo3Bcg8Yfi2lKmaiQ6Gv2u7
KwHx4G3+51w6YJ8kujjdjQ0n0UTBZ7H58LUuCcsOJfkdYKgaytsA29p/UWk+
JN8+ccRkHWk4Xe9fWqrBRq5m8rpGngpYrd/fm7iSjYR3ptanVe/CMVrm8+gZ
Ah530rNl/xVi2eG+6G8kvq+tN/O5JVCFZZZCkUof2Nh5QG5kJKILNqoi6ptf
9EFscZbmi3+V6LpWIBmowsH9omiB8a4sfFEycHp2n4CZYK/Qk74W3DBTGNp5
th9WR0IeGjDyML1izdXwhWwwU0wWUyxpiNGoYNWQ+u+aOzmR5dQBZc4tYjh2
ADsMJUIaayogTaRd6Jkg89LhTelBc4F4MCIxrWdNoIzr1cY62ol0j/qeckHS
v6xd3nfGtSBc/djBd2ok/j56ja4JrEHkDZeeL+ZsDKrF60eIMmB8mc9lSroX
PDx6lorxFxHhwkhoJucvWhYW8O0LHXXxvtEKI0O43aMe1JXVjCLP+lOOA70w
/SEopGacDbvNlQdGRUn+57J2XZesgtbU+/jhIDbyKkdSLpvlY2NEzyidnN+3
23WS37UNumcvhI2Q/htmll+2dgkFcw8uJY2sZ8N0/oS+sFwOMrsDzR2MSD9s
FahV0biHzgyluEPkfGGC7H0m795Dq6o3ra2KzJtK+sIbVtAQuW9U+cImAqdi
v/EV6FaCqbDLci3pv7bLG7RqFKvwYiI2cR/pZ3Kln3nOlryAZPgds3kyr21Z
Pnc3PSIZCd4WwrIkfrP37zCb/92OQ5YSe30IDl4pbPYvFKTh+L6wYkURJuZS
P97XU2uHW6BZ5gypn33p/O1bKC04niJaZJ0wgIrLryS1V3biu+1KsRspDAik
piRLpLdg+O/kM482Dtxrk8L5lCohFVF6f2MbG/cv39ml+7cIaQLVjmd+suCq
VVFTI5yHcs7LO7sbSD8abVdJO1EJvqT+dYW1HDSPfKq78ioLcpEGv7xSCTRz
HNTOJ5TDsbIn+2IgAR1XV3HtkFb4uexoUiXzQeqvGEm2SiMsHjTGuJL6/m2D
hbijbid4xVg7TVPYCK4QSl69rg2Mcv9Uh2Mknzn8eamNnajkaLjNXBrEx5QW
16jV7dhWviOUHsJC4DUNHfOPNKQ7FJynribz4cHFFaeIUjzw+l16RZ2A3rNw
Ks+PJkzfvXL1VQQLmoKL9H6k0tA4vJ5xM5IF7GJUugR/gKHo5IHgFySfNpgd
+E0pxcoHTf+a2gnk0bkSp3yoKIv6unHdCy4EpLwqrBWpoMbpbj4hTeZ3/gzZ
fU8oWBBUEmelxoLq1WvN7iaFEFgXnTHST/LdvvxatbI2Ot8u+aBN7rNIaWPf
rp1VGNutvOirKgfvTArdDvFTcfyodcNVUi90EuQf1xV/guTp/0qxi0By4jA9
yboaTg/Cz1dnkvx7mBlB304H/3vJEzPbBzFYkT8T4VuBM4l+wU/IvhLrEjD+
xLANpiNP1XsryDyj6pE69IuGmoCsnCd7mGi9n90tPt0Mzw9z+zdEDWBsj/C+
17sr8Nb96U3OGXLfvc95fbw7kaO/W8pVjYPTiz2PUcqr0djRwXibQiDARaBl
TLkZUDg3LlXFBk+O2SeztjwMhwZ/+neBjS2f6xkxsbW49NZvckUpqR+y1d+2
9DxDw+h+mWUnCQjks4R0j3zB/LjowQh/Mk+venhloCAbtLiQjE+PCRjLtAmX
aJYieoXv8/51BJ5Gm2YpiuXhRe9dvR/tLFQvCKILfKBh62nRH17re+F7Ki9E
ICAUqx30jadIfE1UOGZkkPm2LMNquf8U6SfllxKlVUogbV9sKbKCzMtXfOoa
tPJIH093ZHwi88+cvsy10M8YsFf4XahJ+p3QFq+x/ffBzpr7Ykb6y/OALYP7
n9FwZNen9jwyP9S94Eaf/USFu/DAA0KexPfggs2peRSoGm1YCBUumKk0hYUa
TyB5rHxMh+ybCSYuUTa57yBk+O7XLJkvKTH293MpFDKHbKYUK3Dw5jo99s3C
VlTwxr2jkfw7wqjtydPuRAGrYJDjzMEp9uGepJN1ePS6VyQynewLigVBa3Tq
oUvIWFpb9KNOef9//Su7oZtmfYwx0wkedz5hm6uZ2P1VQeEwqW9b4taNZhk0
o9NrOTvXnoNVCdGXp+07MXus6kkPbRiBoYvsaj0+g+Lw5+vZOgK08pJbQR8r
wNfxfbpegOS3xR19jbQqzG74GbI8ng2POkXrl7dKEVw1bXOD9O/7CjHeYcsK
8HAs4eW5VhJ/47I3kmZaMBhxaqm+XD/ULZeYnuHthNLH2StVH5hwn5m8w60j
++837nP3LYOoySv8U/qyE2ztihV7iH7UWJuIZ3Rnwyv1s3OwKQExqv0ZrY2F
EJGI+qoOMk9nq7g/vkXD8tinFX1l/Qgbvl7bP1cIocIVv8zjyPNnVPrUvCko
44lReOjEAY9ljl5vVh2yLq+We+VFgK/PK8ZIpwF+GTkxSlNs+I65z3SWVeHg
vs60100sBOgVpspM10BWz0pD/PgAqla4rUl0bkMaj8fnn2p9eGaqoZMjSSP7
1QLlmckBOEsO/7471wC3nu4nbapcDF0ScrioT0Puy1AR65sc2IpKusStiYdv
/d8G1dsEnE9RWiRHOvFMMNw/xqyf7EucPQYTJB7W/IqsEmLBNCpyASGRgX7N
qm/byPy/Y/Sb9m8ROoon1OKkm/qx9rHYkv+U6mAkvSZ6IIvUz58T17v4qyBg
H5u5i+SPremQxYwcFWIWO01kuSw06k6WOrZ2wGpt2p+MWDY2Ybw/6wyFzIft
Bo5+BJ4pf8ynKVFQ4L8w8uq2AajmH58s3vgBtmsvdkSR/iYif31oWUwpbsto
rE27S/L/3unz6+oomPKf2v7nBQfh5xMluxO7sO9kPb9cZjf0dhXSXp5JAueH
4uUakj/hSnF/r++gga6pF/9kqA/BtJL9PdRWcD39DH37+8H5713c763NIGxW
qXoqDSDne+kRs4kOWIabWMjrk35tISNsYfARWkpe55a/I/V8ept3hnUrYhKP
BGq2k/2Nh0/tsU4WqLq974pWEdAat/OrEIhFwPGHnu5kPoo5VfNg86M6ONk3
rW/bxUY3r4ZY6el6TJzmrj/xl+ST/u1zJxZUgymurlYrSe5LmWu+j5KBOwIF
ySI7SX+fcTufJFKPL681XUxek/rhYXU2IqMYJUOiDtnuBHJkYyUeltFxz0lU
K4Xkl8JWv+dWzBp4Gt1g1rZxEbg5aGHkmQRYvPl9tJrEs/7Iqu6rviX4fcPQ
zJ3JAp+QlD/3Dpm/5wdT3pP9m7mvxnfLtmwI7m3PMSH70SZjrsR6jXZ4BA1V
rDfnQETlqPe99ip87uM6Hq1hQVCNwsfiMnA+K3LV3FQHxn9aMkuO1SB5vUf5
bdLPeOWEk3l0esFvntg6t5WFp6vWXH++uRVub0fZIp85+CPVOza2txXuuVXv
xX+Q+9z6c/GdHXXwvZhq7FzRj31nZ98Fi7aD+HZJUVmMgAXNSqe5tRZOh41W
3iT7zK+/NmOatmX4OaOQE1hOzlNy/uZGggr+xqCimY5uNHetdPYXS8KzW/yW
vmQ/9ZQNm6i81w7tHQuSRZhM3L5/9vzxsDdYpfkqnI/UN0djouYVpRIFxGyr
DInfjFtDHzhV3fg+sp5v3GoIzSdyRZyzPmOhlOQM5QoBe1H5hVY3+xDB0JGI
7xvGac29y2RHSP9efTLNiPxf+Q3Ky6SSZpjPnF7g/ocNt2mT5Vs9qvBIwXGe
60PmU48jWkF7apCmnHYoluwbilJq6jv4mxFrYG/yI5MN4gtz7Y895VhpM/H4
pSMbNLffsvz3cmGT6hP1qprASWudeEVNOg4snX63jMSjoXi3mEh1FniM5qMT
dUm9WmK1xlOuAq7Cx4pH37ERpmzaa6qZialv5r8oJJ8KJLLaj8WXQMFaYUSa
xINU/fWe5PlSLChzjj3PR+pVgdmOmdAG3DjCl9X0mgv18cMHqH+bsHR+U/cY
+f70NuXVYie7kGEcuqircBDniC6HRvkuMGsmS2+xmfCY6vs33lGDTwcXiEQU
smAbedfIVpcKgezwcvMvXPAorlEPM3ZCWbPPyXNkPlF9mCR/v7IM4lOr7X+W
sjDd/sl8uzsF81ppC8rusdEnzjp9Q4SKVeVtxE8/DnxfxdwvKW9GuN29ZpUx
Dq4t2PtmtKcd7E/2EsN/B5HmYbpXLq0CS8sEhiIGWEg/kds3Mk7FJlVr79rF
BLoMol2/iH5B0MGcyMY+AofsdEPWbSkBrfiFXyjZB0+66ZmWK7XAVIUaea+T
if8BIv4SCg==
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk8lWkbVkJqsmV8SM1RiWxRDF+qyzYqES0YYkhCKkvKUjT2JFkiyjJh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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81Wkbxg9NKkwknRbNvCLLyEjLKFqukq2SZCqplJGtkCUVGi+iJiUZ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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns8lNkfx9W2UoukJVvUxEZa5bXZXxfb9hG6sEhFURi5bG0o93QhkUiU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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8Vf8fxyUrMsK3kigyGpSQFb0osyhpiBCSNJTRkFIyUpJIyaqkyMxo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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwdlns4lGkfx4cURejgUCtRORVLRJls30pHUdSgrSkiUeml3ZLtKKdaciqJ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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk8lWkbRqHlUD4jUkSIRknkU5QLY8kW6lCTfY1GoSFtluxLSWWksSRF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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lWkfx1ERmsSLiWQQES2S0qbvlUmDqBkpKkX2SrY0tkZKi9ceQods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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lG0bxkWLVKK88aJFRYgSpUnqVCQVKktECaEsRSVJSGUf6SVKSmSL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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41dkfx2Vs0UhUI/wwlCRJE36i5k1lSZGkbNGQIjHJmjKlbCUToUW/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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns01VkfxuUSJYqSpHIJkzQSGmLqEamJIWOkRiqSS+5iyuRMcUbCIG8d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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lWkfliUyg1TWKWnzhZo2xUd1nzJCfSoVGppOhGQrUio+ZCsZ66RF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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWGlcTH0bnnZSpHq0kXhKiyKyRHElSZKEkLSgIgpRlArRIlFCkhRFmyTt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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41Gsbx0kLoqMiZUuWNkvUkd03DtLJViJapLK0p5IQh7QhkuXgLRVC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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns8lGkbx9naVikxK1uiiCKylJRS/STkUDoQrUMSpZySTrI6qGikZIk2
TdM4VVo5ZFqMw4oZZwbNwbFmnudR0kGvqVVe6n3eP+7P/e99X9f3970u/QNH
dx/8QUlJKYM+/7+rUv3KRkUd2DBZv8bIm4KxjpYsjNsNu7NfXe3USEwImRoF
dd0YsW23CZ1JgMtzPv3L3m7oJgUdVIQTeO+j+jJhqhEnmw0tv3pRiO4/rKz2
sQmOYfIbY1oUglhrDvkIWiHysyIfDxDYlWFZqCzqw6eT+ZIXyyjwnrb4Bfn3
gTceHz4xV4afWmKP+Q88h/1Ds03D8wgocUYGrCrtUPsrRtf6Uxi4/1lOGbXA
UE9oUriLQEKeU4y/QoqRpT/s8vpCoLfaNF2wXQqTwA3RiYEkTJbw15kxn0PR
3BPe6EdAxMqkJGe60dbTNGJ1nYTVaJjSIK8TSiraTnPCScyLyXe+v7QHlKJk
3COUgqxtxKA14W/wk4K/brWksCDDNkRNqxnezk90zk6jMBzKPDvZwEego/5y
F18Kq1pGo5029MHC4Z75FFuGj+bmigINDjLTizLb9tP1Dbuw5cDWMkTHFLXC
gkKTO8ME61sw4eP/KCCARITNjsfsEhHclVjGznUkkr9V3zXyEsH0n9eTf3qS
6Bscz5825wFcWL9WWBynMJleZPJdrQNOZdnM6UkEbC9MJ0mvZiTktAg/sUhE
Kzb7RP3WjaNhl3pzvEmkpMudn4WXgdmeOL/pMF3/JeYnJYe6EH0+xt3xNgHd
xupN7tdb8J/ANM8rYhLLdrOfnzHowxvlxHxLDQp1PzJa72cNImiMv5z/dgA7
531ONO2pwgmduoSARRSoLQcv1tQ1YraK5Ke1wSRiubGHPDn9IOKf9mrMfwne
2KD5rQ4RQoi6xRZCOdiHA7VseFWoSv5lybNdFBhzFDHDm7rgn7jgTrUBhfLE
C2YfhqWw6jyusX6nDGFRUeLMyHr4JkkEUVso6I3357luyoTkdtZ/WfsodP6e
SSQLK5FRLfBgjpPQOXY5PY9qA3WljNH8mETkH4aR/BQhYpI3yveP0zykRm+2
9ulGxqHwl6FdBLSr4uxiPnRB23KPw0pzEqzHuxTxMbW4HLXtyNVWEtZOvlnh
/Tz8HMHue6hJgfPl06z+b89xOH7MZ7hMjmkjBh4GjzoR1pmXFF9MobXE2rDm
qATbX3GLa/ZSUKq1Wr4grBc6DWnZizVlOHruUP7dE2IURwZol8+Xg3XJiK2u
XIdkJem70iKa371flRwWdkPhE3XSy4mCyGpl6mlNCSYWbnuXtlUO2Urn+u3J
KVA7M+e1iQ+F5dwHZ+xVpDBLuktUhFMYuX/ClUu24Elrb57AnkLPkpJeoB1/
/ZSRlllGomaNnyJgpBPK1yfjx0xIDBc6/3teUY5L7CbdggU0///cTCxeXIdl
uk/iopZQOHeda/qjUISI9ECtR38S4N/Nfp/tIcYt8Sqr13/IYCY8bbAbzSi4
f3VGM12fodlTv7Hv9IF10y3EKuolYit8eGPidijNPnDQhSLBxrkD09y7MFMe
ENSpTaB2jje/LqEETtdqKjPp/rJ60/I+35ZgaSl7sbuDHJpnAxTSUz3Yb6Nu
+q6WhCxUlaem/wx6e3ZYT0ySUDfOLy2wT8W+tUYv7tE85LLHJ97v40JmLDEK
o/MZE7uK8WBJOwpVNYN2/Ujho/qGRFX6/ak2N8cuMgh8jGRvdM6tACHQ+Pvt
FxLahW6zunvEeCVZp/r9uwzXypXzBT1SMNyuFiVzZYi9UZ7haCJG0beA/ZtY
cli3bHaMP12Nh0f9vriPkEhdpXZs1c0KPFrIY7yl8+8SUTmr/89+mM1wiQvm
yVH05Zv6X9Y1GHU70jBVTSHrXWbiUkcpplxNiPbfKXRctt1z64cmMELCm/Z8
ItHz78S190fuY1k99WZoB4WdQ9YhVcFCuDgxedxkmu8zryxNtlSAcytH5upB
wfSuQPfefikeiFNz0rZRSNWKHRyi+fnjvIaT8oQc9GsXGE/14G6PTfC9dBI5
GcdVjdg9MM+MfNjQRkLvjsaOiy6p8CtX+LUdoBB35fXgjJ+7UNRnJyz1JXFB
UKeavu5vZKnq+6qYUvj+G9fXxrAXk9JIAaNXhmHh67mPN/RCwlm0fuE2EpY3
jh3JuicCQnTcZrYSYBKFe9cKc1Gl+SFQn+a71s56Wu31ixjE84xSun+rc58N
WZYNoKCM99R7/SDe1jxgxjl3wWA0S9ZkSWL+WUFXyhE+PoYVP95IkuCc6q14
MCCC1L5CZdEQgfnhKtSb7d14klv+JSKAAKe43vU2nwVL77LOQXqeRCZ1cK8k
PcPek5Vyx1m03z4Eri2l835IJd7h7QUStn8tLnT2r0drSMSGQtpn29rEbtYe
L6C27xonxH4ABiFFc7LrelFzvSO+so1ArvtFjryrHiLGq386CylYLNeKVHlb
gnZOl7In/b8rLR2f5W19+LigR03ymcSkgFyk8GgDYZXd4FhNYqOFdMS2hfa/
PTddNZpCtoHTwvrETiTl5+9fs4JEzIvR0EZDEUoSfO30nEhU6e+eOxlSBdvp
rrwPdP6vxT7aODelG3FeJ7hMet6u5uSVxg0Iod6tdC5qOoFth8+mdZ/hY3Vz
x42VjiRqn1r4z/AqxFBEkOEwzZPJ2I4VN081QGCYzn5N+0emHZjX5DYIy4yA
A6tpX71ifs5yapSCneBZvMXnJdRfXLXJKRXDpVQ1uHZKhuhzmkLfUwMw9nt+
a8YeGXzrk4tZJS0oz99aHtxH8zldXVv8kA/OeI1m7XkSFoonocvD67DvzvDL
3fT8KxguOJnY2Ag+77zLKO2fIMZttvbQM2y/TarnRZHw1jPTDVonQuPQcFNo
J70fCOYZLT3YAJ/JT/rXaB6ZHDZ0+yvxNLPKYRq9f6QkdK0wHinFcZ8k17GN
FFZoDeQW6tL+0rvoMrWSgr1083c+U4j4y0cjDDwJbFKbGTzv5guI/R1G2jyH
UJbyu1eK8VN0OJSJf95J+5N5h7GmuQ1vFh25VK1GYaz5ct9sLQHa1zEndXPo
PJ6b21+1Xoh9OrELI2if/g+fe8uo
       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8Vmkfxi1RI4lJvK0iIxMZ1ZDGcj2GqRReSyXSiMqUJULWFyFbI6PE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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHk4VG8bVkmRiiJpHVIkydaG3JJkq2zRIhWJQpZKElmS5Ue0SkkkW3ZC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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81NkfxkdJraxiU7OUe4baCiuF6pFYCpnSCpUsJUmhi7Vu65a0sbQJ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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4lesaxonMJDILUYatRCObuot2liHZR0Wl7GMjlKGSpDJ0sJMIUWTY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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkbPyEkohiUNdNGWZqRlPQrmZZv0ldGkpCyjISk5pTkkBZEY+gb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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VH8fhkdJChFZSkkhRZakBeWhpLL8qFDZQpJ9T0pJJamQRKmQJFvI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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk4lXkfxo/BRKLGjKbSkWQsvWPJUspy06QkNcfWSJKtJmuUNuuZGWS8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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk8lfkbRVmTlAhpE24icjOpqGPI0iQuGSXZCaWoRFnKVmYUGQwSY63J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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4ldkbRW6VSlKJ5JI7aVyipFlMmokuKCSJySA1pSYlybiMw2gol5Qw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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lOsbx5FTkjoloZIjUYOU5MgS30qh1XqKDrKVJaJQsmRXNIU6lESy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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk4lekbx0+ylExIEVH2yDJmMgmZL6UiynJJ9i1Lq6TQHpKfkJEwZUsr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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lekbxiUjWhBqikyobCNjylYmV0iWEuVnp8XYSqFIi5ThGCN7stRB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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8ldkfx5EiJYpiqKjkZ0SSaMF8ME2ENPWTJS2ye5WyTyW5ZMmdpMWY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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VH8bxiVKCllKIclS0iZKpNy0SErJTkiSlEIl/OwtZGmVhCiVkCRJ
tsi+yzZGYx8zZ2YQkiVL5D3vX+c613XO9V2e57nvz73B3tXoPDcXF5ftIi6u
/z+5hqTf1gfaQ3/HBdlFZwhIGnXTbG9048Dh4OaDIVTMndg7s9acCrUXqyRn
jNngYtZwuFrsoOGQ9H47+f1RU8E5/qOt0IkvSnNa2w0+i3aF+X4qJEd1zVxO
EnBwpiu98KZhwk3Q/X3wAPjkx5JinbOxzjAh9pMVAQlLeneBGwW+TjEfaxbo
CLEaWr1dvw0Hz0dVnpv6CQ9dk6OuKu0QLLnn/fEBE9Ku2xZe5FEQWFlZ0erA
htthsQPJ+/LwzahN9q0wgRCm/0PdrHrUOJUKeF9iwEjF91xAXh1aD37y/JPf
B+Wzd53P5BWCJnwtzuYIAd9gmVPFQt8gSmjPMopZEHfupX1kNUN+4275OhoD
anlrtlTua8TjJrayak4ffKVEmG//VsGOaMsTnGUgck3hpqTNFcijCifNpTLg
FUONHN+VgocWgmHNfgSGHdeP8wlQUTL/r332eD9ycx6uD0mpQbpWF8vqPBNZ
ARMxkar1kAoJbSgZIBCm+Y7iuC0B3N03eCedCaifaFtRJZWJu6usVnh8ZcJt
Z9IVt6pPCL5Wd/M1uX/63/vbBKueIT8mymi1A4GmMcffJWVU3NJ7nvSRxUbI
mT0f1NYVwsjFNmZcjIlcl2b566/zcZBjapxJMGEwwXeNO6gWpvtvJvxNJTBu
ebgxsLwU/2hpG/UFWFg7HlP82DYDx0N8KwwTCKxxzO7o+lcOGRFD3Xw9JkZ2
+q7iamjGmEXi88BL/ZjoZO19tKwTGz9/qPwhwgSf8FPnlZs68W+pYnz/ZQba
4x73RJxqAd2kPFWkvg9OPVmNO3uouMdn3TikxoZUTlPb3yVtuHcMQpx5BvSU
pgL1yffjFY3jsiEMKG2Kkild1Yq+bQXM2kUcbE032PHvFQVKDwJ2e3dz4BZT
5Wtb/halUclPk2wJ8NXmDhiuq8azNMNxG38Cr+uOuEpLNmHFY4fUjVwsbD1B
5f/tXwOxwPW/XQpZUHNe/YC434KoNz81R1M4EFZo9de5UY8/e/VUN/xhIOEo
0zzEvgLExsLDDB4CxQ/i2Ttri/BXL5l2/zqBwNK0s0/orqB8v/BpjFx/a9Ge
X0m9lUh32B/kEMhCYNGw+MOVlWDrGe3QkGehYHq7fOJlKh68YdRr6rHAk6gX
T3PNQ4acyuXnyixYF0jpPdpbgtSoxSHv3JnYE79V9AW6ceWZivt4FAsti8Jl
Ao3b0b5yZ6ls2QAsGJOF0vUZ6Ly+Rk5ikgk7HQfi/Lu3ECxWjTO1I2Do1/La
730CJL6J75h0IuB2em9DdWAGxDh9983I+7n2g4NR3mLo9h0dt3hE4E3l9DEv
wWbkjXjmlD1hIvLdtw2Zl8vwZ+v6zfIDTBDsXWO7s3LQlO+1LyqTPD/L+0Ya
vuNLwJqT0f9YSBmxvck/0YNTMYvkuMincolPCTWoBtNrFiY7Z1jYTmfGegmU
Qcs8YWx2FwHr8IgNSpfakKjc5bw4hYHfPUeb/1v8A1Fr7ApKR3qwRulCZ41T
FhIqRzcXnSPg1NInzlrSCP6OKycnhJlosvo7XL+uBNFObhZ+Y0x4LZx+6Cb6
AYr2fqneIJD/oHZ9QEA2Hr47zXL5SmBfntJutmIN+G99j+AxZaCB78ul8flS
lPJLBsWeZGLj9CT3B5dSzAXPPTpCzouUVrVozwkKwn3TnbPF6NCq2hfYIl4B
id1vtsf1EzgsXJbQ0PgOzLe2g0+2EIjonBR2ru7Cb5uEwaP3e+FwWjGI/0MV
5OeFPRUbGFiz7uA2xnARtp4e62WS5+HC7kPvm2pgvbLXvdCZiewbl8TXCLTg
07wZr1kWBzR/jc6v7q1YonCB5Wfdh9EE5l35n+ngCft9fAdZv8JVB4V332pH
7AvL/tMC/Wiqi5lK4qfg1wfVngRWHwIjnMX9dNJQLNJMTX5J9kO0PmWLZz2m
lPPrgq3IeZrIjjJrbMOh139el/QykHs0m2aoVoH42Nojp06wkMjPXqZ/swaH
pN8wZSIJcOcM3b5zKRcLV3XDNouR9VhPKIqtrYORQKfH81ICswaSl4786UF2
eoHv6Y3NkG10Wlzk0oLB6eNFepps2FXf0bhiUAT3TNXwgj9MiFU1LDn2lYpo
CbMto8F0FBikDvu9bwJ3SsXH8ufdcHObjhIRSEOk0srZXiMCXzXlfDR0mqCx
gzN9p5eFQ3UGy/rJ+/I5f93bs5SB6itfTLX7qtC650FejRYHn+97DFjdbYb+
rYa4+i9s9GtpWRnnUmF4hMuD49uHYFmlNt87FJh8SKLJjzEwWqHlVni6Hd0z
Lfab8uhQv59NLI/PxHllVtp2PQJ6H92FrCRyEREmdNHxPjnvGSZeXLx58D6Y
eJ1HhgX6suWXla524quEzbucnkHE8SsoPAEN6VL6D1UyGAh0LAoVi6xC1WHL
E7jGwOfYfT225t/x566Y4pNtTPRLoobp2A4nnVysIfXGNfFJot/XWqw+sMpL
cRUbGcXVNhZqjzH6x2829TyBPytEpx4oULDhgYD7StKfg+vs/3z+k4HtlccW
28UQyBiqPn1EuRN5AVdVNY91wUC+ueVXcytiuWuLWxL6cK81+bMdXwcS/ou+
LeFOYMDEwnOX/xcYdeyK1dAg4KFoHXOa1IOJ+QidcHuy3w85vPu8vxmZzMMe
Exf7YCspGXTBphnSAowrh9TJ+wn49KxLogfaac27JzZyUF8XOZBv9wn0lo6M
p44ExhT2WuJVC0z1VQya3tOxIfpq9H/rq7CJITA3lU2gR4t3+Ht5B3YMX36h
EEj69ez0xYKDnfjmlzU3rt2LUEkzWrodDdr3zhiX9g4gfGmM9NHZFmT4Z111
TidQHXp/7xO7JkTy2v2n2c3GpKz48s6sYnTcvjnUHU/Wi2vn6eaxfFyyOyfz
7zmBhJ5fWuZnchHtulxzZiuBb2y3tNSsWjREBp90Z7Nhe1YmN2K8EtYiLcoc
st/eNhZ1BpJ+0WaoHCTW1Ac7acHe6cxObJ315tYRZ0LIKHDIZ/cn2ArxXxte
QiDbdY467dkCltBiX7MANmRiH3F9D2yBo0j9eZDaq8Yaj3fPqAafpV2S73EW
ducVbj3wMgseLusKDscS6By8O9PmRUOdrVyqzzCp34GMojVjr7D2AX1/9lWS
f0qIfx0Jn2CfV11lsplAqvXETwqzAwcynPRk7enQ3r6Ht00oF7HWBVuG5QgU
iI5Mrn5ViX119CjZMBYqXxLhs1QKnExLEpVVejDqsqV7NW89KosfXvwQx8L0
4GvvuSNU1E/ZLtm3qwcqOi9r75DzNqatWevWwUTKTU5y6ucaSFcpcfeWk/pC
xVrfF8mwstAOsn1P3reFrrLon0asXbNzwDmXgRvr68+Gpv3ArrPPBqRUOCCE
anfeXlqNIxb35B1WsDAkcW7tErF8CNT8MlhmQKDe422qtVwDODpWfsm1ZD/M
/70i6E9D9ruIMy93ctAkLBrG0/cF65R6kh/lMKE3uO52mkMphhhmiZOfCUQV
He85Vk5F4tK9N3rIehsybE7GxdWDNvs7vewvC76lMXUqvOU4p9ETu9eGPE+R
0OY4iS8Y3/Kj64kF2U+icg5LTarhb9yW+zOAAaq6ZaRHfj0qKHO6NygMBJmN
OPMLtqBydm75whxZ3xS5MZveL5hXWUJ72kNAuSJ6i/TrRCjtmzuVeZHA9NSr
sKUk/5VfvEGvJXmA503EurdBncg+Ec2s1hlA0+7n5zjRpN7JBjnOPiTnV9d/
GWOuAn/ndf46tTBR7SdZLCf+BQwZuu8rbQLyw+nji8Ya8ZLoDtM614ddI9kz
G46XwkQza+pnM8k/vxcn/G6vhfBvk7t8uwl03b4Q3h9UB3ZTlcTOVgJS84uv
v95YAJPdj+ukfcj19t90Vb9cjPGFhML1u5i44FKycH9TE5yER7K00wik7L26
wOXzA4XbS888KejCxv76LXNSFJzLlz2+OYcBmasiPJEXM8HwEX4dQu7PbXKF
33jqR/AsoR9IIf2eZ6Cfc1SkA8U7HbhHfpM8PBqWY/C4DJesS3X0RQnI+U1q
f2G0oTlz4a5rYz9oPZFGzD1ZEJ2OTLM2J3An3NrQW44GefH46ydIPRVjnjrZ
NEiFnUlr3sSnfrQ2xZsY6zQg+GzPU08W2S+Wy4x+/VcBw2O7fLfRmDjg7ymo
8LsRdO66ykoJsr7/VXYF/syBRvNSKZPXJI+IhifzKtXiV9NaL2tnNkLfXnHd
2FAPmSsXNZtvkP3hOBx4vaEMZo/bzhUVMLGSb8FgwL8bQUczXQ5QBqEtnZAg
xs5A7u+jYmpuBLz2qNy2mOnAnIwBZVKPAW26gc+xrEK4H5HMUeZhQj1gVLmE
UoD9jffS021IHnBO8v6+6hXCTS6JKh4jkNjhnOiW1gDGbWOrXYNMcLV9LRe4
Yghp71XZUqTeuxmoLVbyTYSuZZSI2yXyftQ0h6ZTS5Crv3PI6y8T5THH1l+W
LMfM0tbHFtEkH61guc03tYJS/eunfRCBVYoLzT8HO+HAJe7Dl/cTytHPhq6p
toArxbPt0x42Au8rxZwWD4GsUuSYGTkPev8688oXl6BUyTyfn5yf/nBNq71d
P3Cx6jlXsBMHCd/MtmRqfcRh7cdq+8g88zJa77buZDnCMgeKXIrI/Qe41zm7
VAL87BQzcr7N/in76++pQfO367RPrixoW172/3DqPrrsVwvpkfz6vF71RmY+
BWdKhs3nTLow3faW24TkZ6P6y/KF+zlYaXckhzoRDyM7n49WugS2KXflxL6k
kn5brXB2rg8hgSs5UUuycfxhn0fWDAGZqIp7F8M+wu6u+ei7LwRyX13dY5hK
g6ieFY21lIDtZqPeMeNefO20qeDzJv9Xlfth+7MVjfuW2qiS+S7Bgz8/OLkN
Ec+nBs/4kf65XaykLO07bKavpjXvZ8L6+4XelmvNZF5CieAeFqTcHK+ySD9z
OXmvMFG8A6PDQ55Mh3boPn12M66G5Dk70y8z2+pxipI78mKW3J/NK669QvkY
8famiMYw8ZoeaDdzrQsxy11KlLq7cel7n8zJr61QS66yV3fhwOH9IgsF+ywM
RndvEyHz98hG9aIOrx68rjRrzZ3mwFfD4tStfDKf2ppO2HgSWL265K3o6laY
U2dTxSLYyHVIqtM9/Al9f44MSK8ikEyRMZM2aIf+XVr0Kn42VBKil0+db0RX
YZVjsjgLXjYeYvMq3+EyuJQt9pCDFW3h4dmC+TBptCwIUmUh4lpG2oqVmTBQ
iKlaR/LAynHjiq693Xjz7nhJcCcDG0M/V6m1/EDXLc/RLwFdOKijEi9/pQE0
IZvLjWSe5j/h9vTDo3J8UYhQ+mjPREjVL9elZH828Xw9WLWqC7zPHwYQN5oR
yW/eeKKmB4Fu7z8km1TgANfqkfhtLBinps5fXt6LKwqh41eoZB78ejTw5bM4
fH7o7+XiQSBr0wHTJ7llwLCD8Z4sFp6k+3Tvp9fg6rrlNel3WKjf3htW30TF
9IENpiazdLiHbhSfCW9FltzOBRnOAObuKlPblFuBoWzGu04OHKOSeW17O2H5
LO1pkjcdFu9M3rxQLSM59illBcnLWfSfa81+ViPk1I/bimQ+6Wq7NJEoUgZb
q6mYia1MWKiYUzRuf8dPW942HlMmvnX16096NCPqfSSXlh2pV0mJSsMbW+BQ
y9uv3sqBYqoX06itGUPGItx/KHQovagyjhwpgaFoHt9peSamIyTtg0levLDf
1XLYsw8Pes8xPuRScH61+4b9pL7my681+WHQhO02i8YSSb/+t+y3o3dFFWJC
F+f/e8ki+6hP+8IuGnLSjzzZRvLKdLKV+tnwz4j7ZVgsupbUM6J8XnqCgsGw
E9zUxXQQyccdFq/PgkONQO8UySN7rzef0FAqw7qPNWleR1jIaeBQHgu0YcVO
oeXtZP6j35BqW3j8Hoo/ziZsIPv1UYm5m8iSIqx3CP2meouAoqXK37y5UiS+
fhBmvI7MX0u03NSXtMJpRftRwUoOvIJ/uOx1j4J6+5T1h8vk/6oK3sbhmTjA
GF56LpHUT9raHolBL0z9kwgsPk2A2M919Ri9AmyGvl5lJQM80+W8cmGVaLrR
Gn8viQCENn88HNaEDsMrdgaNdNhVOTL6wgshoxnlZS1CoFYtOnGlYBMeJ26v
3HCwHynaGWqLTIvhtz706RFnFopb6+1+yXyDE5/Hv1CSjwOH7Od4xc3Rack1
rUfqc5yju9rgTBU07tSJX//HRMRLf1fmagqSHoeemmAPQDrWRt1UoAk1SVVj
PmcJtOaevU+wSlCpJiSSROZXqTUKIdMbqhAR+rjWhfRrbYmnc1dkSb4Sjqem
3iNQnEVP1H36BrKV6qcsyTwg48O5FOYUB7Px5cMzxgROlGpuzUzrgEKbLD12
tB+BG7gr0rYHoMPrBE+aLclDWbqLnMmVVu9a5+JD+oFdL3Wzn3Ya7nWIlNSS
+bT61kxa9ngNNo2HJtz5SfpHEMNyfX8ZrI5aXXg0T/LIqRBlp/Wf4aDo9WiA
9EP3h1Gjz++VYbuhiIaqEQvlWofdmg2qIc9qbeuIYIJWkadVbduMjJgEyU1x
pH9WaWpGP3yPraKNUYdPEIi+8DdK4GItanS/H8v4xoQykpa8afiGoFv+RjdF
WeBqvSNnfrYKOZ/d37uSPExvPesZ7JqCrJSO1yDrfd3jlFSjFQVj+/yvfdXp
Q4o69e6CZRP4xRfJ0g6RebVSI2OxQTG6/ZbtGHMgoGJywGnreRrcRUPPZz5i
wPCV8sjXkq84eCuh++MGFkYDTi/aF9COe42rb017DWBk1pSd9YCGRzFFtZX5
/ZAlrFj7E7ox+tThmWdxNyRCdo/bmXfB7o2XUPxNNtjLe1eJCJUheO31C7mk
/k7k9N21ftMMJueLzrebfVDXyhhrmPqAtok9HKo+Adqr+z6ZW94BmnB6QfKi
SaVz/v20RuQ+D5sQ+sGAnd2FUW8PGoTLc7UWuDnQlkxX5dlZCzX1ybVL3hH4
HzVIKhk=
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlWk81dkfx5mrspRU4lqzTZaZlglpmfFRCdlFi8LIUqKGRBhCKWTKXmmS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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk41GsbljpSls5JiE7FyZJsHcmZfOkmEUeRwsxniY5ikkpKFFFxbG2c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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8ldkfx40Kc2vIMq2yJRlNlpnmosWnUJpKUUIoWyRTWULqhyRRSZHl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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8lO0fxS0lSlKWx06WkkqSUg+PIykpW6KU7CJKVEJIkkRUUkRRUiQt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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41dkfxxEGZUkLkcqEkkZIakTvOzSlyT5JJFui7NRFRclWhChZxlJD
Wab8LI2QZM3t2rq4lmvLvd/vlaQhMlHK7zt/nOc85znPec55f877/foou/pZ
nxESEBBIpcZ/86d5249bUzi4MFSs5DRJQKydXp3jWwnT5ei4i7EkllvjNR0E
OXCdqdD/p3YMWwq+Mg3WtCLYNpCI6SKxsePHEloDC5PEmmzeCxKWG15YZleU
I0jw4R2GBQm9MobHcY0RzMT97mbiOg4ZkwMXLOqrkZbKb408RWJssT1HN6IB
LSNVvYr7SaQ33ma6SGXje2373XkPEgKTmUdtJUqw+/7cbomTJJoXixy/L+ch
PTawhmlAYkufWEaCYQd2Fn+QuyZCQt5gn/3ajAYwXgcauRwiUZUpFjtzqQ0F
4iad6lbUed2XapaaT6HAunBZz5nE/XvHOsfb2LhakGQnG8QHy/7Wn7aiQ9A+
LCqXu5sPSVrHrJzVIOqc3MSLDnKxNi1CkTY9DGeftZ5+V3n4W1P6w4ntg9Df
F/FkBYcPgdAfuOeUG/C2nDPbTelrUphujeJ3IzD9KTPlCQ/3z3R6hJc9xi52
1ffsYBK5Gc5L7srd6NQ0/nLuAomoaJVKqeYhnDlx/ftoMYmZioQZn6I6LN1p
T3jLIcF5vHj5s2wDNJLNjlTYkHA9MpaVs1gNmsrEiSBbSu+Y4997AzrRKC7r
+ZMQCf+PO5ZnvXtRG5R88KQFD96z66eq+3vwONGOHXeVwP8ij23ske+Flten
Hq8CLl7ILqQX6nehb6yLxnxN6bEZ4JwRbUaYg95AkywJt20ByW/WNqP7X791
2xNISJzJmpWp7UTSyFTouzwCSdxM4WlyCCLFTta/TfCgdpSm15jHQvGwlPFN
LgG9jbJNozkV2HnJnHHShIT25XG/VStGMZpWoxAWT4BmbX4i2/4PPI9c2dbi
QMLqSsw3JWcWbHfv6N+qQGJ1wEmbEJVedByIpb9kEghMPvK+9CAH8lOh/i2a
BAT+tGFvMPRFRNS9z42OJHbEmy4NlnRDp++Bedw8D36Dc/uknZphSX6IFD1N
gimWvOnieA6i2367to2qZ6i9YKRMARuZGvyar7+SICJib07PsBHsdnzjxX4e
pKLD5i/xemFi9eCYixSBV17KO9mxvRiiqTiu0xvHxFa559Fd/XAe+0U9azOB
UOVS36KCTiwXFjqcyychbOf5r054GSTZFTdD/Elk1VxR59b2YhwHLB3beSB4
S1ZWvn1I9b4ickeEwMJge1ZGUznmxU/+o/yQxD2hm6zqQ304qlbTzNnEQ7Ot
6mp6WifqSjM6zgrwUWqzU1856Sn2zsWr0sMpP9zNChz9sRU6PLV1BksEVolv
jjNMHMC0/957xi95SM/ZWaLmWgvGndyc5zQShWnBc+Wrm/GjZrJukQuJ+tPO
98kIBtIfBmrEe5NYeWvr5ycre+BUmnKvSJKEs2j5gg6YqHr5UtepgoD8qt65
jaYsuGglXYk8RyDx2/gp+7dsbGvq/dl4FYmYUzeUHPgsbPc3DLleykeE5Jqf
y3K78MlsReQ4xZs8ep28l3wPdijSwy1V+ZAZF89rDe2jdEzs2eDNR5bL4VNV
p/pAl9o6NNRHYOJgNjdAiIExxUdudvMEtMxqhfp/qsWok6hZkxT1voZUOVuJ
27C21umup/jBfpdiuX5pAI/334r5/JGEvnHS8r7JLkRoQiaJ8ne4cuUvS+t6
YeyS/LDoOAmToeWBSfoImLphOjeSSaBlMqG7thWdKYq164sJnJfkR10e7sMJ
iYK+iHAuvL0jlpxuN6LhYFLb62ECN0zTTgusr4aQZOwbXVMSor9LPPe6xoHl
G6VvzsZcLOh7BdFXtcAj99qb3QOUPwL12u6Id8O2aUHjwwKB+pVR2v/oNcE4
65z2khKJgY++FYbLTDzT0l4spni272laoHdaPXheZbuIVIp/6V1L8+I9GNd5
dDt+lofnZpJiGO2G1q6CimcKBMp7ld8VrGhGvoyir6EaxYfGeEYIpwMXze8O
fVSn/Kamc/bJy17E1Ox3V6LzsWmi1D5YcwAHFG1mo7JIXFIWN7JVYePQyGjb
WTseDN5JWugfY2Gqm7vrpjjF0+Vyj6D2fBTT2VKeVL7IqtYGUomN0oGzR30X
KZ7rDs/6ZpyGwJTCllAniv83abbV12sh2q2utIbKW3d7c1lTUSVMfHYdDDAk
8axtS+554QYUcrS/tLiTYDlIuZ8LL4flOunZH6h92hNOlXl0Pzw227zNb+Xh
Gb1odH8AB0bBmpOCHB52brd+djmeiS793+mS5gTM/p3YceF0I7QOu9MWGBRv
rGpWd/+agJ6WFaxEitf3D8xVL6zORLtZV1yqG4lo8cYve1378MLR/3Aik0Sp
mfoX6Yu5KDxaeEnWmkSIrVbwobvDeF+0+XWmNA+pE68eFNQ8QPwvGXvyqf6X
ZCQcH/RXOa6uWBR6RP2XwCvTTwkGpvBRfyOqS+kX8LSd13b0RlTGVycDah2y
xS7KOrwdKqyVEnXU/zfH2Weu2dOFUkb67A0VPo4tOz9bFmRji93MHzZXKN6W
bZt4d6YSwuPEVzOq/5VuODKfEsxGoID8pDrVD8ZUGW4ZRg2gMTZoBz4hcdg5
Tp6mwkGYxaOVgmJ8VA39vHrxWyc8P2i8et9PQDe+vHkhqwoxPnIx31xJHHi9
o4kXMICflu/lfZXnIWXU0dG8rAkqn9qUVLhUvmbFTlxfx4R7iU6YhTCJTuPE
qgmzHvSrno8eofJk2p/omafaj+yQ/IhfKV6kPJYUkdFow/bTCrlcJwL+hvEh
YWYNyL9eDxEqHzRB9iCT0YWcXXXxef/5cbL1028nG6HtvqlDhPL/K0EfZ7U5
BtxFORh2ILApw1TdooeFUC3pEsUgAllCMeygO/VIv8xIO59H3ce67BEQOgSj
NlEDoVYuxMZ0dLU0W8H6a3vd8ftU/af/2kO05ECaIaymTfWbpOejvhd5r7Hf
U6RSVY7K09T0hrt6oxgcE5KYb+GhPchD/9JsD9aLTM6IZ/JB95OqtGwbwuz7
W55TlVwYrPcwGvHrx9kPJZ0WPgT+D5cotuc=
       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41dsax3FEiWxDiiupUCdjhRtX5ytRtA/tUqZkCnWUaDAcKcJRna5T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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk81dkbliVKZUmoEBU1GNHiU0lPM6MyRGjoZmkiIXsIRf0kiRaj7UYp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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c81f8fxY2KVEIqlayQvskuIzotDZRNQ2kgpEIKEUq2okikomRkZGaF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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41NkfxydKsyXXLnRBl3VrJdYt4q3JKl1QIUIoxMaSVSjVUHaZdeun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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk41Vkft0RlD1ekGTK2hFGTmjeTD9IMgxI1tmRfswztElLJUpkiIUWW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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lukXVvb0E5UUWcakEppRQpbuSiJJJBIipFSoRBlkjGypaSQk+QpZ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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8Vf8fx6WQEYpoyExGS2VF9TIjqZSGlRDRklSkkBFSKqFQomElX2Wk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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk4lekbPiPFmMZSklBZkgtpGBSKO0uhjbFXKjSVaZo0dXQo2UaLyth+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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk4lekbVmkSUUlhCElUo4YQUm6lhJFQWQYl2TJ2KjFlDYW4yERaUGSX
pcOPcKzHmuWcYzeH7/tKTBstjKTfN3+813u9fzzXcz/Pc9/3825z9LZwXsnH
x/cXff67KYl/mzXkR6HjyeLYH5vATxtsVnXr94FZbLzb9wWJZ492zWVFNyG3
1CwpvIp+6yXqNjFKMTd0xWQ+iELxZ89GkX1c5BX6CGz7RuDJc1HvG2vbIQmp
R+u6SBRoumlWJQ8hzDucjNs0CYEHraU+rBxUBBYdKDahIJHSXLj4rR11Lb+p
NvuRiNx3xCv+BRNtT86sT95IwSGrOXanFgsz6s8ss5Xo/K7c4G/cGowLuo4d
UaBQv/mxul9iH0yiEoRPJNHxy3wPrXa9xF/f06XO03jvROQrrlYcRIfY/+zq
hCbQdceIXyplDD+FzA8tBfKg+89epn5mM6jvk2//PUyhMOxZTuKOZuT/Opqg
fpTEQJlQl752P0SKREd+7CJxf//lih/NTZhY89grbjOFnSojrAxpDt5l94p3
lhNYro3R+aWrHA+b5LyP+FNYOh41G6ZZAS/x+CllKwrSFiKcWM8y3K5Inz+h
RiG0DttDZLvhbHuwL7GehKJc9vDPP3pxbevfGQqBBL6ztucqx4xA9lbVvkgx
AlX80q37Mxrg6OxpOKpEYUNLnuXqdd1gKLW8u+ZEgG9TkX2ieBK+RvAvLthS
YEozZrV5bQhI3M5OF6bfW0ZVulalQuTu0yF3Bwr2QlZpGz+2w/iyQ2f7NF3f
B4t7zx06cIh3OfMIjecqIoJ2uw3DPbzPrcuOB7mNB7OLHB/At0TrWO4pul83
AzykDHlwY9y7YSI8CaQqMR4kMtDtFT6lmkSB4zBi8KmNgz2u0e175Qi0WV1a
cl/iID/uqcyC5SQalcMUd2xrwGeHtQ01TygsWNqWhXA6oW78Rx5XgcTZoa6x
1dEcSDy8HmWxeRI5QQYdRkWNEOrUkCqm8yt7rBfXvcsEv0hEqyldn6HzfL2y
Vi/KL119KxxCQcFH7G5A6AhMZFkS7brjaHS0Z0qW9+NQZMqNnG0ExiTP2vJc
2fh0vq7mig2BlFdlMTIlPRCbF7ibqUXh4pm95UGH+5Ab6cr4pErijaDpx53Z
I0iJYWrPKfMQKviitFvxPg6Yk49f2lAw8+rgnFErg5m9scp5DQrWeX/EKHBL
YKLiK86m+RXplCwW+IYNfhu9xoI0ElJ1Ov3RH7k4nLaOqrKmEJjrfcdZsBK1
RG3X6XkS/Du+LZfatoLhOOf/eZnmt+CK5L5TXHwlt/RUCxA4bRRaGlnaAdm6
tAVWGAmJ+L7Kk1saYCZQ7H9ilsSJ61+eCgaPYn9DjufY2CRSBh7hqk4/aik+
ocJqEnIHMjc+rS6A99mfstLpej1EmY6kAxs7NOMUiFcTkDNmW/ZPJ6Hc8cwY
dZbC/a0fFmN8a3HolGHRnf/w3u7xvr04iLHvOXc7t0/Cmp9S3vlnNTJeZAVq
r6bAV5huWbYpBy4XPaYLjChonRsSW9JhweGZo0jyLgrTIWst9bVofV4vMpKr
nYTKVxnnqpJcXOh6+S5kP4U3cZksnzW9eLrYMB65ggRzLsuJtdgJgdlfo076
kPBpePa3plMdXMouXPGk9XA/tXT3OnIQGdyAao8dE9jrq7NgIdUHR3uPRwf4
CXA+jw8SWa0IHspX/aZPQcbUNzsybhjU7xYGRdok4pY8BGYINiqcAntq+Ajc
ktVmHrQcwJrhkqaMLwTMzE5pNDdXQo3cICVC63c6ml+1R3+I9kleXF3yJBIU
F3jtKaOQ3/pX49w/BGbnmhi1BsO4diw0bTGFgKOqsLxL6SCmUxev6SsScBBx
jQ+fSUeq/DLXwpL2w2l96902OTAxn+C1OFMIIgxPv33LwpKku3T/As2/KSbn
5M4BGHwQPyMbRPvBrI/JyIsaDN4cJ97FUBgXemZb3tGM38oGVgb7UTAIunXy
pDkTe2w8cmV3U/gzNDNtKn8Al85uYGYKkZh4dcm3lK8N9QFsP3c6H9+FG1aL
y5dQuLHrAIOet4vbvneEfgWuyyqPM/Qo6PnJrxDtqsc+xrCL6ncSTnZXY68c
bcK91obO6OckPkbMvQ9RzsPm/MC86WMU7EzfkGpNw6i4xx076TsBlZRTYxN0
/IaRX+K799D6fR8yc06tHMedzKYEAij4LFadKxh8iU75a/5h1wjwh8/tFZcf
wMxRIRfXRBJ6FTf01ttxsTzOaGQETyLjKvv1rdWDiD3Aud208hWM5YX/eaDJ
RK5zj94lRQo/HxJbb58wgE1TUzoOkgR8fnXjRO9nwPxugWSkO+0XOYq60wQD
K8WECg7wSOQq1pSuMhhAc2y5oFIhidcrPG9/OdSCfv/38wNfSYz4uSVfEOzD
yS83k7vLKLh9WNAliUFcPMa/pkyY5ue16ciVlRlwN70lcZ2e599LJvtzR9ow
y3l735WOL3ttueH+Vi5MH76aNpciUOd7WPdFBBvn03rTg+j6FN5HiR5+XYm2
jyEa23+hoF7NExZV70alLakhdpkEp3irsJV6G7rmPHfskaH3z76F7JDkFuSR
U6YfaP4+4bbomDC4uC1uGrdZchJaVrF/+ve14/e3qUyZeBJJrDMD5zKHESXG
UvrkMAm1JJ/Tms87UNUZeXOA7v/HDxuD2e4VuLlJWdNagsLBhN1x0nMczJ+W
iQ9snoTGonfB4sVheI8lhCe+nECx0ebAO9m9kDFmB8ZcIfHZ+rCdY34vypLf
h0oYEwicPRj+pK8WKzODpyy2UOD3Ul42eMuFiMuPfAUjel+pHCyx+d6PhcYp
8066/1Gj9x1ti6qwfma92qkI2i+0Q0qOhnZCxUFToZ7mn3VsQk+haC2sVa4Y
espTOK37dCFJpRNXfUzk+avo/0f8S+E7b1qhdfwWI8yT9rdeZnW4fCGSHN7x
ymk+BizyVmnsYWCBbd6l/Tvtd8HqvakWfagpeuyflUXg/UEfy7V/sFApen5X
eyqNx2vsei97CEM2Uru8JicwsUrrRklePfKlmXFK6+j9ncieufDzCKqX/Q4Z
Zo4jUuFo8va5ZDx5OPQ83I7C/wFkEMHD
       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk41VkfFylCjJCQIhVKRTKi5lNSKTdSKUljNyhLWpQKxdiuJZFsGYxo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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Vd37xr2hJFPSS5KUJFKJMlTcSiMiDTIlNOhLyJBUyhCS6BUNEiHK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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81dkbtkUKRagxuCo7idAYGY8RUUkmla4xqCw1kSWMyo0wTcUYITLJ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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns0lVkflksq5ZbSmvoUoxJGZuKQYR7XaKgOmRTjEsrli0RqkppTisNc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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4Vekfv9ZpQfRDN0ypaChNk8xE6KMitJFf9USSPUuJmwxZkmIUZV/S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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8Ve8fRwjJqjTtUsmIFCFve5ZERlrSEpJKiEIhI5lZfSWjhZJQKiqZ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkfxi9Jpl9NY8sSpWWMLRUKgx4Ze8o6oVIIk5ItDCMlo1IJSfZu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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41Wkfxr0lSxSyNSoppZORpUSDupUlRBkMpUiSDCnDkIoWZKxFDaEZ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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lmkfNbaJmS9DhrfeFsZWk1IjheJIqEwjpY9UsiSyhJCMsi+TJVnK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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3cg1P8fx40GITSkQTISKYqQ1FNDNEgIiVJRMiJURkMiMiIqI4Qoq7I3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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41Gsbx2UrJLJFRCRLEUVScb6E0OJ07OVQIfVOcii0cLLklQoRCceW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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs4lOkbJjppKyJLbUW21ta20VjNErecy6E29CPKYRGRrJC1irJF1FqH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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lukXtqRVUYR+SYhISExEmVujRQ1qNEWDkEQixVRMhEkYxJcM2RqV
KFrsCWP3Wcb2WT6y9Y2e164YkWXi98wf7/Ve73Xe6zz3ue9z7vPInXMzcxDg
4+OLps9/7yY1peQFYy4+2MlPim5ikBxjPeri0YjWPvNY42yCK3wZKSX5XJwY
9t952IRBpG7B0qW0UhSd/FHX6wpBf0qZfKxcL4Ykc8sVoxnUTLCWh8y9QfQf
K35Ye4lgb4DCxsv/dkP47sNL5rcZ3BX3dm7v60PswLkC00EG5VlqjULveqH3
m/7V0HUDEDb9eubSCBdnrJtvvtZjEPFiWyECOZhNt/qcRfEEf7rgJvuJi1Hb
7L13x2l+rWeV0wnZWNE3YX7fgYAddOxXXm4zNomdWRNcTOC+K+tm4jdtkHTM
MBDmELgIlxd9iGzAgcTWBcsnBPWqmVaWNR3o5/wdV36cQWCTm8zjjR1gO1+1
tab1dg4em/wan4/0ue7YXbSeqI2BtQtT5Vjm5cjv40MQKSy2k1+yHN8piRWx
3Qg+TkYLLXpyMbvOdtdKQQbPajYo5TpmoygsryKX4uO7LT0+mfEUBZJ33/Js
6fflgtDP8r8gMJFR3mdDkHXSt/kGrx1EcbdP2yiNz8aODVgfwPXN8f4aNH7v
hq+PrQQH9TN5qWW0PuUYqcbvfboxpRdblpbPQNRBP9Tzey7Yh0NO+pxloPVp
0Itd2wYXCaMjrhsZ9Cemcp0NW3BV6JbHYgZBxnFR+Z+WGiExuC7p3kuClhUK
q4wUOej68LxCrongghG/v9jrZmxpnNBv/pNghuX6uSmmFpFTrAfsaILklxah
Hrc5SMxcpTVF8ZD82G6fz90YreJ/PHOSQcaen7UEfihHxfi3xrl+BFJPuN7b
jYvwuuhMZK0rQad5q1B8aDfG/3Sfs6F6G4g4+vz6/D6OLu3bmUbrrXUVX36z
g4Pw2JRXv1cQ+HkbfhzxfIvDbTtOPHGh+vOaZtzXcvH7pvywEGUGxk5s3bJV
dUhzP+RHoggCD7rWs33bYCkYsVZ5NYMb0t521wtb0RbR+k2FEAPZNeeLi2pK
wPJTeddB8RhZX4j7sbESjc9zFXQ8CbT/WLXH7CwbgY4517qDCPZr3VJjtdbB
Qttu/ksEgQ9v+qCHTT2iWiMkkx8SGAi7FlTNBGG109wLC4q/JzGo7BuDVvRG
1TwrYwgUCnle7ll12Joe6NVwn+Bc0OKBTpU3OJdQZ8F1JKib3Z85+7QHIj2c
fUE2DHiWDm8mthaiciEh6gjFV9ruJscXGYHEm3IVHjR/cnb/n47bmhGhK3mo
t5LAM0CvdJNoO6I6pmXGab2lr3WTwuJrEPFAhveARWAqme6rXMfBC10B2RHK
p0agpl5mbw0ezVawLH4jyIeeSCqnGPvDY5WuORMMrBCZ2qLei1vr/3bvcGNQ
WW9RZjvXgCGzki9hj+n58kfnYyzbwXuZfPJENcGhIEWPS+o9MF6wrw6YYZDk
ZjcVdz4YU8FaY5YUb012p7fm7h4EDN8pWW/AQJhvTmt0WSVOBWaYZ9yk/Z49
qKCakwNBE7ZX2HmCsLjKPJuQciyvTPr+1A2qz/HF9Qr7C9DOb2xoT/UfsvrL
UXy8C+v6p4daqf8on72WO7Q2E7K2X7hWdN6cnHw8t1vVI+GIlvA6irdI+pa8
OH8tpodeioU/IJC2rf7jlGoTXPtZ3fy/E0yoO2TkrE+BqGSvk68dwdigv3/X
ZDWunHr7w1wYgaaSB0kPKIO60iad4esEwlLHR/XHa6G+JeyzF+23/jUyUsse
dqK68/T4ETsGfH6y4wFd9WhuOBoumEkgezSiX7ynGBrRp2c//Uz5cLGv9UUD
Kn4JNV35X/+wF0htZSxe1UtbdlO+hNvGrMKTyiD/92kJM/p/WEcM30lOLWSX
+5iZPCK4PjTgJf2sBxKRkvstHjFINYw/cNG+E0H91Zd5pxkU53mlpS60Yiyi
fMfptQyGtF/ISk20IOlObMT6bgKWUtkt1eFUzCSdPWhI603geQenR1O/9P7i
tEyM8tkvRrjqjRDQGH+SS/vHYHr7tNivPZDV1I+6XMhgj/q9EMM3naiwfpPV
tpfqXSnAL1tXB7NdvENNqQSiV4x3TLxvg6zgkvo89bOPKq/493o0YLW688ud
dH6OvX/27lERB9pJ4toNdD4C+E9cO/C+HhP/dH2xoXyWzvnnB+uwMBYS8vgX
yod26MMPnr4cjCiS1SUfCFYqxJmG/K8ZH4vDXw0WEtg95Us6s7sdkQMXx7tF
GCQwustupP0Fue7ByEiqL2v/VnM27mOg871+DM0Xldh8ZFIiA0p7Uop87AnE
9277WUCxBqLI8a+k5+dHL455bH0Kha+DmiaUH6P8UrGSlkrwhhR2/+RNkLT5
n7ZxgWTkDcs4l1I/72Jvqxp0bEa8Tn6bZhVBRMz4dZ3UNtjUzovaTxIU+N1b
+SqzGayRgyfkc6mf9ZvktF+4Bpl9pz7qUDwPhkRLzHRyMV91Vj70It2/Giuk
j6tlY1HT+5HG+f/8nt2QV82FSclVtQ/iDMQllqrHLbkojtEqT9JkYLFkLXMp
rAptIc8Os+g8KX/n6mOk9BYaAtu/BtD95T08y2+7oRHCkhyN4/EEhub2y+8c
5SBQVYYXwyY4mJgrbjTNgWCpal94OvXXdF2x7T+1407ejbKLcgxMV2RU6u/m
oFEtpdC3lsZdLsd4B/fB+atly2GDAegIu4Z/+2Mz1KVVBLzfUr98pbMw6lqM
8jDRGGEPypfEhQfrVTqhlyJ6wYHux4PPZZWzljpxOXWhzIT6sbN1X/hGdGFa
yE8qwZLBbNzktlSrMhxzNIiQo37M2mx6hRFLwzz3oovDOYI2ke+G97S2wm+j
ULFuP0HfP2aKImLtyLm3tl1amoHGt5yWDS7JIAFBn6epPqzfqjskq9yxxaBH
QpvyLTDy7m2mFBsacf8Wz9+m9wOVHdaRG1pw5XSFVVo7gSqKR8TfV6BBPl0n
kupdFbpabbG1HWs2Z+yJpvOkUTesySM5+Ci4mT/Gifq96fZ1SYI9iOmsUokK
ZfB/aijEXA==
       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lG0bxlFIRZIS8UZZImtUWjjppaSyV1QKISRkJ0SkTb1EiiTJVkqy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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs4lGkYxlFOm1QmsshqUiHEppPTrYNDJUoqixSbUzYRqSbEtiapLHIo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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk4lekbtlQTg7KksnWoZEZTIpX1zpKlbBllN8jSkGXISNkKoykaIYmS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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4lFkcHqG0q0hbqWWjR6U2l1AtqlcSttQqG1qbkVtEFLKJkWtJRNHF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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VH0bpohkq1CWkBR5ZWmx9KrblmhBVCqKJKGUiqJXRdIiopIsZc/S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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs4lOkfxp1S5DCzOWxSkegk1BJbdLdFhOTUOkSRhFqxQuzYqFTbSiSh
0oFIDlEpRGJCIYchzQxSZt5nZtkph2iTVL/398d7Pf+8z3U93899P59Hd2+Y
a6CMlJRUBv39fz1Xnj5ncIKHkoHiSa46hRLTpNjGHB5elbtcmpgSYt/7wKE2
5XocYPQZlY1RqJKVDHJecKAxvOeIMxFik9QQh3OnDTckBVmrzhMwUj6GXDne
An2NN6m2HylMHZnPu1b4GGuSv9wYMiEIjy971u1yHyrt++pmfiN4Wux0fdCX
BxmufanGbSGsDy7+q6aqFUtqM0cvEYIEje7pe+nlOJ/f5cv0oPevmzde4fgC
J/OXhDasF8Emdsmpu39yEByaq7KEI8RScfGOJEEjrPZlJoWKCbSVNZ+ngAe3
BT9kf1kpQuIKasHD3EY4il73KB0i2ByeGGIv2wY/vw1rZqVT2MQUs03snsDS
NOmmmzMBYUoyDIU8yEnuFQWtEKCKUTGY870azhcP1gcdJ2h3n8aJMy/Rfvnu
u4hdFBa9Y9t7xj9Fxh/D/Z5fKewU535eG8dF1FHlr5x8IZoTP6ltPfQU5gy3
Pu8sgvXB31mZY11YoacoWn+Owspag5mKMT5cb4tTHnQNIjhN1sXgXhOmbfbw
WRSFbLPxKemBTlheeL5OVZ3gZ722xlsFXLS7sVzPBFEwWquwQd3qDRbmdb83
sBfCsLZ8u4ZiJ5LPZHNSiinUPwy0eMh9AoeQVWEXzWmecQ4Vd7wfIc0v13wR
i8Ax/Q1jsI4D1l6j/TXBBGlur3z3nuxFfyfx9PaiID+qH5VxnQdvFbZJwQz9
P9Ud7KbAwSF2SmGeHc1345n5PdsH0FN7dMl3mg/R5l62HO9G7z+6z8bo/oz/
pddqrdIP0rD6ZiJPgKm8EuaeKB6+puYUyJyi+VUx4ytP9CIs4PO4iZMY2w7b
novczcHWiHtGy6IIfmRUH7mc8BxH+jXz/jQmsAuoT4yqeI6U7ZdMzjIJVir9
4Ort8wobJ//0r+gWYMj2pO9jz14YTMnmvZ1PIcur4twO08dQZfYyJJsILlVa
3bFWbMHe1YEe77op3BJ+Oe3j3w1vzvF81U8UDl0t+nXasR1jkXPMvq2h4F69
4jeHiGbULjit+CyHAkNBl3lreS7k5Vwq9Gheh55+iomVeondtXWpahNC9Dkn
zNiIXyLYVIc1e78AJlvetvI35WOb7xWJ1B6CVePvkzdodSBt2xZ2sSJBa8vK
l8Vba+CTsLOp0obOh12fyPu1GZPXFMxk5ooQHuMfpBjYCDU5x1SdawTPLmuf
ibEZANNtEhFKQjjluIzOkeqCULSMInS+MT+adpoLaiARrCq1rSawsi8rW+sx
gOhhLv+h/FuEW48y6l60wnLpbekNQwRSb/SnM3ZlQq3J+7h/CAHn2tIIr9RO
1F9qEMrmEcQeGDRuzeNiKNrLlNgIUavsPke0sw6OzFnhRicoSO2vqdX85RXM
auxn/3FVCOd1Z0tHPFsxU3MwPWCFCDmv/IW/hLTg29GMuT6goE0+PAlz6ERf
z9avE7IEOi9K+uxXFiOrKcaas5NAjt/aNGrTgbutxilHaH9Y/BKk/eunPmzf
0/zcdAvBJpbxjZ+G6Xn/9YnN/U4wpGm7XTBShznVXVm1Jwm4W/TTVdW7cDbX
K/6BNIWhQjvXB4JKvIvNYIXSfSq5U7yMiqiDwbFEeS8hfZ5HZVWvS7noMYi6
erKOwkxK17yZHi5UGTNCv2E6j/thG9VKCkEsC1QMTxBUTa9PROhdVP+eFzif
9pOWVx3jfjAXlXNLIhpsCf5iTU7abSiH/eSVkmfutB/lq37W0q+FvcGGnIm9
BD09OnH/feSBu1nNNs6EguWO1x8jDDswqbXt8TW6387CaJmmrAbM5DyfKBqg
0Grxc7B9TTPEI54yTjSvx3oKr4vtG7C2/YGkjJ43y0r9UVk1BxtnGf5wtYNC
5IS87L4dbEwUXMm1MSCYZfDfdUUFLsz1pJjLIESkt1ZsGe0/cVK7nA7tW2/p
7KRKIR9jA7khddYCWFYUb2G0deOk5nkdy346z7uS5BreQzhaqA+07ya41u4c
LdJsxZOQ5Qc2L6Bw1iSgU1eeh8X52nPn7aMw5uolbyvDxaeLAr9FpQIofS54
5HGmG2uzKv6tT6XgzE75aZF/J8RL15xeRPtCx/nosn5hN95lL+yNoX10NtHk
IEobIRkxroo3IphiL89/q98CM9/8gUUWBH4yf/8z8jUdCUpBny4EEGS3jpbF
+L3G4szFDqNmtA+yx2pXH3sK7nE7Kyc12h+q99wWB9RAbKp8zDiBoMOy8Lse
sxO9f6SHbXYlMJBMVN424uO+e3HdwW8UYqatVAwje6F4YG5z/CYRtoY8PDXi
zEZcrft1p/cUfB6kj2S2crDaJFrfn+7TjZ98G8Tnu/F3XLZvqAOdf+QT8dUF
VfD+4HT6aSmB0rbho/dmdcAzKnibFn0fbm6N0D38kQudkqIrF4YHYe1FndJu
78f6nqulq6XFiIiPNzif1gtJ8C5hej79PrE+xLqAjaXDA0NzaX/0DB4+OKXD
h62C5jHdZJonS0a5fKgbypGxzVpsAd6F1Iz0qfFQJilVUPUUwrMqLSYivhM+
TyySPxym+Tlf8mB41GFp4MBkIH3eR2JHTlYcB3vt9n29WUihZ9x/vOUyD2+e
VUZ9MxDj1Ljd4tl+TXhb4qjNr6DAN2jOzl7ZiKOfJ4d3uxD81ndI3X9/G4rb
ZSIWhIngYO7QJt3JR3B20IUvTYN03vk713zhwP5iLsumiH4/Yt/UDL1uROrI
i4Xn6D45qYTEvFQfwN+5/rbs94MYDGqvE4QWYDQ8XP4RPa9GYNEt1/IOxK3m
p5lxKMgNOQ7s6e3DfFO3/zL5YviUuk+eOFuF6OpIY+1jBHffK79deLEDtdUB
4bd2i5AglSv3nZ+Bf31t1Tbuon2XqiQo7MvF9qlomTJ/AjUP881tpzrQIboz
sQ4iTBpe9uIW30TCMdk19fYEmZMazKQiDnS3uCXXjAjREvoqTCjNhQWzRML6
XQhGvq6FI7sFPVf4p/8xJfgfD9/Baw==
       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4ldkDx2UpGYQW2oT6FZEKSQ2+lihKg7LdoUVZJtQgZNqEpCiyRI1B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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk0ldsbx2UqbotK1FWhTKWy3EJSfCUlSkoq6ReuOYQuMjS4oSKlrjIU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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8lI8fl5YyW5IolVRGqEiUN0JLMkpGVKQkRVIaRKSUkb1bSIhCssle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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81dkb1nSVNVxGY8IkS5KSRjNDy0NRpGJkadMgNUS6vzINuoWytEcq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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk01ekfx3WT/GL8LA2FUanIWBKSpfHWOonKpG4RkWyDKUILksiSVGNI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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lukb1SQRM7+sbWRJpckgkRKOESkjfWMZS3YKY8lSilGJsu8VokQu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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHk0VWsfJpG6mZoomUKmDKGS4kFClKSSREkoEpJLyZSSoW6p0CAliRQy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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81dkbpgxS2TKI6lKSUF0xMZYekyYlGYT0oRHRMIkWsjdGlmqQnyZX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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVWk8lVkYV8RkyT6DmEGSQsOQpMb/KrKWQlkqI26hmpqGlJmWq4RJUkOU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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4lOkbZqUkHWxbjbJlKanthy05bLhDBzmnVjlLDpHwS8raREXZnHNI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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k8VG0flkpCJUWSkFRUnhKVtUt2pSxRyiQhqSQVpZ6IQraQpagsCcm+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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs41NkfliS7i1CIIqlVSULRUvt7ZSNFcquI7eK27v3I5lKSSi6/3GKj
zO7atImUkYrcb2PcGoMZlwZl5sxEW0whcqnfd/84z3nOc57n83nPed/38673
OOPoLSkhIXGTWv/usxfOaZ6xKcMz+zX+2ocIopzk/cVPuHDM6jEr3CWEkPfm
SnoeDxwLdz32+GtINLkUxLOskRir+srwJIGf6zJ68T8VOGXzae/lSQFe616f
vzl0B/4sN93BUwQGJp410uI6NNdbD643JSi8a3/XhD+Ab0wGV2bpU/dLq6be
2jOhlJi86n6aABH7/G9/Mq1GTouOTlMRwYWoXF+xqB2Hsyev5O0g2F940ejI
Lh40RX9Jfwrjo/zphlKaKwvs6OrOZ/kEEsfV4+yPXkMGzWJm+2mCdzs+tP1B
50KmrHihr0cIemWnedn/KmC+2yEmsZjgjkbRxcjPRejtdWYG7CawnqDT5c+x
Yf/ZQtP0FoVHHDX2Nm0AxrEt0x4/ELRZn8z+vmMAlhWzdgxVggmdE5kh8Wwo
/5IbGx4kQFz5HmulHDYahg6oJ7YLkKK1Tm1ONIhd820Bx2cJVEK31Rbu7sU+
r4kyLSmC42MOIZvpQ9hsmlXoWyOA3lxLWGdPATrGeQ3OJwh0m3e3TlkxwG7g
mR10IpgtuJ78X+UmpFqW50rZEsg8uGAoGT2MNkvGp3VTIzD0S9JQbOBgecN0
+Z4mAa5HvG8br62DSkbxtxcZAsxeuq2g0J6H1W5t2nf3EWh1v5GmnU6DuqDq
7brjBK93jiqax3cj3zJgx/RVPhreXHtmPf8MZQNcuQgXqn+kGy3DrxHaXjbV
+tJCuBxPqxB5c2Bc3u9b9AuBr+3Em1f0RmRreK2LLSXoV8roO1BLh2T+F566
JcGMUfDmjc0t8JKjt81mC0AP1onKohVD//aN6ZQggiemUmOxz7lYPKyv2Dsi
hJpQcWregAHnSI05m48CPDCVr3ha1YvqsA/MTX+P4GPf2g8+xlzEx9t2QZYg
5HRLiUtFL6Jmfvp2MoEP65vtXkNNJfC4WKib+9O/eoi77X6GgdsFC8p5Rwlc
NmazosJbsbRqJMssTgDbuen3fiu6Eb640Bki4OOSWoT+ggQNEUFxPH1K78E5
SeRX5yE0PTAZJ4bDUDD7M1GZ1gAlJ37CMJegTsBy/Wnb33BWM324n+JLb3mb
xZcb7TC+f3p0jwHBJsbtiNqdXIxvkqnMI9T/mBE1Es6G1Dvl1ymUvnyC6uzf
JrNx6pOP35FjAoi/TOgs5dLh8Z05k/MrgWMFWRu5uR152+R9k44QFKVYZjMT
u2HlLCp85kpgtdVU2mLhPuqcKmu5lJ87fR2y5sf7sbo+0j3mO4I133cdKR7t
hO29w4dUc/jIjC/68feyFvxcoek06CTE6PjRx4GvGmGkkz4fsZ/A5GDOPwOJ
XFyasMw3eUzxb1bS3UzVS1b7eVG8XAC2qmzURzYbnzXPWSpN8/Fflqt2q3oN
6Fkhro8o/2/N1Pbs3dyPl9J1SeGPR3BThnE6wK8Emjr2UiwK76nFr+lTuZ2Q
P6jzSky9x95uMt6Q0wlR/dBSuxKCo+emrrp38vAo1jayeZHyk1V7zaQCF/9J
Lo6o0RNgsmouvzmwG4EKdhEKzpTeve3ds3tawGLq3317T4Am6wHvM569iLjg
833zDB/38vtL1hr0YmpSqjSmUgiZh1HFuUGZaDJjynpS/LKlGFlr5J7DtKM9
1JaaHymta700VF5i4VYsr3GPCL2DP26/rsuB/BIr/cs0ARIKVRQv//EUJgEP
ixfdCMoNJxrFj+nICRoTn7QhCH3u0Zba2oNu3e7oFkcCelhQSr5XHqJSb2Tf
8SL4GjTlreXXA/O30fJMNz70aEuKcgQ9qKRdOLTimBAa4jOtgQoD6H7T/mKV
FR8tqjGMyBMMyK30aNeoJpDbn9v/wZ+FPx8ZNdUfFaC/poVroF+Bjmtlkg5a
BAnpC1Yu9HpcOTm/OmSB0m/3y1TdQKreQb/S9L1CqAt9UutWDKJ75uNf542H
YdB4Nk/+NQeFqQtZCkpCbKyhb/Q17MQJtXNykxTempyjG6TLSiEzouAtiiPI
NQuX1jHqxybO2lCrDgJFJQdFzfschJVV2kdZC3DVzX/XLYqfzG/PZ3jG8vH4
G+/ok5/7YdXACn6xgeBp9m8Jks1sFKgFGe28LkSYVKzssrkSBKWfXzAJI5A9
bGikfrYLtJnPacEpFL+/WVYGpvTB7UTjA9VfBFC/ZmiqvqUPCsXjc+duEWQq
z+idiewBf9/rltxZITqq84+9sO3B+xcbbFfJEFwUu2oXMOrR8HGwwdiKwA6/
Rn+160OQU5mlfQ0f3dVqtee/NEOr6Am72UwAF53UAKu9bEj3rpZvsiO4Wt5n
wQ/ox+7C7UfmDo3g3oEEn4IiNmj5yzoklwrwvO5iSrL6M4gUNIfMt1F5lMVz
YL/kgJt0wOvFMB9i67JilR3VeHh3sorXSpC2SqnFTqYUJw/s3ZJ6luCyrFaB
EYMHUUDwWdaxYeyrGVYV/DAA7xUtPzrn8+HilXm5q7sCBzj6atmSBIFihlbv
kmZcVb06HVpD8S1a3W4SxETbgP57cyUCSeEWuiKFf3raPmMFNY+rFrU0o20G
8MMr/xt2riLUfafcN+jIRZj2+oRQphBaNLshzmQJ7q9cPpaYRPk3ztKMNtEF
0dwhW1nK3wYjGX4717HxSe2fLYpbqPlVkZGkqMmk8s6tM8KXwuOg/urJ32zE
xS/odlH50n9v+9ekd3SYxVbf3UCdaWncQeOnfdBfLLR4x+Kj6TJTO/RlLTRL
rFevoeqZ90mzPD2u4L39knkOlX/sz8wXjolszNw33+8qQeWVNqtguKsPMZEd
Z0eXiXDt+dCNdfyXsNk5Nu13jPJfsMriaH075GlbI9PdBbhROK6y15ULYY14
ldUjPm5u9armzfSAnvx1gGkkAu3UeseYax04fUE+8Hd3qt/Y0uQ5m060RoYc
iqPw1N0pDlmp2AyHrN3P5ySFKP8jbziv9CEYDXp9wz4EC+GX1ozKtcMuhrGt
34San16eNJPpOlDa6FhF+eP/dIfWtA==
       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41dkfxyWTRKIZy1hCyBqiZCa8LY2aCEnSFdmpTJaGHyoJg5QWGSQk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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8VWkcxm1RNGnamMxMClNRDYmU8pShqxJCBtm3CpksWZJSUogsSbYp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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lO8bxW2RimgRUUmJSpKipDqRpZKiBZUt2ohCkSJk+VoiKkKEspcQ
kd3Ysu+GMZaYecfYQgil5ff+/po/3muu63nOc+5zPvdmiztnr3FxcHCYcnJw
/P/Xg1p4pflaOtKsP479DiTg597VE/mkD6d1Vzg7LyGwTnmstPp7J7R4xQL+
6BIw7vs6b/a4HE7Rklp7l7Fg/oV4YqybDy53ldDTNUyYL8YFRq76jJ+sWzU2
+UxM8/PtNNZrhG/RKYFMQQLvWF7q2hk1eBqyqVJ/MxsOm3bNmDR3YJPS0by2
GBbs1l10qBR/hyv/KP+89QmMf7A+Xu/ejx/979SDZEeQn7uxO/1gO+zMdE4l
OjMQUhO2f049F4IvJT3OvycQ8sD2ndCtWkhnLp61+Eug7p+xsptECzwtwx9a
/RjEAempDLr3Z2RNB8sLGhLIpG5Q/nwiEU80fnqOmRCgCKzVvmhcjoolReL8
2gQW5x9ni10oRve5aC5eaRY+v89U9p/qgtfCX65nZSwItUuc8aFSEbvScPeB
4WHY7WmYTdfJRoPXwefXHhI4RzUK3JrRDed337MqNpP63I8tPhTQAREe2Yb3
esPI/OBru2RFJwIKKuPPJjFgWd22TX7ABU0u1UrF5HlqPHU0YkUKcH+l4n7p
KgJZVGKghLcFudKrPpUKMPG2obl3el83MjasiH6mTN5nmXTd47t0BD/RWOyx
G8RAZ7h3Xmop5E9aC0+WEZh6ObnXtbML9QHS592dGJB8WOm3KiofvSqJStaV
TPzeMifxYmMbpjn3fy7iH4ZcbYD2WrlKTCVPUvm/MuGhHZ0t4P4aQRJKPiIW
BMY8/rQbH29CwZSTmVvwEGoaPZc9MOqAwlPWbOzJPvjVMThUk+qx40zPyRHS
X2+9X6cEm3egWuj3wOFmJjhO7NYcSfKDWnTbYosZASc2JWQskopKqbBDM1Q2
eLsiAoK1yyAktJbb6A0ByZNlCs0fwuF6frNC3Q0CJVHbEqvN2qHHv3bJdYKJ
zL8T8XLFJdhy/8KHsDQC13e3S+yn9IHN897ZoXUQRY6/DsTZt2BWIEd+lwQD
sn4xd8KuVEHr9o8tJ/kIDAfu3aJ1ogLDT8+PZnMQcHUL/yUV24SEerVXte1s
6O25nP1ErwpGa+cUc0i/5TimyoTMUWHAtI6X/TeEtFZ7jwT3FhS650QMDjGQ
ekCYp8a9C8FqXr0puwdBe33iW1l/EewURop4HhHgNgmLtdpFxfiJHrmLuwax
rybAJvtCPk66RDh3yROwSQ9/KOdbDwsObBeyIdD7VSrVRrMJqiIKBzXcGVhQ
0rl84zQdB0259heY92PMhccmOYeOnBUTUWm/RmE/vVr3sVE3vq9fu+vzn6+I
ObbzpsrMR8zK7XU5uIGAx7ONTyK8a8G97bjSxBMGTq2tpQZuaYSO9B9n00Am
bhoVjj41p4B+tvHYkz8Ejho0KduENkPC6HWuhM8Q3FyXreNY1YrTo4r/GtWH
oLTw4cT7jzSskzmw5PKeIcip7J7zz2zBNY5NfpevMuDnZrDHfGcNVuX99N73
kAXqtPM52bxOLIrXDQfUsXFKbpTmtuULklPuqD8NJcAl6363b6wLVfNLb9ke
Z+KXxuhMfEMbGhKL3JZ+G0aCdNp67YR6jH6vDbztwMIa39Uhrj/oKOfKlVzK
YKIksEZxO7UVNZdKio4cGcLV9ImsAko1JNoXGKXMIZj3Wj3rE6+HkMP2l23+
DOh96jWIIdLQ0Lit6ZYmgfoNEeoa/s0oGjniWDA2CMH5wuTdsm3kffkVc1cy
8PBoRusjuVbs4/AW2xE6AONkw2N9eh1YmqaVa7dmEAvcir2NcpmY4M69scSN
QLCfx/6C2RakOa5l37nEQsiswuDepe2QFCga/7N8GB7/qoYGn3gizPSZargx
qbeZ8J4RmyoI8/QMZAYT2Jamr778YjUafXRm9mUysNEr0i8jPBV1gSuYt7UI
tIR3uLrdTMUeTnP22UsEyuW4jt606UKnXZ05e/UQjATmC3Q8y6D4aqMnVxSB
xAN8JlIdnYiwG7EznCDzxqiFy6G0DG+juI+63Seg56c0u2M2DlombtxJIP3C
txDK9kpDQe5b9rtYApObbS41yPcjWrLv415dBgSWXTc05e+Cd4a3YeQ1NgZs
w8+H/Y4EMes4x6lGYOloYlKPSRe0/WxrgrgIqO2pnw6ObMct/qoOwp2FgcR8
PhtRGg5XvEw8YTkOipKnm3BqCSQehg3UKLFwIqDs5vcdnWCdYLN5pkl94vu4
Tk48RlZ9ne1DUq+SNyOfJn7QcA93OQ0ixhCi1VTOOVSHmLt0oTs/CCjqvTgz
dyoBVqX1y+39yDxsyVHJeFWKSfa9mAFOUj89A77VfvUoMM/5GfSIhVetS+/K
WzfgzcmPCkJVDNz7e3XpE59GjJTaKem7EjAwu+7Vzt0Dntz51vjgXpyufiOd
WlgB640J9frqLBjsOr1JJrUdl/WnP1VkDENW3iow8GYhAsvDJLRYTFCS+u8d
EetHx+b1vyvER3HPJu1Nx1g57iz2c8RuIvXaLVDh+LcNzjJj72fzCIjOcfTt
NW0DT9XWst3JDPD82sSra1yJpk+niwKYTEz4DRqc96LB3+1utq/gCM6VecWq
ZzaiQcJMXWQ7G8azWzmSHOogcrnteaYZA6Yvrz7LelmEOh6W69t3BCTk1U/H
sSmQZgkp2v5lQq5zq9Cav2VYaNbLsJAl8En8nX462ae8moyqSvK9j5Y+1LMW
98aOj1uCUsg8jnlpNRg5WIF0Q01i8RLZJ3t7eB9otiEjzt8tkYsFba9FqeSI
ChB3M+tvkfzwoFjXiEHmg3EFfazOfhiSpfleQQ/LwTa49knsGxNH2SuPrqmu
RcPni94vpMj3Nmzb8i2BAr28eLVXLAIKW/Ye3qQaCycb9ZHps6TfY81cD4W8
QdulD5nXz5Hf7+e69PvFg+3Uc+432feBt+rDdnQ2QH5lbkpczBAUOq4w0uI+
I+B6zR6HMAJCfr1hX9xpSNqd8UhIn4VPn2fC4yVoGKs6atn/dRSOFkUWO5qa
YHm8ePY4+f8vr/rlxvK6kPBgXvDf3274idDcT+dk4WxQys11ZH9vXbB+xeHe
gdhTK+K55YbxN1p8IlmKBlM1yZTae2Mw668ymZquwLTD5FkeOSZWiS8xO7q+
Bt8bnnYn9bCwNGNbP5d4I8bVtz2MmmAi5EW/VhU7EcPcK1wWnQmEKkg2paeR
fZmwrY9rgpwfE86FoOASeL9QM+Ql833S90wnTa8P+qEWGk0jA8g00isN2N2M
CN+hJW6kf8Q9w7tV+Xtg9eRXXuMnFkRt/Yk/XLkQes03tpTkr43vgpXS17bi
ktPF775BDJx3VZisd+6EXmCE0AptJqjtf312sUrxMujC+RrSLw3ySx2sHuXh
+eeiP0EBBK7+N3bYeQ8dojvPK3h+HIGc+MtHRna5mHpaHOjNJnBA5JjOTj1y
/iMrxL/osGGnqvq+qaYFooYBYcOcw7ix9vnHzWltmDySnMx3cgA7YxaNYot7
YNmYq6so3Ic+pm6cTEAnhlwTjjGqBxATlJUz0FuJua7vippsFiQ9vxqqnaUj
KizI8os+A+yC7Xum1BqQUiG5UUqBhYgK3j9irlUYtJB0Sq4j9d62b5Iy1AfN
1ZxvH/ONgEeW/92K6Dbc3pVk/Z2HiWZT0Y99IlRIbDezeu5P4LiluH+cThFK
gjYsvk0j5zlTnBAfpOP6RHEb/w4CywqVKQmkLzQk2HPLF5g46PTX7KNHN5JN
vu1PSWRhbdaH4TTHSjA9vL0PfyPQkL13iaRJNULToxSlSP0OaS6tPbO1HJEy
jXdrRsk+rpyh04s+wbLPOnvsMYGFuOKzDSVZYD98JrKQRfLfbtGgyA0F4HhT
trG7lpyfo3O1ZrS3oLjIJv4m89FgxYtll4rzUaf7PkNxJcnzC+9awh9VYHGr
jhqb5B/itGnhkrJKRDiElBYvI/Pyxx13DZF2uN6uC7XxpCHOz8z9on84Mg27
DfP/z2tDzbIKtDLsuGn+e3Ypgbhfy3+6XCTzipUjeMmCBaMvvMK0ukZEJEyY
300lcL9mPCDpfjnOl4WvLp1mws/Zxz7LJQsPfeM6r5B+5dWMYn7MpyLUveCB
3m6SL64JLeyklEEi48lvhTME+lM3WtJ7qPDqemCgrDsE0TZjD6kDrZg+pSXk
c2AYtpTpAxkPu/DHoZrP88IgKoelZuffUBC6re+F9TaSnzNMp7qZNLgyt67S
WTuOzGNGoTzib3D96rkNuVYE9kV7X+hHM4pvl8QQVSwsDr4b8iikQN7jbZMS
jeSx71Ya+d/asL7XYVe9MhMiUiv+a8xrg807P/NHvGzUWK+6OLe6GZzZoWGc
1QTO56U3Lsg2IFNQWoxQJPMrWu1x+eJ/SEkVTb9I6je60Z+xzqwS8W+qt97b
Q0CL46+o95kWjMvYEKrk/uBakljyVbkK6gZSUjNKQ7AuTFT5Y1WLV1lU3U3k
/PiULA9tDWmHic6WdupeNo5/CKSdH8iC0ymi9TjJj6tmVOqiD1NxZV3RH/ew
QajaW3XKHKFDcnCnFV/LIMw/C6ues+/AbO3H+xclCXRekQyP9EqA7775q8fI
PL+3OWjNrZIGGAxED/baMhCqKvtfNl8vdri2Ct93YGDfQmf+fscaFK5W6XRI
J5Ais6/NQagNoX7jX7WLWGDURulzOLRi9FY9j5oLyRdXiEsed9oRdeTRf5m0
IdwTtv7ySKwZpyKcXqZosbBhs9FTXst21CtVpir9ZsEE+78tynaBnlTl7szf
h5omw2DbDApoA6o56w1ZkDXsanmQTIV85vFgJZevaAv1d1xR1o6h9l6V+AcM
DAdfkMrfmYtoF++C9U/I8wUssFbsTMLnaVXnhqcECmMmuSMedSO3fmtJlCIL
6wI5z7Ru/gTW7BGhBnJeDsaXHNUVqcKr9G+8oVsJzDc7+9S+6QTtr1Mhs4OJ
ZW5P+dZW0vDS2i9kkeQjipPBzOnlSeAoTQ4c8iB54tZ4sphJCzqzZb6vIue7
3N1+ZNKlFWJhczpsDjbWVKVQN5xtgUOw+CJNhQm9hR93dlBqkZDH/1qQYMGj
2zt+m2IZvI9T7JNOkn2yo/f8nynyPdhVHw6Sed0RLR2l/awMuluZJlUkLzfw
PzLjUm3HOO255ZsK0s978Nk+pR2W22TlCJJvW4Ql49YlR2HJi+F2VbIPBabu
/5uw7oAFt6NE3BQDI+9D2oaIdmhcfRqVQvKRcfYGzj6RL0h1ta9L8WGh4GxT
lnRPBfSuHVLx6Gfi+svigwOfOnBcN7maHc3A1PVXZotaOagRkLKUIu9/k4NX
aGZHKYxUxXr3rWehQZQukLWfBnp1sYzDfjYkNamN3VNxCKjSeuZ2nkD0xvJV
Mmu/wClWk158nYmpKopIn2geot+I8XceJsh+u31mLW8mKNeFAvVIHpDlbXIK
DaWilzote5vkV6GCyEUJrk+gZqmEtWwh583nQsJidQpO7i6cu0P6Wa+g5kjJ
TDnkeQo5UjaSPF0mlqdC9ELSdUD70F02fr/4z8j5aSOylc9576cSOC3bJuXI
R8dQ6fWpGXJfN7wh7bK+rAii0zVbvch9W3mB7fT8A8nv61c6anZ/hcKd3Ndq
Ts04tCeh1zp5EHOO/vyHPneAcb1F1fcKeX5fjRJBbjq4bvioJWZRsWq84xOP
fxeib76gvV89jNzXLn0LizWQZc5fOPF2EJkj259PhOej4d2z5zKkf8/YbLK5
u6IKEg9c4ou/MjCQqmszv7wD3g/CCiTih6GeZbVGUakFTI0RMXkBBr5MHYhU
02+Et9KNHeyr5H58Ids080M+fnlcqX1fREAjQVrMK6wdotZ0Tx+7YYwnbVo2
c68Dgm6BZSorv6Lko6fSWTbZ/0c+2kZYMnFmPd3YspWGFPF19HYhJpnLeoUn
zarQ/2n/+7f1ZB8KPtJ4L9ONZbcfSNGNmeiz1HE/GFwNudZ7MQe7yH4YE9ep
HC3EjiNcHTFkHp7a9UFZJKEFtwuJG38DSH65omx5LzsT4doTor2eBPqaYm33
7mnDknFzm2MnBvHjbrKo2fJ6yAeFU2qbyfnwW5i/Xf0Gdv3i6y1IfZXDVJZZ
mXZgnwSlZ2iEha9lppfMY3vRIVkU6/SAjpSJlCuC/8pxNGHuRzjvEBb87v2I
zGkHR7ChY+EYAfpxZa1zKeU4aW6rpEfuU5TJnbqCNC9ITF7gC7tGYM2vbmIi
ug7xu4RvRHUTSCIKkv7O0ZHZ9UxOTIkAzaGnLJ36EWGe41cHSX9wWJlxrz/y
CnYJJ+8WkPvfzcpSFdOFVMTxcTWsJvUy67d/0xVMw8XW38HnuFkwXy7c59tf
j/yh1iC3XQTMH98aattbAA8Nm9rZJibSJpJTLU434rCcx74fHKTeFVs9FJbQ
kXp5/NhQQh8s3iqvFn5QhsYNNj32vxnod2NJyF9oQsxEaaCDERPq61YfSf9D
x+PXA/blz8l9t/yL/lRZHiwW4jU1VFl4GcIlkCDZDvlFSvpc6CBOad4Yue/f
iKr9jyea9xH4ucbS85xZOUJ7fXpuXGFiQWhJiOJYJbR91z9Tu8fA6vlbJlZ2
3Qj44SAyfIaJt1r6m40jG/C6RcZwMIkFimBbwr8ML/yecuNPvUrmk62qevtC
LUwHfvA2Fw5BceCupeUEHXn0A5q9vgSMnvXeqRqmYDzK/+nlCiZqZBkZRqda
YdyYt2vVTwLeq4OeaB+nQy/i38ZE2xEsZhL9KpF9iGjw5OJ7OgY7BbMTZ9Rz
8JIy6WhJzo9COse2hsZy5PhPS2Y2k+/RJW4wUNYH33kh/s38LCj0Z8j6atRh
Pk+a0UnmPc/yZX4/r/QgJPVHlvzLQdSs4TzkmtGF07lH9Nrm2NCwtv39jV2K
UR6H+WATJqxHRSwUF9ogP52z4R+Zr3Y9BYIvxjuhkXT7u+vYAHoFZx7G6tPh
v2bruB/J109OaCwPFqDBaKfCcNgzFvy4dSydPn+BehdNuLuaCbeOnMfn8mgQ
Ey7L2nlqBH6Dju4+x5LhGXmDJ+YOyWu/XjXcXvMFbaOO8vzmLNwc8G0U5SwG
m7KB1XyRif8BiYstSw==
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81WkbxvESReq1DSZLIzslNYrisjYc1ShekaUFLfZRQg01oSPLy4hI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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs8lOkbxq3atkWRcqgIlbJiE0ohl1Aop6yMlbCZjGSL1DisUwihk2Ip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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs8VWkXx49LUpShkhCRS42omUKTaX4kopJbGjWF3C+RkC5SJpIX9bpV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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lf//xjWkgTSMkKyMRJKQ5FIfqfCRlVFkR1pCouzVEiofIyoVMkNC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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41tkbxpkwL2mSskS/7BpZQ8LQrU1aZBlJQ40hKiPKluwiS6hkSWgs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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81HkcxnXIUShCaGVarF27ZZObnnItSjlzZKWW1ESppG1tmrGJ6HCH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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs0VWkflkvJpUS5lCL320yohol6YkrC5JKEQUUNoSIpIWSEjISpRIbI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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4Vf8fF5IkpLIqSUIqScs39EJLVlJmGdkV3yizqVJJdhp8hYwiihCy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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk0lGscxyd7C7c9IeFKq5tKZKlvomghpJJkKZRtULduJpVKclGi7m0x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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lekbxiWZIUlCWeYMJR1pmmpU0/nRRZYsLUIpimRNRpIUn5JMiyjZ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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lekbPiFpUSeMJFRSZEyiTcitRqXzU1nSKIokKdlahU6WSEQaSzqW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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8Ve8fFymbBiEKLVoou/K2UlRaEg0pDckKUX0VIUrDKBISUhnZsilc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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVns41FkfV2JFRViNVFI2olDkVcpHusiljTKjGkXWWrmOipA3uiwl90i9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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81Wkbxk/RaI4lSqUy2dIylJGlTS5zUEpyLKOxn9BrwojKklSWSTVM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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8ldkfx29jKWmxVZIWM0zSNBTVHdunGZSRJIz1Rzdc2UImRjItJqZk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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k0VV8bRqRMFYlUkgalkqQo8iiin0REZC4UZQxNhAaSUIQkpZAQUpnK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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVns8lNkflqSSJMktxarc2oqoddl6VC4lKdqkoYhFSZHLLpaIUrG22ViK
RmJCksSuXEYNxjU0ZgxDrvO+gyTdJET93t8f53M+zz/nPN/v93mec37w8Hf0
kpSQkEih1v/3Ha03bWTaarDVWknhj3MEVPn1+ruWNUD//VQYx4TEqfI0pUUy
QiS9iX80UzmICCOW1I2Nr6DCfsyNHB+Ge//2PbdquHBenh1fdZyEBN/LRl0Q
B9tuj5zrbhTmGnq9fsLA7qLY49s8SeSnWa/OYdRgQEUjQjhKoCs4Zq+lbh/K
DZrvLh8QIdy4zs/JVYCO43d4zi0k0twc58QbOhD082ebrF9FaApVTDKx6gZr
+bPcGLUhqKQUaUgZ8LHUaIhGSxBBNpnneGXjC/jdTjPXnSAgOys7ouJdj5RV
BCP5JxKD8hLXwm7chtH4aPVKDxI5v15O9S4UoG/+66emWyKMsnrz23Ryofxx
fFlzAIlrqel0p1utUFAK/ryRIUZK1XZZ7aYaePu5Tpk8IXD+9q5jfZ8bYBsb
bGucRUCiVPuXnUMCyE2/GL90j8R7x0HZdVaNsPsYff0tneqHm1169uvfkcLs
r/Ci+mPy4Yhe8f0amKrv7KOnklCsTGHCqxbOWU2TnpkkNihFFjlJ1WOOEcNL
DyVhuZ+bEyTRgqqFE+rGz0U4zJxd793Fxbyn1mZBGYEtJ/YS3Q/74PbLCTX3
wn5MLP7Wtb2EA+J87ZXVPIqf9AhttDAAJqWrrm88SSJ69d9nqgLbIFikl+G7
nsTobpaaekAZCh2cxLscSHQSJVNJA+3wCFm/u+U1gc62ZaHPCR72hfEr8j1F
+F5exDs78QyjCeYLjeRJMCtyVI+6sZHX9pddvhOFETfjeZyHrdulxR7/EJCK
meoxu89FBrcmqMSdBPuonUxQXTRCDOYa4imcHEUsSpvgYsg1hF97gYSzqiG3
ubMbZ86Xze9zFoP9T3jUcuEjVM3otg0dI+F34UZn+1UhNvDWmy20EMNi3MGP
UX0f9jY7nEZPkJAPSbz6+WALQncv2JS+UoyxTwsGNX6uQ4u+TbJ9BImW1PuS
WzdwcSTc3aTnrhjN6rmZeXqvIJFxS52zaRCFaZlfc4OF+N2r6nJKPIE5lRGS
k9gATYaldfMpElKGw5O+gfWQbsxqNT1H1Tuifr1UrxIsWmL9A6p+kwuj5t39
bLQE7qhNMCJhURaos6ekEUKFpRI6ZiRMd3rFqXY9QjdzPsLbnsQaQnOc8V2I
m4MRG+WMhvDxrwPXHrZ0g/fYZvZM5iDktcKOwbkHW03vxa6h9PfhoPweBdVG
pCza5zdH8XMPLVpkM80A7cKSyVgfEpk1qjr3XubCzprcE08jMV4w8rLcio++
V+6JDH8xJDLHZCa1DkJSI+KbKaXHGM23JlZGAnRXXhqoXiHCt0NRwYQMF3/S
teofFxEI/2L0ROtzO/4d/sGH3ipCovJL1vUUARInFtjdpvgK9R/Y2/lyocIc
8ZDoI3FY6BvJW1yHgLC1pqJwEuqyO+5xRviQPZrnmFcrxj6Lm4uDfKpgz2hV
eFpIIuK2HF0U1g6FjPjZbF8CQl9WYptpMX57aBClfYDyj5Uez7+IA89Zab+v
FhReb+SWGROHyyw9pgPFX8kw/ob5Pj4ag3osx8xEiHtUP3lASoCx2o5UxowY
0VqKgvWuRZiMocsRiiSylLvy5EbrcUtaTXU1dZ7GgC3z3D0OLjesmnZzpPRh
GNTft5OLFr1P/G0yYixILVqoARYeBeYOe68icVLpTobtCBfFFcblh/UofdKM
AqJuV+H9fOAYU43E8gs391Qu6YHsSsNBJT8CCoXvHjTv5aP6jqmBXR4B19oD
x69eEaIn7lv/0lNivK+c078uiEGHlPUmCyqf9uUdE2z148OD9XiLNeVHE1dt
Yd0kB47np7VFnyg/52sY/mTbCumZc3WHQ8TILG462mmXDFJ/9s5Kyt/y+tnW
1/ZkwiXhxTOPQCr/Zs+0DTikQ/KEpM1mKq+XPGx5c6DmFUz7TAWnywahbHj+
g4WPAAUz9BFekwhtij3augf5CL+00WOeKUKv37nT4q7nML6ZmzVoToJX6s12
a+NBUZC+izVNYHvv1Vr/ai4iY3g6pyWo+b09n2C4rBk9M7qMcj8xBq1kfd99
zcCGI7XKhyh/sl8/8XSRvgvF3rgI9zMkht0amxZr9mL2bPN++xASq16VcA7F
9qDwK7nzta8IoYz5ce3LXBhg91O9KAJyHvofG1z5OBXvyso+J4Jmc69ioU8y
WLfYEzpUnvwsznB5wRZCZuywjdIYCfcJQ/of1Umoj84ucHImoedbkPSyth6z
P/a+Hdeh/HJ1ItmnuAYKSf5jMg0kyj7sT9h0moVt4QcV14WRoKFroG4TH+te
0llJNDHUzoZqv3zchbZJvtn3Z2JoTtVc/m9pEgiVNbEC6v69l9Jft5OdCFty
d3ySGEKv9RKX1SfaMcFZRr+yQYydrv+MVdS3I3xF3d0/thDQ9LJU7bnYj3XZ
jU3R3iKwjxjl+XnUQCvi7aWIJBI/yV9TtaluhXfpGmYEmwD94nhxzIqn0LZQ
nhlwIaFG/CdVHtWN2fy+vfLdBJhrfWw2WfOQNbW2xDuJQPyykorgliaE2H8U
JNYQeODyJuR5SgeYtAMG039TepNbkBHArUL8A902u/2UPlbaphE+Zei/XzLJ
fkq9FwNL8vwNq/Cw19dhlNLjRdXo9qanTWiZuuPOfkcg9LeciChLPr4bCR6G
J4uwq3d14puxbiiu1P3qV0TVX/FGvi+4A3P2bLMhFgFOsvkWx1QmaIs/qDpY
kSiutFnrv7kf96YLOIP2gxDqvbN2da2EiKb2pViW4rPrTP4VyQqc5BmPeLJI
GBNB3280dEImWSnSmCdCwP601oTH+fhX6OjFjCXhG7VGsjWuHyrDX3KiaMOo
+sR+MbGmG6kSF5Vly0Ugf/w4PcLlYQHjJqe6bAgue81O8hN4cPSNXHVhuwh2
BbryUckdKFUysawcFcHS/L/NCw+VouCSnHMz9Z8xp1d2PvgixN0/W947ywxh
bHeyf+ZIF3ojT/m22w7hfxVAxz4=
       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4lekfxjUx/DARQxhLtkjWCEnnVmmIklBGm+xJlqmxpUnFIOcoarJU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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lukXRlLZUlJKsmXJFBHSTNyWiBqmpJgiIrJ8xRhJElqUraQkmsbY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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VO//xq0lVKKQdj6pJCQk4ZakBYWQFqKESEq2SpKIooVoQZJ8syaR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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lekbxn0aaz9aZlS2QqKobJHS5JIoE6GStXLsZLILUWMblSVH9goj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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81GsbxsdWHUkhJyoiTqc6r4NsleWiaErJ0ikpTbbirY4kW1RHXooQ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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4ltkb/sKkmBpNWQY1mGqIMfo1ophuI2FMssSICjVZpkKEClnCIEq2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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VN8fVtmpaBFfkgohiZKQvJSKlD2pZEuFyhaypFRSiIhSKtlDiyhL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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81ekbvbZGIpGG7JKZIjslUx1JaWyRlFAIV6HMGL8RSipUN01mLFOJ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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns4lVkbxjdJKEYqFbumCVEoSRHlzqGDJlFEKJXDMCVntSPHUWKcohw3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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lWkYxm011FFMKdek6BqJyohR0cRdkRAaW5SlrEnUJSdCGZFk1CGi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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k0lG8bRiq0U0IyQpYWaSHZLkpRSRtJhLJWiuxLfimKUsjShmiTtEll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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx1GMZJv0a+o30mKJpjBJMeGDq7GNkahUZAsNFSOkooSkVEjJ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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk81dkfxi+qMZiuyjKNtWtncJWaRD2KFjRNUdYShaSshZSGkqVF1lEa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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk4l1kbx0mL0spMISFpRslQtqamvr1SUm9NE0oSoSwhFRJR1myFV4oQ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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3lUTP8bx6cURSWESrtKtoQKRW9fpbJEQiIiKgkVrUIppCit2qWVSki7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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs4lHkfxiVtbXYdCgk5bsWojUptOtxDpOMrsm+SxDCRHHIoppPD2nSg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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk81Wkbxq2VHAajUpG2QaWslVd0SaV4hZlBx0yWotDIWMqWKLTYKoRw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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8VekfvkwmaaSFfhGRMBVCSfUz03Onacotk6UFyb5VKJRlRJk7UqZs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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3kgVPsbxlXKUolQUtaIulGpROiR1K1IlGS7luIqKSFRIpUlUslSrqUk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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx6Ui/ZiRuU2y9IsUJqSaipIPcyMqS0VlyRIaZKsQhZT1RpYS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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns4lOkbx0eknxKrZVOkpoMGhRSbki/KZLVKyJlIpGWZNkqFRESpVESI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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs8VGkYVtlINbl0p6VSCimSW/JMQ1LJlhWK1UQi1aQV2Q3N1LRdlrJl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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k8lGsfJtVRVJJsqeioJJVkS+pSSYiUCnWENjqhJIQWJHEQEiVRyJYi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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlns4VOsfxadEJacQIirddCJ3RaGlklN0SqiQ4gjlUBLhoCJJRYxLfkju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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns41GkbVlsU1W6bRW19kcMqtpZSkrqVdiSnRbUSVlIrh8TnHJFQyaFo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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs8lVkUlYmK0CAVmpAKIzMiw5SW52SkGHM9kpCSZ26KEgmhpJC6Sk93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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3lYDe8bxonSJi0qSyiUhEpoE3clSSlJiSRRkaSFRPuCZEuSQn1Ji9Im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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlns4lOkbx4cQItr6SaJyKJLNioqir7WtQwfH6KhEOsiZxUSS4pqVM2lE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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk41dkfRjcVKluijKVFJq2URslLm1Jkm6RQyDIl1dXYB2NU0gyRiV+W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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVms4lVkbppG4apoUSiSlKUkGSWnoptTgKx0IY4hkoxw2KpWMTyIyziEh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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VPsbx2VLUihlSXaRCFkqLZ8SoshS1oSEJJeSSgu3LJUSKqKobKmk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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs4lOkbxx1ap02bUi2SqSZJJ5cstuIrOa3QOFTIryQ2pNZSRlGNoqO1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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs41GkbdvhEK6m2dWiJTg4RQ6lVttsxFaNZVGwqlLTZZQqpsGnWKaUs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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekbPkgkqqMsadIoql+YqcbWolu2IhWSUmMrsmslihwpRVlDhelK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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk8VO8fxSmKylKJQpaSKEUokpwWCqWUSJG9skSIUBGKKFkqIipKSEJI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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81dkbln3XNC2mUSQhlNapRI8ihEoxjS1ZyoQGFUYhLUYSEqUrS7ay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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41OsbxqeTLb8iSYt0rqFOyRayJdzT5pyUpcjSIiFZIg3ScRqkhJIk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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlndUVNcaxccgCEgMQQhFfdhQsADR5GkQ2BgER4lG8ixEiNKUFpQWukqI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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VO0bHkpRQpItS19JtoREhFuoT5LwaZOyJEVZU6lUiiQlS0pJUrIk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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk4lekfxlFTZJ1CRnRkSVJCDSV1V5YylpAGcWKMGpW1EOnXESrbtJCt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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk41WkbxxVFaLKcohqkGVLqoIak5UuT8lIke+RV9l2qkZKRpcU+jYli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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkbR4tK6TCJVF+ojEykmknWn0qYpu0zKhlT2Y1RouwxiXRIlmpI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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k8VG0bRkVJokIkIhUK4U2UusiSNiSUCElSypYXb2mTlEgIyZ41u7Il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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81dkblmYSKeugIUuJhiSyFNVTNBGKIYwQWRvJWCo1hESWaRGylSzJ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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4VesfxZHKUIZug0qFcilDFLqilqgbkmOIyJg5kX5Rt3BNGUquqVE3
KYoUknBkSqdjijgHx5jh7L2jhArdRNzfvn+8z37e59l/fNd6P+u75N0CrDyF
BAQEbtDnv6/+e/PGkMXtKLJbwcq7y0eh2awFU7QHrrHPAkSdBiAwzfJ8uyEd
f60v/zDsTCHvS/LCq/VP4aOd/GaDI4V7+sNB4zEsNFu+l2T0k7j4U5q6ns7D
zeFQL9NfSBh/2E8qWd+HRPYp2ZIjFMo4VEFt1XWw1uspux+nEP229EDYYiY2
tCkVrrCj8CDelzsx2gxGAm9w1p+EWEyFg/r9PphbjXFtGAQsBMd1G5a8xsR4
4LNl8yQ2FnDLYj+2Y1tNZW8Oh4Bj4PO9s/ZNsDXeV26XRCKT9wg5jztw//Kh
Cp1WPio/btp1d4yFNZtjdtcMk4gouhCdlh6N04HVVgwnCmn1k5PE9XasEu3J
M1pNoaG+zeiJUxMKpfMM75MECv3j9k1feoLUg9YFo8coWJxvNLh0/SEcvQJX
O9B+CHj4qp/33YOaTaIBW10oXM9KvSAj2oyp5xnzOvT/GrdFspd5V0F91l6o
4TWJmWBmeuJQFYRv7a7hlpFIfCCqfCqiHgYh+1wfeVKQMuzND1NvAUtWsvvQ
FB8rvyyc+DjSg7rgFWEmwgOQJNOLp4u5EOtIjniRRmEmVDRULYyHrTOSAbrP
CER3LtVoa+GgqM6A6biMhHKMhJnvNS4Sl+zPiqBIeAnV6Nlr8iDC9NW5suU9
xty1GzIv1GB2VpiUHyMhp7A91PnOTeww8rWMpfV9kDj1Sr+iA7sn5t5HEnys
s3nmw41vg/x2D9a7kyRkvAuMrHWLscZdRXP7IQqP+gvOfF3UCpeJA1qhLwkk
f/nTMP/aEzzusnXwZVAYEjTOeu6fg005yW1uhyl4OptatBv04p+pJN6B+xTs
BHb+e3v7SyRkCkV95tPz9MdEfu67A99dxYFe9Hv9JhEd7D9ahD+6pDJPxlDY
ba8gveJJJyi3nxFXPvKhHyi/MqOzCl3nw1+dSKX9l1sV4jRUhhfnSjPfqtP3
T+rvrXmvITfGpEQ/kdCwGPLruVMGStom/KURBeXyXRYnLHh47iX+61VbPuLm
B64GaHQguqbA6OMkiQazPIGa44WIb0rnr1eleeB86QlyYcMvqDYgQoPC9Eaq
dNiUjSkV9V8CWBSOhLB4yGnCeZ/W2vA6EqZaS9iFc13IOLzgx4smIKthvXlh
fTvikj78sBEjsag66kHEjSwUzslGnvWhoJqe2Bh0vwFH7b0TCo3pPH42VYtV
eoMD05LNrQcpPNbosz3uUYMzY017gndQmNwasmuwvRjBf8fIJNM8bjO0ENBx
6UW/8zXNqEw+5JQG/JQ86zD7zs7mI5Pmcb/OxhinKqgNrxKytKJQ3D/blSDd
hMvL3MS+WZKoyagWHzl4E0M/9li50/sghRlz7URKNxj1169xzGg/pEyXWq94
CcWJn83G9hSCWspttb7xcL6iKyN2CwH9wUC1l3dLsexzvfYWVwoDnLVzfR3t
WIhSPKceQUCAde5QeOsR3BLdN2lEz7t/XGVxQBkXa5lsbvleEpxYDdeOTR2Y
TaisKnIawmedGIFWXw4WSVra76ggkerPEPNU5EHM7ZDgFSsSvx01XaeY2IH0
kvFHNi0E5JgtO4QcSpBZ6R6mvJ9C6tmRKJOLnVgeDQP5URLHV3DTVII60DYQ
Y3mphMTd4O7TrgZ9KMg3ciUzhqCa/fImuaQUr8pU5t+Y0PzkypuwC3rxb5Dq
fJLIAAx5J7MHGN24fHpZfOzCIP4dXdxzmM3FTz+V3Cg92r/B3qWE4G0YrrNg
y9N5GtoNt7ftf6OYqv8u7kHhzQPftIypbgzq6vnP7qZ531QrxhZMRnbk3k98
BwrxkePlj3LZqFOSVfQJoaBT5O9CvG5EbepMffefFNgXhHfdZdVDS0JxveNj
EisV1IZ0BWshouM2wjSgoO0z0XSH5MCgR33q4igB9bKIpzNunagzVA2zYRIY
M57c1ujcCvOZlKYxgkSCtK1liW0rWmRlftgbk7C4Yr1Lq6QCBQG3qnrNKSTO
OBvs3dOK/GR9qn6EwL2BPUm3a6rht8vyWNQsiXtEiqOGRjH8yB0lC0r0/FLT
yz1SOzFb3/WPaCuBtrja3KVf+7ClMszx/ToKyef/t7TPKxN3uN22pbYUjp4e
LTVR6IVmxIHyKE0+qk+5iJ0R5CCH1RQu0kvCZ8bkh1DeK3hrso45/CDh+jVI
arlcHJLG5mSyaL6EFWRGdDdz4XTGTdnmDgnzdUN/BovU4uaagp8j0nQeGSXp
Y6NcnLm6tsLsFIHwP1T1NOo5YKWEiocqUJh4sfEamdCNS/US8qPPCbD2Wyee
pftSSMjjj9BWmnfj6vli2RKIvxuZ+YveZ18080+H5HeicuTp5y/5BH63vyB+
cms7ctluHcF9BLpbeFsjp3n4vmDxu4cUnbcHxAVn1ReQz2Js1KT7QVS5nyXs
WgQB7yPhp+l8TzbbPuxl8ABv4vt2Wt9vU/wUUZMO6NqE6abHE1Ad+mYX7PoK
gYxUjx1qFOQkLwp6LS5H0o2u7P/67Mi+YfHGuTYYPkvtyv5CYFq/crB0Zx/S
j2czs57zcU7+chSjn4PyPZE3ts4SaL6i8OFRIhdrwoTeZqUQCFCR/l/Cw0EI
v5741lczBOX6pZxbVg2In43asjqUgtUvP8MWkVyo7tOX9QwiMOd+jPP0Xj8O
ivSbrbMiMGg6NFAtxEaWw7Y+n7MUVss5LKzZWwcdrb0nx2VIdA+0CWc/5YEt
4emqnceHzE4qRGZjJx6UrtpgRveXSLX7B+82JsZdSoqmaT230g643dJ/DUeR
SwxPbVqv4uuVKYczQIRHEOp0PkL/cZKHbg2s4tKjf91Jwfx7zI/v8hzk5tVO
fXrGx8yqtQ+v/spE7NXb2gZ0/lg5Dc1rl79DUdLwFf2H7/C19K9a8987kaZl
2uF6l8CxfLVRNpeNuNW2HXo0j+eOpugNdrdBKk/FMFeYBH/+dteS0EZcslXN
20zvHzsXXsmWp0wop1GvBOQp/B/wBsFZ
       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4lOkblihFEWUlHchKoYNhd7bonrXOpOSwQ0ItOcXKSkiaCh1+tm0U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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VW0bxVWGE0KDUoYiKopKhSjLEKmQlzJFIUVKiCTKUBGSVFIpkpAx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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk4lekbxy0troYokixFUSRJY2uoLynZCuGQLINqNIQoQ5ZSkiRDEUIK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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk8lOsbxodyUkmUZAnlqESl7WQpLmmjJISibJWlCIcSFTlISLKTpiSS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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekbpu1wWi3jZ2LKVsnYp91ym0o/lYzdpCyVbRCnsiQGZUkn2ZLM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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8Vf8fxyVFg9BUKkUXTd8WSb1klKwWGnYohLYohIpCkaRshYaQVRmV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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk4lWkbt0xl7OVrU1ORDELZmkr5SSRCJ1NZSrTw2ZfIaKoJafkKWUoL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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk81NsbxyckkuWmRdeSrcUlW0Td6iOKst24ZSwtSHFHshQmUnNLJUsk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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk81dkfxmUZkiUackW2MWqmDJF9ejJlEm3CFFpEaCxDoZpIypItS4kW
qZhWMoioIVwuLnGvncuV5XxLll8LrUN+Z/44r+8fn9f5nnM+n/fzPFoegTu9
REVERDLo+u+bJSWhI7WhC2PSv6i+aCCYuRNQzT/Ax3hL7jarUoJy2fBT08Fs
NIaznIuOE8yZTyyszu9E8bFchXPiDL5JSZSNm2DjTPHrwx3HCDTlk90OtpXC
rJp9+8khgtkTi74Jd+vGJcVMVTExBmoTvNtOLn0olMh1K5VnAFNrI2ZvD2ye
Xzl92oeBitX8/0x4f8FKVGHg5wMEA2JfItKm+9CUkGlxyJ6BRVeFn0nfAP46
MVMZKmRgZVr7SBjfjNp38i0XLhHEjS57ZXisEWWhf0YaniVodKvqEattgva7
G2IXzxPsFoxomVm3wcGgoNJ3hGBF4s9v/2zOQtKJNxri7gQxC1TFpQ/zoRmm
Kp3NIbjbcchzaC8bZV6jfMdIgnp1TmT1+TaMnVA+PN5LID5XE3PLvQei2rfs
FA0YTIrNsmw1+NCJFqlh3yDYkeIppSzCwdhHqZ2PIwiG3gqas1SvQ07Z1cSD
nnfJWsk73paHI3NC9eF0Ar7kunMVCTfwbNx43oTWvW1CZB8s6EbIsOj8UlMG
Q54hrEuihRB+0OHwPAk4GbpkVQkfygfs0yyrCfx/ddj49DUHo3IRW7qSCER1
+T381F7ourm9CpRhIKPvn/IqoAoLtFZW/nuEwNDzmFr5vhbsXLy6Uv8eQeTK
8h+PXn2Ckpu6T10DCVYpZacbMN2w9cwWSFgxcMrq9Pz9aBe+mN4Rr6Lzc5hm
SRZpF4NlVmFs5EUA2WU7vg61wGOrblxMJoGIRva2pM5+rE2c5nxuYyCSOuv0
XOY8cqwddM/uJ9ifarnsuoQAyTMvHMqiGWxx6DB6MFWGFaF6+8p9CCpOhkvp
fO5Frd9ILteMwUvjSzmD+5qQZJfYqZ1D8Grgvv76qX7wK/wTlIMYKEaNStXZ
d2D3WkmruioCu4vZdbUvexF5PVtu8y4Ge164Y1y1Dt4O48kBlI9ne9f17Yrt
w5MHTZocGzq/8J94E7b9sBRXvzoezIAvzLf2Ln+GuKXzg7w7BIvfpQT1JubA
1TUn/B86n/TclDBBbgtcJUof9pRQvmJZRdyQeowktknYUt7GzKvD4gbq4esS
yveh/AyWF43Ju/WAzfn60pHOk338/k17my5oC4u7JacIzH3HAw84ChAR9JOJ
tBODoDnh/D9KZbDdGqew05tAbbK9PS2Wj05zHw8fHoFxsePdHCMe5Nye/hbz
hOCgTHjHmQIumlrvhsUkU747amsNllQjI2op3zuY4Pjg9uDPUV3ovxySdWEl
g6PWZ9+P9TTAdCppmBtP0N6uEcBltaHaQ4LnLCTQvxnbXBjWjo1rU+KzBgk+
fbe1ROREK/Q31nj/Svtx+dDHHycHm7Ek+JTTpvsEKi693Zo76qDZKGMkG0Yg
N+d8WVxQA6FfvvQhylO12Ic/avX5EPmfjJBdTJA6GCaMv8jHcNZLMUEurXfF
zE5O3IHri/e89R6U/5QkiUzrTthMP5WbnyQokVCPPtLYC6P6Aq7CLwxK7E4J
so4IMPOTIVMbwKDtvblbgEY+KlTMXznS/SIFeQE19wqR4/Rhj9lBynOBko+e
Ug22lg2lBlG/qnmsc0FlXzv6Oq6tl2cIOjV9vzUx6MTr1b1FFgsZ9CQrcnfP
1+MP+W2dZmcInO5ODMrWN8Le0qrQ9CKBQc/2BbsUunHnmnCJwnIGnyY2zmz6
OxN1Hn1xlZRv/5ui+WOLynFIW8r4GuVZW+XklzdsNrZ8OiZeGELw9T53X6N2
Hfylw/kxJwlOXVNza63oQKpDmWLvO9rvvGGf9NF2DK/YKf/2G3ofqfhXb9Sa
0CoXcbb4KkFKqGXF5zoeolZP/7L0McF3P9s5Bv7ehgw58WsbugleaJcE8V7y
YaHZcPPBAOWXda8gWLoSccuVI/wCqF/O7CtRCSxHlJ7/Q/gSLC+7bzEV0IPm
T+GpGQepHgP9Xh7PfYZp9ZkdYpTnmctDTuNtDXix4s9PZecIep9fMejd0wfR
w37e8dSfV4d6BjWt7YfJR8dHrpRvxdglfabLu8CKv2fE41OefD6bfO/Xj5RH
9LUMg3cPC46m6fKxnXukqLmV+uPH0R9Knaowsn+NmFoQ5ft+8RPrhRw87Grc
UEn7M9k4O1wqaMUnP/0wp1s0XxY7QN+Zh8QcLWEi9dtqaoh7j1+Hy0jDuC3V
Z+FH9TK2bDPKIzWRRv21OjJhZo1+G3IMfbUTaqg+bkRZWGZ24J5XqnLhAgbr
y0+lqd7ORtDZ84NKdP/IkNYBvZWNGLAMt+RRPf21KGiRwhEOElzdH/Ho+6Xl
nUfU7bvgbL9wgNB8C6r8+8cZ6h9JtbtnfjNmkJGsYUwucDC53PzcdXp+7Hb/
ZjOXVqREP9D+4SbB98qpy05Gt8PmzUG9s1yCPUVr9si10P8FRWxzWkXzNb5S
yrmnG0MPHdes7SCQecR6unbVE+g0DM3K0vmt0IzS3Dz9CEW2p9I5NG9XeBkl
OBa2of6MS37KZ8qTVicrz/YZTnuJz/XmERjtVjGWrO1FYKPH6XR1miftDp2Z
h6vxLLzVyj2UQC9VzY3kCWg+azJVeQwiL0mWnt7UgoEp3buvqb+N1xw23Lim
Cxk2Ed/FbGfgP7t58ffJbHCuaLTOUz3FRtvs4sq0Q8d69N1WNtWf8tchL8l8
rFSMLWdonrt3b3r7h107JKLJKq3X1C8tVUJuBAihuHg0TD2JwSinKPlfWg9V
UKoJpPXIqgNuDnneuJJkfX4N1dNFzwq9+opubJirsk3eyoBjtU6K18kDt+Hg
orwigvXBz2vW73yIuqAluzd4/+dXN+wDewqxv1KZtYnq/4eAws0cQTOyf7Vp
9qX9cDIv0eK+4SBZNuPfvCiqj5rYjY/TuuCyMmZL4nuCjnUqdqHdlbil8eH5
LOUxvTtXDOJcfHt1acv7CwSqFh/r3Yc70H974l7iW4J+wy+mWiw+pCKm2jMp
z/8HejC+Xg==
       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k8VG8bHipKiSwlCi1EVErZuSRRKipkL0SiQpukKCqRJSQtIrKE7FuS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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81dkbx5FKg6KSiupKmoTIlGzNx75HaDFCGFtSrmpiREOWhGyJipaZ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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns8lOkXd0tsYkItklTKpZJCIT9f0sq2RLpR7iFaSW1FSipLZbcaspQi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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4ldkfv5ORIjFSSg0SKsrWNtOUT9Y2JLRRZGtBl0nTRpaUFu5kiSQk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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3kglGsbxlGEEm3anCzhVKg46qhwRUiSkJAjFbKUZI+yNyGHoqJIomzJ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs41VkXRtG4VCRyv026CFPIPS+KUELFEDpyS4ZS6TSMXFJIiulCUW7R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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lekbxpUsUTQnpEKWlF/JFv0IXSqFEJmMUpSSKSm02mYsI1mLLFFG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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lWkbJooRpglF2lGyE4qarjI+Ko0RvkiSCaEs0YKiDoMaGk2hQXYl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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Ve37xVGGaJBCIkmmUCllKFlIQuVFQqa8ml+RoQyNkkohMs8ZC1Ey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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkfxi9aiVQIMWHys4zRJGSrx5KlRVkShVBjmUFRlLVuxc0W6idC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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lWkbxw+KFiWTJZospdKmkyIN44dEjMaSsUQcsiQpqThTKnQyhMLE
YAxRRiOVhBaVJcd2xDkOsjvneZ6DvEYr3rL0Pu8f9+f+4/7c131d9/X7/i5t
35NO/tIMBiOdXv/fxWsERn8efI2v+6MunPxKoXpmlaHL8hz0/eVpEuZOIe6i
1Zag7dXoklcf8rlOoUxm8fXQ4jas7Tn5UMmWxFF9/0VKlg2IKk1ICbEm0Z6R
M8peLQT7sPKWtEgJOg2CD3zicBHzksrseUvCQ9NnwH+eD0udpGYFZRLJaxbl
FKcJYXQtaJ89fc66MHzsN/5T1P3OWldpQGFri4xXp285mnf0iHI3UdhftNbJ
c6sQvPu8M6xLBOpiwogcOt4OOd6BRWNiKDnsbktd0YHtCdv3pS0Uw4zXy9Wr
qsT47RPR3EMUwk/flauIECA5veugfCSBYo0/Vb1te2GY/TKi9PYQMuzF1p22
D1E1lOsxbUNhheP8FXVuOSoyg7WOqFDQSsx0nr5Tg0q/jOpvahQyCvYGBk4U
YGR61x8qfhTUozIbVZL7MJus+ZuaDoUYjuniEVc+9O37rJvs6PvzsK53z0as
ZFVGhgeFRg0fbU+rfiheu7IpZI8Yx0odt3tPd0NWNVHHzZFAHGWr2/K0EXE5
oesWiAgw5C581Axox99LWCUUV4xx7dPuh4bq0Ni5nrQ7TUJcYGHiUdyNtala
RatTJdA1Zn4MG7sH4kPG9JuzFCb9GJKwbXwctXOZXbqYwmbrRinvG4Mw3HAw
UJYzAGmD4FLXXi52+8rtkiRRuBkYs/HqshRkr1HScPOmcLj30cU3VgJMdp36
8KqSRM2KLLbxBvq9kse55sUE+J1FvuVkP0xHOPYXxBSsoqVmHu/sQm+j6UVY
i+Ggo327L+op5CtLzgWtpsCYctFJLcpCMTP2/jI6/u8OijfdlYVIzzNmzeSR
6BAs9an4sRWGx3+q29xGIipEyj6c+wRMT/bwD8coiJ41MNav42HQ5L+hSXIk
nMMuR6o5NeDBSOyEbhQB1u3lW04tzURW6uttBT4UOqtmq3zVOtBo+b3FeRkJ
9CvfyXx6JUCIqFNBXo+EdfjYy9JPDxGk+vrw3M8UxgtLe929+IiO9GzaX07i
ZoVlVFlhPFa+UszV9qRgMSvHPvN4APomk5TD/CA8p+x/suEJkVZt3m44KALx
JWxC70E/ynYLVfnvaJ6WL2jRHB7EHeIghNv6ccoo8ph2Qj8KGat8Q6vpfl+y
aovTFiJl7fGdPCkSPlcWluo974PFtTrJCWUKo0eS+Rph6WhsiuCq0HpW21E+
eeF5F8pGu3KFUwTcmSFJfy8RwsRJdjhnmQRKd7U+DigPoEiz4Ha2lARmhUfr
G7vr8c3GzubbeQrmuhtbma412J+rzSkIpJDszFDPe9uM6kmNa5YLSeRfbJv3
E/ZA8eXm3NbTYnSc38Qu82uBTkPrg3ya1xqzlNSejT340n3cz8tcDE/97e/K
Ip4id9xlqiCI5iMp6LOa4Qvsog4EPz5A/+cf6z9wUjohdVP687gKAWb4z5Xh
/Dy0M97qe/nS/GiMcX7cxwNn5IsGcY+CQ85wtVnSMyRv/O4XbwUKuy4n+hwN
FSDyxN6eoisEDG0qbOr2DOCMuCArslkEh/ro2iN9uZCJ9bEWBlBoic/xih96
CHb8RLsTnY984QqLPLxCg6mG4akpEqmpTI7a9TcYvOphu9lCjOZdbz1ja1rw
r2Y6a05IoW5nWPCX5h601m5M9qfrD2VuUbd+2wKH8wYc8UcC4SV3xf6cXqRN
fkpPyBrE1+ad2X2lr3DLWfOz3GUKUzauTSpyAvQ/b3I8uo+A7mqFfoU9JTiu
8fyFhT2F+7krd9nc6sQPD+5Fu5kRWEBaa5wt68SKQ1V/f7ARw2LgRHFPMB9O
MeP+ZUwCoayNejpGyXDqU7DgeNH8JEQM7WBGw9brtsFLFgU3UwbpZteKL9ax
Im93EqKy9crKglb861KXXStPQsc7pm46phpR3o//Kq8lUa0uZ169NBtLqj+G
y9N8+OVbViZe78Jswnxh5ogYlZkdE9Xfd2AdZ+59ojQJ/tL6DRZZhQj+rJhG
OFDQ49k/01bswXdxmu/DagiUeN844c1/jQVH966dDicQJehVWmBZjm49Zy2X
FbR+f52b5ddzQfiPqdVso5D9NY0oOtOAFzMPb75zJjGc+ECpP1+AvkVLmKl1
JBrdFUWfAoRgkOxDtr5imAjZqaUkFxkmG3QDaP6KZY8HKD8QoEPLdW9DKonl
W9Ogp9mADZlfFPo1KZglnzMelPRjOCNKFCoeQKNck5vYvA+1lhY19ypEUBm8
z55+KoRS5WjNpScExn7pPjmn0QEP9l+8GT06/4GEI3dnc7Bf9+qiuSMUjEYU
eaqPmmFnNDifYkXiW9icjkNeNxxbb6oMnaSQP5M/nRXbjKnEToF7B+1HRbZP
3EKfIL6oqLtqCQUVKa4k/98esHIi5oedRXA6+8hYR7oPHhk2ssXHSTCCx6Uu
a5TgYLd7VjZdn4H0wB4T/zpILVmwT+4a7Xcj826Rm4QQG2uO6OvS84KlsfWk
TidO34l2HNpEIl2cf2YnqxYdujVTznspYF3AC7OJTvS1XfSVPiKCjcUtmfcr
eeDb3Ak5RueXHLzp3AvXEszLD//q6E9hTLE1TWFNAy4F1E8unKDnrfM/at9o
vvxvjAcLaH0zMrLLfh3Vhf/qjNwdtF+L4j0lG5qEaLivv7LyPAlm/Ez7pSI+
mn25gSvP0nrh3u09r/4I+uN/fp9J6705/MTKs7yHEF22/D3RmQJrUL6kW7cB
gznFSQGGNO8F88/31N9BTEWttCrtvxy26z9/mLWDac+RTdEnMGr6i57q8teI
bb2a5RVHIm8xeX20vgQRDvbmBrQeq55lnjbKK4NxyN0RuSgKghnJZ7bsIIS7
4xoDZimY2v0naOpUM6Sv/rBuhu4XoyNN/vATP9S6LFzaS/NkOSrRsqrlI+pD
yC29TyQ8lwUmjp57hGWLLzgxztF+r92xps21HbHd9SYmHHq+VNywULvOg4xD
5qrcRSSK3r+5+lmvC2aqpeGrdQj8D2lUsoI=
       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lWkfRq4sg/GhZSLVlykGQ41E6tzVWIYMvowS4lCW7DWVbeJki7Sc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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk4VW0XxjUJlUwJSWQoSqk3vKFupDSgTCUJlSKZCYmcSlIKiQiJKEJU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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk8lOsfFS0q15WQSqTiahMuUrkd2ZJUCgnXWrQjERNFSkSrJC3WdJNr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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk41ekbxkUaMzHKnmRUaKEIU5Z0k5KhMWWko0JZKjFkzaBFZOzTlMRF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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4VukbtswYM0yLqEkUkamJpjIkqVsTaUKEjKJCKoxChKxRJpkaVCNb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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k4VV0bFpKKkihUkkKEUETULVFCikpSCUkikhIaJPMrCkkiJaTMQ+aQ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs4lOkbxyekJGVyaLZQTm0HP5SWGHxlSUSkctiwdFibqBRLpPDLMUVl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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk8lfkepgZl2pPtWiKa5JAt0UyeJDJiSLbKmi1LSpkyzC1iSnbpxghj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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4lOkblu1AIjlkUmSkJTlWRNm9E6uNVZbYtlRS0sq5muTUOCZpszax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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHc8Vf8bR7RImqRCZIRKJYXyliRkJQrJKElLpRQlK30bRsgqIxnJFpGZ
m00y7jWuzb3nXjsjtMTv/P46r/N6nc85z+t5P897nG3nbxhf5OLg4LDi5OD4
/1Wb+21pUEYWtj/Qp65aQUA80l4i8VszkpgWBzxcGDj77JWan3ULEhPdY6xX
EpDhjHF1D2jB2Are+zJUNnRPWs2ucGiHWufC5Y/Cw4hYmkVVl2rBacukUw/W
saGuJShu45oE77wXGuMmBOTV40SUljWDHWl5UFuEiQXB+68ND/WgPLHVfXoj
AzHW/UPnVOpQd+XCiLkJE07m+V/3ibZBrWPDc/cNBGpq1S5zmCRAyG2F7963
BOoN/tw5/C8f6eeMNp6pZEIsuk7C6WU21vRYmk7tIjBU6TH1xr4QPNSTHvu+
E/D0/jnhe4+C7Tc+TYjtJaCetpwZ/7MCgge2pog9ZyH1whfe68saQLX+bhxQ
zUDsOV6/SJUSsHt+xBznZKFcJYrqq9qAvpr8Sxp7WJg84Gqsea8N8m6BCqut
ByG/kN6jp9gIz12Sk9muLOR8fFgrENKGLG1FHn8vNnxki6iqLo0Y3LBgn2jI
RNPLm42tol/hvtJ18/cRFprS7ZlrrmTCo9MjedCbgMlpRvey+SykyypIiCwl
kHVf9bMrJQ3sZfLhSk4EFGyOy8b9KkEsnSfQkcTndKPYK3pREB48Xf1QQJ+A
lrTMxMj+Zhz2UYlh7GHA5/SSuxKUz1gRVHd5SJ6FBrGKxUxHCpoq7ybSTQnw
fEo38vRvg6X9xkYD7VEI6C5W+21IRcPRHJd3DwhwxPG/fa5uipbRdVmS1gQU
tfzeRm9txobjCk58kQyMbZO/sja6AULmJbMFbiyccuZdHM1vgxBzcxhNYwjB
dXWtokfbQIk6YKorz0BugCdltqMPZWfuT3ArtMCFrqgJjgpoCxwJ2r5AwFhi
yTovRToCHqoN7F49hlsrOM4YzdQh1LIg5ttzJmLZa5nLJ9rgpxc3VnxzGCbt
YsVEXA0qQrS8PjuzwVFuauEwXo+zQh+9Ej8SeDq7fuZQRhHCpJRqHLyZ4I5S
lb3NasfmUMW82oNMtK0Vjw4vL4PxsD7/uxgSn2X9Fk9iSzAjNM2ZL04gxpFt
4pbVhOlt8d+UrjKg+PLElIVlEyzqnyamprGQMGyqNiT8FWoR960Mylgwqrp7
yfVvAkSUK/Pa1Un84t3/vOAqQrTaRg45cv4m93pd4ulKAhf138sjLgQS0iWc
xDyb4Jhy/x+HPRMVzrmG94k6lEa/ax/JZqHbK2Aw5GI1VKqEFgu4WJD6XlWS
QbTg42dx31fhTNjdVk0ypNVAdnFnJg8/E5pnffP3TNOhd0d669GOQaA/cadc
eRumXnY22skTENg3XBG/vhUVnN+07vIPYonneo5wyV7EiCd4ZX0dREbUPuZU
QDE6f5zM/XuTwJ0007nmohy0BPZnr/cgsL3E+6drRC1qLfbKdU4yyX2QP2pE
y8aMdKys2iUC1g3jyVMjzTgSojk+YMuEjPTBjkJzKqqX6lvbGgyS/PB49sim
Nhgpu4j+ih8E46STQPObONx5oep87iIBe9qTkIYGKrRMn3uIvGajv9Njyq7o
C3STD4bZGLPAERnJyptKwbRMr62kAYlvV14r/QUNj2SeRFWDhS2/F6U4Rzow
qbf42HKsFzVSoWmDrcmQcxemrrxBoKzXr+JsViH+aPZlr8wm4FVjkfbWohLi
EvV/ykg+PFF8teaUchPyDdicTRJsVL9U4fEVq4WY/pvpCjEW/PQX4z49bsRB
s0iHf4ZD8P4qMRZ+qw5band+ivtKINcqvSDrcjNiShkh+qEMlD76LqrW2gyK
xAfLhOUM1Eq3ihQH0eHIShr5wcvGFbejB+jytRhKFEuRJPdH3IP24F95B6id
Bp2jlsNYNlTOnFpSBUP/Gcq0KAvqf3daVU08R0a6xKK+DQHLyEALyvoOHLlm
t41vZBizkw/zGa/aYWVyvjeYzcTQtEH/nAcF7JNxXUXmBJZTTHZ2c5Uj+IGu
Dc88AeH4FdJbhJvB/yqOVavGwj9uo5y7fH1Q82WaPu1koPycx2DO6Q/4/lLv
1prn5PN0jQXPL63oafzu9GiAwLVkDkpLMhUpgna/vXQGUDy0oHhzcxmkkoci
1gcyoW5e6M85l46Ez6Xqp0m+cThfYnfGpwob9V1Gb9GYSM70Uw6P+ooTjyub
k/VIfs19sHVPdjo6ywYOmGwj8ObumhNOLa2QWR7FcFLsBJs19GBXegsSNnSf
7WOwsaPsd8YG8W9oFc9Vb1o+AOPKDwJhR3IxbaXEu6BAQKxJyP7n0kqodJnT
LpH9MLmm61OlVgveLwkuR+eYEChsXbRnBkG7THwg1YwAZU3sfV1tHyjuORyj
Y0/OY8SQ/00WDccMM3p2tTARbCVYJbe7CvmzP7MPbiZAqCzOm+vmQSox1ouD
7Mec0p1VMnvbEfAnXPnKfBeK7aTf/Vmox3/8nqebdJiYr3/g79dfj6qBnh/9
I2woKn0t3pKUB/F9DGducp6zDul9+lyRiktukhK2SQRGgn4sKqzpQjarMfXN
5haotPQZ/vyvE8ahl7Xkudh4/2TifTR5/2uLfGW1HYmbZu4voW4azh57xTPh
ycJSK63cB3nNKJDRTBedYOEzxGPGt3eQurrj2d32flD21vVKT1mgMPiY+QWS
38U+9nluXRkPg7CEHzUOBJbIcMffSqzG1cclrf/WMuCgRrPNL6Fi+/1ce1eu
Ydhw2b6ePvsOUkpdeg9PkH5BNNK2+E8bvPuqwzsLRqF4uSgw+U0LqkZ2Nw9L
sSDwlJoho9CIuUN79nC+GECexIHwgnd0FJ6deLaejw1Z4Ytx/95VgP/XfG+K
EhviKqGTvGk0rO8stDsUTyBiZ5palF8Dss+K7VbiY+FQ2VC7XOAXKF6fWG2q
yILbkpxRlUPteLcu74hw+gAqdJmnnWs6MaLVoqU52ovtkqES+xraICKfe93i
UT/SRszauUer0Wt4jncDqZ/cvy+vLd5ORUtbeEL3JDnvfy4lfq5vRRdCPzdJ
skBcDEXC2zTsChuXvEry1eFDoq2eDaS/uLjuofRyAoyt70an56ngSklY+ndu
ENvXHdVJf1OCtgNbNkfUMMExIn9zmYg23krJzRiT/TY78OlY6/aPCDDqtFve
R+qPjKvxwbokdN57M7DXiIB2XsvW/o1F8An/fmDyGYF3hHtSmUI5vpamhp5o
YuFKTaLj3oImuL3juq22yISfrb0MVbgb/haPh04mDSOB+FVBsWjF6pEVv7et
ZSIi8dpsmEAjcsYou6IbmdB22uhxKqcaBa5TJ6+dYeJie3P5ip3fsKrj42j4
KBM9NnGxtZN1EE/wk5biJ+t9o3TR6l4RlPcbjl9rZuKXo79+cnsV5IOcOT3e
siBWSh/Zql2IiLuhM/f+I+B0KrxW36kV23NSL0h596O/10fdaaQSphwxwcpf
mdAalZCrtG2CygXJgBf7SD2uunCxKKsS7l8qWbzHB/G6/KyGfUU1Qs7EBh4h
+Sd2xe57ClfrQHC6Gnr///3jEJc90o1W00dBvby9MLy8qrDqSTnu0srKMnTJ
fZJnlP2itMD7yYEuKqsfZte8MjeufQuO9x4ZWWcIRAXNTQQ1d0DwTB/LZtUI
iAKNhOEllVB+ttXS245AsbB3o4F9L5Tnm2mCP4ZA49zgNcdJgQG9UOkRqcf9
ll8F730PxbYd0eY5pwn0D9aPJHjkIeS79JN+sr7Y0OKF6y1V2HvtGH/5CNl/
r9odTR8rYHOw+P1+Et8/tF6rGOEm+Ox0Xll/gYETjid0qjZS8Vv94vGkx4MQ
euE7kebxDQLlSbbTcgwcztiSrTDQgsCPbo5X1dio+nAz2vkDHZO6c7NucwMQ
CxCOOPnhA5qul7w8H07AJcxPrkKuEzc86AJjO5joixXNOHW8EctyJff/SB3A
wRmDErn7OTCmZxpx7iP93sqMrNTOEphqjLe4PiXwq2FRRli4DZo3nUqi45hw
2OvjqzNaD8ljHFWiCQSENE592jbSiG+bPFZujCIQHKzt3MdHx9Owuf1+pN8i
XGJeLXepxdhe8RNrgxig3zIqEOb6CCHR5ZvidUi+TfbLtZOIx5Dq9PVR0r9n
hz4Op12lQkIy8JSnFQPd5TU6/UfKkfVB+2MWF1nfM4ulggGWuGu+NkmD3J+a
U/NW/FMUTA4FxXzjZmPyy51/m/lIv0yLezEgR8Dn2J9Xsn+rwL2tMW4PB5l3
xlOcI8i8sj3q/YAgef7pOvsdtOBPoIoXnn+2hkDa6aL93B49qEt8phd5itTP
pO0j5l2ZmLySdrFdg4Dd7r9nnA7QsP+6hVM86Zc4OJVvJ8glIH/FudKxQwQu
nBiPqXb+Bhuz9f8MBNjg2zujcruhCR0iB8x5FlhwcN0sORNORaBDa4dAMgt2
Ef90Pvu0w7vDauMXMq+kHedSy10sAyNSQZOX9BvLA42zHdaVQEWDNpfZS+Kp
Iv9YWa4c6pa9E7k0Fk5/vn+vpqsJ8eJsFl8GiccVnv09ynVwVDFn7Cf5wngg
jvciNw15t32WFioPgtKYb/rY8hE2a9xn61gRsOGnxiuFteG9g8oumWmS31Xz
/IubayHt5r44q0bqN09HgW5nIrQ+ywU/JvXRc+Lx2mqWKxoiw3iWkOezIjkX
RBeyUbeJUadTRb7P2ldX+nsMPhbHKj+8RuaLa4ZL3T1o2H2EV81cgMxnbnXn
CmjNCB5yrDtewAQ/2/r1kzUUOITfXuJ9h4l8x7jRremNiFWgehjJDWIoSHbE
vqUExa2rpJ9Ik35HME/lh0wNFCv7TCTzyH3qvZ+zISQFM+sKTu2KJf3Fmbds
C95sNBzYM/KNRqCcrfxS718buOpEqxI29sNojKf66NMU3PhwQ7T+JxPrvf12
SbgXQ1jA/HwpyW82G95sXGZUgHtPL3mLlxOo1tBgyZrRUSb0n2Og1yDcHQPp
ntO9KLxp2P7t+DC6b2+L1Z+lgb9ueT61ngkhlxUd19QpSG1p9Mm3Jflgv5+/
rFMGZLkzZ968Y+LLm5cjF/I7oapwP2tKahgPH0jHLrtBw02r1JlPdDYoDn+r
ufQDIND67Pn5CwTihJTodcE0vMv0ZAXVM9Afu8b49pI03Hk4u7lyJ8kftdWp
87vIHFWzag5KAxDg+zpmsUjH+nx1u8NjTBzaomHeE/4NfK4ak3yk/wtM450f
vVaOLr5XJzuOsZDtal3Ck0HH2IWow2rxJN7XXkr0/o7GZ40U1xDy+xRZW5P1
kc2wev/qlvUkA3eUNCeTr7ZCSePf9sdDbGi3n1mvycrCmiKddjeST9/LSh5S
2pmA8wvxBdpk/umVIv7lBJL1q9xh36liw6LwSsprSify7kamVnUNQM9C72T6
GB09QX9FdsUMIWFRQDOslo51HA9CF6sHcKh4hh2aTcG0rvGXUXI/zeZcz2i0
5yBQ+ZKC4G4CUmt+GJQubYeG8+8+YcshiDLXCilvaAJhc/IsdQUbETd96Xpa
tbhX9X59jSrJFxvvyTOrExFzxXI46iHJbyVZwyKUD+AeO1ZXTOYbhbWLbczZ
bvz6T8MsoJvEM7yN+1FwFt7bEtNWlgTUhiwbee7VwnhTiF1TPAt7zi4zWLje
jaiUH8pa5Pf+nF+b6D3bhvOZu8vcakbgdvaT9IqsCsxE/YlXcSPxE6nMrFha
iICALeohZB6UySm8yYyuwfdKPLvpSEC99NPgDdVEhMk4HDHbSsDIXYBXPucL
5iIrRRpbWND4JBuQ/aoTH2LZ88e2MkC00OaTVlHhlPX8kTGd9CeSaazHqINd
TvikXxcLjvqunUYmnUje6SWSbjcIpX452YD3LaASw4bBIwxkDaqJLJtPgLdF
4wNnMr+VmvwVUdlVh9PenyrNXBgwyjPnLnrfjOhT8of/7GHj4EH/pzrh2ZA7
px5ELSTrH93GcfhnDWau81eb6ZN6pKDzPLuzG4r/DQQcpw+BO8jw9euKSvxV
2ZNdQ+6r/uSJ9N2X63BJMND6TQgL5RXZv/6W0vDhSclDL/YA3vMObyj9kwnK
g88Ke0h9UbhvOd+Y/Qm+4vkzgmT/WeP9UZeX0BHrXi7DT/JzsPH5LVYnu8Av
IWCfw8dEbNdRnomjGbDv2L2jn5zHeXqC/Q12NZJNwg6HGRPofhfcGnKXgp6O
zJd6T5io/+rcuYr/C86lPBM/9ZPUB/8CruJ1PYikbJqyXTYEW73ch1K7W8Bs
qjm0k+SPydS5YA6xbHQ7xdT1q5F5KuWh9UAHmTeuKBMpGwmca/qpqj7YgdXv
VadMtQfQlMSnpmNKQVXYpgtFowx0UrIhm1OGwtBv/qvJ+g46negTLv8KRuHI
M73TTHx3oCYIk/N/e7OpsUkcAwn3GihdOY2gpJVetNrch37/N1HXqVVQmHD0
OrSPAbO9YuaBmZ+wMGHzJ5PcX81eQ6RLU8E6pzmyppGNXyemlLldghC81ODW
FOlXqVZH7HTDa+HTeTGKj8nAWN3JObHhRliMLxUP4GHBVuz0Gd9nTYh6Xde8
5DkDnhcevEu+GQi+wvSDDmS9nrI/Nh00isLlGo3wsFvkfOqMmM0VtaDIn2P2
ngcDFKnD7MmLvqhTNfIWIf2QsenBmv6FDog/VHUtzehGjeKp2TcNxTh89l5s
bxETeVc51EWX9IDLLMbr8hM2lAx2SsUmNKN+YfXjuzUszP32Dak83QaDcw7j
WmuHcAWzfRNX23DX8ueSvwKjKGyr4kieb4JLyOqIpGcMCFZ0RPhGk3pTH/+f
Rmg//PZM7vD/kYGnqsuenfj//4xcdpzXz3os1245eYzcv0qZmb7xWDqe3y3X
+ifUDw7CYvJW9B1EyNh8qyT1TT1s3K/waR96nv5o268yDH1i/c79XXRUa6qU
fL06AJtsHwPfn1+gWVyZx5NJwC07SPe1QhsoKympUZ9JfLOvHnHqpkKeJiJk
uW8QAu5npk+8ooBvSM1JJ4TAFmW2VfbxesSVCtwUIPNv8HGXTmfrNsyZCe11
JPWwf9mWyCL+NCzUV+06tY5AE+v7a534LNyI1jhzh8RLuCDebHG6Gy6ry/0M
rNj4H6uFJqo=
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk4lWkfx5m8Jk0LY+ZIxxZZkoxBi8n0janGHs2JGjSSLGlTR7xCtsQo
WRqNsQuptFiSMHayHIfTOcexZH3uI000QtKEeZ/3j+e6r+d6rue+7utzf77f
30b3swdPfCYhIZFCP/9fdTRLvOoCOjA99H2//hxBk3bbZ5OMZrSfunLdiyLo
742NvLT7Oayu1WpfUqNQs3vVgvKFEpgF5fDqDQm2f9mk3RjfDHOZP/hu9yhM
RMUYVL8pQcbhusRuI4LWOm0ztlMtopZk/B/9RqD1M+/kiU9ClB/yvmVnT2Di
3c4czuCg3SrzPfc/BAnaX+f1criQi/PJiDUlqJRrMtV42APteXVXTYVRpI9a
sI6kPsGDxB1BunsIQo/tU7Gw7wRzdkVwigTBYrnl4++e9+Bgcefpok1i7Cgs
DLynMADblGWJy2Uj4AQ8ebm1vQWM+83mZnIEcwYbG763aMMVOQudWwwx/mkq
LzhaJsD6p756jh9G0eLkK1u/jY+/FEplFmrEOMh/q58QxkHKJk5FryrBSlIi
wxjk4pT6U3fhAsHIowjHnp5i1MWkhK87QGDw7Viu6T98eP9hP72xj0L27dlp
ky30/7FJCuw6AqLEfWea1Qd7xhlvDW8xDI7srZTQfwKuVezAFxcIwnLnF0JN
n6E8ftH7WBAB5+4Peo2BfDgkOdgWdBGMq8iP5vmLcC3jZoBZHAVubn53iooQ
nSp7bEZsxxCl/Ml7iDmILU39jWT9OA4n19u7KT7BRNVExNhPBG6vGSO8Gwm4
3133nd0vBCmPHhiYudagzdmVe9yV4IfoF3tqf+wF9cwri/U5ff958kpHUng0
30NumYYUug0qjgUZ5kBKkmLvPUiwM3l+4XlALtZIPzolfZRgwqzs4vhcC6K/
tjXR6KB9aJm+NGxXCs8zmtpaxwl+f5C7+igrAaT08FUtF4J/GmRWTvG7UTil
4qFrTyHMtc1FObIFAauiVwt+JliwPF2zYqwfhh/zWlsjhiExcaxwQzsXnqoe
rcoWFNYzBk6lWpfAtqFCeN+LwCXhq8TmLAHWeR772LaVwn4fVpBfCB9DfB2z
vSkEwmV+oernA4iSECvr/TkKhdok6+XMTtiHregP+ZXCwukNDP3gFpy3UL0c
t5n23aUpz6FgEB6fnP3uzxCYWj4L3u/Dx4YANUOvtDHoDD3n88u7kMST7Bob
JJgfGborn1EKLXbbe5EjQfvDh2lp+wvAVqnhLjjQfIx4hl9aFsNmWf78e5rX
pKtL0UeJVuR72Eo2B9A+vblkFVlSiNhNMfavaF7zKkkvG/r4mN72Qp5XTfOx
fOB3nnkC7L1knRR9f+Z/Hfe0FvIRP+KVm5NI0B1eqPqOWYam/l3VVvT3JobJ
nPGGF9jypn95ZJJCzHttg+3OreBJR10+RufTPe5D5acmIRhTWv9mighKtNii
/G1P4b4clGxyiMBI45JCcEQrVNhZ7olzFDyNLkikn2wFZaqsnPqMQo+++syp
2yIEp9osLSWMQqpdo5/lwYU708m/5ZwYcz5izsyRdkjGtp4oDSVoCLyVkckQ
Yc3dHYq7xAR1t8dkoxt4uFTeJWYr0P6fWfuD4hEPKD30MNhFn7+Vqbho6dgI
WY5drUM0gSjC+/BOw0HcifT2yWMN4tzk09Lh2Up8ZayXXRhBYPzT3IsS6R7M
yOwR3IwQw/psuc2r6QqYG3iEB8jQfM9Uxfql8eGiYlfuVCEGS03ICU2vQkG9
U2ocRSFWV9a99Wsh0knWggfNezE/+qupjTVgK8XMMi4S2DgSqb7XxfBiKcoI
Tej9Pr4+46SWjhjmFX4ZnR8JXw8Nv+QI+Nfu443T51+1KLdW4CnE2KshXaNa
MTKGmaq7q/rgGrzG/9D1EYTr/B150KABder+17+wIti1Jil47T0OPgs3bw1P
pSBRJjf3uL0CvW4p4vR4Auv9N3/+ENMFtU7bo0v3KegV7OBxc1+ArZDs1tJM
IS6yM/qa4CXks4tMbxG6X5kzXE37HHA3qbcVnKb7ad3tq2nzHNzd1bBZcJT2
nQhe2bWWY7WvI5uvQ9BzYpitlM2DJmO7algyAR/8tOYt9ZjqGIn7YiPtc37N
HQ07Hlbr1So++p6A7Xxh/UPvduy3zQyclCa4E5O4Ut1rEJkM92TTnDFkzz05
EKX0G+JG1v2i7UbQIagu+9DZiy1Og6p5cSNQq7o62y8lgBpzZX0K3Rd1wgEW
X3QbNv7j9UV0n4Z9fPZw8OoA0tTCjEOMh1HUW9pFfLnYvXjLp6iC7tfCAvmZ
thjwh11WDtO82ep+HypfcbBgZeh9ln7/vWx2j3x+NUIdqIx9dgTxZrzSRRce
jqfbVpsZiuGSWLTe4GYtGKx3UzduEKR/Oyk9p9eNfubEvw0vKMjyZwM+d2jG
G9VqY8OzdP5zBJ177gziJ/2UM+//K4bnuSde3yqJkBfiFBD/hs5fstVmsaYI
bucs8vP/GgVr3Dra7oAAITq7c7JHx2DgYPvYUrcPzNDGBOJDoWFbYnPwr72I
kDOZFNH+ORd3RPly+ED+pHvd2AiMB4oMti8IcL7FaqCNns8yStlSKYwOrGXk
T+19RGF18Ctm4ToBDm+/bq4TLobOIU/NyLdVGHKs8ntJ94vsA13W8ZBW2K+S
8t86RnDtsrFwhBLi709dOx/T+de/F3BRurscGpzbYY4GBB7nWUYzWY1g9bVJ
bQwk4IkPLP6p1o1dVXWu2v60j12Fgb3bfoMy6w9FDdp3m/uVu1WDeEh/Xp1i
GEzBe/5itKR5G+4EbX2sG0fgWDl/JWi1CKHUa5JtQuGcc4tpe/xjPGdGmnbT
fbiwNN34TU4x1C/PrJn3pfkT1fB9fk1IipEPWbYmsNMK/pNaHIBCML+LUTOO
7L/dvKKaahGt/99I5xiCq7pGZt+Y1SHhYnuCrCbB2hu+He/lhUhV8TspQ8/z
0KKlpWv0vJxOOLSzfH4M9pvN9ATDfKy4V7g+RHYMah4+HhNmfeCbvw3t/0YM
6Z6sHwfVBfj3lOHVCUsKL08qNnb6dGOrZ3HEu70UujrER7cEiiApIRkzvm8U
YUWx+lWiaizGnNP3ekvhf0zmx2M=
       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lGsfxseRUnmVnLKlxVYRL9WJhCtrUoRkaXGQao6SObYoHUtlS5FG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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lekbxqkUmZqpQcoWg5hKmowtupwapcQgskx2ypIYSYhCSmKiRQph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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk4FY8XxilRKmklyZoWES3KUr1SCSEtyJqkklKWlHxtZZdQypotS6Ts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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81ekex211NeLKZG1GmRg0rq3FEfrYs5TByFLWkekMRhiJUMZYQhF1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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk4lVkcxy91M1nKlsYakuTSNGUZom+loZAtjMpEYUIzUsOEbC2UhqEa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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk81esWxhUhc9EW1T2KDxqQTkodetJEh9M1ddBtkFmZoiIVleFIMhV1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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk8VP0Xx6WUSIos7UoKiUSW9PhQSoQWSqVGi+x5RAptlDWFkhKJ9CCS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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81NkfxqXkkth+SJuyksbayn1TVE9NiiiJJbZJhSKEhC3tYkkKSUVL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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lWkfxnWylClhUg0mJ9GiZVQcZUxXUikTqbTZ0mQrSklNyKm8aBnJ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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lWkbPkWlxZIpSaVTyrQM05R8Pg1XGmRpIqmsdU6NmAihRYuQSGVL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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k8VA8blQpFkihKotCqBiX7kRKhCBVSSUJRpFIpkjZEUqiQJfSnVJIk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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81dkbvgxJkxbbNMhQqEEIpeLnoaFkaZFKQogsE8lgMKUrRDVjvYlp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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs0ldkfxlUqmhRGrl3ckmZokAqVx5RSqOQSIbnFKIoSuXVxSwphUoOK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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lVkft5VXKZKyRKSoMDMRE730pdRkRggjRWUfZUka1EiWEoVw6UaW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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k0lG0fFpEtqdCiRbK1I0mSS6K88laUiAiVLaVQaEFZUikSQlnKkgov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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8ldkfxyXhF2lKSfZBKVpkiSn5SAZTsrQMGaGohIxIxK2IJMmWNWtT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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk41Wkfxk/KMmXUlJESpSRNJktqkLqlEaXDiLI0lTXqVSlea4nKkiVR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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4Vekfl5Q9oiaVpMYakxKyNR+hLLllGiNrRAxNiy0pE1KGcittV8pW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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3lUTW0bxps0aERvpqQoUlRoMOS9QhFCSKVImjSpKET1lqQSpVAyJ0rz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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVns81FkfVuRTmzTaaFulqaTS+5ZsBrvqcWmjWNlSLosiobuX3CLEtGoT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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81Pkfx8X+VBOtUluOzREqR8lYm6iXjeyQHBlHmsparGRldZCQnKVD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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk41dkftsRUJBWFVJLMnaxRlNLbKGqIZBtMliRKQpQ7REpXhCyN5VqS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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4le8bR4omlVAho6yWEZXoI/FtfpHRQCkJla3MQqnsUpQtyUpIVkT2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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41dkbJ9ljbmZoIaIsSUYlTcIna9GkrGmZLJUr7ZaSQQgtP0qyJMuo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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk8lWkbFskySE1ZmlGWqCwx1dAXumw1GHEsLZM6DkVEODNUStYyVIPK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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk81ekXx5WS8gtJ1CS00IyUXTL4mGoklaWMZFKWGCNrRItCIgnRYokR
KalkzRLi2kL3ci+ue20Z8XxlUFRKNTP6PfPH9/V9Pa/n+Z7nc855n3O+a118
97vNFxERSaLPf++BUl8nxSg2LK0XRJ69QzC2d8U5Ms4G7+qLq4VpBCKcHWah
xBUqJ9fLaR8lkMtKdWqr7sZwf3rlOkUGW6zj5M4ad0HGRIp5N0agbBQ0/LNs
OnTkVTSWOBEMnTU+1jjSjaGmC5P6bQRTjfvXRzj0wk7uhJWOH4MBYfjNkdBW
pHY3mJWlEgRFRL+elOUgxmGFg+Z9au9Qp3ttZwYG8+Tydam9mDN++yvjO5BS
0B916hlBoLrVse1R3RDxyxIYLmSQNT1uJLVKiJIh9eWingw6F483HTHiYf70
Js8f6gnUL2xMknJhoy9pVlstlmCi0XhtqqsQ2QdLlFSsGbjLSfNMQ2tgVfSE
U+lDIJl5KXHztV7M/nOC+8MxBrJpXNNdxlywbLIEvz8iiGY/M7aSFeB9fvP7
gjkCs/jHdazqHuhYz0pIxjFgKbWHLdN9CluPg7fqfieo1pxUe6DKhmJNmRwr
meB7mRXqeZktuBjf9vhtFIH9BsPw2wadyNgW2WrwguCTtbJCdnETGnv09Twj
CGLtUttSIln4xxOSrlRfvYaYhf/+Yqxjfv1g6UZgJxrTzzvfg6rMluYA6k+H
Wv7DXcEdYOU/N74oJEh4OhvzRKcTCm97Ene+IXh++m4k2SNAhtKIXZ0cA1N/
N41NGtkYYXKtimi8rcpKN3xa/xKc7tpKltIoesTH9G6klWKg9mSUlDtBT3W4
6Ju8NnxZyUlPrCbILDdsWqnVCtlPWj65lwhOYaE+71Yqak1dmJeUHz/py7Hi
TBMqI/LPNQUSLFinlGl+ho+6ejnzPwQENxivD+ubGqDVJ7Zk+gwBX6983afv
uEjfy5ZNyyLg7S5U5wR0o2fnofj0UYJ3q1SMDB+8hG7cudueQwx6hlMbH7Fq
kHHT1i3Hm/JrYnrU6O3vEDTH+uvQ+/fm1AdrFraDqMZuvFdI8Mvd/fMZJy72
pr2wWJJN8NW123Z3MOVfI6h8NIbGO1mks8GMi4GtK0yHuQTOP3LnJno70X6b
SXam34eF+eWukKrH+ck1PTYnaT7+VlCfETbiI3lWeCSe3me16meNci7kosIj
/O4SbG+7cdVIphtJA/GimdTfOtmmkVVfhLj83rDmBxvKy3jg4pnBEozPJh9P
ofG1Hyr4nuE0IOThUtWmC9R/06Zb/0ZyEH90qXxADq2vX+bbz6RUQJjoUvP3
bwRexGTjtG8Pru1yCJCRZVAfU+ofpF+HedbttQ7BlLfgMX7yWAmmpB90TNPz
mo0GRfFu/cjVisgxSGJg3hdrIbblEcr0HqpLuFBernuYB3f14vEtzVvJMwRG
LyUPGPlwEBb65Oq2DAIPyd5nlq/K0do6ZlBE7XElM/hvCwUYqNo9zBZjYKFY
7/9NrxIVgzrZvccJQg6783X96uFrqbw4MIjy4Owf7pfDgY+b6+mG2wT6Ho2h
0219sNvzk22BC4M8UQXrqMB2zAhGI7TvUb2HpBfwlZ9jYM/N5JrLtP6f31Gy
F63Dwc9vfAYoTztXi/i6FbAgnMs6/sqL8iTmrr/9eB8yPNIXcpUZuKzJwL/R
PMh49w34UJ4krqjdUQnnQGLMtH1BMcHAEt196W33EP1gyTY1Z4Lz9Vs14wo6
4dUlqniVEKTXHjx33qQZnSEfY6dovZbdz9obuloAr9WjXOuPNF9ddnPfSlqR
HjRmI59E+fsrqifwO8qr1aYDyyQY5LyPj5m72wKFHz21Xl0jME/sCg3Wu4OF
/3v+6Catt4sqxfZJIvUo3myreoLyX3TUTe9aNh9GdTE/adJ4hhybqDj8jYXu
AE2tzAACcujN11Oby5G7VavSyYPAwHGNwVR9OxId7Ur20f50xUXz9FZhDZ6d
j6o4TOvBfsTOdNG7p7iQZyO4S9fWtb5+g2E1WH43tZrtT6Dga7J+o5YA1uUN
r/WlGDh9C8/3NMmDz/EdlYtcCXLDQrzzb9dBoeT2aXnKk2lmZNXbI2mI+SSM
Faf6hVL7Jxov8yEe552d+IHyttHsjxzpMvCfOIZFU33v12ZcK2wWQO1jtITX
JEGKgfKETlAnUuap3mqh8yHh9XK38YRWWISzp+1pfg2K0s8UlPKhvmi1U99K
BpPBITvrhTxUHmB2+uZT/XX3TX1NqxDmHGY4R/OdsXVyZKCPB85l56y4/+bD
FsX4qfuNODH8ZZfjKVof0emZLlMCqB+NKtH/h4A1VInqkCKML5+YczpGIO04
L22ZYzp0U2bFx2m/EGMO/qHoxYeGt5KS6jwG4V0m6x7m07WuT94WSQbTr/oP
RW5IxVzgZ0chPa+YPWG+Qb4fMrpnFETyGNgvit02z64aYWer1Uwo/0u09rq8
+JMHnqPB4G81VO+spX75yQ58vRi+q7mL8jdS1LSsgo3Mxd0ej2j/CctNULpZ
F4sKkZZGd2pfNyjJ7XpZL6q1L1VZhDAIa2BbvhDnQNz98BGRhwTiKVf9WdId
+Hvt9SMKtF993n7WVedLK9w0g9RWJhDkJJoPbv6Fjwy5hKoqOl+Ue9cOzJ1K
wwv/6N9Uaf6smetVT72a4TscfU3nIj2frNqRadWDhLiloW+/Y6C+Y1OO1NdB
bBcbWXby8CiMjWPTVn7uwonxPUfEaDxESgvNdC5cwbiAJeVC9Uq0lu7W4PDh
wPaeWqVA9drsex16/CLaD27eto/uO6aaLdjxVyEydDaolFG+PJdqmOQo8vDn
8DfXKw8IbGdWS4wJGuDdPRKURPPH0120e4NzLuKNJV4/pvXJ/7z55a9oQeC7
sIQtlBefjTtXLGSzEfWoa43jDYJdN/6N+T6jC9sCZIpr2gkqbCXly7e3Yp3d
WtYM9c8wXuFPp5UCaBU73LjTTefVMrNv2u96cWXsADeS/k+ECEctsv/qhn32
/H75ZrqfG9tmPf0UUh+YGinK2+DQuXuV3BYoJ2nzLGk/1A54s6WLx0eSs5uN
6CIG/wcPar30
       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwdmHk4VI/bxtFGqZBS2lQqWcqaJblJi0qSFEm2FKl8pUSFJDuhUBIK2YoW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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk4ldkfR2UnZQmjhrrZklREWT6SSMVYipJisrSomKxRihZFzC0NMZFK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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns4lGkbn0Qnaq0tX9RGErYt6YpI+JGS0zis84acKRraxKgUtbQJiygp
srHSRymUM+M8QpkhM8Zx5n0VIXTYWIe+9/vjuZ5/nvt6nvt3up/tXsG/+IrR
aLRb1Pr/ni6wPXZl5hVcgopMIiQIKL9dLDpj2weTPz61nZInYVlPVzlgL8AE
i/HTQ6cRLDFGI98M1OPSW57R6q8EnGXTb+Wtr0PKgSy1miASNFmpNT8nH4Vr
fhN35wkSfCvV+tmOMhgeR+3CYRLxOWXfeSe9hvhU/7X4lwTunlZ7nrW7F70W
liqzr4Xo4VhJFcwKIF35iHRkisD0O1JDbHuKjS3Pfgs7RKIhzatQLVyAVP+s
vIqjQzC8YMq8n9WKYZmXSb611HvmFC5vVyzC5rTTbnQ7EmUZM99P895g41lF
LldXiHJdq8i50deQvsNa+UZChCbLL/bsf95ArGpk0HpqBFGKa3t+MeAg0f43
f/VDBKIivV9db+eDE9zUn/1WCMPytc6TmT3YJbvOSdNeBLaataeUXBXuaP7b
PDpJQDHnP9dGR7shNe5Y7WEkROHgEwfJy40IsAkJ05knUD7f36iY1YJMjRs6
vRIklGqu+x/k9cD8WTi9UEaEM2eSaz6ICbC3fZvPkoMIPjzlnelnu0DTYXwy
+Y7ESK+Kg3zHPays9JzrMCMhb1VUkhbZheY4L0kJcxJM97/MskdK0JncobBW
luJjMeDgf7uMMT4RO6pB8bHxZ+mc4+0suOnQpc6NEvDQ26cpxqhAdf37p7mb
Sdh4XNSddnyJucEbHX0vCOS3aAgGxbnQmlX+6ndaiIATZUrVRtVYzkiW+pHC
V9J/WaNVxIf5Ea2BvSSJmU5rxsPzJdCWajpht0TVe6Uw/Wt5KDH8xd9lWYjQ
56K5U3kcrI15Z61pJ4J4SliLsQ8Pg/2P9wb9IEKl24ts8xY+wuKX3l8oHMFT
t9ZodbtHiM2yU/xoQ6LX+1FT1Xgvfu1jtoifIpCjosAyNuJBISGo3r5UBLXH
XkpzAQ1QJx9t8b1LIK2lpibmVy6sdo/trt0vgnvac8siRg9+VNW2+8tYBEX5
4VS2eyqCvfV5DBcShuz4oKioXqxi3ty6PCVC1mfbyYj1XIRJXyidahPC54DW
YlYiH4dFzp+vaBOgNQQxM1vTYXVAb9bXi0S668EmU6l61JoyPQcKSZDSMbMf
jV+DlH3pUe1BoCeBeJoY24y9vkPXVv5FIpVfrjSvz0XJZR1P362UPprImotT
LExnTP19ntJTyMkr+99xuAhlMlcvhYmQp6r0adl9GLYJWuFssWG8nd1Jk/bt
xhbj87KCXUKw2E8mng7wIVrI23TsHYEAr1rV9cp94ByJ7RCj/BEUG2P6kw0H
VWYRiVq9BFp26Iupe/DhqX0+wp02jFMXVUPX8TngsTQSjumSUOYnEEZ7mrFh
q+vyxU0kbGntf+4K5sNHxeBkFynCZvHVWv4+A7gaPBxatleEaqey2gPP2jFv
Gioa+kag4egjG5nkLjBO2ykoUvfxFS44Cz7x8GNioaanJ4EdHRptC679SKJv
K3+sQiJjxl4+8Fg3PExmtENzKH96qc6nkJ3IenCtvsSSQCzz9Z78Lh5yJ4Ij
JvaPYFH4rae98zUk3ZbFxnpE8OIY6L79oRS/ci9NWlB80G5kBtV94YC1QmU2
PUsEjbRve+rVC5DLKLhtZUKiYniV4N8XbLhed5k7c5Din/7Ok193HxL3TMUV
fEkcWlL6XlOuDp8kpUL1qfM2C9xNxtpc3Na7at30uwhRheuNrsexcSWTi68U
X4Gsqhe5rVz4jVXlvp8gYGki8+Xsmz54/Hba3n27EPEqhPNxs0GcWjcspmQw
gKSYUi2l4AqsMP371OTPJFj7P6rH5ZdB2SDYIpJPQNZQIXZbVSe+HlkIVg+m
+glZpnUQadCtNrfUpfw888xCbTSjFf9cXpMYTuVvVP3mw+ILvbjaGmX6/N0I
RE1a8eqCZ6i1lbJTNSCx7xZ3tMClA8lrKle8ZFL9qn52OOd9D5pyDZbbqTxh
lW+xoyddxav0xQonNxKTcg2NLjo9kKnZN+rgIcKRG+ZKnoMPcXP/GvpafRIR
g93hGVMcNNxQexgNSm8VqdyWM8UIlDS5bK5JojT88CEbWTZ2nBvzXg4hoZ55
ODnhGhdbbtkdc/Qm8D5akpwe7scVsnBZVmcYXNqSzNC+bmS0WYRJxwmxUSX7
y8PmZhSb2fHCGBT/bIlG5nQnIgvO3dcfF0F5aNFN63EfWk6OZySmjoDeaJ71
cZiDty5beqIWRTgv/ObBvdeBUJlt/P8GE9hq7fncQr8BzneTZqWWqfnjmb9q
JrsXo8df2g1+FSIpZ/3ifGYubnE+f1D3p/C+zbJWqYhGSNmmUkdPEkdqZMzS
81loinPUWVFG9ftHHIMjOYA8vpND+Rg134ymAxM+d2PXwz9P5MeQ0DMJcWfX
NYJ5f5E4SuFvkdV0tMakCyznj4JyCwKr45/X1UUPQraoxtXq8DA8fOf69nFK
Uex7ryNkD5UfckRr5w+V2MAsvqOzk8r73v6SQ1+eYdWN6ty/j5OwMjO647qh
E5wxH9mFWhLsV5EHO9tK0H5C/vbJDBJJRYgO2pcH1phNVQHFZ/Zi0vwT9QFc
yj1ZvKp4AEZyvEz9Q80IXFcXyHYiUd74JO6BRBNavrXT5WRIONYQJ27t58Nv
SK+7+MMILiU7BOjFdiMoO8acOypCfpfJxkp5AZjzxi2VhsOgOWakFSex4XdH
Njb+KoGN2rHOD3w68b7w5oqxPhHKDzis/Me+HJYGPl4xVD5kOvSs+8mhFw8m
1dRmdCk/WQwtzsUUofr6V99uDxKuTXdJP7kSiI3LvE8MJGGaIrFugl6NoZtt
tA2fCBgaLTOE96PxNMKH3udOIrGAOS8m0wex4LDCc71DiHqS6lS9IxwllePN
fpRfApoef7i7hofHrqW7/2UKwfyzZnAl5WfFji2/pzgR+INx8bsU11x8HM6Z
ZVHz4KyXVTSjW4AeYu/oZUdKP7alhg6KApQbOilMfyChyLpPL4l4A3povM1m
gvovfG5z0jsZi1zvsBALCu//ARORx6w=
       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lVkYF0ZKqwqpxtZiVKQiCj9RhjJ1QzNM0iUakWsNqbhDWsiUBhlF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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lH0fxaVET5FKIkuRlJKleiLk2CqVkFIKJcmWLBWpJKHwKElpkaQs
pSJlypItBslgjBnGiMzMfY8tknZZ3vv9a/6Y67p/2/me8zlq7gEOR8XFxMQO
ThMT+/+v3or4Nwb3GmGzUFq/+B8CfOJzs9giFoo1++5XmBEY4376aKDIQqbF
oWl9UwQEL+a4/hp4CROLpfESbwnsDQi5diL2I1TX/46cN/gJM3InNT7wa3Gz
eTCxYgmBXR8dFHVp7ahU+ZCatqsfCe6F7GqlSvj9dSqL204g0NLb62s4B+Ez
T6fnDZO4H3gpaqM2Dw2n1k7TVeqERTQ7SfSHgzd321rC5/UjPfbkhY6ERBT/
TqLPdCQgm38v+bt6O1Lv+YrUPpLwf5d+JlarE8teJ/Z+CCJBE/HtP04vw8qM
8j3sLSQSg48H3TbLR6mDwuDCewS8vrqqMzaVYjRlaprvLQKTxXc/qr1gIfp5
qsGiQQHYebGaUeteI0xpY6jyJQIDwcs/rWB2IGdfz6rxk70o7o3qEmO0IyMm
xzl3Xi/SYwijQzI3AJ89+xfbE5jxdq21bBwbEZG/3l6O6UGRtt5xiyImKsNN
5EKf87FiSWfSjLEO8F5XNAWIEfC4UTi1OqwCC+6xooxKhOBe4FTmzqFDdcNF
32vtQqTNaLNGYj3Ktmfu8PwsRIStUexgnD+4eW/e3D9EQMs259TNVW14Psxc
8eQECfsEiVJf0ywM+jXaR28mUPWv3JnP+p1Qv3jRrPkOH4LcZKsnu1pwcqL7
ZPE2Asc0ejSHDvDgO/J4vZ2OEMtjTEedJbigO+y9sHjdJ7CqkhfrT7XgXs4n
5oJzAgiiHfhaGlyMbaxvWiTXA7mKLzU8NgcsCa/UxGgSJ5oNnhzQasHxwx2G
izwFuMeoYcqLdWKH4VILRng/+oqfMv/JLMeddE8l32tCeF4TJTlpd4C24K+v
xxch3ossTOkqZRiY8Gct1SOh+qg62iSOB5stfy9E8YTI12wTFzetR6XBQZ+f
5wlUWl3YqqIRh+1Fj2b/cSOQ6PDWYyKVh4PFJ2fF07kIezU2pny2ATal9eZf
U0mM3Mq7nq/FRMkEv2h+H4l8rYLy/GN3Yf7aRVzVg8DrZT7ab87XYNXh8CnN
BgFuQXVrXlAnDDXTnPsXD2Hlgrc6SW4N4OVVG372FsH67lC9xvJqBCtW/iPT
S33f4uEX49MdiApcNVQUSMLPb3Cn5uUGpKZ1mt7+ToKV+GGr59JWtD3dobWW
RulXZnSDTCwLg8ZXTon6CaQGDVxi7W1GqLj29SoRgaWzhp9n89tw9m2RzWSd
AE8mkzN+/EiBzDRueCX1fgydFD2rQCYSDPY/0W8WIn7/OiLufQuK9b1K6Owe
PD8nPbetvAsJcc13pocJ0fNjTtDuGxnok+xfv+0ktd5s8Yv13dWYGV87UyOY
QDpdilsx+Rgez6Y1BkQQaHM/4rT8BxOp1xcOLOWQyL37JrvSiQmh/OYHJc8I
yBTrxxS4voPFaRNhbhoJ5mYGy1HjA6Q8HvETvgjQvSws0VinBfm8xsH8JhLK
BtZJeht4KJzPviUt1wszx4Rb16NZGA87LVp3rB+Gqw/wxd1LcEs6IOq7MYnw
RQohS5hNsHOxk+hYIMTnrsjrCfRCSKwzSGYRBLZ42a5lv2rFekd7sb75BHR1
/0a6HqrB4sLHRgfvCLHyVt6mHat4+Cfg3LIkQS9Ko1Pe/l7UCMnE6VtSBgiY
zWw/7NceBs3Sn1cbDhBgKlw7RNt2A04rb4rNpvQgNqv1UbTbPdh4qE1d3UeA
V7Ws4EcoG8eXTzU37RZC5eUL0fqhevQtqZpr/JqAy4Wnbmb+HGSf3cN5I+Ij
NuLIaOGJZuRUOStnGgsgK3VmU53uI6zljdz/c5xA5NmB4ZoYHtTW7RxbMdwL
+w07Ty3WrMRwu8SDHh6B6TX6sQdd2lCh4KLsoCQAkVg9UL+wCwfuTXwL7u/F
0gTlaw37Kb99N5s3/rwbC1/4dOtZtMLqSIYp7ZAIv0OrlmWUtUJWu+RVrnMf
vCIyojzPtOG3iabXls4epGvsFJrZp2PSIDfTPojAr+2jI3K6j/FN3uWInDcB
m4ThK/886cQtZTWxK0pCzLB533tZn4bvjoaGG42o+5mcc48R8B9OzXrbcZaa
P8kBQv9aeS2Mx1b38jKo+9WrsfOLPYGUbRP6eQcpvcmmJ7UsZ8HK1Khpw3w+
3Jdb9/dr0GFsbul25a0QrEL++VWmPEhHkfNgQoJRe9hPCxyI5vlXDPkLQRyK
CK9rYyN2gxFDcVQAg9iBGzMrOnG7XGGdlFCIWGnjLOPDbAyvHbBaHyeCVI9R
vENDFy5OcdvlUwm48Y/e3nSzGvuufLHUbCUgkZebatBZjCIj9Q5nyi/DWj1W
FdLZaAy10zy6isqbH/k5XvMzMJb8uVvBlIByd+Oc/ot5yJo1t+ypBYFVT1f3
rfBowbKik8GWXwW4Ynp05HAnC/Jh33ZXUXnabRjcQC5sgjwjxOvrVQHE+O3f
Nu3LA6N0j2MA5d93JH/WfP/bAPu/p9TOUfmYGB/umSmXDvmMQB9FSh9WzT50
pefVCLxuuFrcm6R8brpGG4cFtWN/j1x62YdHq+/HrPdoQsjGx5wb8wRYmh3i
G17yFOr7SneU5RLgJtcqkBY09AXImCdcI6Cw9lLSfq3HGHasrQ7WI+CqnA9z
xnvQnG5nJ7+g9N11q7B+kgV7ldCrbrYERhoPdG9eUIZnnsbu95eRmGF47tr2
lBaMb7Or2xsqxAY1oVxOYTuYmgE5xTsGEYo+NfcbDTihLu4/+w+JyjMxGmY7
YyGuO0v4lXp/Jl9mn7iIgZbmJba2XBKX6bEB9OY6zF2v8/nuOur7xxOfz3Wq
Q9SMrMyichIaQbtHSDUmfiovT8g+SiAzr2pNWWEnFp1689/3Ai72VI9fidjx
FrXfu6SMQwiE5tzSMppoQd6ZPnb3BAluhF1BuPRrZNerF5+Vofxq7qH67E1c
nNzMWRJ+tRtDktbk0HAzeNcM1ZXXkkgfcira974R5J6je2VG+Ig/QNorhTRj
/oa8I0+nBBi9mnvoVTml34odjmcmepDl+2tNnns7DMNvxqaX9SHR+sGd2+aN
KNS7ncKRFMJMRyX1tlIGvOK1Dyaepfhpl1NO6Hk2AFX9MVofRnLj7O43lcM9
2oHOovL9SYbh3IJJJuTmiM7kS5EwksiR/aP2EW9t5hc1FVF6OOtgKK/PxPfL
T982Uuchjo7vZqYx0FU0t+G/cQHaDIycNVS4+Nz/q32LIoGKygLf0XUcWBQq
zyn7xIN9/sOiEssW3Ljt6DJiR4Bt/29TAScfNnN/sr9YU3n6cF2SVZ4WsoY0
f6+l9Mlt2W73Or8KqjLz1u2ZEMLNd4lLhkw5NjEefF4USflTx4HGRcM0ZLQE
DKyj8kOs20tF0u8aaFdy9DZT+jH4qWDkosfByhdt2f7WPYiVzx0qIXOh6hz/
YvAMAVGRiWeCVxs6XGa7cOcK4fEqsFqmtAW/p71zqbtL6c8gzTlYuhI9ae0b
brFItN3D+vmD1XD8mhYRlETNp85rsphxAvLWzhw+tV+rV+ItdZLNKDkZoW1G
rR/1rvajZGgHfL3/vPbIE1E8aZ63xacJbGmp/AwvAdyKFwi/GbdDVev5/vgg
ERKjLgY7d71AZErFzf71lP81B7s+/tWE5OPSspnqAmhv81lcU1QPsWF+ibku
CW+Zee6zR94gfVG10Jm6zxkxWbw5W9hIM5T06Yzqh1Ps1GHHG0UIK33nPLKH
QMRQxnR7rS4w7VroK26I4M3/ZKXi0A3/Swv65fVEOP7kmdaQMwMfvzfpKE4K
YW2bkeZd3I5tpY1pqrq9CHTps9CrfoQQ1wjjXMqPxPTHrMR6wjH9XJr+Our8
SpIZUYXHGrA12rr+TgCJW/Q8eXYjCzNF4+nK1P4TVmSlPQ1qgsNCWu3vChE0
Zr0o1Hhai3TrhnUaUUIYZhlOS6piQ354ZnyrDh8SgTt6LYs7sTryhKKurgCd
1sFyH53Y8IjplOczCFz+zglbOv0jWOe2WZxKESGzUfuAC/sdSv7+mP5OlwDr
QYtN93grDqS6PrpPF4Br8q+9z+4ynPV0qNmfQMCosLDj5VkWVLeRtpmHBjDq
4Mm7qsrD3go7E1oLH07fhKtuLbkLRVXRI4YrdV6HpPNee5/h0fu0pJxQAh9P
V67RymCgJl43kqZL8YH/+hr/zd3g+Mx1P3CPysdnttzpPTQqf5ukDtpQvJD1
T859fKDuzbuuaZTEMPfFsmli7QiRdfjW8oWLwMIA1/MFKfDofVlQQPGRt/qI
cZF4O+Y/+37p5GU+mAvdBH8OsbB5pL5/ASnA/RVhLxdacJCy2dGmLIaa5zH1
5jD3Mow1S9cfrRbCPUcjk72UiYyK65aTQhF6ctJGLv/biK3y0nrsEBEKZL1n
Rb98jw9L7m/IWCOEHT/PYri7A6rumbZyWgMobWXetd1eh0Xk+6Tlpwm0L99y
KXacjUA9ifSODyTEXWd8UPnahvV3bo9MN+oF89E+sV06NIzZ9pFO4hS/NXyO
zb3XBtZ5xtGVFD/saZmttm1RA5IP8gjXGwSsnVZJZkozwGtR4Kq1kZD1Ypgv
rMmGbv+VowJqnlXfFIdlZDExUs0IjPHgY4Ocda+beCd8niZrzintQ8Tb5MOH
g1Jgu153Kp7K/3RnyxSBfh0ivQZ9riqL4BZMvrdisGB2bZHfTONeOK02yhkN
KEPnhPb3q+LUPGeGHYgK42JKs057xuM2WLi7NZU6c6BWf5XmeJNA/uwy2+iq
RwhYoe9u50ngt1UpLUpEB/N+Uveul0LQNTQFd/+ycLBd9lzIcRI15cQf8wge
qmMv3pGLF0EhOtU09GwFSoXe5g+o+XxSonDFh96Ggb3ZL5dFkriStkOHtpUD
DfU8nRL9T1CKVHSdpPrb5MWzkn+n8cGTGE7UUmzBk/NHH22l5ldq5tJWy2uv
UDXg011vRWDOTzfzActPyP+lOf2FdS8iLpzwNiprQ9CDJTlfHEWwMVLULHCu
xfQ9CHnyf15acyH9SM8NCGNGNCepPPNvon9d6NWIkD2H9o/4Ufzgcoq9/Fsd
uGcGQztGCZgM0OXOLa7GlPwRNe4cyj8CU4oyuM3It0yQvb2fRH/duI6MURdS
/S4vlFH5BM7fwVmaKmxkBJ8Nd1pKzZu70y+xVc0Y3vk483UdCb1Nh1+/yS/H
UutPYo6nSBgMnS3uf89Fvf+PjRFb+uGRXUK//IWHkW+LZTaRItgbi6uv2vcM
Ed7qHsFHCLj/q2GvWt2KQXkf1/OUnrbPeRavU9+O8AmtQ0ZTfUj5UXItqIKH
opBv87Wo9+J2Zz8Y/VAG586KF0MmQoh961E6/LkNg+8Oum5+RlI9YoZZmzcP
/i/EzVaaiBDxgHVyq0UI3j/M0k6h/Cz0G3dtL6MEOrYf5k2VCVHZbN1rWpuO
V2ZEysQxAsNBBVsUpjjIjc0olw0U4KdSsHZOAQfqng0aB/72gHmclkTz7YLC
FmZxOZWvJmb7aE4yTfgtLfdwXj4fGerWH4KDnkPgsULquTGVp8tOa74qaKTu
IR52lymeEg/dGD6NAYfTchpLtlJ87plobiBfjH+KZ6ngHIH1rHROTH8HOI6V
EQ65beCGJhifKqmD5cXHm+f9ofp6jGXS8opGxG5xz4RAhIpDbkqaD9tgmqFb
0/ObQF+13K9tbo+xX/nUoDeVv8yTa2y1cwqRkhm6v72EgF9YwNhoOwPdX8ci
H1B85i8d0qD+h+KDpqxEbjHV91dyd24Ny8XyEynFvyn+pT//2yr5uhMrtLrO
0zi9ELY0L9VUokNak54xtpFEqpkDLU6xC6+GfHs+zyJwM3FedF8EHfOOvfMl
LUWQLazd9TyuBf43z1q+9u/C7YMeM3WpvrB6WbBKvFIv5PxyLXfPrsMVO4tj
q7YKsX71aeWm1Hr8R/LbVYcIOEn4hv5QbMX72++dJv7Pu4E0zvydHLhWSC5t
3CPEKZFtVXg75R/mE11X9Sm9Pciq23GmE3qnh26knuoDQ3F8X0LIe7g/v8tj
UPp3K/sWqLWpDLc8JYh3DVRfn+qXkmG8xM7T81+N/0v9r6phExL2DkOKwxuL
VlLzsm2bZ3ZOGeYXXlDdQ+W/mNjW6PmDB2DYIRi1pvQ0883aXyEmiZjN9spP
pvKEm7RGhSF4BcMdB+38NhJQ6Ulc2Bxci3gr0wUBVN/9tnOTQ3dgK2x7+u8/
fciHHkuodzX6KYgTb57KgoCa4MSW4NEOmM1iPar42A5RcqVF/5dWhERLziXN
BAjjfpH6nVpJ5f47g6I4ym+/7rGWim7Fz01c3Z3PCejNsabLb32CT/tWypsc
pvabauhMU3RE3zy5jdup/TrlTTeNOcKBjW3GpfEYEk++moVWzW6DwrJk3Q/+
InTLD44ZR1dDUGmtY/OO6vfiWc26FS0Up+tW6niLYGg+T+LkiQ6sM6x+O/Sr
F7z95TsTREzwYvQVkqJIDHzyMUl9yYZZTZHS8RTKH30Shk3F25A+qP0zMo7E
7/RZKrnmFI+ExSkcOy5CWM3jE+f6mMieU+6heEWEXW+t76c206FHT06odaT8
kKZRUSJXROXJk2jNGRRPrxUf/XEsDwO63jn94ZSfr3kaYsGnw2TTXsUSguJj
qcPj2WZU3zm3e/61DQTeb3DVn7Sl+r+yc/UY1UcTZHwMlP1YMDXY2Ht8dg8i
2H61HMuXmOxsGpei5mXDDNVFHvZt0DvzYmbQwl6MOFp50RKq4Ky3T/tTqRDa
Cgp6cVeoPpd37G9BNIEvW+QDzz2sR2b+0SXTAknsSQl6tlicjZud0l/KxIRg
r3ixZGZeM9T5g9+tg4WgHd1wwfz1SxyQOf1OTJXqe8cUJ+g7OrFP1TOdv5KE
2OOw5H3TmnD4vtKgSIHESI3dxsZgNhbV/LBVaBPCICNP+LLgA+h2cStWtQpQ
e29G56XAj7iT6Wez1p/i18USfQN1DdBcqSBdRaPW/+I98PXfBsxoCmv9NiZA
z+joyZTIHPjXftq7yYnALJ6W0+QFDtZ+kZ3aKuLjSlf54gnlGrj8N87NEpD4
H1OICgM=
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lWkfxg9pIjIqUclW1qSQqbHUpaJMoeyKCkNkSTVSHaNshzDZk6hI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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk41WkbxxFlmYiMsfRKI6QpSfbSt8JkwlDTYIxkRMTYUr2hsWUiNBlL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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4VekXPpUMJ1GSJqMyRbkkozIl6lUjMUWRrirKtdxLblGSW6KEhNwi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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c4lf8fxpFRklUJJaOoREmhvuKOJF+VlVBfmmQklFXJCMkKWQlJUiRl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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVns4VWkfValcIiE0JpcioppS+iK1kJKKitzJ5aMpE4VEUoPJZVQouUWR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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs4ldkbPbnUiAk1jhAdGpcudBqX1GBVSkKK1GkkZBRObl3QNCrTFZVo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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk41fkb1WIyRTEibUKypsXWTExHNUrIiGpUv0oIqSktCkm3IlsjhBRl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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k0lO8bxhFtFG3KUrRZKiIlJJdKSNZSJBH5SqQkSpGUkiWyFkqJ7GSX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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx2+SNMky4deobKUSbpKUrY9IKEqrVIYWStOkXxOjn90gNUO6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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs41NkfnrVKG7XKtWJL7U40UYrKJa/kkqgkG7qxyNpY9CuZctsuKAqp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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4VekblS5IxUT1U4QyimZQ0U+JpWhSSSIqESMSijNShEo3B4MZl6jo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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8lN0bxilvaZMkqWRL2mRpI6nLnurNEiolhEq9WYooES2ECJEolShb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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81HkXxz2upbIjcqlIKiSLtpQsfWgVSRuJTWHlLhQ1idVjU2rto31S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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk8lWkbPhVROUYxkt2xfKQaTbYiF9qMpU/IZJSdtOEzvoqhpAalhEIp
SyJlPVpGDrInuznH4djPOe+L0xilGInS935/PL/nd//xPPd9X9d135eGT7CT
/0oajZZGnf/fPK0He6bsWuCuLt4+vYPEsJX4nHFbK8SkVyUuPyQQLJ16eH5j
F+xLNpjYHidx3SSBnnn0DfRmVz68NylE0kzTOvb9GqRYjCmRxQREXaGmXtnV
SNyaoaZsRULSITxSebgLBnMxi0NPheCdfdIaG9oGj51j5az3BOzrn65t7OxF
xjZWFSNGABFnf9DvB/ogypDOXLYTonBisOBBJwcabsobpI4KwV+9/s4BqRwo
s8wK//Ym4VgtNu9Ay8fgYb2IOz9T9cksfItlslGsuJAszxdgoUP84PXodvwa
7f5fmXQCTa7DtefFmqF+ctz6qjMJU49wVtTZIaQsdmR5lo/h9l9cj+q0Xnzy
OlFiaU1As4Axs1PYiy/nbkQVHx1HX7XMJu/hXhS67lfKsxci0Cf02e1MDtTk
PwvjlQn0z0ywGt8NodpLsn+oWYiestJJi9f1WO+XJTcSQKKUKMvJLhjEOSNL
+cBIAvTSIN3G8j7IzYpMhZoE/u4JKLPL7EfdhLBV+74QojBjjxveHTD6d+l3
0nok+Kd9rQZUkvFWMlvu0zESmxquHCt27oHm+vYP3HdU3F6j3326ERY/jqdL
8gjkSNTpRfQ/Qik7nKVL4SMd/qhou/WfeGWieeQ7YwI2FkrrFjTyEWJ4mcf0
ofAY/89XxSIWnt2O3TuaTCIqOs/1XToX6in7Jm33jcM6yKrVoKUTNQExPvFM
Ahllnz5GZ3OwJHFQk7lLCEkNkU2ECRvdK+6EfO4g8deGf47WF/VhwKvGSjAt
BMNoMelkIRefJ3fOmiYIcU1gpFOXw4WfIHTFTLIAvaFmSxzxXJyPe8Z/6Eai
rr+okPGiBOYqH0ZUTEkwFjwrpG36EShZ9/fJxwJsnDyhN/OgDf73zSVqhwk8
T7Uu5SuxgbkPfp6VVH3jUj4F0m/wQ3lJvj0Vh2R5/aXQ1YcL+5rajnApfvS/
jg+UDMCxYjjTLVUAWs3bke0J97Hq+BUB15OE5aH0eZiz8WencEGHRSCGnKqN
4/bDTvGLmOoJ6n22o2fM1kFUmcWuXZQYg0IetD+EDKH7SP7Xg9Z8zCyNil7j
MbRWLDDplF6Z+XztlrddcF0hvkGG0o9M7P7GCtt+mAdnMuceE+gI3atAj27B
3qAsWb4r1f9hC/t181chnyim2u1OIiB0Y6rSmwcwdOAsXqT4HIto5uZV9uD2
8Can9H0kTvk3nJHzbkWTNtelj5o/WsnL88e3eaFNyyPciOrnYL6MXajYIEwt
6C+uHefD5fTDonlhG87UBDZW0AmsdtDSMNceQruNwP3yHhKvJjQT1e9yEO8k
u2y8i0T+8M2Pqm95uCD++LrJCwJC5y8sFeUeGGzT13zMFGJl1DcxDXo7FMWm
3nwYJRD9g4XW5uAwkAqOZuMeJDry8ho0s1vx5kPkL5GrCEjOJtP3SNTDqSLX
44oCCTkZmoRqMw/tFYbGK54IwJZd6OY4jWBniyhSpMGH4aqRqzS3Xtxfqy27
43shcuQGeXX3BjH1e4NtfRkBy7MXdjc/GMDT90vL24wECOxg6rEVuIgsrzTT
mBMgLXsgc1ilG1ceSdgaryTwbirhgJYbDz/ssjImBgRwmTeNG0IrXlbxbkzL
EljTvsYnIp2HgKmoDNNwAsxcfYZ8dhMiqtpoMfMEnPy1LjbcZmNRaetn4V0B
hL1xnQ8n++B3j08/4cKHfdC7a6fuN+Hu5dhbP9ZSeNxjlE2a/wbVtCoXW4qP
s7pBBspRvTgg714hIyfELz7lZPhULyZO5O51uslHTuum0ZNJBYi9luas6Esi
D01bgvv7cEumgG7K5OPxOcvZ8VtM7IHjrw22JLR0tEeK/FrBKH94yUWWxHPV
/TadEhxouXFMIvQISGXtVmCefI25lJsZUdsJVCWlJJ17xcW3RV+pjD1CWPP8
h09v7sCnR0+ftopR+UJiNMN21KDLiOZcwaDm4ZmH+PKBAXioGX5H/0iA45JV
Qr7n4GV+wCfbAgFijMyv1bYNQnmVisIhpzGEHQlKuBBegczNm1ZqgkQS/dXP
7G42Gj/6OLB+FaBrLbniVj2Vv+Lu2JI0AZdgkY0+tU9G1BTl7Ck9PPXbsBhz
mot3OmdMlioFqCsMVjlx4y50dr50OE/pydRXyv7oUg2eFYguaSuSmDBj/bE9
rBOJfof28FaRCDk2/L1aSgc8OREVy4UkvhScMtfb0AxGPG/3gzoCrgUT4dPH
ueAFT4+dOUTgXEKGw6h/HaLsJWRUo0mcT2ve/i9uD3T8rQJjLUh0GtctVyT1
IVG+4HL3WgI+hs3KT7SeY/TqNjfnUxTebZlbF/W5UPl9xH/6uACSjKxa35Q6
hC+8ybSLJRHmrvZbiy8HMUcs89JFAtypXZdN2vXB2jl3+rfDJLy3fBQxzPsR
ff7m0rIdpf8nIcvpx5pxa8ZKszmOxJYLYj+tCXsBxZmpoVJzEup9NdvvzbLg
3dOTFEj5cwxt7m7k4SbMqosGleYIOM4Vp1zAC6hPZ+o5UXrTXcPIKX/bA9eh
TddbBEIohO3z6TccgRwpqypZM4Kmt+NmvLheSMpeVC7mCvA8e/lGZXM3zkbp
XnbsJtCQ5Hl1dQQbFlKs8tQuAezlJ1PV7OvRHlOs8ZlG+ZNsbqbC7jLErubJ
0YxIVP7UYD66rReBqSe3rvmF2mdF4e8jbnViKsSiupjyx/gnufIBDvXQlK8s
3WJJIl6/xUk1rRY8eadyJXESk670mcwjPYj2O7S3dZHqx3f9RkZZIaISlUM3
U/vPYPTUjKUlG+8v5eldNyMga1yyI3mqD1++Xto1RPG398tC8gLl/1Wf2Qmj
cgSKD868nvmeiy1hGqMX/xHAa6XO9Fnne2CaHbDJp/zZYHbtQn5oBwzsjQRx
1LzqerSS8RLUfwluvM2HhPCq/mpyWDcd2ksdNZqUPxF//HM9R58DSdGO2Y9f
qflK6LD1LmtH8Uv3vIw/hfgfUm68ZQ==
       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns41VkbPYO+oWFKNySFzEwoRCOTzBIzZlCmTE36RO5FFEOSpNuIKFI0
I/eUWy7HJRRJOhkhjnNzHOVS+ydJLnHQGPXt74/f83v2s5/97vWud6333Voe
Rx29ZVgs1nX6/f//x29mgW3GAlxpFgXfGiLw8byffq6pFas5ASKtmwQbWF2S
ghUtmCsm/m1pBJtWL26202uHqKrwlkMrwV/h70ctn/UgKaw4VPsNg/6bX9ut
k3RB7LfxhxfeDExXN9tHs+tgkp1o1h5IoPnysJmbKBcRnMPOAe40/rdW/U1T
PPg+Up+d6yXIzmHOnd//HA4+4YxcAQPtGJFR3E0hzAxKtd5pMAjZ8Ul/eoEI
Q6VJBtqLGBhGlC8tcxZBvkWvt1qXQY2x23LtU3zMrboj2fiOwOLr6K98G/g4
MTwVy5FlwHJdbvPHQAGW9PgM/u5BUJuemGysK8TS0bpvJR8IDk6MmZc6dUJQ
7DzV0EZQl1ib+t8RAU65erFLRwh2WDTHfTIQYbr72z9dXxMEe1q7Xf+DD43Q
k5qRfMqPRFZh8iQPF5Nm5R4JCfJSgvQ21ndidaRK5rVpAnmp1Vf/FknAjQtU
CDzJIGa1adCcTDt+yNz8ti2bYHE845IY0oS7Vsp7LsdSvsY2aZbXFGGkalVI
K8XbJu1S2Mxuh+rk0YyBOwTvD6w5t2mMi7jD6jPrRARZ5Jhu6v0cXGeX7VxI
+R265XtD7pkQDVecXr1YwODS4l9S/jlQhkbVDRafeRHoKJovmLHhIcztstFH
MUGvi0FKrUoXtEL+1v9Mj8Et9pERsxkxDK+pvyxyZzCbPWrvu0GA0LRIxS0s
BrYz187r9PXikr1VR0o3A9Vn0d4L2SWYzc0NOeVJ0JRs902miIfy+K27X9F6
xJ6tGwr7KMBe6wy5OxTP7nvTE511fOhkx46rvCfw8w61fbtEiAr/gUg+XduK
ZYRiARemimo6zRUEitZtByDtxP5hleJ1lF9LzTG7/SdSseNeJVFyIyh0mfa4
elcAjaWFXfY1BOPSgfq8+S4YD9+dm9tM6z9ZsdnBNAZafwak7j5Az/dNvNXk
V2MkUPQkyYfytWXq+C6Tx5gOPfsyLJzgSu+g/d/KT5H7LOecEtU/W4ZvZPN7
DRzLZDSjDhNwPurWOYayIVBdn+hH+VTm+rZI2zqx8CQ671P8mqp3UWTIx9PS
uZeXqD4OvVw3r6xVCfOAbeti6H2WFj05uYaZ6NMOHt5F8Uv7u88uCu5GrPH2
RZl2DATya+wEha1wGtP8sS2VIK2nS49d8wgFju3OBUEEAqe5hKdxVP9njAoG
aT0KZ37Zffu1CNuDrSbUqR8ibJ5Ee5W34Nd88UKTBHrf2TxvvcSr2D36Ju8C
zd/ndXvf9ohWfPyQsbsinoDVOlA74pOAyhHNbf50383YX8Z1cz2szLoftfkT
7Bxek2O9sACWe7fIf6D6WvGmSmi5gYu1Ik2fngcE/edqEwsP8jFR8kIxl0P1
bkzi04v5sOz/WFz5BYOwzI60kegOSNQeZO3PJ+BKo1TnQhsx795aFniCwHX6
dELWml4kLGhXi1UYRNu2tckaqW14LHbnraH9aMXaHTeO6nUi2/ub0+9o/M5n
R6r1P3VjpjrEUT6OgV98XpCBAw9bWdFMKSHgGfPS3+3rQtU25dzAPQxWRrOO
lWjz0Kfifiy1i+pFR6J0MUWCdveo+S+yGOTLBv+seLANf00qHV6TTrB1V5TL
fFo3qiLZYbErGWTVbo8suFELG/UbMa0BBM4lR/ynvxfC01x2LWuc9sMfBfoP
d7XC6tYJ/54yAoPHwb8xMi14wbZkn6b+Tl96psiJ0wmvy1+FLKR8LS6Z0tX+
5zlag3Ts16cycFrSkcsbboSyScRDbiRBUcn1RfJVrSgUd6qaXyWQ1ftkVdYo
wb1HWTJvfRls75rckXhSiIzB0szH1L+vJd9tyU3iYDzBsenhKYKw52WpoiPl
4HgZVg5TfY5bVMQ84Tfg9pBRbXYIQYPa8b9KHLj4PmT8SUU5gekeP2fzH7ph
pbh8oGIjg8D+p+4mkd3Y72x2nOvHIKfPxTJoiPKbEpbycIBgz5cCi5O0X1iq
rnz0yoFBelRsglhdAjgu1f0liAGbs6zUx7oHO22tP85GMLgQIFBwDuDDvdBP
35D2Qyf1AavE8laIxpliW8qP22zA05T+LnTtE2dPeTLw2aBhniPhIfnmVTNJ
H9XLu/qtSzOeYcUHDa3nlF8B7z8b3weXw6bPY2+QN8Fyk8+5AmkX9q2XFnoe
ZeCmJzfm3HMZUb/VvT5I9Sy1Sp+t3SWBVYVr5dUHDNadNhsYNucByYKCizSf
hhVqRgjMwj5uUuQ+6sfFaY2mBi5cqG7N2Hkmj+C+T3d0681OrJ9YaZTNJYi2
jmjsdhDD+nrk0z4PBoe4k8taxsU4cDxJ3oH6sXH1PdHnlc+xKsb3glEPA29/
5QeLfuIhfELH/j90frDO/TkpPhQOzyvnq8wpvjPMYAHPyRse80YexnR9P5Cz
sXE/H8/rXznaKDHQnBWpNM+1wU8pf8iQ6iE8zTPeWdAMY2XupW3X6PzZKj1h
ot2CD1O5MZtu03ijsrllY7fhIh+3T4X6tftUocSusgPNnVdbZBppP/hXKcxe
oQjynm+cYuh8sXx4Id+u5T689FkXhNTv/3IkQfpf8tF03EDmnzGKN6zifM1o
MjglGwLvUXwjyoHltocawOa61ZhSPVldmhFEWj7Eyr0PKuqPEIiDAoaFspXY
YiuICqT1Yb11DBK68nFQrSgsrof6z1GhY4UPB4mvbLyqz9B66i1K/1lOAPXR
g7ql9H0hLV7y2s6pECFvG2LlKb6mKS/z8XwBIE2316J4OHHVYaVOPIw+OMza
VUBwhKTfi/Pmwan388YRep79XXL1/HADLOWO1T+h+JbV+CTtkLCRES6K30T9
sK3brEFN/m+slVFpvnORwP3EkEKjvBBXjhp1/6pI58XMZwqDv19DhpFCRyrN
tzLfpyhj2V2cb8j86RPNJ+RyHpltEOK99KYZVtH3ioXWyLLJRmRoHDeRhBH8
D6LB3FQ=
       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8lO3/xSWl4pFSUkkIxbfFEhVyhLR5bEnxiAipJJQ1ClkjZY0WSZGy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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41Gkbx6USrUOsNGqTSg6bJq8kHfhqtI5JDkVyikWRrEOlSMoWYkO6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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs8lOkbxqcDpibksJvNIWo7aAm7lB/VNRSinHMKNTmVHIYmlCjRiUiJ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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4lVkfVYlMSBQiZaYp3YgMRWXJCI/5KBUp5JprqZGKSJQaZuQePiSF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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lf0bxxUhCZV6RAolVORRRkkfq6IQJSmKkFURT6FCaFmJIgqFlEJW
RPbIXucY51gZ59znoCEyUtbv/v3lr9vrfK/rM96XpI3riYvLOTg4zi/j4Pj/
X9rcaZaATCsavcUz0rTYCNY7MGjlWIwDK4Ty5y4QGHEy3xxZSUFPuPuvaQYT
wQksmdm0FgSMW51hTrFh/C53tVxnGw4FbEndZDSMrKg7MbNT7/BWyFHtLPm9
RNlw13wsHeO6SqMX5BlQfFHj8cCXgotsBRv9HWz80tAqdpCtwufOs/uVFAgk
B41Z5mV3YBvtzITHuhEs2v5uc/pNQ5jsGrVSUwbU/IczNZ06sLRQpZ/oPoKC
76ut6A3dEAmb89mv34PVEeKv4vhoON9jNpPvQWDxQ9nx4jNtyLek/rlxgIFZ
uZSB7Wp0VE7b6/7wZUBkvQp3I4V8r7DREu96FmD6wznxEAV5IofGHomyYRMb
7HlwoBNSq+j9DfODsNOl6qhJl4PBmJjm0SZw0ir5Y6FRJ9z+yIRMB7DgMfTm
k8IoHecNVC4H7h7GWx8Rw/ANuZC1zSmfpjJhasS1rmxvPmZFzyh/8yQgUngg
yMKMir3PZ5XCn7Px2TXix5ekFjj/NXPZ+57AXukbi7ZK7Wi58JWX4wQLQuEG
DhTzVDx1Lp1vPE3AUn3JI5+7HYl3iT1vCAYIKYU1xn/LYc9507g2iIB1/fKn
m7c0wyLUOc3gOwOrpt8lXDbth6fe/f0RgXW4p6d/pS6EDsKXcebxvSFc3b6Q
YnowFS37Jq24cghcO+i6dLa+CvxrdjZ8+Umg/MxP68WYGHSvOHPM5jKBef/l
8u4OdbhQsqukIZqF3RMFR5s0cmH+oeHP7xICmj1tYgfOl+DoL4kJxkkCtVwu
GpfWUrG1/+VV1U3DcJS5cj7oQRXcN2W2smMJDJbzMYOXOrDLzfrKtyMEwlYa
Hk+Jp0JCrLDlXCkBRe/+RNOMYnz3VeEceE2g6adzkOxgE7Jv8Xo8ySTnObQ7
5KxmAwROO8wSlQxwLHZHvvP7hO13M8U9WQTO/LPE1gipgcKvDXAWZIGSmXCr
rDQPHGsr86LsCVAoB3YsLRVjrK8izayYifCrbX837ynHfKPspioeFtKdZXK6
s1vB23ZnTOY/JhRvrFQw4m5EroNeustaAn5HVY/6TWfBJ+dHVMkAE+VMfavq
5xno0qEHpjgQGBfU/LEyyws2y/YJLJ0nwFGsaPj++SdcvL4k8K2dwNAA/YFD
PQ07NjOdPO4NgDvVfW/SDzqqDqXVFB5k4dzXsUG+qCKEU05W+9cSsJhf4JPr
a4J5WPTvWFIfM/5aHtFjNWBRop++0CPnpcUr1dP+AsJuWWOENfm+QJ0fTxxy
sShjr5R5idRXvyV/0alMzPLPhj05QOrlsfaA26NYmE92eLiS/lFOK+26zaBD
iUdGIi96GKVbJJsHX3RB6tVWarHpMHqOJT9Yd5UG1QD1+VKxIeRek120mWkG
Tbkgs3aKBbV1BXtcr1Tg3sdumvs2ApP5nTHf8pux/lZ49tFeFrx5wx7++VMG
5dkbCviHBfuqju3aIW3Yv0E8Tp1vGOMfWM2F3xNhLO/WqGJOAF+kTor6UPBk
Q06AvzoTH0fFlZM0+hA2GJNkfuQL4u/mhu70bQJlMmDNNjM2TE0j7aIciyCx
VUJhGY2Jhg6Zr/lreuDONR8YOcaGygvB7aJeraijf1jFlmPCQClyP9FJwZL0
xOifdQQc/wZtzGvKQ/GdhqksfQJqhu6F0dwf8WSkXub5V3Kf4ed2iRo3IMA6
pOgfHjJfZHeKT5VQoWvwVHarORMW9cuyX7xtgd18ceU94RGMUz9zf+YqRcXX
088O3WJCUE8t0eRgN1p+fzzr9oTAmx1yx4YDKDB7rxm2h9yXgePdhed2VISp
TzTKF7IRKcjhNyvSjrHTrLa9pB8lyyfMR/RbcTNM8fqfuCFkVSu47XTLQciF
I1qpJgRo8fePD73sRvtu+rLTd0bw4n7W+uV0OrbNNXkFy45iQopvjZ5YKe7L
pin1kvl7/23NLUk5OlJfVt47SmUhQYsnhj6XhuASmQ3zhgS2vTptGHS8HC78
15pu8bPg9X5Swrc/B2ZvtZTfLDDR1EUT8cquh0r3xoA4bSZiP4QdvPS0D8lS
irwRG4fg+Esr+e/7ElTWi5juLmAhUtlvK89QHszpy8dy4pgYv/dcIOxFC3b0
t0tmVhCY3b32Z9yjEmhI2HG6mhL4PjOyn6nWirg+zXVFGQRKhC5eXZ1fj52a
7AiVF4PYNZCYoxFMQQF0Vz28wsZer61tNdbNMB3bFJxKfp8QUGBze6oQX/e+
epjhRMCustbJNrYLzjvUhb2bGLDXmo3m1M6GduxO5XeiZP6NWsv5XuiEWFBj
zZgpG3XKzpKzGo0o2nWhWp3cX7mlRGttRA60z6/auOIcARneUEphcA3CjgZm
OaQw0PvvbtXvVnR4nOfasiVvCL8nu1TG5nvgdzlE5+1TBsqddt5WC78DITVF
th/5vcTObCfD3kr8LqcLu/1ggSPvUWk9LRKbVq6ILrMkwL7v8/aUewPGPONf
epP5IuzlKrDicQMCLz0Z6klhovKkXYBVeieoKSKhp+4PoOceJ3PVyy7wO2QY
z18bguapB1I10mQ/PTxmMGdP9pXjT3E5Sg4M6t0rXMh9PvVT1pGf70BLrEbF
Ba4R5FCE+woD6Wi1DHyaHTSIAsOA+iPUathkTK7W0GdBNi3/9+SDVixnrrPJ
mWZCV1ekaseHctjwfbw5XU2gYFoxfbi/GG+zb+yM2Ez2gUGtnpRtApKUvJoe
qpH5w2k7nH+rCmYs483yHOQ+XJJ/3IrtwBT/rqvyuQRuup+IMwrtgMGXY2K7
/xtC4MTRF4LaRVAc7ov3TibQId0UdkWagj7qjVhJaRaKmpIijTM+4920yb2W
jQQeMp7GXf7VjoRDkd9z/2Fgc5pJZIpCGwQ5OZ/5r2eCY/qWbOmnJsi/LNdZ
4UXq/XvjrfGIevhZZkcVuZF+dJS1/qpch5GEBsmUPMb/35URMJ6HN5dqeU49
IpC1qbkxPKwIt0eMhk8/JlB6XKf4BqsCKedV5nVJPjDY1tiwK5sCl5HH9A2V
bJTbPlp8uuozmoT23ool+/C3kRKn1/VmvEg71YvaIXz7qPBm0roTURytGxQ2
DaH460OKz00qAoo2TujvY0Hu7YsH+7b2oFir5telgRFkPMw/8DGUhn+ppjmn
ekchu1zKOKi1Anct7uZOuhMQ5qlwLNxExY7kEZuGLQTSO1YeZg9SEPb7QeML
c1J/qZ3OwQsU8HmYcocJMTCl3SK57P1n9LVLfY3QYiKhM5qdqfoRXica9xiS
fgnM2OvnepfkFzdNn4RyMi8n5MMlcml4UxKXE/6d1GtrzYwAtQhCjldT+HaQ
fc47PxK0vwFCR+I+M++R/TJQlLo/7hEOWNZ+fUrm+fnQx6t9pzqx+mUor6cu
AwVm5o82rMxFZGWoj9xOsr/WDAWskqRgvdenuutk33Zeow1ZC9ahWEh2RmeS
7NvLvT5CroXYz1gx8+AmgUvO8vy2URQ4ZW+ZDuxj4+wXadGjUaSeNblSeIRZ
yP00+trqXANa2ovbR5XJ/VZwWwTtq4f/1DXGvyksTMQO8Tv5dQMGGTaikww4
PiyetOCtg9/4m3DhPpJ/+tRd1q3uhI1iPF8O6ZdAYW+lqmsleLjnsIjHv6R/
L29+H5IfhfPdmaeryX5/neZivLyrH0Yqpz6KkvMLL7q0ttm9Gn94ltlx6zNB
jIyKB4Zmwb0kd8VHIQJ1Dq4rxduK0BlbwJA4wILBmyWTVacoaLs9TqNeI/uo
Zv3a2921kPDf/crLmQ3PRC3TvqUK8P58kitK9sfoDas4R782HBRNP9B3axjW
jmLnCle2wvd07PjvmiF82XtBTFSyFkWS69K2RRDY2XfHGF0U7PcZP8IXQvKD
/M8jI/GtMPjcfL0jaRCDe742is22QDDBrf19KANvn6hdZuxqg1qzcf0HsUHE
yD1dtDmYjSYx4h7I3++ofNP/ZkwnnC4+OFOUSuDX9RTbc2s60CV81smaZxBC
SbqL1XNFsHQ2SbNVJMDLKX/F6kYjDiqv37jn2TACq3Nd1/PUo+6h94w4ya9Z
1HKlLnsqBu0437StI3li7k+vlXQtVtQMpVc9ZkJtcvvNxOoGDCjciVYzY+HO
29FL1kc/Q21V0LJWEybi61w3Ol2jQrKvoorgZ2Ib9byApRIF0fofAobSGeiZ
OWUntZyGzdZn+E71MpD0X0mt9TYKFOlVS9/Je+ewjy6Xh2wduAd+17UVkf7I
syjbYV2LuxesY0x0mZhbOFZ84mc7Vsuc25Ju1I/wL1cbdBdzMD/1jVedzHNN
iczntEIapqWPuOf9y4D5op8rj2UzNkjEXPi1gok9366zO2+1YZdG/F2pAjYS
xtJ3FxS/hNfBE8X5t0m99UTpf4iOQkFns8iJ/+eRhZJ/VkkbpNxH3co4WTCz
aM//1tiIVDmPARuSR6yjKIJu5ztwdcY6XDqanF8fL62J/hpdvOFRqgdJfpHl
DznwoRT9nQvDLt4EXL5ZGe6KoEHOvkrNO4MNs6FG87G6NtDe3whY7czAePN9
dfOOBETG5039sSHgdTmEIyutF5mKxjEiD7uxprpOetD2MyQn+i3OHiX/X9Jv
5fvBDXDdXia6ch+ByKBSwz2uNUjoV5i/o8xEqrRyjph7Nwqkg59p1w9CU7tt
derVOkgrxbw6R/Ko5ffL0Q4i/WAkDR9ONmmDF/vLmQEa6VdvFQvFfiYkSwQX
BIS6wZTw2xglyUaTWd3W4xwUfL+49fjzxyzoBd5+3birEuPXzMO2urDg0/jB
WrmJBoNVXIyU6lFovzrt7by9G7u497lYXiT7O0N4yTfkGaLKss8ccCb9MKUd
NnW4GRL9ib39HkOQODmzmFBSANvElTUSk0wcqAjZ8aeiD0LNWi6KYTToXdeo
dqNlobg34sYs6T87idrpEx+aUVKj+2+JIQN+MfWd6fG2UOMxuSpsRebvyUr9
7bxFCNzz+bT/XgJ3TW6kqi2Uw/LYs8xid1LP2a8E9igkw6791y8ayW/PTT0d
1O1pcK6S+TFN+v9j4nv3H6U05AhEl086DIHj1yVToXvdKL8gXx/hwUKyAt1F
cK4Ls8K1trk63fA6xug/t7EVhrtPTgl+I/t2dOlP8UQr9h9aTy0LHoZm9jTH
Z9GPSBmc+HsymMCW4QiX60JdKK/hr9a8Nopx/q8ynIGN+N5br7R7lIVilV/7
nsklYu1NXYakMblvnWtCd0apMDrqkjMqxgZHLa/N9BFrsJ/e3GpHvvfg5rpv
5dxUbNN5zNMTyYDumqs7pkTjYdp7aXOQC6kP1zm51QkNmBGTDD9UxcbbWfUS
s8VPqAtfENUmeX39evba9jYq7KuDiPWjQ5i9ONd2nk4BvaSZf5PcEPYubH+f
bU/B+VyZe7zkPdisQ7l3I6EH3/WKhrk5R6ByPHXbvHgFtHeo6X/RYSGjxWPm
ZTEF3SzTNyvcyPtNyVzRTK8D7d70tQtnSV7Uj93/SrAVApM18s0xDHirrlJq
nW7CwBYLzhkKAyJVxhllFrlIlxXP9lQloOelqC0TVwrVYhuRsAICb2c0eNwv
V0GJskV6xpSJ+fvxqkeOleCNoN8/LWQ+Kjh2P3cuaEfX03SeP/Ekf/1o4juW
9gGfmidvFf1iYu2Q+cu786/x6uZAyYPrBNoPKsdv5CtFcMSouUkUE9YCbjdU
v5ajaWQxzVCeQIONpPaG9BLMxP624uFiYb5p7Yp5uQ6oiL9efTuUBbbPObGt
XzrQcO19r58NC5pDDqr6sd04+23ItJbUu4TKQfsr5xrhfS29iT+d5KFvx37M
d9lgmRvz5ANyf5TDapOxq9/BvaBjTX4SgRH/Ozxd0XXIihE3WuZF5rvOf9Et
gvV4l6Lm99KViUiPikveR7qAU8erCm2GIVBVOaUk0kxyeHbD1CMW7iYHpQz0
tOPxubISOSYTStaUGl77ejzPO5Bou5sFIbqhR/tSF9p+nR2cI++nSzIOGQLx
A7C4WaHBB9Kvnw2tgrIo2F6QmN0sw4BHRA/n4T1tCELO4+c3R1AVzvqQ9t8A
ohIkpbtI/tF8psKjwKDioJUdo2wzG4IFOny6ye3gMv/70j50GLXSDKd1qp0Q
pIjXW5H+kJXu6vJ0LEH2YRM+I5JPCs0THFPuUHHiiZYnJZsAv16m0VnfWkx5
6Ux81GRiplBtSjKmFbP1TXvPjTGgZiIBca06mP9zxtcjlLxfJNw65rprYOwv
/TaV5FNFFe/0qtfJqD6+1taXzPPw380qzOdFMO70va5B8uDmiGHParRB1Omq
LVcEA8Kt40tyg6W4ct26liJJ7u/S8gscKpVwmr+7XcSZiWHR/n/pXO3oKOaj
H/JlYZNfWsVDShJ+0P9W3SH5Q/vETyPKiXY4j++O3/ONAQOTDWY++W1gUjs2
/TUi4L2rPM/nQT2efHFw+DFJ5smuFL4TqumQ3yUllEzqoyt8nfIJsXdQUH9Z
dYPss67KENfv0oWIkJ+Zqowi9R90Skb9fS8sxptDpUj96XqnjMfJUsEXLcId
FT9M3i8Cd3QUsxG2MlsrfD+BpJ/b/qsLoqDHKcLEs4yF0L1XjdULaNhwXeFa
3RS5zzfi+19foSNJOT1iyb8fnlzyXe9s6yGRIvtlIZuNkVSP7Z45tQiUKe5m
FTExu9AmamdYDat/Uv84dBBI9ToWfE/+MwZnKntfhTMR/rppwiexCbnL7RpG
Zsj5lcip+t8tgF7GQ8JHiQDX3Fh4j2gDjqVOZ9MZDAzdd2vpv1kLDjm9y2sm
GMi67Csguvk11FaGjH0i58VwnJ1fOE3yROZje9omNvy45QdM7Lxxf7i5cR05
n/LNzWENfRWwfN98dlGWhXGbVXus7mTAwKZztoW8531Pmhdm/6VDeYz7cm8N
yVfjZSa+qnQ4isVVVjEZ8PKpzxmQL0LHX48tbuR92Wd9SNeBKx+eIxGjI5vI
e1T79tJ2lKN0TvThUXUyb5wM0o38qDDU7QjuIu8vOxsX5aeW7eD7+b5BI2UQ
/wOGeid1
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlns8lOkbxoe0TkuOKYki2pWi0abD5JrVoBxaOR/bYWWw2ayUVkklRCy7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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs4lOkbnmIL1aYtrZIkVErlVD8V3U6L2iZyig5DJHLIoSi1CWnZRLJY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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8llkbNkKWShMT6ctHw1AYS8lk6VJTtmRsUzLIWgpZohJJCU3ZQpHI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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwdmHc8Vv//xmVmVlbKzKiUUEm0roSWCFFoWCWprJQRFZERZVX4lBCVEhGS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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs41GkbRio+OiqsKFskSsmWSNtNckxboSS0JSRy1nFpK5MtZNEi1FSi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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns4lVkbxn1IKgyF0ZCcNU41JUnlFiaFZCvFDimUUEaZGTNTQoRyLBWJ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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx4lCCSOkqJEZWysx1a/iU6FSVIpRI9mNrciWBilJC2YwsoVp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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k4VY/XlaR+UiRJSoYoSmkwJVqmSlKJlJQhY0pRxjKLQpIozYMxhCQR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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81Wkbxk/yTou8kWQtyyA1o5QlEVcZRcaQIhRNCQmTZqKxzbFHRSn7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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs8lOkbxqeSEOVQoUUpRYkiQ6S5Jlq0WaesVYmIXzmsU8ihNNvJFpUs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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns4ldkXx1VDaijXRvNjMHMooWmGSoWvoShScptRoeQ2iFMUIppEIUVy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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3lYjN8bxlPKtz190x5FKCUhFF/utNCGSpuEVFooylZpkYQiWoSUdiTa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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81XkXRpiKKZWtSfYkFUXJlkfCS5/GHkU1yBJ1qRmhdGXL2EmiRC+l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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns8lGkbxyml3ZDaWLsqp0iW0K7ToJ9CvGpRaYxz7Cg6rN6yKCmnpNK2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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVln08lWcYx7GSVVpeFsVKW+UlRqi8jB9SSea1zKKoiKFREeqQRFQqlIrW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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4Fesft2UtRJakTQotlCUhPkKKhCQhpJJECm1uy0VZyy2icqXsSyXJ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVns8lVkbPaKTpLtc+solk+TWZRoUzTrlFErijFSuucsUUWiMiEoYkpIi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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlWs4VekbxpGMSpKkRpIzTZlBmbZUtxCmJDkNsiNyztDBIERyaGiXMsip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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lWkbLsJE0yIpNCUkjOpopGLMJcnIV8qWaBFiUrYsM5aPVEKLr0i2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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VO8Xx5ElkqyFVkQkQlkSfYiokFYpvnZJJBUpUSoJKaRoISWJkqzZ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81Vkfx5UlJJFwR4sWk6RRIVw0H4ZKuWnRMiGhLDUVRUaPG1kaNJaK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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns81NkfxifNJlbKpS2RZElFZRHa8PjZaVxWudTaoVyqpWxitS6lRFEr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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8VVkcl1RCQw1FJGVpUkM1pGnKNyohDUpS00xSqChk16ZUIjMkZZsM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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHlYTO8bxkekkCRFCy2IkISEpLuihHYh2VKJikqS0irRhva0KSrxbdMi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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81dkfxm0NhivUSIk0tqtmlFIhPJU1S4ykLHET6WedJJTENCX91FhC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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lekbxsmSZmwzFbJEC4oQSinjsqQxKOUnhGQXSUTaiKQMMxXZWuxr
1oxsyWTJ0mQ/nINDzvK+slSEyjbl984fz+f5736e+76u63tvcT1v5bGGh4cn
iTr/3U9qzuoIZ7dAUSo684klgZqTl23sLXtgs0be/5Q7geALllM5ZQMw5/to
xrt9DI75grpaGb2gKw/JCK8ScPzzVNrgOAMNgtmvz5zkYEekuuVezb/B9vrl
f75HSRy+zQjfb9APBUv60MZEDoTM0gNCpqvgZKF6iW8niemmj25Dnj2ImPvD
fUssF+K9lsb+E6VI6Hjq902fRJmPuk0nqx2HGsvcBGYI9PfO69lfbUfOaK36
Io2LPQENnvQ5Grxvy8sl6xFw9TaM89tbBqFkE4PfIkiIq8TEyH4uwaHL8UUv
T5GQqn9d28T3BlaXIg8V53IhywmuNknrhPVZjf73MgR4Zt2eut9PhfO0eLKl
E4lm2aCxfP0mtN3N7T1nR6Luen129JYe7F61qv5gwkXRscLfXpoMwdA7q+zz
CIGXuhF20R9aENFQ4LnnBvVeS+sV46g6TB85uE1dnIS/7fybVsU+uMr8uDVn
lguFu1c6FOQZ6CoSChH/mY3FUw6SPR/pODjXbhcCDibsVJi2rHKItnH1A0VI
8PCQ5ZsWXLAqGeSifJoEGSF7TyarD15q4W7i41xYy4sX3PnaDX+NsNlN4xyI
fjkyRPu9GadP8rLlH5CwG1LKfVFci4v+zwsq95BIkUpQ7d1Bx/07n5vtnrJB
KipseNrcjMS8R38HfCTQ8Fnd8q0PEzbJsRIMIxb8Ur4c2yfXhacbdHS/S5No
2DUq0FFSi5TQY9ODhQTY5m+CH3wbwDnOmYdXHUns9uE2uC8P4CfBvaqnV9jw
VF+6IDU4iBMaCUYyTDby6m7kPRVpQdK3zidN6iSKR3Uls1YrUGXMHqqQJTGT
XWaZeW0EKidbiL9eEQgnE5WTaY+w/kIp+7QNNc+rdrYCxhnQ+S2jnu1Cgk1L
eKmWX4/R+oZW2/VUf49UPKdihqASyad66DsXKkGLfkaiNNRq5X66p8ZFbGLe
Tff7WfA93dHm6Eki8EX6T5r/NKJAND7+/nES/NYGf/wo0Ic6bsqve/m4mMrp
LNpaw0BlycZ9J025eC7xrU17XRMSfozyXNEj8e66T8E29KBKpC9b1mgMPFIa
rcp3DFEYHPJQjdIr1nxazMSMjpuI2J/9Oxffh7y5yaZ0OCdKukk8Y0Pq4b1B
k85a8M4cvbhWgUQVM3REO4iGXZFT3a3OBI4N17YX//UE7BibPanU/2i2YbJT
DCYm7chPhtxR+I7brp2X7gStt1KHl6rfxnz2b07oEJ6Euq+wnrEQLnZcvVyy
BoWpZyuLdEmoiM43pGmOQNAkWMTmLht2FxZOaOS0wlM2yf6rOYHlxsV8n4EG
WBQkinyQIuExubvutkAn2n/u5FM3GwP/oYy07epdsO9d27n4kIvXC2Iquv9W
IehV69EYc8qvgRuiGfKB8GF/HPem+k9JatN/FvEGvhrFDpOUvs6PLYdD02Px
u9LZbFVKv5DLup8UNvdi+5nSgFVHLnpqDCdrZ+hQubZd0LODjYptCQlnHV/D
8/2KbEs+gRZZVmLNuSEIWskphK3lwFqbmO4L7Met6VOiSqpsrLPVTncOYiA3
qXXlgDABMY2Jo+NLlB8Nv6fLkSwIvVctSO3vhqYv/057Wyq/DzI2flXqxR3j
arsHXwkYECrpTubpyMoayS90I6HAWk/6fu/ANmvx4TEHAjI3FdiRlq8hZB59
Y4RJQpg/bUqJ9y3EX9rO1htwYGAZ0r9qFQ4Jut67CWcS4d2qbpn6Wdj99poa
rweJx6JhRhYCb8GMjb3HszyK49OSLpJGAyg27lGW1ubgsPaWh0v6bXAKiyPN
6yg+8R0pMklJQYfoYs8PVL56KuPnHHxawEj4cHCJ8ovjIr1MaH8niEApPrMA
Au/cfcbZk3Rk3FK5Jp7BxeFUhruRZj8a5daX8hzkgkfkE5+QTyTa5TaYXnQg
IcRvL5bHYuCdUiZzkeLTikHBm+eJI4hK93HVERiDtn24TZkSEzMMX98SGhs+
Fs6mvo29WGMWdyTGlwDDTUvLOnQUns3yeYMKIxCv6zO92J2H8X8n80Ip/Z2b
U4NDv8ThUt20ToMticVuflv/pVpYLP1y6LkVlTeu85IqLw3S0Raz75O4KC3k
F9JspKPu2bE4q0scXD+e8GrBvRzKXl5Xlk0p/gk/q7eeeIHD9Y9vzR2j8u87
sMWQ/QhX/wyq9jhDgin4h2xAVjdoZo7ZrCMUP3ZGTwtqvcKBWpOtFdkEhJ4E
9ikqjqDW+JVMWfYo7MJ3FI63vABXTi5MQpuqp28w8yk5EQ/UDnocPEni9orX
cBhzGAEJA+1rDxAg07v/crWiY7NoIO9uyo/9i9rm79KYOOAyeEliBxuy2k13
pc/3Is4heKaO2q/sC4FvLSZrEFE4P1tnSGJ/1UaXhD29YJeOR8cvUn5JqRIb
ibqDFBoTTpRfyh9vnhameDHh6C2yPMnCTxsbz2ff6MEXVnK0FklgjRHfg9Fs
BoIXJK+3tnJhF0GXPT88hP73ruVJDdS+TWzouVZRi8gfKiVmlShe7gyLa9Mr
RcZju1evz5HYsalPPzSoCbUFcro6VH8BgraPlH/pwwn5EucNXiSUvMV4Pq+8
wUIpUWekNYYPtOueB+y74aOT23J0jouflRcn0tRoiNkW4Hh5gQt9mdwosbd0
WM9vZbhXclC9Vfi287o+OO0tzHz833zU1Lfcqm7E4o22hovBJPrDE2sy93Vh
rCtKbIDir2BF/IhJ9jA+K1Y6eFK8a9bLOVwRn4fi8qJ8Mz8SF3dpSi+7M3Dh
SMhK/m4OFPY56UOsAC+ObsiMMqHyJ+zkcvccDcUnqrjRTRzETMn/+s/mQTi1
lLQdbuHAPzXxU+GmYRgPFZ9fWhiB2WxAnGlxF27zBJ8WXKXyoKhtM5cfB7/I
nkAvV2o+etv8zqETpcL9NVbrCMR82cFYFu7HCKuKVX2dg1JJj3kP3zYEV156
30X5jV86vyRRbRA5Vyr81+zi4P9SkrP9
       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs8ldkax9XkkkNhqChynalESrQ1mp9OTaWppoSKsHPJVsQuRXK/5Dq6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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3cglf8fxSkRCRGJaMlI37JChaNSSrJSShpWKZGREF8jZJSdyP4WSZQ9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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk01dsfNT1KheKZUoZ6pnQJS/GjnfIkQr2ISCSSpyIPCb1KwyPPD3V5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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk4lekbx0UJMVkqSrIkFUZGyVJ8LYkmGZrG2CKiOUrily1bo4xs2YqR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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekb1lgm67QoEiozVJYsMwzRuSV+RDUlEaNx7GPITgtRp0ERNYmp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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VO8bxpFsKUuSUCHao0VS0Y1QqZCyJWm1hRBZErIlqZQ1LShRkpTI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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41NsflihXdP2KQhSFRElFJHnRggopV7kpKkRXRdxItuS2Kku2uHVl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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk8lWkbRmkamUNCpZjCHByyZPlsuWRIY6IoJWQLnyFLhQpTSKXNEsl6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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns0Vdkfvz8TU24ZJKSbaJRHxjAoCh81kvGKQpKZMNVkyiMqTBRKI48e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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8lP/fxUWKFkXWomzZkkopSh1ZolKWSmVLIeSfhNBUUlkqREWLKHtF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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk4lWkfx08SGipb2sgSkTC20YZvvA0Nb42EJBklOqLIkkMISSo1la2G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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4lWkfx2VM9ZLIUi4kjWTJlEYk5CtpKFlKGTRRREK2StIkpCYilIQo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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4lGkbp1S0Q2zWYduK6OAsyqpVv5IkpySUGjnEkJzZVEbNVois7PKJ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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8VW0Xxs0VCpEQQsYSQinSJWQoZSpJMquUQipUnigilSTJlKeMiYiI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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVns41eka3SMmOWhrkBokTCRTSkUOLRq3KDXZ2y3HSG45hSTjFqaGqWFm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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns0lekXVjIphAnTj2ai0JURh2SqBxOTUEqk0Kgkl8atQShk5FIxOlLI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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekbRhJZKtOmImOpmKgsZWbUrYVp0ahGWftZSpTsZafjZMZS0VCW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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VP8XpiRRqCRpISKUpRJaeKWSIltSJBRDEZIiEqKEfEuKRGRXIZTs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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVns4lGkbn/EJodJ+SCWfZFui2JQO2F8rbQexIaM2ySKUQwyWtKJILEWt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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs81GkbxlMqMVEOpehIhLbYFDsxl+TdWsfWSpZ9y1qnVFaicogIYZ0r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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lmkf5Z0aSzSmfBGSCembjFxeW006lmQ3MjKqyfJSZO1DoZBQyU5i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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k4VV0bljcyFRpUSiEqQ5IpKm7J3EBSKZJokGSqzCENKpGQKAmZhygy
ZVZmOmYyn73POcgb4UUlvv39Ote+zl57Petez3MPYtaOJpfY2djYLJexsf3/
NyA32bbNloabkUUcdlVMTKYcTHO/mwftwFXDVxtJ6AoedDNe2Q2pgbC+tgMs
LIh6ytzaOQBtm+08K6UZYE6WqR1c7MHnP27mRaoMmL491Wr0z3s4iOquU+8j
EJJcqX5byg8NSdwy3pYktAtpdmu02sHr1LfdmBhCZJSe69O1tUiXsXn22peE
f7VPxJGcVBQrtYl4nCPheOW6aseleshIv/N0sWWi3rriC0dpOWb1l5fbSpGY
56uvvZbQiYc3vkokOY8iRFYtP0Y9HZw8t+m1siSSDQ0t7mn2ozMl6hSvLYGz
e/eSCY/K8T3Xes9NVQIHiresItN6sF5Sry5+ggTbno16A102KHBMsFl2nqo3
Tch2Yn8jSu7ptRXWMrFweGXZtqPdGKcP7r/0YRQD3gtPIxx6cYxLTO9YIQFm
xs5bqw5kw+hmfbKsDYkHgeXRORKFYG9aXjEowUB+y4bBKtdWtIZM5Th501Fb
NSNvsKIAd8JO4wdJQnTNLuWn/NlI+XArNJHCQz6+UsDbsAltmrkdJm9YGD/B
xavF/AJ39YNNl/1I8Aiw/Ex52tF6TfygoRQTT1R1fiO/FdqnQ3Ll2Icx0d4S
a3WvE6Iqd7c4UPVr3o0R1Q5sRsYho7onqQRUB5es3fUqsf249gPFfhKeep32
989ReIq2Cnh0MBBy1yV7LDoNixL16pW2JPSjvV76WdCQEjHaLaJEwE/XQ85k
sRkSCWY2YpPDGLr3UnH0dxL6TzDPZu6l8MzY/1I45BD05D7zqVB4uhyzpXv4
tOGT04v1Ix0Ehk6W1g/vKgZ9KPfZhBgJ7y+1KRfeV+Hjw0zHZxcYcLLxLrB4
WgKvqCRWkxCBIKWWheAr/TinYO+6uIxAQYaUwQlWHaaMH9cPTQxjp8RzgV8j
zdB01DxoPUXC5D1fEs2kGxoKp8yOGA3BxTCpPb3oM7xfRzQEfqKjIn9EwkWi
BcqXjP7FIgPuPoFZIsOtsC7zlIzYP4T58qYHR6VqUG0pZT45R4dTXI7FE60U
NPlpiE5R97v57KfjbgktyJtrKT66ng7jmNU+Qu210BqVSlCYofDr2UOPV0uA
bLaZYoA/CafpfRvF13yB2XphyUsnSdBT9f8kNtSiryY2IjmFhGviNSf690aE
LFRfqP1BwGlmg9tnpxDE8PUOxVwgYWVQkrPCth6RoZJdGquo59kJqa3xFfAN
HaxRIEh0xvG5G4W0QFTs8LZGsyE4xfscue7UBidNNfuYEwNw3ZpMW1PVjVhc
DeaTGYWJyeFN2vpt2Hkgqum8xQgs3SLt9sdVQMk1JuDcNwLphVJJV7e2QHgk
pMv02DDsfzpzb1tfAr7DptN3PpFI2XTy2Kf3bVjhZN0y6zIM48Nz51RSUnB8
8tqxKup8nXLu5ppZjaDxXZlds4kEzYiRYrT1K8rHrBUX1xFwmZsJ3tZQB9vW
p6k83gTY7AeaUsYS8M5jXOZyEPX+mSIL3x+9CJ84p6dVwYJAiRRXz50EXHXZ
69JD9ZMFMZDtOdCG3x8qBQL+YaB0d4Cr3SMa4mWn7qUoMhApUl1zfzIBmbre
O+WNSAz6c6o9zWyB7pXHV63KSCy07Xk1t4yG8D/fVYgBOoRVLlbzmrbjXXfY
IbHnBNiTJUxc9VoxplfqQQ+hI6bye9n0fDfC3w7bNETTkZzwM7N5ayvSUgbE
Z0NZYFMSYndfdhgLger2MlR9jYnLVK/1FmDcuZ0tYDkJH92AgDWrq8DpYaG8
9zQBjY19Er5xfeh2697v+WIMBxRISeugfmyVdXXUTRiG0YjPfgnJDqSdzJMa
jxqB52+24p9x31BwxFyrQH4U1RPHOablaCh3jj2uEkFiMiAgWF+yC81bDLdG
CYwhtk9+KFYxFtb7zvka6JBYkc8iioYHsN7+YZrHVA9iY39O+NMy8Pdx4FqP
IxSeViLll73qYJqUXTexicA33RrOPyKl2Keep9RrQsKQJ4hX+WwzbP+S+xSX
CNyzNnBxkHkFXVdP5aNOJF4c1ExRWEVD6QXhsKUNBBZdv8fk3KtEVxGRUJNF
7T9UXtspWAvGea+nN4aYEKocCfwvswOlLJfnv1oJ1Op5sl7fr4bvSalxYep9
+cd9cR6Mcuge19PrWs5A+OaOmhNBBVjMK1GzBQkhRXaj2o42rFTbcdSQmoeh
2//O5JOvIN7W+p/dfhId+18dLU+owWDRiNf8cgK0aZ7snUsVWFTWVODNITB6
LketoqIaGeK1STriBFiz5nUbn1Qh9WRonTzFr9pKtxQy9NpxxbHokfolOkT5
4h9w2JbBK9rSeSqGgQPZ5vtN7b9CbFey+FImA/qfxNlijIsRMvd62nieRK7q
Zi4Xv27U3Q1Y3Z3YgSkJ+6MLQX3Qf6Is/mJpECP5o7qS35ph2bIyr3otiT6z
Lu/dG2tRYinNo67LQPPEF2NRrxKoDK+dLPtA4uyrNx4lgR3QGcrm5jUjIKwu
HC98pwd8741Pd0+y0K7Tf3DzaBfGxE4Z/ulnIHsiwyflaweWvcoPdU5n4Yht
oWiOSSe2c4Wd/+VDUgj2N8fat8K9yK7O6QYD2t7q2tWr68F3kq8/7yoTPMuz
tQc/12H3xkPLDbRJuHOXve1bXga/pk5P7jASDzm11zLpZUjzKtixdYBE0/0b
b1WDiyB9LGnFSzkSrA3k3cgpGgKX8tJfnh0B21KSZfYDV+SKmUpnU/ORs+5e
oop0FwbZlY7MHyLgTnew4PhTi+uZZSEb2yh+DxkMo+u04YfJP73ajkzYDU/0
XHnajRblow5Y1wdZvROii1c7YeE1U7pLg4RmV2TfYe4Y0F+r+E1T3ycjc+N4
TrdiUdq9mruGhJZBlHHQSBOG5xZneZVJhLiVRZ7ibMXmR9pSt7kZYJkVvEo5
U40BepT9si46XDdIvlnjQ0Pv+24Z7WYGZllykhsv9YC5XeWuy6FhLAYvzht4
dcH4BP+v9hMjEDVbpjGr3otKmx9n+fsGcJH71qPunHqwfq1LneElIL3SLUqI
pw0Xm49lZu0kEK0WU/x8+CtUxByzXhlQ+l17RjJ0VxU0fdsDBLXocMkSZw3y
d6H6CX+qldgorJZPPbYl2zBi9ns8JYwBv2MGJjnPP+Jl8u8Td/eQqGgTEelX
+gKNPVk8Ir9JjJeGJ+cc7sHJwpT9vo1jqF25bMeKkkIkxe8WSXYh4Zf/MSC5
PQjvfLdvrqfwCiEPFdSoV2H7Hk6mRQEBzRm744Nq1Wh8d8bfgEHHB8HVIhq3
6mD0dHpgzJgOVvd5JsHqRN0qLcWbQYN4sniDbeN4J/jVVv2pDGBh8HT6m8Kx
rzB79K9c+TMCq5Z3y+8W+4qI7Vc2dHkzUb7t663c1iDcD1t5f4HS0x9/VUr+
Xm/F0D8qLqotBMp9vyzoRBZg4kFYuW4dgY7x9bkPM3tw2lWwteEuxbfDKUqS
d9ugbN2i7niOCekp662fxzrxXdX8ao8aHXyqcbqJ3jQkjS0eXiqg9pthcoyk
ZmJmy9vIWEoPZHkdaJqVn8FVIm4VySDg1pHo4ZbZiHVNTkGFdALj2QwVcVoz
tjm0j6YYEJBXWzmdNvQeRbuZS8F3SNj3b0nPrmtD9KUXit5XGbh5KHhC9Gcr
HNh+OH6YZyKaeD79t7sWtLBvtPHvdMz/+GpeGUYD01wxX/EFhfcyr8y5W6lI
GvrLZahC4k36f7uLY78hj8uYzUuQwCb2/LnL93OwbWVsQaEktd/qnI/HI7/B
/mXdkxQfFsK9gyztZL5A/MGa26yfJHbz8Z8yUu3G3gTplFCjYcju47N5JtGK
LbvmVpTlDCHboXrNbEwHVg/0pxntHwWPL3u4+as8DEilfkswJiGgFa1lOpKK
J8kJckZUP6iaLpnST1agT+g6n3XC//v104hLczlkLyTGctox0KcTuDCeRQO/
MeesxBCl3+JBsYku9XDk5E586EgH13W3LTVi3YhmG/H9RPkt5tnDPeZONGzS
Od60rYGA7ecsTve2ZuxULBMV/EHp130Hvl8nUrFahvulMNWf39g5qzc6d6Jk
j+DGcYzAKpxL6G5oMx5bRN3yi2SgeJkJLwfqkF/XsWQZykDCyKKGqU8lrHri
GM5rmRgv/NIjgC44a7ytFXxG8YPyI/PJrzVY3RI68radRHa67OGzmjTY87/f
uo1GwGwkMvrl2mxEeGDGz4vEvobgUfcLXVio320Tl0uiWGdHnphpHTbfFJez
3MRCn/+/PY66teBr2DRXQ/l79+wz2goFlL+XtmbJniMQfiGxzHS4HXL8gb0N
mwmY/5WSr41og+Hq6+s5HjNxzr5/m1lRHZLsebjYqPt/Ydrs1pbUiSP/3ixz
u94DW4H4p/cM+vDTOSqDPZDAbJY0+OJLUar1fDRxNYlfv8zvFJZUIuCyc4CR
HAPBp+kSGi+b8Y94iZb9LjqeJHhk6SRXIEefZ7iT6qd19QLZg2xVUPk+K6hB
5avmy5WtqyWrcGK64cSICQPTjLVfuhO6MPRa5I9rJQOTC/d4DtwvRfNFJXIT
pcfBzxrYgqtpyAnR28xvP4KQmDOC3m/akdx+Ktbw3TDY2n9f5NhUjfGzKb3D
+iS49HtJq9/lELjme2ucg4Fj7af998V1wcFDlpWdSod9YxX/ZH4PAnfe6FBY
S63Xz80c97+NF9UbZIIpPpC3WeQIXviCE0nb2ddLUf0n/37eWLoNlsPyGZOa
dFgFWsxh8QvoPELKleuoeo2Vc+NpyYi85qJzh1I3rg/7Xo0K0HC2fs9DtsRh
PExrZ+lv6MT01G65HeEsRER1PN8e3YQpM+/HG0UZSEluyb2b+Qz5huzailaU
n7hu80lkXztOndS5KEjpXeT76X+eUPsNPrxRvDeAgYVz1wpFE+px667SmYsZ
lB4fNOYK8q7C69wZL3EqH1etKsyIv9OLvoaIZgPKL8Tv+yZfHt6JHLH/Ql7w
sPC5qqWicW0dKv9pecAhw4B0dh33z9gqkMfydtOo9cY2ku6nhSoxG0pTtvuX
wJl8zrQ/1Pyovvg5gdkRxH5vIybLE1CsWZ0495DKI8UDGr+H+hAhpGrppMzA
/KebeTtU6lEcvfzqNl4KL27fxR8877Dl9PcwF8rfWMR4t9altaLCeH7XxPVB
KKs+mWW9yYT95io27d3/58ecsMXXSWi31zRTpfxh7cMpE7YMGvq4jdekWRK4
YB2mJMH3GcLMlRetKf3M7jubdnGgCX8f9XsqUXzxl7s454V7C8Y78v5TUKBD
wGbw0hm+ZpwUnvbhpObrLM3c5OrfNvxcEvUWdGJCW5xf8sn7d/jW12bqQuXN
WEFabeWZR4hM38aUpO6jjufazhCTfHzQsxIbo/Iys/eytUxoKzg/nWo6WcFE
88cbrLknfdDJfvoy9ekIouS7lGeC+6HLJSoWQ53HmnNc3cu4BrUOz636wwgs
7/fjFh3/isQj/GkP5AhUaIqZXtZ7hwdCvwX3Uf5Ivy4nR9fnK8aOqjmUPhtG
Qo2zX/+3TiQ+tZ8/4cEE6Xkha06xAr2WHEctqe/v/Chi67a/ATNXQi1CfQgc
MN2y7JQ0DXpvbDxUZKk8wC5LnjtdhhCvy7ukfhK4GRwgviOuEuGzmXY1iQwo
WsgMdb/7BoGHHyNqdjEh68bfeyeyExLzDZW7thCwL7vW7GhYh7caviv1ljFQ
fm2CtrGxC+uaTxhYWg/jhuF9pf62VgjHb9YXo/TQ+KzYkcxt5ZjJTRW4lUDC
Y9pzq6Z/G4T4o2r73QeR8tt/L89COVa/TDgwe4jyE5r+g78dnHE7wXH0OsX/
tqbpAQVhVTBxu+8+8YjSQ5vwo1JXelD/MSW9OYLK213Rt3tPtsJQUZTo+YcJ
JftQ5qhcPZR4TfyyKP3OvrrD6HtjNybTtuSsXUdS/yv+ybDPxK11eT1vDUnI
ME/tT5L9irmyFwd4Okl4buV5nnOMhvpV4zwOVJ7RWbPmaBylZ3b+an1lD3qQ
mXPWubynAR+upHxI5aT4sDz88LrzHdAciErS2UrNq+Gi6xeTRFSeLy+OofKO
qE6V7zGecGicsV4Ups5z2a/om+LtWhjzi2T32VH5ld2akTpRh8E9oo3Crwh8
3n2ca0SxG+lNSp7hVym/qupcGLvLCfq3mBVV1Pp2YoXnA+Ue0DVX0JdTfrUx
3r+0+EojnGpK1iq20GH6ocE98XIrIq44bzexZKErvKpHI7wa0c981wraUHk+
qIPlf/0jWvxlYqt3kvCOOtP5LLUDanH16wqTqXwodOWGsTUNBYfzDrym+Dbk
hkhCeVYztDbcNQqgM3DU3pe3qLgXAh84Mn7fpcPYzVt/ZNkH5EbZPVKg/IHx
StUf/afeQUHKNVWOws/6tNy6hqQ+bO1wmA/gHYdpXI54u3o9guKijDovExC1
S2X3WvMOL6/qDGfTqbyzo09X8HUvFsfbrfxthvBweEeBEl85SiVvmN0zoOp5
07mUfpw6n15TYiqVf8szhc/8J/0A1x/95Dh4hoTV9a4rqVNxGFOgbe+m8oJ0
Zdbr8AAaOm4oe1SwhsFTPhXkQjZijae4nO8XJm463/9dwGxC/tNsQ+coJsIL
JvKnLdrQwsj4KGBO9Z8Ect0sSrF6/urB+TwC2vsNwuyEvyA6Z6XvHQqv2J8W
HvKG8aAnxjcmU35uwJjcdt72PR7z7Yn86UbVM/PL6pjKG6xx+XPn1THK7you
OAtsrcFFjYfVNyi/IjD06M37A58w/7PxR1U9iTN33hSd29SBHZfLK1/lDWHt
2Pi2I64dyLi3Jyvs3ihy9aGzxNOA1RVCioF9dFzSmtn3Lq4O2o2sXsdqyr+w
i58nfNLRbRjv4KJF9bN18yRvSAv++ucWHbpGYC1PBsf7Ukq/bz486vKYQIS+
gXHExlYk+e6t2/WVWh8aHMYmWgWzyS2mZZRe+ilHc2/Qz0a5wqNfWkqUPxOZ
OOK8pRADPEyvuS0k7BK+68R7tKD6NH+QoMcIjnjN6tWHdiM4KF9oWHIU/wN9
Aww6
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8Vekfx22hsaYhYyjTKNIqW6Q+CmmVpWwzKkZZEzF+EbKkRKGxhDCJ
VChrlqGbnXBxr+u6du45FyVGVBMxfmf+OK/n9bxe53nOd/l835/zk9MVy4sC
fHx8ydTz30oea1907CnBTgn/w2vuk2is1L8sSeuDpHKz43kRLrxLPF8kfamD
xzQvXfM5iajjbs9V6A0QaH8Wft6JRHIlq2KSwcKEXlq90UUe/CY/BkjpNkB1
nF6k7UziZKpQcByrF9qDpu5bbEg8k11IWf+ADZvxSv2irTy43spTuRnEgLSV
ep+DGg8nn9l17o5+jZvea5Z3aZBQHi4N8G/OhPyTg4vi3iQMZ6yulnHuwFI7
IrvnPIl2On/mlHUxcgqnpyIMSAyEddCKjTswVxUVohJLwp6tu6kriYMxO4OD
Mw0E9v7jFC6xpwwNDKdN8X4k+KyObczSb8CUuW7841UCx10Fvwu5046NS1qR
Ct8I/Foj/PsVv05omXDObY8lsMmIIe89VgsDu3s3c/8lIF75xZW2Mog7P3ya
vP50BJf8d61MFLIg7tv9N9eLRK1If2bDAB3CZ40P/UyS8Lr2ePaPDwMYTEu+
KuvOg3dp30gnPR/mGnOpbVR+4ufDRzO+q8Z8aavn8DsCN5m6Pj4rbPhljN5J
IAh0lzftOnq/H/KXv/f2/G0CarpZEbNNdFg4j72/foNEmHLMBjfNOiz2+RV1
C5DQKawbdrnaDca2He0GSSRYhtflfvx5EC/jBFYrC3mgX8tKfqPIhFtodrPI
RS6WIqMuy/UxcXdaZlWZum/VL3krK5eNmjO+fVuLuCD25W1vCu2CYbHUsdwO
LnJwuuSjTCtMjPpqYqZJXGmXmS29QMU73h5aYU1gLiTQYaCNhf0npqZPmpNQ
m7VVqd70BoL2ScoRFiQ8hxqKP/zSD7+9t6qqS0h0FwjTGs/2YEoo+ojcKR5a
V943zhW24V7kvPuGbi6i0s6HfBmqQ+L69RL3zajzJVqTXlb1yI6rdXGk+jkn
0fKqarkIZZcqA5i/kUgydeHXNx9Al/Ln3NPOo1BWSnRipfbAJX/igwBVf8nB
NS+eLNfgmeqVqwOqJMbepg2+cUhFUvcWf0tKX8rd7NhX4RyE+AQ9MzQaR0iV
rOXCGga0J8cfRioSyOxkBrVhAHGsbWaduiSmFIVpIWIM2DDM5hdFeRgqOjCx
z40DvkMho2b9BCp95PIqlFno0gm1hjRVj/V7Wwal/gR9i6/XQ6o+htXV1UMt
hegsquN7cIkEbbfniJ93H2oS9i1+MyGQNkMTt2qsBzvtHjvUiJqn18tmCTFd
MNNfir8dRsI1OC3wclkPtbcWemxKouNGSWKQMxMjZod9zlwgYJzjtfBKkIHo
cXFxqwAe/hAbZk/+0oc0pG3mUvpmJfMCrs/W4bRAdqL7RhLZL3UMHrLbIW6z
RaMqiUCHfxXmF+vAFb1gvXc/iTMJaXpV9QyYVqRmPfElUZkeo5bgx4TOmcnC
DW0kFMoFs2wu9GDptePrQiYBo7ep5v1ZTNgf4hS0pBAwHJK4XH7uGR4ZPy+Q
MiaR2CiVqvsbE6y6SwlR0SRmGxsfbFVlor7uyAkLVS7OvJt9k/6gBrHFfYeY
Xwgsz9pacJrpKLr1SSFmFwlzKX71favNUO2POpI/SkDlqGbxuzwmxS95e8sf
CeRtbowP9uhFiWCZlKs+CdvjzZp1pZ34I6grPs+S4tvR7KVaTzqe7tx0yq+J
4iFL9XYQjZrXo7OJ2hS/HrXIvUjiZEBPQsl84RwJM/HjdS7ebHQcNpR/5c/D
nm5nuxS7OoQblYnee0NgTEnvQ7Z4GSRDJBXzL5KIsJWMnPzUAHX1zfFZCQSc
dv4ZduQAG4rs+VwFaj7fyf75mf2gG99FB3QuHyUhodM/bOrShB1mDsGdEwQ4
dFKvzfMlzHJsi5V8qHzTx8ttXR9BMe6zeZQdtf+qwGn5qRcnj4kPSYyQcBda
DvH0fgvbLpu8kc8ENnsI+zO5LYg1E9s870JCWPWnjFnFajB/jUsIkKTio/ku
iMz1g3XBakakfQytwrdC0zdxYP67dcYVSi+ci5VFjLReDJpoCpko8LCUbnqp
BB2oVrvmKVJPQtHI9au0ExPTxgNZ1rlUPOxHA9HHHiP6x/WWCVR85xId4z66
snByq7CS4nsuCjy5onTDDhTZBB5KsCfg/I+e/umUcky1hy7MUPHtrtcfYXj3
oNbGgyYUSCBcJtDd5K9ujL8/LuevRdX3k0/SuFcR5C2+GZdfIeETcSS9kr8X
1w0bq81PEWhUubHO8G4FtDbQTJSp/DgJy5nzKaVofeeoPkXdf/fboMeZu03w
2sjkfu0i8Git1aS2dwZYZh+YL6h+7UlQU3rdkIu1A1rKiw4kVIbN749n1eIW
n0vPP4UkWmX4NSqk38Jgb3b390oUL+58jdH73IkG1TCfH/R4COzduF3oVSdO
BS9Kjx2m+HI2ZlHWqBgfynZ/evk/6vtH9LZtMR3C0jcPZ18Fyq/sdtvIvOAg
Xkqwjbd/HGKLGekubA5sumSevro9Ts3HCZ6ndAHcyfyJVYpPfF90Eulez5HD
ipW3pfxG9K+163UN3sJfSvvv/PckgpLdxhxMe6Fju6AhmUmgoESblNeqhVp4
r6dMIMUrN9c9YfxvYBaqsbgrgoTfSKno9e1NEOlTt0/WIdFmoRkUuLcLYo6X
3q6rIzDxQwE7h92BAO5mv19nCCiPVNHc6S04mO3sMkLxtltFRVJWvQLy92N8
vu6h+NApSzpw2hD2Mup9D42E9znZjakn8/GOc/OAmDWV7/Lu8w/HaGi1Oruo
SfHT+UlWo+eBanxEU9W6//TyjawRmGJg7X6/RUfKX0KLrh7YlRyMbfyve8Op
fsh90ff9fKMB4eXXmgRTqPcFB0a1mzhQt12JFIsZw1G5lTlnnw4MN7B3pt0h
kWKxGnlrXQ3O5frt2FFM+a20fWvz0zoUacd/EqP00EYPZn78dwhOM/HOJh48
GH4/qy+z8gQlE6MvzSm/sTYqmRSsL4fjNOOeLvV/4PX3VIhOJgfcB6InisUI
5ByUDnDT6MJo5N3YIAaB/wPp8M19
       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lekbxk/2aGJUfpImycGESJNMGZdihIyQOdmbQk4qRIlGWYahQ2Ub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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4ldsbPY0UdUlR3J+Q2zxwy9RgqUyVikualFmHaEDCyXjdQiSSo+hG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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk4VO0fxmUpSVpJkiQJr6wlpbqFhFa9smQrbZJsUZZkl6SorJUSQiok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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41ekbxhGZJiZxoWxtmpAp2WO41ZC10KikkiJUkiUNpoVCG2kiS4gG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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk8lfkXx40YstVPixgjIqIsTQoTPo0ka8meSsithBgjUTchRck0hixl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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8VWkfR9qzV4hQKCXRtNgaXxXVpJQZ1VQTJVtRpLJGlCVCIkuMIVne
orJkXEuhiyzXdd17rSFvnnMj41ZvQtMy7zN/nM/5nM95znOe33dd4eT1s4uU
hIRECr3+vZvtvDZ2romD6MwN72QqCdw76ibvJXYjbMFfE5VyDBa3XZo6bcPB
nGilOyEpBKLAlVLJic1Q3/dTxE9pBDMJHdUml/KxpfbRTMhJgjTzukDZ0S7k
qxfMFVoyIJ5rJpRi+lCmF1GhbMPg/Unnh++iWzFc7Zr5gO4ny5744XxoL1il
aWJxDINi95kdK7aWQL5Jv/3iKYJV//z0t8ObQRy8YhXq3McgKjV5mZyoAfk3
O4OkQgl0ytdGTto3YaZ028nw6wR+Nx9beSztxD93fL+Ecug8T76bWq/MQfk/
k0WuJwh8uT/rrfmrGuoHNbQNThNw9pE/Uxdy4O6Xatf4gKD0bv+xz7rdyFnG
rvaUZDBzPGRMNLcVHt6M9dsbdN7Bm2FOS3rgkXy5Q9+UQbhrmdlwARtmNlH8
onCCc4vVFIP2N2Aq87dMco3gaL3Qta24Hv+tKhl9eZlg1Eawh3f3GdRsOiTE
ngS/Z9uv5/ZwkWAYEbm3gUDFL+lGvUMBrCtCJ15TPC0em6ur6neBd9hBo2wB
A9sXM4eWKXZBQ+1EWrsyA4l9NoXaowF45D9kbe5I8Zcty3JL78SkT7bx7iYC
Z1H+pbiiu0hIWucRQue/eP+t+o1tJbhusadP24XAct52vxuWddBSlGYEFwn6
fVlqisr9kM8wuescy0BKeaO/gTQbQ/JukuxAgt3utqyn7D7Eig/cz/WifK08
+TPnSxNCOOUrRun79C8RstduVMNhs+XcvLMEK1fxj2ud7MP0y5Fg298YcLSy
9JezG/Gs6PJSVgyBVuRlJdVRFubvdDjYeYYgVDt+vIibgcRnRlnv6Tyhdl2J
7Ak/CHc17TOjz8ON2lw3nzZkFAcc+yWS4NfEpC5pHhcpjUN792YT9Pb+unpr
kwBT+30eDEwRnFiTf2hjYSnea7NFa+m8i/JLVKMZFlTCPSJzPQjC1FJLvBd3
w9mk8na3OYPYD7LfjacFCNNLVxp4S7Chu+lOxAIe7M1mCt5XUfyey1j59Oei
b/vK3PWUn1XLP444pjbh62GWWxbl+6z8GTVHyyd4HL4lq9CNwHVdfW+9+gBm
u3wix/9kIH/f0r/gUTt2erTlb4qn+lQdW3lQswF5hiPvGyn+Ja+bon9p5aMo
fH7JxUmCGq/lMV23nuHIE753jjfB6Y9RHjoX+eDm2Df2DBLwXhndCnMth95X
zu9e9H9+JvxYcZAAJZGDqlIjBBJtSa/rO5+Dpxlj/YLqr26NXoBlWwtECjFn
fan/fHXlXsa9HkTMG6tv23RFkPrbvqQotw/joc2pRT4MEsyE8QH+XZgy7qy9
SvW2ZWiDV1VoF0KkHW65KDGwFw8Ja7S7IY7MtNJXYOBcYLF5cZUAw2frzW4S
gs/8xCF33YcQbf04LUn9rMLT5X0NbsGuDiJ5L5PgwHLlU84fBTA9JlzXR/2W
UzF+9bYBD+IVSTEp5QR/XMutzjRuBskQpJuGEfg7IG9yZy0+7OjxG7hE0BYa
pHmsrR6r8oKrtgXRPDhjbu6jxMXeQAer+jyCgQNODy2qOrHrS9QmrpAgO2cr
J2YtBxKc76X1yQRSeeK4yrp69E4fWNsWQPVzO1j5ykIBPqk+eFTWSWDEEej0
RftDKkLK6F/9FctZrH0n04TrNhmj3Vepnnq8vPNnv8DkYevYWyFUjxZ/Cgu5
tTjp5mbYS/kcltZY5K16C1OjAZrB9PtI45lPS0x7kRs2Pd6kwiBtV2JrXkkF
1N3MWZcof3LGv+rXJghwWEO1JIXyn6AlqdZxiodwcVbb/scEtk/n6WUd6sQf
tofiRb0EZ77aOnf/PYgWqVlnNmuJMDTeMawV2wcTe5sBd1kGmzj3DTZHdyBv
Q1XeYC3FP2Fs+oKwESojE+8y6PmKdT+uZyweQs6+KDnXiUDPxfjh5hddsDUx
9sjRYXBx7ENjbEAH5HTaJHUqqL9X6BUrvh5AinrL2w8FDOomdHk+4zX4fjpu
8Bz1u5Ymyz25oRm2j/ua7lF96bz6oFh0uhPnStylLwgItq9zk3eU6kU8WT8u
PYcBv0HEf1jeAJ2rw+InVJ85DqX9CtE9mNzumGtwgMGhqrvynoIebJQRbqmx
YBCoqRGXkPICrkHx2UuoHhYZhNz+T347UlpuLpDOItg6XsZa7cGG0X9nfbMN
JrjiNJY60cJFc6XfGys6v8Ru/wdhhSFQPFPWb0n5SNBxbVshJ0SixeT7+d8I
WGHeHiZyXUgfeb141gxdf8Sm2lmhFvyE2dHcCwTXGxRW59rfh0VNw2cW9T8v
KERjQpKN8OJSFQuaf4pVnt1hm5uhEJa1hH+bQHiE6bB+ykNRpL90DO0X71aW
wtjBfsSouJxzcqT4Khnvf/6Ug+3l8vaXKb4n5lRoJIuqMDUl2ZJL+6Emzvx0
UTobS+eQKMMImj/BpWbHR/iYy3KXt3xDcOnHisrwr51w+vHKB/MO6ifH2DWe
tXw42e36X+Rn2ge+R/aTbU8walBrZ+xK89vS++3xPe2YVJLp/JH6Y8LObnDC
7hW6z2sfUqX+Zz0KsFD+vRLVVWm8szQfb3zVbpsn/wq5gZljZ6VESApLF4SM
lqNuUGeVF91Pa8fTgYrpDJRqC8Xzab+YvLkQMlXAR77p89F1E7Rfd0stfuJS
AJPLEVOnKF7Nyt0VC/WrEd2+iJ1E9SL/bW/LqCMf2eer0gppXxe/zDgYGlQA
kWHSp1a6PvraD4nzhoYw69O9+DsfGRhttPM8+oiL+RObTP3KaH+OC5ST+gfx
tirl05dkBkc7zp/XkX2JrlaOYWUq7e/D78aupxWi5ptvajbV9xb+sUVTG5vh
O2BoEB1H82X1tj2T84Vod03TVKd5Wmw/x67aMQVZy6O+P6P6IG7egztkOtF1
9ISQw6bnt+r2/itQAL5RVDyni8AzkisOFgigpHCOZ9xPsGDpMu/+7y1Y2DK7
XuYWwf8Bwx/VEg==
       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k8VG8bRopWoiT0t6dIJKSFSyVLhPaoLCnKVkqWaCEtpCJLioSiUUJI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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81dkbxy0tarSZSTF+0oyQijRJ+uFDGVosl2wZSxlutlAMohGhLI0t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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs8lOkbxiW7iCQ0pFml2EypUDJUrqiYnIqUQ1qnRqKPdFDRwVS7sULK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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4lGkbV1oUq9E6RVm1KtvJMau0/WwOlVSUnGuQdehDvrKZxm5o02VV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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k8lG0XpqJSCqkkRWRrkQpJuChbqUgKhextRJKlJNkqSZYWSpIkZKdk
yb6P3Rg7Y+aZhVTet7K8Sd/z/TV/3PN77nNf55xr2eLgbua8iIeHx5aXh+f/
v/x8Iys2GrbjW3dZ2rAFC9T4gncZX6oQOaOzmb+dBVfVaA2Xp5/x/VVh6Kbz
BGRuec06TnXhyrgIgz3LROMX06W6jp2oSv+T9nsFC0LH/n7a/18PNs9Mvfug
xgW/x1e3qYpehIi9YlifYCFpyk3Du7AaAjIlP9ieTCxZah76S6oStWUSYckl
BPYMGN4QftGO1I0FOfJHWMikxcbWDRbDQKT3iXYZAak+pe2Fb6ox+2dZTXgV
Axeezpf2BVFQJrX1hUwHea4U2fPi32IEBIU2xh4iIDK6wKQ+7AH71bqF6+85
EKL3TrJc+jCSdnvNhaNjSGq9GK5ZWAuZeKtnUacIJOmtkpiMyUbzS/2rAqYE
rN2ed664NIDHEo2BMxQmKld/b6cnv8On81x9laPkuedRg993G5BIKN4hhEl8
9jzeqBhTBO+JC2kP1hKYvZKdypzOgxdblf2exCvkmOnSVIV2jM4NDSweZaP2
ezy/U2gVhEoT4xW3sRFmaaq78yQNi4afSvz9NYHLG067DPj0g2f0quObGDp0
bgyHGt/vhbj4Jd59JiyImmprlgX3wDXuQRl/PRtJruJrP/UXYneFrrHMSgKT
ixabd+rWwpWwKt/fyoRdQGW+yfFnCPop2V5jSYBRqbFj0dI6LA7LKhpazoK/
TWBZfHs3VgkWJYtGs2BedVX/hRUNH0vkX/5HJfD42vw2t7N9SJEojVmkyIZl
1qlPTp8HUeUts53yiYu66SWXEqlDsD7PS5uSYUMxw+ppdcYAxmu8BYduDKD1
t6HDuh/d0Lh77Oq+UDqcwk32x/1bg4SaN7m+SwkksGlLvIo+wyK6nnc3mIgy
ETYZDInFPcN0Ps0TBDY4XtsgoF2Foyc2WF4l8f9pvvjV3oR+jFam9uut5SJK
NT9G5W0RhmIDrJcaEtj1/qvpj/l6HBT/bGreQOBe1MH1/wT34p7N86G8ewTi
+FTtHkm+QxJH8kfGcQJD644pX2trgMP3g7scNMl+H995ND+Vis3vCzUYIixs
frh2IWCMCqbjo9WtcUz0cW+6rj3VhfiwX61PnJn4p+70jPfPIcQ5tcqnz7OQ
+9kqWGZ5BUpixX/byBLIbHWcj77eD//z/LeU+QmMcMcdvr7rgzZ/qko6eT9V
nFc6nFOCq75uBxz3EcjtcPE2FSqCRsH2nFwXAjonbxXznHyBqoa3J0wvEgjx
3Ctg4dKCfVOq55w72PBKDKl7E1ODn/ZX+bbGMNCYrU09K9WJUiY3Mv0J2d+c
/LaX/j3otjtktXKQCZ35usBnfKcR4z6tdfwcgX0WH6bkbNtAe9r2vTKMQMa9
VzfXne1B3iXR69ozLDwWfDE5FVeH8OBrPX7eTGSPb/4x39uF/A+F4TlpTBDu
Yh5d5tWYa7JIDiHxP3hk5OKcBPk+11fCby4TWJJuTvE37oNviaWXZgYLq2s0
zmlY03AiKfGwRt842h5Mely16UDE83+WRpvTkXDtCLK8q6B81E422Y6AQCbF
sedFH57qHiw0EmFDZ//Hx3NLspBilbSv1Jfs33n5KH2zaqxbsfXNukYClc/c
dU/w5EF7MFd3vxYBoXqLUTnye7Mmpw/kRjFRtp65Kc2LAs+Svis1JH75Od2c
RehEiLeyzc4JBpa55XS/ls9Fxv509y4NAsphsf6fDz5BcthMtb4jgQt9g282
G9KwYub5TWlyPuQIRdEkJSo6W67OWmZyEGW1JF2BmYfmut/DVm1MSKkfylPa
0gF2wBvJBC0G6FvH3IvbcvEzeyL+ohwBU4mPPPf5SrDa/IdS/RzZn5k964oO
JqK5pCXGn7wvrb370CKXQiivja6Qe8PEur37VyfVV2JevEFNdg8LtHeUlvwk
KsrUmkYiDMahviff8XBjGr7HVLwd3UkgcEOFdWB2AcITz4ok6hGge30WthpL
AlHMfLuZnK8dxJqiD6w6HLk6WmFpOwYVvn8qqkRqISgcGlmXReKrsEZ002Ab
PC2FjS3J+6miQT//+NGgO6p9Bjc4GNm+pdejqxJx7PFfgsUELHMV/kSMVqPO
lJ1tzyVgNEk71yqaCekz+tJlJP+IPJd70WfThJJLXySnddjgzvILacxVAU9n
jdISGDjzdHfw6/wOHFu9RHo3i4Hj5zL2nBbqQDJHIFt/MwM2olKHf0fWYG/6
7etq5SS+nUVx+X/S8RopE67+5PvyK27GXWwAvY74HOfAxGYJi0nv358hZv2Y
pa5A4JE70bRjuAMSJ8NzT/xiwbqgqrL6SgeePrmf5tXGQkZd/sQ7yzpEes3L
P8gj4FTLl9K0hYI9zfT2A/5sTE+ET5vwdmD6apsAV4MNZQ+TrPWubehLTzZe
t5jAoH7RYcmWbmjTQzUTV3Oh07vC+W16PgJmJ1U1VAl8e55gIttGw22jyWX/
bWJDKkLX0yK8D2ayrjmGvmMQEuMTebI7A2fte7P8NAksqzL7+iqoGzGCWkKZ
pL50aBqxB2Zz0PLguRDzFxM3Rs7p73DoQNaz3b4d/EwsO18XunhjLzTlT/pK
9bJBTo6ehWQ9mm/M350iWPCoNQuUby1DC/WL3TCpF0nzpnsoe9ugofOk91EV
E15BenLh4Y1QLRRo4CPn82ho5MzHJ91gvF96/uQ5DizjT19ki4xg3vrr+Epr
NgLrHIolh6pwpSXiAU2WiXDek7PDKztx5+OJkEzSPySVx6dtZ9bg3o23kodI
vf+0ao2EhhMFjf4p6XzzY6j4WLIos7YHfy7OzcnFslDvayt2z64X3HXprptH
WBCL2Hn2b3sF3DZYjDhOEWjcPXtAb20n3O1TfiuReu6qIlv3a7QeEWNHtn8j
/UbHXkF/lf5U0H/tcfYi+bLN7oH/sQ4aJNeaVQc/GwPhLfBh/05SP/njo7ma
dLDDC+QTWnsgnvzso+7CEGLrs9UbD7ch6GvY9tRtTJj7u12+LNODWueSkATT
UWyU2Z+xu7Ubf0xuWNDH6dC75HJ7lQ8FdcmCAn4OLPDICqmyldyhvXtaLo7k
Vxm/n+U95QN4UORncLOTgcrSVyLttzohf+BrHtE+htqfIU8D/6Gh0bbY72EP
AZXibPlfpo2YO30ka48TC+pLIqIaDD/ieZWqu2Iwgenp9P3M5V1Qz5bv6dbg
Qi7ATc9sWyvocssqjv5mYMFqdX7kEhrEb92m8pF6pt7ecNdQlgLv8qvxAlcZ
CJSg/21a54UwubrO/9fn7X0vK4b0Y2k1i7nt/aT+Uca8zXjLYcigF/jnk/zz
o6HvUnEr5JTXvG4OYqKZwi9nu2wIUVKnvdIWmNgv+71FckMXzJW9bWkX2DDQ
VBn7M9OIXYGOKsrk/scEnXu9I6gXLqwdi9clEwi4+dRuxq0Jy94/a+HZwobd
GXeR6ncuCB+ySjAl61GxmKUrG3fg4ZFDsbrkvk3FBfMHGYSiZPTOOh6SD4V9
8pLUq/sxKHw8xk+QjkjPTInf2VRQry3m0tQIuHx43JTpPIwzyx0vzqcwkHiZ
vWJfDrkfArx3FqQJNIcLbuhoGYTtd+2p8PEx0I9L/BUcSSD1gmNQRc7rjsyw
U3c7mzE9epT5SZ30x4LtGxSk+mAZPnDJPIuJad2Nx+5ODKBaT3fniXUTmIoS
Kd9h04iyyTUqU3cJXN4kYL6V1L9C4RbePAdST9KaOLI1RTgSFy9EnyNgrmW/
qdWlF6feG9KZpSS/isgY6NzvxEjBpj/FlQSq3Usfh7dXgdu15NbyYiY0JtMW
Kixr4dD9rwLXljy3qjc7fLoKQ6oN6Zbj5D498swJudGJt0ubiquYY3DaVSUe
W94FZZ/v6lr6dFiGCJdoXawE/8aXauNgId9lqfnt2+1YUDgr0uDJRYpM67ON
sjWokFO//9Ga3NcbvXk6tfFQsw3I+GxP4hGRknDWoxeNYoEuXaLD2BwtNek9
Uwk7yoH0XA6BlD9WswuldbiiwezdK0Cgz4Nu7TdDhfRO7V28bhyERA8K/p0Z
Bm+30uupvDEYr3DYRTHtglMGuTJaXCTdj3NKWPMeb4wKswzukHr4sOV4rHMK
xOsOOB88ScDLpPtA9qJBqLkEa+6coOOa7nqP+7U0tIXMfOUtZMAySfdRkUI1
ViUP9lz5y8S5L1Gmh/tbcFRz+b4tYgR6ONqplgsDSKyiyhkuDEPhgBifmnQH
FAJPCuwJJ3CIUtx4xrMAyhsujZj4kf6h3I34c4SGJ0wnRvfOMahdmFAMU+pH
gBCz6mQo2b9LYuv5V7WDqpsUqr5A6uvyl+5rSgex6ZzbkLAbA/zb7Pd0ZXZB
fNGX0ChJJiKdivOo2R3oMvyQWl1Mh0Pa6Nc1bY1w8WkP/3OZ5Au9r090o/yg
OcFnsYn0O0OfElt1dEj/+OnQ4cviLAS2L09ZP3wN8xMfn1FtCPyrpxOmYdaN
ADZ7CQLGYfZdRphypwc907q6zsIsWOhqNfhE96BJ7EFQkPQEhI2TFf39ST92
SLRaeHgQQa71bsLXGzDVsHC5oJmFn57bwnm2dEH7kZ6TjSoLX++7X81RasT5
l/wFRrfYEP0wE9Af0Ifw40XLXEk+mfX8/SI3vxKf4g1Vzqwh8P7osXe0rHpc
LhdrfEXyh6d75hctrQ54yIcbOKZy4GHqasF+9RYPAmf3HtAl/et5T57Jh5Xg
WsdeMCbzzKuWnUphii1IKKsqOWPLRO37CKVNe6oRktc8UGJA+t/D7PHT54NR
xn/hfZozOe9vvsc/WFkPNTfKsr1FLCSUZ9huJOsLoeQbHVvOAM+rS5l2t33B
NtLvuk7Or0uBsH+EUSU2lPAs272DQLiGs6bE9n6UcTPnJTvZ0GQJG7padyJw
UnXq3EYC6TkN2YeP9yPoRnXo5pWDEJvzMbL404EDwXsx6crCMbOIPHOZQQjQ
6/QkTEn9Wfkyd5zTD52Qj69mOjg4fWflxSJ+KgRguPVxEAuGngtW1qq9WG5q
+DDYkInMvbLqR4L6IfeoxMCeReq/zBHLx82lkI+37zFrI+Cx30fFvjEWC5Kp
m4TJfbe2Vki/VEiF0ib5IZvxYegVHnvXr0UDe+GmWVgjB/yPfnQXLfQh4+xk
X+3NMdR0x1Jv1Xbh5au7Xx6ReZ5HRGir268WTARLy+wWJ6DnqJ8yFTMC6a4m
kZtnuKDQVy7Y9dHADbWeLJMg9Sh4+c8Pj+uxbOOUTWYRAz+dFaJ25daC/8f7
TzIKLHiV9nUejW4EL53PZziO9L9MDUbhwz5UxggqZxpysG2bSoi4SzfWLh0r
XPjLgW+T4d/E+0PYOrlQmXllEqZpg3PS6VmoGRiR3W1CoFDxS3BKQx/ym6lx
tAgWfAtE/dez6tHDNY+5Q+Y/Ce346eW0bsQpnmm+T/KlbzuT549bIVwDR0VC
SL7uKLh+bdPjz2B+vCkbuoaFyvyZBym766HF2pOx4R8GXPvfPX8q0wSM7434
O0b+f9lqS1GdWoz8phVxc0j+UP5WFzCeh2vVs0vSSP7WH3px9S/fIJJit+x3
C2BByl75ADM4B0YOqj3/kfr0dnGHgeXGVhgfXV8rzGHg23C0tFFhOwitJW8Z
5mw4fuoqr9tEwz31G/u14oeQZJeoeWhNAn5Mv9y+1pzMd4wpdttkERQub5h+
SPpzE8vkgnR0gPJm6Y+aswyYdo4e1uPtx0PuoE8p2b/GVKrLyQ05+C/FXlr3
GMk36aIvxM58xAVfDdHOQBK/yDWL1MppED2pk9o0R+rZaM6zU1/f4o6+Q6Yq
med8+ySvSB6sxadUT5vSbjLPeNioVHF6sVSt9Rn/+mFMV5RveVZCQ4jp1J3n
Z9jwXJtnf7thCE5+LpqjZJ5TV0boo8IKiG97P3GP9JuN6xUUt4oO4Qk1XjfB
go0+fs5AcWkLaH0MSbNqApfc/1hJZpJ5rmNkaAU/C0c8vrcc6MhHzPy/Xj6/
mfgqOlRw/kEnuI/uZ1+T4qCj5gv7pWIGPLBYVlSUgNIxX/ed2kPwdvkd96Fm
DOoer+v5C9oRr1N9yIjk20wtWz+Lmn4S78z55mg2UnJPm2bbdMHYNeNbSiQL
3LGzbzxSK2DGY324ahsBtfu3q8WTu7GLU1v3/AQDvinRiT+a8iCgVawyWkBA
IT7z25usCijPSoU9LidQq8Pr23yqG/8OvLAzX8uF+iuDaMdBCmyUvvVe4pD8
qq+p6Kzbg9W7jCNMyH2xFN+VvJJejBUJ+fbOX0l/0eW0OnyyF9pWczLTZP4U
jf9MOSdNA3/aZZft1zkwzTXxUbUuRkto4PN9Zwj8F+z0b0rKAN79fcrb6c7B
wZuBcz4c0m92lUUNttMhyb+/zFOpCiX1hgMZtQywdRo5hyXrwDi45fjYJANX
isLst0XToBRyxsYhnQn6iR+jepkUrJIKLjNQYMJWcPBNGLUP98aedV8xZKHW
ZME0VO89glcPp96VJ/P5HXVXv34KaHU8dntfs7CVw79Kea4OLhW2h2O3MxEx
2UEknaPBV7xzXJPUe7FzQh8Kj7chUdCEtpz00yk3+ahOOe0Q/0fs2nZiDCuV
jnyKepcLzyTetlNHCEx2aRn7qdaj+Hq4h3IumQ+mdETvHuqBilVG8BNFJkwX
+T46/j4ZDpSYTkMyH6q447VmexEivt21/naP9APF6YtMfGpw4mxhXgP5nrSV
kWsGqlsRcqH2+8UIBoQW62oxa3PRv5myXWcfAf9n0f62lHaIfTT+9LmdDZ2o
Gw3DnV0QXXvN6fQmLqj5z4u3+Qwio3nbu9ibHBhdUvY+p9oB8XBpteFg0q/p
6rYYV1Lx4IxEliBZ79Tn0anloVRI3o9xL1pN+sE7NkUSZVUQux/mkH6BxOPk
tWvb/qtD/3fFPXpyJJ+8FdEfo/SDEiEsH/SQi9Sw5ucsVh9uCu8qfSfNQiZX
yMngZRFEV6yfsiX99b20445a9iM4vssj0sBvAkeVFDPVcihIZ9ys/sDHwKzS
fOlrSi1s2c5jkXos2A0aM3dJPQH/QTERXxKv9kO3mnRqasHTWqBnp8TG/wDT
nBI7
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs01Vkfxg+hYlBuU25hXI5YJZWRNA9K46W8iKIhUiTVITJpUokkl1Ah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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk41ekbxs9EJpUspcTJMmXfI1M0vxuZQiQ72c4YhiyFVEQlKZGlXR1N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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekbPpTGHl0mS2SZQqWYUlTq1qqFxq9pI2UJ0UK2GMooEiKSPak0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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VG8bxu1FylIkbUqkEhItli6VLGkVpcVOJEoqqZCUKVGEbMmWbD/J
FoqUfWlkjGXGGjNnxkgLQiX0nvev+ZzPc855zv3MdX+v617jcNHcWYCPj8+G
n4/v/7+OoZX6d7Xb4d8wYP3oAQHX/67V3YpsgPBuqfL2tWwETvTlhn7vxMTW
T7Yqv1g4kq7ydO2GDzCQ2RPQYskBn8Ntb6VH52BQ1l9PsyWwlsOcLfChwmJQ
Oft5CQt2Jf1uXIMgyLso/5lProdLxscyC6gQ03NPLX3BxhkV+6kTEw34G2Ot
k6JFgO+j53pKnh30NuRaniLvv1BbMcebrAKPzZdweZJARaPEin3hTET/NqoM
6BxAceLO+k1L6vDb4evunc8J9M52xP9s7QOjsXNe7RsGSk00MrUUWvAtYMHa
6JccnP86OXgzohZrU6ck8pkE3De5DmVa0tATZZ8pvaMPyZWYR7F4gee78qdm
dhGI5H5Tm7egB89DxBYVqQwhU3/zUQXZSsg9PmbJUCOgMZR8P8qoDKyxrfEc
OQKesznNSmNdWNx4y1wjfAjuNZaXikLL0a/qYO5tRCAz8UJcSVYLZBPPJDmV
sjGuQ6+2d+0E/b2Hc24OC1GyGpTA4Co8ttGOVKVz8HRupZzYZwbEC3qMRhcT
OJOjfPmAUT1k8wUKDagEJtp879cvoiP07ptVX0wGQBy/JkbPakP8I2n91LMc
7OAbq4wY+Q8PbJMen40jUEU5fiYmthzdmyQf3DlK4NHoPFGXE41YETTGEWGw
wRNo+zs5VIZNXtonDzMI5P25+zuU0wf94c9uKz+zMX/iog6/chs+tPbq1V4l
sP+jqXfxyl5EBHSF8l5+htazc6kVa2vAb18gwerjoFTk+7/MW134VTiy7ZLg
IISP0OPaNzPhH7rf7EIlD6GEU7OpeRcExg86UylDYOn/sLCIoaP8IUN2d8gg
jj7k5pj3UVGhf+y17hUOvNYLG43saIDQi3V19BtcyPFnz37I/gTe+F/VnGYu
fG789XCiNILOltbSXkBAiDJjm83HgObVEbPQUxys63tz17qiEnpj6dI5SgR8
mmSnw851437Kn6G7usPwefxvUZ1rBR7ExfKHzCOgqF6wI9KtGSI/pVc0W7Hx
H708TNiJjsxQZW+T4T6ciRP3tRwvwQdbIRtvBzaypUUdy1a1otRz9Ue32CHw
tbCnnxyqBd83t7MVqSwIZZs8maW0Aee0fiSsYSFU9voq1DXCM8JZgKLPhkCL
xMpM5z6Emrx+fiBwAFqKMxFLXZowatmol0bWM/psS8B62WZ8qN/j5jnLgjif
8pWQ+XXIbdqV0reOhfPfYkZljTtgvHln+pcIHgqiVj/a/qMPVis2/L4X24dS
6/FLtfo1GDnNmxuLJ2CDjersaAaWmX504Sf1wmdxXKpDiY6dR0vuuSizQXNe
k1LXWgceU/CQGNhQ/ixmZpDcjbk3NWkC4CJncbjS4J5OmKSP8u8f60NCkMde
BXRBTHCs46b3CIqElXSuUjvwxNihnnd2COWVIYtfalSh4IIQp1Se7PeHlFXi
bm2gKXS+mb3LgWnqrMsz/UZsFgnkuBYRSD0jJ9wS24OlSt9klxiQ+uCeO3W9
8AO0TihfjbhAgKchdo5anAPDd2dCdSkEltzUz364ogc8Y8t988SGIZbPS9zJ
7YHzCM2rsZIFSbZlZ+brfKRVxqv8dCV516XLDE2vwc+L7H2jJ9g4orl6Yo9P
OVj1ztedvpPX50X7nI52wM18RvZJyxD0gr1PPiUaIRa5UCZKmwXPutRzYY8r
cfbash/SIhwEGIcnqQU4wHOvruwZkl9MoQD+i90dMP14vdiaS/Ij1tDge14e
NskZLLojTOB3s628UFAP7PYsDO4KH4T3og7rUn4G/A4sr923iQMp18n1chwm
Xu19JJR2jodyc389A/d2lAnKrv9C5cJgZtos99NDRCpLCFPJesI9upf3cPIw
o6w3MbOXgL+FFFO0hwY5LcUXRvEszG27Wmi9pBXmO+uvSAtwIRl+oGbG8g38
xvtf5LwlILB4V1Wk8jswy11Ft7mReriduXS4LhTxbGtzqg0BPYa6nojNByhP
R6ZTF3HQ3rD1kHlWB1yj3xrslR/AfaNt1qZRJN9tMxmtmRx8HxWJ23ewHeHW
8VL9Y1z8ExnK0tesQCr7sdXjYQIHBpUelDowcZUqdGPchws+NcM71vdOYeHi
CIml5PndXWiY6uTeCaGNKQXlvizcv7+k2vBzB4KpKmt5zgTsJmpc9ScqsEjJ
s6PgMoHmC/0x9nfqwO2z1aa6sNCrd8BKvY8Bwdt/wjQCOxFQQVlRpcQATTLi
zNw1sr6S1e4Udztov9uhIk3u10fY5WxltmNkYMors3gIQZsNP58K60Qn7aK6
41OS70qHSyI3ZoJ+fMv5XRcJdA9dLfvF/IBf2jsOD4+wYVBkvOUO7T1ya6UO
bSf5MRoyj8fwzcCiveq6dQcISFoaGfkJ5kFaJDQx7gzJV7EXFa0WVMSoTcZT
DnHAFeo3E7lERYPLvP7Xv7iIzSwVoC5uQjrX0TKNS6Betv684Hgrdit7qm8h
z5/nb39sweNGuCZ0PesKZsNKaCz1TVcP/Mbctf2UWfjQNVc9KXUHmUs25184
TWAeJ/7nNxsGwlg7/1PiDeBBxG3BO3/eQfxZ4lAw6V9RPlMy95vL8cxS1/BC
BhuEZtOdjf1NCAhV+uO9lI08mbSrOs/TIBe3cjf/HgLt18ILIjm1kA88V9lc
y8HvtpKFrJI3oCXVbuU8IzBgoZRYLpWGxYNXszd7kbydvJbIUswj+0ptYeVW
0s936vcnh/bivYlo5ZVuLkzkD4r4rSyDb3fIuKgqgQbfp3+fxhfjspizmHcz
G3whv+VKlUIRRcuJUSDPT3r527kTkgwoqS9recRhwUksMNJblAbm6V+zLgc5
sNvpc1zh43NovXjHUCHrn7/5nsf5VbVwdW/v3CNDgDL1xS6phg6XbaUrk8nn
PeGwyvDwS1iFuZePehIIrj+Vo+zQgSaNofqVF9ho8GCa1n+ph8XVyfzjThy4
RqR3SnPpEOo22aJ6egC/S65FplPaQX33NvTd6yEkSyfYn5fohM3zy2mHvnMR
/9Iujr6wExHh+a4DyhwkLC+2b9WjQ+diqUKByBCy4mJYZw4xUOF9K+GC1CAM
fNKge7MInjqa++J8CSQoWkV9iSiBiKJ4tlkOGwFOt8yiElqReaQnYAWpT8lo
hfdBndUo/W9jjc09NiYypEtlVrah6HreiqPXWPga9We3VEg1VOtnqTGeHKx1
CXG59bYVVc9tFB+LDeLC2cPHHv38hHBPStL0Ag7eKaXuuu3bDofx1dq6DhwI
8N4VRoi3g/tam35PgQO6+Bl23VQDDh4KLvAl+WpLp53IdGlHwg9FYzttHnb4
8r70mzJJn351mrqJC1fNPnPVm+T3pK9O0FViI3wb83qOFg3thZc9QOZPib7b
1YZLW0HsmvYZTBoCrfViV01QJoRmo/mOkPrh+5f+wlerDaF5IzN7OCSfhY9f
JM58wo49y3c8CWIj50GvnrzfB1AMPIxN/pD9ONKqd1A8DVsoG9xqD5L5lNnA
n6HRhDfbygXGoggYzW36Zu1Gw6Qtf8XoOi7W7T1q2+uVjraw6y+X+RBIecqZ
EitrxwKHnSK5/ziQ3o4rzgmd+B0Uecr3J4Fd0vv8o90ZqEqSS5MJZ0Eg7Jrd
DuEuOAyvvqpBZWPgiMnKsL1M2F/Rf/j02yAyHx4UFNLsRHhAvWMu6Vc1LiXn
vEa60fqeRqGUd0B+t45qtxoNOYMbTy/YQiCdYK/Z4FsN7lfpmjEy/8Qdle8x
AR2PhDfefqPFwZJDN5b2B7Wj0+jryCGdXtgQZ4PNQxmYed5fnHKJ7JeyCcq7
xDbsLht+2sNH6kXoD3/EY38olfAveUPyzsloXlZJSxf8B1bTq/aR/mURbmpN
3ILz9L2jP6wJWHwO+TKt24R66VhDqYssBJo/rWsw7oF5x5rjrWYjkMsXT3H+
2oyvCkFEVAOpz1eBL6ZZn3CQNXgvs5Hk+ZxqcoVDPvIsbczsyLwV/2/D24wF
bWD97qmb/MqB51Ulx7WHm7FOiyV304vkGV3ugFV5A27k9X7QWUOgdLtGhu7V
BsROWzjyk7yO+XFp7OTFWhiYF5pNbOVCa4w7V6rWiX2nf2hPh3BQR00Vk7So
AaN7uYw86YdF4dIWr45WouHP58dBP8j3rZC9qF+aBKbOwcMu50m+nPeb7M4o
QvbJrJoDVgSSLRbfM89+C96oqFou6f+jA6Z8QyHvUZkU/OEcOQ/4bFf7w7er
HV59DhR+ex6GKl6nvyptRaSJTFOAEAuqq3jH2doNoF86xJQi9dYenxko8egN
ok5+eFduTOb1m5QFnqJFKL590eT9TQJyNPM929fVYfN0pcL/9RB3OsnLMIuB
iKZnVEY3GxmRnk/HK0qQeTR2glJI5v+1DsH/9tRA0mdy0VguAYXr3xQdj72A
QY52sRxZT9Tk3OESryLEf+6+t5ycF1wh7mjGbETz9XPFGSlcVIhHKjPI/W+r
5ngcJPmrmrR3ZM3WdnSLHfWTekr6q3lWeKpkLbq3DNSFdhDYERRcWbaUBvfo
uNqFgWT/T294mHSHivybe5PTDrNBPTX62b+wA4uqPbnC5QSIVQoZVkQ3Iud1
7bMs5UBehZEY09iC4Z5hRQlTLkTe/6I0+dJgP+F/cvw5qY+B3mxq8CkkBa4x
DCP12JpZ1epU24q+e8b/TqwewkD1gvc1JtEYPZIVEnCE9F+vKx0nDJ7A4sro
s3AHAvu6p3Sz67swL546VjzAwal2xiDzUzc2BCSJX/cdwmhl1k2bvir8lOE4
HvTg4FEHT01ptB2+zqHsZaQf7DFbZV7d3okLy97Z+V9iIedUa5GXQjVm3IKp
d/vZULA4YRVQmAY1nW+/CHJe0pf8ZTYT1Ao3ydK3w+Q8cUR3aUoJ2b9VLeez
2SQ/Av5+DjR+UIaxn/tPbBsj82vaku7nlm3IoW2ofrewF5o5v3q89lehLCAx
1T6T1JuGp5q8YznED/+1dw0k88Ac2/Z5XS76i9a830nqo0C4XzWtoxvXz4mG
hd0aQInLCZdE13qomPVZzL4hYAjpB2df0RBM2yU+94T03y7DkBVk/zkKqd74
lMlDccOdf3nnGmCalVAQR37P1ruam6VkWvB9hb/wDg4XU6lOzNdVzdhjGfHM
bAmZp8ZzWi/914UH9f+Fzu8nSF6ku60JDsT6FsliJUdyv//md726VQVz8ZGs
wk9s9D60uvpvfRdKRi1DBcU5mLEilq0jeTVt+qJsapSsR+jWSCZRByLqs1jc
SxZKbYZv/NjQgYlQf4/U4F4IMQ0/JT1sI3Prt9xgRRZcE00nNvxuw2+3iv35
x4YQ8Pvy/YCEO7Ay0TP5ZE/mwSddUdYFzdiYvza8Z4IAbe2zw2uPf4RH5Icv
bSRPfOT/lT3JpuLu5Z/Va73Jft+c9H31PQZW7fmYvaBqCG7s5XEJDs3w8E34
mscm67vUvCl16QN4ujlaSJDv13Dz27rpQhGarJ6Yq98i1x9dmpY8RvLLO/uT
uAq5/nLT+10pTfD3m26bIq+nBKjtw0atWOeom9X6movixXoeahLNuNf4xvMZ
ybuB4vKENeWFqNp12ytsE9mfTD+Z3PhulO+25Wwf/wqd2Zdt0YJtaKrd11Z3
aRA+I7PuEoV10NKcXJ6zgQOnG6d5lcvaob6jc7PsNS7SKMXCdTZNYObvMF52
mIOy77/tbLxpiM9oF1Qi51MNBW03F74i8ERCt18m/Y12wO6XvkwFXrQmCzta
cFAz+ex1jREVU2kp/W8jWQhPT/v11b0F/4r/LTeiDULEWPBy5eFOLNQs/KJI
5kGF+4QVz70IS4+9rVpMzovJCFoVfDcCRzbur0gm85GJKtFoP12DRamif9+7
c2FBzEmXi2cgja3eplJB4INS6dLOezdQfuDBnAHpJ1VmWmVey2qQ2KMxafGN
wNhknM2NBx3w33Q918JrEJqPdSJqwmpx0tJWRuMhC2ud+mpcNOqx2Spy1Xry
ebWjf5M9brShM6T6gXULB146W/2GyPrVPXwEFXksnBouK0xL6sYx6+0Z6+L6
UKT5++7J1XQ83ur5LCCZBQOpt8Wue6vxyykrODGWDcmQaO0TSMHqAj7vvyRP
9JYUSOV1NGG+h8qCwVUEDLh7oh2EH8JB1/yK/1kCmvEyM+3CPeR84i1kKkvm
l+WfFJcJ9kLVuCBGPu4rkv0k7310iMHi84IiCsdJ/UVmZJmUlCHb5brcClJP
PpkImp/cgYgDqZcuvR+C7wuWUYZKNVj//MyG1cm8sPzO8YbX0WSOdmpwu0FA
ZDY2Mnd+F+LuFr7VZQxAIXD7o5aBKGyrW3PNjOzH8WuPch460zBkfEqO1srG
ykXzn1JiOxFilC39ymIIxdun/9pepoGyc+nDK9IchIeltNut78XSRFo535oO
UAaUqkdyqjBwWF7GgOTJjbzuuaRAOsRShZiBA1w01Fq4ul37CEPFC6J/Sf7e
FylSbJ5fD2/uX52szyww9WJ3xupWQKL7Z9ztfDJPF5389tC2BuEp1/jorhzM
l7DRLLasAOOjzD87AwKdLYfEjWkNaPBZlWVcOYiASvfW9LyPGIh2eDLoSua5
/aHaO8+0IPfLljlHMj/RNuuxk9Kb4ZjwozduORd1b6/udSfzdeDZeoEF53nQ
E5xn2nGpHwMVQyMjU+T/l5cAdW86KsemEvXoHCjOXFZzyWjAbkSfVZcn9Zyn
3tC57RVyY4at7V3IfNA7HH3amU5y7Nmm8W9D4HM3GRcyZqCk69pxhiaBoJNa
Cuo3q5ArelJRZQfZ/30uu1Py6VDLq4kptOUhwFr9gulsKG68WxQhb0cgVIIz
ed6kGgLE1p6d2Rycva3vNuHHgHFAvJ3nzQEQsaUlB8tr4KDZnnhalIWBwrrP
d2No4JUdn6sbHkT4XmrAiX1FaLCIsRkl522aKKJ/SFWho6qD7+QMySPqMjPe
wVyonJUf/knyjbI/ZWTZIiY48yM1ijpI/TxO+aZsHYeNi2tdxcn+/B85BBcj

       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk81dkfxvVDpZH8JO7NWJqyZAxGi608NSGTspRukq7KvmQJZU8yQ1Iq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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns8VOkfx62Eipp6WZcoly6bGmKTyuKji01SqNC6hErRSsomEevShbXu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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lfkex4/INdFQGZqKNpdJsqQaxHyoSMM9GdMioewyFcKZaCE3kcgy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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3cgVQ0bR3rTJJWRlFHeiJKIJD+VMlIRskd2spJKimwio0JLIiorWUVG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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41Vsbla5Kuq4MxVcfB6UydTSQ0Lq6kjRIZShjZkVKknR0JVNIGcul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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk81Okfl1BshEIiV6ImlQ5XS2/kSpTYcqyWIkabzNboUqGlVFasW2R+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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkfNlKZmEKNfFI0pWUMxUcLcjeVMmUby9j6KmuSOeo4mYoKQ+RL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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VP8XximhshQJkSiVCmlXqQeR8k1KJPuSkCVClpJEtkrJUgolJCkh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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk4ldsbPY3kRsoJuVxjhGtW5GIZSoYk0kXKVCpEqBBFoek2ITJFwtVN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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk4VfkfxzGFjEJuuGVN0UJiVCZ+vU0lITLIT5JsZR8q+3KTmVJZQkY1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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8ldkb10JKSSZjnUiFTGVJTanp21hSKUkaLX6F7m1UGltJETeMNMoV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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VI/3loQ2EWmTpaylDZVKvdqkEIoUwoeypIVQWZIs0UKSIqGS7Mq+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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41NsbV6Gb3EgLkaUokgp1pZIP2iSUba5Euoq0ocjNaFEJIUshhUKy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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4lekbxynJXsQoUbZRtMiuwhcpmUzFzEi2pESW4SeVokZCJ0ukmkZJ
tsmhkq1CMpaj7OdwnHMs4Zz3fdsUmqxpRvP+/niu53qu53ru+74+9/d+vlp+
Ya7+i8TExH6n1//3El3mg/pTAjgOKZ0w3CSEpr5S3O2iOuSm9ezK/0ji8bG+
M8Jl7ci4GRAXbU7CSv4r6cHoRbdkrbM0h4Rv307H+DcPQVG71V/tovCmwtSi
BV3ouXw1Tm0/iaiHtiZ5B9sxEDoe/c8ggaxHGvmfDuYjqObHhAEfCmLODzO5
uWG4L2GUKaDPWZWFe5+ntKJS5v32Zn8Ssc0ulbza01D+EMJ+T9/H2btrvtbv
RoVShcHdagIMJz2/o9IcRA7m7k1/S8A3aL2l3JZ8JPlRU+4HKESG8r+wC9ko
UbE2/0jnj1VjPXELCcex4NPMETrec0NpD/WJbqQn8AvPS72GnGCpz+QdHlrC
GsknM0I88BzolLRoh9SI/SWxZSRSfI7k5xwaxPkAz45k+SEEvtYSzrOfI31i
i+sDTQoSv19gHGH0ofGOKJVlL0TuP9ZKJj90wu2gYVJhAgXmmFQbL6kOKX2X
pEkFCsuXu6unJDaCY1I8rTNJwsNeMUGJwwVBOGy/rEAge+3XiiYWC3M1PIsQ
fQqGWrNK6Xo8PFkTeNXTl4C9BFhSVj146aWr/6WDQLjnqGHZXA7UxM9qLj9K
QXntSdPx1Jc4HhLmP/aEhN+KjvePFKuxhzn06303Cn0ptwoqvdvRPFQanjdH
8xvd3WujmIC/VFe8qKH5RLbVL321sRUL8yd5et0kEgcXx2w+0gsqqdBVQpGA
nlF+z9wmDuKj21m6a0jEW64IzNStg0aLA55r0Xyzbc83qXejvMbm8bW9NL/3
7TGJuc2oOp5k51hC4vxo9I6dRXxoMbnqq/8VQeJA0bbPn7pxw/3TRGKiCO9W
fM85msuBar3GkKwJgZbWM+mPepqhovODqVCZwlSM3zunvRxUe1k0nKXj5RuJ
B2935MDhudUPIY4U1o2MYpsxD+VlsResaL0wRx1S+zUrcczq4nSlNwWrISMw
zIbxKWUzWcEdAUPvrr1+eiUi21XNArwodDmEFdktbcFMBCOUfYKEsllwRMez
TiypHnVnnCaQyND2H+sVoHzVbbvo/BEUHDU9cO4hH7+Jrcr21yLgMyQ1YV0x
gJ3VIybZ3UKI8fmyX//Oh+S7mtVDtrQeMiLMR13/QvnD6zuZURRWjogsihWG
cGWbgihqeBDh0eFfOk9WwWBjmPQWTwpHNuQcK5nswxvb/M3Zb0kEinSUozwf
w8fuoru3FYX0EvOvk20sMOVMzy6h+Z8qa7gf31kLiSW3mwJ+o6D7p7t1yHQr
ZIbqnhQKCIgOq15UBAv4ydhb4Ezh0e+hdU5Gg9gUl+RTq0HBFz3fW+5KRc5e
d8E6Wg/MsIKU2YB+TPxyvCxn8QikapgmP18Zoev3ZZmtHESs/4r5tnNn4J8W
5rHyEAVvBRmLf9RY4JunFPtuoJCzZ9P7CLcsON+8kc6g9cncOhh3aUMz3ug1
yKqMk6jqk1SLuP0KeuLDU3XFrxB/cbz4V1ErBsSKciLGCShfUJh33tCNrKNK
3mW5BDrSnL3fKfXAbMfckeQvIjwwLt51Dg2Iu3fTOoPWt5TdCubXeT4Ewyy/
QIjgplraXqDLQ3Xv2HDjTwQstQ3EBMYcLDSmOVRMEFhKKMRdnunE2bvymuKq
FAKf3+wf/LEcn1tl9gctoWCaFb01PpkHc8GxRVxDIfoMPGfODNWCkfn98ZR/
SeSoyFeop5TDLNHgbxtfCted4ywtrj+BR9LYU40gChlNB6v1qwfBVft8hMyi
sLvJMeBATh9ilXmGh6PpeXWO8WG/70LGzJ+zaodIxDXfONCpxMXWSfPJ6RAC
7yTCdF4EVWCfkoPzwXkSpSb15ERrC2L9lsb/tEBCWGsf8Fm9A1PTHpdLWAQi
+eGTOU39yNSwzT4gQfeTMZ6quvEO6ufdXJfR+n7aaEbcn+Ijb22sj3coAU68
wbkoVTb+2ERcZ/5BYjgqILbx8CB8g1dv+fY/Ci12ak0r+9kwNSn6VF5KwNZx
vtehtQr2YyoVMnR+5f17Ghz+GIDe/KBrhbkI/gXu3CYjAWK4O/d5B7+GMm+H
V8KJBpza5vAhq5LEvhFnIs2pF1PJkbPZ90lsfue1dNfZJtTy8kpO0DxKgkP5
IR1tkLZYJdTWphB7qSuTca0Loy3DKWmWFGrX7b8auJKL+sak698xCLy59PlK
lx0HLgu+2oESJB4sEvt4P4gLTq8Sv7yfBKPdwnjhUDMWPS2UH8smYfpio06+
ZAXyUk7KDUdQ0DQYi3sWcwVSqWnniuj+MY6HVWt3dSG+frgzZBHNt/eZn75N
D+JPeFuHnSXR55q2KLSLjSrm1dHkTNpfAh+VrQm4C2dF2aoyWt9b/AUXStNe
YEr22o5fVUnYcoU5V0cbUTkdLMb9Sv+XwuSZtOwePN0U/zBYna6PO+RlTdeX
rL2nzHiGzidTN1O7ug/FxcEhFZ4E5p1abpLDbMgcVFs3Qc+zQoH+FlW3Wniw
Z12wnfZTqyXPpnc4gzCzFBjQ8xf6nezRt/sGYPSbQGPiOu3XQ5JE/WYupN9e
na28RWD5hjLeF5tSuJ6Ukyx1oRDukhrUcboN5++QEoQVifq5bKfbLw/hxtb0
yJ10vO8+5C0pb+hFhMbbb1UhIriv1XEpX98Cj6Kgn4sUKaxVrO0ZZvNw/t4q
u6DX9PuFDEuTrlu4I1/9Wpvm0bf13jcVr8dIqpOL1FpLYU7Na714XDv+rStc
HKVDIkLpVO6jnGbcypPpELZSqLe0Wx+azsfPnwRBu3VEkFKvac3bI4Cx98Qr
8ZciXON/uSl7jY0p6cXezYUUYiJ+mW4tbIb5/r1rFOUprP9ovKEwpw3JhZ8D
y/+i+/VMoCLRxEJijIT04T0USotqu/480Q/dmEYn+QEhOhY42SMfeJid7VEQ
7xGi5Zy6g41cARR0VfZfo/1CVnDH555MAx4v8wm+RfMOCtSJdUwXwC7hVKkN
S4SNUhmDtrubMD6f9MaF1u9/t1a4jQ==
       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4VekXVko0EinpSqX50WSSMCblTRoplw6DJJUSSRlq5LjLIAYJYXIJ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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VI0bxSetlpAKFZUSJWvkVakjyVJeS6RIIq2irJGIlCQllZBUSFEk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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81PkfxxXVEiUdRqstkbVNi027qVUvyWod9etiO1wRyVmOlHVOGleE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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs4lOkbtghJOYQUOYaylXGW0k2hw9JhqJzXKSNJq2yr3XLoaAulItU4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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8Vfkbx41kfiGVsVVGUrYsyWiU5MO0yzqV+EUkyTJqcBlESI3QwpSy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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VP0bxgctlIq0L7ZSkrzK+kbdKhUSQipE2SL1RiXakKxFqciaPVRC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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lekbxo9GZZgsZadBQpYMUlTqohOyjGiQqZREMUqWMSGVKYVEtNgK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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs41FkYxyexW7sUFSEklya3pMVWbN9BuZQ2KSW5VS6RikQUpZJQwobc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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns4Vdkfxk+liDIkpX6UGkp0IZdxa95UiImkGCEOudUclzAq01ANxZDL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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3kglGsbxhGKJFsiWyglS45KiC7kSKJEluy0SRSlhRCRSElIIkRyVCJO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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lekbxqVJ2YaEUIOErC22sdVlyxINaUGEbENCDFIzhFHRlGgmSray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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81GsbxrXzWk8rU0lRpEKlSLgsdXRQ4W3hKFmG9yRpIkvSCYcOSatQ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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lWkbPqMyQ4oihJAkIyR9WrRcMibztUxFTaZtrJEtS5xOprRQmCHF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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VG0bxyWJED0kUU8qS4uylUL5SbIUhVR2JUUhkopSIbImSngqylaK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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk41Wkbxy0NmkRmWmbEZAuFNjSU+hodb40UWcfaIYoUMkjJKJQlxSBk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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81dkfxnWT22DMjQgtlmIMNyE1GHlkKssgFc1kS5StUFK2Bi22RlNN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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8ldkbv5hp5YesKUvLDMlMNI1pkr6aKJUKU300UhGSELJPTGghEpIl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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VO8fxaXFVhIqZakoUpJKSHSElq+INkmyJVuRJSktVFKJEi0oS4kk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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41dkfxynZ0iJbhn4Yki1NygxFb5VuxhSRZFBJdoUJlZrKWErmWkIT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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns81GkbxhVaFVLYrSWlty0d1mEdkp1col5EpaJ1bqYt6bCVIltRJBqH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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4ldkflwapDBLppkJpkTBMqUk+FYmUGCYJyTomoiYhiSwxirrST0WW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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHc4lf8bNiqUilBmJfGzUlZUdEslKhoykiKFhkpSSGRntZRISSSbZMvM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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81VkfliZpGlvDULaWISRkCSmPLUnIuHbC2CpERQpNQxmi3izJFka2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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk8lVkDvmGkopHK+EqLcfmIYrhE5T5otWRUJutoEmMtsmSJEioJWcIo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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk81VkflkHEi4wmRZEtyyivvGnjESpTRlKKxk4ThmxZymRJltcIUVkS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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHk8VF8fRshPVEobKtqTLSFtHpSizZIWFZEliVRKkyRLWQsVUUqipJA9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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81Vkf1mCYxEhIGFKWmBYpCuVBMYWGUChxVa+MKZq00ExSZCtLKbRY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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk4lVsbxhGiU6aIEEJInBKJkjtzKYpCIvNQfUdppDLzkYNCpjpUIlNs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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8lWkbx7UNRaihlxZLCwZRyCDjJ2WpV8uIKW8NJXuaSIiIJEvWImNI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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2kglGsbJi2kok0l2aKkcmSrLF0SpY5IWdJGkmRLJ0XlSBRZI2tZE5Il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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8Vukbxl9C00oh1UQmQ4Ux1VCJXGQtihQpeyGTkX0ptNgiJRoVBjGa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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lekbxsuYkagwpBgcNenIlpRSwyVLmSylqTQSEcJEp6iU7VimJNSg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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns4VWkbxiXUUNrTVLaajyI1GecwTRO3mqIwjVNSGUKkyKlIQkrJISLn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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lG0bxlWUpChK5UtICKGyRTllqUSbhBbylp0UJZJsKRRZkiSJQrYi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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk41dkfxzEtRn6KsZYsJSRTSmOJeqtxxaQRLbZUlqxFdTOGNKGyFmUb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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVms8lGkftqwoOWRLUmnS1maoJWIrdYVWlBxCUZTD1HZEkdepaepNW7ui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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns8lOkXn4qiSEVFJGyh39qwP5XS9kXWttIil0QKKdpNdNsVlpQ2k1LE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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VO8bxodUshRJCZUklS+lRIq6kUhKStmSZG+TZEuIUlFSiZQla0hl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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk4lekbxynKqMlkVKIRMmGiJJIW36hhilQGQ5Y4JDTZkrKEJmXPTAmV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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk41WkbtiR0TTEzCGksI2vbJKJp3EiUCp/UZAktJMQhjC2MHKUwkSVb
lCwlRdZsHftylONwLCfbOb8f9c1MiISkvt/3x3u913s91/Nc93O/93M/yud8
bFyFBAQEUqnz/3vykK5HuxoLzA/OFa5pBExGlI5kNXNgJ+3IFDvLh4DzT2H6
BS+wftsF+S2aJHocFDmT+p145acsNlVMwPp3+bjirET8QgsR0jlLwsjWyVus
vA+ai0wHvQkCrNzSveq1Kdgf0MWVdyWxnXN3o++HUTgtDWxzk+NB4Fpia8r5
HAgb/ih81omEbH5zuGJ5FzRpAtezBEjkWnSpjOmwwaalP4gtImDkyzg47FeP
0xMdEnIgEf+t/0xxdTuind+ErEaTeMyTplXVDCB7y8O6pS4+XAbaYjkGSThc
0T/+5TSFT45gjXm+RFAxzbW2kIDkxIktxz8/R/LcS39xLxIMQcuVEF021sYu
aW4+SkI+Q/mqW+AQIqZupL024MF/bl+XkDwTChJBOvR/CCi02zh7FLIRKL1f
MKKch90rdb5a1t3wyFrU/m82H6pyjt2Hb/WhKLfH9nU7ASFnO7Hs2CHsjGZN
9Z/jg/b5zP3u9xUoWD7VPEH1wx5qUWUL1qF+RiFzPoTCm7GyKqOeBrqpnfsf
jiSFS8v+0Rc2DjcFden6EVDqW3FpCkjFT5si5uwp/iNtetsPnffEDyp12/+l
+HyVoc8MOdIGp57SPcUJJPL77dRiajk4lbBYZzRCYDO3Lnie1gz32L9EM2+Q
CHtueXmwcxDK8baBOjMTKN24PzzlwzPsjY/OHIwnkU6qEqZ/tSHxk27E5BKJ
Ib37TV3VLHT8Vi+aFkxC3OIQcXx0FJOpNLZ/HgkXiZCjApU1kIwvMZ5fJZDq
zV47mcvCjelM72d8Ao0WbcWq33MQI1TI6WZP4b57bhh5vAPJ0zeOGvoTGI00
M0/9kgHWA2nhiAskbJJPWlYIN0FPStdE+0cSCfZJZ4L6e/B9e/ri+jUC6gkL
1nvq3qDGuro5yGESkb3KHLGbd7DDrUYhlOKDVZZy/odPT9Ecs9i5+RIJ00bj
vBpzSj89b5R3Ue937su7nnW9RIDE59Nh3QRULa0zNZw5mD/mJmv5Ow/J+iV5
xoaN0JFbcZedJ/BNlh7hVvgK6d1nA4eSCbjLrfvuTnk9uM7X7gquELj228nO
UTsumCdrs23aJqH0Tl1ppLcH/vqzrUbTlJ6dFT/wm/rwyf/It5+ZBG6nlG20
GGfA98pgqqUJiY+PRB2PxrHg2N9Q61jDh+VcZNpWzQGEvmVsOVbHQ1D+kSEI
voS81tXK/BkCgc2SBnecRzDqLByY6M2He0LJ8vq3lfBJM4gLUyTRKtmsZBbA
hYqsz+WiQj6sz5zw8dLvgL0ip1uNTeBVIDFOl+dCQ2iPyt/P+Kh0XNtQHDIE
daOZzfRPPMyzgl3D1w1DVvIKd5sxgaChYMvdFgNIYSQdaqLqlSarSF21aAPD
4ePEagqBYeLihcvXq8EJe1Ig5UZCYGxV+s4+LkYtAz66xExA9V3mW8kgBm5/
+Ztu20hgHfNn05m+JgwLxx/UViCxqhsTW1jHRlPibe/7rTyYHjPdFNA/CLUM
vQsl1VT/iqs2Gr+0QiFUIxJnCAjMn64VUX2BJ9bBmxKiSOy+et3hHjcfUQdD
WLvtSJRGORtuUqnHsazC7KdTBHrEEhwUPzUhOnVnsqs7iUYJD9+S8ld42uIZ
cneAQKld+q0/xouR+GuG16wONY90IyemZCK6ZcIVNah5s526kjS6awg6e0O7
i/ZPIkhO09ZGuxZR3TnXqkxJeOtZf3Q1rIZHZBt3+3EqP/7XFqs0NrbeI5za
snh4GFDFlFLlgPHd5UuMMB4mc4QiXU9lYd7dwUrCgUT0g9EDC5xypIoH95I7
SWQqP9kSVcMGvdy0v1F4CqnmQW22gizYqhcvVCiTUHpkcOuiWixmGnaO0Cm/
MHIR9cnb14ihCXua6UGKf8mGOG7CfuzTC17b4Uxi+LCYt05rBbTWy0SrGJB4
/WfSOSyOIC7+wOtP2RPIr3abu7LSj2MmwkXmHQRyH+Q8Z2zNxLk/3C3NKXzD
94USF6Y7kMsT2lBlROCQvGLR13/ZsIzpLV1a46OzU3pZVWsAVt/z6rt3EJjJ
+1K1fZiBFmtWw9hhCm8OvSSsgYm979uKpwMJ0H5zr/LRewqLr+IW7vYkAk/w
GnQZDFhWpuezbEj4fdPTOC4+gdRXtNM3y/holxHx4Euw8Hcf06iVxceTk/4m
y3oPYZLrFWlG5dcuXlC/d7kXy89cvtJKCDhy+1W1lFswwvpzQCKZRLnC4vI/
zycQ5jey59QwCY0ciag+h2Fs/1H7nW8vH9s9vLJf/6cJYiHGz0PpJJw8A0Rc
w8dgOCrqYyjDQ9G299yhwgHEfq1SISg/l/EMMFO5y0R3mpLPoVACk0/mKo11
y6HdJOtXJk/CbHBrztNvg9gqRZ/UTKL8P078gEh4I8YSrfSu+FH/41clGXLi
Noxm9X8VOU9CIaVtZ+BKA5bamx2LKf9aOMEWbiJrYf5YzMO1ksSKXcR0uccg
5JPNG1t28dH6OfntvltcFByd7eywIlBvudJQXPAYZxzGkwouUvVj4lL2cEdg
EEs4tFQQkJLibUqN5uBG5l/Zxq7U/vK8Hx6q3wazMkFR3igVP6GotiDZjAuV
xnSPHgKRxmvhVlHN2MlunMmrJnDU99ud94w+tFdJvbi3g4/dBSKPWk6VYYOz
WkfUAcr/VScYj5Nr0WxjNTKpT81L2jfxhYVWXHq4NB+fTkBDILmjYV0X5j3f
1CblE4jboZ+pK9MLZbtfxjMb+Eim/fSwrKcVJs/eWXWqk2jO61b0VBhA4WzX
2Q5JAkk6X4cUR4Zgdu7AHCh/vKW178WoMQNq2oc3LZmR8LINFlmr7sJlDfuc
WYqvrCKjtHc326C/MYbagwR2C3dF/nsxF6InmeMtlL4Y9CveD1hhUNlmNatG
8Z3VX/FDmnE/Avs8Rq594ENJap6wri0G7WxTP+0IiQHp6RtB0bXw+nLa5WAq
iSfdbzNMPgxig6zn9UlBEv8D9tO/DA==
       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lXkbxr1nTMlLSaVG2ZpGKtlqJEOX9CIpISJSkihbTmIqQkIMIi3j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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHkgVH8bxSdJC1kKLYhQIZWlqMixJaVIVCp7ZOkXkTUlWpCEIlRIJZQW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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81dkbVpYkRGVIRpYWKSbbpKRHURm5QgjFGFtCKJqRqSxjmGlUKBKy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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4lWsXxk1JJ6ck0rBzhCKhsp0S6lZRppShZCjDh6hERMYM6Sjz0HDS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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk41VkYx1XUlEhZUsMQjaYZoqRum2+pSUpFRAuVXYVKskYkS0yJbJWJ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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VH0fxtHeo5KQLKVFSXgsLRTdPEkpeyUVhShUspOEUKmUSFnSokSS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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81dkfxqWMUrZGl6FJNWok0UKaqIdLZcgu/WSJirIbUcYaFWlUV1Ky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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4lXkbxlChKfuSJYZQWoSR5dNtRFGdBmGQXTRoIkXGIDLRIktkZBtL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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs8lGkfxofo7SB5EdJRZG2Rdrd1KFyxqYRZJCVlHJpaVMzqRJJ2LYVQ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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lOsfxpEWQh1Hi0LKmiPZU5xulYpCKpW0WKIkS0lZKkmlooRUyF6n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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81OseHpQkhRaHOESSrRI3yRw93ajTImeEspPllKXDiFIkjdKnuKWI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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4lekbPgltKlNClCyRLIMotN0YNbRIOWXJHsYoQpslDWkOc6UkhsTI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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekbPsikZWaUUSFrMpbGT2k11V1+MjOYIjFk7diS0qHMZAbJSJHq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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHkglPsXxnFbJEVlKUu2SEWhunVtT6mQJZIlFcm1h0oSKgmXElJJkmQr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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx5EyiFBpWux+JUuyTKmMj+xRWSJCZVRCSIlkSpQtxTXKEqoZ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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4lXkbpqGMpZKobyJNRlR2H9OCW5FlLEmFRjjDSSGKscyQLFMhGUVZ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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8VekbJ5oWpJ/Kkq1oFCVZRrtv0RQmuklly3JTyV50LUmIuklZE6KE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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8Vf8fx5USFVkpW7KahKT5QjLSsJL6KpIUIUlIQqVIVplNKzvZKiHZ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81dkbx2kRSUrCoJEl2RKlUuGjUmiUFhKukHXSQjUSooWUkDuqsSUZ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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk81VkfRqpRdywVorypSNEihFI9mEyRkIiiLFnKeEuUkEoivBrMlKQM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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs0lVkfx10S0xSRVzrMUMqSlCmXCvm6hV6ppgy6yZRcDyMhKZckFSX3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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lG0bxqe00GZJKJI2L16EVHrDqUUbFVpI9kpIpGxRslUqlaRCKiTZ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41Wkbx7WOSJRlGiFU70hZamQf38ZIzKAminRCkhOKQyY7x1ZZ0ojO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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs0VfkbxlVqVOiYyTUUZboMZQyFUY9xqxzhIAyikkJyqVwyKpeSxiVF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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwdlXk81dkbx43R6s4kUk1UlkgqSzLRND5RQ1OaonVK9iVmXCqSpVy7hIiQ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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2kglG8bxRVK9iRJkkpKsqSUbEdSSYWkQhJSSSrZlZBSFFooJFqtSQg1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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlWk81ekbxk+WaJtJ1iQRiRGpEcZ2yZDItMkWskQioYiISUkiS6TJIGMZ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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk41fkblbSoCNGQVGpSllQqjXFzJNcSypRKyFLUVUKWiMoSWozSYg2T
ooQwF5HIHiPLva79Fr5LDTI3pEkZ+n1/f3yez/M+z/vHe95zzntUj3sdcBMX
ExOLZ97//7t8DaEMtx1H/lHQ1b9OY6h0jKVwRgC1pFFT5cskdLJFDwy35WBf
zMv9t/xplGpob5+/sx+Xpq+FK/D6EErKhRCtlZDZbSh35AcF8W+NkleXvoNB
2bBk/7/vsPFpvKNoQoBrS5omNGcIDIUdtM6Iq0ZsgHPV5GIaoUdS/xr1EUDv
dmFvYjqJrJEWDs+tGdlmJ0fU20k43FLNnG7k4+fiUysP1RHgnqpZnMbugdw8
U9H3LwRqSncF/PhSjNwH0yGl+jR8FC+PJ4p3o/tq86OzASS05liX91U1Y5uk
wTPzShLSJ5NPpgZ2YeFxyfS3KwiELvrR86vIC6Wm6z9rOdE4VqKqGDDbjfBd
Y3nENIlQiUt2tyVvor1/WvyrPQ29e6sjlfzeQus4/F4nEihzOxQ6LP0O4lbl
54O+DyLqwKjE/v1dUJeRFgXdI2ERFzXPM6EFyeckXLxMaTQujvHfyumF9e5c
X/uLFPoscgNTvnegK/WbvDSHgPfnxkYPsyLcSVE3V3Rn+Oj4O3PF3nJ4OqcO
HfWjIR+qyo0droesQf1rnTcUQkNqVixbKcS8gZrotDIKgQ4l1zYk9CLEySrK
wZRAyqfuPTpWQuSY6hRHBQ7ArPZ0Qwe7BFOya8v/DaLxQlni1zq7bnRd29PU
0kjg3hVJ7vCyHkzYs88q65P4LHR4o7+pE8qzCgfbZGnoPjvrdWJHJ7Kaiq4Q
BwlojW/j9Zi34nHhmNjuYgprFijO7R3OxDe9ifW+FjRGw/IPFyQVwTJQtyHa
g4ZzjHD4mFoTppQ8JO7foBCrXVJkU9UAlavGU1bSNOiEOfxxNT4KqmNOpHaT
yOBwCvN1hBiyXr8zXXoAVcan+ZEmYXBsKOv/yvA1Zu3r1z7VAI65xPL6SQrj
th/j2OadGIoYDHSIo1EbNXI+ZBujV49bI2nnKBToZpr/rVuC0/td10hxaMRq
1fAXrOUBEjveu61l5m/1cZPMq4Nrzh8xssmMnrfd6JZR6kCPu1JQ2CSBpljN
jH1TPOQn28wdqaXQI9qQ32GUDcNX1v5qx2h4Rxnmej2qglH2UvF5iRTU5mdb
qVv245OewX+X6gZwT7syOiinA4/zEmr+ziEQt9LUQuJ9B1a9+4v9jz0BVozX
687NfUjSaKqoYHw2dUXWpG97NUK1h2aaeinwQ2oTP0q0o0qj/c6SnSS81y47
FlEcC9GW1x6DLjQyBPq6N70FGKixcreToMBifdzFsWyGmqs3ZP+gYOm5xWSX
fTW21Do7aXhSKKrWjrhhWoupoCQFl68UOAiyaXvaBPH6+JP2JRQeXOyvS83s
QmbQrNUsRcBonZKdWwcfbTdGFpx6TUGLVS/IznqMqszyQ19P0uBwMq5KWT7H
yyh1lUfKTH3UYrPcYDvYqz/w/q0mUO4akVWwnIdjAVusLqaRWHVi14dCZp9P
9IWjjr4kNkaZdfXYVKJNOXx8730KJxJjgiNX8lEqt+56vB4NsQ+jnqdnOFjq
OWQgdKRh4vreoNCvDH677z/PC6bRZ/vEriGwBwUqwQXj9gyfniXPD8w8QnDq
Hr9Jhp/TPslxA+58FHUufJhSRqLxkOKcx3vaYHxd58wiUwoBwmjewC4BGi85
v68XESjQUtxGnC1HFsvJ4egUhSqThVLnrR+CODxkvcaOBk8lhV3TXgOPXJ1K
pxYKd9xLxyvEGb3arnb1eUBgbOJ997fwWrD9E/rqGymMjP1kPbKvGOGxR0JC
DGls1N7RX2nAxZr0h5nZpxh8GauSDT8y+vvATtH4ncLyrobFj1/2IEf9eQlr
J4HopDZfTkIfyn6pUlg2SyJQKHHBPISPa/FmsYXeJP6Zt5Pg6lZDmfNEq1uJ
hvVFo5sDWenIKDobkORG4/y13HX37QRIjPi9ObqCRIHb0MzR6TfY8tPMhfz5
FGwvRKY90eSh+9mevwqOkzAbbPnk5vYKPSXGFWsZ//7imzSs5NuCMy/TMgpH
STizvD02V2ThbbxtmL41jcGxCCNJzi00BnKzBc40dHgdv8tr8jFRY+7wkMkT
Z4sL+t91shAodcBdzYGZrzVS2pvDhY9qic9cIxrsF47x3mvegcoeP7xlkNlP
6yX9BcVvMDEZ+EPRhgI35vBWkVI3ktRFNyUfEjiwymnU0ekNnA9pKxUfpOC4
5NNxySU10BTyyS6CQoZ38v7rUk1wmZk8zycpBufYGpd9L9Gvn+5aHk3jw7zl
ev6iHmjdc5/fK8Xg/2Jxd9VAHWL9pot/Zvpth4zDwpUKkWe5aTh0NY2p+ams
dWGFYPXbRXRvpREuZ7DUeaQTfulcTxMNJh+3yrYX9NeASy5o/MjozVAQ4rnC
kgsBP3GzHYvGduqk/ihdjSmbTeGpORSmTrF+SyiqxHR8S4aMPI2qvcE5IuI1
FC58XlQ3RcI6yugy4dmKG3tUulyPUTA81Kp9NKAE0wUmipGJNG6/TH2ad7EZ
5zZR2/MqaSiqPHwap8BHCiV2x/YIo7fJmy7iuULMzHENWXqbyZvZ0OVRLzpx
Jkz4amQDAXbufJu7tR2Qz/H7cpjxj2Lr1YZl12sRNLfnboUxU//i/zn4ai9c
ZzvcNrsMwibSK8YkqRO/ilYG7FhIYUnuhk9zRM0IU54bz/1BQnLWard/Ti8q
tc75lmfTsOPhjuqGd2Av/ibRJD0ImWDWpezeJqzvjPThMfdxNP+3ek3ldkiY
LTEW5TB+nOa4bGLwFsvdls8WY+7zwZJHB64IMbXjbahPWT+MNSs8/Ld2IV2S
cgs3ZfK5sVjzy6kSxu9/5r7YSyPlP8f8Mz8JcNFZR6pLn4C2wEulxaEdQTfu
6RhJkxDY7tT7vkGI2fTo2zrWFBxUEy5PC6rw8UfT5VEm3+qGxhrUz7XDPJ61
/rguiTQltnKAci8OqyeNn11OYNBtkewfz/qw8E9SO02LwAOPeo+wrdUolnfP
1W1j8kJx1cEWmV58zxW41PgM4n9vsLyl
       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs4VWkbxvVFyhiUGJ8ODp00JKdPatNdhFLJFCUkbXIIkRShUDRNY5BT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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VG0fli1KaA/tJUv2JUJu5JVKEpEWFSFahFSKt9BCKaRkSVmikLco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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlWs41Vkbxnc5RtlSQomZVEMYBqFJ3ZQ0qRyKHOe1y6EcKhQSphwmoiQ2
YyQkSlFhFBmEjZCzjRz2YP/XVqkRvSKMzH8+rOv59DzXWvd9P7/17YmzR9yX
MxiMFPr8VyPvnCx6tIGH3wYKX+jKjsIoz9ElsKAXEQZs/xlLAn9xH0btik6k
vHawfKlIkNGXJ3enphNfg7VZs8cFMJavUQsQjoMTd5+Z6v8ICiJbL7NDarG6
QJ2xJpUgy8tEU6EkHW7hIXt97Qg8OYmfS5Z1wK299fP9byhclkyeSZJ5hvXC
CjJi9gQLx962bPcbhLRxU3jO8WHcOKcsWzDcg9fm4z0OTyg07gsv3D9Zjcmj
TSNTpwm6M0zLtoR3YcbWISFqng/7na6+BhEl4DBsRYPuEvgcMZvdx2hFWf8r
5/uxBIdYK8MyA55j5baJwi88CkYlhqek8puwWKj5RncXwU8q3TsLpRrR06s6
l/IzQWpJumSdSScSQ7tU1cv5OPXOvBp+aZhWWMviOND6/L066MD6JviI1UdK
yRJ835VYHbuxG18uicqoDxFI3Ip8PlI1CGELppXBvAB5N7/U9etXYbKVH3I/
icB5df/QPrkmTNTn91ZbCPDQYFjC/WAN/NP+cBf+hUDDVWWvdikHR7LsJ0az
CErU4qRlo5oxcs76aFM7rbfQosj3Y71Y5v6TkUwiHzHqA96+O0sxqBRU/Maa
YG2xty7LqQtm827ZydYCdAhtbDVbnoDeyzW5SywCJ6tqFW5JJ5qro9qO3qaQ
ckBNyIT3Akpa/jy9BQo/x6/Tst3bB6vcvu5HvqP4WGB6r8Gbh5IJncI4agSF
VxfVXN++gp5HvJhDhgCP821l8u16kCsWdnpNIAXx62Z52eF3EdBp9WXOlYA1
lbapLjIBtaknGn51JtDOTV8QOfAUidc88p/Sehd9DLzpKt6Pi1niHQ5LI8hi
zzGCY2uglG5xkkXnw7fOYw11swnCU/UpIbR+HZIO/vdy++Ce8zamL4zASNh0
hs3qxte9UkvW1ynYHHy3V/xqF3YFMSo51+h+fQtwR2uhM39/i+PvBCGVOWca
5fph79tXEKM1ApbcKzbTPwWeO0Q2hjoRNFZFyhvcfQh4KZZuOE4gI5F0V2/u
BWpGFueHRAi4+R81FvaWoGTBaHWeLYH9jue1zN4+fLeU0GvdxMfkm8tSWnK3
YWGfsi3YjSA09YUjz7Abmi5aGaM6AmzdrDlw8GMH/jnqU61bSmHz5fgUMY8c
HFScHpOg5+mbuoeckXiNdbdGbzLl6bz22IXGWZZB9YoJoyWQoMI1d3wwuRGS
y6M7eRMEhjrQ1IxtQPEkj51B6521etbrfVw57unfZpXR718rPiY7PF0P6U/O
o6WSBNmVEnNv/v8SrXx1z+gWClKXcnScfbogfdpwvZezAG7NK1xEOhuQq/3s
MeVD4NZkF3W0ohGf5OP5V36lYChxeHGGX4Tzk9fOKtN+jqVfPf9kOwdRNcs5
Ch8oZPEv+hZtbseR4ZMT45oCJDwI2N87/RqqVyPCzwkocP1+Xjzk24xUTxET
iWv0fucHOn4aqgD/faKkggV9X6akiP35Lvj06m25dIrCJomW8qr2fmSl+bGU
LlDIUwz4S8S9HX9kKnJ1bAgY+UubhJ6E0dVWVpjmke/bzwrBLm3wZVRb1mym
MLKq4IfxY1UIkzVfXlVMsKlQ+UBmSy/c0lf2LLtK88KKJ7Kxvh4rQ6/8zqb9
YumbsVru30FB50+cxycJdhgyuZ/qupCxrUzY4CMfwrxJTzczDuI/lzzxLiLY
oyjjDr1O3JP/To6/UQDtkNbqMqoQobAZf3KIIG+3HpeX3IHs3FN7rBIpqNp7
amyNaUNAUrO3Mb2vVuLZkgLdQaRFiUoci6D9tPGOVnzThUSdkwddVGl+Bbt0
aKh0Qn91eYr2Vgqij9RNGtq6oOf9vaV+mgCXOaIyRy720Hp6EaWvNL+yY9W8
5JoRyiR3dh2lsG6PAqPdtguzgvLSOR5BOaNt/efsJniIbtFS6+WDNVDutcAr
gk7WyzpXb4LA2bn9OSUNON7Qm2y6iSBqT+5hufkUnM1IuiTqQrDrjIm/iAoH
jnd55ef0CMqWeUc7XhvEFQOpW+X5BOyn6UtCtnXY3dh1Pf09waT1MPNcZSOY
TIlaf3eCbS/qjd3uv0ZM5p/WojR/9aa3sTTWtkD8WLaCJ93PuqB5aIdBKYzG
hQauBxCYJyu+u+TSBXNWe+qPjhSeKc8evLvQAw8/arrwC+0v8zdHZzRD0/9E
UK0DzTtVv3Bnk3rkcV5Of3OCoJi5KhNsLqT9zXLj2whmbmdGLjpwMZ59gzNL
/w+nIqcUWPJcpB1fScz1KEhPaI2N3qvCs9asFd/eIqj+6heS+DwZ3LyNfRY0
j1g/xHq0xfRgKr7N8ICsAEpOg7tOTXPhGO80GFEhgE2g5nab3f1QzvRW9hmh
+e+oVDnwoQEVNVpjH+h5Q7sD/ryQy0HEhpNrUsUIfsy456P7gYvoOKH55gYB
NKSYe1SOFGFifCDPeDeBx1CfTF/mK9QxA3RNhvlQLUtbN+Feia3Lb8w8p3km
7zzKLh4rAiPBRkMyiKDnvU3fhEcPxqviD/m68GHKlVjmOFSL2KS0gnkrAuOl
ftMl5wdw+MFE+r/9tbmZ1frQsgNTxaJ2v7JpP98FDwRveIrcZGuTD54EOd1n
P3Fse5CR4tLw92k+fCv6t0RXcvH4jkpFUrgAPu1xO7TYbXjLDtptbSfASu10
rbVhneDs39/3JIbgrZJdHS+lFs47pVmHM2j9xhR/iS56Cl9lsYQqOu95U+U9
+wvb8Gr4kAZU6Lz0NV5ZseYpzK7Ob/2D5nuJtLq00/U6GNteeZfxD4WIrGV7
2rmvYGOW/OAD/Z4Rvpqlr4DO14EH43XvKXyJyNw5e6MXfNn0zAY5ClHBuass
hbtxMdTIsnw7QZ+2Z8SQOb3PD916/qoYRTo79VG6QhvU3ytVh9P+eq37vfOb
gQ5Ibj5vMvsnhYrUm0Ns60L0h2H8Nzr/FyrZZYdXlMBsFVP+Bc1XtvuZGuXY
TnQsbTq+KlCAfwHOSato
       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVWs4lWkbpXJIplQITWMrojIxIQ2yEJJDGrPJsajdRBmHwSb5JCMZpEjI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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk81WkflWwV0mJaVMg0ZYpKwqvGoUyvqegmWpSIyhpDkfG2TKiMVJgs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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8Vf8fFhpKQ2V9W0ZRspVU8qBlFYlSVIhSViQzkSYVUoqMKCsZF2WP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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVWk4lVsbpiJFCI1HEhGiHAkJt1Q+QySaODYZtowZjtRXGgiR6ISQobap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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk01ekfx2+2JktjGRnXZG2RpE0i8m5TRBqUEMpWDRGVZYxtpCIxOUKL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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lekbx6kYGdXQaVFCIUm/ytqk9DVSiGyjISmhpLFWtjAle0VjLGUy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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VG0bx7UJbVosqSilFNmlpH6SEpXssoSUJyRSeVCSrSxJhZDoUalU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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41Wkbx5EhJSGFUklpDC1EE6KvvKVSvNomHUsKEYpElCVCIpmJEqKy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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lWkfxlVMNDTRkN5k6cVUFCYJ4ZIsJ9mTZQgplESkiBbClCxFaZSJ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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8VekbV/lNQpNBlmrKqCwx8ZNMKX2bqLRRRAZZo2tfkigVpphEZLnW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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHk8VG0bFiIR6tUmWXorFKWyRLhsJVHhJSKUyFqWKKRIJQqlqEiiLGXL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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk41ekXRxhbaBNGkWgkRLY0+GizZAk1kmxZkqiUopCshbKELBUJFVJI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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk81HkfnyIsLVYSqu1wdMmdcr6VDgqJVSLMKJsr16bIljNnRdGmknLX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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk4ld0axrcGKRWdBjRQpnSi5OijgVsynooGKg2mkFB2ho2UlOFLioqE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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VG8bJipLWUtERWVNQiXi55ZshQhJpaIkbSgRWSJLiEiFJJU2y1iS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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81Okfn6wOFfEj2daQIkJSJKm8E7WOyJXuWFFK6ypExEpytFR2NYiV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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lekbxpUWU0YhhTFlisb8KmSZpOEiKmSroY4tS6ppmLFEKUokCZUw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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8ldkfFkYkSZTq0tStMTUoGUskj0r0QcsvpEIaSSptQ6iMENpJlqTB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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3cglW0flkL0GglRiCIzO2lwSSorSUiUvF4ZRRpCSkaRFKmMiLSMVELK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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81Vkfx2+7CnkKyaArTbaENFkqn9QkKkuRJEIJZekWxvBMJEu2MfYk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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk81PkfniIpR0o3RRpXohDbhn10bGJdoRIlKUQ5GxaVpRRli5RNKNHk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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lVkfR5K2UZEaU2lhFEVlsr99GyJtaCFpYWRudqKQneS+omIIqddk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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lHsbxy2VJS1KUklKZUlZTjv5KrK02MIplV0JlUPJTlLoqEQhWcqR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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81OkXx/GTVCplo3Kp3FuWakvS8rEuEbFWg0JGlJlFJJRKUoskSVKu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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4lWkfPpVKGBnZSslMm++YUKRRcpMKkyxNE206GXtJxWCydELKkqij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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns8VFkAxyfVJo+NzZa1sii2VhNborx+GmrLJtJmSy/aKYkkDS15hCST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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8Vf/XxVW+lShDhSSSzIoiya9aKkVIQikVUqRIA5VIJGXMUEIisySi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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81ekbFSkhIcqoRpFG/EKDaDGHFCWy1JQKyZJlCJOMSMnPVpEaMU0i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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lWkfxokWS5YwZJlUiiilIWrKxdiGxkwhL0ZZEy/JTDLGJEspJSFr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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs8VekextUxh0qZ3CIMMpQoiW7Eo8YMTZpKRSEhOSQp7QyiXHYmJySl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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VP8XxkmLFtmlrFmKSLKF4pFUCEmKEmmnkGSrkEp9VchSiiRbESpb
luxj39exEzN3ZkSikFD63d9f87qve+fezznnOee8n81nr1pcWMbGxmbHzsb2
/19tbgulup9D4D/rebm4iUDMlgAHW5EWuCZGf7IJHkb6/ofrvfyakPVebnFR
hQmJazd3y2yugx2bf5DLFgLKlNP9u5378M7uWUPpxBesGecrrxKm4s3s3siK
FTQIF9ineVDyUHLJPe1MBIHauSiNSPFMEFfkf2UZEZhOLLbKYOtGVvUUo4KP
BpGCuNDt1VSIGnl9crk9BC0T/+tGLd34ZnA4WuLuKGJK6KXuRjngyWsTb7lN
QGNI1uWTQzd89XRmxMJYiOXaJ/UpvxW9Xga8XwoI7HTg9Nju0gY2v/gt0iUM
qDnOPC76UYuzI7YapQt0GG4M67nomQzRnrhbVXYEXFfuuXvvWwT0Eh+es7Ik
cPOmlNesdD8ezcfJhOSO4ATvqFahYzsCjhWvH2pjQW/F/e6lpT4UL1p5tL8Y
gOtrMV+KTh+SbL3r82ijEE6kRd73KEVAXCj30gIBwyXxok12/fhYfs5mZtU4
DIdUsp69pmBqo19d+iEG7NkXzcp2x4Hi6JC1y4XA77Pydl7CnViZNPU6T2YA
nWK58vGuXbAITl950YFAmEbHedEtg3DQd/EcOvENB2ie0v+U2yEcvfWE9qoR
sJVrl/Jz3Qb7sGHNEhmf0ykLLRPOfvAomOzKT2Ag8vWh0nb3NtxZu4NdaAMd
xieqnieXdEHcYjS4cc8o/P2ue9Zme6H5yMkrLPL/mS6CBWVfyrHnyCntWn4a
1MSuCdxUp2COORh84Q0B75Ci/L7D2VC3L+hg3CXgE6i0J9uuFYaeYgk6WgQG
5LL1ufb24Vfiwdj2QRZSMnJZn9lbET/zU/r8NA25SrFRRuepWC7EHxMszUL6
rFIst2w5nIoPpMV20kD7Lpt/414zLHXHzh7NYeHthlcmgQ+oMPszcIgtlI7F
/pfm+4268UjIIzZQ5ityz0k0Tfn1wU3t0mTBOwJlSZdSl7aFIEv6YPnmMwT8
P76ayH5WDAtRWoNNJx1nkzt5fVa2Y6DqylquyzT4OzounXUog6fK+UvJewh8
/qEnKRTWgXmH+6t/ltIhIOcfRtncAItDs1ati2S+XQVs7SSvg0948CA/mS/O
naGD53zaIfaEGbE3iAXxkc1p9KY6mNqLDbxVYGDbtUP5fkKt6JHuVNzuNIwF
83OxAbI10POrOez8jIb7P3/JHctvgZ/ju3hFRQZ0DSLbXk81IcRhsVdhjkAj
l4mbuVknYlJtmn7p0pGzfd6lxLEKHyRsm/M1mTiZ+PD1jzVdUNJa9zOqiECf
W1+ZmBYZn7eV0jI1GvQe8C7JJ/YgyG3mEnGe1PPTgty4l7ehXVuwiYc8v95M
66+4bQPw1Dy2y/X0EMrcRIzX/M3EwuXEadMkAmu2f8ypOU6BHwfWHdxKICj+
UIduRDa+i6+pEm0g0GoSc+tUxXsss1D/Z3KIgMze0gsGEl1IDeDtN7/3Fep+
zU81t/TAVjRHJJV3GF8qV9NT9VpQ/z2Pw1GXhuHH7x+HbnyA03qSsD1NQEBC
cO+KrjL4GLEaZfPpCLyzk+vtXCfuad9KspejoyxFlmOK/J5lj+DWZVdJPa58
I9InlYVduoUhHp4EhnNcOtn4X+PGZgGqEln/gHVZH6fbBhHz3xWPr7UMEJJF
HrGNbdg4+UhDtYfsFypl0GlfDxhnPpV0LA5hLLhE3VCmA6O/QtYTTwk8puSp
Sod0YNkKL5FxUxq+2ZUcUFzswoFz3Gl1YQREPrwK2nGqA/JG12Mc7o9AWNYx
pc6vCDNsnn28KQTMMzU/F/wuh+vSHQVpMj5D04KF5B0V+Fsc5Jq7j445C+rW
T9NdkJb5F3jzOxM9d7WVzCe7oPdqcJv7diYCLq7qqL5eh86EAamCF3RIWp3U
KeKIRnTCZZUyMn5zzmu88c3t2PpY8bW9GQOZ4lt3vqxog6W/zu6bEzQ0eqXv
eZ6VgziW8esGGbJepvWntryrwQ1Ft739v8n5XhA0wsjsAMHuoSFZRUej2vrk
BftyhM6GvtGRIJ+P4pmNLqnEX4HpJ6c3ExgRvMWny1+OIh2B+ttM8r6MQyxP
RzGUvJp+ZsUT+NZ3S+2Mchv02VRnfLwYiGsU/CkdHQCX6DsXlU+R/XnygayY
dxhCcpcdmCTzccr0qdLglV6sTclY/2mYjC+wvIEiV4fmH31q7V9pEBXydPwa
mA62sGmmVgyp1wmbp9l1WUhw08pezUHAXVU2y55Kgd0x0Z2bPAgQfT82rO17
D/7YTTXyZD8//TGcuLC8HJHqb/hvhBLI4g2+sta9HRmq01o77EaRHyx07p9j
PUakA6uyh2n4IfeX/7wmFV9vhMYougzhs4Ry/PpN3VD5467mwE7DVODR2ndn
CiCgaNQ5qULgSc/mx5tUvuCiyJoUkWejkNy33GfGJhN2M55mPwRJfeRpPKsi
992LPw6r4vpH8CLCP0Y/oQVeV1tjPnXTwMP84LMrKA18l32PXyXza6CVffom
Rx9MFrx9hEboWKh7rPEulgr7D3/WUr2Y+OO4Sjjeuw2BrjwtdyNYUF51dM6u
v4icjzFp4WQ+Ag/w7mZklkEuaYVrXxcBRf0TZayFDkSMqKytNaejVjfTykun
hZy/+62MqOT8/qBKVZ7oRUYyzcgqj9yXo9XdTMEscOfN+wy9IvelbftqmkUX
jEcD9pl9G0LJafdWVx0q5EU44r60MaBnZZ6le6wP+xwSYWLajRKtJ2s3SPaC
9nG1/WGZTmzKZKmzreuHsaf33/SPnTAx3+1uyOqG7hxx+10HDa0Pt2l92PMG
DPXK2oYDBIZY2uXZ68n9deeVWmEcgaox6tpph34kKc9/UNs/ilq1Y7eij9di
5Ze0Xs3/6Hjl+jv3sUITKAkaizpK5LyP7NbU1Uoi5/jpLdo+BDQfxC2b/FuE
faaGlnUXCMhOxlRvFO/Cd4M0DSkuOna3H9CzqSXPRx+RO6bFAltcXeXBHbKY
uYLVyqQ+RUfPREuKVOIwG7fzdhoTeD/bv2asHden+gpLXL+i03qX4y3jKmjm
froqtYwO1zOGd5PKyfosd3sjYkPq+UNbNpOahon0XxoPjxEIrV0qqRjtwa34
kwMcNiwkOZT6pYwPIO3Ym9IRS/K6ZrZFL6gDDiKmPBNkvdgos3n9BamQ43Da
feEKWV+BS4Xjb7rQZhXWHvWsHzGf+idbr1JRK3pA/XEumZ/XWou6yum4OC/u
oXycQFwUYTxBVCNk9sK2bZZMXEytyWQPbcdIRl5+WTQDS3E8pVopXYhyj7G1
sh6BpmaN4uJMN9L9I16Y6o1B++7tXbFlXdA09ZcbLWSi8mZZ1fEmKu6/jana
lU/DTEqXrqBvHfIsdn/7vI9Abs32mp1fqvE9VtjX5hq5L3gi+aPnqGh+K963
dXQYZS36dzg/BeLu+lLbYXsCv3Z8fXIxvw1hg+GakW1kvqwPUrj8c/G9f3tA
RzKp1/iayMWQJIStsZa1diagoiVo4zrUBWGPS3zX6V/J73z7kbapDTZr8xQj
m5iwdKx/2vSuCvWZMnse6tMQarSl4UcoBWMxfXFJenTE3U1J5hOrQqjZvEoB
J8ljMd7N4VUtWFUkSam6zYD/wW2R7m6RGPLcuGBzhEDRjnj/7ggq6r46J6oM
MWG9bN678xSp77iTF2pdabDVf1XwIDEHjww2ltQ2ExgtcY95Ti3Hd4mlx/PN
dCi7215NW2iDN03o8I0AGqwGzeNO7qKgd4Y9q4mbgRQxgX/1qW1AWBv7pnYC
59trOVX7y3HB15Z5P5mAfqHTRcWHzZAQU/G9dZSJyEoDr2redmwau9ZW930A
lha2q7Zpl4P7X55bNxsDd1cfobvqtGFW4UPgWWcafp/z/54bVgw2jd+eVeR8
lIt18PfTLYZ4Snj9MUcCbpx6bzwO1YOYiv8tPEWHtZVq1uOKbMx5VAtsJp8v
fjp9Ure9E8S7fUclJGlo8LqbYlZSg64VjJQ+MSaEKyqc8zubkE2kX+2aYmJ0
+tPyluRszJyQCLEQY+D8upF4V4l2+J05KSU+QkPwBYNCy78kr5iP/jP3Y8Iw
yUZVraMWW/gZUqG6I7BPesrj/LwZmvwZdOltTLiqzLbkHu+EVD1le20lAwNr
LHXNuetxQGKWL6KJgZ5h43XO4hVw1nTdF1tNB1yUht8r9GD0iRln46MBKK+b
z4xjb8TRn34Fk0EMJP288GSnfR3O5oWnxn+g49n7b0+Mj7RjcImt4aAZHWrj
2bumbftBqZjgfBFMgP36YECQdwZeOHr3FzkRsLdOmN3MHw3Z29RxDzJ/hKJE
7NoXRRhTDL9VSPJQ9NtHgkUxPYjeu2ffTnEauNWsPdc8bsW/f/HPDL4x4fRc
7YDgjW7InHRO9iD5kxL1/Cy3zwDumwhwNsgxsdVe3sLyTheeO72hpC9noVbl
vw3iBtkw1LBn/mgjYBzpN8idU4dfJ583ivyjY89NcRmtzm7cKzAar6ql4/hT
lfOityvx2nTXmyNrCCjY/a3fv6kdKQ8zuWdVWLDLCGhJcmlGJNfmor+hTAik
7RjL4OnApbrGq4Fz5Pxa8D93OP8jHrz3/y6wgfQn6mbLF+RrIZUSEVNoSsBs
kdOg/HEzqArR/y500KF3d6TfX+I90i35zdaBQJ1FePCHA52IXrZ1k2LSKMwt
pr6wr8sEt9jYm1zSz7jm/aw7V5ODm3qaURd+08Hz8GZ4TGMPppiXde+qjUKf
UiCysrAGxQ3LdOI4GNBifcyfFG6C76zPppwUJoa2qd9rUOjCeU8VF/MJBvjA
V2TUUou9QfnE9u103F7hnbFvqh5CR6pyPKsJSGt+VmDfSUVe6bfm6SImmt4f
mdih0I8QvsnMscWv+Dc+ZmboSsHrM8HdG9cSaDpYYbntBBX+6aPNN7YxYP2+
8ss6h88wafyYO3OS3CdCf0x11xbCsIazUYD0E4Y3HCVOjpVhrp/jmvtLkk+q
b1rNOT2Bnfz8DVFzki+fKLlWSmbgP6kVDs/dCJzrjdP98bMH1eJc/ef3UyEZ
sOnczmUVcAnOefvwGR2VtuXCPjxNGBo9Pv6dTuanUo7tiOhDJKgOaxuR+fPf
d+ep0EwCkM9SEjpB8sLxueuZoVn4/MqG95MqgRzn5Rrmvh3YwlbOy59A4M8z
x665E4M4uzEw/W0JC6kUOBy61oxioTff53UY+Fdv7cKJTnQK5v8OVSL9kGEq
5wHPOqhKN04kkP5/u+qJlcF5PTA26L0ctncU6Vtc/TcnUCE1eS70uTbJ2yPP
X36+EwWtwxJXZsl+eLA8sU72ZTc0/eQesSX248V9//CH7J24aPahwFRwBMZb
66q43tfC1nNlsRSZT8HUEu7pk02w9o9yy3hIh32L72En0q/tkpc99DCbjikf
J+UXTx8jcmWhtKcN6YdiKHtnmc1Yb3Bl7/7nw2BruLrq8qMT4C1bbXiM3Nea
qb1Ztef7Ea1uSf1VOgS2LA3zHffPQnbOiuMB6Xcio5ecDrl34OyCfe1AVA+G
3T3iBgqeI+WE1RZFVwJSCVv5LJwaYRB5QXsqnUB77+deV5LHu1Jk+v4j9S5g
yEjLGu5H5LiELEi9SM/RlV6rDcBa/4LXXY9R2Ns5L092bobIO7HgaxcJeOg/
kTmo1oOlSxElqlu+obdf4XbUFVJfa50vq/uOgqNAtFFJvQ2NGhM9quaj8LZY
GHkg14spfpmwiRsM/LnvP7x+Ty4OX5OTv0jQ4WUp2FoN8twvUp8dJ+fGcHC5
Bt+7VBiINHRcVSTA42e55T+iBNPXPq44w8VA6OZdvqElrWi/M/T20mcGGv8Z
hdIkq5GR/ZyjmYxPv2uiIo+tB1EKqfIvyP4ts6gL5+UOhEud/ZZwcj//djA1
ubi8GQsplwW6lEneX3mxY5ovFDdLbj17ROox/8OMfJNQOoYL5a45k/d5vr2z
jjNphYyI3Cqx7SyY3w5hNbtEILfBW9udfJ+9jHGhRmg8ujiyTgiQflGVoflH
PrwDrZRqGWeSx2aCY+ft13cgqf7zeAk3ydvqg/Iz3Am49cGjOonkGd9p/ntF
UZ/QUrha9Dd5/dMjQtxWuRXatlIXDgYwodHUzVXyg+S7cq19u0UY4HHJvTFr
kgM+QdkPqST/r79lckCugeRPl+qPxVrjIObDD3E2VEPtgZpAMYsGO1alvolO
P95GcFGOyrMgOVIjfiW5HTKlby8dH6Ah7sW05KDoWyy/k/Z1gyyBnffyR33p
jTDsWDBdf4mB3SGLrbPBnWRfDN2/94TkR4mRyqtN/bh1nMf2RDIDxl9a04zd
urEu4kpcqeo4WC/4hDldqbD0Df6ZfXMEo22ZHioVuRBIFlQ6P0UgJa7nagA3
BStXHIynkrytJXXlztmgaqxyWrhn60O+z25AlLWSAsX97WuTWggwvcS5TAKz
kCSxQvrAewK974/83lnahc8vvk8OFbKQcVDYWsA8EfWhImrsZL/Y7y5aUDrU
iCaP2SPzuky0xjyJ53rdj3c3kLFjA7mPJXUe4FcxnDRHzBQzCVRqBi+zHmhB
jrS8z7LlBB6WFHp9F+mF91u+HF9y/gXl3Jl5ZVNB+pqxzJ4hBqZ+ZF+ftCb3
1+0TXd4hBLm3tcZrsocwWbbtMrOHCauZ7jq9vb0w1FlZ+nuS9AN8RvMvK2uQ
/2rbURqFjiebuXXDU2rweJ4ZpvKO9Kc+gcOcDr14cFxoh37GCKb/Uzhy5GQn
EkPWTZTvJhDCfTjR9hgVIWGl+5NX0WGqsley6l4b4u0oJjMNI1hzozbvX1If
OoxpN5iPaCTvW/GMJzzFnsgdH++TfO7jOuZt3hMHn3pNgupF8jNbrsoVsz5M
clFS5LsnEGnyUsLYpQPp6rI2O37SsNLl70e3wDpYXbx/77QCAYuuMqteiSgY
S9wVCSL1zpYv8XHhWAuChmN+zBxkYap2SdL8yADJu1Yt4TQaejb0yUwxymFv
yLFqjOSlX79DbW6712K9/+dc/T0kj9lr2iVZ1UPPJzHMzo2JtPq9X2osOsi5
wDbxXIGJ/wHxKvzr
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81GsbxiWhg7ZDibJUEr0HJ7RQXSEZaRFKjkKdI0JMC0papZA6tmzJ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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs01WkXPsq9lFRyG5L0IQxFRHlichlKGCK6nEEliYqYspLo4h5Gkwmd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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwdlnk8lWkfxg2aiqyjHEoKNaaaNzUV2S7RomE0SVGZksYyyUSy5czEkO2V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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VH0fxkcr2hRZyq602iql0C0UIdlTKBL1VLYeopQsKWVJeipJhago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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs4lNkfH1SqbZVcsi4RbTb35FJYn0wbUW1CLYtsmEpIWUVShBiXlEu0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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4lWkbJ0UL8kUZGUkb0yrKpEy/w2gZIVlq4owolaRCKdt3rFlKZWRk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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lmkXVvjGpKZFxRTFpLK88fqaUrarlBJpmiwhxhYaCSkiCklGtjRk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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8Vv0fxoUGCmUkqaRCpVRKS11FyuMRyioyHiFKKKWBcpdkJSoSCRmJ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVWk8lWkfPpStYjAq2xRCmhaKCpXrKJUtYooWo4O8YxuhkWXkbQYtEkYd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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs8lGkUnoSEJNlVWZdcKmQrZCProVBrNymSS+6UsKUL5VLaSigJISuJ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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lWkbtp5pLKeQTA2TyvZN9ZWlheSSpaFo1KhkhJAiSyQJqYwiW4qU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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8le8bx09pkaaUJCNCNqUpHxUNohAhWSnzK0WRZEVJGZWEJGRlRCjZ
e+95rMQ5zzlHSBp28Xt+f53X83qe+z7XfV339bneHyGL6zpXl1MoFJNlFMr/
f8PPbT8oktyAhZUaEsdaCAx8q07Rf92BK9aSWsKLQ0hcF95+QLQTTYNaxx7k
jiA83yFYOLkUWeHrmqdDCVgvfV2ihPXCkCPGbnCgB1FhPO6/aJ1wStf7/lZm
CCpsArpdErex6bL1uTljAjse2bpncvRi0ZZ5dJybQOu+mj2e5gWIzVIrE0oh
EG7G3jS+UAdfjWe9w9douPfL/JLkkXYw/hVFmTnQ4M5mf9vuQCWqc/Rjtt4f
hrUVr9N37joonMm2+51Gh+DBercHFysxZOEpDBs6Tu/rkSusrkb0vqpfTBcC
jRcVe0WSWtH0Xv8qNX8YKRbfn2g4UhFu+LYqJ7cPaxzOhKk7dkHp2C5xgQkW
ROIOTFf3FeGvb+SJdkNyfXDah23bK2EgXdUS8I6BnNkJm4z3bbDl5vcW9mPg
/OEnzJkD7dCZmvrmosdAclqzs6lQKmqVRa5Z3CCwisd0vuhQH2pPbYx1EhuG
WWt0wBfb+5g9QPMqNyOQM+acu42jEfGWDBexcBqs79UbO7ZQwTE0/X6fxFcY
eJaGBN0pgkG863KjFXR8KHlj27aTCk2d5mW650cx1NzpPf5fNhbTM+u7cglE
H1s9/opRAZ3JuKHnxxgwSFfhPGXaAjnpqR0/aodBsRCw9aztRuEnrkfsNkOI
tuwSDrNpg2OyjOKCOQHHvOZEp49ZeKTING0g70cmRU3Fd7oEcYsh3Gbk/vax
xvs9hUsxvyHzfpQwAwLS9UT8tnr0qB06aeNKB0XOflNw8RvsusWrfMeJAKEm
8jBbuAuj95W23V4zgiGBN1aDEYnYXH/7oOsVAmlzXFfk2KgIWZdo3JsxBAPb
KxVsw30oHPw1bGzyDbcKYwT39HZAIeRIjNkxJsZb4eHNU43GVXNr+WQILD78
niDh34bT5yeVqLl0WK8QXzR3+YTqj2ZnmcEEpn6MP7Ppa0ffoqvQ2TN0rEj4
slc8ohq+y/95K+8j60XTavqn04Ys46rZxCUmJh17qzmn8tFouimpjU6gic2Y
v2auHpsLAs30KhiopaSIc8jHIkte5V+gBQGKwSscTQ1H3NoQ8R2XCfRU9Cct
RbdD3y5FegMPHQr7tG84ixZA545Zr/8aAqVbrI4GG0eg77NY6fNbBMx2aRRI
Z8ZAcmPCgBLZL+Fp1pv74vJwUrLszEwSef8S3/84Wd6J8JmRVKEXBMbyxee9
vFtxIseQd8VpGs57byqen/iMy1KXNMbSCQiWr8xMzK1An9KdtWaKBHbx39lz
dH8jjpedC9TMIhBaOsTyGGzAg85PIvaHGVBZI8azT7MFGwbTs6ivhmGi4DN1
c7oDzIH7mt9YDKh/nObwe9wKH/7HpfsjhmFc66X/lKseW8Ie1Yuw00CnqN6m
Xm2F7j6lo1/J+nfStFR1B2ow9IQi3txDR7vdqr8dlgOQu2PPdbfmG1k8zTDP
Y82IaWZPu0r2r5y6j9Eu60akL9jl2C7QseX5ar249F6csOrqPUTWa3m0qMHw
vm7IbWnNiz3BAKVN6dTTzd3403LJrtpqDOMIoUV19CMk4I1s7DYWXK1tBh3N
SnFT9aUk05RAfZbhs1/bmpDiHXx5im8Y0dZXV1MyO5DGxz2yKMbC/tCeK4nm
/fCcpfgJuNFQJJZvKiTQBLaC65jsIWCwadH4DHsx/BVvcXDM0RF6dlHY+1AV
AgSO75E6yUCj1YXJ/sheLO8ocjeVYyEm6OytM+4duGj0pCPhLg1Zp6JlQ3f1
w8D+nk2JzTdcXpcuHxzaCYXVIa8sXzIwmL0n6vW7LlCkrD3kWQRqNWuU6mI6
UTf778DRN73gj/tUeOpGHTjuiEf80aRjPL7mzTetVuR8DaSzaRBYsbL1msL+
NhxRfe7rx0VHdnZy6v2/b2FPecGu4kyg0Nhgm8VIPgafDrtevkDGf+zGSaPj
dXA/nZpxL4CJzvvDZd+4G3FWxOOZWwUdPipD4n1/itCQbRe6N4Fcfz+v4t/6
TsiEViqlNDDRbSzHUXy7CqIyjXl7qxkopzhNGV5sQ/Htvq22J2jwfZmrGx7b
haghdf1xsl/WmDl9LxGrwIX9y4K2/iDrLVvw5GrRO8wvnI0JP0Igxr03QWI0
F6snhCTiyecwoWn2T6FkPdtqrxBVw9Cvuu7XyKQiYDDAfAMnHZl2Lu5atgPI
bJI5nR5DwKRROp67pRWb2KYy58j7VrqYovW53QOny4827yT7Sf+C70Ovl4Og
nhxfe0iNidbFdeEzZWmgp54XlgggYCW9ih5W0I2Jmw50q3QWfO/OTFjx9qAn
zmCv1t5+ROu7utx1a8Px1uynMgs0dFa9KKuR74GOtnNi7SEWLqyv+TlS0IXQ
XElj84ekvirc2KCp9wg5v89djCf/fzpN43XKpmbUn6514G1iwoDqeyvVvxD2
60RvEJdIPW2TGrB4UY71L8Wmlq4xsbFV0lDEOgmqJ3vYiZMEVNQfrXF9GwQO
l8uJZ0h9ljr+t6X2dxfeD8td8fw1jMJF/zEZwV6c85/bXprAgrjgGrW8xmzs
qq0MGNAjECRn5F1XU45rNmFviRs0RH+VK1nt14aeqfSIo3cJeImxWZesfQBO
3TSTfHJ/A4UBOR7ndkiZ8oXF/iZwPqiQJZxchv0WbnHCuxj4IOUqvjO7CyOd
lMuT5HsF8+pNBR1UKAcvuN7bzYTg1MPJgWVR+I8/07HhDoHl9k/KmGP1CLW1
az9nTYezbs1dalMDjhesk/19iQ5FR8F1m7hz4cbv1PuonsAF9Y9CYnN1iDBf
GZPeRcfZxjX/Tr5qx9bBxZYiIRoS46Nvyol1IbJI4N7q2iEMxNg4l29pxEf5
512yTXQ0Xtkd9DQhAf9p7y5me0rqJ8+Qzre5alQvwWA1Ge/VoIOblibjYHvG
/bE5ef75KkpAdlIfTo8rlqerkfwja7txtXc5ip/pz8jlMeBmnauXNduJAZZ6
JIc5Ha2jia8rZtswtvBvldJOFr5nxQQH9FKxd+8xyZG1DLz/Q7HNNG3FjeNz
y1YrE5DLvEHEi1Lh//5RhYISC5yhUd8EnFpx2uRCp3gtHT2fLiteUugFb4CG
WvwXBg562tk9XJUIWSN91TByvsiZrVH0ptbgnnBxbWEOWZ+/g1/Yx2ohHmyz
etqfrM/jSd6V2h3I4aJPDZC8w6fPH/mBtwn2t/Lfn8hjwrbbNNxorgmcyh+O
WO5mQPDB9/9aJJrBnj0RNEvGV5ik5+BzvAahbFNSu8h+53zxTrjdtxoKtYqf
135iYMSLx5DnSjaeHLDx0LlPwNy036xFrxuWieuk372m4WxmAH9geTvMvJNv
v5xjwHeH1/ZxMl83p87u5uH+gkmLqSRd30QMp624qSFJwLczovBTWAe4jvm9
iSXzFX71waX87bkw8nqVmPKB1DPHV0685/qwTOSp4AkFJm7qEIIUtWZMOFYM
vLcbxMEI9feNRA2OJ7bZtj4l57e2/Qenbd3QSdyt8NlvGF5vemuy9z9AxI2o
DarkPE6mXJgWFCiEkktPyNxqBoh7sRo7g3pQ7Zg4NO/NgnCc8UwlqxvLpISS
5ksYKGY96IyvLcO0e8fnC0M0yA/67awa68eRMFF1hwsjkGZIeV1NKodYxfMV
CWZk/BpHnB3/K0Rs4D9tJTKfvPZflxZW9yP7MxezU5cGxxVvudxe1iCz57EW
excNoYbXD53h70TzFnmzJy4sjOo6nDuoXYdr/ae51GXpkIpSfH2eQs7HH86G
/6LpcIz8Jzh5KR4vjGzcDQwI+H/pEXCN/ALVVdlb6uroiBFJu3w1pB75en8s
l0cwwGcgK5M/kgIHtb9OnLIE9v3RDIrnz0R0je8v5Sckz1lmSbPpxmFibMbT
gMzP+7IVSeudKjH1eldLaxfJM9YPb9nviUDQd41n3nYkr0Qa8hm1lcInV2CU
c5qAiLmw6u6oWlTXfrmTKkXy91vBd7fbitB3xlJXpZKOZ4Ue0ukp9VB21lO5
5EHqywuhn+yKZVh3PFZDvZkBj/iHkgMK7RgPeq3esoeJ9U7Doo0xrYjX8X7x
4RkL48cc8Gp7AwImDYsKt5Pz4ZCf2rW2GjzZefPAPlEG/OlT818qOqHqLJrj
tEDet1zDkpQN9chYGc2eTZ7XJPmDZVJPG/6kXt8SkTsMi8MZQSe+dYCXyh0S
uY9A5O9m2sHGTvh/dDb/ZE/y91FltfHXg6hZzHwRpf0Nlctu11iEdYJ345JV
XzYDpc3TRY3u3RD/d0GkqbsPgqGv1j279h70fH6N37Ykv1p9+UI9V4tPtpf8
5gfJfO24InH7/Ec0tGRYfyL5c02HM9e5gkZIbzhz/+N+FmovisiuTy7EhMHS
NSsfkm9yYuRn7rbhDKf0ikZncn5c8Bw/dO0Zbnse8vS8SOCdTwj3TF03vK6J
+Xw/TkOUSGYNu103LuxUlL83z8KAvOL3wxNtUG/W+7nHnIGL9xraV6R3QzX0
z5XtzGGcnDU+attVj7CMkW1FJM+1VodyZD+vRD3NMeEF+b38SEmNgBAV6bI3
4baB1EFhienvK0sRrxGewUnm52//V9ltW1sxrkttW9w5BJHgI3584aQ/zJ/h
0l75DWkGbQ/YXtYjaYhPmceVBoN/1tl++Z/w15lHOlmM1H8b7kOUV504Ti8Y
m0oaxtJ2q/4Mt36Mvks0W72bhaOGhzNa/nYjZ6e5R+HWMQyOpJToHSnFybPj
l/LmSB4OCM2YWmhDOsM3994nUm+ESkZd7lDRrPH1p00ygZHa3RkHZkvxJNAu
kGgjEMLkn/p2pR3thO7F1PVkfSYqz76ZzwIhxt6/zIbAcY7vTtcvkPM9P3/a
npsFLzfuf0FNVFDV42RmlVn4mbj7JN29FUu8ut+KfjEwMZe1ILSrF4xRbROO
biZ8z5jmcW2oQ1Z5brF9MANfougfgoRKUdO+a1PeIB0Zv+iL2R86EDmRFfKD
5EeemFG1ea8C/Czu+bBbgIA73zmt7uEemM3cfOAsTvrBZVVMrvFyTDtFxyy+
JPnPL6nJdXM+5nitCydJPb/rqacf+LEGuuUnIu+NDWPj0kxkuVUvTBycUZJH
h7ilZbF8eh6M+JuohzcyMCSy6VTw+lhEp+45akD6CxWZtNOLe8vwb5c5a8tj
kp9+BVx1WupGuPVUwaG8YUxmc1J5E9JxfWvKMZfzpH+hdb6SzO7GLnqz4bLg
YfgkPG3vcKFCZ3ovf9iuYaw5Y8nVWP6ZnAt11mr9BJ6mfzTku96OwxPpR1lM
kl+iZrYsd0uDl3RIzmFy/pd69P3HGVgA1+rcjesCyXji3qkatd2Hgv9+nb8k
H/k8dr+4sqURUlCOECT9JB/DznVxvg7qCW3uBStJ/5LtrOnm0YvxlX9aHv0Z
gcqW0Wc/HR9gp9MLuVxy/d6/6dw5pD+5FMnKsltB6rEnl6+LUxbOStzRNpIg
9cqqSZpJ7UGc170DPVrkfergYve+XAG1isqetUMEAlatcCvRrYJGhu1CiScd
m/QdKA4+rVASZTtgbMDEGn3Jws3ncrFh1EzJu4GAceL7dTLtvVCjjvgqyZC8
+Hxce8OJZBxaekt9Sfa7vyvlqGxDPvjOIaqG1NsHl2hpLm+7UKhlYXLiziDO
v6B80d5RAcfZ1MJjPkxs0SzitjatQ8xofUu/LR1D6wc3z259DYpyVvMWsh6l
l7+IaZj44uZgoPQoyWeSJdmmmu19cFH8VdbjPo6ED8OrdI+R/VNv+vJFFYP0
g88vx0R0wzE3R9/VoB+lcs6Hu/fkQlTbsTrWmtRj3cvFe//kYjR652IZuV/k
zEH54369+CSW83FPP+nPtcSX1lnEwGJeTek2yUePb3QOZZ8cwFup0jMe+QS6
59hM2LY1YMUjKfuMjQREr/twFHZ3olblUMFBCqlfym0Xnxi9RbG89aw6Gb/Z
4opfqWMdcAiNG50po4PzuV1fd3UX2E9Oa9lwj+C0LuuWcXMVYgKlTfQYNEwy
dEIy75YiTkJ0IvQMef7ezGcO3KmoPvYubeA66W+v7NjW9ycRxbojbqfJ97Ot
ae4JHlngHPBvPUjmW3VRhF+7JB9F3/h/CheT80PAbrnkQBPGNkmt7/1MQ2TI
gnjX9h4scEl3b+Vl4bOKmFd+Zx6e8HFRjUn//ED4rd+72DIo6f+gPJmlg0bR
5uZpaIOK4bRAi9MQzF6Ubvxx+BlUJJdvOKhPILEoleNZ+QBcrwiun+ccB5G/
T6DRvR3KrhFO5uT8iZc5ZXVLqRveCXUvk38yYL+1zlvjRyVOz8ja6I6T5+me
vkw//BqbPf067a+RPBaiFBLo1gOXriiN13I0ZGq+laL/fQeajM89Owfy+/ry
Bs2MYmxW5TlgnUxH1KFLtnu9s5C4U8F+IJ68fy8Ds6XjUzEqk+zNTvqLjp8/
PVvkP0PmISzVXxOo4peQvZRCRR/Xzblrb0eQ98w98L1IPnpXqWprV5G8LFpk
a6PbDoNq9lKfAyycH2dutrB9jqeN4Q5JRmQ9si33/zlcg/WDb6YDPZmkDrVx
8nH1Y97FdXtsE9l/JjE8L8Pq4TqoV2v8kAZ1E+aV0LWNkHAZLpvlYyBFqyKj
cudXfN9BVTaPJv0jM6TwKrUYozFn97WT/RiuJbZz390PCA/++cJDnuTddRe2
RlRm441r0sHfo3R8ph8tCj2ZiycF2QGrKAxsabx6xPZcM9x6HnH2+TJBD3u0
WXKyA1k8EfEhYEBbtpidK68XD+7ojl6tZEHTqUtCVLYCo1zn+e/O0OA/72vR
pZuNuM2c2j/JfqA4VZyuayqG9bS2btwWBqKc93MnP2pCDNd3XW9NJricJt+b
dJN+5KEuPz+DgfaXNmsctUkukPR6lWM4CB0Be0Vb0o9Wt2qu3ET2T2FwMr94
NBWBoY9w1oMFE+ngX3NjrbAw9Frp9ZWG/dZZTjwBHWhaZcGx8gETQ6luVeb2
Pdj8MST+8CE6jE41rJKR6oH/CbnN0sdJf1D+i23EshlvVbnqPykQcKBustaJ
bcMA5cMabR4C/wM3oBHu
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41dkbt9XkJiRky1LGEvnNSKU0PtJQYycMCr+0TIttJJMREUmUPUlI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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk4lVsbxgl9xVHJcMhMg3AaTAl1C5kjQxSiooxp0El1QlHIkRNCJMc5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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4VWsbxpHpRIM0ExWlVDgqc+7iEEVJSmWe6csYJdJR30nlkDgZOmkQ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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VH0bxj2UyhZCJKUoiiQqQl1aCEkIIYRUkqXV0yIJyRbSQkSixRIx
CVH2fR3b2DVmzowRSRHyiPe8f51/zuf8fue+7+u6vvcGZy/zM9xcXFwO/3Bx
/f85tsd/1GdHM+wWRoYmcgmoDs9EKDn24Kqet2mFGwNv92a6DJdX47Lm0egC
KxZSTVqeXN/VCCHZ2EwfKgNTwp/m2j0bURS7xXvgOx3LG/VlKIkV+H1o2c1V
2kzsfBT73ka3BuYnOetcOlgQKBkS9DxTiid1KSqrBZig25hqCRZ1Qq1SWux4
IQHXiPKjBYVVMGilvCuUISDQNS80cbQRU01hmwyfMmFg8+i110wO5gMXVv8F
gcCwML1Wy0a8+XPjscZNFtbnzeerJVBx7WOk6omMIVBn49yqR1qRuP2HvtMO
Onbf15FW4fSg+u+8jd3cEH6soWxuisuBhMDyA4psAh3XZp1FjcphHLtLNEmC
haQ9OgeCnrYhV0dyU/UcE7UPQ/t6BSqx/mJMxLV5JgamraTyirtRd0zvhM8m
DtKbKvmaE/IxazGuu+ICExsfhinW7WjHzo4L0xKHmfDPflJIC+rA5tqIaovn
HBBvvaYvf6xFKMdVWk93GIe+L4QMTjSh+4q1Q2w8A4duScuYxhfCWNHpUIsV
gdlke5MnAhSYevBWmqwnIExLWKe87BMa+YSGD/9iouNHZsWgAQWblR3vCO8l
0K0tXmDPS4N+zyc1g0tDWHswyGMhuwUUDQpPozyBJV5pQ8/rWmBndoi/hryv
bpauyeviYFBCu/0EnQhc9Lc/dtPlMURu7x1bIM/H9oe3tzc3QNGrLn9sJwu1
FbJLXXjScew/voeKhgRedUhHO9Q1gv+5x+TUIB1Hrxpt3itPw+LTbXYllgSW
h7Rd/LkrGqbaclZ1pgSCPVmjvB+7kOf1rqzVio3gWaMuiWWV0LhcrPApn4Dp
5XJJi6BS3KE72kpIseB/PMS37FIbph+dWrZqKwfmT8yJy709qFnmnGvSPAyL
pg775MIK+JklPNuuR8BPV3te2y4A28cSb2XbEkiysM3y2tiFqbHCdIP+AZi0
ew5LJNOgWbo3vWk/E7/iNFVv0LsgUR939oUYG8KtuWns8y9Rv7DqJ+08gYwo
Vd3s9Z1otdQ/+M6Y/N7U7T3HB3OgszgvtSaBgLe2tPsevVrEscr2R+YxwPX1
veBATS62lfxR918kwDxt4zgVUA/PlwdpXqYMNJ41+LWVRsXFGr2Q2UECLmfm
I6stOmBU5J+2818muJK2F/vuvQXXhAgthjMBzaf3j+eueIawvEC5l+T/hG+5
RrhMlWKqwS9fw4PUp/+6C09+1GB9gt/Kc6UErisc+bnD5wsmxa4uvu0iUPvn
Zcgf/XJwrjuMuUYz4Re4Ud5V/wrkDFYcnDtF4PIpjhXfgU7kJib/7p9joOB8
d8ZDXyrWjn+UnkphwcLJK1tqrBH69hZFMv0MKBafp/Ob9eDJ/sh3T3naoBXA
OdE/3I6D+/jAoz4M7j6LZyv+tmMLf7rHOXL+Er2P2az0bcPf/D5x+oYRfNbx
9n5XW42vbkvDDt8isC9WX/CkFA3mz/6drGAzwO27fOOETAdEPD8WPPnBwPWY
650RTm1gxymVF0ezkOvhXPtdpgxJncJN773IfqQesNVYUoLqJaWbtMh5S/LL
qFFYTMCU+suhe+4E7LQj6c94CtCm0ifX9ofAuw8XRB1ZhTCylGDmdRBwdBbz
zt77Chevz2rgIAGDgo+3QnVjYdXb2ZpK1js1s9LCzLQHN7m5xIXNSD8anG0L
/5CNGJ8/DS6u5Pcp6xRCteoRXyl443kACwVHajgK/xTATavsl5k0C7HWXe4n
+Z9izwTvLis3cv7Xpbs7mHWjMiGV80xhDH5KZRT16LcQq9pMb7lJgCtCTmbw
eyziMpYtFl4i0KZ0qMk3lgrGzpZN8+ZMKC+R5XpS2oWf29jfko/04/NgoJLR
Qgs2O0xGuS4wUJvDlzNq3QnxlfnGmSUc2OsWu/Dv/Ay7uThanSqBsvq79lVn
qXBNCadFOrARPnH61BXJLgg/anJwIv3dmC3zot6EhoszXt/3iXKwMe1XUkkc
DRvv7NcRiR9G6ZlcgWMyqcj7ZCP6wpGAO69y0PfuChy7f7M25QFZP8M9P+qu
5cIlvWXcYg8BXV656SC/IvT1Hqgb6WfCwShK7U9yBZIq+C9dPkpAWTM7zaCk
HEJWm1W2zTIhGlJhGHm4GAIhwQ5RO8h+Nu5XOHutBW4T/I05vgTWZAsOybHa
oTvKWfGMMQQ/m7Otfwf6kSQ3niXl1g+OfohQwYZOrBadL3bqHYBAwJ4NijQa
Gk9fO/7FqA+66yQpE/JNGJG72zk0xICk23nP0SVfsPB+ySL1JIF0D/1CtaxW
GIZlWWuYERiy9LvS+7AVc4fblT5Z0qFbW1n19lkj6hQbDIy1CHxWKFzK9bMJ
q1b4/0p+SqBq7nKGlHMndviX6Bz0YoDe+7qvRrwGf464vduVRaBSXewIdW0t
irm5//3xh42X5lKai8Od4J0StWImsuBXHe2+6VczzItWKA7Ls6F6ywSbRSmY
sRq+Fy5EQNEotG26oQNc1UkPPvGz4Ur/aNJRmI/cCO9XZZsIPH4iZK1uSObZ
s4nSmT4m7uwYa3wbTMOr/tizQw5DSPLMNfY1yQCXn/R9bWXS3yvmy0OrKnHM
RFchPo/0k192TuXDLfDhW1k1k0Pmz/qkd7rSrQitba9OIf3Stezd71mJfpQ1
DXZyS/bA31ouOWGYCg8BnaP8HAIF97BdY0MFasRNLlc1MkFLoxqckOqExKDC
Hm3WIKx/FKTv8fuARIXe+ZOR5HxIdRkMWfXg15q0R8UUFio/ZmSma7XDbhNz
KmPZENSit8vto/UgxoL55Fs1AwqPHonfvkbDh6XHp1b+x0CSfKlHSFQfGrNK
Rz+3MeD3xv5v6aYYaIiob3lwg6zHXy332No26GYQeWZBdLC3fkiknqMh358n
5B1GYGrPfmPrUQ/rIT+l6kSyvpxLXcLtnXh3KuR72uIwVL5uJlpiW2B2/rxV
pDIbx29oxTl3UsFbseyUfyp5XklZ2L6RaNRaZ2llkn7t+bXzKY9MHxTFr1LU
dBioXvuhx4RVCopeiWf7GAGL2/Jxor1lsONxWWKzkcxbtotyQEoycNcw0jaA
9PeYXV8+nWiHirPeX04QC7cpgpl8DTTs5/t76asMG0KehobUmU5MlyaVvb03
DOo+omTyeCeWr5etOLFiBPtkj67OIVrAbfye5XSQicDgiXPq1z4i3aE3y4HU
5zh/4M1HEq0Yu/lzfcEuFsIuxhzpMWxGvcj5lGtuw9A8pj0ucK4cvDcO758m
9VtpZjif4FoLYxUl+pc3TEj2N+YoThbCYlVGbWwrAZ8phVFX/VoY/p4Ztusl
oHZx4edP737ouE1GOG0dgfynxpz10zX4nboxaKUGqe9jTf4rma1Q2/T91CJr
BHazCRrxP8vhGGkWP+pPoNV3oN/HtBdzyWOWtreG8bjl3BXLDioqqRTllY9Y
8FnlacXl2o6tySPca8LI/sswMlXIfPPbRDmmRvJIYX2lt+aNbNBOXLlqokNg
f/GV5c912+B7aFQ2XI2BwOOPj7R4dSK/XPqA3iIb3c/93NIKKyHJX35VaIHM
x/GNY2sFKxAxFxgnuZuF5a5izoN/e3BA88q4uxgd4WufOXOv74GWyHgvN4UN
r9aoIL7wAez8YLtig9UwulcdMRkficKb4QSRCpKfZB8QoszBOFyfOR35w4XA
2kr7OqT3w/t8seTFfaS+19C5GjVzQQSd+rdomoCoYp+CkuJXiJudCWNyMyBk
+Cjf0YuK+m9iGl0PmEjNN/gjLtaIgVPhvZ/PsRGlhZUdkZkQumsAIX0yz4IH
VM63VUO/ZKkKMcjEf1O+p8wEupH8QFglp5cFDmdoQymlDUK0qQtGVxmQ5zif
mpXrwIFWycyYFyTP1Trd2DXeirc2gzdkng0hz6GlccmmCvD1L8+71crC2acV
Ka9KKrHko5g67S45H5a/RUfSS8E5GJcRakHmV4uHUb/hY3zfEzCibk0g6kDL
lV3TtUg90y+W0snGnslBre/aXUhMU2bsXWRi1mDy9rkHJE8Vh4U63SdglDap
8zuBPE8700ongomhng8GPrJteHvhuWaHLxPBFfrrDoh3wKXf1ezxGAvG/X8o
E5mdsO7a/289bQhnlx8Y547pQ/8FL3feoWFEtV4PlqimgNfbf2Mlmb+W2mpq
DTfJvFtFDQ8VHIDm6c+nnb9UguE4+J7OIOD/eWvh8Y5WTFlKq98medu9qYjC
WjeIrLXPZlbLfgd9utte/sYraN/YbE69Q/L4an/riQ9d6G0n3sSwh+GzXlAj
WKkGXa4x8Zf+IfV95+bVZuFs/Dm0t2z2CslnnqpppuVFOB7w5ecQyeuHNLZu
ko2jYn9KT21oFh0FMUUaG7rI+4WE84wrsWFu7PLQ0JKGEQNm7E8eBi56zqxz
ufsZTwSK7uw+TEDK867CY6t2TBtJru6KH0H00RnZqFwqdrgX3ykzYGFJV/GN
vP5GFJjqrzpC+kf/t5JtAUMDaKn+81T2/BDmr98QW/+nGifn60OS29mgFFrv
WlxB7jcaZnOapD78NNQNDI/aID02X5uX5EXXR/HPo0Oz4WlwOr8tmNwfu8z2
99g1YV3rP545TAa+nVjZO5XUDq2jxuq5Emx8z/diGKvU49fI6JFQWyZsi7Ve
Xn/eBaGKr+fW7B/ELDt3qoWSi9bpvoG7HUzIyvLZqTgVojrxaPUvch9k1CRE
7ZAtRd/VE/dV45j4Jhp4MPxIA+JOX17vfIaNJWtOtehvKcLXlF6MfiXr3Zm5
0typHUd0VKw3XOFgYnh2ftz2EUyuZW47YU/Wm8fy3L3USkxtuZc5U0v6VcWW
q8nkfQcbjn8uvTsCWbNV7LkbuWD7bPj0hfTjUsGrozayKSip5KQNexBoXCMa
fnmyDapu4fuEhUag0hD4Wb24C8YxDG9xw68oXeAvzJiOx5Tav6GnDcj80WOc
LDjTDF0Bw5MOqiwoW9nGNHxpQra5Lu/TSRY6XtQp9S4n9VBufk2mgo2GfzZU
Bw124m9afBq9iYkl8+vvhLZXofyFFN2NzN/iZyZpufEk9/HFCDseJPsXQVGw
XV0D+rOxpIhbTERJF+27KfQQGqFjhkdIPusY4rzy46qBVcXuTyKHmFB1lJSb
s23E8BqjYg8eMu8yd23cfLMe89HSdYrCbMxLSUSfPl2Nx6od1x6JsSBp8/C/
j6QfG939rVtpNQo/1SCuWOVyqFIbXhepkPWZPTo5nZ+OtXuvPnygTvI1UaQw
ONVAcs7JcJ/rDJzlPZGxTa0PLi0he7BjEL1lGpsPN1KRwvdeyXGE3H8KSyI9
tbrxj2ToP0ZfmNhhtFbjtUIrBhLe2f0bzIDs4SXswJ2vcbjC5vJ+NQLTAgnX
GpZ2oDXZdkkiOS/VU1My7s97wFfbMFPhQ+4Xid/Mf2l14MXMKtcvZH50iKgV
aMa34oKcoVwUyb8Olr50VlkOPgoZKU0UknypqRhb+vcRDGPHqU/sSP9K9049
d8cUoeFM7W3kvK/tfnPsdgkVBZ+L1vVfI/Xdom+eblGI0Z1L9Sjk+2uLQjP9
jlXCVpj9vNyP3F+XRbx4U1gGvZttw71kvse+Frved7AH8+bedgMhw5DX94w5
Hd4Kt3urlrbZEOC0HPqP+aAX6sYtv23qCWyo25O9RacPwh/vjCoudEHWNCDk
umwu1LbL8/STvGxndcU+93YzXjW9E//PhOSB07uDY61oeMx1Po0W3wsTz6qj
NlntuJqiWpoqOAjlkirXCwZ9eB5tIyAmNwyjwLSAXzaF4Lp0Rpc/hIB1YXff
r/YsONZtea1A8i9lI2VXAsknsnfPNrnRybyVZ28/rF2DJ0J+b06R+2DgzSg7
+bxOqOnrPWcZkX5UrdLAM58DRUO7y8opBOgGVFGvTw0I37l4NyuP7GdFQerc
mnbwZ/V165+lw/zfXTH55HxbMMJ20nnomOjnyqbu7QZ3zDaj7yZD8Am/utO3
rguXQl4YiMeS+6sPazZapQiqzUVU/2MEsle6St/Wr4LiqNZi9jmSH63v1XPF
PMLKkktEH5mvpfIvFg294zB2b7m+Gvk/YT8DBccianG3d/WpiXEmrh/fGCWf
mwVJvdSvd+UIuInciWLEdEEx3TN84sggah4X/SmobgdF/sOI5hWyXlLZQ5/G
WhHFG+ATsHcITQ48wbvZJI++WBlvP0zuZ4aaPZnBVHx+Fp6zj0Lg28CZs5fy
22CTFehhf5aNYxTOy86UVnD2nywPJPdZ05e+V5bz9UJj2ZsRn44BXF+RpZs0
2wHDczoflm5mwD1jtG46oA39Gu2CJkV0yGS1pzvmlKPc4PTHLz+Y+JS0cbHx
AxUSpS8UZ61YeJe3QtvPPhfOd1bu5b5AgF3Ost6S24Hz0jwjP2SZ+CtenvnD
iIbkpxM9UWp01HJ/0OnN/Qjle+NB1OcEtP5ybXLOKsXfhYpkI1IfRMPSOYEq
Kt7nJvbI7GRhd1tzTJVZG+xurdqdz2FD3sFSlsZXg8RYkbzJ7STP/lxOjxzr
gN4Wvva4BDaEM7a+3uwSDP/YfXSns2Q/uPnrH64tRIzWoeouFxZmz74U/dbc
Dlvl/+5TvpJ8t91isqS6ANEmP6vkpAhwU69aBet0IXWTpGgaLwGdbe5LvZRb
4S8ye8xYiQXhMj9B5ZICPA4aXRopxQKhdD9RfmkTJBuCkk43sVF7b8byvjgF
AUT5/dUkT1p4JGx7xdOM+dLso3HLGUhX7YjZN1QDcfPLcwfIfGy+VHO/+MEX
8JmyP1jEMtF8RtJkoaoHEaEvq9bwjYG2LNo77XsbCMu19zmjHJTqu/v2eXRC
2PH4JTMy/4PnbIS1VAdQIkLR+3yQBcUPcyme3YUQyZMqYpPzG3nBd6nrrR40
fxKpc4gZRGLyXa/Si22giIZF6mezULjKGZdE6qCTKHZQwIf0QyfJkjY2FbHt
mV6raQT88sMecOafgrOPwb2W5Mn0SfOF8be9OIOB2BT3IUiUhPrIrxpA4+pL
wUtkxvA/fosc6Q==
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41WkbFg2iJFu2hCZLskQ0tm7fULJkClOibNmZSCtfTKJSUjRCQiUj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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lfkexylRFCoZW2TKklHTpqYJH0kMpWRLcm0t3NFim8mWRENMdkkk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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lVkDNsO0cLNl7CZJZW2yJIM8pZRJjMrUYEiKIRHDSMrSF0KyZU2k
EpIsI0LkYuRayu1yr71MnVfyCdkyZr76zvzx/t7f+zvnPec5z3bWu5055P6l
kJBQOn3+fRvWpGzNGOqFY7byc4d5Astfzgp/lzSC0muzjv9dZvBt+d9DGX4D
iHXU1frkxYBYqOiMu92ADr/HZfEYgYqaj/Vn3xEoPUhTXrzHoN1+4kpYXhsi
FDucy+MIhARdcf8s5yPCfX/TnCtBnHvhwImyFsSxnJxrQgjsBtaM+KoMQEFm
3cFtRxmcbGmrPijXjeEAv7TZBoLsI6OpdcbDkDsy7hvRzOCfhZNpU1/3okQv
ZyZGloGr7MFKZrkRkXnZarWnCLr6Zse/edkLlaCfn/I+Eii7nVh30YaP6MWS
HcHrGfQf8xOOCmnGcHNlpGEw3d9paK0o6cSrlD9Xsu4RbC14KP/MsxkhKooH
dlF8rnzT2+dqObihNl996ypdrz5BiU3P9yrk78rua3T8q4gLbx614kfD2HaN
/xD0x7r4zaiwoX9TudsoiMBWljMzcb4dOpGx8RszCT45cD/JawkgUyLln/U1
Az/dGy8EsR3wMbstuvciQUt4W2Z84xAyW4UTPncyUJ3PrHj0Ow9Op845iL0l
qNloOed2sxemwa/a5v4iOO3U9PLMPjZYIaYjjr8RfJAItLrkXoHTq3fxc09S
PIdF6j5L5CH/lMYuZ8r/A9mafXUX65EyVRae60v1ebXCe9NQHIxWhKU4Uz0n
z8e1FT+pQOgt+Y6iEwSr5nZ46Bl0IsVS2IiVSiCf+Xp+RKwCH04Y1CXS9T8W
/b1qz8oOrFiI0gu/QnChvfn7yrgmsNO8t+0MJGC/koy9McOFoot/c3A1wf5F
x4NBzwXYpcZrVZoiGNYTU5k62YD7exfiS84Q8Hwm3rHPD+DaM64125HBzm9W
qodoPsewmOWQRDHBw64rP3uXVGGvS0urpifFb6afkCXCRwd7s3/TZ8pH2I09
alu7UW/p5aubR/HIvLVMr+cgTW352DLVK9NVxEB0qgNPN3EzHiQT+JlbPbe1
yYH06IEkUcrPpKAh4I+ecvSbpz+zoOc7sHhMItuiHybcX5N/FWUQnD7OWewt
Q83S5ORuyk+HvW6Ux2ILPG1d2PlUP9YKFZnLo4/R7BckneBDoGk9eDhZopvq
vUSGbhOs2XRy2iqPA/ZLhc1KWQQl7edyDaSrUFq8/WHlL1Tfn8VnNyZ3Q7zx
9/SCegLJ49ZKT97WIEYycY0Z9ffkRHHU/K4+8EdiRM64Uf8rL7Umi/VBX567
otqGwfORaeNI6z58+E3Uvon6xY4j7Hf9x/uI1169cNeNIE9aKriqMRXDbrtd
7lO9zZ5cHxwy4SGhvtN2YIbgvb/CXKnZIExDh+/p/8TAStDolPCgBD6G6Rts
6XkNV98cS9oiwHzCF5Jh7wgEaR9zdCdqYeyWPHWI4tPYXTdbaliBDbGqqqN0
voie2vkt2/pxobsv7NNhqqfYUqrQIQ/ov9a+qE/3H5XOEBJ2L4brDmKceZxA
xjWn3GWsGZy+6ehvIwhEv3/WlOregk9fj3vMUX4lw65pyXl3QJkTsNkilvrB
495kXSEPMZtKRu++IRhLcgq/W9aJ73rVjXUyCJZ7zqs/Mm1Gef9CsSbNu31d
oGKhCvWHmqjucglBvdfR/DHnOmQePMDKOU2QZLQ/QedkK3ynuz/ahNI+cGqV
E/bh4oiNtUZ7I8HMwIOZc5pcaKW0W/jS/xPi+vLXre7EhdgtNro03/v3ZQwc
Cn4By5AxNq+b4u07W+H+agjqclN9k8kMDHvEVUJo3o3EGkKzE6gePM3LP7Er
6Lx3B9Ko32rCPjVLqVbg/XSK9hXK37YURR2xghF0ByRre8UzWBjPLYJcO7Tt
hkfeU3z9IY9btrC4SB0rq7LNpfjk1YuM57thsm6oy7uToD3xl5yKtw24Pven
uiLNe7ECx0wxbxAaBeLJhukMcvNC2fGFAswmu69z0WRwX3ym56OhAPEmUfuS
1zJI2iVb0bihAq57XRrcKJ4ZgVi0kn4vOleyxHOWqb+a1rr9r5wH26oL+9b2
0fPU1t2ZOZALRXOHXAOaJzu+wk+bl7NR7Zyir0m/b3IczL+r7IKEVNBV/2zK
9yF/07SCZ3j0R4tndCLtF9acpvj7boRI1fx2opDgXq77Tl5+Ha5LJWp40zyV
V4tU9plWI3rAeVGJ5v/Z46UPpiuHICLIkW5PYZA3VujGJD7BztZLvjl+hOLQ
Xa+XLcDgGy+lKJrffobXejyxCLK5BkJf0Twc2W5hFvNwAHtMXM+8jmVgvOyR
ELujDnvO2kUbUz+oLkxVOvn0IbMl1l70Bwbj1lUbG9Y3o0LvsuuboH/7klWr
oN2NCbvHLxuoH3h8qwztCj4WVM6pHlJiECfPTtII7YH041BGlY4b8ZXn7zlX
QaugUaTKi2DklsHRf1z4UK3zkrEeISABgYN3ip6jNOSiVNst2h+B07XX746A
V2i+Te2rMXiGcV8e39KEzL/2r1Kj95OHnXfGE+cBTAhnnBaheuqIXNHMOsuF
2qZm4dc1tF9kTm0ZHKX3X6qT67wcg2G1rqXq0w8hean25i13Ao7nxFQDqxIR
DvVZZz0IuLI2b2QelMJXr/7uVcqPn7f1qWNy1TD3rGMtUr7t+V/qNwhzIJ/0
Q2QCve8io1bldDFsXDX2Nhz9lSBwhC95SVCJC9e+6VKg61lEu5jdMelFTai3
XNsAgcle+Yxvk57CozJLYiqSwFmjnNWY2YijdwTb5wJoX4iNflG89wWy1KOM
Ol8QBBeM3XxYJUD/jh6rNcIMuCr+LNnLpdB/H2oeTv24Q4t3fyDnBfShsfY+
Q/Dy/TuGrBrCk5qzl4X9GJTnxOwrCujFTEOZWvg09UNAbEGPMB+yf+V/zlgk
iPDarne6twFilSdEpqjes44r3DIW+fj4J9dzfhUDfs7qx5vzebD3aohh99I+
UQh0UBV6ClPPR0Gd4bTvLSQifyjjgPN951pT6merD1q71T252Lpp6ajKHYL/
A02rvCI=
       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2kgVG8fFRXtCCFJ4h+lLG0qHGSrLFmSLYlERIlkL5FSiuxaJKIsIVsl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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41lkfxiXRmLxTRL3qbWxJtkalVHIbS2GkCKk3EoVmLGXJ1mDsxBCy
79knRZYeJNtjDQ+PPbI8v/OoJBVmJC3v7/3jXOc61/U913XO93vf90fSxsXk
Ki8PD08ivf6/b7Zsmvn+YR8KehoLQ48QfJoOW71n1IcJN/mUw6YEi0LXtV+p
NOLD+QoN4kIwLaFux6/CwjRH5PMrewqHvvSYPrd+Bm3jlC06HA7aT2a5HtmS
i9dJ1qafzhPIS/PzJX4Yxy7nse0rRRTuGw8sBSex4Du3zLjYSyFge3ToF6t4
ZDb6CG2yJkgP69vU5s/C7MeU6UU9guB7w6yjXCYin1gU7q8m6C2OezY/0I/X
kvbyM04UttoU/S5F9cPi5NtWf1kCS4GbKhuD+iEgfeBq13qCMtTLFb5vh9Y5
bmtiK4WDZV76eYkDCGwpjYhd48KhL0DT7HI9pn1Fq+4HE/DkdFR5lCXhvPC6
oFl7gif6Hhd257PAs67z2xZFAtl9gvljhWPQHlq3YFs6jcaBXiPZskkojWcf
zFjPAaMvNJEnuRVbk9hjnlkEeXd/WmMEd2Mmixn1MZCgw+poXPPdbkg71ndy
zbkIdN1gE6XHxr4aKz9TZwrZBm2bfTWfwuWNtIobPY/rDUvMRmY9DtntVOm+
SPDtnw3mLofZGG1ZzdDq4MDQh0rLihvGDQG7kLl4LsYMwzxjZNh4tI+nbm2S
QuPbwHdZxh1gqDu/HJfjIvt+rfpp1jO8lb2yI0eIINlw402DXgaS5gyUpOMJ
dDiLkQu2rZATvL+/rpMCR9jMwrahDUF7wiWK+wkSd3ZuSvVmQu/0i8gj0gRP
1xR+qB0cwGLYL95bKQ7e30tKH63MgBmr2O/6FYKJ3f+SXy5sRGbxb4Yb9hOc
7PjFUVSXDfFSPdNBbS4q9Qu7zCaGcL1IydBLiYvGleK6kLJcTP7w9thtWwI1
0e4aNc0mVKtdnveoJBBIKTpGjPuwuTZTLOgiBbWL2h4Li03wmgrI8PAm6Hx+
9rJTZx+aB0NLfu0mCNCNbFV45Q5Nhw9/S18iiJuYrwr3HEOzuMfDyZ9n0BEi
1JV9sw6KNx8bV2kReNsduF1a8gLJTV6SC92TuPKyn2U43IdwviIyFMnFvtnJ
R6G63fBhzJnmP+DgIMukJWS8B/77oSJaQ0HPbbghwKwAGlpvlizdaL+wvirf
YY9Aw6UjPiuL/l9lQK/YyhNkv9imfO4A/T79Vo7Pv4oR22LRpWxCECI5sbw7
ZQQqy3OnhVkcOLbxCI781YR53zqrsVSC3J/C9hr55sNudVHPx5Jgec8BxW6F
ShR8bE13O01gXareFKeQhLW7U+HVNrRe7a0r1Ba6wSivH6ygz5/vqO2pdxtG
yQ0p7/QWDkynNm3ji67HO/6Hx1dlCNrc5V8+7GJiurutyb2PArOBumzu0I13
Sq8EMEVh3rXQnoF6lKQZs9JpPcbudC173vYQuYrHk++YEah2pFZs6WuFXUt0
zDYV2k/6Ul/Xl5bjQ7tmT5o+gbuw4kf90QEcK2g9pS7CRXN6zeuuN8+xBlZM
vhcH/1ZQq03YPwSzs4p37Aw42Ok8ZdXr0waJwRR3ax8uNh85FJ8/VwidpY7M
cneCrxGvH1+RGIVJRN5faryzCH87WfWVGsbqqvsLndIZNEps1ul/OQxPo6vN
qpoE8+VLynxbxiC3I8ZJO4GC8tjJAB2xUZQ0/HpNppRConglo8J/HBOe3XaN
whSsXYqURI6V44pbsYrRZdov/FEJT241o/h81bdocS6sD6YVr3W1I1ywT/C7
Dtqv+eOfstprsZqx5LbkT8/jdnmEb0kiRpN4FW1o/Y3aavVN/1AJqYoXEjhE
9+cpn2G2dgYyd7D9a+h+btRqVxD1LYZq2t8lFnYEmpl+p7auhSI9xSTHmr4f
5ZYmLZPWjrruBvtoBoX1dk3lSv2DWPxaqXG/i87T2JT5KYseHBDyU/+kS2D6
9ETOT4EM1I4buK1XI7h1+N5KLncE8wM+9kJ0PjVeOr72JjwEPpVHbUJofdjp
1QsL5/TDb+jHmuSXHBjwuzLSO4Ywe/4KU6SRg4+Hf/xQfaYNl401VBSGCZiP
a4arQ9gQS1bNebRAgUEZ90r+3Iwd9jqvyzIpdJ35bkOcTRP89DT+Up2l4MGx
VNqjNgx2RM8pzUUOIl2P7FVaGcID1Vf9ngKzkJFX2MdwpPVmJWP6cyeB3MTd
SxJ7WsEQuM07osXFo7h6XZmYflgzhebncgn4PwRHnHPoh1VzcaB5PgUZdZE/
EyI7wWv+61QSP523P64cY3n3Q3po53+ef6Pw8QKPuVlKHuRvX7rwiNZr7pCn
IOvzKOIErn1SZ3HhKN+fb/3HYzBsDsXspnkkURtzRjyjF2+KxK6N0Xw4Fccj
6irdhKjUXZ5ORgRHj2kZiq60oOB1re77Egr2Nh4KKrEFYNffKzhC82/54b6N
gXtH0Gm60wXTFBxUlP2XrPrw2ZY99pTOz9G7I6f/lKqAfnzVqwVXgjMnePNS
nSfwfmBJ3Pk7CoJW2a1TYpMwOi55IsprFkkGa3L6DWz4pb8NYvlQiH1kuZ15
aBiK5MuNiKtccJb8/eZkmWgUsD/R8RsBn7R3UGlxBgQyt21Wp/UUdTFvKZWP
jSeNx6c0aJ5FhZkdX/5+EDax41EvTnCgqJMhsltqAPUb3p2T1aVgsffCNlxr
h9jgYdnk3wme7VU5901pGCfPip/4I28GZdcLStJHH2D+QWjz1H8JjEL0x/y+
jUJVb605iDkDzviyg3XOEKrFrfyWBziYoNRcHSXb0MLvlBr7D4W/OYvTozJM
OCZIaQfwEhzMV4svPDcJs4WDVafpPOL58qk08vktqAuSaHMrggUTa83y9hHw
3KJSqQgKcmLBAXZlHTBJSHi5+JjmZ3XTJhVmKtrWTdqK0vWah0W6NRpovmzX
1ZCOJvAqPWuUlzaA33WL6vKiKXhdrGq+0VSNXXd69irS+a+jmBTtR/Nbr+if
HVwngoz929KK4thwkogJXlOm4Jw1V6i9axTNlum7vecIbAazqmfC+iB3pmLq
/BmC+3fql6/LtEF16E27w58E/wOd4dN2
       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns01Okfx6dcklzayD1JHZeSaKVIvYktW6pZKnJXspS0LllFTLbaFW0u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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns4Vdkfxo1UTCV+jAqpZIxMF6mmQvOqMDGEiEiR+7iEEn4ohxq5k+qk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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4lQ0bpyiklJAXZSSVbNUr66clIatCGSEhRVaKtCShEpKIhKx6JSF7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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk41XkbxknEJDUSCjEibdSrQjHuOtkqSkgpkYycIZMcIcboSJS9srXw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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk41dkfxy1lSWnaMFRSsiVNVIPwblCJFNk1GXNJhlESJtRYRlGWskey
Zku2smRJupZrmbjca7ko1/1+FWNJpYji9/39cZ7zzznP8znnvF+vz5GjXTpz
XoCPjy+RGv+f7w4QKg4LzxAd5JT/QY7E6WCJu5+X6NA5kRpRnkSCRfNSvrfU
DOkPJuR7iTE4/rffS0yThfaqA2rFkaNwXf/zG8brXDTMVVt+siRx1fO350PV
9SiPbhbX4BJYdZBHMPRZYDImlG9JkEj93pL13acHY4IH7297OYpHv95t97zc
D3qwec6DRhI1vg9a235pRmfydOEnFRLvXJ7v/lz0CjoTyRcTz5NovaJqnBrc
AxtzbVrHewKDyvGnhlx68cxgb+6gCQ/pc6x30O+B6mmhyzLjBGbvLS7zCw/B
836vRxSbC8usmhWXITpK6Sv+Dkok2F9V448tv0JqQ2wh53cCmn5ByevOZ2JA
b9F/5QyJPVeM5Jr+GoYKXWugQpSHI/Gek5JOd5Au+LJziUaifLjb1DegF57G
AYqRG8eQpnCWvSLeB+7QbnXm0CjmAr+rSVzuxK+5W6aVqnhw5FxLNdN+Cj4h
+fiQgySaMkTilf0YuOUca3OzjsDZZu16cel+8AZ3rCzkj8BQfVBUp7Qb7hOJ
t/XoPAwcyJ+96MkGPdrkWIQbD8FEopvD/nbEakRGXfmLxHL+g4zjcmzkWJx/
mNjLQ8b+Hl2LiFdw7Jf0eP+ABz4yUTjQPgvOC+3Jb61I7B7zEXPMG8L8pxTh
skc8uGXfu2nezIKtU/iWbC8Sg/YWPoWrGrBvdt4x3IKEme5MHT/jEfQatnT0
OpC49nv2HvcvnThGk3e0zSKwvHXvxqHaHhy2PlHISeChKc8mUse6FsNKKRX1
eiSGjn4cXdToh47uzGnm3wTWqZlnuqb0wlp6gCu7exSW3en+8lNDYGoptr6t
fQ1FdYbQE8l+CPgHXLguRVD3/GrfJK0Y3teiv9kbkZiV4voq7eJg5acXavU6
I1DQGA/MLOlFotQUx4jDQ+LDtzdzPzFgKUzLe36JwJhCTVb5x26o2oUmi+sS
EBkOqhgZZKOwPE7Qag0PAssSob8EDWCNms/GNh6JjA3fztXGMaEZURCtL0HA
74NB1NSZICC14PzSORKb/QW25Sy04cb1vWm3Ogm8YRuNq+iy8I4rpXu4lwuR
qK1eEZ+awU9mf3YIJBE/6sKbIPuxzn7g0J1YAhx/3/eJn6n3nNxgErbAhVLJ
Dv5dF1jYs5GUCioZxZQeXT+lYxCPN986SV7lwahNwb58EwNZHg6XDn0kIBcY
4iaW0YaTxV6dzrtJhCesMO5VZuGgLNtb+zgJkTPO3zkbnkBXx/vmU18Snpr1
R0aetSJtIcOOSScQellE54RpH6z8+9Rt/uBBBIcf+y+34YiRzIDRHQLbYzZF
mEyx4SXoqRVwlof8P+clEgVZiPwnhpGxwkO4gYb5ZtM2pE2fCjU8QVJ8GNJC
jnVDolh+m0wED9xkwxLJhDK0iEqEjP1B4uixMUbGy0FYzf13y+oxAYe3CzbC
a5lIu/oDM3+YQHxgukGPcQ/W8P94bfU0D3HxlRE8+wFcvdUvu/0rifHcWvYd
rx48n2llrV9LIEN7WT6ptBa57gpqR5cIkDuFHljo9CAwz88pNGgUqfQyBeku
BhyOfn2y4z6Bn7IrDWruFGAtPcvJ1ZniV6VqJbyuF2WShs/tqwnksxbzH95u
wWRSUquJIpW3xu3pIctNULBK15l+TUDpzOT1yqJ23Di+LqVYkIT3Ycmd4cJV
sAy06ycWCaxdf8g+msmATLGMRzaDOv+NurjO5TyMuVbJxJmRcJ2oTmBKtqPZ
hHlkfD0JY0cf8+JpJuh+yg3G1H7DIz/YftcbRFoKjVOnQdVrcunAjBYdjLMd
v9szCcTme5xzRy9Khd7+wHQdg1JSjJTt4yqI6WWuqP5M5VXhrVbk6k54VvNV
aTcR+NJv+uOZziEIDTdMOYGLUtdG05PV1XDxTv+76AvlOyK94hxRi3NuhTFr
NEnsUJLvTJdtxF3JxMTKAALj78KGkzueoMqH18CQJWG658uBDScHQNJ2VplR
9VmKCzt3/PMv7k553ZbgEJCyeaEdvYuNgLOrNq71J1EdsG9jFYuD1ZMqmQmZ
FA+Fw9UPyTI8ThftPEn5NzRB80Ul5X+b+RPynytGwfXbs0OhqwiJUx0jUpRf
+NYY/PeHaTHetCu3Lv5JwrlayInTwERf2Do76zKKhyTfFJrLc/RLSTsepPxj
qSbtnhDGwPZG45+WygjscDMnT5t0IfaiSoPscR5ERbsqPtCY6D6tW8GRJaCm
/yI5OYwJi4Lpue2Ur0SGDbhhogx45ppu+raZRNbBbRbleWVI854Pi7pGIjJY
yDlHqxEVa8QORQVS/SVv4r2f4BBSzbY6P019DcsbEy633dko7d8XeDaMhzk3
2TxiTwuQPClmR/E2JzdpFGneB2PTVwpZGZSPv51aip1uwaOtCr/cPUlgoWX+
15ZHpdBOMjscQ/lcxCNPvfD8SzA/WC7bzRHQcQmtMQigzpdaXmQyS/XXsmP8
srKdeBZu8XdgDolFhoPdVkXKn2zDT+GtI8hx0irxuMHCE5Ub5fmrqXoxV1Qp
0Abj9o8Mm9Mk5Jc1L58KboeyZJZoL8XHrKLt3JOjzQhRfXhklwCJYkEtsYq9
PRATKwwJrSWhym+xumq0BfTjUxF+FD+uTfofx9+wELBOftWXUSpfY05LXSda
EGIdU+6nRcJ2f8Bv3dZD6A1R/6hC8V0/E/xtbXMXZi78KF6ayYM07cIms+g+
1BwO8G2x4qHOq/aikkUH4g3m6+5cILBF7qvcFZ1XsOcfm35D5Wtw1jqtTaoP
fQHngsTUuWC77hvwsBuE4kAU8Y8PF1JPx+2jDRpQss8o/J4TCZ0ivbA0xX8h
UeKdfXOBB/mY2++aanqQU91OE48bxbjDtp3XL77ESMHNtIAiAg+crhUxjPuQ
E3f1UUD9KOKTGzQWFQYgwPGQjbw3inJ9mY7vTY14VqDZ5U6tN8ueeTzRXIph
4auLQrbU/0euQJflcx+nfPc+lbcn8T8ubMsy
       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk81VkfllBTaYw1E2FqEBqSJgmPxpooIxOVLL12QumNQlnKTiYikWTJ
FsO4KUZKuJZruZbrXtlizk9q2qQ9Ne95/zif88c5n3Oe5/k+3+erciTI3lNY
SEgoi67/7wofeh6dS+ag4JOStHkawXjRUcWi7f1gLXNcqdxAUFPeFbo4Pgm3
KoM959fOQogpmj060w8diVdZkX0EcZZ6ryfmW1Bz9ui2jyEECZ36taGFrWhZ
lCGPYwkcjDcfzhBuxof0nYbjQQSP/iotf+5RAwtfjttGDwIr5aywx4o8zGku
9YmWY1BYxt48mDaMQVGtgadfCaR/e97yu6AMwzUrn3keISBPgmXXVfbhyB6P
fJtCAuWHjNBJwx6sK7CQUS0huBzMZJiWsXDG6EBXmyfBHYZ7Q3iKizyTitXi
LIKZ2k1xd4R52L922llJlEHeLxuX/ZPMxbuXGt6Vg/R+1fUmvR4egr2+dtRp
Mng1a5MarNwPwbV9RcZ3COwYNyvW/UqcjznQcZbisUnktX+/rxFN7wxs1gQS
ZH3/tTfCiIeGa6Mu22QZ3De19h2wYcM+WKhWLZJgJLwm/PxoF84kB3vWFVP+
1ZExEqvL8W29WmSNO8Hr/aKytg0P0XO+xy87g4FzxeG3cp96UVyYp5JG+d33
e/nHT/yLyKjwup/hSvCNpKjTRHMX+s1id+0oIEBlx8H5jn4Exkz/9+M9Ap3Z
GyV+P3ZDQXJVTH05gdRTWeORaAEezMcnqGxjwHJxa99ozMF375c6tFYQ3JSb
WNeh3oEWZWP1CFo/O1ezqbH9UWC3OjSY0P/0TCtEricPoHnR+bvENgLNUJ8u
+49cJFV6dlbPE6SnP+0yGSvDzoC4gEzKJyv488FSDR5SPONrGzdQPizZf9PK
bmPSb2i5li+B+omae+LcHNQftF7g0/dTrrMl1aO6IfwgrS41h8BLl12ZsZaH
iriF5y4MwYfDc59Ys10491jfNO4iwbPA5hem3D7ESA9xFovoOVc3229XO9LN
ix1Z4QQxDUn5P3t0QjAjL8fOoH4eimlqf8pDmbKszO4FgqgvDkMzBv2wmefY
19DzqGQu75YnF8bZQia7cyl/Zd+MpV8rkLTjktVDysfVWjt6aPkoqnb1xXeG
M2AvNdcKsBvEkmjSWEX9pRMyEIoLTThcJdKsHUDQHJvh7tA1ABPbjyfetRMI
pT4sOlR+HRpzRbWhbgQFe50On5JqhmQhrLypf9J/WzRY+qMAX9WsVCMtGOjq
Tp47HsWHfMiBvyIDGUhctqoKELmFZuutkhxvgtb5RAuxkmFoXF7VG7mCAXck
KOe6bDsUPMs3FVL+Cgc0X24Nm0Tyz5YJgm4G6sKsHeJFnbDY7tHtk0kQnN1X
IYJWRH4bIMENJthtlL/SaX0Hig/7XjC8QPFtW59pIzuOwG0cR79RBhpeKTvN
L7RCNMK1f4q+fyg1RUJ+0zC8wrPq55czcAvK3OPcewUXxTnrRmk9TaT+UrVJ
uIUjPox/HsVb98ny6ZpXTfguX7FP/yiB2IM5Tbuvw9j8rTV37XuC4citA7MX
R+ByrDLsvQgDf7W7ev/osqGeZKmv+DtBsZ+k3zXDMcgr9aYr8RhYR++9KFHd
jx/Ks6VEmglOxN82SLa6DZ8QdiZD/1ue4dGiyvSjP9PxSSr1t3pl9S/183dR
pr3GTJjmVZTpwJayspO4yevetJ3iLWazfpIw5UDhTLOPXhnB9sIiKedf+Zis
YNtk0355xNs2briBg1LPM/ZGtH8z3at/nYsfB+tNfMWZdgZ6p7+MGCW1wM7+
zef6U1S/hZWfbz4YREL+tbOSAoL89fLH7BMHIex/r/rQY4KyHdrvstbVw9v+
lCqheIU0lkQkhmaD3Ws53UjxmBXc2PRfl4dYcj7PMnkLg5STf78KEm9D6+Vl
Vjk0TwwySi/2uU4g31xe9o8RBgW5Xmpar/mY5g7Nq/gxeJobtUxrfykivHpy
nKh/y549eJvj1wq1xkD3OYpPQWXMN9mWDzUP6bvnVBkkuly6csGKj/HqeyJD
6gyM/NLUzs3wcdzK99+FXQx6Yrj+2gP9qA6o1emk+bIo/fGO9J4ONBgO/mc+
muoZ+CXylDkXY6/NxsXvE3za5xvhH82HdblAy1mMwTmpn3M5S9j480OU/mIU
zTPHVP8N73IRG5aXuIL2Q8S9/BdVR8ZwwnEuMyWRQVOkuFP4i0Hs3TwfVNNJ
9VFZUWmU4gartsdpm6k+AnG5W7HqdVA89mjLPJ0nOtPFf78U9ENDe/H0bzeo
/9peav/5QzlcSi1Ydyn/1DHFFr79GPgfvZtIEYOydXa8iMJbeDeUK99L9Y9z
fSTZdHUAIY2x/u5vCNpk3+soi7Vj9fLS1OenCeSW6CZ/KRpBdOGoqpQNg/TV
3+xzujQAZXfW22tzBPHPDRTMKtuh6+7yRRBDEGbbaa8kw8NY6BXR4Ck6H1+E
a8kf7MeJ5eVylrUEIvprZHgHuhFk42TKuUr1vKptIuvGxWCKQNW/hWCvd2uS
ttgQRCa2/rjhCc3bThebgjvj+KbooKMQn8EK2d4Z6bVdmHaQPytM8+9s30DJ
6OsRTKWI/PBenMFcdhqLO8rBjJ5M/YZUWp8Hxkdei7aiydezfiiCYFW2oWy+
xSiq7br0dtH7mb3HEuJ28zHxS16JFc0fC51qseiHAlxuMLy9YMsgrODSvETJ
IHa+XbNngUPA/uK5379xCMltmDAmBLZvDvXxFIdQF7usLeIFwUne5H7ziBHU
nvSQEN3OQBAYJl0UMYyqHlslHp3vizfyvC+lsMHyvKrslE7z7/P7ja1vr8Hb
M0lFm/rByix1heBqDbSmdLeq0vp2NjQVhQTewqPPGUvkfQi6nfVDkpqHcTdq
pndqkUD3/BZXRyk+DP8WOZ6izeD0zbQZs2k+Lrg5cbUD6DzfmF6qt34EGl1R
hcdWM4gqd5fRyxnBWu0yUqrHIEGlPnyZQz9+d43Y8ySfYOLKs7QRpV7odz6b
Kqbzc6ZEU8bygACCrJdtmrPUv8P/JOSu6sJk3fHRDckEAcEh2t3KQzAR0zn+
J83D/wEnwsFc
       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8Ve/bxU1JlJQhSRISZSqSipakDCGRJkL9VP4pIkRUoqKSqWRIJQkV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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81tkbNVoohNSQSUgZSxmjkinjJEIqRMSQ5Q3ZskyTSlFRkhiVkl32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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns8lOkfHXbb2qVyjy6oFKHcitalk1RWbBfRijCuu2UrRLSR3FatxKKY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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lVkYxxFpZaKalAmjUhG3VKPIL1OKUhNuUcoo2ZeyRZZCsmeukm2y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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4lf0bp9TbHshIpERC8hbR0AcpI2VlJSsjKbJSQkmRRGVUFCLrVETI
zl7ZjnXMHOc5x0HolYoov+f313M91/WM733fn3XvuHDVwH4ZBweHJScHx/+v
ovr/PDdrise97szQfDcCufpjx33bK/EuUGHjRBcDsw9U7Y9x1yP3yfjdwxpM
LDOuddpb1QOtAo3ymi80JPzdWPfcqBYunfL2lR8ZEHCRiE68Xgnr0F0Zly0Y
ULKanGxL7IZScYd8zLcx5L0I+2XFHMDt0qiezfYEKpM6G57zNYEi8dZIK4EB
ThvfA88zabCOtd3q83MUQ0LyGoV3u3D0hWL8nTQWdsjMVGbJNIHbOiw74haB
co8xm3J6Atr8TTcLOxBIlxAPcrjZDk7jxFmxRCY0gipuWdQ0YWVBimi/KgMc
KyJzLb7mIVr6irfcbgISQl1C2Z/KwH4jY9j0gYDecnOnB3ubYHRY2q3Vmo65
02M1jgFlyFOd/6pdTWA2ozWlpKUTwQ7bD1wUYSO4uSK54nwLIm4U+9gJMJDK
q7h0d1UvpPfmP7Q/NYxN+zxKTi1RkOVy9Z4EWW+Tc4qv5akO5GylTP5zdgwf
71zViSzvxg0uxqC2yQAcykXY6ql1uHDp8e6BNAZUz2xZ10WlwX36aWtI7BiG
Z29vjRCqgGhalbJdGYG3RwwMQl8Xgnqw27bkGwMr/RU27aFU4hei9qROETBs
087wvV6ORaP8dPPjTHRs7Vm3dXgQknOcuqubGVA38VGpMn6D1v9CQw/IE0gI
85EwKM7BJmwz+XcLgU3f1cudQz6gIK2xy0+LwH563bblhvVwrPUNO3KQwNET
32KtagphoL/KeUsJAwNuj9kdqxKx/7RDTasFATeFVQYxZr0Qm/tmbmo6DH85
o+uHcl+he/vooesXyX67XSotu90Krl1Lxy37GNA7ofNml+5bjG8T9Qo7T2Co
+b6SOKsPBe2Nu36eG8O/Goh8kF6KJnfbn8YkXji4AnIqG6gY+8xp8dx/BLqX
KyR9KtKwZrfVBP0mgeRxMZqXYiWkst8ev5rPQMJa56Ie5zComeUE3CS/r7Tu
fOyphgr89D6YUyXIxA0lY49pnxrI1ASe0hAn628qmZ2z+4jQpfHPL5cT4IgQ
uR+ll4S51XyUKSsC0a70NQPcmXAZGWqItSNwwz7j0PqBYtSa5CXJyhHQPLKk
S3nfAy76hwzeSAJPPKVvz734CNrVx/N/XxDYsGlpuMidhv9YNvZHDUcQzNko
8uBIM1INH4ml3CXP+6fRfJQ/AqkLbBXeKwQKXodlduwuAY8aJfzdKiYq5XPP
yffX47VNsdLr+wSsE1J8tkolI/orV+Ep8t53ZcWh218+Yy6EnZJWxEClogmX
3PggQu2zhykS4wh9cNzpxL4KuFwPuZQnTKC6abe3lV8nzh2ZM8jbyUJu/fPU
COFexIQ2Xl/MJbDl8ku31bntECl2Pnqbj0D9zKoDqgMdkPQLqjX8wsSWhJP8
6ZuboMKQ3tdzjIFdzdn7q60/IUfYQHN9NwGrzcLnFkWo2JmqMTCkyYarTHrU
8rRyPOIJ/Mm6xoTv3vxC3jd9OJJ50WxhBx1yJ70vcHnXQPvCFeHuWQaG9UWK
OONq8NfLRjzvGRPXox7vfinUjo1fFIQVfOiQT+CR2bO8EeMsVS1ikUC8eZzW
O756TJYEOPDlEJCZ/5AZ+ZwG+QwbUd8ZFjQbOvfE2g3C2oq3dmEvHfUPV7fu
jC3Ax8pRQSlusp+VKq82aVPApfWwyMSFQPiNWouCzi7wC85RvDYz4T/1n77s
HX8M9a5U57UmwOrSVlf5QEW6ivnA2y10hMnrSK5U6kTkxIyzFokXl7hyncnf
bfB6MMJhmM5CqvmxZ0ne3eBn+fVHR4/Cjn9lmJ9KBd5wh3SuSiXxrdTk1pqt
hiDh7ZeVyPclD1eNcZ/sRqv7nWR5gyEQd/OHL7/7DI1dv8NHjQgovxiqrbag
ISTQSCi4mYm1+5dc/y4NYqJwu4hC4TDOUqw4WbPdUA2XDvtuN4A/96gx1GUk
/0I5XlKPDkPO++yAhWEpntx29h4TZyD5x/aP2k403NVck73Lio2bFz6fFxVo
w76a2pRAFRY5583KwS7hcKlqPmdF1m/XY6NX3ZyHPdK5BoLjDMQWKAiWrKjE
/tVJg9NUAnEYc0/aSUWMvuAFjRt0sMWZtGs32lDqebr+V/MI/BsvUfOF7kPe
vUKWTfJTz6zHVoc3A1ydPxb100n+lRo0c5vmw/R4rINOPYGSAWrWPZDz3rV2
+yqlEZjOZPysti3AN7k/482XCZyN5BA2jGrBxMoNuaaDI5AZGXgcot2Ds3yX
5djWDJS7fN2dWugMxoXDgWFkf331C7bf66vGvYOIsH/MgOYZXtXiF/UwaGB3
+a9iIVb3R6TTik7kvl6u3aPOQHWGYs7a1lrwnXlgv6GaAeum8LRIhUKcfDrS
yFvBgFfr/VLZwm4k623K7b4/Bnf7kfAJtR58auq/L2JFh4dordHy1d1YM/wu
q2l8BAc1Asr37GlC+vuKhYPZBGTnXRQG8upIfQ2f7z1J4jGm6Jb5VAwWvS8q
rTMjsG2l9qlLMVXYWXi3bPwrWc8L/lO+1yOxSu+viQU5D0+cDt+kVoEDKz84
byT94dL65f+tN+8HhdN71IHUk4QZ0W6tk31oZBZyVusMgcNLKDEh7CO+umXr
5pgS+BZ6qe38dDM0X2aE3vlKhw7tXXjQrW6YTuyImZdmgSN3UZwjwB1lvc6J
upZk/xidi3udW7BB8IfS3ygGNs147Tze3YbxWp0zyv1MqJyQqwzeGAmX3YIp
Ou4EFsqM6I9H+9HiX5p/RpSO6FLeyKCf1Ui5Jq/0379MqEdeDnPaVY84xX/3
2GuSejLx6uXZ9C4EXBnxvPqGDq6Zf2xndtfjJveNmHXHmLgV6miWmNQBvqiF
hTiCBZfxIyvuJLRgOiSW2U3q8dHkHs/6hRZoNi9uHvQfRckWHzeJuS7cr1r/
t7OahfITMo7jIoHoywrp1LAh8Scbt3BatADr+s6WL89mwP95mOP7DCo+vuVj
Hl0iwPew5vW3hDqwDkoaKAgyILn150J4dC+UzILm/LrHEXLCXkvUowcmJ0s/
MUVooEQ+LAnZWYeov8aqqVNMWD55fs05ugMLBkXTdyij4NuVgFtbeuEboGbO
chzDzaadlBg2Fabv9dpWf2fB7uAnlxGXPuzIDrVf4U9AymLDchenLpTvjAs4
rUzgXMBh1nm1fhK3j7P+OI8h5s+VzaPCfdj5ZudYh8oo8m0ry+7JU7His6h6
ZMYI5qhemlVyjdD7pCRTIjkKumeJ3sLVfvw76Os9+W4ED1nqfE9MW9FGfyu3
W5/k58Hk+fDdgZCzdDMuOUfggILibwEuKoj+tgH3UjbmxMeC+5fl4KjncfnV
ngSmNt9XrB7pgEhLwsnoeBYspfVT1kt/QPJZk73CegQoPuaX/rEsQ1Tje28/
Piba8jznxJ/m4OHZ78/idUl//DW/K3eRhkO0So7mMSa4W3Mbq+2K4U7hNAuh
EYh4K0x4Z3ZiJoRndKp6HEr7nN1MrzfjZ/zsd1USf54+cYHHBNoRG9NhdSaW
QNtUqs6L+5kwYN22z/Ih84HDC1mabgOiM5R3PY5mYVuUMK9CdgtqOZ9OnOhl
4daky95Nd4ZAV7GWf3dpDM/XZIp5ZJXBU2uw7cYhAqeM0TfJPQiJ7Prk9eF0
WDoH1Dl4dCK1fjpRDiQeit3Wp/ZUIahvSuVvLQMF5+yqPVybEejO46f0aARK
HrzS/iwKwom3zfaapL7xv4w4sdMeBfQgw1BSjwTULVwEGeW4mHuoV6KSABFj
UWRF6nnXVq+tSYFM1Ku//xOZ3APZrK74j9HdqJeuSp0NaMW33u+XTUZHoEeN
EbV/mArv6GkjfjJvma9hbz+f24kV+ed3S9XS0ak+s3aW0g5toQWno3QCjhab
96648BZFElt7psl853AxI0BHtQ2tlj0fmK5MXHG6eHi5UTeZe88VhEjT4Zp7
c85ZIBEtlSUf95B6Yqe3LEJ+pAimm/Z96vYi9afuqPzsrT5IjFi277AaAIdQ
kUMRqlCbcrn4Ganf38oGAza4PoUFd223GOlfvCukXnserkK3loVT9+IIrNvU
8o5JV4LvcYFa0XpSr9jVgi2eZ8EpEfzFjOyPhFSa1B+HNlxp8ZFNnCP130wn
U2ypEK7GgSG/rxE4tKZo0//5mkVUdmltpEP0Tu3qfYxmPDrcZ9RdyUChlhXt
ilgP5p9JLP9WykLBqsYTO9S7ICu117qicRiSPfWvxcKKcUCxgfAn9YAiX1Z2
8V0bFpsU+LdsY6ExcYfAYfdatAkIK68boaM8RkOIKzAPxBDvCDcIsGkxK6ny
vRj7GMa3YdcYOLLcFaPtzCByc4uREXl+WdpOgU63Xiycz+Mp0qTj9vO5MiWR
etRIn3DpD6ZjZrAmvsJ1AGfVR897cTJR8PBVxMMjOVDy0nVuaSDxJ3BTTIU2
iJPJt/r6UxiQEwyLclsfiGXvoyVPk+elaepQGt+Vkbzj+vG0mAFHAxOhh2Wd
ENQJiXvkP4Agh6RcbnoPDL8IK7ST+G1KbhZPVqlEnK7z6G0zBmyzBf67d6wd
E+Z5mb9WjSBh6oVOsh+FdBWNwGpyXwxNzC6I92mHn/CXdK5gch/r52eo3ilH
kR+R0mdI5qH60jCJB30IK56Ttc4Yhad9RIrhxnao2/z8vY9Kx9eqgTvXTVqh
UOfI3ihI6m+SRf3BvizUxr+2d5Ei4P/BlYelQkOY3cK2KDUyb6hs5kx4mIeh
qybKnxMI3Dyfy/PkdznO8d77KXaDABfX8wuTpP88HWSdtfhKYIZqkr6erxUc
6+ee9Nwm+eW0ILtGrx8K3JLHON+MwUnfVfSkRgfeIqtY0ecLWihnGiNs+6Fe
sMYryYEFSfEg/o+1HXgtR/8U6M9GUO2sfP7ZNmRpnvnHuYyJUO5DFkk3umDK
jpM1dybzufmVVfrvqyCj7GPIViD3wTdja1IeUaHRID/tyE/i3dpjj+eKOmgm
dV7SsmFCdC2VCI5/ir9f3Q0cjcl6b3kdiPJtwuWyydxDL0n+91uwyjUTkG4d
kLLxOImnNukjStYvUa66hlpjQCArMWSqToL0jGC6lbsTgaVhLheBX12YaT7Z
GHlxAOdPq2vv3khFqToxyL9iBPVmeWrV0r14smN/NqupF1ky733TOCjwpU3L
zuqQ/IpTiOvkSISA7bqmdBK/cqcfREuWtuGqMb/KLJsF0Xs9+kn51fhV+MGI
h8wnEp5OW4/kt6H+SXjXoB8Tx2XljT4tpyHh4KVfXUJjYH/c181jkI+qTPFb
WWQ9QU2vVOb90nHxYSbN0I8A1XSmJjaX9H95ujrTahwtxiJsrvoSNERyf3/W
TOqHxIqVXZU0hB6ZX6fNM4ryIvFDg1HxKDCljfOT+HqSflfTML0eDbbKvzMy
mDgQuDXtfGUH5lr3CBTWMKGm/aXu3EYadltoZAUzGWj5zWt6cG0n5tsGtCkq
TAhlVVim9ZVD22PTxFI0A6e+JuVwHO5HdmSY5DTpx3PKybelMjoglvKsUmmR
jeY0H7Okdb3of5ymfcWBwMtPqR6CS804pKxjs9d2BBvE1h4+MtyM78tkFnJ8
R2GqU23Xt68X8TkaWaJFQ/B8JmNZrliFgOSSwV2jTMS8V5i8WtuJ+J4G5Zgd
bFgHty+9zPmE1Ilv2X75BERLjttUyxWg6Br9cEwEOW8z91tFKkWYslLf61rF
AK1DKnuKRoPurutuCesHUfTohEqFajeo7HU25iUsXJEbdO2trIKOWFVAch+B
d5rV6XIzXQg0eRBygcS3+nxVbaxqO3xXuWpsvj2C0KODSl7relDl2Bz2JHUC
oisZ1rEFFIS2FgdSVUm+54sJToW0QU1po3CVJQPfmnrqPfg/IO2BrfRNUm/G
5TLaSmhd6I6T91j7dRh82UJ6vz63QZsSET8zyMC9zaY1l8X6wNmksv0m6Rfy
F6KO7ncfwKa20NTjUSzM8Dnp8ln3od74m8idJ8OgJEqoS+xLhODdCeMtJP45
ivX7vFKTkTv0n0ChPoHUA4/IVb0D8UGtHnuYo0if13qnZJgA01eGbQ/UyOdX
PF+r3u+Alqmuyuek3g6cM/Cxc2+FRIf4eYNpFt4rCBZ1udDQt/VFc8WGfhgL
xvNoKDWDL/rnwZk4AjbF2g4VCq3YeT3k1afFYcS/DYzYM1mLtROC6tNrWODq
k+HqGerAo9/tC6Ok/qy61xofPNIIgfWu28bEGBBtuhdyeqEHy2vaLUIeMZD9
LHXrzVc0fDtOZWx+OQxNytIWteBqOP6wmcv8NgJJdckY96BedHpZ/1D3pSM0
PNjuS2MD7t9I8Om9TvLzwRfX1D9+CJ3s8DtnQc6DfjqLr76HzIdCkx3Zwyh+
8j1XKmYIMkWc/k+dmCicrl5HU+5AUb3lpz+tw3gknJ92sbsD453vHI/fYkPu
70SMLk8JRGKf8kTpMCCzR0Bnqq8KVz5zufiR/rlWdzCrqaMLZjWqOosXSX+N
CGSHTCYiKPKA49xpAkPK3lJpibXomHr5oECa7HekUGvUxmtQtFWUqyD3j1xf
4+YGi0Tw7B2Nmj1FoFqsVa9wWxfiRk3F61rJ/9296lc914KgQ71di4oMzH2J
+yNV3gGDugWuaAXye/Hy5cMPIhEqLMFWsCWw7FVhlM32QfTV5VhySrPxyjNS
frtnJzSvXNduO8tAwvxq+H0dhIm3Qw9H3jgO3eOiXN7QCcfncUP7ZQjsHGd2
TS2rxb3lTu6570j/CB9c+/hoF9797hOOURtF8ulX1Hn7UmyV7P2lHE7mLQuT
1S3NXci0yjU/v+ELTJdpJip79aO+Wn11zzM6NMXnb3cZlsP6r+eSoi0TyWUz
6/+c6ybnRPvotHoQvu2LBzeJ1+Is72QZzxtyf5B/cpKtcx9Hcx2/65L71Rh1
9IxUYSfyttjrB80RWPeGq9Qtpw5rbpeWplNYkFurpNwQ2IC/wR7cGlpMON53
uHratA+vzRS9no4OI9tbr4n7yEsUZfBHTl8lMKtQZ+Zf04MfL39K1WaO4n+g
nBHw
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs41VkbNRW5hZRy6QujiVLGyEHCikEm11SjDFK5flQ0I5ehGJcQpSgS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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41Wkbx8XblCwhkaXSlKIkhUL0RRmyNZahGTJkiyJKE2oQyZIIJUZJ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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk81dkbx29lJkl7MTUtaqQQSmpaJh/8pM1wa0gZZCxjSbaICVkqDArV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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lf0fxumREe1SSZRIqWRFZVySItIiFYqGkaysh0hmFDKSlZCMlhFC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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81VkbR6hIKEODUTeyjYzJkpAv2mw1qCZNluxaBlmiSEqytFqSoYwa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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk81Vkfx02W7hRZCq0TpUi25tGG8bFVKpXsyVzakK1LWSpT0qBk7GtG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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lWkbPl86kmVSEqEo31SjKEujQlfS6JgWS6LFRJYc+mT5+tFIjZQs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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk4VO0fxklFklTqVSmytSmSslW3JC32JbSQfWtBIUWWqLwtlGSJVJIs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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81VkYxsVMpJuYaVFRsiuRUiTTo1IjmghTEipLGQklVKgsg0p9MlEN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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk41dkfx1FRaNMyKiMik9JkptSthreLZJCliSGVvSlzRTU/ZV9qUEzJ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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVWk8lWkfliJOZWqQJYnSiYoiRU1vVztJXhlRGFuIimSyhEqJscbEUShj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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VO8fxSU7lRAlW6IoW1JK6SAtdkm2VIoiSyW02FNKJW2SIqmkQrZk
q+xkC2Mf65i5M0N8kV0Lv/v7a17P6zX3dZ/7PJ/zPuesO3Xe6jQnBwfH8SUc
HP//jUmsK+uN7cS260F2QcNMnNGJMAp8W47CcZHMLxkM2B3oXVfqV4uEb2r8
caVMmDs9OnnBpQka6haaBS0DcLMcqIgwLIeDxen1uzUJdDxqkT3/Xy4uvjps
OiLIhNKylBWnO2qQXqSvX+DFwCpdH9lHa9pwLNnT4sTGfjwY3sn/NyoD5eu2
DhwyJbC9X8qxfaoFTuc8L848ZCKFpmrRwS4Hw3O3hlYmE+OZAlnpT/KwPHxD
AGclgQ8Vkb1uCa2IF66d8SXo+Btb4J8QU4/K/Qyxl3QmGn5d1EnWrsYtbrk1
HsEE9IQl1hW8iscuYeqKoQsE3HNF1U4eLoZmVn+JUC6Bkl0bLhwxvw3nxCfd
os4E/KMnnwzu6YP8cOuJKyvaUC37KUOwLRNrV3rYLD1EYETHLPbQwy6ouMXt
vRo+BL14q2p92VosvXYvHeMMVH1TcXqVU4Xy3UIuPyMZ+KDIpPzJacH7wPfW
tBkWDpqoVfD/+IG0MdfEwrNsXDUWXpG70AETrpaGleTzIs0eKbc+94BPCXpd
Z35CxEzLXVSUgkfB0z9qzAhcOW2quZxBwY2nqR0pq5jwPfZZJ0ygEzsUD/er
+PxE6HzTyt6f9+F5Kanq62kCTlfMXuy3o8DWZFNaw3Ua/IiSRlGTTkROT1VW
76RD2KtX0r4lAQLcDUJhbgR0bl528l73Gaabk5O3iBHI3+AypXi5ASdPDdye
kmbCnW2s/MCyBeIRXkaGUQwct8lVzpOpRr7/uq3W21kQC265s9K7HDH0xSkL
8n6ahn8f1Qv5hOTHY92t5H42zJgUcNtRUYZsKmFFh6N2NmOPwidcT/rPxewg
AcdKqxufDNrg+FyeNSVHw4J68ICeNBW7O3elWGT/BEfCL+/Af02IvPntxyMl
Aua7ollrZyrQd/fqb7WlTGyzfzJ6WbgEe5fk8jQPMeD001co/8UbCPS0NcWR
708U+H7DYUseBowbJS6Szz/YPXMvf89jELQY26XnCXT6HQhtzW5ChbAin23f
APrv8Bh63q/BjcdyxrcsmNBdtanmTkwHXn4NtSo90AWXnldOVL5KuNUIBw09
YiItIr3dar4avyni/a7f6IhYCNvCOl4K9/RgrbEZAsKbtV+vX1mOFfb5Qwc/
MXCwIniyOKoUrUJGRRwSTBiulRNq9UlH4E7rwtFrBGSURRRC/BKxUSUnUCuE
AMFlvH3csws6kkoffUTYaLWoim91aYXKpStbksNZoGYoqX5Z0oYu+1OBpaN0
2EXEaY8KVGP13q41lGkCqY8GvU3vlKF97bfTa/sJ0CSkWGFSuSh/w+qPcyWQ
UayxWprZgYToky89mDRsz77O6ZaTiz7dnZJrPQhIKA7Tzyk3YeiQzof8ywOQ
7dOXXjXSjIiZzdPm4gOQe2f9cc+/zxhnJQTIcBLgULNJf9f9Hb7/DlfUdDKQ
ps2HrYFfcaP7yn9aexhYbb6s+XNoAZSO1L/7Gkcg9knYxPi9Oiz3KVfzkyRw
I0P4oZJcM+4JEYSoKhOveeQqiwxbIPzbYDfTjuTBcb1p+hwFRbeWNQeODIIj
7fivE/KJ2OUgt86X1OusyL6N+Um1eK5597eyKgt28ZI18ic6wXFf/upDcn5N
xAJ8A482Q1ZzLuulNR0cOf+pUiVPoVaQtmHyBIHuh1v97+ytRP9jn5mCZUxE
eZnbjt+iInlgjWpfCR1SvnEB9i7fIBYT0/b1GQGhEDnlYekCNIr7zv7cSEBM
x+Vj1pdmDFSbz73+y0C7zH/0JM1uTCnr/+bZOQhnkfkd6tkV6DaQdBN+wISe
+Z6jxxz8oGTrsF/mJIFgQeOPt2Ja0EY9uXa4jY5ljpRbGvbtiNolZpC5bxBp
eiLuks41OKWReWhSiwVvHxXbSalGiJuv5+hwJ/Ua5ijl8YuCqdvaQefeEIhu
cx+jazaj3fBjXeIpGgZfOU3NX6yCpeKrtJp5BmrFNcRfF5dit3KMrIQyE/Y/
ucYydjVh7aiMi2wQG0pNS2W8RvMgruXaKP6PgTMLxiETuztxg2Iwdr91CPYb
b/8I6GhHaNkb7pHFLsQLtazZ+/cHBocVGT9eM+AvPzYXlduCfJsXye8Os+Fk
tuxq578sFFqOWK0n79PxYHyQ4w4qzH1FeRK66ZDTNvzlUtCNP1SfdKEMGh5s
E3sqIFYL1NFpS3UZoAUo6ZQ9pOAln5P7DhcmDv4yPhpJz0XsuTrfInWS778G
3mlRMyEsbf7vzDEC1XQxeOyrhuA9iUZ2O4G/K5IlvGvrMFpuupn3LQG70tvl
zxyLIaxqk32eh4ncyrSh2VQqbPScSkQdBqCQknHFJ7MMEcPcfB8OEDho1vtd
rbkGl4YeW28xYUDvQlOfv2wBeEq/u1ySIbBglvTA+UoVVK6plW3VI/B+sExE
NaEIoZ4BVuvfM2Hs0XeW5V+K5WfnHd42EAg1Gan2okbCSLDr+yS537mqJx/Y
fekIviUbayNEoE/dYdvXmB/oG1jnPvuRCQ3fY44HZerBy6HZa/iRhfk8iZte
9zsQOt4UxcvuwnueTvEfohW4X9ZkUDRA+tdzAUaMDRX7X9rwv+VkIlRBXkTC
yBlGmUv5V5DzPuJ/cnh8RSmssqw2cA2T/sz/9XO4WjuqLm8JE73ExGre3jCj
q1mIEjq32tuP9CNem/rwvB+wrI7lnRwleWtQZZs79h1T+SJZs/EEQvhPMWML
G/Gp4e7UEk8mShIFI8NeR+Jk05/SUQcCEdXhL6q21WJGVKAc9uT53zTo47Kp
gsvgQ5XHE+Q6xL3B7X4xTjKvCDdtIzD16muvtm4LygMSBQV4BmCoYLlXZqES
Nn8Lt/uuJcBD3ZFg1N6M419/9Use7Udm5ErhRe0CLBzz6rNbRkArWDB4gacV
RPHK324vWGhaE3/bPbkNu7mXMr3/sqFyu5xfvKwDza8VpzSXD2Jjye0v/CVU
hF8/OFcVwoAGQzLBkLcNPzserQrZxsau7Uf8FlZ0Yv/Y9KbwRQYk/UNGB3d2
4nhA4Y19J2ng6znqvH68BBcTHa5fnWFgcGu+na10M2akXeX9PdgoyXiksmxD
C+asghxtdNjo5OS2mu3shLxc+pSGCAM2fNmm17La8TzMTb8iiAWnAcrq7k8d
ON5X+a/Xagg3vy9PCLrbBTX9Mw5c65nguOx6KUI7FY8FD4zFniWQeWrdhIrU
NdTG22o7kvnGWnokX5lejfFV/9j55+gomissHP3YgqcDRnuV0gfBVXOs0+R+
OxCTpLR8LwPMjuJVfr9Jn2u4rBgZzYbCMqvRD5+/YWWT9tAG8n4Nvh89qyNF
xWuW3peQRgKW3fuXVJDzLJJDVCz/QsCNd+tvN2obHvx5v+rqFxaEy46ML+jW
Qtyp9Gu/OwNRyW6p2+3KECoRyltE+mGs8/4fJcEUrI519op6SuaX1mf1j3NS
0cl3W0EPBE78jdQ+uqcFftr1d9zZDLgFKJ710cnFeQ8vf7ERAhVnz2nLPutD
81TuLkEvOlKtFyOEOGogOsV+/bCIAbrg4rNrKmVQoSbu3KfOwpyyxYg0FwXR
dR/FTteT+9txPuAtZxPC2opqH2kzEDcmxxKUpuCmkjx3iiIBNbFLm7ceK0VE
x1EFznYGkrjZTYpabbi7zct/H3n/b1wje2xEu3DtauBgEa0bCzeD1so4tYJf
/dn80mk69K4uvy4WW4c1OXxRfvuZ4Dvy9PF7awoOj70qPX2NgSsaidjzIA9i
NePR/6URSFKI5j3K+g4ha5qRRzQLMnmJEXcFKKDX/Cp0HexDobVZ1JviNrh/
bNKfIv3mQnorRePuN2ysG4rg/MOA8OxRTnv+PPx+oXHYnsxziZUeLLkX73Fn
cUH4HsnbaLH23GeUMlhInx2J3EVASuhxaNuuPNCSb/H+JP14eXCI3YuFR+CT
SZY/QvIo4ZvHirw93YinpVQGlJB+ut6c0OhMRPsll9kaL5LfMmVPo5c24dz0
Rb4KByYsMzMbjwcUg6+4iW8thQGhsud6F13aMLreqee8Dxu3VNhGX+Z6sNrw
ziXX+V6M62qO859+BJsqkYY+cn9XzGINLi12Q8GxdmDwPxbSUt5cmiB5IvbY
+5TkepKP85Z5vNK18GAuhmYMkXz9rXHyz/ZmvDqi3F/ykwFWZtudwpZ2iD7U
3xm2l4mEpIjiaqFGbDkfdlgik/x+6UyOLJMqlO2E0Y58kk/ywUPxm+MgpacT
cs6JzB+88YlTZSXQdkmtcibzxFzj7Vtcni2w3+ze/7qdjswMraqWTckon95p
WxVAgP6PkLH71YO9cXsChysZ6NHWfe2S+hXCFTsDlEm9cFx5PfOEzMd/N3h/
4yHz/jjFcFX8VCNMCz+tosuTa+8vzsEeFVi+zfJfH8m/HdWPbEbLCvDQ5IJ1
4wMGHtyR7dE48Q3ZYz+UaX/J+aDkP/hFVMJRiuI1+YT8/9WPv4++KkGm/fUl
/I8JjLvldh5TrEKK/ERqC5nv9X7Q6m02ZYAprV+n7kvy4e0lgxyyD9rV28g7
n2aiPmb4TNzJElz4lPVkC6nfaOHVk7c2lUB9/+KBSiOS13lObb6vPiOnQEqk
S4LUZ5bY1ljZYhhnPbCgWTNQsVXmvXBvE2LemXFOtJB+KG6x97VmOA7IvbBT
J/1lx8otcxKeiVhlenJOl+xjNTwlA/fDKWj0UfMXWsOCdcHit50Glcg2eF3B
4GFh0MH/Td/FPOwKV3a5Q+rL0meWXnChHKXPFK0PkPpV4HhqQZEvxWoWlyqb
zJsa0hwSNOksHD/2yWw+nYBNo+vs3xQKLGVD5UM56Qh1DUlxC86GyIDuhdgs
Aqw/nqncJa0Ik3yzVJ1C+svNkFw/zQoYb1SduUzO+/GQsgp2cjtooWNseuog
um205n8lUTFhMtvVsrUPgTrvdwyWtGDPHf3NMt9YoO+qX8/Oo+K52O7bisGD
cCsYEukp6sAKtRB9viAaauvjrNJEO/HeObTIv5AFveitN9QNqeBYmylxPWAA
DRP5m9/J/8AVA/a9ogUCvdfPj4dvoyKuXHHGW2EIPDlrXLs/FCCLi/uw/VUC
ttmeUfcES9HQ3ZM/d5dAcsXdnVJ5zSh8E1y4fw2pV7Mv6/I0W9GwbvJBeA0d
WocvJEmc7sCvTUcU1/GSfXj9ZsdzdWR/7Vg2GjjBQERKiWeo43ds8eV6yUnm
v56wZc9PiFbjb9blV8vfMdFbp7Exp40Cc+OZd1+Fyb5O2Ofxfc7Fb9XSDj0b
sl9800iyXNmIwGfEVFUUARWn8v7llt0op+o3n99O6ue+Kv/9iExks2Vnz5N9
g1be2jR4g4pDaRnt8/rDWOJ0b7MieR6zlyYa690GQfs8SH/7LAF/m5gVzhZk
PrKVKJ88mIqftbl5ZUcIBK3sCcpdbEGa2YucmU1kfx/pyZCY/wK6/zmhKCoD
9ZSvYaFdNWi673/TSoCAiJofdxatFYac91xKyL6VP1y8zkkzE7HXDQVOkf64
Rm7yToJtGcYtv9+cOEzyWIBZ2jjdjDOsvoybhwbwaomdG+1kD5YzEi2MRDph
eviA+qooCjQCN05R79BxYX152+plWbDpvHBBroNAkeHitUsjpXijrU7tGyX5
pLNjdq1lPQ6OToWGCJL957h3je5iPZzkHE068hjgm9zyfE6qCvKLlzccIc+n
Qb5Ay2e2B7vf3TheLDqIuZnzz9x8utHDpb7ROfknokadmNtHW8A1r2Vc58JC
rP3Ap8TN37GN/0ZmpjkTpkdP4N3zMkhB02/0E8kDQ17FL9fq8V1N5uA8qccK
xindkYZuVA7ny7wOp8Gy6TLDx40KK5u61AKSR8R6V0amJxWDKXSJE9vZqK+m
jx/uo8LtVkfGp6RenJD7OtjZUwdWqW71+PwAiHRmWI1wH1rGPFkjX1l4NZFQ
353QDkapg92VB0PQG2YrXe56i+1ti8zlEeT9L1hnnDWhwGV4o8pxe1IP6Qeo
9R7P4VAe/z74MgHjgE/j06rN6Iq+K7FlgQaaOH12hv81cvdJMpLJ/DhyRvqm
6qEq/GsTeeLKxcBiU9CR9n+d2HjWzaLAgQWrgopA+7wvmGEpxfWQ/t0VI9Xf
d64NK8Z5TvfFM5Eef9N5XXUfJrJdp+8ZUdBnVNBgercE3BOW84IKZH6dOv54
MYnsB8cZj/ResNGm1tRvYJ0Hv7T52SO6JH8DBR2Wa/yAAJMjMZXkBb+z9rcM
0xZs/w6OBjKvxqInPt++EmIeYzZyzUw4RZZ5/HveBEmbvobaNwxc2OM35m9b
AWqptJ6IMQOdaX4zWhcrENg4nbeK5JFl9L6lfTK1MJVzqm9eJKAgre/w4ew3
pHLKt0+aEIjyDT11saAHVpN3Vs2L0dB5YvPiUtM6nKI9Sgxis7E6Mely5dJa
zKlPWFXnkP2hZ21AswkVwSlbNjqmsJFvejjbam8zRBqTirVI3puKP25JI+cl
OuxQTO4OBuTqvCwH/FIwY5Z034L044N/JNvEC4uwwrDC4VIZ2ad6lix6J1NR
9EFPSltjCN5VysH/DDpgJfulvxd0xAZ9PtH/Jx+m25Q3GcYQSAvpkXnqWYHV
m7MjxWpIPTxb1/rGvRThqbYl/5F5QyhjF//enV3QEG0xjSf9Q+nz9Vzl9BbU
lRv2eCiw8VN0Inf6Tyc+2JZu5lZgYQ3vpEJgdz3q7V1d40oJNCnXVBk6vYO1
uWqAM8mj0DdbXeRiX+D0/pNUTXI9QYgbrxihYJKzfHhgD/k9WyKNddeSenXa
Sp0mecr1bmxFGtGExNyV0zlbBpB/Nm1j8zWyzylKrd5E+mssg+t+cWIrynar
5hRtYSDwqcH9zvBuGM5UbyrxZkOfe2Rk52wfnOPsq4ziOuBwuvOiXCwFyUef
8LKmyHk38/qx4XsmGupoegd1CAgkmZfNtTVDSiq4pLGEDnff9IaFyErs+jzu
nstN4KMu5/a2DgoOxTDjcl+y8Hd+o1ePUDk0lR+ceEXy4UOdXehVjzokhlct
yAYS+B/EDRv6
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk41GsfxoeT5SBapKKy1cEb5eCUjLpJorQIZWkQGkcopo6otBwOLUp0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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41dkfxy0zo5QsLZYSNYqydM1QxtJbUmMpZOwRkZ1IQsuIFvk1hVEZ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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs0lekal9smhWYkKoWo5HShNJrkp9IUORgmkUQiEhU5llTjOqFSMqLk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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lf8bxmW1rUTJDEXJykjR1RQiktDSkFHZo1SKr4iMhpKUSlbTKKOM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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk8lGsbnnaKZEgpJSJSspQS1aUPHcophpNdNJEUWq1fURxCISJL2VJ2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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs81Gkbxkdaimz0InKsHErW6SVt4aImh6IsRS1ZNY7JqYRSEkqUEpoV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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk81dkbxy83GjTSJu1ESWkUTVT0yShpaBnlhrEvkSQ/kzWJtKksxUhK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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2cgVY0bp4QiUaneSkOyU+ovJH6RGRWykxVpqJAGSRKlQogykhJZ2bIy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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVns81NkbZlq3JLdySawkRG1KWf3E41JSuSxdXFaSdEGytElyrQxlk0pC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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41dkfx2+o24gWk1KDLJVlmgmRmHgzk3UqS0byy64myogouzuISaRF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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lWkbVlPjlCRlmRotlomRkbSZlAsj2YZIXyKSkIpkUnYJCWEkaw4O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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k8VG0bVtFGkSRKpUJaZN42W7mkksheWUJIklLqRVG28hZSSQoRRYuK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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81PkfxxHlzFkoGyrnjtCq1Na+KGG3IuXOFkKiMlEiyRGZJCGxHUon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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns8lOkbxlFRW6kUsUjaVoeRHHJI1sVSIacsEol1WNVatKRkd6lIVNY6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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk81ekXvpkSbZaIaUVlSXGRaiQPWvj4kZCikCxDJkWpRCLrCJHBtFCK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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2kgVA0XxylKUSlLJUVFScqaNvpnKZGiHknITipL1oQ2ochOUXkiyRYi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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk4VfkfxymPbcygQdRkTIMxyNK0mGjeKpRUSOqWGXv1oC6RbIVKWcqS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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk81Pkfx2crraMUUSNqHeVqW52OqFdp0zWErCKVI/1mWzasxlXIulIS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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lekbPsSYmqOMiUxMWcsMZUnSoFsLZRiZBoWRLWUsIUumBWGUbKfI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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k4VG8fRkhlS9ImJEoiUslWd1pU/zZJQpJ2ImSrUJZISZKtkiSRJUT2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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81VkYxm8oKklNU8pVlrIkjZSGyKNGRZmrmlJhbKkoS0mWJDL2EI1Q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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk4lekbJqJsiRCVtWUSOq4UJW4mhJAUbaOyNNkqMxRajLVB6TeDZF8S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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXlYjekbTtPQzAg/GhOpTiJZCmkh6S5r09CmfZMWklRDizYl2lSMUSkt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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k8VA0bRZJEIcRbIluIqFSUnJRKwpslyVbJ/maJbFEmKkuSJVIoJZWt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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lWkbx+1DvEIabWPfU2mqScivsaaOBlNIoRBGmyxDykihTZPRRiJL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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns4lOkbHjqQQw7ppMkKoZRDibal25ZQUtLJKSKhAyFFq50Qaqm2iJCK
VjmkHIZQOwwmjNOYwcwQYb4vicJSUlv29/3+eK/3ev54rut+7+e+7+dd5X3G
6bg0jUZLoc7/76zjzzMlVjzQ3HSZjFcETrOsPnuZ1qO8NjFcI4FEbvDGkbq9
xYgYUGMaHyVhrJjC1U4sRhH5rHK1I4n4d101hY/44LQ5HFjbTyBkJnlPjDof
+9uS793bTIJtfzZ3n0ofNkmYw2zdXvxI6/FU/YkPhdgU9f6FBD6t1tfPpTNh
Kwg8dcmFhI0K/6kgoRaNXurJyaokEq3PsEst6zFjmTdDxJM4vL7848uhPriG
xamNiweR0aN9/7/QHowJJkcErAHQFAJEuTmVCFy5S+z9gYBz3vWG87zXSN6w
O2Ro6RsI61nTUkYsFJBf3QIZJBy/0toL83mQ/knBrLFOAq1OnWiuhQDZTsu0
M58RsMvX0n7cVwRfNvvAxsMkXurmVM2uaUTf+PSRpBASn8pCGcnFHGQYTAYX
dROwMqM/OWD/GmeDUtL39AygnWni8/4cDyJi3ewGZQLiG9dNy4leTPKze+Sq
epHaVLg8Mb4Z6f5Sh2LDKf6V5IVfMppQyDyz1XWAgOYKFa9xh4cIl1Wcv2Q3
NQ+TQo17pnkglYZFQ/YkdgQxMMMQI9vxhoKf1VtEMi3Ixd7n8B+xfjjWkwTt
SWuTsmsICgaiZPw8SGSKTl9aY5KC0i3n3l7wJiG2vmx/cm4ffFiKVc4FfWin
9w0KPpSAzfrVwtaIxLW57Lxd6Z0wvPXn/k0vJOCsm6roNeFAaCZDJASToBt+
8pIa52GJtK9jSAaFP7Jxu/AfPmIqP98KTpCAXeRkML6vF6HNU4qvx/twzXOx
mrVyN4QnHX66YjYIWVN5690jdeBIucTk+pPgbiob4xt3QPM4YXuTTqJi3qjs
Kl45fmxv+DduikD4WYeomvPNuKv3N8dfiUBWZhai/m3D7n09K43kKTyWpTuz
PTtxf13gOKtIAv++u74/yxQhK+nmvEsWJFrilH1VFwrQLH6stPacBD6xTz3+
LBGht3J5RMQJAjd1LtT/O8LDLTKI+dSUQNX8Y1HCuibohBll/krpwdmGYbnf
koVI2dUHL9YTMBY8pvFaX2H4i78whsKbbvV53f6wJmiWf5ypniBQu/N1WpWt
EPQdR65efjOIALm/F5YnNeDuZlJiRBJoDxfxHhzrg52WQPnr3l7EHzD4NHSb
D1Wnn++Ejg8iteYMp/RKCeKm8ywrqPe9+VxwaE//HTAebDoscSdxNc7S25Pz
Ara7ZkXf9UiUXm6tNmO0YEix2/j6DAG1iiWacaYvMBuQqmGuSPnLYdEd2nge
2uzbvdopvnOz1TJWLG3AUtlFy5zMqXr+VOoHoRgPuRsXq+YNwKru7tSDlZmY
Gf54keVAYsI5TUGFy4TfWJScHKU/1cqtH/276pHdvTPg3BES0gUxX6Nd+Zg4
mGM+I5JgYIhepuf7B16V6VR7UPnRITstZteL4RbtYW7QSCDlWLHxnC2d8L5X
3BCoL8GEzwm5xiQe7r7zNx+JpvrTC7//1ZWFUWPb5Gw3Er0GXdFtb7sgc1Qj
45mQgGNs0u1amUY82sm8LqdLQFgUVMLTb0fi9r/ElnsofL/clz3t24KiOC9t
62sSHFM486ikng1pd72PQf8QsOeuTf0mEOK6kbnU/BEJaFEu97J0QvBgTVTZ
F8ov4mEv1VPOnZhzcpUW3XAQ32wWxO0Si+AeYTgibpEgsi9+6WXvasR8i5io
uUMie3pIfmqnCAJTho/h8UGMuicve/JBBFdL+TFpyv+OkpyugJVJOGTBzgQ1
P7OFixdG7nmFAE3+ke+nSTxfGfwtuUMIjmvHr9rxBD7cMA22UeiGQC7kD1EE
Af+SwuO9n7vgmSaz6tOSQbDPMrKyfW5g+Z4U52xXEpvJpWNOScUo5fGT4nRI
+Jy6Pb2bKUaaNsdiP7MfVvuj3DdN9aF2yKPGxrEHQRrPPWOf5eFYAkc/wJJE
Za/eZPFIJ7RufLjmryNBZ6tOpGlgJzasuDebv00CO30/DWsFAZVL27ndC0nw
qrlVjTY52KDEm/uLL4nWB35Fc5I5OLC15qPtRhL8C/GzLHonXLyTXn5WIWF6
PqRUUyQGUzF9zmTNIKxKQo6s7ajD7fjXUrwFJGa+8MP3ujfBN2Ho6SmqX3/Z
nFgvGgu6mkcv3H9H4MuJUfOOba9hUvWemewyCK3AkURV3S7cCqaHm70nMPu8
XF/k2QEuN/IhLWYQs0rol1kqQvSCLpXBBgmK8prz/QyzUKBXmbue4p/usu97
m2oxNJoZXt9MSNxOLMx94SxGTOBus10eBCZObMvJusNFKO33N6c8CcxtT6rl
5lfD7rTH37NrKb7VhMGlU2UoPBGcdlebytt5SmdGt91EVfPvq5Up/cwccV7z
WCML9NGKBX6BJBakBTvlX27H8jhnnVE/Ko8MB+vkXRqhZWChMNedQOo4u9ye
U4SMCm72QWsSFltAyPKZ8Jly/idNneJjq+/6ROtmeDjKbuEoEqjIeMpwiOZj
eE5y2LMrEkzff0S3fteJr6FBqY9WU/rMa+g4Nx4BUyfTAyepfXBTHEvt2Dqk
b1O74PuEgIyPxem1XW3wMGK5GYwToJk9+KXsWD56ZoiDKocoPl74yTPGWiBd
9XUFw4CAtnXlny9HOvCzlUqouqMEUmHBjK6LQvQffGg4ZUfCPY9Oby2rQc+2
kL221P+ADNNQ9mZzMDKy61IZpUd66vVlnMIu+NJYm7d6Un5LuqlXGv4HHAaP
Hx6j+Iokh4dFt9sQPPmbm+EOArJt2HTKphNVU6Wfrxyi8qIlLLLAXoCrQRrh
V9QlMB4xUj96+AkmrDrfrqD2s+MGk+Jb0624//xHSea4BEu021l2i9pxsem9
9HizBBVWlzKrc6rxPYH736K9JJ6MfgqS/42DFudwuqIPld+zU71Q4SP7R5Wv
lZIE4UluKwvsasFKPK/2jNJj7WR/m3ukABv8D7U9lqHm33A1b8e8aiz30NM1
qiJwtcK9VUf9FfZ2N1SVUvX/AI2Zurs=
       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lWkbPlOjRWWylRMRsmSJdiWuFpMoUjGRSLJVpEUoCkVRQlkrCsUg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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3cg1e8fxRWJklRGkVlGm4zQOMgqlCKpyOxbaZCUkUqShGS1kJmyt5It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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk8ldkbv0qyZcvIEsWoSGIkyfY1iDJqLCnLLWsqQo29ITf1kygpW4rS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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns81NkfxmkliUiybuWSW3Z2N5Rtkx5Jyi4Ssi2lSSXZ6bKhNC+kXyqK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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4ldkX1mVm6GcodYZQLjFjdFPSKOrVjRJFqaQRHSSVSK6VQVLUISpE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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VO0fxifZSZQoeVHJUsqSeiW6JUW0oF5LL1FZi4pKKRJRKVlKIilF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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lWkfxsnSW6lMb5QaWxlLK5IkdVnKNkSyVfZUlmzFUCJlK8n+njFi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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns41GkbnpBazVohk1TrkByzorUSboRqY7NhnOWwnZV8H5JSEjkTmwg5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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8Vekfdo1pKEkZKSS0b2JCfpaeq/yQNspIElJJJUKWFMO9KUUqGqQ0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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VP8bhlWyhyxZUrZ2a1R8C492KUQRJSKkbCkprbaiLKGisqQVbdaQ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk0lVsfx89V5kOKupVZ45VcQ8XV0detK+NNplI411zEcjQSCQ2mMhSi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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlmk81ekbxrXJiFKULUJSpMhEIi6EMbZDw1gyhUkmEUm2bB0VadE/Ii0o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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4lOkbRkSbalYTsiOVsqHDsp1QbpWSjT3oZGOdKscabBsqiZCUlUOY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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3cglf0bxikkRTIioaIiSsOs6JKoNJARCXmzehuiIRWlSVaK8KJSJDTI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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8Vfkbxy8ho5IrS2EaS0rS2Ic2H7RYRpNdNbKXSGoKU0woNAqNdtmy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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk41Wkbx71lkDmFhkx2KhpDRNL+VYYSqUzqqGPsOiFJlhZkeE22kWQZ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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lWkblmJkssQkI5WKqSRL9TXV0NUoKkJjfJISypZdmVIMIusnqZDG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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VO0bxpUWeZW1hSQl8RZF2ZJcekkqsrRQyRJZIioqSaWSPRSpRNFG
WUJCZG0wWYbR2IUxZ4ZkK0KSfs/vr/M5n3M+5zzP/dz3dX2vNSc8LU7O5ePj
s5nDx/f/q4qDHn91fi1cRBg8jhaFLY9vFejfbQWjPojvshkPKoVRfQleMYja
XZ505SiF2JDEi7t/MxFUYKsk20TeP7zRfmwHA1TkqiORuyl0LnlVv3pbHtJn
jB8rD3GQ4vF8f+nTT6B3rbCV+dMLH+nKX5EHWNilnsd35xMHsivp1mtcn2PK
1PXLYTsKAm62JatOFeLc5pnAc24UavWR2Hf1M+5vOK2z/iAP9JTUfnfpfLyZ
eqsSP8PBL8lLay5uboGFyMcm1V39YLSVvJCI/4z9K+a35KnysDUlGsOP2/C7
8Lej5akvUFl485WUeCgsrLu+3j5GgaY+sUAopBLb5LUwwUf+r2BUK72nEi68
cTnPWxRevDN5mO7VjFnN6j3isd8gIfu9TWp5I9ZXrc8W0ePioPcW3XXN1ZhY
b/LfE2k2HvyW6pxJKUD/d7stV3spqNzlLw5RoGNglWnM6D0Kaw6WfFzY8Rn5
cqqW2to81NEzau/erkZK6eddSk84sPOv/dkr8g7Sh95z0ns5MGtJDTXMLUKG
wfZG2aUUwpMNvPccKIWMsrZfI52C9vmb2Tl/m9Hj7dXJleiEStW3qe6DqXAp
VV/9i9TPNs0ijfWMgU3xArd3a/RDNjrY4KZiIqpe31XSPEhBNls/SazpLc5r
PFMdHaOQX5Uomt5XiKhtDsnPOyjwTTw3b2BFgSdnVHrzEAWplvnLi4RLEafL
f3YVWR+t66auYUwTfJ2+KOr6d0C3ZumQv3AFemxuv7Gz4oBubXfg1EgNHqrG
MS2GeHiQ9tdoUWsyVJ5nGvUbU7AbfnbipwkDm78Jb6DxcRGVbjd9as1LZFro
CzyWphBxf/B0RWo5sucqrKx5wwEfU046gPYQmUVtt1eYUOheUtRcZsJClAF/
SaoaBea2h0uctGrgnhr3MsqGi6Gc12+3izdjYlajWMCyHc3Ktz/QrlTCkf/t
QeFxCoc8rzqtNGtEaWbxG5NoHgRakbzA6C1K767PTSb1+eFiENT9/3n4VJTN
9OYg04kzrvtPHebnl36cZ89D7eHkWYXwFsTOf/on5182WuKndq4Mb8S5OR7P
nYO5qH14ps71VAUU5aWWhidwIfIt4vX09hx8uP7ZslSDwmU3BUHf5HwE/Xth
1w11CgX/zDzJOcjEf4ydKkOruWBtHOYvEvMHf9wG4yIyHw+exAmEG+bghn/L
kUkhLnyWyl1aHUBD84ccRiWvF47xT66NchmY3SLqHxfBxjA7+8h5PbK/Ix9o
gZMczDMZDR50bkRrr5lnjd9XZAq9NkpbU4v52W++x5ZxocCZ7Die0gGtLcvs
J9/3wcyj1pbtVQydpI2mFKnve0sLhlQsC20vCoXNvvfAOLJr5+Cbdti0W9Qo
i/WCsXcwlynXipSUooOb0vohPTT0frCbhTNqS5SXlLKhQhPdnhGTi01ZrvQM
KS4cY//400M/YnrRW3rKJgpP205n6KAB45unDJvauVhnbS2Z8KADBYEHXaPn
DiDR1VT/1tMW5MwEfDk+0I3SBZKWO31YUL6rs1jEpB0PuI6TC00LsUzrwaq1
pD+jZuOc94wmYjDOh15yikJDarCSjXQeckULVszPpGCV2+HqocPCI6+xPTOB
XAwOXtOwWsBEoeVPc2mXXvBJfG6Ti8pAwe6noj7KFNQi5jXvedmA4LzpF0oO
bLjskjuqdSgXab/3SM5ZRGHmhToMTyRhwb1Guw6il5Wa5m+LvrcgXOCNE9Oh
ByqT1n+zWPXI37q6sE2zHyqfup+0KzfjRURpwouHbLBeujCOz9bjmcjw1JsK
DtaKN/UoxTVCJn+HmDaXQrl40wY5YQbiEk32JKRTcKqeGpEcp+G/PnkRR3MK
h+e7JfQlV0LY+Etw+Cey/n3/ve1TCMDVAa9JZXsK1WwmZ19nI/baVtIW03ow
GooReQ4DGgKS1I8THOhMNDdHezdif8kZh2QuD7Jtw/wDQQ8w+P303hofoo+e
3OvTfXT89TmgnvgvhXklH4WlN9GR2z13/dr9XAi+fTQ4GdqMP05mPXdlyXyY
en9cK/UKl2qjMn6QeRVuemJyLLAZvZG/RAfX8eAz7+J8L4M8uHhMKxtyKCxV
dHWm8zFRx/s1r2gVGxdyxhyEbuZBQoIhnr6fQk5779VTdyrhx6y8dpl8L4un
EtXj2Y7pyv+C1k92o1PVXx3n62HicMLSkcWFv9/DP5kvPkP9kZpRgg4XSR84
o78eN0Fl/IqH/vOveO01YGvjUI0om0+Mz84cBEssVNnrTkPSnJFX8hc4eBS+
kGZuWYG3bu2+GkQvijNt6ILN5XB/Wj4sTva/MrTn3KfkzzDWjTb1D2PjB0MK
qnMYmBy7kGE51Yt4TdtVql0MDM1rE0xMpJDYfIAR4F+FoFt6uzt+cnD9W5x0
oRUTFnf6zwZs5sFz0PmCp+RntO3iaBzI7kGDX3PItT0MzPOfvqTlQsH//MqZ
q1/v4EzIpk5jWwqsJ9MMH+cqTPwo2ypI9ME45PJTyrkTVNeo+uIOLo7oX5jX
F9AGk6TMUnNVCkYC83PdB+rQelbXhZ/091TKLdGnlwpw/E7/4RKiR0qvY8Qn
SD+v9Q6MHu3hwPF4+rw74tVYkGA9J/5CL4ZH2YVjT8k8GnSaza3joaFFaYtF
2FvsiLi96tk54h9mXStV3ZpweT3re5/pVzzgMdwrFnSC8eyP1XQ3D7R3lqVX
eSw8cd4QXPWoD8Gsfx7xH63AsyDPLwrk/17jqsHXosvRI63cLVND/KfGmf/G
ks+Q5QndWOfXhRXZlSNKGsloFLlvMUn8KKX/UDivLhcvjuwrvHiXwqbq9g3b
Aiugm3WsWsqGPN+nsDV/ZRUkio6rs05y4JJVYKQYVoPIy7PF3fw8GMWHtrmn
1cK1TNhK+DEbaYKDgkecP2OFyjMde1UuzCJ6j/y2SIWiVn1AyV4KelX/9P0+
koRBGz/RC0SvrTvXdPOqa7DD44iimSiF/trS0mcSTHQXTcScMusF69y+7+pt
1aBmJMIt1biYoToHNq4ph//OjkVJZJ79v5bF/KgPwacfI2fvk/X6LFpwULug
DIMx9HLWBg5KR7iMgbXFEJtc6CL0jgP/rcsTK9/mQuzKoSmP+RSE/vU1PheU
hVeR+okWRD81mrinCi+246x6SvqyXOJnhwR2Zjk+g5jjwdo/VhSKuKyE/Vvb
sK7v/ja9bjasTvpLSUYzsceje4WUIQWzk4rawsTPZB5JzGsk+qjENq4ONmfg
NF9FiagvD3zv8o/5qb/B4p28FU2bKSjmbaqf3VWCc/5hUhCiEGy89bbbcAuk
j1crnVcn9Y4LK1JWqESzy+lLesMcnNxZxpIL70L5TGng6UsDEMhUV6/tp8G8
JrC+kOx/nvahC5evkPN2s4zknib6+rVywH97K+yVNZVWWfSB2s6/fOZEGUJr
Nl4Qv0t4If7VRFxOI0zsnMtyv3Kx3lnJ+f1sA9zztwR+EPkK+oGHP1V8k3Hj
oqjme6L/Ovdr//xUJLwZ9/C5PeE/s1CHnhCpRLQMT8prR1IYnLZ7HCZXAnNt
iVkbBS72bL4Rdv8WC5W1lX8niJ5L7zU7laPWBJ91PIVLff1YkXG/80ZpLqYv
bXWwZRDeOfO0+XPuJ6geXn+FEc9Fl0x7pPjhTtyWSrJsNOmDVXrrvUrUI82K
MV37hQJPLFctLi0Vaiq+pvcJ35Wu8nDRdqXjVMn3hgIeBe8L/f/GCLUTngp3
4vz+gojF5r/3xr+Dk8zzjRULuJgqszRu29kGXunre1eXsmGh9cskeAMLDEOp
zKENvfDXv6VSrVYHtK3+Tzqch5i5AsckiH8+lA0JdPzIRuYvn8JDaiwsF3IQ
Nu4h/dtR2/hNNxaxjb6xek7kfL9FV07pdMDvovxueWfSr5aWW0y6Y/Gy+vIa
+RPE75b9lHx1oAX0w8cN5UJ6MZA9EjqdW40e/vcKiWR9wafTdEPOFUNEL8dB
jPAKfX10heafQnx9Uvz13ioK2V1yK5OiX8FPJvW5USyFxsB0WmQMDSp/26qd
8yhcKpEyoTQ6IKD8KJJL/FxN/eXNbXtK0fXWLvChFxc51vpXFI/XYIluxN6A
rVwY7Eo+W9ZZAVqjuTzKejFj3bI0a2sHsubHz4wvYuPxPo88NQMmxN5imWYs
F1rzdq4260qFpJzDYjtfoo+V5V4/7Mpg7MNt2pbQC4E3KUGGwxUoN8th6v6i
MJ7oxPRsr0DMyxize3qEB98v2Vmt8RS5IVXML3tIfQRkLh20C4FvVuyJHcRv
EyUX2TdMpiPlEFd2QzCZj9x70V38HVDd6x7Y7tyHmFKjml6zD0izV3l8VZjC
sPv+GZEhOkY7X092RnHwo0PS9P2tVlxY3Zgbd5YDgfp9mlZRdMQvXtwpdJbC
mZrLL02GmvBDhnXCPqQPet/uKavof0Sa/IdRxk/C1xNyg2Le9yFiXD+7jfhn
9frdry+zMxElsOjTVpJv7LTT81PckpH0RlLcjvhLimJ5v5/YexxV1l+0WITC
q0+abPbmNiRZJJzffI0D6/IHf4MJ/++Q900yPEnyQ55qXzErAXy06to0a3Jv
wMwQu5EFx/UTUUYBhK9Ug+0qX2ZBNtczqZTo1clp7lbthTREdWkOnkshfjVp
/6VKphLF2J8Xps5FZm1tWIA1yRM6q2Ku9vXi4u/nbkfrmAiQXeanrsJD667j
42NZ9ZCJTu4NLyL+cLXdwEyyBctPmt5fq0ryQbc0hFObEPVw5b9TNm3g4196
j2/qFX7LLti1gfC8a/+c75quhD807CUzyvowKy5Y+iGlGYJrmHMqyHp63BmX
pP/JwCJuK/+OaxToikFpdcVMrCrsTXN9xcE4Xe6Gx5sSBCSN5DcQ/uhqkQn7
admIsdRDhqN7+2HdRWNrTLfDSMFikFnARqPoPwIzzY3IXh5wbtvpPoyaTyzX
8UxB4/cx9jILki9XvPK8I1SJZ6Urph/p92LJeOrrkYtM7GVPfm8MoeDSUDAw
J6YW3EQR01R/wl+nPjZSRjTIatINYlS4WOP76EXGeDOC99d9cFtL4Z+zjDU8
qSYMsKLtF8zpg4DAozOhSeWYGTPq7jXkIHeoqNJnaRUenup2GxfnQGusYaHg
m3wEhoefeKlI8iovKS9MLR1DKYtrA8n+w18eUOnVqcGP+pYTuW0UDFsblmh9
boSO5AeXoYu9OB6T5XpvYz1e7/cWr6O4aHbyeh8d1oxlmYust2wn/rlVquxZ
azomDuwWem5KYcG59Movd1qgKeR2rdl9ED1VSZNy4+24eOZ6pyo/Fx8NrJM/
rmMiUKM2xWSIzNOk7q6W0xVQKquJ9zPhoMOT9qDOggmpqBjrGxWEHz5Oeexb
/xF+bSH0R0MccPhXfhn2a8Xdzp8C1/MpBK2teDi4j47soW11sUNsJCoU7DPj
loBx1mfqiSvhw8ePn6ovLga1Zs+V//Nlv5HqbEd2OQRjI9aLkvoGjMV5Z5+v
gUESY2aFEumviQDNqUYn+JwO3pBH+Cv0jMrc5aJNYMV3xzvlsNE/LFhnatPw
/7xE1yR83ifz5ICQXTfWNbjvNx/rhJivhZdS3ieM/Fo76kD0Yd6yqferFJj4
UtJ/yLa9B1fTRX5HVLeg1qxnSs+2D5p+gVdMT7TCkKOW3fG1Cw9quIum4wsh
pubdM76V5JE1YUHGrk3QyLarWRTGgenUzfjLEbngXpV3PzhK5tvksvP3i3Wg
pTKWP5nfB9eYdfpSW6pw4Erq+ds+XIxq3Vvg/iIP4aLqHlreFLSaTr2WIX6v
8kd6sJXkM7907R3+5z5hQWLejKkID/4jYiZmtv74ONmvSRG/blQ4u9BZjIXX
FbL9guc4GN3brns7tBPmIRfH9Me44Guj+5+0jEfrg2TeTTJ/pcPeKds0KzGz
x/qDhR0XZ9ICxoXF30GmcybzEnkufe/DHY2kYsgMrH40SvhL1nn6IJfZiR2H
d1R4cznQa7i4wbSrE6mClbHKcv/nF9W3AQ/fYdvjdEFj0l9CGdd0aorrMSGU
6OHmRfz8j2CG1lAWjDYF93uS70fw/7GnK7ZASPkQTYnkZb1TBafnllVh9FeJ
cNsKLvbLn9gndZ0FO4+NMapiHBjtjh+/UlACs+Gj+UcJ/+ut6aop+1IAw8jr
fmNEn/nc41vej+/FwbVWoXKkH6Q22wl9PEJHwRzOmVp/DsrVJbbst+xAc2qR
1jJfDnT97hwbsc2ChvXRouEECpkzc1KmdtegM1NcFLUcyKdcTh26yQLVK3o2
0KEPDzZpbkrQLoFiRLLuvqcUYiTL1KZ0P0HL8UZDPIMLm/hb35faMREedlV3
XRUbvlbCUgazJC9OhXeKmPegOS/vUOSxCghbbh9ZHcBFhFTzNjbpt6z6hLmR
WhyoyEhYajelgRF0bo7gOsJHStywd3PLIESb2xCzkZxfjded9HxLOMqrtPOT
/bU6sOXLj9fBvUObVz3CRXGD+Eq5DCbOaMhM6+xlY9iq+ftpTgfkSy79MptP
9FLKaiOH8OzTm6Fd5elc+Bg6S/jp1SGO8lZqDSH9tdXZacQ1Hb7brQRFyPk1
JB7TD82hwe9LQ2zTbS6OzdJ8fbY1w1jIfdbTrR98+Wr2odcb4fT4sWg+1QOz
Lt3d793icSfU+MCKMyQP75y30k2jDtWWQrKGjv2wKb17dKNfJ17OSbHlz+0H
ba7j6itXy5DJFzfXS5mD2h/Cx27G5KLvKUdQv534afbFjjv7SuDRymh61UHq
seNm06ALE7xXw2fHosm8/534pXuzFb1zmxU0iJ6GmrKEXx9uwLJ6D1tmMoVe
1sAUz+YzCoSNpu/Vc9DwQWXqtWQZhpvsI5aIkHnbqDkTME3D4Rtjx6X7ueAZ
VYsneNfDI0DC/H4s6ZcL8jPLIpngGLjko5gC9Y3xKoivFvHvtqw+8x/x19ZP
3FWxRTA5kMGjkfzZqjLNvk54sTMhbrUx6bepJ4Ib1FUbMBJTs11uaS/+ByKc
HuQ=
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81VkYxm81SRMliats0RQVGYkW5klZWmQfJYrI2CWyZFK2GtMyRPYs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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4ltkbRhSJScnSGGWPTGOym1/dFIZqZCdRsqRkiRgMKflqypgsCRlU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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkbV0OolESlbGVtUUoNk+XnI1IpKoUce8JBmDRUhoNMlijmqzGN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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c81fsfx4UkaZBEVEIqIyqVhJdKGSEtK6NBaFhJMoqyc0tGJIpCUley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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8VPsfxicJtwW3uKks5ZYlXbqFVPTYrjWlZInIpXUoW4tsqSSh+REh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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4lVkDt5QtwhTGOlIkS9aK0M9SlqL6zIQsZewaWyGyxCjKkiTja7OG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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs8lXccxzG0qCSSooW1htpcUq1lfcgmZMhIzXCSynSUcimKUnIJJdFh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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2kgVA0XlijKTio7Za2IUoo8XhFJWlAqW0SWkkRUSEV2JRWplFASGqNU
SLLv2ZexjZk7gyxZWlTou9+v+TX33vOcZzvyTucOu3BycHDYL+Hg+P+vUJvP
CUnGK4gf/ohPewlEpKSqPDhWA+jvTC/OJNDWyBp5NTaACH/X87vGh+ChVCyx
O6MFFlJ+zxbes2Aw9luuTPkGii0oLt8dCFho/PHdpVgJm+whz6w1BORMzPUN
4nLRMtS8asyZQBznY0nxA+14/qJ0p6Y+AdO0C/xjSV+wZ+fhgKuSLIx/VBYP
9msGy+SySefXIfB4L27b4PAJz1t7qGfECDgFCVL7DWsw9fp5kaLnEBK37Xlv
FdEN3zciSk9saLivfFz6sm81UgSRWUtlwZitEHTneyV0gvd8oX1ioVnEmMn5
rRknxrgrd6uyUNwkPHmA/B5JVsAHW50hqEnyrxA1rUTirb9eaz8ywRw9I8kx
Wob6e1WzulMsvPgU4q7tMgA5Zrrxv9RR2G+3WrIsdABl4UzVQv5hKBQlSmhQ
aCgVecewzumEXcrDhu+BLcjpGc3dbU6APllOe8B3G6FXsupj7AnoWRVpKm3r
wQaJ8MAb9V9BOSWSZehNQdLhj+nfNxN49OK6dKxdCx5uTDpKdSfxEl2g/lBs
BkM7wk43iIWBbQEbtFV7MJs5XP7fQzY4/cok82ZoeHYyZ2lq0QhsNe1s4q3y
0P/pbPFv8nlyKYZca12SoWC/yZv7CAHNx8tCG/92YZnd5wrVbQSUYkZ2Vvt3
g4hpmRkk/3/bNy1UTjQbIhcPuHREEXC7QZHnTM7DqcVnas9MCHzX+Ot1UKUY
Il3HtbNOs/DIJrn3T0gZ3J0vzCyos7Bzy/MVmyRL8btEgDMsmEDg7hTf6LPl
8JJ8KC9+moBBdc/W80fjoOhkF1XjRCBJdnlIyKM3cORPVjrRxcQhJ43o90k0
HI6sP1fVRyB7NEFPoDgf306vFyl4SkD/rLaZSFo3pAK31Y16DWDE+3X0b9EO
9P0xefD2E4EDX7Itkint2KGlvmL5JyY6RVZryDE7Qbu3SXqrGoGQdfkC+ipZ
OF7X4v77KoHTQYI6S8IbkBZ1fzyYfP6f4JlZP71mnHtWV5+oPQTvXZpSv/vT
oNayMbYlkEBfQi7LaKgRctEG8kttWeBxT2jsDCnHo5jyfH1vJlzZ8ud/dZVC
9LHa03RTAsnn7Fh7ElowM/7YpLWVDZ3UEw9ubniDjSXGljObCFxf4mYiI9QN
i+qF0Y95Q5h9qH2Mm5yn4szC2qS4AZxxlo5TNujDZQ6LWkpXJ7Lrzze3V5fj
dZVmB6cNC0rBFas/HeqETvsNV9nGYXAQXgLUIXucVZPKP0/qc2PZjnOScrUw
G1KyOWDAgnZex7a5351QKl16c/QmHX1rqs3Hecpx/ny+WeICE5cnn0y93NyG
kbsfp9pW0+Fj+Wqp76pOMDQnFyxmWKC06SjcvdqF02OqnI92MiA1kax87G49
lGItth/8QvJV2fP3RdlPsCrXP2/1jgUp4ZyNTHsqlqT5e1NUCdDaYySs3Zpx
ZuSJ9NkyNkrL7yrKexUiWc5s/aIvya+LrgHMt2UI2DLnqDRF4JkMl0cArQ1e
6KIfOkIHz65VlqeDvyDdemlFcvYwso3UjUPUq8GUecLftp2BKxKGx566t6Nq
e3QX/9NhuCmpuaz47xlYORtvevkQsCkoOUJhV8JCOCh2G0FA5ejt/dton7F1
eHTLGQECU9Gr951pTkOn+SKT+xiBybXsmVS9dnwaeaK1/VYfOH6l+rSmnELA
mO29EFLPzem7R4IyXsA+zCxJieR3ercexyH/NsTZCaZ/zWVgjdkFSseuHnSe
WNmQ8G8CbpH39vnezoSHyQutXiMCAWprNvNdLoA2f5OO8l8C5sts366XawO7
z3JCn8WCj/N4K+VIGypkZo+y3NngblrjczqxBn9Ne+dbnNl4OqbRcCSrALX2
Sm9KhFmwPidbLZpbhzshR/R6ZOnwXicssMmiBDMGqVGv3xGoGJb+KbCpCLfL
HN86RjBBq8/p6hltwAWmdaDUDjZcVnvN3/Lth2uvRpbq9RH4Tj+4LU2th53U
jrM7xgg0/afwuXCxBduzhnP9RZng/W/pslVmnfhlGy8lkDMCvaTDH0LXtcLW
L+7chuMsTPVMp73z7kKRXW9LmuFXcDhQdwU0nIZAzFVPKZKfomKSV+/Lt0Fg
l43T7CU2tpW7jfFdqEAhf7Lmi9tM2IkXKz3UKsfP7ICUvctY4CjR6x7TDUOh
UVDWIVsCmw/1tv15+QGdNdNtmoWk316z6p/e8QonzxWofSb91yCGK/ZW7xcE
28d0ZYYQ4Dzlx3VdvQ/qQa9Ff0szYXCg65DDRAP8I97eE+Qk82al+NnE+2WY
Oi3o7Uf658WRrlVU0r8MXtTeJtYzcRwRg5rMbjTe9I8QuDIE6wvtCdXGVdij
TRmizDCh8/0EfVNlGca5DitZpbFQEbuzX2xLM0IdNm4ZJfEL2Thdo/q1A84r
dP9eTmOiz72SZjffhaauo4UfkoYhMxryc5reg/YMsQn9nSzYX3lyKNO/AuM/
vVf3/GXivgSljRJfhdelPdxXuNiwOK5y2SilBcrb2Q9GH7NRpjG05GF5C3j4
Cw5LWNPRLkSwvvE2ozuI++X2SgaURneZKCX1QpSdvKqIzMNLW5Js795uA+OH
aYhHOwNyfHt1hiPrMdLd/MOa1PtUImvWMj4NmanXKV6XSL4nscPHhDuxwi15
hX7IAITKji6s5uuCOa/B3rSAUXDceau5OyIE1gYDW7MdSfx1DOI9sx9BO+Ji
vxKZZzObrPfN3O3AoZ0nC6eOjeBgifzLdT9qYM839iM3icSnPr+t1S0Ze3jW
v6btJ/HXNDy2K30QhSeMhW1IPhRvvqGzcKQVdk3p4VpOdGSqGMq6WL+FuJwk
h5sugdJoMUkb8XJEELFrtSKZIJIlhjZbVuA/ZZEghgyBVzamNs7dHciVDmit
N2BASNGBz5xIQ24Vp4jERQJV9ydkLR63wPO76s++FhbGOIdElo+2wOvLgSyT
EAYKHk88DpFtQbHohs9TIP3EM9Hj/pt82IStPLyG3P/IlqACgX+fMNV6uOnN
TgJPa9yGDWoS4dvYsXWAzDu3p0kZTh9paLFKu6IbR2DcNmnO4UIdeO2f5PPU
ENAKXW2q9ZL0O1GZH5Z5wygNXUbZxCxC6MGjT5PUCfhGpoxs+FuGI0dVtz2J
Y6FEtMRofRQ5z0RYhrIYE5k3jNMkDWuxnZWiUOjDhBB7UW6L+ABKres9bbjo
yKVSen7EtsElvD2yn85GZmKZ0Mu9lQgwUSxK6Wai5qR6oca1OjxnqmebqjMx
nH7tjxCpz/n+gHrzKgZ8ji1T/NvTherBhXurSwZgoOa7LSiaCtPv9DsZ8QTq
TN0Tnrh0YmetleKlcjoKA0rETj3vwAZvpvuWJWQe2NxtvD9aBaP+3fudo5gI
FZ/PUdOjgZBt2VI1Qe5vm5B1bk4G1D0cem5dJtDxer/ggatlyBN+uMjIZCJn
iHNdqPMArofePKX+hg2px+/LGMpdoJuu4n40wIb4pnTz3Zcq8MeXtnyykYHJ
E2WT74aqsfl5WXaYNAFxCvfgQHo/Ds5yGjfyDKK0VFJiQq4Gz2Fq/9yDiYBX
E+KWeaR+jVIu3JtjYsLrQFXDk3rMJW+YvrOaifn4ta7J36ohZb988v59Jrzf
C8Ufqn+OkkCO9LVnyDyRMFF1Sc1Ek1zhk2iSb+t5k9Noc7Uo9Wmffj3IAm/+
129Zdt3ISEh9YOE4gsE1Css5uBpwd3oVdUGEgdvKP2LNN3ZAKW1gj6M72bdl
AjQZvS8xwn/jeboxASI3pGKdSznEn/yoGF4kEOWdt01Kvh8Cvx7qx1d9xeZ7
v3QVhJsRyDd5yekZC3U/S//eE+kFp7dMp5YdmYdRfn8ydMrgmPtCO5XEg6cu
06RkPAGRnQuFNQcJeD/sGk/4/RLiv8ZMBv8jYKUaJHFLrRb2J6QH/AxZsPF1
KzQk/Sw112Kc2U36gY7rzUCLNAiNT708Suqdy/DAh31+7VD5LrAwHUr2wxPP
EueNKrCne8LVJ5KNrKjY/ct8i1HI6H9gcpvAPPVwU8bbZqwUrO+WkiH9OM4z
x9U5G1EfPfX/JJJ4ilOL0wsaYaPhH7x37RBZ8l+9sivuRPHnEuePYsM4mB8/
Hk3NxGG14/5h1gR2/hE0Gnzcgz0NX4SDukj9/Wo8XYJcLFzVe6ThQuqrgWLt
yluP/hoR0cwtBG6W8GxVEW0ETzR3ZFzbEG5r+j9tmqvHq3inJZpMFrw9zmql
Lb8D4U5GswOZV6Urs668ulUEi3Df/dmKZF9Qyvk4R84n1JJZEzZA5vmxyEVH
xzfI7CuNOdrORJiFjMsB7i6klYbXmVuOwOb+Yz9B9Wbo6atOJSuQfYGa2rRn
eS/UvuwzyrejgxJxQcv4aTf8P8SUhw4z0exw7JACRwsCeJqDXu4i8bFhdp8d
vgsezk/mwWT+9fFJVi270omlD6m9/x4MgZC83Ma+2wJz/YcKtFwCMXStYN68
t/AS/ND5k+z/ZfcsFOt2NUFS6JyseuswDGp95d8fK8ep1ZXDTj/I/JI/kKeW
14L3eYG3/P0ZyOSneazRa4Wc0MLVw3xs3InLdPeP78UJrs33asj+snGdUbbM
nQ+Yc/XUPVlN+qGiw3ORG0VQCHHVvmtE8kU1ISTjAdl3Mx4tab9G7iO1Yt7z
ehZSGi97+ZH8czmbfZlN9lE7LsXg6SVMOKnsmv2S04aUCz8z+ZJZoIcTzXNi
FUjXW5z1IfH3yLrhoaFZC66+v+YKVUzE2WYrpFsO4rsafUXNlkHMeTq/VaBU
wpDzFMfsDhbkJkT6rTTvoSH26o5KDwI6KQNzK3QrYSTGdyF5kYF25byZfWuq
oTQ+zxmrycJiu/SQoGkVAhzExR3/kP1qZTlfghcFV8dNCrMNCLR6WDrv6OrC
TqvTMwnWTPCltApJKZE+wv18c/2tr9jZKv/p4MkORFYoXLkoPYzC+AmhixMt
aJyzGR9cS/Ld7NwOtbgW9O3hrdrTwMRa4a9F1e978DdQI+o0ewABGufv+n7O
gtO31ElO8n22rpdYJ+JpmJxLmPqhwAaHWG+Y5cdqlLJPYaMyE6eSN5zc/L4S
wUEB/rLnCFA0NhnI7i4E8YpmfSSDgGOssC21KAlbtOzNbEl9n6M3lezf3YPJ
qaBDNUFD4Pty2jHD7TMCvG59ePediRV0y2srpj5jtdc/6jzZJ5NWZPP83foG
hyd1BeTI/H/tEe1Fe9SOIxvU/sn9Goasp89UiHw3Gv4lUpzRh4ILfuEzs50I
TdYtPG3Bgjt3/vADFxqS+F+xzHeTfWne2dPCqAcWmwZVy6Lo4KBUSkdW1kFn
MeaOlDfpd05sv/iITKxyXDzv5EXgyONb4W8nadj24+psVOsEzCMUpriW9qGj
1qviiRy5f801nCqZLaj7Vhf0cNcA6OZeAr9eVENRVLn4qAEThm8kIyzfdUH3
xsreO/vZOCiqoBcz3Apef5Uto3LDaBLjS8oya4aO8GvegBEm7mzV5+1mdWEh
8/bXaF7y/YkNi8IOrZj1kX9vTM4T4dTCuVe8E27+snflyfyfO9n7VcSqEq42
/Jc+vGBhq7KHu/TaNjjtEU7krx3BmlZ/85XOrfjXl0d9u3kY9Bcfc+Z0sjE2
YvruYBEBC15f6UJ6F+IYA6u6djNAfeC6t7WqFnGR8T/fcLBQ7N15V9muHdk3
FPVieliwpUbua4ruRpuVLmfpSxYCsosYH6+lQlAvR/YR2Q9Kf4cVT59/j7xG
am6TPOnPW3NUeck+LWdGuRhC+pGHscNR78MDkPixnOqj2AH1+rLkMDcaHos4
Hg/kHIVJFDUp2rcTcrQ1josOI5jrsLFIcaXBQ2+0RpCPidKN90VfuvtiQ4XS
n1pSj2aDkcvXLtSB+pvnDbcWC7p/fbp32tRAfnpVmPd9grxfBbmyVzbAjVV3
SSeU7BfBVbYS2kWYmt0duMGNQOKtvkff+jvBlXNiZn0aAwK5JyWOWvfBWGEy
MVBxFJSOBXFt5/doTbJ3kCDvb47gz1XGht2oERfLj5kk8Z9WqVodUwBv4Ze+
H/IJJPXMtW4l/SNNj/Huig0d3YKmnf94q9B5o2/c2ZwBndtpNiIbynCJ/8/8
pT3kPSH55JLedW+o/Kf5uoyc5/i/VZnRx9tgGC5b0ZpAx5poz/hHjDJ0vVpX
w0P6p4fZQcdVZ/qx1+fAuqPEGCrqF/jtvzyFac+xaXVDUt/xUlanx5th8Fqr
7KAWAyUW+s9/n6Qi3exXt4EfmY8vInPLm/uwgfbmVOt2JihvA2XCqGXwaMyv
7SX7w2bOtw8EZtKgTv1auZy8P0OfnjPTcG0GR4Ezi6ATmA4NJIjBdlSMsph3
bzERwj31ar9+E9bRHSn55PdtNlcMaWzOxp1z33cwNpF8+Bk+fJ8rDQbbmdOx
h8jnqbAzR2brcMpd+Pz5XWyEdMuo5n4tgLGkh+ttbTLvD36zlCkvxMLBN793
bCfzIqJjasdIO8YtFhov5veBR0orMMKjjLzPvsvwkf5r0z0U7WHXijozXoYA
eX/VxDmliO77CCmTM8/fWRFQ2/foxdJz5L5K1ptZ3hiGJo//mynSJ3y0XfQ9
t37Fh5mK0ns2nRjM7/Q2WjqGR7/pBSM7GsCalWixYw2Bp1vfwM6yERmW+95H
7RnC/BTP8iuKrSjMadqoO0/Op2Zv+tWhEYF+/PzFOiS+IsF0xSPVCDhFK9i/
wESPf7jY7sgyhPtnLbtK+psp/jwrWNmE3hvrbHUusGHqZ/BNRpGK8WrZ5ROx
5H1seYRTt6AOS2N1EpTI/NnsfVF1LXcGosSUTX6EkffJ9Vvr79lexffLvUUT
J8l9Bz7ITMiNxHEie1rpOIET8TWuDgfbYVZVT0fYEDhovzSc9LPBL/pxYQuZ
P91nLt7872kvtl72uNZCGUVhyuzWwE8daC74cnb8GhslT736Ytpp0HZ3/bye
7L/5yxq0Up4UQ+VeNObJe0Zsoy5xqqkOxeGlh1T+snGk9Kyrp2E51E4kuL8l
5/sf/rj52A==
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8lWkbx6UMWVJNtsk2LfY4k0lK48e06ShbipGlolKR7PXmpYZGllfq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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk41OsbxlWiRYU6KpGOkS0VR6ks3ZLsR5aQhEKWFlosOaEp0yGFjoSk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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwdVnk41dkftrRKmzEUk1R3JEWRJNIrUVqUlt8kjAohVwiF7C2kLplI0Shl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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8Vf8fRrLKiiQVoqSS6Gs0PaRIKCupKClSCWVVZBRtQiFbQoi69mjY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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx5FRSSXZShmllG2YSoziYwkpkZKtSAgNgwaln2KiaaRCpCHZ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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk81PkbH5aStnVUdJAjOlA/lVRW3otcoYOpiIiMVc7IsZRjaStJl9q2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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkbPzP5pLEbMmTJklD2aUZSv/Kl7UMIUZFsUUeEaOyh0CYl+WQp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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8lWsXxqmTJFQi6pSxlAoNjgyHy0ylQgpRhohCKY4UChEimQrRoEEq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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk4ldkfl6GkBZWlKGZ+FIZRMeOS6YPIboiRaKxZUmPvZuxqpsVWkbok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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk8lekbxo1RCdPY2iyDoYVKxpSGcB1MyBKlorJNyFqdUMNIKiohSdbS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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lukbpWQpSraRllGpSQwlSvJzGhqprIWJ6ovQEMVnihpCJVmyZi9L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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VPsfx0VXuYlSlkjWUqKNK1u9EWGSKGkhlShaCEVJXVmKIkKFK1c3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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlWk8lWsXxlVS6SRDRFIypsEQRaJLRYhkqPOWpJJE5mifDBlCSYPK1iGb
ZGhQshUlc2gbMm3zPOzn3ip1ynBoEO/7vB/u3/3lHtZa139da52Tt+3p+QIC
Anfp9f89Quav9H02A6hbcc5/Wc8warm7BNIiy3Fx+JiXwQmCdR97r/XXlsP0
y57lRm4E8mJqW2OSqmAfE6KZGkmgNyWzaPpECzyO527QlyAQ3N7ZqLiVDdsE
BvOdH0Fek/3+BV0NeHREefVEKIWaCL+9nkr16Hjhb+oWQGEF46lnOrMaDWxt
EycpgtQHc0z51Hvw31kpP+dKsKXy8NgWvRKcmYhMeL2LoCxH92NoXyv0R/Na
d6vxUPBYoPB0GQeVm4tbn5jyYf3GSnfyLAdHnL2tMU5QL7Ij5EN0PzpjdZVS
DxL8UW+ubFxYjf+OLX+2tY2geHHSu0Oi5aj7pOJbkELHG979Ua+kA1kvfNUj
ynjIExM0jt3TDceTW3UqKimkOrfoLJYtwqsarXVfbQks5pP70uK1SOFppgZr
UGA3zliEvK4F72+tAsdBglfzORKQa8Yt9aDk7zkEv1WO73M3aMe9TfWPQr0J
fIx2HxL1bsH95VU5xUl8hDm15n/Ovo1/i+rmZun6P1srMF+B24mLD9+wpFeM
IGjNWqVZ5Q4UmkVdUmkbBg9hCr9se3Bje8ost4sH6yijDCfhMjBZK7V0WwlM
1qw7PstsxeWXrLo4JgUHN7N5x+TfYSTo3+plogSiJ9Ja6tWfI6U/btPNCAIr
4yU7957kYrXK0ygZPT7GzDqshHWqwLiZlCH6lYJx5ntF16xuSBXrLyhuJhCQ
PJuwSyQHQqp+ERN0fVkzG2v7xzoxUXUr6UElHx5Fnpb1UflYOK2x49QpAn+F
B0Z1hp0QUj4waF41DGE7R1ntbT1oHTWQ/HySglH9AbOa9UyYnRR+c/A0QZul
44pB0oxy5SVLtNz44CmP96d3tiGoKXzr3+t5ODLISgodrUK9xWTYtnQKXxyl
iq7FcDGikf9dW4UP16XfORr2DXA5U/hp1JlCbMzy2xb6nXDyuW64LJkHD72U
UTlBWv8JB2efaIKBoEcKXoNdaNfaKdGdwoMPq8l9jXEeCjn5Awl0fn3dyYVD
ORz43DiTKD2f1rcxsbp+dy/ckiSV9q4ehnWJ39Sm6nyYTmGome4Xo3l8l5eS
nXhycHe+jiUPFUYsE//wbrCvzAbqb+QjUnVk2G1lNVTVby3UleDDKNLxVUhm
ERjiJnNPrxP0cAo9mDvp+tg5m166y8dixwyBHuEaMJT2aXL8aX7XitR9qMyH
rO6ttFNnCPgbA/kNzQNwmJtqV2vvhYGGqPnGrb3IGPpVnGjOR3nyS9kVLSFI
2bz588xxOr74/YoaDRWoHR+X8jKl8Nhhj/akfD6ERp7ejHQhKJ9oPPHEtg89
Q6YFTod4YC9QDLhX2g7jdJkVKWUEmyJ7F5UXdOLjS7V2IQ4fKo/yv3Zb9GD6
wOTdplwKF/46sHLatR6dApzAldcphFnmrv3jKgcmd9u84hbS/OjJzO04W4iM
sjFZVy8CEXzxsTvCRZKUz9IH+yl05/UpWfPa8S1v4KrGfArBqgU11NFKJE8P
3lm+gKDyjnrQVdluGI5khV9jU0iQeuA+114HQY3/uF4XIdjmNtd0VbULQ5vV
p5xp/a0GtN98z3wKsxu5SqeOEvDkzOMUz7agPPTnjw2jPATrhCub9bYg3yFw
lXgRgXrjuh0dGe3IKIg104nmo8PVe0NFaTOKJyqvBm8h0O2TKfXzaEajVeH2
yXGav+J99y5croGfk0vbFk+CxaZvB8TVKuD18FticBad77vFc9FPE2A/r0Zl
hvY3QX6VuIhSNTis4hTfbAqWz10049ldMP/O2i9H+4WmrEvEIYs6WIiVf/0t
QkHUX59v35ILK2f3vorLBBdWKx84x+rC5WPZfhHqfNzUi+B/MmzCGuH3TSU/
6f7eN+A1U1CGgE1tpmZ2BDpB1cKvY9rw3Prn0gozPtar/6FZfbgEq+5qM2ZM
CHbdfuNdKlGPyxmfmerSBDVq8foZ6flI6Lo0fYX2qz/lzn0wOtUFgyj2Yz0f
Wu84G25t8Hv4HvzroutqPhi5WxR05NqgOZnuHnSYB2fVN9petVzcXlqiXTvJ
g2bL8Kp/QjIh0JfpoEX3k/ys+u/7aq9xodvlXbYFwb2FRl88t3fCFWtm7KZ4
eGZTPnLyfh4M9uh/+6VCwHDhGAkZtaE3LVbvuxIFgVxFj2qJhxhXvajvTPM6
lGvieWbHMxhvHuPFHCZwK1Hhbp/ppP3nor2ZyDBSWT++DZ1nQkidHLztQOAq
xzCp8syFXdisrZMzrY/2UbWxDdlwjb/BXu9D+/NOK8saRjpYYxvEVA4RFIhN
sQw9mjBsU3SATfNTeoXh8J7NRVuUq9i6KAqCSnJ73/pUYsTt6v3jNvT9hNLx
bO5zMKLVdi/zJfCSym70Mu9GwKf3lVIyPLjUFMQ++dUKIcmL0lp59DwVMmFm
HctFR8a+jOQbtL6vF0h96GrCZI1munYRhaxG3wsTzV0QKM+UNV7Gh310okDI
nRakrEn+dY4+n7yN6XrvfBd2EYvUfEmav5Bcu1inZliZGHar5lB4IESZWFMd
aI+aPq/2bRiP478cDP6RD+fGqOQxul56284Jdek0I7XKXogVQM/TpvNhww3v
EEiFHx6geZR3dmf+akjCT9kL5qG0P7NHHm58m5kIEu7bevMIPb9TBl7Y2zFR
miW5k02/x9EZfPhEugMepYmq6S95+D30L8fK8i0Ka2VOr7pL8KMu7cXXRR0w
s+sVHusmaE6yLLGJfwbF22RRjRaBnUlgf2FTIySm/uSG0Twk9FtHKQxUY3O0
Y8oJBv1fmbnBP21NCLgmZriYRUHvsstub10ujvp9mrfsGEFmypZfNktpnkwD
Dbe78KA0rhAc5V6P3FRGiGAcgcEQ9+PnM+141TIrbn6aj2xbnStxD98iNKc6
LPAjheiAP6dHFCqRdiJzoVUwQeRv5pLhje9hz47hSenyYVJ5yDA7vgNsb8FR
zw08yHsPvpJOi8fX0OPil2i+/gfw+bIu
       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81O0axlWUpZAk4Y3ozRJ6kxZLrpK1RRhrIaRI0liSSiVyqCjJSB2J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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkb10R2UcOoiNTM+ChLCo3qhzYzpFTSyBRCilGIIpcOZYuyJMkS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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VG8bnpAUSSL0QyVJkTbtcouUFpIkIVkKSaEoJCRbGyoJRZKy75Ls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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVmk81WkYvVkiYSyVFkkqIZRGZUqOGQ130IyQJRHGHoaGMlFIFDKFkkyy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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk4lekbtpU0MpYaWxsaMRHZj8pdQiqjg2xnJkJFStYOadVmSZSJyJST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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs4ldkXx91HSkm5TQhFNUmFSsJXZSQZuaT7oOMkSiKSTEWjIt04IbdB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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lf0fxlVGg5JNVoUkJMmIXGRLWiIVpUQ86pGGIqWyKmQ0pEFkz+y9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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lOsbxh1K2uRkyhJlz0mp5FQcXJVCGyWRaLF1RIpSlpOSyDaWkC1l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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk8lfkXNiFp0k+MSGpIIyF7SYznWgqFIiSKW5YxUcpIKDFMjF0qjH3C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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8llkfxlFhGKQREhIlTU9aJEujS5SlkbGMFpKlNEymlEi9tpFRGUS2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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3cglP8fN0oaorKpkPYwUkbqJdGQQsqXokRDkoQKmdkNK0mKbIrsmZHt
Qpx1uBB3z90hFRmVqN/z++v+uHuez73fn9eUtbp56jIPFxfXeW4urv9/+vRQ
VQM/d2KPvLMzzzcmhC+uKnEb7cLhx2Wb9zpz4DLZGtAaWwKGgMLMJV8CuarZ
LQ/4+zC3UTe19QMLkcenNpZUfcTN/IsnZGYYkBcQkwtnd0JWYtf3m3uZeHTj
nLDI/g7Ur3pQ1FNDgP+S1fM0rXJEh5TzbKIS6M8cf1XSXQenpqdurl+ZMI2y
upz+rxwTbmvqCAECssZ79qTsoWLFI4k/085MqFVEtGiqlEDHg+CMP2Ei6KvW
d7HTHyDVMZleWs6CltCmVzzSNOhvDuDNlfuCTF+hyI597ZjeHnC4OoOBuCvl
EcXv+yGn/HbCf9kYmu07qtYXtEPCijnxLWgYWkcu6x28EoPPEpM19iYE1M4m
bQx4WQb9pgullAgCYQer/V465EDv2b89WxUI9CpfqnTXz8J081brvOMEhtpl
VCwzMhGkY621cICApqFcdOPeWuz2HexP8GXgimLNiOLEJ6TEDpw0m2fh1zFj
hoVTNHTWLmmgnCXwK3drpU9ZLQj/zLUXVzOgEiClKjpYgSJP7vK9FeT+xm5l
pd0pQIWQWiQzhzzPejbDhp6Ofct++/c9JGC64tBBkS/1UJPfmf7Wm4kiFk/f
5sXVGLD/cImPxcT4Yr8TRSLliDttH6JBI9/3j25x1Tcf4zuFhKtXEZjgl7l0
xzET9QKR+aWiBLr4JuLY1+hYvcj65d5vg3CQPc0KTGxESuuzdKowASPV7/85
CLSDE+aoZpPNhJ5KVr5zWAccdwcttGawECEe5HvqChXmMc8lNERZuBi7pOxC
DQ2zA+ovvxBsXLKpn0gi9+N58JrYY00CXFwVdwKCQ1HeuqT8rzGBjHkDOy0B
OngmZRx7yed5VD9arAxsR9GPXWtKHrGgRx+bij9ERceR9zEFiQS8XTmVz/61
QYOTJet/iA1xX0fH3r/NUDXKEB7UZ0Ka9/6Y9HEaRqh7Bv6s+gz3o8sFB12q
Me53hm54mgm7CxmhzxS68Fs8R0mqloHUNpEXWdY9aLahPHrIy0T6n6jr9/wr
kMZqnNK9QcDXfJvWd+decJsKeJwpp6MrqSCX71gt1jksjg8ZYIJiKif9gJ+K
i49f/3eogQnvgG3uPS2vUHUzQ2rMmryvWweWGTwsQkhssvfdDyQfSiee8uws
RZ1B+KzuOhL/vuNClTntSNl2+E+v9SicDN+vdzrcict6w/NbHxGopSu8o/F1
w8yxkm2vzIDp0JXPZ5fUw7mFbts9TqDoH0u5UbQb+/fs63fq5UCtObTbPSEb
/vxTOiUXCJjsVzWyMa/BiZlY/aoJJgIqw6qXfach+fSN0nMBnyF2Z8fIP/F+
jC+KyZEKHESJQqTTvVWF8Ms+U9H7ioD4XSe7g5/zcVY/y1Mpk4Cle0WsyHAT
orYYhclbEaCG3lnLLVSItZvqPK4vYSFscxCHKlSMH2Xu3xMjCbTk7feKojZB
7lZMHH10GCrVmza/SMuFZ9bSmIPkfraGXeg5IkHHLQvR7E3TLCw23+cucPcD
ZiY3VZ4OIyDEvvPTMasSzk3HUvfWsOBZMCVNvd0Ffmeej05tTAheK59fzzMA
891jgpqkXo2Xp7lu0vsI7spNppNGTMSfCi7t/9sKRdZZQe56FijLOVPhAvXQ
Mr6sc3maxNM9mV2Tvsk4qZPS6nSGgH5aiK/WcBsqJxsrRnI5KJ5TttV50Aaj
7sLwOXUmqrRP890QKQXl6f4wdUEC5rsYQV2b6pGYbzpr+JIBl1nPLBX5PIjn
qlQL6xFQ6eY9n3eEDlaZSdkhGyYihs5JPfubjjuW+rwp5PzUny+kLCKSEfHj
+hEbRwJ2+S/vead14B5PVNk0nQXt4MtqmS40iCRJI8mVPN/fKGSWtxaSK1RT
Lwwzcb60ad23oHZS3/XVeday4L3YpKa4IhjzfSLJsecIBFn9cmLRcqB5ZO2B
XnI+0537A564NsLS3+LuU5LPWgI+PMMfGiEUfl7Ej5uFo4PWul8WJ0D0wljJ
MlcCdwosGqicNkxMSpXIZDNg+U/1rYTCG2hG3ihZfYyA6/Jgxx1KDcjzabjk
LMRE1IoOqaX6qfhzTrX9pB05f3zhMh3nWuTYn6m6vpZAvPv8iwshXRipbXTq
2kbq+Yl/Z0a16qGSqX/1USYDBfkBQ6HXKYiTvun5dYHAlv4hXnW/PvxNXbL8
r/EoxvlYUzUhNJiybmgJ8RI46XLgulpIDcqvHk+QtmfBMHqyz1I8C/wKb89x
keffrko6auaSgw9NXXcX6RLY5JopOCjcgYkV9sunGgmkSpir/KvshAH/+ju0
ZtIP9SV2VHEKYFtPHM4m/bApSsP/ypcaGPga05XDWQha3fG69nYxaKmKUnss
yH1OLn30PrUepReyB0uVSPwE7Uwr+NGMH0PqZoGl5Dwuu9V3oRr1Mvku8zIE
su59XPN1SwO8bfW1A5LJ+3oZUBH2LQMx75fYG+0hzzOwDbpA64Qk/eRRw7sE
LEwDRuyW98H9bs3PqVvdoDU5Bh4s6ccZ3XWl6X8I7Lrpyq9U34ndx785VDux
QdeQDmUr0aCa+6Zmy0MOhIK8trOMKJBelzK3Uo8Nik++v6/JB4ypFhiYxTCg
K7H62u919SjI3uC7NpVAdJgJb/APCmzknLUfdbLhf7cw34VOQwHyottI/zes
C/qQ6ZSLGgFPt5Ru0j+HTH6eVeiB2e0N+97NMWDjECx/378HXvk6gq3GA+gX
smS6LepGzkav6sdSTMTJFkgySD/QuPyNeXiUBdN9HfhS/B5KUfuOHrtHINs2
ZGuNZh9svheLJ/oMY+hsnYLpWDHUDu3dmbiewInShSDjAzQcnjrHE23BRsuL
lzOZ0VRs3ef6RjCeAY2Y0s6F+ma4fVF+oGnCAP9rUVN3A/I+qJpc7iQfVH5u
VM8bqoa0l+RmwRckXpYXlM0Z9EBqvO+jYgEH4qJd5yVXtuLBarEpgRAWXMZC
Z0a6qrC9r2W0ikJAY+kMh/amC07upUujbBlQnTUxMZF7h9spjEWPHpN4YPhH
qDg0o9J7nnJEjuTrLVGvEzfpuMreJ9H+bQRc8a3GxrpJ0E00V6NaEpiLKkop
zqzC1/Sg5Zb8LKzwN7l7Z2MLdptJvLpZzMQ5DoexW6EVQX4ntTgZbEQfHaLN
SFZDQOlpfqw0G6mfHidzDX5CzuepW8U2BL6fSEmWau7GePCRKtMHA9imeC7x
4c1+JNg3Gvu7M+A8E9c4pdwB+yQFn4YBBvSP7yxfEd0FuqFD/EFuJjz0PYfz
2ntB2a/lpULmlxlPHY1RZhtOP6w2m9zJAZdOTqzyojN4Sw3TEiH9JUxZ/YlE
QwqI2IMLNqYEFuQfDjIP9sDXsHHjYXsC3UbyIsl/+qHEkzQo6jWEea2WWJmW
bmx6kSi/qIiFdJ1gr+O8VYj9Jl7gpUzqsWzWb33fWjTN6fnbSTJhzqpRDuHt
RcF1kS+tBzioV0z78TieihCdkSuLn7MhHH37t9jZbux5Izetd4WFOus0276J
HojJbv174xAH0eK1wnEu7WT+SbCIIfmkYvPCoY05gFci027pYqO4lF3Amn5A
h4PKc3FlMp+4FP+nUyBcDXuWUPP3FgIUyb4WvddlkFutXrjsExP+UQ8CBLRb
kSzDnBvfwIHDiYC8wolK+P3JWu+1nIXM4cUzItaNcMyzOtQjTfK7Kf2Ix2cH
nDulELKH3BcjxkU3XqIPco90zm15zEL0SbWKvaM0zH8XvzhG+uf8LflLgWkU
fOtWkhGWYSLHI6fJmdYOXnqoWH4JE2Fltfa7a8n8u3ujmrT8EGQKj/0SNuqG
6HHXUUv7QVBiXg24rWvG3O307NJVLLwrNXvVQ/JQRHO3xZfWUTgIyHPDJwVN
zdSXE2T+vcn7gnN1LQ3rHr2LnfNhY6Won/g++w5kc3q89O3ZcGop8zcKpOHI
cIwfQebd+DdFlRyeWOTd2JjTT+a3caM3dw0ayjG4fl2OpBcTMrF6J+3f05C7
vn/pyzoyDx3w6Apa9QxWsYc/C9iS+iLD8eVPM0d8mzi3PbmPSK5j8f5nqvDs
5xIeqywWqrjWt3zTccOg7NVLPqS+Br172+L1owoJ+bFHTgizQOXu3KDhHg+3
8LwhP9J/xp+dH686W4sdvvcrFikSeBfDI2id1YH3jQ7smahhKLe4LcvfQEFD
zYoVvKIMGIyIi+4g85aHm/uXgzokP10U5F8VJeLp2vtL74M87xm9m3O/GhSp
0S0zpF5Q79t8U5ZpQLL/zw71cAbuG+krHBWqx6lMoXAlFdIfO7M9/aLaQbV7
p1Gzmby/oaJkdmwrVP57K0w/wEZ8s+AB/12x0Ll2ib5dm8zj7Mms0qk2lC18
LVUVYMGKozSUd7UL6p+0Ho/kc2Ba9GmreEkO5v4eqifkST6omdrVLM+GXePY
QnA0gQJ7ysU4rzK0PhDPSEwhYDDwJlcyIh7CccbPWrwIGL9699jxdC+8lB60
pkUNwXCX3R7dkkLMimndbCT15n6spv+ujd04uzvl+XlNNsJS4xQjd+WjxUxE
2LyK7Ad7uRZV5KSjUlvfzMyF9LOrp1e82/ABat8Gtm94QaCNb2or+28HBL/o
PDU5PoKwyWsl7XwUuJtVH/S5y8JCr6tAiw8NmcfeVjO0RmH5ZsZ2jU87snXs
rXQLR5Ej9JOjsToCyx6s099N5kf+ksfG9xYVwjv++BMOiQ8viR/cS7i6kLir
n+vUuWHI5OttmFWOBv91v3tdtwhICmg0d1fQIed2j65bwQTXrjWyRbM5CBLU
SLi/lcBYoMIE95NebGy9J2U3PQyuL1cuNG+wgg63u94ZEm9C7jqfHZrq4N4U
fu7kRTaorVU1i4IjEOGdvseM3A+Xu5XGvroyDB2lLRUMJv3Y9Ym3xykaWBYh
Wm0TpP/r7+wK9irHbELIWGgBgfO2CfI9gXSMv+kYDwgYQ4mdgMy2hI84Me6/
MUWRhfYxn/1u3G3QVna99nvPMOIDtrjE9XegbuwOy+odgbOGh7cfbW3HjBDv
hKcKG/2q+12EHnYgKT9Wg246DL6Zrzacg6T+SVOzxcwJ3FujhvVtdaAP6Mxs
zyT1ReXCe3ppOX4J02/+cCOgMx2joKNFQ3vwm/EAMm+VKK3w1pHKx9zb/Z7a
JH8ZnFd90mMDoC/rdxc8NYQR2eezdwV6sNcz8q3e0BBo1jbzOTX1OL2GHrdA
4tl929Gg5XxFeE3bubucxNt8d45z19Qgzpuvi67VHkOv78Mc84Z+RL2ftZgf
I/lw3mvlHKMNxXeelcmR/ZHStlyQ/04HlnfqZoSTfSnddGpesa4IRxMPmT/3
I8B2vOQlztON5hONrnPzA1DbfNSzrK0Mo9VxGtv+36+iX0cOqaRBcTvZs8n5
4gsCvRc25mF8dvbQisMEcm4VWmZ4FkLkR6AJk8x30nLBp3ZXlGMTX0JnKpn/
Js5fkX6zrgwxv8a/HnUg+9LnuscXrQbxUe1ay2OdL5h3bGpmB/fhV6toYUhE
L3iEksoWDfXBI1glQyl8GHc5jXWePykQjgrvvkrm67h7fB/uvehCfKytPYPk
d9gRuds8L5KgLaAscuwaiRcpA4dN+V1Yt2vtVz+yX/jFCc1u0U5CsTVHaQ2p
JzqB6Ym/bjdCWJtT8yGYxO/TJWoPHZqw/8XMkaHPBD4eHZds0uiDd0xgHWcJ
G5aSfGnPauuxT1CO2VBMQEtZ2oXDCoXdfqUn10n+bCw1enFF4xOmt3nv+M+3
E9FKL6PX7izGZMWxUxJ8BDxur5r/aJeKlUUe0yFkPvW+asIsNY2A4vDgNibZ
Bw56zv9tLOiAok1n1iGST/N89ZH9FvWgKolu2a1A9g+P56vTNvTh5W3tUGc+
kk/vxF6a/XGB/Ab2hCvJJ71uw/Qum2acuch39fYyBnLGxtambPmAbb5vdjyV
YOHQ9bja5I1UUNPTSpZfYIHGPOLo/6cdGZZ/ri+lsGFYYfjx4opC2Bbk2D8j
+4fa/NnQ/xZVwPa01ndZ8j75nZUY33QLwaWhvq6dzOPiY50fcy42wM4/xSCJ
7IebLms9NPtTjTv1poTrTfL+7Tu5bLpyUbJS7Lkl2b9yWiPVn29tQLD24O9X
sQxoTbSY3xpzhZgFcdnyPAHb90fX3wjtIXXmV7r4aRbiHS15mv+LQtNpPvHJ
ywQUz01GLUh+Rlbq9Xi5eTrEm6VVHkrSULTrte8axSH8bdJe8PWm4kqmmkce
LwMTDb4FHtYpyFqf2CByhdx3xZnOhIhS3J/okHxlRurLKxfPZtd3yFo67XNP
jkDeZS6LhLhuJI88mh6qGMLQhI6y66wRNC8K50v8X6+Eqo6pV1QgfkZY9+wp
JkQb1HZMb8+G45lQHkny/VUFRVFrPXwQN/+4eik5z44l236qyL6Hfm1q4yAP
C/YtC4blLV1QHDev1l9B/p9xM0p8hhPCBymWa8nfX6nqjpTd0Yub9ITzx26P
IdmRssLXuBtOxrIOZSReHeK+j4n7UvDDNoCqEsKE51uhwIiUTvg4bmr4vJnM
+4svVi9MFiN+5D636XUCmlqzgkPPm9A3UEjJPkzma0/l5mDzx4iJiv9ue4mA
m2Jd/mKtTuQ8/FSx14D83oiX7VrXjlpV/dB5HwaWVZ/JPRRQi8OcA1dlS8h8
mdZgPf29ADzoY2/WIvX3RCQl9GMlxPBtZC6JiQRWkVO4TTeMsvRuRpF6MmEt
a/cu/wkqlNUfXDlL4Pl5O6b57Q5cjRXL1Safd8oVPcmyroZJT67TbQMCyeuS
q5VfNsGZkjkkspTsw6tnNBsswxG3823o2VMEWvwviSY1d8DW+7fmaRsWep9+
KZ/qriJz3VvIfyBwN1tOrJCnC5LJ1qElpgzY+wR/PNXZgWGx+v6L3UykpW+f
VhCtJHN6lBD1CNnv/+w9ELm6D7LLGhMk+Ei9fRS4YSWrFxWU3/vja0bQlftT
Qt6wGqfOmyjZjhNQUN33iJLYhkaTh1Zx+hyMcI19fxFUhbbIO8/0D7HwPyIM
As4=
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41Wkfxo+l0IKRFDNZqlOKtMzIkrpVyNaJGea1ZVeWFkOzpDkSMoqM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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4ltkblopQCBNJZcuIlGWyxdxiLIUi+/YpRSoVrRSRJZSUpY/Gmoxq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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk81dkbxw2lKSUtlmjQlML0a1BRUh8hpcaShAxZSiFCZVpJwtyQFktK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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VH0bxoUULVRCllBEhUgkpUvSQjxR1hZJCNEibaIHeSRpkSxJRAgJ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81VkbV/ZlprwmY8kSwkiolKX4kq2EiWhEkZB9aUGlQqWNhJGylKVL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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk01WsXRq57kluIuKVDkSu6ppApjylKkojMV33cVMZUhlREoZRoVp+I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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lWkfxk2nUNOUnRlLRpsOWWcSxVVGBkVNb6PJRLaUsmdNSEJ0krIU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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VP/bRoqkQkgqS5ulSCUp6rYlImQpvkmSItkSpVAqSiVZS5Lop82W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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs01Okfx61kpxCLXKJyi5KEttqK3rYo0ZYiIZVULpVGyqZJqeRWloiS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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk4lWkbPxktZJQYMfaomZEpElNSPwrJviVSwsnoKz5apJAlWSqjkrEU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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVn04lNkbVpSSpJQka8dXIrFKrdpy02/7oFYRv0pKiIRFlKKUlgqRj4Sl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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lO8XxiflW9EiJbTYIlGpJEV0C5W1QkVlF0kpSZtdIUpCm2wpCZF9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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs4lOkbx8ckKUQpwtJINQqFVML6OqRVpBObnLIqtqKVopYQteWQwiiV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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4lVsbxknpkMiYHIpIKkV8hoTbQUSKMuSQ0CFJRUSmBslwRNKATmgw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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekbNtGk0DpSUkapVGihaaFulK1SlmPX0MmeZKpBSAgnKiKhkhRJ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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VH0bxvGUqEiUhGyVKFG0KOoiW4u0PEIUKm0Usj2UUGk1IipLQiVa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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41dkfxy2FhhmSbSIMKiNJpaYMve1kkIQWS0Q/iklDUlPJXohsEWNC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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4lekbx20xk6WNCMXRlLVJljDUt5oII7QhIlmTFkRJRMjMRKESMjmU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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4ltkblmw1mkxmDKNsYxpbKpSt3BRDxC+hqQl9pDIiTDLJ/jUqoZQl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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k0VW0bxjXLW2QIrzmEpEiSIpfKUEppQqgkDWYyVeZC6kWRZEgpswoh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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx6VCQ6NQU5JEdJNUpiyl+RBZsoSyDFHRYr1SdmXfkmgllBoq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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs8lOkbxuVMIp1YpWQr61ArlA7ay6kDYamUbHJIG21t6bQOySEkh0JO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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8lVkYx2+ytCGRSGOmrqJGiKlE9RNtM9MgpHCbabGnLKOSrTSJlCkl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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHk4VG0bHyr1pkWFJK1UikSIIj9JkhAtSPYthSShelUSsiUhqYQW+541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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk41dkfxy3l1i9ijFCpwWAshSwNJt7NUIlGjcrSoiQyxpIZS0oGWcqU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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk0ldsfxpGkQSGipEgkVzcpU9MjSkgyZM48pEEdGkkZGohSVJyULoVf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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4ldkfvyMyFU1UUlFIWZvQKCl9bEm0GFGSLSOEqNGUO5aoX5YyBiGV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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2kgVG0bRokKSURSyNLyKnshddmSpFfKa22RCG1EsqRNoUWWLBVCoaSy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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41dkfx42iZhQKkxBTSSUZaZmK8VYSERVJ5CYUKrJVpPTYI8SMtVAY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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs41Nkfx4l2hWS1S+XRShaVkFVJ5a3Idcjaco0QueYS/WiFYiMxwkpC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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns8VPkbx4WVJZd0G5dalZRLG9GmyEdsG0KtVJRQqaZy10VJLrkUipKS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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3dcjf8bxpNEStKkNJSMtMyoL5cShZAiaVMotKiEJhmpNFApNIQSDSpp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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk41dkfxy8TUSrpR5RQGq5InqKk8iaRrLOUZSyJspStGN1Kkl9ZMslM
xMxQ3GRJhuxDtqxZ7725yc79njuotCkky3znj/Oc5zzPWT6fz3m93+dsdg/4
4ZQog8G4Q7f/+uHS5R3tWnXQHU3KmVQkGCmI8fUQ1MNK9P6uqnMUZoUhlg7j
fChM+dvM/U3gaydbOeVWj/vh67601VLojhO5WBzBBffX80bTlhTi/aQ4cu6D
eNs4J5siSnA3XyPkWtTf2HAjZetfhgTOdmsEG2qLoM1YlFZTJ6gdL/RT+ud3
jLi1HMu0J0gd37cycEsn+mIDiw8rERxabEy6dnMY76Kz9Rwlx5Ayf7U3r7Ed
J0zL9Se2CCE9rDIZRFoxEBbmyXtL4DDS8FlO8SkKa/+3It+UYLxVOmhlLhu5
K50ZVccJ0jrMjrGpJGSo6vLn7Ojzv1JslcBSPCk5b1tlTrCZZ5a95xkH906y
GeHuFKJDFESsu/sRr1uSq5w+AkWZrV5av3OxXMP9+fouAQLDXP3FkpvBy96y
br8KQXcMKflzLRfhXiXlAgWCO6/VcnsGWnFww6fmQi8CFqvI1rq4HyKUjnFZ
7D9gfJXWHnSqB+PRWbUnOwg2FGtEnfvIRZHaq7QLa4Uoeh+n/vojD4YtMqa+
BylYbks0uGY3iOrshsfx6gKEv/+ZmRmQjq+ln007bAlOVi8ZKk+VIySD121B
5xeUs6vzVMlDpDj4HWHrExS83m5t8ks7dlb1Koq0ETCmlDcd3caG9BqHCAk6
vvgbFpl/327FbK21b3oOhfEpMbHPpjnQ2Wp0tdSX4MXz1BLjP6vhElEYsFeC
rifhmVmEtcFINXx1TQxBeBKDbWfcBfPL0219W/+rfxzrwa0mbNeP6vFyJNAy
pzS6Xj1GxUhQkocBwXztpvnTOR2wVx1yEbtFgTn4zQkjjTbctmI3D1IENn53
Lsn0vcRcQboyGGMoMArTPjFZjRV9Bs4H/QgaZjdl5r9rwNifB7Y976bz4z9I
XGtagwqJ1wc1tWie6wOom9rFcFhYybRnEmjLdo8lsvpRHG4V6PrxHxheUVf3
eVoPQ1mZ6xLzFMr5uaVPJDvh52BbpkIoJA98ef7sdh20+3a0NuVT+PZom6iT
Tj8W1BV365tSsHHWEVN3e4qQpdFV4mq0PvpcZvrn+1Bv6zO/8geCdspves/y
DrTlZbekqQqR3XcyckVbD5iLR6Jzrgsh33TJ11PYgvPiSkYzQ3T9imV9ElNi
wPKSVYh2oXmoCtlbpD8MB5e0BbaAHnveTCuf58HI8eh23qQAI22xPmWHMtDQ
IDXa9yOB/MEF+4GsLqhyGetPywjxvj/SxOxzIa6reyjG0fqLvqAgL7KlG7Gh
Ftp7vYXwdtXb+fl+Ntp1OL9qmhGEEmmdK5YVSHO4GHFjC82H8spvpi80IqEo
NvW9P4HmGwlDg4AByHBqwiN3D2PklHWT01geAh2vjfXQ95GGd0xTkwEc598J
kMmj78fh193xjXx0SZVNSw0LYSSabWm4n4vI9Qdq3E/QvDVYu2/nlcLBYMUK
Ls3Hy5z6h8KEZlQc5V3R0ibwkPSQFb7lQa4h9pxJGgV5lvzcvbg22IV0rkp4
SCFUr/djzqsmyNgXubX/QeAtVsIWDR3ArPdLqUvBFNykSiU/TA7i0fqzcy9s
KKj0V58LimtH8TqJn4ppv5E/0trhLF6K8uDP2T2WBHVz60zV4/thxnywZuie
AKvZebNjNY3Y35y/KaeEQsTjjsFZDQ56VPR++S6foOanmY027Bf4tGFJ5O4x
CiNdDIed7CQct07P9XSm9Z5XG8jJ4uHNYbunua0CsF6lCFjxDZjJL1uU66Pz
cZ+4PvCuAuzOkKKYJTo+85TS13aJGPeWnXCk1y9r4MvE7XoG8YIXFQ50/f1V
U3ZphLYjfs/B//clUzD666IOLl9H1/T01C2al+/uGQePcR7ApNK39QcWgeuD
ZauCD3NgUDPZe2kVQWSdluaicTdysu4ML54WwvmL3U7eEBf+KWe+Gd1Nz7+a
8shbMhe3lrqjtlsQXMvgey/TbMFahcoPkWEETEJFPexth7jk/Sm7c7Q/p7LC
l5a3QiBZZX3oA4V3W1n2E9taMcH9w0rUhQLH+Mfy7188w4L8gIJ6NwVpqWPK
U2UV2M2NYVTS/p8wWOPlVN2M4KpDp5ceEWTxb3eYeA5BTO0466i/AAVyE5ca
fn+GQseQzVnxBA+YIvv22RQghORaRNN+1L2sV3dKqxPGqYn+ud4Upjr2GQ3v
fIbbS2Hi/hUUfpo7+RR+/dAiaU+kJUcxxUxMFhtqgtmRuQYnaYLyifoYcUEJ
3GJmqvmuBNwYlvLGqSb492atzfKg95/Ltn++uRuXz3ZufE/H276gbnXGpBEG
by7LVUUQWDnGTSx7xUGTtNHYqR4K3x0WjCus5kHfXeL7AFcKjM54+SjHDtpH
uO/daX/ecYUdkOHRiw9zjZWrP42AmV5QZLKHD7HeuHY9c1ofYevCgnsiwPYo
PaLjRhAxO0oF2dZhwSr2jW4yzevmMzvuSfVhb0HN2L4wIXboZqYPb+TjZ1WJ
ZdJlBIWeTLsVPjxoj559+1WaAlezaS7SvQ6yTmdO+m0kML/V+DF6uAUVyebd
akUEYZr7M5tnODAtDJ3pmabws0qmYgyHDzmV5FxWGYXaPN3BLy6DqEx9ufYX
RQq+8wXLH5V1YL0ed+jaMAXn1ONBFZY9SEvqel6xT4iMBKVJ8UAOHrUV9Ow5
TfPfU5+gx+HhsWvA1xA+wW9/nZWPuNCHYLEDpkq1Avi81Qy13PQSNRL2PjLU
KFw1LTx5STW42KbU5RZKYG3JsL0SPYShXSrNBWsGcOix5bpxyR7UFmYwOBoU
bkh/jBiJGMTdtJuFn8uHkHJXotZoWwtUPU1WMxto3pJkJaM/VaL8vnvoAO3P
IzbJfTcis6EpO/s2/RStF1W5KaZkGw6scdDh0rwsztf91qrfCO0DjYZXFygY
KiVo1J58idVizj8W3KLf228dd5Sfz4PTbKXX6yj6v5GfuHtyvBjHlIdV/d3p
9+228/eUXBMS5EPG5unz/gUCFb/e
       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4lWkYxiVJltJmJIMkRZSMhHTuaJkIISJqsrWolLJkmbJUx05ka+Kk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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lVkcxnUpyh6qUZZKpVGDkjHUPPZUym5sI0SkUGqaGlkqEZEURqIs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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VO8fxSUKydoiIdS3hGxJSM4klSRESkRKRKmEpEiRbBFKJSSVohKy
REmG7OsY+87MnYVKiJKK3/39Na/7mvu697nP5zznvI/CifNWLrw8PDyOC3h4
/v8rXP330p2UdkRICqm2jLBQeJaZeE2gEtS8hRHv0xmIfeZ0pb7lHVY6B/06
dISAA/3uvwCBLkyl507ZPBnC9SLNhulLD2FRfPeDnAcBJZ3Co2/VKqEfUWKr
rkZAfkaWL+l7N05cVChUdhjBeLeoVwJPA3hMLa2qLhJYpmuxYqtKN/yjP1br
rx0BpXBAdlNZJIbKckTznAi0dbgvP7ymBreKfwxU/2Eg9VZBncjbEsTVLouA
IAv1B7OkX2o3YFXQEr4ahWHwXYo4I5Lbgsye4il3OhszW/+MZ/u2QnU4/GFR
ChNzNr9LaVs7kOy67IWFH7memnzDxRqZuOPtcOuNIwHqQ9FvkVLhWNdsmGJJ
vv9jlY2u08ZuvDFw1ojOG0F91hdFZ0sadN1l3WbXMpAkUcv3vYiGoSezVvee
MeDaUkE5pUJDsGqQ0uZwFp4WGeg2plSi48HZmUV7CGi9bgkQT6nHYWs3U8FH
TAQ+CVPaRuuGaWZWpdgsG6kZH3IPayZifIl6euYBAvkV/Yo5kv1Qd12tGho4
DMdMZW7jfDvE7JkhVxTYmLoSw5+xtR9iwye3f6D2IFysaE4oj46riUcidw4N
wzXpuITndDuMqYY61g0jCE8vLFFXqYF+y01luYVsCHfsKFRaSsOYhoGirhgD
h88mtPq5t8KSLhEfaseA8JB/hsW3RhhbPNu4VJIJHk9GfJuIMiq2txioHyPg
UVCTdvdsLuSO3TWYBIHzN5Oljvb0oixTgldugINRq9xk6vtOxDs6lkdKMxCQ
mOI3NFwO3mMbYvnHCBRuNx8152kDZvY84BsZggBTwXsioglzSRYajRcIUDbv
fCJRcBjlWjO35sn5hOeNzZzuoYE3j/hvcRULzvcyZ386NqGm5bJ+3jYm6lzS
fgvubkNkybx4sRwXXA97LanQGqRc+2rkuZEN6iFxXoZoNdy3yT3u02Qhabff
peMB3XCyZ3/qlOWC/t3t5Lc19XjkfkzxF6kfpx2sop/sZBhZZ8WZnCTn0RxZ
bsjsAEFofpZoH0LAAkvJKJ0y8O+gv3paSuCkntGigPk61N1UOXw2g4CAUNLC
KpF6eBpJKKhyCKTqSu727UwEz7aabfwnCIyd59GIfZODIuHNTyoMCThNLUpe
sLMYXyk3/s0IEug4OTWpLEzDmhWX4r66EBidPPSSmkyDhEFSzxsDLlz33P9d
ndGNhoiBEa4uB9K2gW0d22rwWpzhv+csE0JLhfN52iqQ+Ex74XwdE/+cZxnJ
bCr85iXOR8YzMOPSW+L5tBBy3CWKUksJdC39SfmuWoMVlNqdgylsXO/y8noc
UwR5ysOqOW3yPDNsgpqL/SH26r1zDTkPN92QhyYXi2BalST1jMOETpKf56JF
NOxbLSh7XI4Bk0ec+YUGA5jc6Zh29REBWkP5eL4NeX2xQPs9gw1ebdlGacsB
uI4U31oXNYIuGZ8b147SsJ76LtTOmwG3QRmbuc4SuG2u9JRUIf3gULD9Y81a
qOhJPH3UzMDje+rfRHPrQb09uObSKANprezCnyn5eG2wtXfHQQIWpjPf/wl1
484O1fTNJixwl36jFBm14mxvcrjyRhYsZz80U0RSMW443JVxmtRbEbHyEvER
jOCZ2rfnSb19lRedT6+HQG2F8t1VbFh221q54AWyJIZdGUEEeHb95jl6sQBS
dctDRIJJ/estuyGnT4f2QSH7hjQm2hQve5hxy/BBLvzSX3MmpGabZLC8Du/3
NK/+p8JB3rm35wJW1mFptGRnWxQLyc7v6gPWvEXBwdH0k5cJSCcsn4zJasf9
bbU1gtEjSAixF44ZKIRCf62OMenHZrbeVyZtSjEgtOdp2jgDXDmHNdGjpeA8
bn9zYor8npH5Kr4FVfh9MsPPU5mNyDzrxxeGWzBAmXP/HcgEcWCJheP3NixO
9PS5acVF/tXAclHBKtz04rEyIfXaanssOGKoDU6N/6wrmCz46d0TG7cvh+rF
OkPrfAJf3UbTK+erEK49dVHqPBu2yh9Nvu3pw7T3W1un9BGsK2S+PBteAdmT
x1Q3bWWBmpgcyi1pw+vkfr+7pN7lRb8p39sRDMO2egcKqW81Sr4+nVmNzBe/
cn2z2cixXfmqd64U+8zUJ8RJfUpraln+qabilnVZ8GEybyhphy3yvgbATdMx
9grpR1SbuBerHQKhv3Lx3D4HApu2mAZWatDQRq/IFSH9//oWPjHFplZUjP1V
66ztR9srX38frRZMPYnRv3qLAb7wnP0+4p/Ae9ShQr2JfL7hzhedfjRYePB9
Fz1C+tdm9yDREioSHvm/CSX3p6PkiF6gPA1NjTeOymUyYXzjgJCzbQcK6N7U
P+IE5h7ovN02TQefiNmvmOZB1JTs2GEdUYJFZ94WnyH15fHT2u7vWC3EY64J
XttAIKP9FtU0oxS0nqSMvaR/HDTtHZMpbwFj1Hhgx2tSH5n0jRSZZti9ehQ0
KsJEZw7/cAi1F+caVqiHfuNi4F5njO6aMvQoNXO0JpmI3xlo5MjfhYPL5qOc
TrNwkGvKnTYi1+9iLF2+g9TP/qS1X1blgrY2fzIxi4BBff+ZqsY2FGySEXTq
Y8Cr8txJbko3ds1bJYhoMeAk5fvU+9lrRGuyZpeIEmQOuK3aXlOBzMSoNhd+
FqSXBGtOS1QiR+V4inslEwmZIgsVvzTiP/P82ewCAmIPa2yC9vZi2VOO9ZmO
LhjPfAoQGKuA0g1DX7s5AkPHf1ycWJSKw4cs9Dnk/JT1+X1WTH8GleLBGX1K
IASyB4tyaTAN2GLQP8aE/BUOLF36YZ44L29F+pOS1D6NvNrPOF0VuaYmm0DC
BHfVyv964bzxg4vCawbiO2sfjA42YkwokndkgIW/S04bxPR0Q3ON4ezElUHs
T2LGeJrToPj4i3dN5RDGl7864RXcAoFbN3+sv8+GofHl2NSjXRDg+bJr9wsm
/J66LnBObyLXs/w+TYGLTNvFYv7UWlDnzFZ5krwyVrqrU1+RDhpRrzxZwQSf
52CaZFknms81NMkHDMPpRFLvGdkWGITLZwaVsNC1RsJ3vK4BqZXZ+6ZEWWjm
r9qXMNuHSt082o86Ut9byqdDbzQgTeybrEs9C+WNNeMaNjSUZ3ltkOIjv2f7
5YTCkl7wxvH6pld0wPL0/eSa+CZ0/fiWKOXCxFAGJ+DJtnqo+hzbteQWuT9x
Hy/zVXRBtVmkJ+s5A/lXdjXRpprg0ewsFW3KQThvBI3R1IPEln8OB6wJ1ERJ
L44deAt3XlER5jZyPfLilN+xH1DkJ7bfLo/AjOvydW8VS8FT0r+xcZbA3dow
7lqlVjh6Kf11Ch1GSFXBj2GjJrAvBl+a4jCgLdZM2b/5BRbMUN9MkXnSJsCT
LbmHDo0lF3Vixwno7zKtDOrvRF2ccN/qOQ7k4vOHsg07ccDkWPYqOQ581Lfq
5Rg1oGOz6fV91SysH85d+fuBLwp4otc+IfntujL/gMfWemhQ6j/vSWZhXXn8
divNSoit/0Q5sZmA1emxcScZOgbuntN+s5CDiictYVFr+3GgQoQ+Et+PtO3u
XkJxNIwqMIxrRNnw2bcZbUId0Nhf/6fXlg2DrjXS+sw6uLx+8/vDedJfntVt
aXbLhMjQUvVdJL+NFlzZGL2hHUbrXh0teMkFcbW2UMX9NaLmq68eVCf30+sC
hh5noFNRg/ngGoHIVsrpdhMaJMW03kgUMLH36iCf/sIe9ElbXJBbykLt+08S
RuZ0MDZdtA7ex4Tn1mfHlsa24Z2YqtPz7GFI7a639uSnY+7dDf5Ibw5WnM+0
UZOgY/2/NIWEHhZCijn5CoG5CNDnPWRLzovKG6e773Y7rFwGy9h2BALchP/a
SJbD9kv+zz/JBLKrq2Ink/pxddDZ6LNAH6JWeNrnv6sA4Xg4rUiLQHSreIBX
WwtSzzC1vT0ZkOHab5Azr4ZlivdsUxwb/DnZvjwkL0Xd2XJ9eAe5n31uG/wn
+7C/xPfR1A4WxHbdtQg4n4olLmbW3lYE7tnYDRW9puPTgImdDZlfZgIlwkLD
XTCJc87av2IYDWZTPOPGLQh9Ij2x8wQTGe9v/jMXewfpyZb2+OMEdLeNSD5M
6MG7cslYzqFBpB49kMcbXouoL/sFonzYqGBucjS2KYfpAVg272WCcU2w0Ppp
O3mf6BK5+l5Qc3t3R3HTwOclz3hH8meOxOK006d6YLv8QfZvDgv31UaFa551
oOjc/TWuJ0eweDotau36Cki1qbTeC2dALFBUfGNUCVKbvlsGk/3njvjLtISD
7Ti64KfFxDjZNw4sW3nsRA2WjZU1uesQsPR/IfekthLc8177pB2YiPUW/a17
Kh1KL7d/mvAh5xHB4flY8xY+/bd/xZN5sOyK1TelDhpCflZWxKSRflyR3uvy
KAtF2+UY4/YEoiJTsiUWFGPfH8OCaJIfKMucbvb8asc45Ue0mwwXuStNr9kd
psIsrLle/QyB4ZuXmiQ21eFnyZm1ucfI9w+45fUkUxGqopQ3akbAZN329/02
nXAr22KkT+rbvH/fq6afnXi4INLzbgEXtCOFZZLy+Tj9ZSB+pT4BYZe/JkbP
+nE8xS/5rc4otHSnKkOG4vBo75A5xY3cz/mGsUpGC+jijKLfflwkm69bW1tP
w9/bvpQ7X4dhcI+aal9bi8hR42hnkodU/YqDnTJb8bxpZ+b3CDZKzh27lm1c
DYM7Km8j9Ehe5tq98zncjEkr4nijF4FDp+6+OrWRjsQb2cP7ZAhkfhwuuLel
GwLDyWfPXOPARPA967FeK06+6TSkSw1j9+yRel3JdswEKd5ylCbXl7vx9K/A
FvytS1/AY8uBPF1KWns6Dws3dDh1PCN5crfSAZdzrQhas0r+/uNh6AgGBLnc
roKa/EDt19ckXy/Q6w4r6oVE43xYhQ8LCu/95YM3tmE9r+bL3Q5sUKhbeC8S
8chc5F4wcYrkRe1p8ZvG7RjgVf7AKmWBh+8H95CUM6jPC27fIXnG0PBKQ19M
HeL05K3uDxKYvGuu8oDkmYcFq7QLkpjIsZt48rsyFX1svg2/9xLQdiyTUM5o
hOcjfV4LFSaiRu83S8jSMSQRffvFIBvD08cds2c6kT8ob+diPYqEmLKUsgSS
B66O2q8KISCVw9wques1qNVVQ9UkzwZ2R27tnSX7Y4m2r3t5L/gkzU7P06hw
S3saGiNE6vdcyKJDaz7CdHL9v0uVBIIknvLJUTqwSJJ7yT5hCCb8cebFnBJo
y0jJqv0mea97ts67pwY65i/Tjnew0JCjlO0g3I7jB0IFJ21Z+Hy5T+v6pTzI
+NPjH6wjsCj7R9KV1RnIEqrLLCV5V0DHN3a38Tu4Pdga4UD2pzbFeV7OqnTc
q3kkqO9LznvVff92RRpSLZxXbign8yg5s/3C+/cwXpNtfZPky8xT2l/5OTSo
rUjZunwDC1r/+XjevtKBTwIfYx1PjcJLwWSqxLMdZVdl9DzI/hV5YsIpub0b
HS+DHv8nMgpPxZaguBMPcU4vfLG/K4GP5on8mslN2O1dJfzCnY3C80muooqN
+Pxq4ZVwUQb2nVz98IJyL1zbj/S35w7Bcq/qilqXdgwZRFX55w+DW+SlpbY9
F38eXd1yjfSbj02JZTMknwprrNuw6xMDbZ9k7cJsGyHG6k6R+cCCb6ojd/8b
GjI1KX0W1xiYXHA7cb11IVT/u9+jIMmC8L3w0iVPPmNvs3bI5lEmWj/VhwgM
V8CEbmO/P4mNni1lql93daEpQlSg1IULR1n6A74jNGS9ec455krmg1nNTZ2f
NIguTncKFOegb+tKtY62SghQolcpkfm/11rTX6WrEcGvV86FkuchzObKd4Pv
DdhoGpi+PJ3ME/v4DAvNBByKv+77yp1Arsf7NrVasi/PN7n/tPuC0LmfrO7m
XsR13dvW3DCE4EVj4Q9/VaLZcFrchPT/2KwR3vy3fYi0G/SZJfnZsu4us0H8
Myibvt69n0Ke94LrMqaWuRj7ej3Uci2Bvp06Mxw6FTKuAXQjMg8G3kykzdv1
Qu/S8gIz7z44GU+EBe2phrhd+SLucRYYB0uO6awrQ/7hRKuiTWQfCb4gMDH0
GWYzCns9KCx02FE67wjXIvWsVL/GWiaqjO/8CZumYq7Y1kGRxoReV2Pfzj9k
3h7MsFddTECwtSP04Z9unLwxPbYkaQimHS/5pgM6ITQo+8vIhpzncSfz10PN
uPlYp0nuJxvh09rbUw9VoP3aEd32WBbZY7c0m+TXIf/+SIlDGRNKowXhPtWd
6KrYlTxgxAA1IG12FTcQBuoQNid5OCdrWbB8XS3Sy2qDNu8h+W9D8w1xbifM
3LbXzRYMI1H21HoPkmeOJ2R8uaHOhpzEUH7qvVYw65tjtvwi0KPB9rmQQwP7
O8/SdrlB/DVXi6RqF4Na9UQnmMwb5YUeWRlHWnEw4uW2ezXD8BChThzaU4Y7
pTJL2VQmPF7kGuhWtEF4QiC8jsyDmfolrxb9zMf4Hv9Tz8TI/uZTbv/1eQtk
clzurJ9i49CDDd1jonQE1/3aruRJ8k5JkFzM+Dvoj+7f+I/kQ67gDT69gB5U
NPVWGWaS/eBE9CxzWy3G1980TQYTH/aeLb36sRtqjX/NSrzIflEyZ1ox3Qih
JAVHEbIfBl/XOB0RTkfTA/X9jZs5kMhf4iDr2AXX47ycvSrk/c8aPx0haJjJ
j/53Qo0N4sKbuPUClZBj3l4RtoeJ/MX9kel6NeCudTzcReZ1LV9XdMHlTrS9
Nz2o6EP+H7L1VPRUHS5FF399rcFG/Lqdyh43WqHaG2bQyMNGk9byCGn1cnht
3+/j+INJ9jWuhEl1GdT4p+cYNAbctE5/ZS6vhFa0dFUp2V+HOr4Vy0004bB9
Ubj1Z/L5Mh8aR6fIvvZcNT2M9ENKS+m1sK77MHi1JduAzMvMkEeaH9SyUfdP
Lbyb9Aee8R8aLtaq+Pb8VqkGmQ9FYX5mOR9zQUh0nngbTkCh61DeCdNGWPH3
bCk9SeB/cLkNkg==
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlns81NkfxqWSSohKhV0tISKlNCk9dnOr6KdMQmiNEl0kWSkqWhERhZL6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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk8lHsbxh1NHFJUzoRUZOkYLWPPSS5bUXRSlkS2VEKy5BUpSymcKMWR
kiUqlEokSxlLJNtgJmONmed5jtMy2VInjl7vvH/8Pvd/v8993dd1fVUPB+0/
Ki4mJpYhev+fBqep2bDaXvgfK3ZY6UkgbPJ5h9KaFsTrmM9WfydwaGbnyZHY
ETD//UoroA9js8272LL7w2i+0bnwSIKPCoXq5oW7nTj4qVmh0onE2nTnCRcl
NlhmNrlF7RTsNbWaZk41wcV2R1L1Bgo5fmxJuaIevIz6qOKoRmAwLlM/hc6F
cXp+ou/vBGpmD95S3cnF7c1Ldlc6ErDTPqjdrdYCk6GXNbfXk7BjXHt/XZMD
//uZoR8eELgrG8esO/MEkSVLlmiFUKi3nP9jWWoD6MMBr6wZFIJ5+jl/eXcj
P9jQ5/4/BPJM9Q7YW2cgIG4hTd2XghI8tDSNOGB8PhWYqEli8aYoesHOAdw7
daEjJp3AGtsh72DPLug2f7qzpJBErPTYtDyjCjJvpZQLRXq8gn6EtCx0o31g
W7KdNInOhBimyt/1OLNk487PwRSKhhf9tvFYL2RVPa3ZYiTMmlaHbHd9COUR
poK8KQX1ihRty+QOyJ+7tGfLERIqGyYCxNQvw5PBzZ51o1Dj0SDQzxxAwF7D
+SkVPurL/juZ+PIp/Lce76MrUXBkk2kK4d0w+Jps92oZibPFlTImewfx8fzv
MT1XRqH0k6Iug12J0oP75fZZiPz4Q0OLu28Qr9af3jr3QABlhz1FHvFtcE8Z
al22lETe+uR1DlO1eMfe42AoSWFY5gXXPrwXs52Sx8rPCTDu8+myi1UfDiTo
ysutFunZZbkQL/MS8dru9TxvCiVeBjYxwg6cd74kwWgjULrpl8IVD+uQprZI
7VI/CS8DFWVjn6uYFi9YFupJIRYvGsaoO5gxKtgsZ0+BeS/8ut5SLi5NJ+Xy
HSlIK3vtS9LrRfj1IEJZjQRzaITBDmBBviIqoecLicZBvfjXPC54bjv8OoUE
ZuLXPG827EVChmvdSgkBAj2Y2x/VPUd0x6URP0MKMzb+FK2qDnfXPr03v5uC
nHDE3u0FG/VXVjHs1f9C4zKb8ZxwFiKqHkZObqFwG4pf01P6MV+1fEK/jY8T
t/7dIZvSgqsCo1WvXUX+DslFtTEqwarUCzLkk3g+9vjMs5hBsC6cjZN/Ogqm
w2cxofsgLMI4iYcM+aCHtgmvXhwA30lrYGskH9PFeTQ9u26Ib5lwO84iwGZ6
36DZt6B8MmvMbSWFX71mVO5I9cHhsLbMGRk+Er+1KqfuZsMkVdPYqokAT++s
LO/Mc4ytbix0OkAh/J/ADKkQHtxmEtsLlQQ4trv7hHc2B7ckF78qnCQxHlbk
eH1kAAlMbomC6L/ufv3SbfRydGRJDz6Tp6BymrOGqcjD91BflcI4Ak2i05iN
9MDxtf+AYgoBQ2ZHWIZtH+QMz/1q8B8B8p/67uq60AP2o9TTX4MIPDibvLzY
6y2KUn9wAnVI2PcMWH8Kb8LJwYYK6Ysif+1uzpWOP4ZBdVcM3VbUVys33cSP
uaA9mpNqFeVHIfjVa5NTbJTcKNfYfpHEVoWxjnsnSzEq3XWzU5+C8525gux1
/dhXtscn4S4BW2/57Y7Xm1D8y9q6Nj8KtTMRqWpewzDoy1YzMx6FTP93RmNW
I94eDXCq2UaiLMJuV4l4N+L3za0ycidRwhJKKLdXQ+WxQOOKKA+b17+J1m1q
QrDiVNiDeyQGvYMR3VAL8/Nki2AdhS7F1YervPogefVLrn8SiTffnQz7urpg
uiOMbrSDQiX3Az3lv1wYGee4PpMW6YmQ0Ta9Xg1ph080ORMK+U7hzlFJPdh4
Ys1l9l4SmmU6aTeyumERas6/ZkFAfuM3iW5uPZYr31xlMUVikl+oWa9UDjsN
k8o3RhQmrYtCNc4UYAPdtmaLtYg/P3fOBkaPQu07re6n/XxoimsbR8ZU4NvG
z797BFAQqkqM1G56iyRTi8yeBQG+uc2pL13bDUac1sCTNALTp/PFHRU4WC9M
d9iQQIDrvKmyzaEboC21cBHxUP23KkvDR+/Q9PNi34yWUdid1LH5mfsUwfTj
lmrmIv9O3FY2OdeL0vZRoc0tAn+uUAhqWz4AxlTxL4qL+AhN7ituOjWMQ+Y9
rh/C+MhbsM6/XdUPXWExS89UgDJP8VZp6XdY8lFs+/0cAi67XeyyDBuRQVVr
D/wgMWMwe/+ExxD6em4ZquiMQuxqofrWJycR495/zEjED9v5+PLqNRzs3JZF
z80kURR9c+bGjQYIzXuKIuwoWFy7Mi15rxMRsXu7Aowp2Iz4VNSZViFaZ6K6
XcTfepqZFX8TByeYY8FVyQTM/rQsc9iVj9q+x/41oj7JaRisXOBfQ/+Ro0Xv
j1J405Dbfm19N0JXqbaqVRKoqsiJfPz+NcR6aIXlzwhsv6x88AGrHy/k2b5+
uXzwF/sMp+o34sNEwJGysxTSJyKzNvb3oejKTxX9ISK/p52ckjpegCUXqJYa
LeL9OYtYndB+hE+EPTj/kI/+4bwQXjgPU6yA/KoDBIiZCxItAVzoWiwqO+Qv
2jeGEPZrZUNmnY4C24dC3AzT5c/Sbhz++M/epLUU4tN4rs2SvWjWOSBs4Qkw
9cZ4//j0IJQig8R8BALYf1Lo2LzrLlxtFNieJym8l22hpeq9w02jzyXZ+UNg
eRxqMeIPQG/uyE33TSRSh+8wDjLyYPX3SI6xqC8mVjEbVjjyUKJV+mUlBIg4
7HfEY7YdZrE/9lxQJUGFSBlaZrUjnZMsxVgk4sGKXcI6z0E4BgQEF1zkI2xZ
+Wb3pAER90Ln9G+RcA7pMvd7PYRkK/8n591GkGk//uR4XB1MMul5LIpEjRJX
7AA4mLoWxfhMIxE/q9rKkeXA7EetafkcgXg1vVZtFy7kZbkjC1IkxM7EHP3q
+QyC8nmNmjkSiayIoGzmW+SkWf+RLepH8NNLywu1uHAneMpfZEjUF0x3XRno
w3zgOO3wv3yU1ky2S/l2wVl/cIf4B1E+95hwdpf3QdxOaqezFB8yl11Smh05
OF6wnAqrEoCmF5UfyuZhrEDLZWxKgP8Btdqfag==
       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lXkbZkYkXyohLTiO0nwx6Ms2VLeiZWqSmiKVyDaULSOpaLW3kA51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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k81P3Xxid+2UopSgslEQrJFqLLraIktzZaUImoJFpQN0WWihKSkIQk
yh6yZ4sxwgzD2I2Z74wlISUl6fk+f81r/pk5n3Ou632us8Hh8iEnAQqFYr+A
Qvn/z0+ClqXmd3uQpatruGxgCMoPVTSeetMwE2LmwHPmIHwJmi/9rIflNXfh
W9YERGY6naxM8pF1cOiSmyqBvEUM843zLIynUNJtMvhQXXM3MHMjFbbaDTd2
/+bik/nl0oQ1TciqvMr2qCJAf22v7firGGMLlz4bPc5F0XozPV4HFY4hYqNK
Kly4z/FkfEMbYBm+gZs5w4fPhhl/X+ITVnEcsmnBHLjxTLbE3mTiWu+Wz4o2
w1i8K1BkWxgLMsFln0K1R+G+zbOuQ7oGhzcEn8lVIdCd/zOr0KwTPYGGRILl
ECgPpRsMz9FhvCHw2yJxApTjY39T9N+hDrffXS0g0Ku600dWuwoRogP3JoN5
oMZGbezMSUH346/LTXwIyKbNV29zp8PigoNNS8EgpHI0HPsKm2DGvN7S/pOL
QEbLnvmbPdD+c97T4hQXp2ZjY8ofVSFXxivjqQMXFFdJxq09NYjwu10yHsrF
oaahdX3JfaAb/lils4XAvnotw77CLuj/6JnZwSYwLHG522gmD0Onzy/1zSOw
9+4/dpvOZMD0t5X57igCHTVqHhfz6AhkmbfPHiDA/q04eXpjHSqmpP32/iJg
RTWdiZbLBf/aImN2EoEntxwVbFKY0L3ho2P2hYMvcUKSJ2pq8O7CZSLuHBca
okLDX3UYGPeziI6N5qJS+Nv6nQopKCvarBlpQ8BI59wjF18mxo4Ib3ndysHN
kftb23f34LNqv7qacC/m37LXHJikwWCaf+Db00Hk85W2OAhR4e5aonq6hUAz
W5Rlu4SO/KKFrhZP2Sh27Y0RUKdj3tqYuLNsCPEfC+6/dWZBp1z8ynNJcp6j
532T9ldg53PD4t6zBBQs9NXlxpiw+ADJM2Z8lMmIVqasY0Bq++ShV6lcICLV
qcKVCpeDJxy6fnGRqFk8K38qEP0ZKvpmdgSUt/mvz5rpxOFFW7w8yHlT5Pgb
d4wyUCJadIMo5SEmx36j+qosNFBclka7E7i5QufMcE0r3OIfCTbTOLCt8psc
denBlIFr6NcYPu4ZBaleOVMCB0bR3x2aBOSm3UJfrHiN4I233s+ZE6h8mVJ7
KS8Mzx57eSwj60/pYBCSj+i4cD1AZ0hgECdSWummeQwYMJYiXZgDivA5q6Wm
EdBwUr7CdiRQ+6/oWrFZGixCJX2/nuXA8qZrvcKVVugLrm68JskBYbivt62o
AzLqKpOnY3gIFv5L7RKqBT5vVovR5sEuNY01sK8NH8SjBP6WcmG1Spr4euI9
9hyQakr5wwU15U7M9uhkGCQ4VoZcILBwgQXlzwMaWMMN3l5tBKx72Z6SI7lI
SxY/pErWn51kzy/Y2YLfgrd9YT8IZvzmNcuJPoy+b9r/OJ/U5y3XyU0aXWgw
NrhY/o4L5sGF/+RmtcDuSu5tnZR+zJfMhw9PdWGDmL9VFdl/42jzwWnpKpju
lLHTnCD1bnC6Y0NzK2RWfj3zTo8NccbIAW+rVhTNHs/ou05gTvRKYrJ2IXID
rLxFFXiobdbJEX7XDkemBet66DD8dvvvLrx/DheOpC0SPUWg5keyccKZUgh0
Vr7Jvs8FW+2U7NaaeHw4ElFzj9SDxUsEZN0rQfqzm8JugVz4OYk2JxvdwV7x
8Q1u9gRMClJOau6vR3/ZAqMzlwl07op7w9xaBCUJu48oJP2wnzVt5NqBPz+9
hHXVR2DotWWDGqUa+nnjOkWXCIw3aL8Il/4E99frz8fOc7BLad3/RFUZKPvc
9/S34hAWD66zyzCsQbFoVZ6GKg+0pMhO6VAaprYIGYfZ8nFQJ+XpQYsusA+L
lTuoE9js87iS8qQT8QlrbCVXsyGy2iow2qACJvZCBzRceSg6rFzVJFKM58vv
leouI5C2ZmLj1wsfIWdcSKy9QdajstRxl1Yrxjef14os4oDLHatp6e8Cy83u
62NSTyvl/D9Yb65GrpnI0Wc3eVguEDCQIt+KZa0Bzx3eEJDId7LvoNNQt4aT
kZnMhWrdWeKJdSP01tHKBDS5OHD9Ys8roTY4Xd6Ye0Oej+9RWj1BKzIgVrfi
qSnJ/7jfNbvkDRgkhwmqPp0Hq8xwwa87mKAJvO/5oUH6/VqPg7cTEx+Lz2sb
zxDQ+LijI7a2BWLOTuFGkQTCrm/CRYl2RIaq7ROsJKB7dIe7tdAHWFVtPfh6
PwH5frrP9ZlufJkOOrtWnI+ET/vdp93aYX+qfmT9NDm/uYM+j7d3wu9cW5mk
PRezirYRk/M0qBjm7N0SxUX4uXN8MYtUMAl3zmFy/p07awea97Vir1vFtUxv
PoxTFR7IMv1R2CwSaEvqR05TrNJmmIlWZpqR7UUe8hdfppodZkL5+335c2aD
oKzbx7DvikJiRfzTTidyvxSxkqvMGbjWNjjWmchHyfy0Z//vdqh3JLQ3fyNg
aH66oN+nC6eXnoyK3DWMSX5QeKpnBYwGd1Rnkf9XYRr9UHdVAZgSLTaiFmR/
HofcHlL6CHb/kWY9OhfDchezHyZT0f1EbHRqAR/U8CK9Ra0FmI2siDw7x0Wh
gdZznz0MCBCJzDTzEcjEfkupPdoOkYqzV6tI/duW6GS2ObVjLsmhYkC/G3KD
0nMCfwrQt9YnrNGPwOnHdlJZtcl4oKu5w1SPgJ6R6mH5GAYe1FhQF5J8ELP3
pdKpDCTwqjel6fAQuOg/O3HZVlD1qFu+0kjeVgf0vbP3QmClulI9+Z7vsbcy
QrRzIBu9fvdDX5J3dmG8a9F06E7EdkuvGYZ1S5rVOokWBPdlvFLgEog5Jbxo
b2Y5olVrXIPcyN+ry/B4ueA9nFXixG5tI/sh4eyZOPQBEh+jjN8dJP19j2r9
Q7sTw0eXn/0Rzsdk8S+Zlf59EN+lJymbPQLbr83O8gONyD74v/9WDg5iau2D
iffHWOgdYuSseTsKukREJO9ePN4STiEz5PzG/nyxeChbD5XNejLKdwi8UY1x
/N5bAXrV1vP/iZF6Sd0XpP3oI7yPR518dZOLXj9NcUexVnw+quZVVELyrqq6
r57Tgjn/tnvxkRw8caA+ynKhYvCiU8P/wrlgyF5NuaXZDtsnL+yngtlY5bDm
j1Z6EmyCJ3mKpH8pNsuDsktPI1WPq6RF8u2O4FUiubwNaiePqib/YSM8aEVI
hkY61NQ8k9eYECjrDpinCdTj8mm37iuPCXi2UdLGjzSjMOzBHucoDnozrz5a
casOjk6OkwH/kvVl9/ITVz+B9XS6zzErAi59ebKenHIYHJZIlqFxcUnuuIa5
cydajd38mhk86IXzxF02d8E7LHoljduHTwVecl+Mq9EzutuRFshDxpzPivV1
Hdi2eX/4JUM+6LS4hu6qRJQK+fJbjxFw6O+g6Ac24i/rt9OfC4PYOZ3d9ora
hZiJuucH1pD788Mqw9nMTJS5fj8kvIv8LjgXK9wWCveRL1le5Pvnah3GWixq
kd3IHibMedDUU98imt2Ok898067/5oPQM+7xT+yCZdD4afrwIBxd7V0425NA
5SQWLN5MztNu6l3fDAPuzR5Mj6Re9CYeH/+d0AhPofcZS/P5mKCt4ElJd6HA
2lZGdR0BqtHUFYPUd5DfavClXpkAmiOf3ZKj44iKjMf4IA9ye/0PzpqUIuG9
xbDfAAH3ruqJmLetsL+48u5qFh9+83651uGZUBN/G14TRs7HZUN6ShsVf0yF
VEv7+bhwY+TAx5pSpG7xuFtN8o79xibA5e5LzN3O38V3Jec/p5y51c8Ok33h
bnrk+3t2lN6MtabDap/KP1EuQ/AWd7EWFehHllKhZIw0G/GPbhdlXWTgmPw3
XRdpPhz9Zi2p1jRcr63voJP1O2/tfDu7ug1+igvt/3K4OPGKbUy51I1EQmG6
+80I3B8xDfuiW3FB2qpfhOR3x0+9UP+ddHS80VHu+klgtIh7SHJVKwQ+E2+z
2jionvDnrZTpw+PK8A/CxwbxRZG/70BuC5LN/n3lTuHjp2/hAy2bTGjIrHfu
If3vx8pbOSWWg2198vLvlhPIYm0qd9VjYqBzIrpEloPal65HLVnNaD2iVZdk
NISEk5faodQNfxPBFLe0Ybgr7x+ROtqEhaZx/IUFHPD9Zy9fNGVhzuudp+Qs
FwkWm1K++DKw5UXPQBLJe/qkwO0lcfXotQxY/CKWg09SD37quzJhK12SqbmN
C+OugqT1PSwcYFxqE1vChYK+aLDKXQbMgk6efUX6c8kG1nXFZAYGw2nUT/8O
gXrGNO92Uh2mtMOKv5P54pSydd7Kh504sRhcYYcxhMuYicoXZ0KHPyWdZkvg
51waLHMrsK4++NKneC5yTBOvfe/owIThnYELT9hQlNi+/IdJGVwC9k1MLyXg
o6DqVMGoxsm5lE6HMgKnnho32r9sR4hZkm7E0BC0rznsSLZgouVrKe36/CAe
M35UrO6pQuG9hSn7Sf2t+6F9dd84C2fP+yw4njeCuFfm6vduMHHI+mJ0w/5h
JIoude6qY0Am1LeZvpSNxWayiyl2Ddir+jkji+xX9KpFYfN6qcj6udz0OHnv
KbToVpffIPn1YJfVFy0elJs5CmYxVIjFvdg5Se4H7+9crZXBhbjW+fqMaDiB
cNrK2hWfUhC+90aY0m0CUeeXsHqIZgQtjogtfDEEJ76imf54I+xdZA90T5D7
6deIgH0BA7niu8W2PR6E8YIJg/moF8iiiCg/PESg+NM7xVzpavjRbZb/E0/6
y/39h1tSDdD7vXatAcGDp3XyoHvMRyxwjdlWFkLu03pPiedrO1GSnlOL0k5c
27D4tspuOhrW3m/uJueVVmn2xtCcieCMLvfrFVwkOe9S3WbdhgKXKjODikFc
oB2V6q7ugdMxB0rARx4yjfhn4hWLYR6UNO3dTPrRZL/6X9Iv3+MeuTZN9yP9
vGnYR7kG1I+daHpVy8UURVD96osefNe3munzZOGOg+qj7RfpCJkTkZEX5OMz
7XudmnkbhmObxkNP82DStXd04mw7eqfOhR9YyYZfRZ2ht34NDOw+P7Q0Jt9b
99KZnZiKJ3/UbsuQebDbzHrpc5EODK3/L1K2m9wHuyU8y8/R8M5++Wi2Ixcx
ES8vFSlX4thB3bEFL8l7rjPnXrR0J4pMWyVjFgwh0YB1f+PqZsyx2wZSEvjQ
q5XXzozqxr3jGWv6/gxBI2I4tmB/LUparEoYNjxc2PkkdNSIhauZZ3c4ows7
q2jyotv7YKS/VNBh4RDkVji5RhQyED38fOqhxxCaHVkuvZa9WLFJRl6RTerN
okecKpcE+kXOu3lvkucB/S6Cmq/glf2Xuo3MW+4eJ1I2TaSiaWnaZC/Je9p2
a/mu9GaYisnGKGXzwLql+pUYYSFriRfjzBgb99rFIuX2V+LsmWNis+R+sxV8
naXpRua3K/mVEQ8JHPmVjgpNFtiXeQoxViM4ESv0IUuiF+dtVuyx3sGBiGXr
8GbNahRGhMeNkv0qEpg549HQDRt6T5D2zmF02qlZi5aVI4U1k5FE3mMJKcX3
B0oL0bEieK8dyZe/ExZ5DxvJfKydT81ZyMawqJca1TMHP0K+ZfqR+aCtkHVz
k3g3WvS+r1R40IkLd00Weg/WIdGq2Fv5JBfrWUuU9HjdGKhU9bjsPoJtN8p0
9ixhgBizdyvJG4JfrZzyq5dk3ulWebT8GXmfm5Z7TYZko3/sbkBwPemn33fs
rVGA1vyfWqdmuChZqDAXeKATpwuUa87+5CJf3j+iZPoT3B7qaPk3cpAY3R+V
vbEKd2T1+gZJP9/5bV0VdasDPg8iNXzvEdjCVZHa68JEViCf+cWZg6PsqnOn
vnfA7rzl7a3dJA8yp6YygujIiCyfTS9jI31PYLv/iSrU/ma9LCX3OXOro8m8
WzOM5V8b0FLZKDpoNMam5IKjYqJWe43074OjpVUPe+HHeML/IjaKTKXnzzYe
a0WZhvqKpu88UCoX2xyVG0BM3My4TAMPNyR+bN4c0YeMmuinxWSeyvnu68Vn
duDCr0UR/31mw1u6Lmu1GwOjaeufeRXyoSFNONY6dqLwrf/fxTf5+PSKrezz
OA8WjgUSMifIPHPu8762J62wvh/Hb1YcREejwH82ST1oShNTCro2DI2z/fv/
JXIgF7Pq8jJTAkUNU3uPZTThoGPY2K8vHPy82RO25AMdgf+T0rh1lIc3ShIL
Pi9mQCpALl1UhIsjUsDO3TRINLYyKP1cRIwVR+ZL0mH+TWMVlcynUbKDIioc
Gmxm444rhnBQmj1lL0VNB7RPW28zJ/WfJX7CLKQB/CXHz28f5sGyn6gUCqZD
bPwNK7uBzDPlq49SozpQKbz9kMHhYVSmMToPZZWCuXKJ1tFJkvdu/znn+FXD
m3GooIO87xJyo983r8+Hgep0r2EyyeebCaF+l+uRGpsYTOERWCuzIEhoeyUI
JUrov6lkfS4vpdpIXjgXZyo2NhCwKvHaGWCShDhj46gQZzLvCwavEXlRCrrr
7OthMg+4Tx75x6K7HfS62RqPhSOQv6I111pQBXe9xvU3yHvLx9RHR/9PGzp2
H8k4EMdD748G3cZmFgzNWjy6RbnwuWdVPqSZB7PyFh9zMs8Pf1QcG6lqh536
sug1vhyUTR9XmMzMBy08xTyKzD8y0S895kQ+Yu+X151VIkNw33joh8ed12jP
9zr+leT9/oGMeCULFlo9jmnStTgIObI21y6HAV0TzSup5L714JdIiVZ0omxH
e8AdawIn4gO1bz8nuZx3LOytOg+lGU2JU2/psBQKWBdjxYVIs6u2uQUN8S+D
jPtduEj9I2P94xMTAg2PshNusnHM7nh6QH85Hg1ZUwbIPJffuftCNL8CQsPi
tT+ek/fyJqEEj7BumFy+Fr+jZxR6GZeUCgzvY9ZHMUaA5J2L86+vO8+Sftnn
cdBllABd1u3jbFAVyk5ebCpwIO8npOzYtbQK46dtrR8s4EEoVUc3/3olGk6s
HFcRIfNTsWZsSeR9vGhfXZPkQuYD25FLu8404s2yeuOFrwj8HxzhGkA=
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81dkbx1VSFCKpUJEsrZM9pI9KTbQIUSGMDKYULUgLojCyZokQlcwk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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lekbxkUqUTGWyKRFDZkszZBILmPPmGwtKJKxNkYY2iwpDQaDhImR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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lekfxjmFikkTI0qWKNpmlKY0+N1kTWoiqaRGshyNZJtQlhIqSfYW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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VG8bViHZUkr8kiRKWdOCkltSSSURlZCk7IlCISmlQomIsqdFtmTJ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lWkfxm3RiLGHhjdlbEljLVQuRaQsNZbkVJRIeaUZEqZUY0loOmGk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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk4lekbRlLKMiGX5WQQCRlGtkrdhoNja4RSkgwtKoOhskSpJEaLzMiS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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk0VfsfrV4rFZ4oUREeKRXuI1Hx20oZFiVRytAgiZ6pXhF6kZBeNBlC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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4lf/7V4iKkqIiQgNFZgPlpaIyKqtCVtKOyKiPlRX6KPkoI1mRGRJl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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk8lWkbPg4tI30hnyyRSk2K+SrLlOgyZN9zUkqSLCNZkqS+fElkKZMW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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk4lGsfRum0oJIthjYiOaKyHdU952uT/VAqtCGFHJJIC7K0yFYkHdGU
JKLsqcY2tkEYjDGMNDPvS5IiLSeJzvv98VzP9VzX/c/v/t3Ls8LNz+GolISE
RAp1/n/TNR/KMdSfooTFmXPChESiiff+FWf6UKTYvLwnSQSDtlaWoJ6HVO9s
r21TQoy7BKl+am9ETzDnPi2LwHHL+uzbfwhwXHPegunyAZywu1J+T64dGtb+
RosEYli+SqlwjeiBcrpJ2kpJMWQeRsle1GfhxILLsavXkDhj4mu6fOIh5PNd
CCU/Esumf5pw+NWwIiwrX0SRKFAjtpsacEDjCWxd7cVIvXVoruorJiK4hT8m
N5JYKFIs3n+TBZtj+2M8rhOQOTVDa+5oxQu3DXLJ8iTqDq61NDaqBC3M00r/
JQmP192nHaY68Ww6NFKlVQxae2jkyX964ZDb9mnUSwTuTW5Aalon4oMGPXsv
iXDCT+NrWQsbbK93MT7VBKzf7lxWkdqLkL3b+l48EkHVj7uH864HvJXZtFJD
McaWVyet1+ODn+c84XGGQN2HpDtpT/pgtWlDzYV8IQzpXTu+O3Wj6pgeK3M1
iYmQ6Wbpr12IeXLS211ejPKqJ0G9+ZnQ2O8b5rCdhHejATcpuBWSLnnlRQSJ
cFk02AWGY2RJ8/3AQyRG3c3NPBvY+McvPECaQSCWLajIse4HPXWV/bXDQsQO
uVhlDfcgZG2cfZ+XEIe59nPVnOvRurii/zddAsfsjQ80eDZh8XSStX8RAQa9
nxb8PQvMbzlXmwNIqEc7jkq7dWDops8UM4xAta9SLt2AB7nz46teG4rwXSmv
Lra+AS3VA24VzQSGP7qcadFqxKn6hUnzxsXQ1F8TMBxUC1ZKStxJLRJVwZLJ
s3d1QjIvefvRRgLfMueOLPflwfGQSqrZMTG0ytqdJo360Sd/ifzAJGHd3dX4
7HkLeDwZH34Xgb+mvC4aq3aityOkqUuBAN1dRqn6Ewumil/2slRJMFYlpp6M
7obFUQf5yn4hJBiVCmZLQ8A6F32NOEhC3n/7e6PaOqSPn72iyKH0MPo1/5N7
P7aU/i/OyuMN4pclaI/LlyDUbeRhow8JfhKLp72oCpp2uQ8PFRDQ01PMCjrZ
DClZdv3BbAImHpZTGnmvEKCmvyN1LwnF8Hl5fKdeiGa5TLFsxGD07LZ8vvcl
fGMvyF0LJaG30snNqrwHUrusD9g5CnEiJX3Yp1uAXRkXdj7ueAOhxCYhPb4c
SreFH36n9EvbX/dSL6MLkoT9JMtAjNkDY3cil9biZYf6ZEQtAY633Nlq/VwE
S8+KHttGwvRq4Arbb2xwCrb4SpkRaGMq/qvMY8NkTLgneIRAgGtBS7ViD1yf
3o/YKSWCxJFvzGfv8mEYdjEm2YuEfuaP58WMbhxXHlaQbBGhs1nxk4FzB9ry
6RNPZcVYe/LdzuSeTjxgaet6dRMYbQ1Kz4wowbeEtzq/VCh9bn2rUWdYhl/a
jUe2Uv7U25SiGRXWDrpOZnu4LgmL+k26dkZFmFm87tR3HZLaT/qYVCAPtcwL
MbmMN/C0jTe0iazB5FYJwR59EpK+GzI+7umFpXFE2XwTEexjjyQm/WgGa5vj
9Gq+GOFjZgmEQzJoV97ZWB4lMRxveM1xVxn65vwuy6D4UFkZ87da7SM0KFxJ
VT1OYh+fFvVXXA88366M11cQYbzfcUzIL0FqS/njBGo/qQWNt6Qt+nB4j43A
4vkbJDLYa3cIHyNq02+Fq+xIBAbN9GVW1kL+ZdSCcQUST15Lamrf7UDXyvmq
GSUEVFKfCu3mF0Ld9EBoDYXXj7vaKqHWBXF9WP/mUgJSxt9zQke5qD6qOrHY
VwxjuX3m3Ze5CC6G9upzYsw5ZXuOdocL0aFH5paECMbWL1JZ5V3QP23Ot2oU
I8DxoebgdTbazIo+zIml8pfQGhA8ZmNLi7d78jXqXVbjfCO5FItsHzFaqHxR
iauPevXgBiKSXykcdCfx3T1CMrGpCMFSIuVZbiQWtWk0+xdmo81IYcjJmURu
mG2rpn0LrPFnZNHvJHTUJnVTzOuQNjtb5QaVf5oxfWK5/CLYlaoUJhiTcD0w
x7bufR0GRtbZXKP0pep6hBsc0Q23rbp55WEiHD+fXW66kAcn4409jZtFCEy7
XDZixcFymked+k0xipq0vloqdiDl4j7O7VtinFgyUpoV1YsX2SE7By6KkZKz
Tm9+Dxed8/t+Li0U4pFRxlMD5mvMnWakRWgMYq5+tL83wUSFeaPyFsp/Xwo5
7ht6a3CheCDx9GwSbM/ts13dGrDx9u439GiqH5bIx+cVFOJ83ITSaysSh3V3
FwzatyLjUub5aV8S9I/cAKYjAx8eqFnJUny4dvS/rtzQhc8P9niMTohxrF1n
ceI/HOSa+hjmLiOx++PTQX0hBwqyPxIn+SIw1H8mZNS0Iieh7e4aF8ofs7rv
/tFbj/DEXxJWUhTfV/uVl2WV4jctnR+31EmwVimFMC/xUFAbbvlJWoRYw9PJ
S1aw0GkX75/EIZDorG3kZP4CvICRXBaFl8lBg/VwCz635k03UfqTjvDcvz6m
E05z1kzcniEQrnPWJaGNiSK5sqUHqD4PDKiKPPeYCwe/dde7Y8T4KOV4SdZc
AIHsr7p/y6l+LxV9Pr74Pr6cHhCx6ST+TrYwWT7VhXden4etH4jxpb5izD+r
DbrKl51tw8Rgrb/4ec1QG9L7rVwd2QQU/Gyr55vxMbOL5/rGh4DFo+LojrOl
0PG2aXi/iMrPc8Wb/Ypy0ZZmpSzjSvEZRb5XOd2DmWVDfzYsEcP+Y9VIc4UA
d77mjEQtEGEi8LGLweZ2/BiVDlw/iwSTfsM5VKoGcuvSqs5Q86p0/ZGvb5uL
2HtVEfytVN6VGmntiKvEnYifCzdaUv5/nyPfHVYCWtkH+ioZEnk+gRLt15ug
Yfq3fRqVlyqf+2bo0iV4NtMi665M7btYJ/BedDpifVIGhS4UPsaDKR/ZC48y
RSJ6gRD79L7dK13SDZmGmD75VyIMma5uDh3iUv+Y+4OBTSKo3NS79NK6CxYy
9hqqhWIo1D4XPHCj+rWwVIabTeI/3xO4pg==
       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs4ldkXx09Il6GSUOaXmsoMXSTlMmr6qjCHRkhMI2OkQyMaalAuY9wa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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VH0bxke0oZAoFZESwpMU8vBcQiUJRZZCJSQUqUSptFrSRknIHpKQ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk41lkbNm0oyRBJUzHK+MJM2ZLKLUtDg0yKdySkLIkSlZgmEiIqSray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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs4lOkblnJoR21OJRQlFhttZSVbbsksyfmQVidGZEOUyCU5TAezndNG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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVmk8lVkYR4kWQooWEw1RkaHlltTflEER0tiaFnJVQpIl60QkQ8nQSumO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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VG8bxomoqJR9/akQSkhFpS6hUqFIe0SSQtFiSRKFEFKRrKmQbFnK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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlWk81ekbxo+TLamxZpkwNURZImUSucrIKJQ0DUKKREgKJUsh+hOVJiHZ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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk01ekfx62hjFHRlFIqaSM0kdL0tnUqP6HcqZtJighZs99RZCsi+snS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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8VekfxzHJJCpZujVaUNJm1MhPDX0kZIgkeRHapGxZJiI/e5ZIuIpu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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VO8bxkepJG2SUlIkUSokJNxJi9Q3FFmStJItpAhJkiRri1Ck7JRQ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkbxw1lMmVpRkg1hGTJUA0Z5CMtthpzkSVL9lFR8sOvSK8KISZr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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVWk4lWkDlmVQQqnQIkoRKSRJk9tI9krIaKI40aIGTVJJqFDq1BgUooiS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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lekbx89UlrIkhXapjDMx0igjla+UJdPMVYaEZD0lIstIMSYNv0K0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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8Vf8fx6VCUqloSFJUZDSEUnrJKElIoiFJFA0JWfW1Z0mKkJBZIpIy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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk4lVkctlylsSRRKpUtSe4kGUvUq6QFoUUqauxki8oSStZMY40MEyOF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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs8lWkXPWWiwjflUswQKsmlUBkyxiLllsott9xCTWIQOSoqJiFMBoVQ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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk4Vukfxt9EpMbaKFmGphUZLWha3GqSTGRpGQ2pyFLJFj/0miyNnaSx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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VH8bxpU2lBQV2pCiTUhF4UZESIulkkokKglFKmVJthCSrRJZf0gT
QlHZ990YzDCYOTMoCQmV5T3vX+ea61xzzvc8z/18nvuWtLp5ymYhDw/PhQU8
PP+/5hiuNnrwqBmnNLh/17UQEO1wuCfxsRiLmQHMjecJ8NRaVNqcq4a/+Ca/
yDA2Ite2njz/qx5W/4lX2xpxILHUR7dHvhNjvZ+jNAw4oCT94pti5CAz99Ui
SSsC5qwfTe33mxE/m7X//VsW0o7+aft+sxHG8itLFArYUBW0kr52MwHj16Mj
s20JyL63ltgz9QlxYsr3Ul0JEGI85v1ECUzEzRyuvuZAnpYTP3wrAZSW2Bth
pgRyb1YlEz/b4fnuQJG2EwczQoaUI2PFePvPwWWLNAHPhWuT4+Yb8JrSHDmp
zoLeZIDXMfMOFNRY2zv69kOIQhm2/hwP6g8FrWRDAsXREzZbsutgd0WgQUdk
ABrHTOlf5v1hycjX4LtM3uc9MJBh9QWrLobfN5fiQG8xJztRORevTu4L67hJ
oNOrx11AswPyxfb0ezt70Rn6JVZuRTaYonrZ0RYE0oYzjrqWliHZeSDJnUmg
PHPyoVxwDYIvHLR/MNePghUvKT+G20DR4pgq5g2gLzqlVMjMG8z+qboSsh/L
Zip4YjfU4KXvm720PRyk/tvxTpnRBP3nqmM6L1hQ9dpew3SrwaSJhXJeHgev
Vv5x4VCoeEPR/P2fFRejLyQPX+zIheruDbG7e9jozvooJfq+A5ZF31bzL2fi
SMU+ifQhBlR978r8Os2F/5qrD5QdP+D++qz8A+IEklKHA04+KYOGcogl7TkB
Xl+x35wCGv60JuXUH+WgSE35XKRWDo7/s+PjjSVQJPhwcOvZVrAuL3hP+TuA
KzW1oeo5zfC/Pf25R5uL6qPhorPxjej70/JFLZcNHs8pvifeC5DH+Gktf5HU
43c5KQF0QOth/fvxYDrsFulcCdepgOWMyXjDf2xk5piIWvJ/RWm47Jq6twQe
WzQuPJDSAM991r2JH9ng3vrwnDvcDLlTUWoNAQRqvde90FPrRCvR6qwrzkHB
gc2096Nl6CjKWNkjyMFgXKxKj10ePrr2iQpMsPEufdPxvulSdBaNFuSv4kDj
V7rT3iXtiKJ0FRf5sfFpn7uM/g2yX93s0X2pHDBkb/+TFmpGmJSOacReAgWv
/hhtCC5ErnlU+TYFAuILrzcH+HeAObTcsdmPhYhLQmcfBddiWq/r27wBAT3T
blc5Lg3BVIO7wZsGoHt6R+aTw11YHPldXDqgDxTFLK6wRxOkM/96qpD6sRCp
UDHAF/C5xyx54U4gxPibZvJ0B2yoz3g2kuf91KkXzFPdBtFn8YdoV7mIby4v
PPY2H295Mw/fDiKgwVoxH+acjJRnf1YqaBKwtxT7S0ktAlvh7MNVihwIBxNP
D81VQHGxzqdrVQTkfi76xJKvAf/W8rQbyQQMz/iO5EbSYBXSedewmOTF204j
6Z5WMPLuXzor2o9j2uZOwisbcW+/72PPUQ4s9R9ljTb74M1Modt7ch54CgY2
3aXlofz3Rb2kbALd0vz2Y2Sfy6IsvxhUDsDtpst6maQOeDBigvr4OXB/WPPT
pLcKwgy1wwmSHNAkB4VkY3qg3rkohPqIC2V7YkPjgiJkrY0Xf9zEhmK1qQ5d
qAOyCTvW8QX3wcbPQtUmoRfrIh5Ylfzph6X3bPyE0TNclul+I0rOd/3kCmbo
pwZQUmmOzA9cSN06MryG1omffHzqXi97cUi9yTpOno6g6Cj5FiXyfWmlXilx
2TCQbhqqv0Qg+tzJwEVizZBoPHVFPYMJQ5n0vLfrSsCaCzMrYhOgGmtLF3k2
YULvx5qoW1x0npEwTEx5j5FyrZFPWiSv7g+X7NaKxr1fw5fFzAhsSIqnNvu1
orGvT0BDqx/yMfU3vb5mIEQ4t3JchJxH8/j4p5sqkBCQuS2ylQ2fGcPKGqsy
OFhtaeM2ERjvauhbc68F+7do35n51Q8RO987Mc/qofvup2P/JQ5S6GIN5jey
4XZhTIToJpBe37vqiS0VllcKZBzG2Vgu1GcTa90KLRqv6fMHbMjmWtRcsc5A
hK3H8MY48rzWSaYNPY7YP6Xg3ULOa/ei/4yKZzuxU4tamOMxiOL7F+eXOz+D
jLzaNs+zBFbnJ3varaQhzDdw0O7iAJTSfvtKzZG8WvL5eY74AALtbbvq52kw
nxugfS5igWdi/1vnb944xdvopE4+/8PJawG9iVSk+6Tfckzph/a8gtTjHZVY
Lav9Kv44B8WiWVk+lbcxEnIr9p0lgUUR/JvrjpYgbtJwfkcmG67655ZeqGvF
yCwEdlX1Q+KreiTdJAt9jO3HL5wj0DsWKpcgSs7vcu4u7X9szOz8mjPCR/Zv
fVXe7HUOqm3aIspeN+HN9/aR0kdsODSdnxw1bcHlqqwHbfvY0Ke2jQhtLIbV
npoMqjeB0kH/0z+nanDA5rpUVBvJn9CM9WeKO1E1YT9nmjQA6tWn3k9Hq1A/
sbvUnOzfBqVAaSWVMtw7ESkX0sVGsxg15/zZFPC0r/ybT/IjXkb98R2DRHxP
kNkvok3AIeq/9I/30mF32LCa84T83l4r/neNnUh7PWS54XoP7NYMKRy36saO
+yuMVVWGYGhiwNjHyMTk79mPpqTeN/CER55ubcVdrnKcnAHZ3xM2289l0NA0
T7xY+oqFz4eMed8YNCOSyth8pXQAERs1FBqzmmAk1GZ7xJUNN8WvvpSnFai+
fv74kYssLIot1PSQLYVo5ttdaVlsbFKKsZv+U4XOf3e3HaES2DbNczhzcyty
77z8vrBrEK7du4OmenrAaOAB6xwHQgVTFz1KKHjL87f2USCp7wlptyUmnXj3
h3udKjgMwROafhpKnRCKMZTUHeNigcLKh3nhbRjmFd80toWFZz8vLp2IqIO7
hCr/mCZZz08td2hvWiB/I77An8KGRTNTKnTXZ1xTqR6f8SH5M2hqq25vi7/2
szezSH3Zbf166bAcDZesAszO3O+DxkXq3wNOVCx6eOpa30s2GpbJfu/mb4Vq
ykJtTyoL1S7BNa8D2/Ds8grC7RoH8btevwwqasA2/vMCGXpcnNC4qxwnXgmV
kY1iJk9Invg5tn5J6sLeCpnq5ANcJHnbqyYVNmLC+1woJ4aFyIV7vjwvbsVJ
2y553w0kXxV19KYeV+DvOornWzc2LCOnPTxUyzEOJ8W/G1l4zA5O+CKbAhMJ
j830dAJSwde7JU+UojTzrneAOQH+/LklgoN0OGznlH/YyETfX8mRLflV8D/j
HKMUS+6vH/Q9Avp0uEesiiwy7EJf19LGn4eTYSh5yjLhPgGhe/vdXHJKkFUn
2P2U9GM8Ejxjn0XEMaG8m6NA1ks9+5E05T3Jh9UPU7vm+1AgOLjWlp+C9lnT
hVAjwFJPObjJphqhU+sfRc6QfNRMwc6gBigqp0tRw7jQXxtu5zRJBe+qaqMo
Jy6Y4kmvlW1I3l8ePuvb1A+DSd8w/9tf4MOnMZm6ltw/t/pMVQprECnS+G6y
ioO9YWN9T0KoKGqtk1nyvA9fBjMcM5Ta4H1uYL+eLZv0YW9qtqR+wLTHo+E4
ch/nbqlUCNhMg7Gab/jpvj5YmF2wtNetwNNfN2wO85H1nV7leHusEOmM7QPM
ewR8UsRddJYVIlxb+B8tj8Cb2psRm/U6IbXObWO0ShcsnCzHawzq4T8lYtG7
agBCr5bEzw36gRvT9EqZrA+P9cqtFCF/9K1ZPDdK+ltP2gseD9co2KeV68Oa
gH7T60IptQ4kbS98qr9tANcku4YapWlYu/gEZU9YH4r1mxouVxXhxNZd/XvI
5zkujvEZn/iEUxavUuT2ELBcMVw1yorEZsa2kL2kP6waaeSXYXUB1w6GXVFn
Q2jr1qJFjHxIP12a4neYwFrpLVXRN4vwsWREM8CNgyCv6Yo9tnTkhoo0Nfew
kH1Ecvn5vzS8o/abXRFkoXV9h0u3NgMPUHte2JUDw9PRcg9f5mA/v1doJPl+
z8UnXwuEuuDbh9yQ4f/nhaF9jndnq7CMsM6hO7IREfQi11KwGZ42dawqPy6u
Te1b8tCSgRk/qcsHpFj4b+vjiQ0xLcjanObhdp2L3JWH1oSMtMNjvU+aXPoA
JD4IbRH1D0X+2I7NKiSfNRzkcva7pMDHfbfw0n0EDlIl06LFGyEe2/Jo7UEC
7ouPN0nwdoEetcjj4LJejF0Rnv1Ea0SIl6jwOnc2co2oEuPPWvH93un4TOd+
ZF4aNPqkWY2eL6ouZmR+0VpuMX45pRUXrH6GSTOZ0FiS2ikq7w1+m1qd//v3
ZepMOfvjZdjR+UHK9SwLo98ceZ/YlmCmcGXZM29y/9yVV92rHovqwpStfrdJ
XufceMkwoSDASEVRjfw/5aENHBO+olJX7tHXJDb61xV6naM2IVq07tC/3QMw
igzs5p1uxaNlkwX8X4awS2DqM79TKXSGq4VivQhMP2U8jrpaBPWCO18dYwjo
Hmq+JNrVjj3/pruZcnQsd9q11+FxM35rxKgHqbAhmtd1MrOOhv1RsatT7Amw
HzyeKv3FgGaUikM56Xd5kpzni3/Vobbk+jsGeb6CoKUWt6epWG3CnBG2IP3/
i1/rgzveYvnXZ7WTYQSuznQyRJbkY1eY8RGtNQSMOIJXu6xLUF9aSn+eTyD1
YFmJVk4tFmkERWVncTCZxfn9VasFQwH7BA16+0E/iteSzCpoW+07tfQWgR17
PfmPFDXizJ1rp41zCLzljrerejKRbrfdZAVlAA9knIU737eh0vT2scsXuCjO
b2MvFWuCwUf+w37HWFjz2fWbaewXvKhNDLa5yUb4lidWO6rLED8Q0zduQfI0
sT7OSLINuxr3CVBn+9FzwdtIpr0DesmvKLtKB9H3jitxdPM77JRhcrrJ+eRb
zTZgVHRCY9Ubs1Zyf3madE1ozzZi0jnuYu0gG05cRldDDxXNybt1z/4g/cOT
bF3xAzR8GPoW4JtJYPO9u+6KeiR/915IHf9DzkdQRP6pVDpkI2cHGlS+I/5q
1abnxcmYu2Te23aDgMDXF8eHahjY+WPmS8P0EDQK6PUOPhRMFq8vOkzyPF5P
2t94bwT4PZc9XWxHYEnUS8XOOjqufp4/1WjOguKWmsGLwpXwrnr3elyO9Jdy
hr7Cv0vw43M5rXieTebYcUkvvg64afDXNUqQvJDa/lCm9Q1c4/+dyb5G6rHq
VEGvcjl4Ajslvz9jw/mk1pnc4m5MmMlkJpB5PU9wT6NBcgsqY169WDvfD91B
tZ+vPjFgfMK91I/0g5mvt98+eLsOoeZREcGeLFz7sEbRh/TzxPb0fWkWZL68
djh4y41uBFLudFDKB0FEyB16fZuBCx0rmJvAhaeOomX4SAu2uUwqGa9gQ0Ii
7xw7OxbRO0ZHg0h9qNKlTZaPf4DcnTI3OxPyvNmfRXTWt2Nt7v66Ff0syO5v
ucbXUIUsGm/CJz8OHF3r7jznTYS4zgmzzJNkPY7cDhIyLgVR1Tsyu5zAYBo1
a1NVGU4JPlbqPkEgQ1H+afO1ahitvX+MasTGgfaiM265hdgWoKuVSOpZa9Gz
BZ1HCpEd/kvhQjuph5fVayMtM2AGpX1/3pH8pqS+WEOjQ19Ns13JmQHLf3L5
zd/aUcLNdd+RwUXpg/4lUYWVMAq1dSsn/W8p8aSc1deEO7PDNMOtXBwL366o
eJaBsdWByUtbBhCyPTKh9nQFNnpnziVeJP2VytHK7qvFKFMbj7w4R/KV/nX7
Bh1nvGLsn5v7v9/2slqjJ1yKxFXMTzPkby9rfZazZRfk7q7gXUzrwwgryLK5
thQOu2MhU8SGxrjZijcBxVAy/xnuQuZ1WZGY30EaH6B484d3L5nXRWk/TTZY
18Eo4m0f5zSBtMCBo5WldZjmP/nY0JIDeVmXm2Iv0hA5pvmxy4qA1Q8epudU
ORKnGkWDSb/lqHbsd86GQlwefPDG4DvJ67IfWbLddvBM/KlZfIFA/n8h2fad
XRDLnLZSruXgTlLb/Kw/DY3Wt9lCKhxc3vkqfUSwE5XLMgPT/5D5fZnpkLJu
F44LrAg6NjsIqZMRK5u0a9D8u3H8EDkPyWU2h87wtKLVWyY0tYL8viOTTgfL
ynHk5uN73zdzYF4SaU1tbIfq1HQ9h0v6YVbEc1ORTtBdC87bdZD+gDKfuEC8
BActv3vtMmPDvfKwmLNRA6buDIUKrGWBMeB26MHPMrwb7DG7ROrRaeD18QWN
pUiLFN2YMEfuwx3vHXA/DP8edfs8Ifdf2pRD24PZesx9+LvMVo3k1ZaN9ONa
ccjgzqn6GRPo3Kn5xFK5EAE2bvL5V8h+akf9eLIyA7/9l3xuUibwcnCYu0eQ
jsqlTjwHKgYhGj4ZGrq8DdmVtbi6kAPuAqv/Au/TUSvdYinqwQJ33WnXb3tK
IBaX1yo+xUapmLlILV8r5rp0jTbuJ3DE5fjD9KUdiPf4J+Kpz4XO1nDF10fL
cBaBT8NJPTk/EJ+dvtONH4KT25mjBJiNYofE22gQ9SnIUDL8huPrneQqqmvh
PJhInwvh4OUV57hoi2qkiWxyE/cg6x0oWbrG2h/NKfd2m5L9lS3S7IXiZ/TZ
6l5/S+YfUd3BRyc62rA1+tI5oTAyD6c1j64Xq4EjbbYmur0f8WIh332ii/DQ
Uo3YE8rGvw0bi5Z2taCfMxh1+gob6XsVZuixLfhrou4u7MBB/ZNVjNq4Zsjm
MByJX1wEOfl0/ZP9ioV5xpJPEwh0pF/xfz7Qhi30rAkKnYsqO3qz9IFmZFO3
bTMj51VZd3hcb3E16u4yzZPsOBgWCHG/rtwCf7nADHFF0t+XGTo6mFXjoNdO
hWgyT4VYxfmqpfaAKGEK/UqiYYdrK7Hxajd0B7JmV5L5uL+6T+yWbTekFoTw
5Whzcep59Zly/nQs+eVi7XGM5PfowcW+YS/hkjke4kv6cQuHzGAq6feU1jn8
qmIOgifl+fIahQCIGNF+HyL147viZIxATBu46rvErcl95pgs8D3J+COsEtxz
2Epk/ny4i209lAuq6Y3Nyg/IvKJfdy9MvwoT1rPGFusIpBi5/jhG8iw2cQ27
6Vs//get0S5a
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVmk8lWkflnpTxiClhKTGHmUrKrpMTJZBSoulKFGSUBHjLccYS0ykMqmx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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs4lGkfRohSmf2QDYlVKhN9RFPZblFJtZSGSGE7LPGVSUjjlEjKoZNT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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lekbxknKRI3UyCBFY0mMlpGaymWnMmWd0akpYznZ0mYdzTCpplRE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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3lYTP0bxltElCSRXmkRERUtr1C5K0miRQvZKyWStKC0F/FSkhYKJW3S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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlns81NkfxodySZLEppTUyj3lstpl61FZt4iipIvsGNJlk1xCoabIliTJ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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk8lekfRSgzIlpoSlrsU8lWSE6hCd2QvUT2QgaVSaFVKCoKTaSiQqhf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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4ldkfv5XIVqFFaijThEncbKU0H9OoafWzJKZBsmVQuAiRuUmLGPta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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k0VA8bJrKWVEiUpFRaJCFJnpSEhFIIoUJCKilrslUqIrRYQphCEkr2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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8lWkfxlEiO9NYUkLbUMlkS+TSkSU1lgkl2Rq7VlH0GiQaLUrWprzI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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns4lGsXxp2y07Z9lUJFCqFMmLZj2t2knUPIIW1bhCJNxFCSSEcVqW2r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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lXkbNrJECG2mUWGYS4XskeVusZR82SZlWlDZ6mSZFsqEZBRZChkj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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VO/7xylbKomSssVHZa8UofKW4msthBQVEhWVKDtFilAUFVJZIoXK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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81dkbxykJYwlNSZFSoSLzi5tIH0wjRcjYJiVLFArJGoWYSGWkwpRk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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk8lWkYtTYYyYwlFWVU4tbcLA2yHSRJu2LKFpcwZVIkhIxSZuwxDFKW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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8lWkbx0+2zitjSTUjMqKR1BQqGaZ+mDJeNRWJUSqvoWSnLIWT0SIx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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k4VP8bxiUkIUnZEi20ixKSuiWlEkoqZMtSlErZlx9CSQkJyU5IthCS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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk4Vfkfx4nRtbT+ZJTsmWooioYib1tGUtm37NKvLialJi3WtEjDRBou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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk4lekbxyUj0+Yw2RpLVGNLiH5zrF+hMpXKkaKYymVky5aQGUJGlCQt
o2Uw2ZOdsu+7o9BxOI7tvO+baJGKLJX5vfPHcz3Xcz1/PPf9ve/7832UnX1Y
vwkLCQndodd/uy/PvDgrtQ1+gdZTi3tJMMW8vtdn9IJzsXylSzwBF4WIyCsn
m+DYcv0eO4PEvgqbdbd/bcDagi7N/gUSIqUqD3rzmmBawiJOs0nM8uU/mFdX
YZ9UZVPfbgqhvNQ31o95qO74FNfJI/CM4BaYWI7gYo/fzzZ7x1F/QyjAW7wN
qgZnfxp6RWIlFft1qrwXXsMyr+z0KGya41bulyzHLFGrxzCn8NqyLOm7Ti66
xXeeXnYWQOolq9eqgo2dRSq/trIoMDZuW/fzsVzohUROpPhTuO//5TUrvhf5
/+qJJAlTqA+9Z/Xt6iAOrrx68F38OAJ/UD86lNgDQXrGzdLHFHSUjo6Z+JRh
p16NheQ5CpmjfI2gohEwDa6Zp24fx1TfoKZJ2ACsxthez1RJsCalKkTPPIWJ
np1TASjcWiUrz97VjR0P3v1yMZcEZdCcnhBcgnpmxC2RIAqP3jy7ZR75AtG9
gjF9QwpuUcLzroGdCNnMzss7SOJhTcwIw2UEFsJmOfOx4/D1CSgq/JCOq/O6
rQX7KYSb39zA3pMO6fYhy9OnKcQ4rmpbjK7FHK/t+gllOr8LsvNLZB8UlTM6
bR4TSOe8Uf+toAcezhtiOAQBr+3ve5IteLB29BAS/R+J9y+sHRvr0mDWMrpt
zJNCvMSK8VRXLjKXd6j2GxCwZOkYpqkMQP/f6b++7xBgZgPjvNPPQ+A1SH10
MiXQ033JIk0sEy7Po+2KjlHIL7yXnoc6uNlPH/SPpuvRal7OdM+BWF2dTtop
Cho+gn3SpRzEFouzboUJ4BRxqL6z4ylq2lQiWAEUFMd0zr+t5WIiwHbCrUWA
tRcVZl5QBdA845/Xf4iCmctIiU9iDR5dNrL7+hOFYU9pBaQ0IeeKro27J4nO
8c3nGvgNGDSyC7rxmkSc2Tat6JwazHc+W2OtSME3e3/KXuVuHJNhaUcYkqh/
p5knORUFdxG1jZd/pfWUP3j0lPUYmB55lvePj6Pvbn2i/o/9eCt+YtrkewJj
laNcB3UOJp+1iDDFKFRtVEtNmmyF8S2+b3MSBXlJf63IjUPguqbrlJeTiJLj
sfVkhqG4i5senSLAfNPixbgVbNx9vslQxYfCdIlPyde0XqjtMpwqzqbzexAv
bXe9HOPDcs+F91CYUPBJje3koPJ3LYYnn8J3kp2fxMM4aAn1DjomRGCbWGyh
48p+hO69s8boPoH2UuKCJcWFZA3/8eiXcZSsGrNXyuEgUUT/yJNcAtVudh7a
Qz1waFvnv+QmgKOz3OOYhFx4LE83aZ6g6Lzdz5el1+DrrFbtKH1eq6Kp4Gba
hKSMoKDQLXT/NW1yLPthBCxVcvvAkRFUGxbfDtbuQ5aWxA11HRL65etSzmV1
o+vDn0anHWl9necmn9lzUZe8rbjXikC2TRFl+0szZs7axXEvkxAy7pK1VR1A
apSttkkbAR1+lRARnIFFOf8vDHqeo6qV1nfsG8Fw4suTi4sjSMp+RDlY9+LA
8LLfLyEENq1ZlGP5JWJKuCI215bC9lMf7szbDMK6Jf72jg4CcqtnK7lvh+Cd
6LEg607CLDRdVDN3BFe/qrweIMdxtyvDYb9RH34wFiyG95DIHs/+e667Ckv2
YlzdHRSUlovEtfyG8PSy+nuJWAKGZyjGLul6fJh4vj7fmUIcx9znysl+rF4f
7AQ9AYSk9EQKWWzEnPdsnt9JYaFMtLuZ3wGhNoUw3QJaDwOJhD/jY5EiNqz1
43EKSTZ6zm+ucDBQo7N16IUAh89Juy5/7gLHOMS4mEFC8fPbot8De1Ci739Q
dYHAuGvV2YFj2eiJ6O3otKDnScE/t9W0BzEqa85f0KXn7Uig7/7GLtS/vuOh
EU7zRZvFvUjR9XQ9PrNliYQ8rs+9HOVAwXZS1EQgQIyt16CDQTsMfWUVn0yQ
4Gsb37gVykGWmMw30VESay2thXq9G+EmrcQQpfl/5NqBS57kC0waGnhrp9A8
l0hQXPd1COyghaa+QAHCv835uFj44lD2iCiHnqc4plNail4/BsdczsjU0Pwo
UOtPyXgCaUVT7rftFKpXcw4HyFdiYcMLprYVBauJwFJxazYkpyoljO4QaBHT
yE52aMOCTZVmMO0322z46mLLncj2bisNiiHRqLmf2vq5DymR2S76ewiYiVTM
NavmI1rY3cuI9h/uP4fPXrBowyoN95N1HSSi1xxYceRRJk5xH0U0HKbwMNCM
vdWtB2HJ9mdVSwmcmpJqD9dqRTpjn8WKq3S+kWeVa1z6kW+zs6r2tQA8tlpb
vloaBIs9u986UGjXdXxFRHbi2g3xDE2a3/aseyGOTU1YjMvZdeUmCUb+zTH7
/EawywZsA+boeOOmdn/+2AudnNIoVwMSnE+ZrZn3upH2ydlsA0XgrrLSb1qH
GxDAKuu7EUWhcOZkUnpsL65saZyKrCXwRuOLeM7O5wgMKVTmF5JQE37/IOFQ
NRbSnJXCDGh+EmlyEt+4MN47km8jQyK5QjfquE0DwslNaaNZFNR4P3WdSOjE
ATlhDpuOf8xNQEX18HB46h87uT4CJU9kjO1dBzHvVtU4EUtiKV6MjNNrgp/f
0XveNbS/M7euPLO6D2EBSSE+TSSkVc0CZvLCsMAffcmh+Z4UjOKsv+vgbIWh
XbS/iW7Ond7HGYR6Qm3JoKgAb4dtrhms70bFv5u7Z8VpnkisOxdRl4kVPqa8
1TRv7J8UL83YNWM2JUhUiOapkJOKfMPtRPzjaJrHpO8X/vjYvChVjaUdadOn
3en3GJ4fecz/+s/cJyNSgEEpx0tSd3gwcTqq80fNONwcAp8my1UgJMSxbl6f
QnP1XSovfhCNq5IfHmGSUNoTbPWBWYLt1HXTcNq/Hk4ays1rNULjnFKoBe23
hkOt2T868yFd8urdbDCFyMTJgu9UuPCSbd8YaCdA0KWs8hy0ov0vvuzl+/T/
YYdv15b3f4FduCQ3ROv7f03/vac=
       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8VWkYVpGrRtnrRoulJtuMTMsN9UhUJC1ESbKNdCOyRabImqVJSIut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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8VW0XxlGEJI+IkJISpUGGqLikTMmQoYQkRZJHSKIkDUoZUhSKSGXo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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41Vkfl9GQFhQyYUK2bkiSJPrwtoxl7MQtWxMyKkuklEp6NaMQFSoq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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns41dka3kqREo6SRIakSWlcyyW9NChJ4zIjUy4pzaiY4riGULlNCEmF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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4lekXlctkpJMxjahBVPSbkFFyb2nIrQZJU8TQQYwTcolTjEujQk2O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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3cgVf8fxkWyJW1RRIMUSsh6KolCKFSkZGU2VFIhERUiu5CWMhIqe6+Q
ca2La8W959xrhPpqScPv/P46/5zxOe/3+3ner0fG/txhJ24uLq6TC7i4/n9N
OaL8Qq+MjvBjSqeWjjFRFHnPNk2qELcc1HKllUmcMFy21ja1BNxKA1Y9cmw4
ePUfMLw6iJkK1//G+0lo+/8Ua36ehi1XPR51hpKQDg6/fyw9EVkJtmeYh0iE
enulWy+nw/5RvNM+7VE4O6arn2IM4FrmTv69iWMwdN2y4+qddpwUpf9M7iJh
tW+9VoIQA1qyYbsWuwwja3rt87bHnYi2+/tjUScHLpfu1ha40pHxu/m/oQQm
7C7w0xL9G7Bw6anhbncCgxe3GAnpdUD3k4jq/L8RfI6iqeQX1WPE+XRSxgUS
Glbff5+/VARRe9lD7/jYUL4cEuJ5ug4NTWsHYn0ICDv3TJN2lVj3SXYm5QeJ
7Eg535miWlzg0ld+kMjG8Lvhqxtt+3Hy+/d8a/0RWPf77SsOasfWnPFXRTks
SKdJNKazaEhtFRJMucJG2bnibccv1mAuUmvBtv3U905rFYhpNWOBvuPlgI8E
xmbmmzyvxWFEWzo7woqqX/PaRXeHUjG3VejcyosksoTLr+1ZWAMtC6ZaUycb
tb39W25f6cPulrgAl+MfcdE75RlfGB2uR++5yBaTmHU7Yc0+1gsZy6K0a5Oj
eCMtvsLftQmvaGUKf6ZZuOK2QDSsnQ65AYmYizwsjB1IinX06EfRrRDTtTkE
XhTsOuOT34cXy7+Nf2pjQtKEZvZsoAG77T3fHo8jYLipf6tkygd4xjgbRleT
GMy6slXUug0WSOhiBxKI/Kd5gTFRh0kvMWOHIyzQeNeQA6Jt6Jy93cssZ6KJ
c1ZZWfUDfoSgZUcvCa6DY3EG7oXIf+5xPk2eDZdXi9anvS5CVdDq9YnKbFTF
+wu/+deJ0+IHZ25S9+/vFP8heCQVl5TVBb1NSUxK2et6XKuDx0pBdlwzAaXt
2mVfRQYxYrJESSORhNJmq5/3HhRgMH7VVtOzJKLc3vxruN2JbRXxkUNfCdy3
FVWs0nuOuh2crclUvZfMNjk7sOlINtDiUa8cxX4zp90GX9txXvn64c/bCaiK
FF1Z7TgAe757DHuPMYxwfzPZk5OGqhQ3iXP7SYipMcXnTJ8iWXF045QHiUuc
2awZcgC/Fj08dLmEjWXapk93He1F9KQ9LXvwI+4ojd3eOd+NtLIpd7Y2gZ5j
d7v9r6Rjq26hwaeTJIri6e91OR9gKzT7MO46CYvQ6d1VbT1Q1v7VfYQ2iAjN
SQlt9U60Dnsr/T7Gxq00cvC1VBlGLBVnxcxJHHr5iC80pQtT+lJ+V6ZYCIiS
jlw5mA479pFdVk9JBC5ZY7Fscyc2i6x7FFrPRsSpCMsKqQFEZgY8WK1K1fGX
VVX3bDhUMyIFvGxIeBTav3Q73oNMJ7aR0CYCd0xaixK8C7Dq3WdOSS51XhP3
aFp1PpLz7F337SJR9ethuMjBLhhz3NvCgzlofHjII8+jBcJBL41Mgph4sjoz
TWeoEXvd1VIv2ZJYdv5x2I7MBtAPLdx5QJPEKq2xk5GuXXDYzkhV3MeGYmFg
c/HOPtjvMVm3xX8MexboKSY1D6Ax+0g3w3MCDIkAud3GXZDkmxiRMCbx4KrD
1NiCLGRfGL3C/YjEzXkB7l7eGlhUkjs6HhMoSZyxub2qH+UZAo4rZ1mI9Zrg
OTPchkPKy+1uUvM7cXWtk3haIbLlBM5mUvMVS/6sjvDMg/dN/Wh+axJl480G
Pcva0HRE5PN1JguNz0KHV93uQvuHgiwD7iGQL7PuneNvwJ8ka/H61wQ0zu88
ey2rGzFbghQPLyLxpM/xoPlYKfqGLMPrt5AYGf3ypvpfNJb26UybH6Pqp1q9
USeiEIrRx+1uK5KoCxkIkpdioFiCGSF8k4nzEtf8eNYWY/jSzhNzMiRWGJt6
Bpd0o0P8q/F97lHkZYUO9//Oh3+KMt/BaBK6m0SLxaze4Y5qS6zpBhJG6Q9L
t3DlYc5g4snaEQK5mz5GKb5Mx0N/tuzIbRLnBQv4U00KkZHoFb35PYHUIFdd
K4ku6H0Wuv754DByC9zxWagT98Uu2gT/YKKsIXKpGrsaEvuk/jGoedG2OuSn
KdyFxJXEXwc5FvgjeMrTqXlcwc/euFqIiZs6gSz6bDcUg2x4bchxPJLV8t04
0wOiO7r88xwTAb8EeHwie7HU8zC/47pRTHP/d3ZwdQnmuJi7dD5Qfl6WndO6
vxSDciuuLh6i9NYubjIW2AmnhFsrBKQJ+LBW6tDDu5A8GiirwzcM4aeak+/u
dsBnVYFu024SIjWfncuf0UA3fZPltI7ErdecyvUCdZAe7Px28TqBIpupF+az
eWhao6YT8B+Jme7++Ns5VeAMwn5KmA2uFcys6jk/6L8ySOG1J6m5/6jr6/se
jdLp/YY1VH/9pIwqc1pRvVL+rFoyAf51QSLeb2tRvONCfkcbG7m5HX91+1og
fyd5euA5C4Z6KxLjXMrRsoaX6249NW+DgZ6tmSU4r4c3zfkEWpb9evLs5QfU
yeZUTZFUv35v85mya4Gh77hA9lUCtH91ja0JQ1gSIswsGh3DPnWz7grfVsxZ
vt5+hPI3jd25pveMG5A+ld5M5LHhmyCkSt/XgxMyJRv+7WTiRLfQsV42DZ0l
csJquiMw9GrqW3m7GvkKGZ7F3WxI60lK8+Y0QkFBz2m/CgGXNQw3Jb0CrK5i
M69Teu3wWF+aHUyDDPFh7PVvNuxoJVHeQTVoF2oevX6L2m9Vm7wXm/bh7pua
qSmucZhdCCdmNsah+oWwJkHNS/vAz//sl37AepH3x0uOEBjIeDhwp6IB78jc
IXEO5S+6tMTfG1vhmxG0IbKJhd0lFTmniiuxVjO55EUQG/wDEkzVD7XgmXjr
dCGMjZbIuFAe6v+2h8+iT4DA7Vt9EWflu3BrwlRDvZVANd+m1fOTVH2sZcyc
K6j9P3yG1qTWjdUu55LiKT2krNPqVXrSjhl6X6URpddL748Ru152w0x8IuZh
BuX/yyxmAzwZSPS3dFeKYyH+2pUHh0v7UWH24LKT5zgc3r4biW+tRbRG7aYD
YZQesl11vX/V4GV+ZEscLxv3zwg9HtxbAL/9Vt8CHpKoL/llXrCIgZKYqzeZ
fhzsN8/hivzdgDVX9+mNh7Ix5pM1UbGsEpckTq6NqaH0aBLxkrhZhTUbe9v1
WQQCXvQ2XHx7E7qnzEf8T5EwZDomvU34gBmeYEjKkih9NCu17s1HaB67cuNu
9BTy2jyZiTEUDxDfvyVZjkPzWeQaG4FOBOrycIpTRsHY8OjtgkwaymqikqYP
kJA3C82RNGLATvyvdlYR5S+pnq/jipvx0f7Gtiv7WVCT9Grs5uqCqdCBsRMd
LKgkt5dYWPXCNFpUoM5gEh7mzSbyTp3YLSg29DhpDFlfTvQNF1fB31VU4O4g
ATG3OCvxx5k437Jlwt6V4h/9y+OtMy1onDjZ5JBP7Z/88G1rClpQ806KyKX4
iXNBXn20dQgv876FBO3pR8Cl6rda37Lxw+ZjCseFRLS1Ru6Uei8YkdNiP3RG
UXV4oaapexHOThk+mqf4JS9cjajy70D4SePEmHNMCLyw68yn/PBjlJzBgBuJ
wvJTI9Pn6Zjf6Hwo+TuB+gHVMg3OAIrURXX5g0nY7avRL7bPBo/emrqDZpS+
GD7Vzg35WHVsb2fwYeq8r1pt1/1qhOKMz44SVao/Gt2aLLcwGOwQVL9B7Q8v
hcDJKlo9GFpxdwQ2sWFmNdsZ6PUWSstV3BMvk2jJbR7u521B5Z6rXK2RJNTk
vYMlTegwbppo1HUahd39X0+Sf8XA0FpYOoLaF5s3ZtxJUW/BI/MyTmUiAcbg
uNSerjy8vXT3sddfyn9aEySTS+qxL8x5PoekeKX3Y/+O6VzsqY7rndMnkcB5
NGkmPojzSlV6ZygeEa2N6yiYoePjxy9Wh3U5MHyVu9dWuRH/sdeUGyxhg64h
Nvt1JwMyrbbLLf+y4Z/cVmgtS/HEY3Hr5xOU3pdIdgtmD2F4lVZ3/LVRhCvE
xFice4PMhQumL1Hn/TI8emL3vSj8jq3wyqTm1axfJFIvrQbKO6477lIgkDXF
t7IhsArT7T139GgkJEp4btuO07Gat2695l5qnl/bXrDtqMceizNXSIofnu2b
ljBr7IeLaItRhMYouA6pHPFp8MS4M+fgfur9XGtt8hXEzPH5Fxk1T/GVtPe6
5XeF6jFKHzjT0klgKntruDDFhy4TItPPNJmgD+mEHyKa8UW2XfovxX9f1kgs
tVRpxh/3p9bXrlN+E5PlpTJUCUnbM4qscgK7HwxUrZt/g5QuP+9ISi95d9SV
KlyaUH3U5r52LIFbkX2sYYdGRA+r/NOm8kEosi0s1OkoN462tWJT/fokIrjO
Jwy/VYrUB+1IcCJNA113tmPDbDRHlsHEfb8IJfqpDvglb52uU2SBYfMwzW1d
FyYclryt0WdjIW/YfLDiAC6X5C8O/zICtXPBnKrCLoxW3NQvo/p93j9Eb8GW
D6CZjBdHdBFoMr3K4XXsRdNIRCCv40codq/TzWivwonCb71bKF5+VhFryElp
h72rtNFmXybEjjhf1BZhIPTnGZk9piysOOMs/2NlB3xX4ZURHwdPAl9FvRtr
R4l7RvD+OyyUnPR+uSyjEdffz5yOpPh0TEkpr2tBBxoR8sU/YAxxX3crHE5u
QeTRPbyJqtS+kBks6296DuvxyYLWIyQaHy8wM8rPhvr7ft7o8xTfJJT2zBd1
QrMkyjPKhMDRIFElBdEetN3cdN4knUQ6Z9HOtPoSLDrX/2+Oj+KnxIq0ArlG
TLm7C+osJDCSsmdJiU8x3K7LfW9uoviyRzdQK7YBwuec+9kUD0m/r1O1969F
TMgxU14qj9C5rl+RjarFlmdip3TAxhNR5/se7jkwPfBFP9Cbyj8yB44Gu1H+
lB3fvItOYuzc8WR1gUY8uS+7+HglB3aNP/i+m/aCaN9RmWwzAscRY4l9XZ2o
XOJ4vkNqDNKhfDbyYbE4mz8frE/1W6J/XPCVbjskYvgFZhhsCEpalUkyq+H2
dc7GfJiAVL3bn/ADXeD3IIJzMim/iI6/8SXkDVLLDcJ+c1N5lSFpO6RDA2PE
55CF5hjaoycSTpnX4OHPqLIwB4pXHtm+/tHmD9Lmq1G0I1Wvkj9Z66/XY2O5
6o4dPSRSW4jt2vQ+8MkHxiVdIuC3VaV5jrcVN8NXRQbFsFF0N8tx6YNqnBN9
feZPEoETSQZP36vXY+yi9IndbpS/NZw1dWl6D113/apRYzZUNviI7eptw4Dl
piYpJRIuM32sjEOlKDvdQHN+Semf9DAYkOpBRXxT59t0Du7UXjt7VIuGbbLp
L37wsWAmHGL1WZ2G7+YR8v9R/dDe4BT0qqkTXywyvG5cZiNNQctexJ8Gi+MN
+ZEzJDL0K9KtO7qwTOzgkeYLbAQM/Vx6W/sdrk1oCD9YQf0vaynEXBlYtg0r
JSg/jF2mEXOirRPbHd1av11iw1nsnZPdpnIYCfKmLCmneMPjYpDl9lpwa31e
5ebLwenWhD2bqf2mrfH8n2jCMPh/9n3Vs82DfenV/Teo/V5y5VHkUpNufPt+
z1hGnMBgYMWDzFs1WFWakLLBiMD0wpIdCiHdyF5T8jt+cBQi+TztcaXt4Be7
fMLsKsVXLZvfbU8rxaz8A+fxTBKKF3V0Haw7sCth+mBHMwfGlce19Jc3w3Tp
s9fRlJ/U5M89LPtER/0kO+SJAQm50ltBF7VzwcV9LyfrMfV8Hj1vXIbiEZdf
bzS3DaFrefzkt/keLPqt+UthxQhCwtSKFat78NgnkfXsxwhWpd2VKZRphG1F
yF5PJUov6nxFstMVyFZirg95S6Ah7Gt1u0cdSuVHBs+9ZOFb/fIEv7AirDd9
n9JqQu1bcutYkDsd/N2Mz2JyE/BxFi9f4FAErhfjuq+pPK4ixIo6nNQDvtql
fp5fmfDpaOwTYPTAyzN1VDKOjf1qhaNaNV3gljH0qllAIHR7WfCnqWoImR9N
9eKi8q3wbb0cdKAn7Mh3Q4rPGsXs3A0uP8fNStRscCcRi/DV8v6D6N6coruC
4j3NR7HrL8z1Qa7fqf9AxwBmvGVpvqFNsA6+vIRN5eHhvxLcyfMdmOU9Xmc3
TvFEKafUrHAAH+72MtPMx8GwrPWw/NuOxovMADsDDqq+kN5BxSnYrpXmK3qQ
xKnUiEeJToOg3R5Mer6CDWXawd2uS7IxvBIDAVTerPJ4L7laKwM7dzS1/7Gg
+C8hVXrb9V44+x5kO/YxET/+o//hDQbmzSPTbf0IcA2aZtSya3GA5R5XU8VC
ZgRDsufUB+yPFEr4G0HCeErj6KXF3XCtzZ9O6SBgFvfcaqV4BlIfnt7VT+XH
yUvOGi+y3mHbe85amS8kMq2vdDtwd0DxsN+uaYqHkjeqOFZsbsSn5QcaT1P5
uFhMf18jGOC/brXkoxcHPqlG4yoBDcjmOjFrNUnihogH+DLbcavu2VTSShLi
m59s+vunB8py8ynG4mOIPbrzteqDASQe9ra19OFA0GtRqJ45xQt5C48ayXNQ
pOdf/Me9FZrmT59SJcVmFZfYrTn58C30fY3VJFhvlyyV9q6FmWRVy91VJJSP
/3g1s6QXCl/WTHgv5qCdpj1m+a8Msad19i+aJNC+acWunSvaUffeX141n4PD
e9may1iDOM2l45IbQuXjSZP1y6L6kHDmbNG7oQFE/FUPWWxDx98qMnTtUhZy
pdboSf/Kxu7VqnNOFK81CtTynE2sxB+bdHYTxdOzgnVnt3DlIJMnq/ppKNU/
/l1+/gY9aJJ0c4guZGFGoN/5SGkD6jVqN7Mo/Tne1N++baIeoTLbNLcFEDhm
ZD+sdbYWjZU/jxoLsuERWRcR8aYYofc6ammU3xVlvz/3Iusttn/mEUmi5keD
T3XZ1riXuPWhJ+SVAsUnbe/i1GhvwB1yYKNcDolvJTeDRJoaUHYj4vctSh97
NZ4uHj3Yje447inF2nHc8eJWjvLuhjFZaflGcRSXXZRVXo8yQP/nlN8iNYL/
AUnKEMU=
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk4lekbPoVSZJemZUgYJCJLJjO3nVQGySGRGpXSZsaSNiQToiyHNjvV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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk8lekbxiUjiiSiMTWUpUiWrJnDpUgahBgUg8iSTmkdS4pKUk2iKaNC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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lWkfxk1JkhxMpULJlikjIkxjulRMTYtSSaQsqRxZjmmSrVJhCjNl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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VW8XxW9l+kmIRgqJiggpIVmRqUKGBiQklUipJFOSKA2kSSWZSaaQ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8ltkbxm0VZRtGSkiWMtKUGUQmlyjZs0QqlYSSYhRGKiRLGhoJIdmy
JSbKTpYSyvba3l4773NeS2goIzXS7/n98XzOH8/5nM91X+d7X/fZ4uRp7cLD
xcUVT3//X/UuOV936xxCaWUH19UjBMyjY1+MTwwj3NB+IluYYGFJy1PDJx/C
nbl2/JYE9urt20NTajHpqHN7zyCBg46QaG0dCxvtlr/1SHBQbvm7k5hLCZ5u
9J9X8iMY1XPYM8pfAVZJY2/vQ4KXQa2JBRcYWGg5dzLpPRuWiR3223Ra0Pru
ldudLApcJWK9BrZXkTLLsLE8ScDVsPZOjEUBljJ179gdIBDTCtO6/IAJcxWX
8StNFOoipK0ULIIh3yF/ydORYP0VZi1nXR9E2kRl72+m8DFbplMyuwlvR0Yz
/Acp7DLXq49raEUzg6f8aS9BwsF7kvu1X8Nqu6JPAX2+vfydbI1tPYgeNpjW
7SYoHO1NPLpQj3Il7dWW6gS5aptb9HOz4PGnSOXsKYJzQu5FUXqt2H+w/9dq
SXp/ZoxL7u4MWNoGsn45TxAQOsWtkv0aI77XN6+fJKijkppybMtwQzxaxPcQ
AalT7g+pasNHMZvhdxcpRDufOXPPsAoh80oOs+MUpFmz7SY7OmCZsLW6Zokg
8tD0aKVJPbL3pFcHZRKUPs5sNtMegvfCp+lsjSHUsISPGNX2o1q48ezckTEU
8iW/MhzvAmv31KRKI4WgGRGDW88bsOR19+LIDQKjwk35to+qwXRc3OAXQ+tb
lS13UbcTgzuaKpP9CVh5EcJmcW/xc8S08hN7AjmeA8E2jZ1IV5Toz5uk0Frk
r+wt3IKNk2fTgmk+9NSslKZMchHKlfyXpy2BYnBxxi+uTaiqmBBNX0WgHqEs
9uB5C1jqFin8tL/vxd34+fpasCLE+MHqKQVnDc0AbdMeBDSIWRpHjiFvl335
B80anI7Pd55ZS+t9dvqz37dn6Dm9cp0dQeCMPKetW0bQs3jWKjFoAM6M//i0
LnSgOlz38j76flvjNs2ofO8GF//l+HXW49jwefl57dEWeKgaiXSUUvAZFh+T
CK3HL2YFRTFCNG/XCx8f8utFsHh4gIwehfNcLipfrvUjtmGrb3w67f+/PtaH
Lw0h7MmXFx6iFETZmp0+p8uxR7ysT9yBQPRDyThjtgdX1OZW9toQFKwxH5US
yMHeP6cHe80IFotVB4KkGLh1ZMiLK5ugy7ze+7hHLarr/KXfbaP9LlwOWzEp
g+fDGW4umn9XqUkXzwt9+OOJpc0PieNYHt4hsc2vDyv2wufvGo9Cii9tvZPH
EFo/ZK1ZIzCEkNYB59TiF9DNyx24+TPt/1tPj9iLvViUeh1fosgG3wnThMGr
TTi7tv4+8yZBUGOhaAXFRIgv4/jNOQr5PYH8xs+6cOTwmuCdORTUuptHj84w
MPrSQec+Xe9S85RXqGIDHMWcMn8LoOvtNst6/G8nbFbUAtl7KMzlCmU9n6hC
j1JLF38UwVyd8QPR9224vW94NozmQ5h94t5PTb14ZmRndkeQwmHlj9afsroh
v6TvsrWPYDAq8dWduQ6YJKp4rVenoNyiO2TPzMHb2d+mWM4EM1cfSiwaMVC6
8fGC6hIHdTeSvbmnWJg4e+DPYVUKXaojfxw+1Iulb6xW6Zd0PsyvZpxVYCKJ
96iBZhoHch0FVE7vAK5pBs1actP6a+8+nT/Wgt0FFqwsdwoawm3nfTZ0w+LC
q0dOj8fQfEzZT8i3CKqmG1NNzhBUfXRYtSOuHVR8w46tHAp2CwoyvMosKL9o
V37xgI3B5IU2t4xKlBpec+4QJ2Dvkx1gsNsQwLTpieEiqF570lh/8DUWdFKT
tI7R+SOwkhtuX4mZiopP2tp0vpSUb95zowcpX/1fyrhzcGVU4vrVxTbcHeP9
cSehMHn8ybKgYD9SR2b2l8pysLhutVpoZydW58ryd/5DQVbONe6GGgMZy7Jy
5do0vzm+fkOaTFiee/l+ZYLAMPLi6vmYHvzobfImMJPOA1ueBEmkw/Wcq7vK
cbq/nTa9E6Wa0NcaJ2ghRqCcVhAWymwHsbP7Xs/LgZH1uoexa6qQ7LPO4KYT
nRcdd/fGRiYhcr7vXAidD2PTTFI834bz381lbT1pvpbLBBN9ouHNxV/zjeY5
4dWEAd8wA87LGp3jAgS/tzkYbhcuRKm4hiTDjsDfd06OhDNxK503Jd6fDa5d
9cOP0n3Q6P/WtozO24Snct58Wo1IvzqqI2dNYBkUP3KptwPKGffHFSLZaFIV
UCve2Yc59QkpiWsE0vymaUL1rTjmPasXNUCQuT/d+f2FN9CRU9li/DeBO/VT
Veb1ckhKsEpilej+5z6fM6f7FrGpfvcGxgmKU3ObvNraMWCnsFuKnh/6h/k/
KvD3Yaa9k3MwnMKge+itJyLRcJn88Cmarq95UGb6u2QRYv8jwTwmNK8qPb82
hPejwSOg/CE9r+Z43ZKOykUhO/Dy94oTBJoDfVOtGv2otI9wmvqL/r9f/o94
rzTUzHsVt9F+KklYKJYHFCIgXMhMw5xANzFdx+PfXjjcl3djHWQjevTUAxfn
v5G0HLw50IcgQ8M9hW1I510MI7uomw1fddMriXVMRG3Y9z2L1nft3Sn/LGkm
1FvSzjjS/IX8fHtwnywDjN9ShGcGOMh1uy/zJOoNqjeVpQ/T/bZg3t/36e8a
lC2UWxvtJPg6FakRs8SA9ZJB9ecDFATndiqrJTIRZBHOmxfNQaHG5YhnEe/A
k8lZDusbQ4L4PvWQXd3wi8w33dpIoKVgXWvm3Y6S0KGTe63oeazvI64XN4xE
R1MD/q/DEFZa9cNkSAUSDUU2u+oSTH4+JH3qejGCSvTzza0IliT7uYlgG7oK
TcIevSQwU9rCcyCgAWGtc1krUxTyBt+zX0t1YVF6Os4xmYJ8bN/N2gcNYHB7
x1ToE8QmvWJ/Ue/GOuWLby4McdAsLC7gOl+K1YJ1rbzGBMuB7VFJeg3wrLtb
U9dDIe3E9ofPBVrA4y73VWWIAtPv86l/VLvBrPbvyKrhQCbVifFXbiOCzB16
RSbo90uq4gehomfYn3/w0RFDgv8B0NfF6A==
       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4lekbPjioCGPSNKiYQkhEIS23mEEYRD9Zs8SEENNUkrKXyhpiFJWI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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs81NkfxmdH0U4uuyjR1S01UULSzZNWU7upaHRhSxEqKipdrEuy0qiI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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8lG8bxZGkkpKlkqRItjapZDtEsqdFVEKytwmpkDKVIkLZQhSyhlGS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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8VfkfxlVEESZCqEhkuIwlk5bxqAYR0bUloyxlqcZS1nZrUgnZUnKn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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk4lekfxvGToWVooTIlTYliEI2QutE0Q9lmrCkxEiWNFH4VkzoJCTGy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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs8lVkbPQjxUUppapSUJEoi97Tciowaim9qktukC+UampoKuSRU0qdD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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lG0bxidaiPpQihY7IUlRaHGqUOQtpJRkKYSsIVtJKKIsJcneniUh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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs4lHkfxtVah0JCqk2WyLZaYmsd2uUebTlFJLJyyGlFXGUdSgjVrkQr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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs4VPkfx0lJDNpqkdtSQjfVFol4C8lSRMhtN5F2VWSrrbBb1rplZYmi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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lXkfxo+aspQY0shWo2yNka3tpXOHslUyTUQhGlvRgmG0CWkYGinR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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8FW8bxkVJi/JLKJUoSVIUIalLhUpIKoQsWSIKZSslSSFUttImKUuS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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81dkbtiVZRxRNiUxZsmYJbU/ZRmmZkS5jj5KJkjKWUIRqUvZCliRb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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns4lVkbxgk1OzVE0ZitJKecRk5JuEvqk8NEDokyMojoIMLXJyGTplHK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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8ldkfx2+2JMskcimNVDRKi6SSfIwkjcbWaiYSLRKplLSpCGnIFS4q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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmGk4lP8bxS2VUqTQpiyplIiElHIkSUJCiyWVpZBUSkmRyJJs2WVJKUsh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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk4lWkbl2RphCLSRJLkRJwUYcrPKFFRkoykj4REskSylCXJJyEHqSgJ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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk4lekfxm3TNM0hSwuhDinKxLEUabn9yhAZ26WsP4xBkSV1BknGNqdI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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lWkU1m3FEDGKibKNNJGEIvWoqdDCVMpUQpKKEGOPmBhqkrF3G7Jl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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VO8fxadCUqKVJEtJCS0SkjpIWggtsiSEbMnXGpKyVFS2iqhU9gpl
i5B9380wZuzGzJ1BpbRTqd/9/TWved3X697P8zznOed9ZO3+O35uPoVCsZ5H
ofz/V4r65dNHiVdQ2v2+wMOSwE8O/7j9Mxrkq2IHWTqTGFAa5GOf7cUXQavl
7QYclNjxFK5nv4BUSfNJNR8Con03hiyYuRhb5icx4E7g8n/tP/WZg4hb1D+u
EjMGf+OJK7oCdPCcfDwDPLm4dXTbMtZ1KuJjrmeI+nJxWTHI5EnXAIg5MaGD
xBA2RymZLP7QCJ0LCz7X32Fjs6TQCW51BwSbK7e/phJg9agctW5mYqMvf2LO
WR5MtdddP3ZmFK07JS1dgifBn9xkp/KdgWUWY375gxy49oy/N3ZlYG9RQYus
xDjyDvpHbPlbB4eY+qfLThOIXPdmg7xeL6QIm6Cs+RxEpu4UN52uxcWPDBOz
DALfVs1Td5ArRIIJu97Oi/w/Zzo6kFsLXQ/+ask+DigC3h/mid/Co9M3biac
JfAhrsX416dGuKR6s1gXCWhcLFx0eq4Lqv73RmJrCEiKGjoRQ/0Qvl8n4SMw
CW2frc7Snm8hcDH5jwofgQPNjGBKSi8s2sIKt5Dv1wob/67ZmIkrRVq9MzoE
PHo+eO6yTEbn45OfXzsSeHgbBuFnqyF42VJLz4SD6h254irTd1BvOi/xmhUB
S2MDEXPBQeiut1Fe2sCF6EIfkz3/6vHoMs+HlcCBu5PQoWNWDIjFrP5m6syG
qHLPZdXlJVgDNYmepwQ8P5jM+3miFmJ9U8ZeiWwkRfnKjD2lkrr4MJPazoNh
WpXRLbFu0LYcJqJWcGHibb4zfeYN0sfWnpX+x8HrTlbXxhY6dv3Z7Tu2mIXp
N/4Npwka3ml+fioUxcafinNvVwswoFXygS50koct65/Pn31QiMySsL032ghM
mgV9Ojc3BN3+cPrZrHG4R1I7K/2okBn//kBZZhwUaQWDqzkMjJfES69S4SIu
tme0PK8Y0XOauY4bCGiNDTOtLGmw9Aps5SvmgRfn7LBn+QBSFWd+F60hcPLE
XEO+PBN/7UpTLy8cB/VNZgVrVRY+n6DORZL69th26kvBwnKUjlyKaSsksMXc
549kIB0SEtPTfW8ITGuLeMry6DDRUvx6UIGHHXKjY83HG+BadTsjjMlF96vu
0tIn/eRupry+KNCHvIQ2vw2/m1Dy1zdSTpMD/4oRpZ/r+uDz5aaIvTkXGlMn
ju5RrYW7VMXkn2EClGzTEwsmXyC4uexY/34Cf9pKGQ73MpEvtXwix4iA9iu9
mhPmIXhCUznXbE2gz18gv96oEiOpezrElnGRJztNC3EaQXpgYJHg4DgietMe
GMfSUFHWEe65fgIX4yNW3btNx3io7O/Rr0Oonnoyb29OLyL4n0+0GnIQvJJL
HDZ0gY8d7b6mDYH3BnOVSa+6kep3iX3SggfBuMUXDNqpWD3jL3dMZgITXou+
3d3djZzsRbMVbVyw2ILx7tFVSNBpp2y6TYCjIXpW4ehdJM56PLx1ioDM5P3l
ge+eQo8pPG/pHgJUb/5BytNKvK55eqKwnHx+Rnh03KQOD9cf8vt9kI104ber
fgQPweqC9ybjzVx4xerkiSgxodsdOX3oPIFuG80TrWn9UM1//ib6wCC+mcdV
/hVvhPxcQtxz8jyX1bfqj1QxkZh0Xk9emQO5t1Wz5RE9sC1KE6CpErAtsPSp
z7GF61xksgC53mIt+1dLXlGxsXRAO6WWg32rHyR+92pCZN0Zte33uVA78P1H
2VcqWhbKqDl/ZkGcHrCKYd0MloLWA/4kAnfm6Vc4k/vfpblA9s35d3DptnOg
vmOC1RltHjs6ivlqG4t2PWOi3akuM5c87z+SFWpjTc1wa6YPSewgEFykO89F
tBgr7yZI3iPPdzt/dd/Vyww8K5L7GOfHhuRvwtknmI48o2P/9s2ysffb9KZj
nB7Ii1EOOr0l/W7/hHH43ABkQtqViyRGcPLX6l85W5kQOe+2zuLtAKxY1h6n
VHuQyfS4P3KOC8OfD/abUOhYbhgS2DTNgc7Tovk26nQIlDnveb+Ng2Sat9eO
h+1Ip0auzLnFhvYcXZaa0INtRJrTcD2pRyn69sLip3A/7rXj0QVy/jf7D4mJ
vYaAQkZ/rxLp34lFBlv1byCZyqg7bkdg3p8OopH000HGXq+LaVykewv8ffG6
BXIaWaXGiqT+GJEuR8trIOw/5jmuTuBQaMtSPZ9BHJ+jCFzxmcBM5yKK3cc8
sNZu3vuNQ8DETaXlWjYNMgqmKhnk/Np759KpJcHQU5/1+kOeJ2XF3gGh4TTI
83W4sYIIsPnNHc7/q4a4s66MjTSBzaOjqvf923AhJlTc1IkD46+m9vN2UfHr
VtfYpqAx9CkK+59UoMNp/dZGtUYOfl212BYi3QJD+iHF7WJcWIzq0dlCsagV
bkhKJ/23zPK7tnAxHdtj1zv0kvkQnPGn86F+Kj7Gq/0TMSPQeXrkSLApmY9X
wqK0r41CUHKIZx9Eg8iwyUyAxzhW9ss1yCf14IZwwCahpHHERGpOpiyph/a1
kP8qDnNRKXLsq4IFDW7pZocGjk0gz+VMk51uHgL6xHclk/crLzqw6X1QETiU
Hxm/1hMo9UqWGL5Si8YIijoZuBCsaLB0l0mAh6w8w9OcwPolFGWnsh4YVpzV
3ObNQ7CjclizjQ/M9W74VZ0h502wUyj63IGXCe9+jwTw0NeUIbzGoBobgrOE
1O0JuHoHqSTcqMMm7+KCfUcIPJ+yLI0N70eyrp1gyMkJfGs94vJDmgqV1GVi
PXZcaJfEBlyy6kOKy7uNnRIDqDXi3XyAHghaLiTVT8CwMHfdicxa+Ou9/DM1
wsGTZ0M35BtrwWsPfWa3gwt/8UP/EsLyUCzzq8D7MQHr+wXf7UXpePFva3UK
6afUxH/iM+IdSGx3k3ae4iK4/MezT1mlcHjGarMn81lUK8XzVt4wVBO2rnWX
pcNZRv9ok3MPYnvFQ1Yc42G6JLvh/PEW3G+aVji9iYvo7k9Lv9gMgbX6SuQi
Oul3ryyH0+sG8XzpzXF7AQKO2erXTQ92I5HKeT1QxEM1IRNedjgDDOpXq9zj
5P5TxK4v/TqIMwENl/LPMPDPut7uVt8Q4vQk7yyR5aLc54YhW5cJl+/sbVuG
uFB6VrLb+MMgbj7T3/HcYgQq6cFu3x0HocqjppYq8RB7t6Z+qdtDjDXk5p9x
IcBIal9kt3UIXfK9g4v9xzCSt7Pg0jo6VrgFrVUXm4DoiuUN33an4G6ipXiz
E4EZ++c+X7sq0CTVPHezg0BsY55+pBANpyTCo66EceEnVDjFF9wP+e+P532V
YsNZSU+p9VAtDm6woIQ0s5HjXN3Zn94FxcNF4rNlLOxzKkpbJ9+Ll2dCqltc
yedf1orEnqPjvppBXq4PD9Yt6p9e3O+FRi/3n63aGGyZcx+FW6uQzDfgV2tI
YKqlpXn9Gioy9xxQ7189CQ0DnfiXNb1Q0v7kS1v8Dh/nXM0rH3ejMsVgzct1
bDSaT7W7W1TDY87gT5Y6F5SeCoPkoFtITjT+uNWC9IuMVjysaQKlTUr6+kYC
43fO7yzn9ePoqSmdzX9HoZ+1Y+ScVB9OHX5f+Jf0zw+OByxCPJhI/Xphaegp
LlQl9g3t6U7FlYo59TZdArw3LNfLDnVobdx+vov06+AQP+PNRfEYOarR+eIo
yQsX2prkzdMQO5u0TZ3MoyFnbkKIfyOMViUG/JLgwCO5xuT30hpoJiRqZVK4
0KMrFs8/14QHB5zr9kVyoNyqEmbX2YuL9fU/+YbI8z3e3R9m2Y8AU8+/U208
nFyTvVGV5OOfjEL61U9jiBvXqnBJqIP2kc70k7EEKpp+r91Q2Y/SAxrPMga4
2Na1QuOBHAP8bUlHMsdYON7lGyf4hImfi690JyVNghlRcZZi04s7SzQbxbZM
4O9KkQTv7b2oXKPEeXRtDIKy1lnz3haC0JmNCc4m1yOU4pwv3oq+FQorXh7n
IiR8qqNwUR80dmV9c944DkXpF6KUVd0wWnrGeypkAguPp+An/xCOr7XwWeM4
Atu7qwbrlVKwYNJkt28gyd9HxKsvFeZi+7mZ6Msk/8b6/TosINIINw8tbfOb
ZJ5U1MYXzH+OFx9GZZqvEvCxUp/paW/GgTwJ5588AtcS3WTPG3ZhVeKkgYQb
F0Y3cjaUZdfgYZBhxONNpF9Unat0Mx/FtKdO1YDaJzyJ+ztnZUiHwUWprf0L
Sb3UBOKCWRTiP9ee3mVLQI7TVaQ+0gXargXh9MdcHLkX95MWxsDk9KaDdTJc
fPtq0C62uQPl2kWsjodcyPA72+z60IctW8xYNUZs2FJuBSu1tyBn7FW+bzqB
dpvTF4iIMkTtPCP0XwS5npFS/SmNVyhdEnlvuwPJ55MpZRHWDPROOloGlJN8
Xvt3yX8XqkE9WtAgPkv2CfEW6t67vUjOfPfyfNcYiCeCPmr2zSiTaLnNKSCQ
uGtbzLbVDFwIju71j5mAfHiz3FgvHev75RiGJN9VL7tyWPxRAt4feaMia0Lm
70TRl73zn8FZuWWz4DmSd5RL8r0X5SI/95PCQj8yL2xf8n3WqgclJWB5Uy+p
15qasr+kX1rv8dU9Rea5aOIL2TPF3bAy090SLMvDn9NfYl0/kfloI72Cj8KG
+IBTZGNQI14V3OUySP5vL5BoDlFpw5hkYGWnMYEOL0H22YWNmD924bcOjYv7
sd8/LH9RjdWzmT1RSwjELOksfEUfQoVp+wFZPy5W5xx5qRzWiODAYzX1AWyy
l/bPz7Slwyh+XbFuLg/m8WZR7jwaCLrCiQW1ZP7nD7xbzscguVckTX3xAPK+
2Aa4Kmcje9WQR4o+yU+9MSlX0xNACc9yrvMg8NblY1uLIA2XnJjEk0EuHKxa
nHNu1sM1qvNdZAB5/78kp3zPYIKG7BL5UbLvZDu9eXevBWoiVh/WrOIiYrz8
P6ZIN9IX/L4z/Z0L/a5Pe9PiB8EJ/+q3ZjuZr2XaWz1sijEgWLtg1pn8PktF
ftebNkyoRan0rOfC55Jll9n+ZqhcznW8Kkiguevut1z1HqjUZs04V5L7tz9r
d+pbOoob2YZvYjmIt9lk69nNgNppvZjhOwQCdLYdmR/3Ftk0t7Jpcj2L7zwb
ezrcCiF7F4m2laQ/XWWW7E2qwVCXsIZHM4Fqr4+7xUqjcFdqJ/97cp4IYdWW
SbsmjEZeMUsc5yBa1SXK248GWlrWzMNnXCx6EGLaZzAAM6ukjEhfDly0xE9N
GXYi6XWgmAaZ0DKxzSVpA+mIDVEsNzUg4DudmekcQIPJ17mQXO1x+PwIy0d0
HdjLmd78oVxsd9Xz+TI0iIIRY9Hc48NwKxIecLhchd0NlKw6gtSnwM7Fn1X6
oX/A52przjg0Wq07b6h0wmVz7GPVl2NI2dS7Y+HtflRa8qmmbpuAx/kJa4ZA
Ierjb/GvoJD8nH9oaDqEiuqZomFpfTYOH1pSwXnai5XcVRetRoZAqdK4/e9y
N8zb9rvokn1akBLqWxrXiSMKNmlT5iywuuWWOsdlIjv1pshJkjeXbJY/zr+4
GgKu5aGjCVx43O6tpSj14lGan2NmMhsU856/6TZ52E6YP4hRJqBKqQoSYbaD
70AEU1KNi34H13ellG7kFX1Y8Libh93hK5KEdNOQemCsd6EUgfQT83dpRtFw
ixbzMCGVgJHAsfeZZ2pBPVn+6sdeguzJqk87cpmwO7hC2rl/Eu15opI0ct/c
83jmSmQfzpk5vi+quB3FLgydQ3FcHHLz53ikvCV1U3DHVJiL6hy5mbHoPMhm
NRhJ5hEYWRn6a9coE7vXf/RO+8pFc/xotUxAG5bOf/ooWJkL28fLlfsu9kDT
6L2VjgEXcnosxSdTFbg27al3U4PAlbSMO4kOfRDhcmKU6Ry4Ncm+XpjXgV87
VhNT9STvhL4Y0U1rRcTpW7dyyfx1v9u4MXtFP9xH74jYhvGQ8+b5dIFTF3Sr
DIuzb3NQcC5r5YvsZEjJO3z2Iv0n00sr+hKjBalJbYXZX8j74rU/pX/NMxSw
NWd9ThJQqw6cjJdiYMnzutKHqmRf97zGyj+cCarrZ31+kmds80Nq1+2vRrGN
9/PZIQ4iFwmrTS1pQKEr9b7ydR4oO67p06YvQCb6gq092ae+UTtV1H0rYDZd
pfujhQPbPVIOA0OvkCn9vNSXzO/g2UpJ9dAmnEnvymaS/Sd4wxeDwZfV+Cgn
+HJ3KOmHFn/TzJ+mYPmyjzFOjuR9UHAuSlNMhZF+mNfyEJIHTkapGp/sANuQ
70TEyBg2hzdkHqvrQ+JOUUXuN3I+Lwdm3OJ2ZLa2VLhvIfBC6YnQqrRO3Lav
CZHs46HSZ9389RsHsCws/W2wzxj0xvdvdJgsglll1EUZTbIv5wTstZehorOk
z8psPhvV5dUhRFMZBhSfPLHKIfX9J83NJrMJwxHf7GhHOTi194efI6sH0WqU
o2vOsmHEo7VHbqgBdXjO3IzUr52nlMJMSjF0FYMeTC0mYNxhrxtX2YuMy7+4
P5lcyF/ZMVEzwYD1lrThhtRhJOpNXGW9I31238WFNgQHDiPpt89vpGFNVfTH
zocEyu+dOrDdvAv7ZkJiKk04UHnkf7VIpxuyflscFQ+PY9qxd10P2acU7r7g
D93OgVDDbPhrMl+6X9EWy5B9OXOxl2KyYDsMufe3bHLhQsNRszPrAQPyu3bs
3JQ4gSVfgsbPp9Cwb+SO17pNPHwIVW63+tsKPvfosGk2gbiEjLlB+UZ84Raw
n6wgsC98o+/DZQNIYifbGm5kwoH1r8VsczfcKmfWVLtzwWf/lpqdVofowuTx
VJL/Jiyu8RK7mnB7wGDhjbUkT6gsnbN6XoSc9ojSlyQvxL7fOWIgQYOg3j3J
jg4e+u0+/8cJpeNJT/2p2DVk/7R+KM14cQsRx4wGksj74B9/pyXcqBWXnmrJ
RJLzrG4Y+Gn6qY/MJROv1dfJvnO0mD9lpBuqldYXL0ywUJ/Z5FtHvo/Vtn7a
VIyDpHHPksAjVFiuex2VMckifcVgPJCvC/Rj7vbSJJ/HVuWsNA4dQuvgHoXS
oEn8D6VkIPM=
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs8VFscxScKPTxLD0mTUkpcJVJNLRVClEJKmG6EuL3ETVKJXlQSCYWU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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41ekbxhExWVIo2yRblKksWVLciMmeoihTYVJCKEKIRpoUbQijBU0L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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns8VPkbpmLstqXtilapVitdtCWpxcOG0IVc2t0fiRqxYSoVuVSyiawl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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmGk8lH0fxSVuSUWyV0hR4kaS0h3HllJIWUOESGmxtSFEi5KyJ5EtsiXZ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41VkcxhUmg2nkYbRoUJIoS2Sk5bW10CXr7RYh0YhSKWFUTI+lqUQY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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lWkfxg9lEN4Y5oNJTaRokgzTjCznQt4oWl5LJSH7W4RQKNTYRQ1Z
QlkqQ7Zwkkr2LRxOx3HswjnPkxeTJVGy1PvMH/fn/uf+4/f73Nf3eyk6eVu4
CtJotFTq/HP7aEd9y03rw+Ge5lz1qzy8pjnb67i0Q8rhkYrXOgGXPL+WiME2
eCpP9pdLkTALsWXI7WtGs+xB8foFAsYt15XSyvqwqZdbYKXPRxlrRXj+Ywuy
oq45CL4jEO/9i+2/NvVjd3KgurAUAV+1zVaj0yNQ3ygauvzuLdpfrwf4tLXj
aYpJscxdEkRO3pGf9Vm4rHeTIZdPIlfqSeOkORcDMbWWGW08TMqfqcqxb4Pb
ctjHqnskNBSmKq+V5qP+vd4d7/MkGJetajJ6OFhIKKozvsFDwsLzL479bSj2
eS2+eJDAiZ1PunakPse3wKWIaCUSZc6RgoWJ9ZCeGHzgcZ2Ey+RtgYzVEYht
KP0jV2YYOclBYkhJhLaMpNBlF+r9sF/fYMszXHrnyNy9RMC0Jd3V9kgrVIwl
lFWuEejNzmstvM9GoJPRSDZBIHB9gAmRGuybIWvGz5BYbK7eYC5UAAPPWT8t
T2r+GktC5jATo/vvqp3rITCarTJyfPdbhFtbF88Z8KAxfCVux0wxvovmDr9y
JfEj/T2Daz8AhrVP5zljHtoe1q6ZVbZC1l1hgqT2KWBpZ37u4WI9Y4SlGETA
KyIpJll/CPUXZpyUisahZ8DuXWjtRWOwPGNdlw8R89h5G81mbArwUco6SSK6
ouiCzVQ7VB7Ka4o8IbEt+xSvI2kEtlc2T7p18KGQmTO0utyNDjlfS6MpPpR8
fd/UtrBRs9lTbLqZj0AzTvS8QjdOfdRni2kQiDDUSXVS7kWor4JSYBMfkoy+
Zv6HakRpvlQO+0Kg+XNXshKDhR+WBD75x/Nh5dpbcIvWChiYxYs7kTAot0jz
2/4IFhPWVRxqvnqBCzP/kW3HGyws7xAgUbTJoveVRDf+3iM9kTFHIEO/XNt/
axuYZvU5N6j/orXYHNvDboDFx8rNx0oI+Nukb/kwwMZydPo7ZzoBBR1D9wE/
LnLykt2CBfkISiqqidvWg3cOGtHm2gRUaB2ZZ/c1gb7YSG44TGL+Sl9XWtkT
lIXdvyBzjkRsvXC5tT4HMTc+qNl5EzhXebz4uS4T2qLnD+k+44OrT08Mf9aH
yp1j67HU/jEX9WomlTowGxu1WD/GR5vUY6fdQfWYz7lS+/sklaf5cQtaRzf6
VRzYnhf5yFm8PvZSqxsp3FnZdXMCnyLvbTw58hZ0xTLPgLFhbBefDp1SysJV
r2c1JSdIsIeqU03X+hAZdFvCVo0P49FPFmlijZiNsfUQSyOwca9ec0p5P/60
OZ3qH0agzWjIJ9GuAzZrEUuifxKwn+LEh3f3oOyImN0dV4rfa/cJptAr8Bt+
Zwpb/5N/51sVEXVQmZFJcRwnEKxtxrnXyMKa3EpfMcWXnI7LmdtuA9CcNNI9
Jz+OQJdVj3STNrCwSZ2+lcSWo3vbpH/vwZdKWuJGLQK00DAPfcMuSBY4huXZ
EtD7NjpbujQEiRliTUmVjxd1HaEJd0bQZsi10tDmIXtn0s9GnEH493y1mDhN
QJVzZku0/yBmi+xWTm3jgd0gWHrh1iPEE+6sPDcSK5w/1UxVuHi71sda/YuH
hYO73QvmehF7a2vWZBqJcdOKbPHQJnjuxVVJdRJaDObX71e6Idou+khehUDH
un9J/oYecDQbWo6NEbgh+l9P/atcRPgaMF00qP88dHu79wsOvr5n3JsUJWBw
c6c5N6kLEkXFmnUeJKpCDk5Xr3FRKaBzenWNjxsRj4euNFvBSdrc9N8OlA/i
LTMXg7rh6Tf7qiGUQAzj5lLkHBfjkToWN7R4mFG99aCzl42H+Ue7fNwJ3K8R
0q1LZuHTibinKt/4EO96clhG9ynF+YJD4SES5+rSm3xqGxCWabkotkqgVXqX
6mPaG3hW2JX7Ub72ifigo8XnwLw4oHw4gQ8B5ZI0O/c++LC35KbO8XBTX5T9
94EGDPcwDbZakahw5FUOK3bit+gE7pggAfEhPT35R2mYtI+praL4NFayyveJ
TIG6a5xJqyOJ8PRLJ/afHAQnMkBGuoUEaJklRcONiOw1zb49RcDZrbPYLnMQ
35ksWk99JXC2dHU+zuI1FEW+nvB9SKCsS8LEy6oUwSm8H0VDSIhcD3fu8+Wg
M8WkMXMDAY1l/0Qlx374bxm6NCfPR3LcCwn5oB5sf0GXDSvkoe/Op18EkzhI
/fLAOM6FD/LsN8MHs0ycLopyVqH89djrdL/t7UEc/6vwgIYDH4Z7kku1PN6i
zED1TursOE5EyY8crekBTWUbt+Qrxd8Pd0MK/27H/gK3UYtTJE6n1eiYXgwH
3UMzaA/Fv3d41Pvg44MQPPvwt/wCEubHCQtJBgc8o34hVVmqD10U7I1OPkCA
kDItmPK/Z31nZf/9AfjGZEysp/Oh8Ul5lHOxAz0Xvc5PGJBIja2TCE9rgvn9
bVLXdUnItEb1HxIYQG6qNDPJbAy/tgfvaPy1CSZebPImxXvuFGHt1DEK1nOd
av7Vd5A5ynofdLkLIUmiwnepPHGeO47vHW5BhONBWR0+gQn/AxsZ9U+xU9RZ
wucPKi+skL8Mp5NQMXG9WsGehPI+yXWOIpPq2f2xxyjfitvXTj35yIB/1QaZ
LUdIxLyJXhZZ4UJy69qM5iMetOMj03Z5sSAc1LFDSpMPr5Ls9sJGNpR/2f81
0JPq3727Nr/48gA3HTimk7YkOucS1L1PtWLkp8TYEMoH9EvCc7Grw7CR+zlr
5NY41JbcE1budqMiMyp91xkCbJEDn9m5bAjRW0tUOXxUqSvQX//IxLTnjCX9
VxLvr4S8nDg1DKEpp0MuWuNY1rA0UXMdwMtdja5WE6OI+fhTTkNrIzZ6Rdia
lVJ+bu383Dk+BIZi0fZeaR6SD0znzEg0IiC1N/PiWwIiYv97EUKvRvXyinxc
J9U3186v22iykFsvnO/nQsA9cVgyb1M3sqwKbKWUCayfrFs3f9yLqO9/6JGj
89DBGmjKWuagi/HheYAfgf8DGMTR+w==
       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lWkbPiktNChMKhktxjIxMU2T9UKS+kIlhEZSdmFSaYzGviRyrGmG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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8Ve8fv2WUUkkKpaQoCclIIW80jMpOSGbJaKgoKpFEyUpIg5Akqm/I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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lWkbx5HCSJ0aU16VImnG2AepiZ91piGFsi/ZJrLXSBQp2RpM1rIv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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk81dkbRipSNzHpUoosZakkaRQe3ExqKI1lkKJsiZBsTSqTtRprJaWx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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4VVkclTLpIldUZqY8e5FCZihmWiKvkopeSoooI67IGAmjlDA9iCkV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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k8VH0blpTCU8haFCopikqlUpckiRZUqFQqJEkihTxZKjyyJVtR2UKI
yE4S2RmMbYx95syMbCFbIu95P50P5/x/55z7uu5rkb1+19CCm4uL68oSLq7/
X5PouzIjB0oxs0rTVGOShZCP97vlolsxbTbib53cBU+PGNevSQ04sWxy+P57
JioKf/BQTzagzvgM79L8Pqy3vbxaXeErjFTb+Hl+EVAT7ih8fyEZf3nyKiRu
EnAvKHCxff8N/rZfM3samAgZZ0WE3PsGkeqnDM/nBMIeqfxefrwVumphX20l
CVDfBj7bnpUOM917vMUsAnOPFqLkB1oxrKjvV6dNIEKZ24Gzrw3bCj0algz2
gMdR383gRhvU3hyjqTizQCm3Dh/NpsP9doDXB34GdI4s55/27cTTPiXlmQoW
hj1OVcvWVePCZdbeGUUWVJ/OS31fUwX5ZQ3DJwYIVO0+Z9ik1Iq1uSpeQ4ME
/DYFPpQ2a8QwdTPdkWBhXUJGnqMjBdsi7hhumu6Ddm3/XRvRRuRpJRL0yT7U
9QrGvi9vg9xcP2+fVCdMWUdV8hpbob7Nxa2Xux9JGeK/F3m/441lyBSrnsCK
9quHhvdVIqE8fVgtjsAyz+G7syZNCPsnuM1eqx+fKscYfJdSoR6UIid0n8Ch
E8oOv9zKcDv6+bErjgRo++t+BG3Ox58oY76mKAKWXLpMBad2vHYSOW/z4QeK
pZQ9iwra8OnDEHddfCeSNi/EiIlkQuP5FCfsLHl+jZ3r3uZqLLcf5m2nEzA5
PsUXK0WHxeMrGQvOP+D+It/xlPQ3yJVFuET8S97Xjg7o2J6DE44rNeqKmJhb
sz5644VuyL1NVlNYOgCBz7Jb+GK7UKngo3Es4QeMqBaC7mkd+BE2qBafQUee
R59rl1017tOtWXHSDEiEcvUv5aZj5t/lXxyOsSBIb55ptC1G6bO3azQvEYg1
HwtemOyAkViWjaMpE8F77ajp/o3YmvlZ5sblPjjVp+WndGaCo2JUss2LwCwj
bLt4UwycddNHYUmAIab3psSwHiXilW9qWvphI8rc+6i5BqxbnIyonSzwJBn9
vtxZim+eLMbVDgI9R1soc3bNuF7/fMXHnwTmnx1dak+lYOBa8E53bQZULmxQ
pC5SsHJhlZahBQcG/IJvQ5NoWGrl8KSayYbZfyepV9wosNd4/1FOgQX1L9JP
3gi3Ivtq4IMwayaW1UJqm28TttV3nuCV7cOkycmrKRMlSPIcM+ZqZSI607Tr
SUYtYr3m1jtEEBBUUJvUKcvB2MhsadVxFtTcb7l5hbej+0ToQKz6EFqW71vx
M/k9loms9zgfToCLHmrZ4HUNVza9K/K+SkDLsc4px6AFTuLyKQ9L2FBT8dsc
8SAfOXnegVd1SL6v3Kp6+WIWxpuqD03uJhByefcV6dV0qNkfn904yMD81qMK
8Y+acNvDvH7yDAuxD3zebvzZBNPQh/9Q3RnQZZy98DaiFTnfdmTdimNDMGJ/
AG1ZC/wH4zKEOSy4b1Ed2bP1HmgBEk5Hye+5v24Fp/55E6i+O/uUd3EgtaNb
wY9Cw8qN7TmdG7qhf2Ca1hiSBbMT6v95PSLglfth2+QoFYZ36k82nGAhanHh
9eGMMiTKm0rEkPhyrQioaZ1/i4Bk5nDcZQIHelyEGu06cXgt3URxDRvq1Du9
Mrub8Znzyk3yORumDTdT8wZpUHAJXHF9IxuzXiPebo658BCPincg9WBs2Qeb
uqk3UPp3FefebQLqzQ+rrp4tRKmi5ZO0QwQGwzeEbotqBo1KlZOOJWBX52hc
m92Byf4FnebAIURnl5+5tSYP2TvkMp67EBgzcRW2syhC1lud4u195P/HnJ51
kW7FNiqt0iCKAa6N/P5P/O/C0ebz+AFyPjVXelf8eVSCjrxTE/5HCWTsfESk
ClGh/UnW9G94H/60pTkPPGiHBeHh+2asD0mc59veCX5H2/r1RBE/GxHZYqG7
P36Cy5aOz0stCFwcrLi4VrQdrb4y7xvz2WgcLSnp2k3BvEC0Z+MTNiZOXtP1
kadCVs536G0HGyFDA0XxPwuRl232WSaBwIZbvTPCtzrxQtG90VuOIPd3o+Ds
Cgq87ur4fBoZgCozUM3EqRSqm/vKdFIJSFhtHdlXm4sr2zJ9/E0JNDm37a8M
7EKU7Hj4+sMsBGm1L7NdHg+x5ATbNDXyeUuxT4kowangeM4eaSbsFm40FJ/6
gJKrnLoakv+N1+RpootNqE09Xz72mQG7NdUDNxRoKP67KP/gxQB8euN4uw0b
EeJ2vPXgKQ58cgTLxkW7kGTdekTVhYGw+MTA5186Efk4dUz+A6kfSl9fLoo1
YXeb+bu52j5UFUe7O8wn42Jvmf8TWwIyBRf3pwnloeCddqLYMIGARlUJM6l6
+Ckv9stYsRGtc118ec432Im8cxrjJf3ySPq+9wHtCCm+sCXHcADB2zIpkV0V
sPwv3//0KBNBp92cbOWLcFHZP6GgjMBAmNITq9wyLClbKldgTkDl5IbmxTMf
YaexxvXVHgJKfCM8v9XLEVb07eByDoGvjoWt+/bToctfMPqOnJfshZP3Dh7s
hLOOw7vgrEGkOs3aqNnHg/vLlMHvhwQSb4qA7tkI71IN22Fyv6LFBQ0K+1Pg
+6KjRpTka+oSQUtPaiteWkXIfif1U8Y3fNvUUDq+OzNKd0oQOL2kM+BveBXu
qutbJV8nv/e4ssl6rzJwPGLHlDtYiH/HVXohIRs7q/4TbFpNwHzap1ZLsxIt
YnHV8mksrJUzelVR1Ar2nbod2Uo/0FE1rqu6m4bj1o3779r3gyt8wjnsFwVP
PTREeUYIvJqJqEl73IK96bzUank23De9pJQrFMNv9UWLxh0E2A8PPDnQT8EO
vpBlTV+Y+BvfK9xY2whKXsorlUUmBH0tttxgFqPpQDjz90ZSD87/qvZ3CoPi
hiGlADMCNg0yUn65VdD0mG6IXcWACO+dq/eFs9C3Pj7AahULm0YVGMPXK3Dx
SI3GdtIPt8xvkN01VwjJvXED0qTfzWuJTMzersHvpaYdVBXSL3ideK8v+YaC
YEVpfjK/2LWt4/J0S4DSaZe6o1oE9sXSflRspiA1blxk0IaB7zYxyqs59Wjr
SYKwMgcDtXzv+dh0nHvVOickxoZO/Kjc5VfNqI6YHhrpYsJ8/lmSVWoGNJjW
ihVWpP5QQ5ZbFZWAbmukZ83DAhffQlDCIXd8dFnlfOEKgZJnQQJB1zPgxiP5
+NAMEyZtf459/FgMH6vcKZtjBInr1DW9/e1Yv7Br1bJ+Um/Wb/SecEqA+XZR
yZcGpP93CQc9OdCJOwbrDsaZM+HnHdhhpdSCl3miWw9JstBoFCPsmtAGdhUk
+f9woF/RnfyI0gLePPH7jssG8ellnLbNYD70WNUFIdwkfw0+CjXW1CDzUrmY
wXGSH0rPCguPNOHV7LSVtCG5z7aPXz9MikfRLi0Be2cyT4jczuWRr8XxmjK5
Z7oEPjHuc31ybkOXRXaN1QMCw0f6j5V/boHqjJVOtjELJ98NheYntyNH2pAV
GUPyoYyfL/lQJ3Z7nldOZrERtq82MzuiEV7ZVUmt1xnYte4hq2AHDWPScbbJ
4hyUOC16STW349u9Dymi6XQM8F21YKRS4a/2IV55BRNdf2/Or/y3G+fGtuxR
ESX5yv1GIa2zFo+7nsg/u8vEMzHvIHmXGqw994WWEsGCyrzuapt19ajge5Hu
uJoJuvau0vLvVPicjjj78hkDWnJb5PnW0uD0kGKRLcIBtXQgQrK7AybJdncm
hdkoIpYfkxGhoFDqaKpeFhN19qvsRc3pcG6LsaQvZUN/f/8OFWTjwhvexwfJ
vGezc/CF+58KHPDz2f8qhNRjN/p5W4EOyBQ1etRVs9F30/R+eXACJIQyKZPk
/IvsDqsl+H9FlF3YL5NOJvhWylpTA1sgoZJ3aYbWB6nnI5fWkvlW27yxaNN3
Joo7VvsM1HfAlMvAMNmnC7oPl/EL6uZgeHhJpMoRFrpDki2LVVvRsze31m+e
QNeplYHBkdVw/fRiq8sNUs9HfTfK2zagVHzEw4nChp7+ZcurkSVw87OoC1Qi
9dI33HsJfyEmfgec0e8h+RsdI7kqPRFUT6HQ2Kck31sulTYUUEE32fkfq53U
8/dPI/ilm7Hsn0CFme19aFzteG9stAK6KtpHznJIvsb/m7HicjVGTV0aPC+x
cK7S4ohGbzNkmmv/mQxhgrquJdz3PhVOxh6l+EwgaFhs5NFcC2JFZO9UzXPg
NOdsmUnQYJ2amMVV0Acflc8tF9NyoN6vKrJTmYDTKTlxm4B0zKlpzquQ8++i
vtos7dyCMeGpsc9zLJgwZgu563owHzNd7NcwhB3zVZu9Y5qhcf2cwtktBDS0
xn4aScZj3YX9CU+TSf53Np/kjk2FCrXRyp3kt25wBF2m6hmCyjcr/fh/Ptqw
bdeEPuk39S+6zwqxwfUx/L+BBBqGdH8/fhDLRJ9evLGG71vUJq6Vlief10/U
ubDGIQVqbXfaxTaR79O7LpfcRIdlTbRYX/YQVDY3c7VG5oEiNlqtIsaC025O
SsHxdtgJDNDyyPy4Mzl4SNuwCR/L01Y839eP5ssRS8Smy/CpvdHB+hTZt74u
q+c2aoKcTdWIQhrpF+NGxP27ZTANq5nlkHnsyCVLLnu+ZpxafkuCymAgYqnx
WZ/vKdAz3mRfdpHEc2wve4qgYNeIbumACAMtBq8yvX4moyi2tmENqZcK1qPv
zwzVwuDUgZOX3JlIc1d9NnqBDr8vkm0MDwItaYOvp82qURAwzndTifSvSr1L
nN9lsN0S5hMnT0CvzHv/zHw7eg4euNHPzQLdt3JAzLcC+6wts4TIvmpJ2XKG
TaXCwOX5hVxuDjQ+pN12Eq2EfabmUo0yFnz1rZ7bDzbBPqJb+tddDpQkth+X
S28Do8WzfweFCVNjnsfXfsWBOB6qOXqHgMU1y0jmHXJ+Z7YL69wlYMYt99rI
MAVdK3+OFJN66vc0RjHqHR3G7351K/oyoE9ZMlnX3Qyxocwej3k2wl/eE6u7
WoUA7XD2KkUmxt6bfHX8lgjjP5wPk6T/6y+kS/552Izkl27/alpyoDAuH3a0
j0b2VuulhrpUcLEFzpz+E4C/z7R20cl8xaNx+9rBtgxoNjnc46wnoF2p/nO8
mYY7odYvZa04mN43tHbwQDtqp11sxuX74Rq9sux+JQ1uBX8DbEm9N/un7Ojb
vDpET/iFf49jYni82Kv3XCu+FGYKf7ccQOkB0w3a66j4mvbu0X3aAJTMMnUT
RDtw7gV9p1Y4B6X6h7VNUIWIwvs1q6aYcP+ytbPtYhNKdUyyZ4TIvhLEIu6K
52AySvVhPtkv+9oJ2Uf+xbj+irdwJelfykK2RrfOdeNpTVKi+ac+PB2xs4nu
pqN/j1KXHq0NSaI0iFzPR9dEeOAAuY9545GW+oepoJgJTEefYELtfZDv0WN0
nLw95fOsYRD6cikP5lSo6O2Vd+n5wkI0mULtcpNQQksWe0niV9K7XWnRzAPx
U1sPS5D7w5W2R0ggvg5KtyaMxVLJfhdAM5gyaMeRE65l65L70HbvxnKhglYI
ZCpXfXzMAk0h3/m8dyuGW66+rGxgYW7hnWu0fzWs9IdqvMm8rzLRbJ/1uQ0X
2z1yE0N7sNLpZ/9SxyawI/bO7bUm82tQziH5iWIE74+x5jMi94PP1bboTB3M
JQ1rXc6z8ONwh+eBMiri8m6evLKRhd9XXNeGhDTCXsjX57VkPwRDNFvtYuoh
6Wbv+MCXDetNmgVu7RTQ+ZVKej1Iv9h9Jtn96StkmhPavDYEXjSk64VGtaPx
R4H+DRLPtoh9HNH074iUVOedySXzaU5K5rROMaJYGtP4QM7ne/llzaQimJfO
LG4h98tpRNFldX0MjoiPe0SRfUhw4dtvobUJKK1Kzg8m+5bdeGt+vUMOXP5G
xqw7Q+7nbppaMjIhoxX6reUHEwO/+H882duGmrtjamWh3VDJcZi9wZWIgfZv
OTUkHo1akm/Y5SE4b6G6Ip3U1+JMvd9SO2nQUUrJkOAiEPzo4CGbigwUW59s
Wh1M4qV9jFV38wvs3uott2MSWPrecTvjXAcoKQKGapUMLJoqUs4bd0CXauHt
lMEEV6/AfEdOLGa5S3iEyT5013WrTJ9OJ8JUN3qcdWTiYr9mqG9cF87m6++d
ahlB6tT3P4kbPyCcyyryjAOpp9Yl/d7mzYjneXB74TULffHdT47mvoKCuuKJ
bHsS7yOCE3P/1aCjpmRqSS0TtBNuY046rdCh3Di8mkbmNZ6Dvz7fiYeZULJr
jzsBd/t/WucH6mAsndH6htQfHV9NJX/pJtJn2td2yQ/g3Li0TeF4O9IexIkP
ke+bNa+wlu6Ih/Gq1xHqJgSyzAV6BdM70H/l0IaT3GwEqc6aHFV5givCv3j0
LxCIDQz8dJGrFTe6FOzbckl/8zhP6TlXin83a1LcSHz6sp8tRkt9xl/P9fOO
kWRe8+CVdUiuRkVBU+rwKSY+Vnt90suiwvlr1usjX9hgr+PPdUpqxC5eG+OZ
JaQf2Ut47eTqQaTWSPVRU7L/8Qdb9SZW498x60PJ5P8mPY8ai3XNheZ28TOd
JD8mRCN+PI9ohnz1jpefr7Hwj576ijB7CnScKbYyh8l5zBng/OZmUEOqo9rV
WJiWks+bGymDq0yOX38hE0/vLlS9eEDH43Q/sX7Sj2RuxkQuqW1BnsTVuG3n
2LgXpL3F/ycFzJTjTzVkyHwxmziyR6MCXo8+qAjWkf6s7KCw8XI5rnnlp2tf
ZmDBn8+qTq4D9s6nE/w0B6DDLrQ/HPAVuQ2Pk5eChTe0+Z+PyT4z/rH6yUlF
FuwrBbQsbrXDe1GqcgN3P0L2X0x8+ZPMX6EROqnbWRheck7N7WclJuKzdtze
QEDA3b7ZpbwaRnLlagxPFsyM9vjzpTQjbKpcKF1oEAJaSQphi23oi+Bd9lGq
G596TvOb/sqB8NsVk7fI86Y2VxTKfcvhKuQoNurDxAbT7+8l2I2oS5fiEif7
nY3tkvHMby0Q7I46FivLgbvC/PCRwA48lqrae4rk36keZbmn9wpgtb8v9kwK
gf8BSlMmsw==
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk8lWkbNipR9s8oLShNgwopjTaX0ihL1pI0IVIU0SLLSFJKtiRkX84Y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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81dkfxm+qq6aF0AymGkrKDDGkNOKhGEuT3CwpFVkqka3GWEYhU0pZ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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8lWkfxk8SJVqkRpIUvai8llFD0kVRR7ImTTQjJPTqkDhEC6a3RaF0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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3kglO/bxUdFKUJZStbSZsmWUsmhCCWhkihEhFKiRb4thPIrVLI1SZJS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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81Okfl1BDk7PIbuXomEqSa7f0641NRTbkWDmKRVRsk18S2WJXsinZ
HJ1C6yimpcIqkhyR0MwYM47RMN/vIGaRe137+/7+eF7Pf8/zft7X59H98cyR
AFkZGZk0av1/14j76ZXCvS6ERjkeP7GqH0PZ0Q85AV3I77o1uqjbC43Z9ZdH
RRysiL4oeWFIwtR8wkwmuQj0HoV/950l8Tm9IkBnsRYDXk++XLEicELNwn5u
aQ4GFw2WJRwjwZSRf0I79QbadKmsfh0JR+PxrPEGARROz8WL/iUgk3tlbMe+
WpjqyrP1TpJQW+2iKe3rgrOzT7HrNySqfMqrSt3b0fE9bTv9TC9unXByZhwQ
oObuff1W017M698ucCj8AA0LnYbL+hLMsIw7OvurUQJ8E/cTieXTV9vDjdlg
sdbenlxH4lHKzf/Ya3PA4DydzmYS0Ap5LJgmuFj555eIQwkELJVrGpempWJK
U7940Z/EJ8ncWPoQHw5SI9dIsRhBjt/rKXHa0BKac7HipQQT9zIHmM314Ki8
txpeSSK43yYq790LJMW3WxgcJnGp7w/RHh4frZsmr6cNieGYE50ysCEPLIau
7KA3CX9jP++eyXcwTzas1C4l8ED0r3x/eDXOzD1XH/Ul0WPMZ6w6+heK/Es2
rDhFgiXsy1NZEEBotELKuChB1YHKhd64qxgIyWNE/Eii3ftFQNiyMty3Lijw
o/g3smLJ7bpaAQWOv4JhPInj85P35CMaceGI/IRDmxi1BlV3Wq7WomE8uqO5
gcC4d9uy4QUelAMC63UVSRyUXLle19uE/oeZtIB9JEYPk4sMtScYvdLKElL3
DUDa23ixFfNWndplr0lspsvUmZl1YcGlfP3pgyJc14UwPpqLz9faNC7WEDBJ
iTHaSxciY9KpPP5eL0b3Co7b9DXAWBOCJScJaG9Osw5nteK3Iq3lgmEJLhRK
H6SoNKD6luKBO7UEmLc9fZfTP2FLELFGt4p6/w+OVxcu1CFa0yTrIpeE81t3
Q5dwNhLsVKF6muKrNnQj36YJB3l+0m1LSDwc9k7slGnDmcNKk0FDvRiwkgtd
WsmB+Y387XwRgZ6c8VLl+We4/Dh3wNWSRO57k2jPxlbMnq/IyqT0jXZV/9p2
dwR+188xjqT4HUsa8b22qwsuSiGlswwRFjWCXPu+70JpnUy6AksCN3fb6m0x
PHztEW481ULC/un+GwlDLbiTOGn9yxSBW8xd2ROB3Qg7mbHb8+8+MF4fvpQ9
UYBTC87b6EdIGDS7scUp7Zjaz1ZR6u6B1+/PvXKDqlDxUvO3Va0kyjTXahxT
zwf5qH+lLOWX7LVx1+QIAeLuV7PmBsVITv+Qsa6zA6Nry38++agHA36uXJ+B
Svyqbif3sYTS70+rpGGL11BcUi3ymCaQq2na3pDciqRvmVvj75CwfDchF1L6
BxzXlNt2e5GYN3vgc0oowIh3wuO9EhLn2jcuY61vR9QEx6miTYLCBA/Wb+Yd
mIuYEY509SDWtPGUYQUH654Gd3KzJPgYrnho/xIBkrc7adXmiWHhHJ6hHViD
Da7pwtlYEuXyplzZiWYosbSS1IoI+CgwDWmcDgh/dT/JCiFxTUBfSV5og5ju
6Tb2O4n8/OCjCw9eoXizruet9ST2SIuT3ow1Q8fkxZSSsgS7j6ZmfLePh+qr
AdeOT4ph6qH2hR7OA32nwo25OQJsy66EHVoNOKiakbOknkBltJ5TwTE2epp0
4n4MIbCO/21v2DAHUSNxyL4igSixfrzprw8wsTJxWJNKgDHvMCibxUZmvkbZ
BmsJZNTZP9z1z0PA6plVFm4kUj4LCy3sniGFUbIthEnlmdu5fHCSh+4VhV9t
jyQh3GN2YojDhvoW0dZ0NtV/XXPaJau5cDc4ANW9EtSWrn7h/agRMmY3DPPG
KHyxJm9mDTsgCHxpfa2awDI7v2n5oi4E+qqFHnpHYCovXu5pay0M5k7ySp8T
aLIsX+aq+QoO8T26NkYkMg91r1CcbsAVpbp7E40E+L/aBFnufI9qlR3Rdyk+
ec/VqjY9qEOM7nzqljcU34/3qu7Spvy99LnArI9AyyaNvIy3TYjL/Oe8iT6B
Y29f0cWhXFTV8O8VBEjQY7dzrvJYFRI/ZD2wp/r2cWGCcj69HDyORe38YxKl
9vVNOyq5MIrcFuG+RoKi/nGNFlo9FnL6aS4gUbzbk+lAY2Nwzc+JdpcJ9L07
+tnWkw1p7PTrwUGKv4DJHea0ZHhd0nRg+pEwSSWFP3nkwyTkcPN3VB6jx7fY
hjLSwKyTBisfp85LG48sk+dB2y44VJvCLz1qlvM0gYeGwlU7dM+QCPqL9t3f
G9/A3OzOGbsvlN7kV+Y0ZS4ivV0F17kEPFZGOlqNt8LtvXR4XovqU5ezpI1s
I8x+Fp33iSPwdc6w8982RbDXbOHXUP5U27y4Xc/rE6IUDQq6c/oRbM+R2+Be
g84ns2HKBiSqfZ2GumM7sMf/wFmvUDESaWLDXeXtoI0Y+nrEEHBUDzIS32Yh
Ss+mSEDhv567taphvgbBW2/xOVRfBJRn4axWK7KZEyLdKALRfTrS7PrbqLf5
EBtN5dMndURNtZQFa8VSNS+qD6RWt9+pUfcxJr8R6i2h5qOJ/io5zRfgkwoT
YdS8PbcoGBb11SHVv19qbUxC55xZwuEUPibeJs30UngKR9xy78SwIW4f2v7W
nvLLP7G0naZ8HKTHbPzsJkF2YM9nTYWPeHloddmfzpQ+3oQyr68Uc+PnbhZ6
UPg3eDlsK+biveW+/fbvSfzX1qmMOVoCrl55l8CJxOBpfpszNV8/rcvMvfRB
TPnMeYSpxoFIJSDUiuKbH2ruPbSbh7SohrB0FRIzBl9MDCzL8MtSXksE1Y+l
WHzmd5/K35ep/dbUf6RTblb55mQbLN17DBfP9oIW9tWFPOIljgwMyWYdJGFV
VPdaVpWN0fibK4/7Elgzs2t2VsRFU3DyHsO7VD90ns93OtQIuYH/bBqzpeZd
0YWHia4lGJpRjlErpvxVvPzhL4E3YX13PuYE5TcX2+wnqp8+Ipv1TPd8MQGd
/Obg7obXKGPm5577lsT/ANhWx3k=
       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs4lFkDpxLRjYRVKtESckklm/zSSCrrnsuSNHLJKi1ScomStC612qS+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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4ldkfv8oSxqASMag0bTeSvWn00aL6JbfSJoykwhSTJCIlaxRJlsQU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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VG8bHlIpUglJRJZCloRs5ZaEUpKtsYSiopCflCXKlqWkqLSQUlFU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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlns4lOkfxlWUqBxWJ0SEkOTUroruIUkHSiJWSRmt7SDaSLFIjtWuQymJ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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4lWkbR5nRTpmyFZmTDLKUGIkfkiSETplG2YqyjEiWb76SkJQ1Gbuo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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8ldkbpx9Z0nJFZipLUWkzlaZk+1omUjK3KQwjjMlSsoUWqYyIREgx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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2kglG8bxf2RFEUikoRokUIJpToouzKVtSypCCmKQkWWFhVKEYpShFSI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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk4lWkYxoWkhjKWomQpKqWmkrms3ZYcZVRSRJRIqBA5SoxINLZIJJMs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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk4lekfxmUpCZGuwrQQskUY2Sq3LBOlsv2ytdpJg0mNtbGUpkKSQbZj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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}]}], "}"}]], "Output",
 CellChangeTimes->{3.5457410369795356`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"ListAnimate", "[", "circlelist", "]"}]], "Input",
 CellChangeTimes->{{3.5457365134379044`*^9, 3.5457365196155148`*^9}, {
  3.5457404521168685`*^9, 3.5457404561568813`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListAnimate", "[", "sinelist", "]"}]], "Input",
 CellChangeTimes->{{3.5457365039842873`*^9, 3.5457365084770956`*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`i4$$ = 39, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {
    "\"min\"" :> {$CellContext`i4$$ = 1}, 
     "\"max\"" :> {$CellContext`i4$$ = 200}}, Typeset`bookmarkMode$$ = "Menu",
     Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`i4$$], 1, ""}, 1, 200, 1}}, Typeset`size$$ = 
    Automatic, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`i4$368611$$ = 0}, 
    PaneBox[
     PanelBox[
      DynamicWrapperBox[GridBox[{
         {
          ItemBox[
           ItemBox[
            StyleBox[GridBox[{
               {
                TagBox["\<\"\"\>",
                 HoldForm], 
                AnimatorBox[Dynamic[$CellContext`i4$$], {1, 200, 1},
                 AnimationRate->10.485760000000004`,
                 
                 AppearanceElements->{
                  "ProgressSlider", "PlayPauseButton", "FasterSlowerButtons", 
                   "DirectionButton"},
                 AutoAction->False,
                 DisplayAllSteps->True,
                 PausedTime->41.84345962631049]}
              },
              AutoDelete->False,
              
              GridBoxAlignment->{
               "Columns" -> {Right, {Left}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
              
              GridBoxItemSize->{
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
             "ListAnimateLabel",
             StripOnInput->False],
            Alignment->{Automatic, Inherited},
            StripOnInput->False],
           Background->None,
           StripOnInput->False]},
         {
          ItemBox[
           TagBox[
            StyleBox[
             PaneBox[
              TagBox[
               PaneSelectorBox[{1->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns4ldkXx08lIVMnU0YoKpVSQqRc+lYkTRlyq/h1QUlKZNSELhIhQ7mm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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3lcjO/bHaQS2hRFCG3oixZK6EQhfmiKQipJSdYkVIoQJUnapE1RSbvS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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk41WkfxpGkUoQiDGHIqCylQum2vCQkoxjbeywxbbJWskyUZRwjKkK2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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs4lFsDxYkiSRKpdAq5pOKckiHSwlFRKCSS3KKSSLqJyiWho5DcRcol
VD6iIYQQM7k0GBrXZuZ9UzF00yGk835/7Gc/+5+991p7rd9Wcj9t4zlPSEgo
iRr/n8WbUhbMG6pDuFWhWNAIAdHMIZXV4lkwP5T3SduXxKzP6kJWcifELNdP
nfrKx+PTmqmhZa+h4kIPiZwicCrYU/mFZgcmE9PU16YSEGg/c3zZOwCrlXkG
yhlcSPgEhXno1iJH8+Pc4FYSrmPN5+aeHYNLq+EXDRcSfgGhO1eEZCNH/7hS
4B4S+0V/ZHK21cCBmNFmfCDgS9O1zwrtx/CrqsucKh6u6lQwdRM6EW0Sc7Tt
CR+rrCPjLW9x0CgVYe60mYeTBrse8qV7sFlX6/foBj4iLQtUmOkDsMjLlayc
5SPO0HP28iUm+G8ulE4N8zG9K8jF2osNaZniB48GeUgQdpiR0ehGh/y+qh8y
BKrpxBrvBA44p3zzoj7wILXBI+/boR6YrLTvD7LgI6I37bNEKgsqX9b4eJsS
kJ43l0V01cPXf9ZJ3oaE0ZK0FdccLiJrjXiBgTOJCIvJ5tStdcgaFZ5cfJXE
GhkmIbajHLN7/Qvtt5HA7wuqLcL98Lx4EfAhodw18qzE8S1qVf7JdlHloy+8
hB74uwN5t9TXsd0JPMjkhKTKtuGDqI6rhQ6Bv4okqtXMK9Dn3RKxcY5aWxyf
yExph0jvbf3t9whEfTk/r0W5Fc/5dw8zVPhIEsiISVpxEHnf6Um5AwnJRimL
ydEGhP/sPDpcQYBx6kZeaHQH9JoiB1dEE1CUe6DnqckCYdw7lXiFD1dhwSWu
ZSeu/mbuCJDiw2xAYx3PtQValRW3DhiQyPK72vrsZCUslxwYmnUjEcAZyQgS
tGOwtXdTvzmBJyFidDlKr1r+2iVaNSQyxyu4STZ9mGql787YzwPtTyPatAML
1X5bbF2sKH+5Y1t8JpsgPrDs9dLN1P4Xd9psnHgI9h/qun/bkjjnk5EVac1C
z+v8vSk9fOyPaeo9P5sPjbIqQfExEhtWHCs7uIuF8ZhvU/k5PJi/13ugsLYb
UePm3QohJHTeb1pXLjQEWYlF58YXcpGyt5CMknyFuc6OGb88AuYL7v0kmC2Y
0lIs7Mim/OCmredknoT77cxKGyrPrCUMmeGtT3AjoHdwE6W/JlRwKvF1Fe52
KDVnnqbyffpgDlc8ATfVrEMbHUk4cO3kQuJSMZNufHjoOIlt5Q005/schH17
8Xk0iYCHaFaFpFIbbnwWzi3+xYd+q0m+TV0/Ph01S5XTIjC0IZHnGNEEedv0
gV5XAjatM+Ph+kwsKPWWSKT6M89tyFuCUQ/WWOqiZWokKjhjxZFeHfB9KuAq
jfMhZF1kPKLVD6G2gp03FN/Bb+OhZZ8qH6Fwfl7JJgsSdHfDNqUNLHgTCpUx
OVSeNcZ1okXS0RhztWyBK4l8bU5m9LJu1C9V+FewnA+3bzSOx7dOmG4WCv3x
njrPxOdS896XiOcn+ApMSRzcsr3524ouXMuWPlL2lIcodl+Yt3kt6L2eanL7
Sbi51mfLuLDBlur35BbyEH9F9Ee/YTl2ps/U6e0j4XPZMDV4PQf6YxJ76uII
JIXFh70w6sC9RtoSXaovNU2lzoFlfbiZbKlXKspF1sNmz6m+MuQwHrQbzCMx
snwZQa/thn19Fl11PRcnzs8Qd4WLsYrluj3iMolWWpD79r2t4I61706+zEdW
eI8sQXsD/arj3/MpfScu2XuVaVfCXawxYbkhiTPFQmfMdryFOuNspEcNAZbE
TbGC2RzUj5K526i8SU5YfLlj1Ymk6Jom9h4e/NcsdDH8wIJOSbLzIQMCGY8v
T/yd3ACGHfNNWC7VD5XBI7G5HUhKmfgzrIoPtUt/OcUuZ0LxNz1O5CEBI9H8
wOJqOlaRxTqcsySGNa96CiZ6sGdwOOXcWz7OLeo5r2PVAJlHygd3U3mSDi2Q
NxxsgEtt6lLPHqr/0flSDPsuuH3OaRm3ISguy2Z8WM7ArWnPUUYdgawdwjOT
atXQVIpabNJEYDWLKW3mysI1o8POCmw+QuacSbnss+is5Lv6Uzxb8Igps3BR
H/7p+xInJM2Hnq1HiWpkOYrSJCWNvKl+qr84ZfF3H6wIEdcfv4bAYoTfbLIr
gEVyIPcXSCQ1ufG6VgygZmnKAe8KLtxjhU/mzvbDa7grUMP4HRSzqnNvzC/D
lmn/oC3qJAIDTEiOSCsyb20TjqP8n9RW36z6mInePwRFv7+TYBSWnc4Zovhs
xDwXHcQDo87WpP95E8xLPDhClQS8vpouMtZiQ8AtvX+Xx0PI/JIX+QdiIWGv
ovuHEwmhbKEq2rrdMBLxVTal+tw94nplM7sPE3LbXt6+QOJL+vM9KbGVkP+q
FxyykMQvi/5A33aKfxxrJYfzBNa7+4WX7i+BbPbZyLNh1H+3lPBnV72C5ZOu
pMgIAn3aRjenV3fB/s9LPj8pXnK3K/3qMynCnmQ7j6pDJD6qln4/SnYiiOlO
09hNYCCg/ezkow7UKRToi8TyUdaQqjwt1oe1P78+rQt+h8b57df/PdEGtryO
2EZdEgLG/8SOyLCx1HzlkVgtHpLtGr7vu9+DEIlVpbcp/ftsOwuTEgfg/vXV
R703BGKaZc3SOWzQV1q2HX7Nhb/gyPdfNDaUAn6qH9vFg173juDU0VYUt+y2
c2RR941WFvf51ArrYNPESGOKf361Q1aDPVh8R8NSvYwL0+j37NuzjTgaHVat
7UXgo4JquNaZGuwatX2cK0q9n06LwSDtJeoKrFdvjScx4GZ/70hGN3jX04No
h/mw9Dtj1ubUiQqxjWMx8yk/ja0/x2vT0f7JMZWbQqJ0wbDWGLsJU+VzoZ6U
X64F6Q+6F8fDaZPUVDjFowyBs622Fwfafk/b7mnywE3oSFsuU4znW45ffGhG
ImTabUA7rgbXejzuzCwjEXOnyCjD8hkcFN146yhen7DvIPfaVSLgulTwdSMS
ihFltCJWLOiyadE+R0m0V2xq8jr+FmkbxZ8LW/EwYK1Tv3akHeMS9x2jJKj+
aNZqRPcUQt6v1PMK9R7/AcOqvsM=
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 2->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8VekfxigJk1STCSE1aVGiTZYHFfPTRLZoHZKbZCKGlMSPRmRJkrGT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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lO8Xxoe0oCRfkVYpsiVJScndIjsJRRKyZaskayQthJAUaVGyp6Ky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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk0VWsfxw0ZlqgUuYk0XBo0CEkD36KBt7jIeM1d85LiquReySyUkilU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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81dkfxm+ZQVGjCUUhRgtpaLSMwkMhFTNC0Yx9iOwiyShbI3EpRBlL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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 3->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lekfxs8UKqlmZEQl2pXIvueuFDFMhJIilTKJyQhHaH4IZS1FklMj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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4lG8bFZKkooRKRYmK7FFURyql0KIoWxJZyhYtPyShskSKZE+2Etki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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx7WMKSRJkWUsXSqTupZRqvFpbKm0ISGVjMZaISM/EqayZCxD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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns8lNkfx2ejtov4bbkVlUaRW9qoZOVjiyK5S8JG5JJ7LkW6KCqVsjWy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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 4->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekbPpmUbJEpmZzJHJMSkxkhNXQbTdonlaKfpWVSiBip7GRyypKU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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lP/7xanIVkop2aKkiEpKKnVK3zZJkrIm2fORvZJIWVJSqCgSki0U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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk4ldkfN0k10jJliiwpNRTZoih8KNnG2ggT6UYkJgxpNMyUPQYZu1KR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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41ekbxk8iW4pIKUtUKJQZxt7cpBmmoWLKyJaKElmyhWJOSUWJZixZ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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 5->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkbP2FMRMkc6zed0UQjmfAVFfLzifIZjGJUxpY9ZmQZ8dlSWoSI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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8Ve8fJ8pIGaWpUmlYRSWy3loSKiEpM5GRjJBU4iuhXaIUlRHJJiRl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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8VWkcxlVDEmW5SiSkRknTtY4JPbZRNDXWUlTGUqZpyBJthKHNlqVs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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk81Wkbxg8vLUYykWSLkFPekJSldEmTrWzNSfYtDFKZqZlKWZskpuyS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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 6->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4ldkbPSQRFU1jUE1uuUQhSlGtboQolcrEEHKZMCRdFFFySf0qJd1U
mogiIXJ0OC6h03FwznE7biWzP1MqUYmS/HZ/fM9+vmc/7/vttd611rc1vYK3
+kizWKwU+vxcV9/IOGIWlYPWyQZrZLwJrq/c0rVwlQRnGjKUvhgwsO8/HV8Q
Vw/X8zVL398jqHgysUrJshpahttzXaII8tKTXWs/sMGtLrYYDyA4GRCSYKPJ
wa5dlwN99hL0mPJu3N/khZs9GwWmHgSDhqMh5789wIopUlJiLwLvwUW/+f0u
xNrLySIrNkHiyjyDtX81I9kp8HcXeQbPo3sFi02eoyt66r8nEwhu5r3OUfPO
haSipGQ7Pa9SRtqRTxViPLRWqOh4TdDr5Mne4CrBJqmWFx7ODITFl/gBQ0Xw
V9wZKf0XQWx+UN8zuQ6I+zn8vfcYlE7fujJmey0cBlQvaR2leC6Mz6stakK0
9eDR228Jxl1Hv1olteOAwwp1aDNI4fQpxiiJYZNr0DPQQzBzKlcYHNQBI4ci
y/qDDPR2O+4P7xWB73e83K2MIFoxtG4b9yjO+v7VvYLiZ3X6K3QvzUJBmkJ9
oidBgfKvGhUr2zB/ZIf7RhkGyVP7q/zUa5C4q2zv2miCvkea02Z1NyPcuHPa
+TcEyxKs8120n4E95ZSWdSQB29Szxcm/EDK+sqmjewg6Sp6O/7BqgsuISdKn
r/R7F49MulNYgRI7pW09+wnkbgR0zi4uR5gV8RT9TSCjsP5mwLsW5Gy4eFw4
m0GOnc3wn2weZk27durzcQIXpRJFQ7UidHUYK5pR/uT7+T3Xg7ho/urXG07r
05pzhr4PNqOqW8CzHiZI0Oh9/89oEmzZzZHHf+K9ZuhnFluGdXkvBrnBBKfX
WNd5VnVhh8eOdUrBDBI3L1K9/K0FPQEWujJiAj0Z2Z233KsgvS7fe9lhgruc
gE8aoc2w13F8Y/ELg5OVDmZLourRNZTaZf+QwB69ITmjzZhz4kNroxoD1QED
fs6+TLj4yf94Tvl16Tqg17uyEDZ3esef+BHoz7nEaPW1Yr7SxnMyrwhsdYfV
DnF4KBIoly9JJjgr01Btp9QGjV98NvAHCF7kR+wcNmxCXn7K7FcU34IyObfq
TSKs5iak19fT/vMUQheuqMbjUPP+Uaof1mPdOOUBL3zbrT30U+8sfm2j3pbT
KBjRu+NB3/+RmpMzb3kz7BZovDaj/T8bHyi+392CkaDTG2OtGEhfv9eWGdOC
DbVTYj8uYmArWbpqR2IeBpx8+Vl0vqVNlTP6Itm4XlNWUuhPUBun7Cqe0Qan
VKFBow6D4MKs2AljCQrUFfc2rGHAknpsZxEiwBTbpnipTAKh7K351/Zk4tSw
9HYe5Sc6qLRaVSwG1/RvTR8FBvVu26aYfm3C77L4ZtlHMOrN0x/bWQBBIK7G
+xCEu9tOMrnVBtvR4GA5L+qvyLGccat74M79JZBF/Rz+76KGbA0JlnzcpvMx
lAHPvSpQfj8XCzaXv9kZRPPBtCTQ2EMCg2F32cU0XwYN/7jofLsegW1fMuRp
vuic6SwL8S5Cmn3oA3dfgoYkRY1qdTGM9+d7FpQSuFd6T2578AySgod2lyII
zLvPpMjaPEPlGcdjUbEEvvoV0faCFsiS82q/6jL471Wg1MRsIVhymS32WVTv
T2zq/OxFSE05OLX/JcEsY7kpYSXtMLqpwMmm+hdeiNN/o1qMV3++0OmkenkX
bnw0cqACzT+qjHQPUr5eRmeLOxthubrO5Xs6wRcfG83+0Hacnx7rqW/OIPU/
i8w9h0W4uDG90v4DQaheZsHeOZVI0p+4e+EIQVfdMXspV9rvmKyQE0YQv+97
9FXHSrwabj1wPZzmZXGnSpdRDUq1+CqOFB9PKYEfElWKmBdnG9tpvpI2H14I
3U/3SI9QpPszxy1Oa8eL4e/8XrRFRBDBjtk2JG6Fib6UpI7y25MbdueudTqc
Tn42zd5NcCgje9DzhgTmw3UV4vUMKt66H9KbJcH6bVsTp7sxkMyuCYvXe4KB
zXb67gE//d/SIu/cDqX3y/0zPBi8tWkIVddrwjSTgP/FtRKEbFfRPjvxAPMH
NnKcaR6vJvGxK+zYeHxhiaMm5a+UMRMFfxTgm+D2nZ2pFJ/FYYV7IxJUrFn8
4+ouBvrWn4xUmHpoK+ZtUcun+gxwtz44lYvvWwxdi0Jova7cuQyfGphkjTjP
O0vrd2svrg3LQU79oeWpVG8qpw55jag0w3zycnEanefgjsR9g+fzYSK4WMml
fll91Lr4Zu4ZODmnpwdR/xm0Vb1MUe+G4uFUzYLpfahIVtznai2Ar8FZ28i7
1E/c1Y95uiKUjrc551I9pmS9jeLdL8Pa8TBRDtWvrWGZUXBHGa4Vb97Boef7
Zh7xPlhLhERvC++rHHr+f8bs+MJyPPEQblm6j6D/VskeLksMXYunPmw6n5vG
Q58PpbVBre9t6qYxgteOTyNU44UQTrP84FVO87tJOi3knAS97AlT9+UMJk3a
vyuxpBkOg56XW2k+OnOidj8IrUTg/ZoPDTQfucUpnedYzzFzyNg89hLBx0aH
pWHBEhyeaqMWwmLgEMYZ9p71GGa3zOe407xQiUh9aLxKjE0ha0sVeAQnhu8O
irS78MolvUzhTwYJF96NrVXuQHSMw/w/NBmYrPnva8K757hxWbokjPYfzLri
n7zuEdjK8Den/gwrXZbDf1SH9qy4IN51An/+FzfJtVrMXNnXMZhI/ahzrN1q
/VPIub2L4lC9Cr/H6Hm/eYTITQu1O2m9r67HSwR3Y+zlxLwO2T48ne56e0Fc
B46fMJzbR/OFLYpNeshphItF5oLp1P+tF+613o7m4qSlpc0Xym+eeMzNXSkb
12TmPr1D9WBy5De/xZebsEvir7me4ivI3jz/ZW4L1JWNzQ01GPgXbih3JkW4
orX/12n0f7bMz+HfGfLN0Fk3b7LWDHofuMraul2+FlcuWiZ5naD3HZ+56aLF
D/BO/Ez7x8/+3eHmFXufwyNRVWBL8aUbJ3/UNSrCrM/K1fJU78ce1kkWhlRD
cJK3p5DO5/8e9Ljo
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lO8XxpGEsvSNFkWyR1S2RLolZCtKGxEVUtmKLKkQIQqJSKukQvYl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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs8lOkbxq2kDDpIDkvY2YqKDSGVuiQsoaUkUQY5TBSSDsqWNoXa1sgx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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4lWkYxoUkRaTQZGkjYcRMGkpzY46YoYSSVISjhKFkmqbsZZk6lhpU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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 7->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8VekflhRqInWjqekXFSohU8NMY+aRmCyFETM1LdeSiWQbEU2iKCVK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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VV8bJZKxUBmiTBmSKSUqWSVFIhVliAyh0kRUlCGVEipJpqTIPEVR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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81dkbtkZDzEhMiWgbpNxMi6V6JFmiZMhISsMVMcnaolHEkCypbpab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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41Wkbx5FCKadRGJJjSSXbmIaxflMIkxkhjKwnSy69JDpEiWSLjiVJ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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 8->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lXkbxk8zRGVJcxRtw5ul7CGvqcw1jBQlKqTo0CFJRLKUyVJJkoSK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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3cg1P//R4UiTWSUVSKVCAn1UCnJyGohoyHtqKyQkQoVJfFBtpCRvbL3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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx1UzKhUi+5pkKaJImManhSaRLCVJFCqDQjOVGiSMkBlMaTEY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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41Wkbx8/I3osUImQZgyxFUxOpvmgTUyFTKiLVUCEaJilEIxqhRSRb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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 9->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs8lGkfxieHpUha29u0sp2jIsnYFda1qsVKGxvCymFeyjGxnSiSQ4UU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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VH0bxseSJZJQRCs9tFmytXm6JKESQhKyFEKWCiWVKNRTERJZEokk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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41ekbxmkkRVHnNCWmpLGUUakYS7lNYZTIlpYpilPSYufSLpMlCXNC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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs81OkbZWVtTal1KYVI5VZki5aUw5SElZq1LrlWbCTXDBXrUqEkqcTY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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 10->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwdlns4Vekex3eNnEIN06TIuOyaRicpDQ3JfEPCQ3FMDTluI5SSUm6VW9oJ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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k0VP8bx22VrcUuiVBEQkUovEVpL6mQhIpCylLWdqRUhK8kSUJCytJi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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs8VPkbx6eySutSpNiMy27bWjLZlMXSh6JcSgqR2066KWkXUaQlqVRC
hLZ+bZlKFHIZRXJJo5HLuAxjyDDmfJWSSNK67Pqd/eO8zh/POef7OZ/n87wf
Pf/fduyby2Aw0unrv3udmfzuePcWeJ2WNUw4UXhXcdN1h14HNg6vHrrcQhBv
M51x2Kseejt+FRiuG8AK0ah25gwPR7TdUiN2E6wI5h1ULuZjz76ZboVYgvbN
20pmHogg8iB7T5rJwLiZeaDPIg6JcyzfMX4lkH7nvimrLRd/3fwlzNOfYDRa
0LWuioeEQ+VVXXvousjW5evWTmRfyztTfJeAq6R46M7ZEijkmVgFeBBkH5ow
KEvKR9B9p8WJWwi6RcL6YxdfwbjV4raCfT902Y+S9BddRpVTZMJ2PwINmygP
I6NKLOxOzdArIjj+p8SkvkeA4/GjCG4kYE/lX41pFMFAcI/nf2IAHucNud+c
4sErOci2fIKCOO9Aqdnwc1hWTORkFdP6zjiK1erEMHq/fvfhFAoyv6z5SQVc
cEiK22I3glD3TJtrCT1Y//ik64VxCRZ8r2gcOfkI6dxG5SxnAk+ubNmueUGI
3Wq5dDvtB9tIlCayrEXI03PzDyoQNDo/MxA+a8DaNvlx3h8UZk6NCazYXWjZ
EhKmPEYh+GnS+n2NrdAfldNsSaT9Za/sO/6KA+fMorhGT7pfOuG1RiZCkLQR
/74CGe4s2GHy6d8WdBmKklstCHRPNBvZmcTjfMzv33X60P7sagzxvtUC2Zma
5c2nZHiUXPzH6Zk2TH0plFzIlIH1eeWQZSt93gMLI64uBeesdAVJQhvea0y7
fuQRrG/8sCHiHz4MJZcLv1yj4GEtLuDqt+PS1af+4oUEdc+zxPP3tWPXHOH3
1idkWGCoWR61qRIt2xyCn9PnKwcGxtqLW7CBLVZXVqRg1tnQEbVNjLwu71vJ
XAoaylNbHox04r7c9IYBIwqjC00beEwhFA15fpMiGa6mxKrzJp7j9Xfuvkl3
KcgnjviWyInh1Bvt9WDlAIryyqKaHCvAbO298esGgp7TBjEclW60OlgHOmYS
bHE3Se+V5uBWhMd4LN2fOxO6WjW+PCyt8nZ9OUDBZY8ek2nXifeHnIvcl8lQ
Gm8fO3P4KT5n6GmdP06gfUz7ur13D9ZW1YRaj1M4vnVsVlmnHkVRoUPntAh8
rKURkesKUJgixz9rSeA2+KpJKbQVUX3T6rNKFP1exu7ZNy2Yax/d2/aGQorW
Mh/eJRFYTY5frhrL4K17S3WXTwdqF81brmInw+ji8Z2u5e0ICm5nOMgTVI/r
XFSZ5OPownMivUSCyk3q8gnDYmiUN0clRND5DGKVPPMXY/CIeb58nAxusVtm
2BXtWKYT8uaoIwVXuYYeEyceGrd77FSl/3/nCt3A6V18MLa3yVusJljAL32p
P10P3R8yy5nZFCL/tVE3WfoCrKmTMU9+JLjywn4kIKoJS5Y7huo5DEBRs8T4
q9qzqGxVuWdFz5/Bx6NTRqFNSN1bfpg5SWGcF/4pNqcJGmxpVpntAIZ/vv45
R9wDFn83n/VJAvaX3KYcqxvILZ3Ty6T1LHkYd03KFWDi70jTRTRfKurdd0ok
QkgXp87NyafzqUMNBV6pw33b2wyV+bS/K1NeWt3Ig6Wn9rfDLgSMjtnK6wc2
I+7KN/t16Hkzq2cpb9xwF3OdV5ELjgQZi/p9nZ60opRlscqwVobK2x3dW39v
xcq/lJdldlJIbkh0eJrUgtHP3nNDlen5id3s0V4jAsPZRdgs7cdQZHFSjs9L
1DS7FOYsIZj+vk3/fWUtdp3ZxE7qp2Drd0hnyLIYqr+Eu31wIpALrGXL3vFR
vZohaaT5NvH1yX9VL/VgMvqT6rnIN9gUxxFYj3Sgfm61QCmYIIZ3wv+F+WPk
r+PcCYsmSE1Z0MZNaMC8Z2o54RUUPMO0La8/EYB3dFmG2aEBsPnuUtYTHtZ8
GK0vuEaQIjwmKPXrgOqG4J8dlAjstW3v/GLViTYzhddJ3AHE/WQpipwtR1Bp
0stYXQLje2JD35AXqLc6fKHbegDVm1/9o7a0COaBrtntQQSDI435/TwRUvU0
fhyADPHchP02l55B5zexT5YdwTXPMY0jRW2QK2FqSZ9QSLeo1ROYCxG/kWVn
Ss8HQ8vC3Et9E6I+ujCN6X4UvGHYpqncxnK2jt+pMJpfn2ePpJwX4tyWYtWm
ewSC4Px0k8ZKHH3X+T7MmiDAdFttAiVC7qu6jP1SmgdrlENEx3LB8Y72jGUT
uAgMRbdZAkR1xho/ukFw9WPF2ZrcItj+cHPsOt3v392Ky08/bMDFryYy+88T
EJWupLEcPq6UOvfIKw1APG+pidt0C1bFvMifiaSgVSOQfTPnFlZZaCmp0nqr
Z98u6Ru+jPWmxidTfQlMbxdpPl/RhtfvV/sWyGTgCXd2aNI8C8n7ivlTGYFf
oY5imhfNE339CxU0TzqD7Dh/Kkmw9rECc+WYBD7f9iXYRlahaD737U6a3+cL
qs8yWELICc0qhpIJWN0/ZSdp8RCec+W6YhaBdbJmdZBdHRwLDE7U0vw0S+s7
sfdZMex/y/NT1abzLtGy8XoXDpQ1J5bTepP/Tsgc8v4f3Cal5hzan/HNdctN
q57AX6njRQCdh+67JjKqkg+uzcmq0kGanzFq6SYlHPTG9Az+Te9jy5Lev2w3
csCabJ4cdCVYNbWWIdcqxJoQ2z6jLBnEXrVvo8w6se/hPOadf2SQmkdxJo+k
wvesb2Ip7U+AYI1knVYdhFZOAS7f0v6v+FBo39UGzY+hTYOfZYibcrgfEF0I
g9AuhQO0vrRUdaXOxlzcUM7m3ge9b1+3NNVzksHMPO3BpL/HPmq0pyQ9GW81
7EJH6Od1I8KeR0aUIP9I/Q9Suh7zh/axpqoInCsTLan8L1/N/WllmRyoxXjV
pNN1bbvcDwe21iE2Yu1wx3YKvbOJiwx2dyDQqVRt42MCfb68f8niChy8WaDR
85DeX0Tj4Eual/u71Zs4nQS5XWrdtoavwC284njsqhQVOR7p25l18Nr78/6T
hgT7JTrZW9X5SA4X3CwsIPg/rvW9TA==
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns4ldkbJVSTInIrFKUYJArjNpZynakotyQ0zsQoEg3dFDIjJwkhl0gy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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 11->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8Vekfx/nVWCLKXqloMOqqrsjUUJ8oJgwZezMqSwklKVS0aKxFRVFI
kmWGKKJlCFnKcrPee7nI2jz3juyVLUv9nvnjvM4f57ye53y+n/fn8xxVVx/r
I/8TEhK6Ta//7kpvB7SzOLXYYXH+feJtAi+n6e2WM1WwVJ5Md7xA4DwXkaI1
HYsY+VG1sEMEDikac8on3+FBTT3bPpuPvXKL/pmR4kEts1o5dpIgw/qQQmox
CzJ+z2XskwhiRC3HpLVaUN5bna3RQaBg22x6azMbTV7plW1sgus/tP8xxK2D
+fDihAq6f1eCRYFkZivmB3ZKiIwQNJnn9Fst7YHVL2IfMpYL0Pidu9S9VB6s
x0Q4bWMEpEL3HK+wAWKzJ9pYyQTrIsSthzvaYK3I3ypMCES2778ldYaL0Uft
8Yl9BNFLlxgqWrNgknheUPIXQX7vob7ygVqUPHrovHCFwIoTf2xQpQJ93Q5T
Sf4EKv+KCvb438Fqi64L5VQ/Yaro+gTU4u/kxR/O3yGI/DddyyWsDcrLhmbz
1vExUb30XGB9Oyb3eu7o2cFH2trPG2Uf16OMVRUqnkKglXZNv8mlDme4pQ5l
kQTSNpGSy4U78MxO96/IID6Yro1Fnr+VQmom/7KZN12fpxfzdYGFxYbBQkk3
CD7XndbPYnCx+bOcbbaAQOzCzCetfU+wkrnl1MXDBMsCdirKXOPg1yAeSaR+
bDlmckWysBqv5bvPrad+KhfZLtf4mQe9tMz+nmmCsJAorXRlDrbrGRqTfILx
zLxRkRoerArzT8Rt4KO31uiThH0mUsoNCoxcCEZzDrxzsGyGTJSiyX76vo8g
/kiEBwtbc6qmzG7R+c2OCzUsaYXfxvWr7CYIJLc+n1q8pA0bLKb7YuX52HXJ
bOzHJXUYONao8DSBzl/KV9tZuQxnTf/WZPgQlL8xNrrr5gFnXlzdFjrv9u7D
p+rin6LgxDPV9+4E7t5W4fpBXOzTqV59+hPBRe09Frf+ege35a3NLVF8ZL2R
Vy+S5yA31Xpd9iI+TgYvEWUU5sFeSuaAqRtBX6zgjvuLRpxkCKv4FhOs8Q4f
mSt7i/oV8szhXIJhZshHLcV3yL/vzdscyofTN5d5BSc2xJKsOmp7CQY01f4c
j6hEWlGJ7bMgAkHIa8W+SQ7Ua0R9+XJ8nG0d+8oMbYJAvV1Yp5Ig+IRKjGQK
DwpjtdFrhwgWMysanG40wpGj078mjmDGsCNHhlMJLZGjLzwDCBrSZMocL3Eh
FKuz+bc5gprkkMqM5g7MirN9WRF8jOeWiK/o56LCQCtwiPIv5lXW4ubZhOKs
/wmO5xHsyY7KGZxmg3nq1P2rfxNo79U47SwogNhhC+7WIwRmh46sXtrejpg8
b59+NT7ya4Lq1+wowGJVT6YFne9Fwa4kK38O3ji6rS+i+ZmPmxapk2YhpKyz
WuE+XV9i0ULA+nbIvRj+w+wCH5qqD9zYq+/B8NVErpQzQbLg1+gFv3IYSjna
6vgRNJtnJlpZvcBEWMIZEy8CuRNfhsJu5EHVM/y3D66U77C8iB9zm9C26ZSq
TSqB3WEPRfWiDoSrmQ8FX+ajz+9QaoXTE2xakTitRPkuYVeP6Jc+xejMQofT
UYJdwgqWPMUwlKu83LyP8qKU2nm1x7UFMdcljBIraB6aRAcTmh9iukToqDLd
r9Ge0cPaxaY9F+mzmepjXeu1NznPRcK4vobkR4KHE56MCpM67L5rLNlA+6BZ
23JlXGAxnKUrC5OPE7C5u7Nt13OR+3DqSw/lK0ZeYNei/gQVFgphWfT7pHKc
/NQPNUB2fHX6wXSCm56ZankHW7H88g2Hmm80D4lBt2qM2qDzw/buO058zBh9
M3j5uRaRsxtTg2Npfsw7xA9GxeFY6eDue1SP5oe553fVK7DobojRHJ1nmvnU
dp5jC+IebTL4SP1mfvH1X3f3NSo/eMspnKb51g7/w7+6A5Hzl+KuUl66VL+u
9zKqx032qm8hFwm27TnZ8jYjD4l2/6Ro0Tw02kQbWlS1IGVkK2ttFe0LEWZ1
f8MTVOm+CtlC9SSnz35/6iUHZrbFZim0v59KijIZe1jwKrTweE55SJiuTprO
eIbrI1l696gfzjrGYrf17sOv81bCMsrD2e4v/MzvahHqOT0aQXn/03hkuHBD
IWJD4xO/p7x9lHbV6A1sBf+1cd0q2vfTirqWKcs6wese88x4yIdHLfPm7+Uv
sGqDqVIg5Qfil2QXZFthm30gzV6bj1GO0gHNonak7fuUvDOQD9V50YGMuiIM
jli3v/Mg6BBmBBctZaPLaWDbWppfpdB/0r5FN2Ei2ST/p0SC2R8ZOZ272Xhv
/SD8Gs2LVwfLnXWYizWfYrV+GqB8uZSr7PItQWXkywsSvrQ/ptNMVfSKsat8
/0go5cG5e135TrtqLMta5TpOeTnfI/JIL6AcJu9dv5uifpHMqM8tV9iIK7A5
6U/9ypkyztfW58GhboddHfWf+XV50IBiO/y+nh1R2siHfktQ6eOuVvhevH5V
T5YPudJidW2vRmy7UMp49YTO02FIT761C8xc9qWXVO82ieL45sky9JkYbNpL
+3PYUrOzwr4VNbvjC3KqCeo1cXxn5GsUWPpY36T+rzwQJLYnuRUaWz6anVnL
x8OVZrLBJVxM5rg+lhal/fwo3/jy8XqEXR5kkFDqv8TIrE1ADdZ0Lzy4E02Q
XV62ThDPwnsHE5uvVK+eQsUVFxke7rdFVdosEPRat0f9/uYVNvE8/Vyofq+L
PxkoPKPPrUt6FYz50IqxPZORxkWSQZLO4WV8BCctCbhnysbJzON2IdSfbRz3
qzuk3+L3T/O10ddpfhnnw/cpVGIuPtJNmfId7JyiEyDIRY3rFdkummfnI01x
d/c/RtQv7v7elOfd0XWyk5VVlOOLR/JpPzf/Gq3kF1WFx4zr8X2B9P/j1bxa
ingDrup+H2xP+U3uN+cx3tfgXJLWFV2aP/eDgwVHhduQe+9ZgAc9z5sd+iyP
y7+Flksom4TTfv7T8UwiPX+MLFZ0mo4T5Ga/3Ji7govWny3a4v/7v0hQfDCR
xcZtkSfbL3EI/g8SMcVw
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3cgle0bPoo0KNRX9KUolBESUqpLJELKKNqiz0yRlJXISihERiWprJCZ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41dkfxyUVmiQko5iuilJmCDfF/N4qGVvTWEYmhUxJClmKpEhlC1kK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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs4lVkbxrdESChla5CRKHTQIFKXG8mIlBxSkpEkqhFNySmRHCJGUYQk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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 12->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lWkbN+1SkaRkIkb1USRENfhRJ9SYxjRUM9nKUupYs2dL0glZMh0y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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3lYTe3bhuv1o0iJBkUqzYQIJcWVkNCEKDQpKklSGYqSJuVNoyFNKjTJ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk4lXkfxu3RgjkjLaNNGTKKGmSbbiJLYaRCKLKHlBLGy2QruxYuIyEk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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk41Vkfv0KUJSWRStYaLZQtTfhYSllDM2OJIVmKurb2URRetDB6K5eM
LGXp0jbXDAnXLlmui2u5XPfe38/WRqaSaXt/7x/nOc95nvOcc77fz3a0AiM8
ghfRaLRb1Pj/fIOz2tJfWI9zqtEx8x4kPr3As6K5Eni3aFsrOJPo1PjelVY0
gGHNQK+21QQ0I3a21nHzYfyPXf9dLxIddOsGl5h+lJSnvvhvoRhTEvdlTpxp
hFhnl0ztOIGi4AoltdJRxCY7fI3YTKIwKslttREXuT9rHksPIaB0fkORUUU1
gmT8FBWtqPubVc12LFRif6CUS/V2ElyXPIWQjh7EyNT9Z1ZFhCBZYZ/Bqlbc
avx4+msmCabb/LShGxdW/UOGJRYi/PvTQnysoBH53ZzbgWEkMJat/Xaaj+/n
aoZeFwqR49d2+mtKI57cgyxDi8SIBls6P7MFm66PWplZELjuc/Rx9swwaK+c
26ZeCvCDfavF3PohFPfKyj1OEiGdXmh61awLvlmpnj1HSAQkrjx7p46F0MGd
ucelSShmlY8sN+Iht+jHkw8WiSG0TSyMRhncy196/BJEQmqybHiA0QtFBaOq
lEACZ+aEd6JcqzBnMxDLzCKhtF3+KePdMHy3H9OdvSfGI72pVL3tXBw6L+X+
oV8EoZZkkeHVIbB1q55PxgpxJjOOt/prG3yaVdUEiiRWesmem/PmQNHHbK+W
MYGpv1yc4o5XQ7bi4RCZTiKoMKR4chcXCnFLzP2dCfhMPCq8tWEYpxNzV5hk
irD05U+fo642YMNv49rarSTMPinksyYGMe/2lkk6CKG7RnlddjwfDoEr2sf+
HYOm5K4RY5dOuLXvK9QvEWOfpt4y56AuOBtqBi/OIEDwjfUDYhrwpEDWOGma
hLW4v/SV6iAmR9U9pUbE0L1Xtl5swIFOrr3g1BExlMK1EtM7H4C9pdwxNphE
2B1vWRVfHhKup8VJzVH1L+bp9NL44OpdsZ+gk8gTRLu/UT8Hnm3tdml/Epqi
yRKjRcU4ZshwT3ah+MGfVago5CPVfdfTA40EbG8XD/x4kIsg3oFNl6PEaHJg
OecYtcPs/VDYB6pfrIsGqZrJdyElOvdZy49EQfKrPJdbgxB8FehozAsRoCpY
lstORW/1Hv0rv5J4K3o1G3e5BY7n5XtcnhKofKzLVvd4Ar/hqHL2NhKPypt1
GAqtkGQJlhx6QcDq+FtSpXsI9JQftJ1DRZB+p9ut/mYIYZnfy/x0Reje3e62
YVsbvrdtPPZqisBKqcOyRvFsdKUVfxvdT+IZf9IkdVUdFrYwKrttSGzp4oRv
dXyE8q4XLxiuJBIbPivPGNfD3rxl8WWQKHGO3HlhIA197f3FI1Q90T6pFqqb
ujAtXlfP2EJgbfpN2eU5VaCb3RtmviZA22sYPf2yBKduGnS8tyaRkmUcaxhU
B1nihn+qOonqqncVcxrDIDlKj1n6JFqOEgql2X1QMrhmb71GjPhf3atD5NOh
mjxt5uRLgm5w+4t8fy8eGpWVlCQIYRG2kLKIzUVa4GuvETMRJOVOlL88OYj2
vbVxpWvHsTRRz27yQRuaeEzWTi/qPcILx2v2l0PP2CplF3XeLybV3AlXPt4X
XIypoY/i5qXECR/lQTRE6FWqiQkcKTfV8rAaxGZvj6UyoyJ42PQFyyd24N4n
wz+6/hXDMnPdQobMAKy6K5r3qAlhnfQxtSSjCVNtEeoSe0gI7Q748tPqkLs+
xH/7LyTkpenT3/16oP+aM3NeRozdacrStl48jFiWSpS2i2Ht5y4Z43IDl23F
UUMU/54dLlVYFMvD3BpWRi2lz8j7k5o2Eh2Iv4g553Ex2J0O6d/0egCax8wo
xT+G+UX4pjXDV8W1oOsTAcFWp85/knhocNyiTUsQwUv8m7nKoypEx/i2RMwS
sE+WClko7YFRcsJQ20YCeRYq9/lqiVCfGv+wkeJjvNxpQS2q4CJVYR62i4St
sH7OgsnDNq+0iLzNIkjEl8t8C+TgWLZ7cO/fJGKSElZ32Q0gr8yLE0n58ax+
Y159TR7CC1SKKg+R+GIsiKMv56J9yf4opgOBn6PzqzOLuNg4LNUdlUiglPmR
+2yOg4/BGmnSdgSW1Fk+ZC57DPPzcka3E0lE7TFP9FLqg9nRbZ6tAWI0GO4c
8Yx9jqcqW/+yfEeAPcO4uSL9BjSakiwcKHxpoRb1LJtTuLTZ9OgIVU9KzqkP
O5xaYPMtVNX6ZwKvd95iNUrWIOTxWJBqOAk15TFHnT95uG+SUPHgMIVHcshz
VfUWJO0okzykS/XjLt+87PdiRJbNHKzypPZf8QkRVwzDZV+lrWa+EOw2zkyb
dw98x2OF7YUkBu+YnrxqWINLMkaf12hTfiyFM80mnaCdnhh4I00g6qzmMMus
BwaXft/EjCQgbyyt+eUYB5drMxua71Nr5eV3De92w3Vscj6gUwTb9/OfjXuf
Uz5r4mlP5dsm0T/7jrc3I3Jwb7h+MJWnWQc6Zyz6MN7Zpc5dSiB+s084stOx
9MAfPdlUvnKcSpxHXJ7Aa5S43r+DBCPOYEVO/ROsSre7utGShG5vldWrq03w
sdG9fKuTgNBb4uFzmzZUpWp6OSkQKPPMF9td6kWuzMAgm/LbI0r5sfsKmsEK
5D04S+XfpTKnjbN1ddgmlDV1iqD0yqON0e35sND3fqBbReHzYvdErf8dDK7X
8B73pvw73zSzcm0C3DrKAkwpfAbZcvVrj7aAv9dwyaH3BN76j9Ct/Htx8kr6
bptZMWisJtnJL57Q+uvaQWtKHydG3TL1LTtwuHeO77iW8m/GmdC+5lZYXGQS
wTEExDTrAA0TPrb6h1aMZYigJtEn3h/7N0796bjVdSulx8hVljnSXVCPT/C6
co16X9gaekdzC+YFSw3k1UhMVXov/JjdAAtth+iEFAJ0mQG54549CJR7xkiN
FCNasNL17WkOChZlZK1uovJiXI5+piYDVmcV3/QdpPylfkSn528+rlmPdcj/
KsSFUDpft7UPygr+deHDIuzLWR66flsrsphRE3FGBPRO7CY3/NmPzTLMzsw5
6v/jcf+rT1ke1q2IjPyN0s//AAiAo+w=
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 13->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk81PkflqRDlkibxraS7eIntFlH9SjtlpxdsrGRo1wxKqWWFHJEUtGo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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3cglf0bxkWppIkivaEk2aMyUpe8vUJFVkNWsiIZSdKShCKjiBBSSUj2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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnlYjekfxjspkaaEksRgSJqhaRGGcSsqSqRS0jKlhBapaRNxtGgRkiSl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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk81Okfn2RTUmG1FuWolKtdWkIjb6KiVVLa3IayzlBUzlb9bEQnSUKO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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 14->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk81ekX5jaKoUVGdWdiRGWkLGUvHqlkJEpCo2ZKliiXMEWllIgryTJR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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VO8bxilFkpREFAlFZSmRpO4UklCREL6IKCSioiQ7ZSlCJUrSYivJ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk41dkfx+/PlGVsydYikdwhJSEt4t0yFRkjS5IaJGsyys+aGpJMlgpF
m2xFIUtZkqGuQtmue69Llmz3e67UoPtDoxTN9/fHec5znvM853yez/t9Xu+j
6R5g5ynGYDDS6PH/udJd2ZOV0oSj8htd8hQJ1oj5rx0MZsPD1GdukEmQtL8k
iyFViomyK5GIItg/wnEwfp+Fy3zP1n/sCE6q9HJjJYqQ78P0cT1GoGxWx/Ty
/Qthu8oyFEHQ5RJ92lnUiIO/qP5ydifBP+52nxQ8H+O+eP7Kl94EMT32z6jd
HJRDX1H2IgUwHyRlzb/BbQ0d6XcGBC7JQ34fR7thUaraUfGFwqIgI3R1NePh
vUxLlBO8Yh2NyFzNxeOGhBp3CwFyfK+1hF/vhI5VgVDNi0Lp/NBbg/15iKqx
4vj6EmyuWyCTY1IKE9uIoQR/gkN7DrieW9+Gb23yceG2BHcFu/tJLheq+dLO
rjMUfIRih89f6MCN2sGZBRwKjNuiRx+N61CU9OKb0mqCeMrEW5PbCHLNukqC
XjOM4xwCDYMQVGA1xXIlcB8dbP2D6sbW8fX6PyVTcJBsL7MbeYVYqykX1WsE
D3bcYvOfdGGotmeTZDq9f4vyXSDZAiZjwX/CXxC0/s46X3OBDSMqIUbpDgVR
mZj0YYsW8DcHDehmEki58eLlAuvgyGYLF45RsJDKUa78jYVTc47UdhaBxve2
otPS9xEyZnsu4zDB9qsdbystC7Dgq/SspQtB/QtTB+l3bBR7N0TwVAmWGD5/
qjf3Cp+/irhXab1f2zW0yUb2QPwIM/VrlRBei5sW9CX1g+H1x5+PD9HnZz0V
NvfwYZL448B3Qwph7fp68ooscCSsLHaLE2yyCbH79V43thk7cn/oJXDQCm9o
/1QHh+HaQrOzBGEFP+umJ5RhJjfmUlokgXbusE6JQif0d935aqA7jAgjFdaU
SR++DeZ2ZeYOoXRcJlu/8S7YLZznv3gRmEiFsuTO1aFqxtdL/TsFjX2fS/Mc
a7D5q+HdDe8pSEsGeLhyesAOVtfZoTaMMx7chSUbGxEVEviycDNB05VkDYWm
boiCXfXrL1GIqfYfrmFyUL3D3vFMDkGN7OVJ6xMFuLVTILnDiSCrWT+0vKcU
xy6ny0zR+jH8pkOv5ldjs+7kl1QFun/BQyOq7zJgHpMkt+MIrV/VdfPTMWW4
0TAdXbyX4ItC5XVlqwpoMZdtSFEj4ORmm4dadkLXb/GlATYFQ8dVJWYzHDC8
U2wtTYWYFO9W77jJxeSzn6KOphN03xaKFZ5txbzs3k9yeQQyLVXrbENeQurm
+MnxbfT740o21sx3YargqbdCwDBk0iNHZiSaMCHc2G4hQ6BaIB4v7twGea/y
N2rHKLRpyno/lOeglTe1rneE9pNhwobCwkaovNItz6uk4Cbkf3Jm9SKtXEo2
QIZCY9/wp86EVoTEyPcLJigU3+72bA7rxlr3VP7s9BCCejdtm2vlgWN+YN7j
EsHomYS7h5240IgXPVz/N4WKo8aRha59GN1V94P6CgrdTU2pL0KT0dxpW21M
92vfvkuHy9xaIKd+U+WeQICwzESJI8btKDb1WegcKESR2ElvyfYKJNjaTJnQ
/Jl8rcuPW/ISObHtr5XuU9if8sr+YVITNJOml59Lo3mRoahSW9MNbYZL7WIt
IRa9VZSYc26HNXorlqcS+BTlB+84VAkd2UHNkuu0n/vEXBUPlmC6Q63vYjDN
i5TZEj+tFqytLznmlEHwIbGSH8HlYEpDQTmuh8JIZHD5nQo+GEwzzScfCY5P
RRceMqvHaZGb7IY9BGOGLLOAydewcnxv+GkVQdRWSF693oGayP7h+v8SBK3v
GS9ybYVHdOZZKWUh0rX/zhIlPIHKlmfTepoERK7c9HHlGzwxTRkr7BeAIfrs
XtLkBoNqBtOc5ovP/E3Dnc86kBYxGk6MBFjmNOv3UMiFwa44MU1KgCpH63tV
CXys1eC5JfnT/DJSftGh1QEu8Xw3Rvvx3kRyKOdEDWabN+TN0f6Z11brZAc0
wGaF3thBKQKr/P3278u7wHYwXS1zkIJ7Qnz0coNOmHRfME+AAFESTmS1QxB4
F1Q3XqbrYZS0Plv28RSspUx1V9JrUZm90oe+XBSvKGlQpPUyuCgjrSZMhkBk
ZdP/G8FQ3hbtpRs46E85JR5B58c03yTwrUE7lDNWbAq0Ibg18C77Zz4PBjYZ
azhBdP78biFIsb4L5vMtj9U8CdSUE61KR7kYX+qhmLhYiKp8jP10oBO7YveE
Lz1OIfa435HRky24r1x9cLyCgiBI78NqiX6kTtYZsXYOg9F3gTBji6HV5Vek
G0Lz+NGpEMVZHhhXm6dCdxOcORBQqOT/BotKwj77zwnAWrT/2IhmOWp9/4qN
N6LrWfrG4c7OV+jnLav1oPlPfhfnrUt6g50eXhVZVgKs2dMRLbR/jcSTHR7B
dH5IMuh2LelD+DeNmDjfEWzbe+i4S3wbJOp3r3Q5QfPbtHmo7EQ1JPPuPdj9
nKDUaZ1xk6AcE1cS3W+EEqSVKWqzIzvxYFeNotV1ASbc/l4lWsiDyj7x9Iwz
FD47dG/dNtOJChmvTtXvNG8jtO9uzGGB+b7A+se1tN6/HrKRzOjFy+iO59J0
Xojq29ZHaXAg0t4Sdt6e5hun2OwHh048T4kx+vOGEKl20Xy+ZQ/SWq9mmI8M
w8dt05VZdh/U/L05kvl0PxL+isruz4LSrMj7gw8BS6Xi8qkbTchsDuYJaf3P
OefV6J/jIDdu82fTTPq+QNMDSorNmHd/+psG/T8YKKt18k7jIcTz6b7Df9L5
EcmVm8zpgKcf08iGTb9HvfMmlStZUF5TtFfdlPbPsJ7mxcxiLBHNyWjS/4fk
YhvOs7S3yBhQkz/+sR8T4XOPst3rkMay/cK7SKBTUnxjezMPgXqxujoPBZDe
7vno5cAArlha+8pLDiLIn8U678iFv6ffO9cjQjBSVqX1bLLDF7mVhfp0/epy
71dpSA8gOrO6Mi1bgGtOrLgtG7ux/PwanZszAsxkMcI19tUjO2Bm67b/UeCH
a9RnhbyAlvJlKnie4F9w1LAr
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwdlns81Gkbxse0SdhOzmeiRGLtLjm8uqKpHEqSU4vNOpQcN9kMS1GtFNm2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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 15->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lekbllQS0lCZn5Q9SiayptwkThMzjBpFxlZKCEVIKtnaVFO2GY4w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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8le8bx2WlUtFQKEpmUyVEfFIUQpI2QsoopULZEqFvKCOSVQoZ2WRv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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk4Vekfl0YKN6RlJJORJcrU+GWKxnySpUihVBjLUCQRYqxDISlJE9eS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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk8lWkbRpYsH1KiRcOgRGiSLF+5SFQyYgghy8kSaTJaRciak21EUhp1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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 16->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4VXkXPrlM5klRDdVU4jGh6SQzKSp65Tq+ITJIYkwql9yVyJ2SM5TJ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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c81e8bxslICwkNUcqIFEKp5JJKycjXyiwlo4hCQpJVUSpJdoXKLDuh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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81GkbxmfFG7KrVErJik0H3pLIFnUpskjlkLIlIedCWxMKUViHnCqH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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lekbxqVRKhJNUcqW7C0USeUiJSMiMpZIqSmF1AxZ0pTQVLKVRLaK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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 17->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk41fkXvmnGpBTJNpaSkRb7Mkj0KstktCiUXyV7I0laJDMoSyFLNI0k
IoSQNUtFyZay3CWXK4rM50tEQ1ES0+8zf9znPuc53+ec877nfc9ntdvxPZ5C
LBYrif7++z+kKqhyc+ei76TYXGk3QcfEJ6fwq42wdW5xqTlH4xt8E/a/nRis
0ag1miHwcMM1TnsLBnzZgo4MggEh1+kDLSloFc6SlXah8Qnv9Kc5iVgstYUT
5Ezw6fMKM+FbDXAR3R+1KpQg0UI+XlH2FVa5Tk7JcBno7akzjI8QoCU9V24w
gMHMwW/6GemlqDeSDw70IDg/knZ2d08ssufyPvxG69WtVzD1+FqMZr8dvnFu
BPekTGRL83OQ8LSCK+ZKQCZkRH/a34gxxSSOWjCBJk+IdUOZh61nWu6Y1tB6
k5a6HdXJaLtleKaJ1tsuUrKv5jUHj3N3/yx9i8Bms8p2nvRLZCtfWB9ylMFQ
svrYNy8OJCQLCkJaCYZHDecz2E0YV5+3/xxNYDZnd/kfu0KoJ+3LmaD95fJ0
rapDO9CfZln8NJfARe48W8L/NvRktNRNaD51jFs0cqQDZrZs2zU031oVhxsR
XSABxxP8ZRhoXVgv7Mvtw7881UyRrwyMpDhLt9qWgXVV0+4/PmR/WIcrAU3o
9IlduCqSQMnxp+GyF9VIVnESFfIiOMhy+lhwOAdypeKX9Wm/oKtL9yYw7TgY
7HX1X7ovdYeojpyXTcg6Z+ucGkcwuO202nJPDtzEBYEpFJ/ZyexXKbIBWPNe
zXgj5cdDbMZ7sqII+pGdqmcp3y2OS5qv+Fdi1NxgMfc3AkPZfZ1x73kYCoek
9TOCvkGVxJbpR9hWGXHf2J/OU//9TY8ODkzW2P+cU00wV+vF0gx6hq0JjO6T
WALttLzVL/gZiF3p732I6kfJN6JW8L9ysF1Pj688TPUiP+wgfLkMS5M1ohoo
fv8D2fcviLYjuiRNiokhyMubGv+7ugJmvxBWMZ1HobzLfcPGXvzx2GyHpTwD
R7Pfi04pP8OEUamS+DWqn7XxPsncKmyZTcoy9SaoVmA/7xfpxPTrgi4yT+Dd
Pf3+u12diJ56M32tn2BiU7/XtsMVmNMqjZKj80yoPBftN7gD9so4ncOU35C0
lrdC0zxIL/kgG7aMwRirf++yiOe4ss02m0/ne/nl0vE4bT50XGUcRnspXg+5
/UOvw5B655aONeWXNSS+IXw8GEohDu9A46ka+YEbZT2QTi3VG7Wg9aKUll9N
f46FK55+yEgnuChQTdkwxoNBmpj/dcqn/CsHG/0HmVBuj52po/yx3M3K1Tpu
4uTCW9lWNA7oD4z7ZNwLfbm0ckXC4M1Us799ZCvdxz8rwij/UVFqP4v93oxV
1/XfuV2ifi2SU58Ze4UvIh4DOy4yOL8iQB36bLCu7Tnl2ED561g59bDwGWZP
PFn7ls7T9kbolLIFvR/Kr3Tn2wksxHjegRGd0AlQVDOSYDAY+d42WI4DrV81
Iucyqd+OhnKPyHQi3XeT+VLKR1xU+J7yS90wWZGnkbyEgah2y36jnEd4F1lV
+NGP3hOX4e/NGoph1f5myQ53ggxLhY47/j2If57oJLafgfghgU3bsyw48tIL
MyhebesHqx+014Mre61q5hRByYWxGCFBNW66emaqUn2ULHNS1bLJw2jWQv5r
ur/6Wbs+O/EekI8v1N1NGaRMDvvH59dipan8Jd5J6oe2lJuxFM+xs/OzsU0E
CUHue+9m34Us8as4QucRtZUWdfRh49hCja75WoIipwtrSz4IwKt5FaND8b+1
/kkp4Fsb1EuiJ5T+019+cW9YcyIEe+MkIui+K4VC7ZS8+BD8KMe4dhGcGQyw
Skl8CT9lER9dGwYm5olhVYcEiBVLL4vexKAyveij+G0ujMXyhbZx6TwpIsIW
3bdRz9IZ0KB4Bmav6zwsakPsFjOLkVSK1zn1GNmSjnbimLCY8lMX0u1qOVKI
+xXiB1Kpnwv7DcA26oNKxRFzH08Gf1z5wcp4yTN8sf9z9+GrBCrNGTETLrU4
+/eeNV/pPjTVqytzOxqhm/9tgUkE9atJ2a4Ijyc4uCrx1hTl+/SnrIGg2DbE
58fzve8QPPR6XNJUVgUJjb2RrvQ+DVTU6o68eYLRBs2vX05T/hbY/pjc34iK
Sfnuc2FUz+u2RC03F8AofNh44gCDJXdz7s/5NWIu/rL+PzSvoCH1RXugB1/l
hLX8/mKwxr26btK8EwbpqaEchoDjxv/8IiEXfjuiJdMpH4ua9vGP7mvFJpuj
9+spHmtXC3L8wAs8nV3n5/OJ3kftnW9z3fgIC7XX2LmcQYx0evbdgl484U/n
2iUzOBMYmLDKqRWlTYNWV24TvI3R1FYcK4SsY+twNd3/2SRyb1HTXUja3IzJ
pXF1yOhmG9teDN2RsBBOYaDkTzztM2ux28XgqMExAhPfX49or6/D3i8dh1Tp
fdS1NNT1F/AQlqK3U4vuM75XSPuooQB2a41Oj3zPQLPn1Pxnyzbck37uKUr1
U/ZA3aNT8ilkWUnYeZHgs+Lvl53X8PCj5Q+ssHGCWNXVrwtqOeA0bp72KCbI
Vtvxy7vuTryQPiMvGCJQHMsZn93VBEnTD+UK1P8sZ9uXvROnkbc5lm9I9fjd
3/mr+zS6kL/d7XC3FPVjd1/KeQ4HCpkNzsvo+2BoZn17UKkTZWIrT3Dpe3oo
Onyjp3ELHG+etFa4TlBQv2BIpawS/BMbpxYdofo0mJc5q5cJ9vA964tUfxlS
9sEqJ6uxrtrQewHNW2Vtb0zZwKc8Beodl2TQJSnq3vNdA9zMSb5sEH2vHfb9
MW4ZjIeWzUWb6XziUUGsK251SDYKj7Gi/EV0tJtGK3Hxqakt4AHtzyp3ujgg
7o2NIws09Oj3eYPCTfGJj9Hi91F7yJdAJmeZj67DS9heW7efHUrvxyOvGb8n
hbjRNHogjfoh6c/QRwWPOpGqFaKb/JneM/auP7dKcKCU6BT4VyX1J3dphLVt
C3xHJ01/o/vgTS4TrZkpR8TXd2kJngRGjgfTikXikFdrvcGb9v8/dfWysA==

                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VH0bxoVoI0m7NUISWcru0iaVlGgnslQkWlT02JJKWlSUCuV5EAmJ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41dkfTqQSWUK2W5lU+MlgKPtbQqWSmH6pmJJQImuWolS0yFakLKNL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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk41dkfx2+LqCxlnxBKwtwyaDGFt6WkLFNkKeuIQhEhahBlb8HMTVOk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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 18->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4ldkfN35KWaKNxtRoEbfNUpMa4pMyTUUz3KkYWSZbUm7ETLZEQ2Rp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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VPsfxoe6tiRJSC5FtNlSSaJH9kRJkbTZci0lS0VxJcmlRUQqIXuF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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk41Vkfv1Mj0oKi9A6iZG9IljTVh5gWFIMkS9mHLNkqFVOhcCuJ0oIS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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41GsfxlGRNclBSkoIJ4okUe4U2VvsWTJoO7xZOoRKvSIHU6QFKSSD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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 19->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lXkbPhmfIRmypogGrSo1SBPupLQpIRKVfRmhhFFCJFmGOmSpQwuf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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4lI8DF8oMaSgqNKyIRAP1aRiRyKhUSLK+NI1QCkURDWUlRUYhRHZZ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41dkfx7lpmaxjVErJkmWiojLZft4UssREiyIT2VVCCoOyp6ahIhNj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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk8ldkfx+WnKzFihrIvJaGUClH4lL3UJKaimkSJLEUjXWVmpAhJt2yR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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 20->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4lOkbnrAbGbQWlbaNpFVt0klk61baotTmkKyUapVjDqVCtc3mUEmk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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk4lG0bxpUWla0iJZUkEdmSVDgjCtH2UqishRAqJEq2V7wVyhYVo0XJ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk0lWsbxs1DHTNlcVRCISFRmbroQydDHFMyK5UGlFQ+R5IiCZnqIDmE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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41ekbxg9ZG8lyKGt2xqC0WAbd0aaSGiY0KTP2n6WiCSVL0qKQipJo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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 21->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4ldkfVypLkSyFkiUJM5Ut/YbGR1IprVcbRRG6opRSKLpadEdGhOxG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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lG8fxa35ZUtSWVKUJCSFpNKhkJQsSUppE0ULpUiIqEiLpFCpCJWU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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk8lesa3aIIHc4VuegKaTAlGZOWSkdIoZQMIdqHEkp1pCi2KamUDKkO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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk8lWkbRqaMLCHF5BOKUU5FKNXoEiU0slS2bDGVJFuRT7Jk4qSF7MJI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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 22->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVWk8lWkflhpNkaVkSmE0SjWSYyJ5cZmJFiYKESFroQyhySlbmZmMMJWl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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWGk4lAsbFi1IKkopItmSStakuhUV5YTSQkSFdGwde1Ikh5KyRIkSIrKf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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk41ekbxu1ri0YjJGkqNGUpkkwztxMTicgykp2xDGXLaFI/oVC2RKTI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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs4lOkbx5UlWimFKAkpZ1rE6PRVSpoQRWtZQskUcqiQVH6U8+okYdNi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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 23->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4VfkbRwvTNZSUSFQSES0zMbR8RFqezIS0yIwkg/zIlpFdMeQia0JG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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4lf//tlMooyFJS6hQCpXKLcIno+wQKkmUIlEyoqRsyl5FFBkZISt7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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlns81Nkbx4efCrW5VVtyD0XubZsSH1GW0a+fS0pWDEVbq4jtQpRIpJTV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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns0ldkfxg/GJQnluAyaIZHLmJBKbg8WkpSplVQjdyWFyag4qdwbjaRI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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 24->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4ldkfl1Io0ZUpuVP0Y6LBSI2iqc9NQ0Yp0hTV2EmhbFERJRUppKQs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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8lO0bxW1FStZXIhIlv/aElOogWVLWROVFSLbKEkUpWSJJlJAkZF/K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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81NkfxmXVChu6kMiy6LJJRaui9VCj5FJqkZRr2PnpRm6VSy2JrM20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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk4VXkcxq9IkkoJRZlQ9AhF0TDpdS0tljJGiEiyRihrZUoqg4yIiSIh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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 25->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4lOkbVlLtEBF+bbQ5LZXaKEuJuW0pv01ZK4SVWuscORRRG0IHmhxr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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VO0bxmWvFJUipRT1SoX8ULRcIiklRZElISFZSrKllOzJ8oYk2bOV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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8lXkbxm2hxlZzoo0USaJCCeFCHCYqTNMiGhSFd1JatBhEQ5ZKEZoU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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk8lGsbZixJlBxbCG0ijkg5UrraOJRkF58ikSURDeq0IEKdipFQ6FOH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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 26->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4ltkbthSSaCqiNGEUJhkhqTR3SbKMLZGd1BSmkDSJSimGaox9rZB9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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lf/7xyWhskKTRDvhk0i+kheiiKxoWSFkKw3KqlQqKzMjUmYpI5XI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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk4lWkfxw8R78gWKaEkg5RMpGHI19FiCSOGRAvFJJUttIx0shRFNVO8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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41ekbxtGQRiXZ+klNIiKRyVLDuI9dUbYGWSMZjKKmtDCWskdMDZ1i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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 27->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk41dkbVyka84spo5REYdKobpSZiA+KiUGylEFTlGuJFAnDcFtMWlSE
hJDIkjApy3QtRVniuvdaLldNV85Xab2VsRT6nf74Pt/nPOc573nf97O8R9Mr
yNF7poyMTAr9vv57n5pPCoK5OKTssLYtkCBu4Zn7+Y9ycNv5npSzh8BM2PRW
NugG9H/Tnee6l0Cpaef8DUH12LK2uMwoiCBjKMz53FQbTp7NOF9ymUDH8lVp
/A4xdLL2GuilMxhxnTi24FUr9CP63NalEjTGqvKdJHQd7N08L5PAzzp5s7RJ
jCH3bYcM/BhMFVZ9FKg2YNbx6/9NhdD4p8iec0ltSMme4R6YTKDRr/Wr4bty
MJbulW+9CUL/1PTodO/H6qiuAvXbDAYU/a5GyItwIk679+I2BjLvwr4byc7C
7w7ObWtpPXFXDEoEaxvAHjo24htJ6/nLa8HNiSKkP7MOJ54E0rmXM5VvdCDJ
MdO58DqBcLK53HQlH5yrc0dFDQSGDr1JxXVduKNwzWdXFUE9Nz4g6RAfVfsb
nQPuEjSdvfVY+YgI+lPPAn1fEshKRN+wIwXQsFfk+fAI0pQ+e1ZWCLFmcGHO
Hj5B1Bv1qK7Gf6AjnMblgzTeuHnh5W4xEpLa84pcGPi26o1K2nm4fji8spLG
l1+9JUZTqwmGnlc44jMExft2nBiU42GxisuEQjUBxy/UWza8HxnT+dU7XzC4
YKHYFTHVACW9Y6wKWu+H4YTg4JtCfKmLvHaV5pe9Z3r5xPtmvP1F1SowjiD6
zMw6v1edKF/4R8KWDwQyjTNfvXwfi7NBZu/sdxOMD0Ws2ujFg8bqQ3M21xBU
XflrtkJPG6TBFT7SPIJFevf8eZ+5CDwkZjXRegaM/q0uVG7HyV+L0lvoPnuR
jVtdei9qzVwbVKIZbJq9Q8ek/hHmyLGC7bMJHmcG5ezb3I8A5td9Q10UP+5Y
hpe1EMl6kUWnBmk+fN2e1Z36eP7pSgiL5nOog91m59WHdG6JXmgEg3Ex/quM
bEdTwarp4ym0vtgoFtu8Ci0m5CPxJcgt8OqebSNEruPST+v6CfbUMSfLZ93H
HIe1XUPBBAcsdLQ/JnThYGb0hUUCgjepHL+fE9uw33Gb+t/pBCsDi7Qdlf+G
uXbxTdl9BF0uY7Gn9nfDOKZ9T9xHgjqOJf/LnG48Lch9GNhI+xFr1zjS9xDf
73e+qX6SYKdtbEa5hOJRwrj4cghMl1saWOg+BjuSVeNmyECirR55zb8BRw7I
960PJXD3T9O/wruPaK0NWeYxFJ/cxa6bPB+gSvbbTX9SvJordKXeo0JoLrEM
KBogKHMU5sYyrVB5oCennkH7PcUajuHzwes+l7qgiearte9CwFo+Br1k5j+v
pXzhFUpHJmsQ59MwuegA3Tf6zinpGh8eba67jtL8o4YEh318RGDJnOA6uTGo
jdVmLO3y8Edl24pSqielsae+WaZ3kSbWtDGm58sE1vLFukVYPxxeHuNFUNhW
tss0owdn33A3mC1nYFLxOvLNbgEUghJ9Fz0hUK6fZT4yXAdBh1pm+mHK7/U/
dcqZiDAsTMyz3cjAbEm8eCKrAPpRJvbzaDyWw5vJFbblsD13I+4B1f9Bw9Im
2fa/8a2roec0XXukdrKitTrxR72/E6+PYMdFd+NW1VpoVK5ePkLx/aFjRYK/
ihi2th2arnYMnCvGMnJv8hGp0LBCUkQgWfCyVtn0DhSt86cD2LS/J7eW5C6v
gJFCeaYS5Q8roT9eIUIAgdfi+kkaP1VvYopxbcEtld2StkSC8MozF4SiZti/
G8xyofrc0jZ6dIlxH1L2DgVk0f55244bGfzTgDI5a0XlcIJtmyd+kFoKsKLD
/T17mPK7ZcWIhvURqLbu3vkz5ffWuX68iYO3UPJ8ZOwo5ZtE8uzA/+7xYXPM
kr3rFoHv9aiSdZfvo0sj+KEh5YtHX/bWUnEvQtTG+GpOtH/XOm4vc78HL4sI
JSXaX9/T25xfDnPw7cvQcgsaP1utcvVpl3bYFoTJcPOpP+rPKZiWq0aDiXCl
rz/lx+Ht/wbHcHFjVGMsn+q5ePaReKPRHghs9Fqb7BlU9C35ZdF2MTiyra+X
nWagETGrOqykF1Y6Z4+5mDBY+EuNalpLLwZSH6nUmDNw+013VML0QL76qNNp
awacgZmisSEO1Je5tm/+mg+D3K67jZDMMHqSHUv90Ht+1ouNiaj4EFNznO77
ygcViluq8M3HgOcSiofa0hNyoXGdKGxRKb1I/dRDY05exqqHWDxq1rAmnuJ/
1Dz/rqIAJHlKtes5gdi38MdVRp3QOfUTmddO8UX6mu8978LeZxPnM51n+pEv
vrR4PsKlHT/mpF0keE3c0yamhLDzcmAZP6P3Zb1uTLjdg+zRxZU7t1O9/rvF
82ZyDc73jhkfpP3pOyfQsJBrxIf+/10IjyYIiDtMZK0KkLQzfOVZOl8SF9Qn
Jy+n/r5sf46lPoOoq5PCgponuC+VeaTpyWBZ6zlb8cIOzN7cETezkiBJLUT/
U2IvVH43CfbRY7BO6HM+sUSEpLkpCQ3qDF6vLNp3vrwTYtewI79/w2D4LzZ5
5yrCjuaJxSXODPLmHt1rYleBJINat90+VK//6Ubfm2yF/NY0940Ub+nMFN4s
Ry5SbitlvaX6Nb12wCl1WgS5w1wYsxnINhn5qWd1YlZBmG0h5fuFEod8xcgS
GLDz5ThUjxmNoaqsAh5+liTp3ykj4N9pmVoa0g+PoeqBS8kMrFJSvl/vxEPO
jJBABTpPU3Tj997Kvo8C7fS2njACbulGU+lpEZg/17jZBNF5tSHE7MxjMWx4
2cWz6f0bCmVLpNtFyCtTHAhdQPniZRbsWtgOQdIHLSuqr+fdP3S/k4qhtX1c
y/MGg/n+tQ88xvh4a2B3e8YLqqfx9VaDxhZwe8Y+/nVeSO/lfbq+KQfjpU9y
M6h/ydSus4NZEeSv8N5rffUXK/Ylv+4+9D6NmnY6SOeJ+fVLN4zK8NuaZV/a
6funWaZ8WKgoQkGwkR3nM8HD+p6nakw7TO0sj3DKafylGjJc+j5QfBB8aZD6
2/8BfTLKJg==
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VPsfxgkXJTuVdG0pZS9FRY+UFiktSDdLqZCbJVsqRKGNsiWVJFuy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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8Vfkbx1VkiUkooywTYmiTS6MsHxVR0bWFUBFmaEEqW+K2iEIabilF
WiRbSraELq59d+1acM6NZjBoNJaW3/f3x3mdP77nWb6f5/08z1l71NfGc7GA
gMAt8vz/rdVvZz6Y+xz3c5+y57bSeCzz/cc90Q6cZ8prajBp+B9UXvm+vg1h
iy2VNRooMBYb7WqP6ICbnsNdA18KjpUCZzddeA2248Z/TL1oGD1uVJ0xakdS
0tvH9U/4MBCdVKl9+Q4FvfvkFjgUNO68+/rn8jasuWWJ8fJhmGu7hkv+VIUY
Zd3bkodp1EXo2kQ1D4BytVPwNP6A1DmjqrmROmQazmbr76EhuLihwftUBYoH
hkaSttAQMcn2YGhUwbVk8+kQbT5cVtwUFi7oxbJtS70v/UMhWFZ4kXBxD9ht
3plzicPwuiv/r49UGjw2yAh57qfx144EF61PtRARXScXaENjXdDI1yDFamRa
aM3NFlLgKhdlTbZ0I+cbI+A1awi/Coksik6qhNFx97RNRjSC7W+fLzNtR1nn
aurCQwqlZlOTJ6KawPxkvtBCzq8FcfPtyuqgELSYV+BJQ3Xivq1heBW6lUaC
8yRoeKT5MAPYtUjR9PucdIXG07P82N4lb7BVpOfQCWcaqfM9cVNiJWDyqybm
SD0WbLL8rq5thfuSMSsxfQp9oZK8fPk2iBydCBP+lULn15Qw3/gqtLgLeDCG
aOTpG4ncvdmCL12aPD93Cqrl/y1MGfOgOVCisHCHxNNr+nm68SVau0fVRW1p
3DBveC0b24yr0ZJuttdpaOnf4sktpGHXjE+YGdGnaau0nTejBuUS3hqhBTQE
DhZe6clvhtdUh16LKx9sc2eGRVg76ms27iiaoMHuHYgxNKlEy800I+Fp4k+a
Ven8thShxytl7DfScLL5j9Eb0gdr11ldM+YwSromWg3S2yEif0dKMp7C5Pye
n817K+Dyc+Rhb0k+LL5kvz4YWIobJ+JY5YTXkoobE4xwDp6F15Vt8qDBEns/
qn2xGjU6gqWZwjTMt0VD0b0ScSynHFVxPkLlju09u24Ame3JJ/dWDoF7+ZnW
No0eqIjMxBcpD+Mrm7nKq4MHi5AXzjFBw/C7VD3ueLcYGu53GE6+NFzZR+L3
pt9Ep1jElA+pD0vqm+Vo/wM0HlZxUCfxBeh/Y1KWO0J82Vk5syM02hgbO2Nc
0rHd3n9pPKnf5IpvEiPSRL8t2/sUHPnQa5TPqj5SjJJXqy95nqTB2Xy0+VHm
ceyMPscSIvZ6jIBpK/sHMD8VsP+5PeGfijTvUn+Cj98L9mVYk/jOZXV0biLY
LyX71FxpjG5PMUtWJP44DfuYVjSMu7IX1Zc+gknD+CMDkp/HVv1yt7ouiJQf
0iiq5WNJVohYiy0P3dqWHQduUzDXFV1QXlaLcMujCuxGCjHdoUPxn3shk5Om
YntsCGfuvtv5PbwWM/GRvUX+NE7YGFRwt3Sidy53/MADPjR1GfaymTy81GsI
aqumUfR49VPVyl78mP3R/xfJt0nnxdqM3zjoszeT4S2n4Ru366DDtTbclXfI
zW8dhty83acrSzuhrhlx3X9wGC7sobeK17h4IWArujKJQsNGseIRMl9sxa/c
gTOFoRxVS45hFeI0er8d0qGh0zyvrtaWigKVyT3ujjRkOooLuYaFSCp/9eaB
AI0MD8nVOXY1UKubb2KdonCjP8Cv6XICDisa/nTOhcaG3awzC0EJ0Pq0Nz+G
6KmYf6in5EQ7ItrXC3r+R+H0yZ0JvKIOGLOq1XuODKFf9rVPgslbOFQuCd6g
ReZRnHvPEflIHIhr4LwnfBSzBSUst3DhX1Gj00X6fzb1Y62RbgmyJMKsU4/R
KOVZ9zmcKUF7IITSTcl5luCtPx/noU+pPsaezFPZtm1jQU7d4FiniPueG8ai
cSkhu0QOHkwGKyU+oXD8Q1ziJ4NWKM9wX7XkUbj8Njs2dDUXoxZrulNHKYgl
7Z6If9YG1RNL/FmEH47vy+T9DtW4FCGlIE36WYsu3fGHaRr456+rLj9IY9XA
w9vn69pgW0iCsPgwOWWlVHjxCVK+KP3eQ/TY3SXuTxt8wHrmzcIAUn9X18hW
6eznEP2msGp8PeEx0jDus1Yhfv/sJuZB5slz+q03L/kRWktNb7UTnltaTaQW
/96LFEaoSOpiCh+jyq/oxlYhVDk3/WEk+X7D/d2i0224Mbxi0kmQjybn2OQV
77hwyHDyL/9B7A+lv58e6UPI4VNPJC/zkf/i9BhHtg9Fo8s/335FY02E8coG
9W646k1IH+AOQSSxZ/ZicB3M2ELNTkTvVbN7RzTmyH6oeJBs/WMY14RjAy0O
cKETOXq+QYjGl7wML3mlAfwxqqbtNjiIsbyUV9FXi/CwfnPPyDcKgnFZ2eue
8eC0pv/znioafWsrGwP21ePLb19bbltTEIjwnE+IOQabsXpXbXLfQaeVGbyQ
ElRk+vDT/iQ8Xr8w7PC9GuZFE8s2x1BoC5JXmopugN/D9Ge5pB9+0Z5vr936
Hh6RJveG5T9CzWifO0epD2JX5etKA4bBMnRUcHT0g7Ngsf9Vsi+NvdK8f8qr
wvBStXshr2loaIbID7q0Y4MV08dNjML16F8FmEc6UaXjtOPpcT6CjouWKhvW
IizWauB+ArGv/W3G6nwuDLpPHqgh/cLafbRi4YsN/DjLogxJ/lbp739ZK1iP
fomUc6cJLzui9Mv3j/ZANlH+nRS5r4OsRmDesiuI+MQc2upG9sl0b7vcx0bI
WAu84VUQ3sRrkzgqfpjsUnsjR/zV5YheneF3oFxl6uxuMm87R0+diW5pxA/P
1QISZF9acUatExIJH8HKzAtsCpsFGfPFu5rB/Hv8WdQYyU9x6cDRsJsoMVzL
jT1EI9Q9kVsm1gHls4HGpYTH53+tr04Xioda8DpTBunnvw871E6b9SN5/bH0
nlSi30rp/R+ao7BNv9Xkb3JuNTNq77+9BJopcFaIJf4u1Eb17WnFq7wC/fFN
FKIqo8Zyi/pwS5zhdj+H/D8kXswI9SpDiNUSw6/hNPycTCQsMgbgfizadDCQ
Qnf4HcfMla3g7Ku5xzpJ4X+1+6m0
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk81OkfHzl2KSorlSMlWYpyG9rmTUQtTTnK5mYpIZuKdIeSXK2S1C6J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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 28->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns81ecft36kSaTkNr9ChlhtSkR4K9cyRrPVkBDlfhk7JZeIpGG5tHJt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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHk8VO8bRQttWlAqiUglUbZk6UgLQpsWSUJE5VukkIikaJOKSmWnZI3s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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81GkbxsmGiiiHxLIVKZXjYschl0QHKlIR0TKdKCwRvdZam0OUHJeX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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lGsbx51S0ZGlUMlEJSIiopWfJMkpIaFIUzg0ScryqgjH0pAllDdZ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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 29->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns0ldkfxit0G1NSU6aLW7lMmEruaR4ZJKmlmkmUxiWZUCREJSWSkqgh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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k0lA0bxpFKCElSSvaXSlGUii5LlEKWQsiaLCmlspO3jRZvi2RJyBZR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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8Vfkbx4WZRBmpjBotxl4qpMLQR5NGJVuWQvYlolAK0QwliRhFllLJ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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk4lekbx4+ijbZDzZSsZawRM9miLyojhGkkypSyhJDKUmJQktSJJLKd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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 30->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lWkb1jE0kkiFduaTLTOlOEXlEka0TTWWVERlyy7EWItKaqyNDC2y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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VG8bxhGFUEooS1FJkWxlzaVFIluEwk8U7Yu0EYpKiwqphCTZSYWy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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk4lekbx4VEm1Ep04bKOkKFyQy+NJoWKZwQlWPsWxIVSbZSOdlGkoTQ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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk8VWkcxm/GMg0ZlVI019oMQsoSbY8MZUnW0aooZY9SslWSUKRGmEi2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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 31->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk4ltkbxxEz9WpRGdllslUGCdH4+VomlaQsw4wmUdnfarS+hYnQUKiG
qVFCsk5IZMsar53XzmsddJ6KIqGJRHN+fzzXc53rPNd93+fzve/veRSPnrJx
FRIQELhNn/+/D3g65A8ttYPl6DyjwiWwU41dd0SbD+u97uKdUgyGs+7y3og8
hFZdvWuVM4HxFU5wal4/5EX3yeg+YeARmfDCoaAUDT5Vty+wCRJcit6yIyLg
HL0m1+sIQejyB2Xac3nI2tQQftydQO60us/SUi9khZ0WI60YnH5sOPJ4czbc
xvVVVY4RPD0esJ69jQsTqSYpmasEFZsSW6xNu5HUaJ9Vv47B8oVdfltOPYdm
kFKU1GkCraY8m8BzSWDLZ9+fp/VZ/vRI7v2dRnAW4wpOJxLItM14z3V345oO
ny1O8xn3R0sfOtEBvktljs0SQU4REzC5vgs+Z9s1Sul5W0nzzGXdVPC13Gus
XQgiT4WKL9a3wcubWRE+SsAfnDVSdazGMhVH+9d+BMFzrudrbbqwMeGivscn
ggDN4IvLQOOv9SsvnSaQxl9v/NPb0TktZZWSRiApf8DMOqIF6jfrxuNqCVQm
CnVeK1aiJqmrknWBoHCCVWrR3A2TAbe8SHkGhnLLfDVvtcD47vhWTfr9jjMz
DcUmrTB6x9P9poJgqlEpUOZECVRCF/oenSAQYG34bSLKHzPvmlVA+Svlvdx2
a7YWfzju1jweSfl4TPdmuQ9geJ9BSK4/g4NPwx36BR7jEzcwln+UoH2r5dod
k10wtl5RwBenPDRjWvN7KrFnUchT7BKNv1HihrRxFwbOabnUSNJ9toYa95d6
OErWtmy8Q2CrrPXt9yN9YIvtnciKZXB4Bzu5icuHpGLzw94LDLzeOoWVJzYh
IJib+i6BIDtav144+xkM7Erq0r0ISu5oLFgcb0OGWriMbC+BcNaRqyMlPKSU
yZgW0vOaRqTpukS2Q0hf/soqPoHYrsuj5cGNEKoQD3lxlyBtTHj/nXvVGJ1Z
K7IimOBmVuXJN23J4GpsKlyi/aH0bYyhHqsa0VXxqiohBJMh6y75WvdhJNbo
H937DDhlH1yHVqXC9vKWXzWp/rP32iTMmDzY/jjT0udJcNsrOXM3rwr33oo2
BvvT/PldnqwKPqS8Q0J7zBlUWhX3SMXwseZk34tSGwYJebaeb73jsKdYoMSQ
5g9tDRTo3dCJQJVyyXZBBn4ZnHyn6nZMDsgHP+IRDAcEWXHk27F+al+fajOB
iL3ZnxVHOtC3MmmV3zyBXm6sJW+U8txNhkREGAyVPV9/+m0PKkRedM2aMFB0
Zx30nOZj4yFpN9NVDLa+b7G0iGlAmeitdQdvE7wU/TQ7vdiJMmdRbQW6L6K+
a8npHz6mHgtFaR9jUDYQqSC5dgCF4ekx+84zMOKIM7k7O9HwIFP89Rda34SR
gbh5MoqSPV6YUD5xgiM+ejfbcbZx2awJnSfj9TfzmnldqBXX8xCcIrCKlZgl
tQPwvBVZ2VXNoGZhvLavuBtju+u+3NjP4OTkKw7zYxs2vlKcMyommNCSyDHm
duB7OTmZ1SwGAjZaOw5Z/YqBDfbDOrSfTQsWN7Fp/XoRPO3nsgzSdp3/Wl6s
HFviXS7N+lD9J089H5NvxVfP3nfZUp5zpjfud/ZwYWzOXj15jfZDtr/xaO4Q
akyruYW7X2JgNrfQIIULZd2xsl8Cqf8Urbx71L4XnDCZWoUzDHQMc5f7+pbj
rJ9VvT6NL9BW+7QwvAY6r+ZSLH4jcI2WevdNShO8Pn5MEIilfKzT3J92XEFP
1Zm6XbRey0ub/57X5eFwfKCC6BPKZ4qtJT9YiOXJ+v+zo/OqFNSoWDbRDI2n
TiF2j2m/tZ+TvZ72HHZqmRxD6i/Satv3VN6swsH5qubv6PqHpGlPtwQebCJz
Nt7LJbinR7Sdv7TBPdO5KH2E+uHimdS50avwXmd315bmP9jxu2Zo0d/gG3p8
6aJ6ZZd19o66FiE63K0/jc7bTiuzrB0urfht6HN3fDaBe8ifUacyKtBgH7xw
4DzBrX3by1vj++FCig2+LmSgPmJu//vKHgwLv9nq+Z6gS86y+PrrWvxlqTuV
cYP639Sd1Va99Yh0UEhriCLwP7GCFSAwCIf9l3p/Wv0SWt5JcSmbC6AuWPph
0I3A42cnqQafSkxPsvce4BAc5ysNsiJb0bDI8hDqp7wnozKg8SfsJkrm0+h5
xMc59Sp9deDomtu3htF1yqk155/1IqzJ4pq2AYOvHn6XvGt9I7pfm+UlU95W
by/vN1SvwR4hl50/B9H+GOX2zIu2g60dWhA9RzB+wqT34+1qpC07mavkS/3r
QXqRegwP3G0bFqKonrJxrpvVbnTCoerbwhPKDAzCs7wUqtMhnT2WPEV5Dm97
oL7zVQGuFUg8U/Em0A/5YGo+nQ9lwZgNJ+l9x8lVW6vMakHcL9+fc6D+L7Za
wsVEivLmc8c6qN579HOlPU73wPKKoPqYBgPL1uRDko08tN09lhqUTHmGHR2L
SGqC5+erxyyofzsn/ZtoUdWIDxlWXhY03nI/E7NNyg0o2KOvJh9N9fY6fODH
eB6UhD5EX8yg/eDaGQ3VQqgtkSwW1bsu1aNnxC8Xy3vEOUGUf07icGrE4SEc
EjETNnrOYEDo2NkcsRqMb5cdPk/v3x35Ws/0UwdQ5i6vOOvN4GbCmvoLdQUo
0Xxo+QONd27s08JHxyHcT92tIzPD4NPWwGzzzx1YmWj5N4/ybU+9yMT5cRG+
Jc1bkPJfyoyXeyrfBV55s+oAnW+tMM2JbK0/cNbkq+zrVN8v85V5Exb9yNJ4
5C/9O/WH0UExhtOOc915gRbU/yoMG086ri1GzotMsZf0f8NJqubifplipItV
OBrTeqZe1hFBTiUejiwInT1Dee3XHfARDMFDrcFpSxq/8k6d7/ZoPvr2CtiX
Ur8bDsrS4RrWQmK1THT5dQKvjgDhmsx+8MIkiYMtg2xfZX20PcGhmIL+NZRX
q5nFv5/FnkBHNZG9yZXgiMHVpHy3eug5Cipcj6N+Y319C6uSDxXZhHcTtF/+
A2K9wCk=
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8le0bP0ZRWRF6G0RISIRI6kuhlN0gyZ69hWRElFVUklLqlZASSVKy
ZW/i2Hud85xjZJQykur3/P56/rg/z+e+rvv6Xt8hZudu6shKoVCsWCiU/3/r
hDP/U7lYiwU+e7/XiQSk9Y7/Tj1UgGahd7mEJYERzwatAc5n+G2q7CmmR4D6
/rj3tFctnj4e7axqZkCwyfz69bXdMO79rF32loFIqragC2UIS+mHD2bLE1jK
9WVJ02nAOP00O8sLAgry/9b5cZbgTNt9eT87Ah9Zx4WP9lUiYq+CuzYbgegn
AoIr25LwtV0pfugMgUuNW0XKzrfhlsKjh2lUOu41SEYSF7qwxUT6vNpxOjYw
6korSsohbDigu207HdL76ymTEmU4FsMMtYkh6xc/NjS3LxdqtxU3h3TREWbX
ZJ3N0QnbfY8edKhMgLJyuu51XgJ830cuCeqS919J95JpyEJ8Rr9BnT+BspuW
blSxAUis+1BaEU3g6+5bRqfWtcG7iPH1iTh5ruq7NsShBNuOSa5OqaYjL8Gy
rXqwE+fDY3vYrRkYWr3fyaG4F172P2tebJpAyUqkwDGXISyLqx3xF/sC/YlB
JqHUglj/76X1cwRuT+0eZf73AMluxdy+ZP9uy7o5Ik/aIPr5D9vCt3GwyrBV
B39pwJXi0ybP5xn4scqyZMZwGKcHfsovu41iY9rcSr5wIXhaHH8FcJPzNHr0
PN+0AxceNzE05EfhIftMODQ+GU7u8iqDZ8lzfr6P96jJeHjPz0v/BIGg+6kp
fKoh+CByvtDYmsAD8bj6szKd4ErwkpyXHYfznpmwmtQe2NDk4mSO9yNas9Ji
1z/ZEJQf4n1kS2Ag7Fy5XGEPzAc7D0uPjePPXu9E9/ut+O9cYOoUNx1tEtwD
3JOd4PRgObVkQIdXZseS1t8eaDxfol+WGoWGE7d9hVoLrCR/RnR4MrF4T1nO
SLELP5S0Hhi5M7AU9N9jGYFO/JEcVWk5R77n0yVDiZJWRPNdkrmsxkSWRp6e
rmI+qHYs323fEqja6LYY4F6Bmx5azrdPEbBx+DF116sOJe/GJ1OVCSSdtF3W
oOZBTJvHfsiKnL+synCoSy10TxbVPGRjQOF9dOwzngrUJLr0/n8ftlxfrdxl
/BnmXDv8Ih4QCPtusptrpg0KZQWlw6N0aCZrrr6jEoktw2t3DJP4DqqZqlHK
zsC9iOQijjsEPnDnhXTsrcKNOVrO5jg6zCWrXyWdzkdBnEq6gwABpXrTZn0q
FQYsKjJBigz4HVI7Lre6FfwG1v7rlBiQV5EpiRSm4op68MgnTQYoi35doXIt
uBMkT7ffN4aeghm2rULFsKG0Q4GdgGLJPqPeog68dRqTPpbAAPv7lzNK5mVI
u1clGdzEQJxMRqT7gybI3fJOurBvHEkcZ7r4r2TDkCEyH7iW3PehV9nfBF7C
6u08I8OJQJOrymFiPdn/Br/gTncaNLJte2Oq2yBcJ3AjjWUQHQ91DHWa2rHx
AfLyy5hIQIrCJ7cBfH5z13tLMxNqmnmuh9+mIvfw0tzakwTGT65EmZq9R5f0
qd86FwlUGPJZrmG2oXph522K2giyvMf1L8/3Y+1evajZs0w8MXGPuaZWhvNR
tkL0bjrk0v1fFEvX4KnXWa4cBQKau1kPj/0uRfSD6ANRNXTskLisW7mmEcNj
0TdyJwmsLZbfG6zahY6I0RNPSkbBWuK7yqu8A+dsKKwO6xl4ImyZzc5ZCJeg
7N+rWEi8cB/QsHLuR76TlrVYHoEfCsNtJjtSoMbn97fBkEChoGyryt9B2Ck9
WVOcOwIKXzOfi8AF8L339T9mQ0CDWXB8dEcdcjJGUuNPMTATxtPO+7wPA2ZX
y9tiRyARmibKur0BIlbqMRnkvI5eEL0p9q0Ht5cmnpWt0JFUIDXwU7YH04Jl
6v/enYBFJVU9ZbQVi9MKc2eMmYgKy3czdhpC2bXaLx80mFgls1DtlNyB5OCz
rzlTJ5F1RMLqpXI3qjOv25RSSH4UpymJGFWDR1PkBstBAvpnlJx89dpw7PhK
dPh3OqLufKjcxNuLIC4ObbaEUXhOX4sUKCnB5Cvx7PFzJB5ufZmaaMqHqtnf
DXFlZH/7LUz9RevRXPvbcmCGjoOzvDIt19vAop0iWnuLjp3DDJkm4VJ4hA65
FZB8nFXv30jbcgOupgtqwSRfWKT8I7t/uQPsbYxdECOwTVCZtfTWTaQFacKH
5J9zu4LmiYBB3KVfEG4QGMXceju2bzOtUIjZc6722RiCfCx1sl3uYK/qHvdH
JH4oLTHibN3W6I6Me3WK/N8lLihaKjAbmqkec/xkvwmaZjNnRHuga/ZkJ+9p
JqY8P7VYC1VjpjVzfUwGDRHhC1Z0LnL/Vzc++aLIRJiEa7ppKRXFLO9oM9qj
SHZ60dtg24fEgJHxSpZxBGns9q8vI/VPcffJoc0jSM8uOXG2vBuh8vbcgkYE
Aj6nndIbrgdX8KnSUicGXCT+Kduy3ISRXf4COiUEugVft1QV92FqvXW7Qu0Y
tm2L4xMYa8KB7lo3+VkmHI/see7t1YOkSwIua1QJOHAMeA5PdUC94ofZ+j90
RL+Iu9g80Y6Iml9KtazkfoTvbOd8VI6oCfr6reS8jMMCkxZNX+Ei+z1OXjdy
34S9Py09ycIfXZuAdj4C22fCuTusupCUxiFw4M44OM+ybDts0o9P6XSz+wlM
pJ1/9ajxcDlGzC7scib10XKHzKvWD23QfStx6ZfuGPo9fEwuhbdhhYXlYKIz
DYf0SgWyzQZQ18OgG6hPoPDk5nfKBT1wQGzZIbsJyIQ28m1LKEJH2rnTPCcY
KH5+oSmRuw/lfx2KXGRGYCzim6r2qxvSQ611e57SkUqkqQq1dMIvIXFIb/8E
jDWF3xWl9kFBNVExbXoCLhzewrT2Ihi73Th0Qp2AdeZN8wqXakjY6Kja+TGw
aud/qbRrvdBv47nylbxPrv77PrYN7chZ/ypktoLs5+PBG6zRn+HXlcnfa07H
s9bxx9+u9cA57eG8qfsIVuw2THD2l4MqlJl4S4+OQs6jTiFVnViWyC4N8Kch
bU5sMEu+Autj5jZuu0zgggpz/p4kFbs6Qy9trx9B4gfWudH0Tjx3iednfTeB
sgvt0g2KaWBNElx0lCKweMTzhsBqUt93vvIfeUqD5tDbxYGmNsxYioy8uzMG
tdjVFfpsuQiaTBZr8CVAhGY8OxJI6uXXIrOFP5NI25tM+yP3FId4srUXXAkM
hWZ5eGU3IY3CmJFdoEFcXy/IZKQO1EMNRsqpdExRlBnh3/swz9sYWvNxAlmv
v6UUVfjAuCWNYkbqW7HBWxGp1nbs7XE44Js9Ck3zfYtse6pwMWMVsUTqUZDd
jZh0jtfIVNF7fY2sZ5Ip9Ke8twviiX5mqz73wdBV6VHTrW7EY//6nPApGOvN
2KyRf4k867VFjh6kHuce+fuXtwsqnPItXy6OIUmHvvbJm3e48MajvyeSfL+t
R611VJshFxc0JlU7ig1T6sTul+nIMJ2edg4l+bdewXc0IR8+lze2znoTCHSf
nhaaa8eB4kmztrUMVK2SFXq9qQlcm7/WvHv4//2QmhVc/IBU/z881ooEDGzD
Q+6frQetxtDQj9Qzvj3s8raFPkhWfK3USOq/COenLcLOLWCGenZaSpN+Y0Xp
vPdoJp6pS+7bkkTgimjYsqR5EZab6054M0k/82Xf7r5EKmprYtdMvqJhndck
nS5ExWThUZXb06PoWSh73+KXB2mZlnnzSjo4LcyeevFkQDL227oXpN5HXjww
XRbRDso+Ty5rdiZCiy321+1pRMjJGJUGLyaCrMOOMXa9g8mCyOsnXqT+RgYI
Oui2QfGm0V4KJwGPXSbN6l2fwPp1i1UCyd9DC9x7QmJr8GVfMcvh+6Q/LrK7
PaZcjqDDJuEdkXQ4vlnkPXqkC1lvVC4//k1DkL52h6OVKxL6B5YESL6Uvs4+
eWlXC47lrgTmBBKYmV916l/fCvB4HYlu9iFgGLL9W8ZYH5pE38THB04gqu9X
jvlyL7qqODnWH6NhrurzSLFUOzyfCVB/rBpDgBJ1q9UyFaEFJvZTYzRQPkZ4
vvf1gSOHbU8Qibc0UevbXr25EHHTjw72IyAf4npepKEcDSqp0nXHSX2S7XNO
JfOGJXdixNt7TDDfDXQFhnbhbJR6mJBjP+K1XaNW+LtxVSpMSyKB9NV1m2at
uFvBM3KX3X4VA8p3lV9IH23Hw4KLdB0eJl4Gbpy34utGkrPmQJHBGCgVLrum
TsbAwmjq+1ty/vLf3R7W+5TB4t6Rujly/hus3fkadTtgfsuMc6GQjq95V18d
W9uAp4LZlcP3CVxb5Fl6rd+CpEgTBssQDfKvC5frdnaipfGSzjrhMSS4eTaf
Xm7HroFQBT6tMfhwqfxtdGtHoNCqpxJxpF/tlz89n/UaI7GMueHHBNwdzWcd
ZrpxZCXkToHsBKQ//NRwqWtGj7780Z9k3pFT7L4qFFgBxxVF2cV7BPgp4plF
l3vQMlf5MVZnAsc5djXqM3qwl7ug/YQgE8bxm8R9lIrQ91BVqJrMM5T29Uf5
cl2RFumUtkT2K7jEjFt40QSnNc4eOW8YmC0aEpVTrUKFtanyUxty3/9Ve3O+
tw0hvwY2ukyT/Ll0Z7Oi0WdQt58baeZgwFj/Zox0RxHky2QPUGtIvQ1Tqnfi
6EEuPw+X1vZxsMvRXi+yNmOooTqR/psBm6N3UupkE5HvybLvnDOBzIISH4XA
PgS8UnS9uI6J28lGEW2uffitm1G8f3IUbsV0D3GZARzbLxJ0IGcCnJxnSyaN
K8D2bKdJSgYdK+IHZ9ax9kPoYISGGZ2GJ/xsjulaJcj1drQ+TtbD987mhMNy
GYrNBnOb3tJxtFvlR87mAhgb/27+lkHm030hn25/LASDuWg0XkZHv9YmHf/p
TpiLKY8uODAgMXD7TtQ/zVj22q1tlUOHh9Sdahmd96h6n5Mc95z0mzVuPHED
dfAeUirfxDOKjJ2Xrg0WfsYbPg3s8WBAtfbVBSfbXtww+Pn9bA4TmZW6Pnc/
dWJ1QfjYreEJPDOhCv6SryT99C/1F5N01LxTaT25ugue/9y8UTdIAOtMZG2q
BlCc6zP6cngY+kFv20y1PsCeI/iDO+nPndJFbW6YV2L2zNWLPz0JZBhqWRSu
60TJgK2J2zQTsu8ezTuc7YHCtdaWQ4sEHs/9eWiiVY5zDZpx3nUEzNelsY+9
6QD/sL5u7VUm9O2neruDenFELCkx9+AIksQ0hM6HxMOm+e5PDQsSP9593O1/
/eBBieBnJf3bxmzL/h33uzEQO5kYReZTm0dbk/d+vgXq8RvyUiSf0LAnjHew
Gkcld9foZpF+1mbQSPvFIMq4i51YJcaRYRfjMJxTjq+d47a/VOmgXjI8Rbvy
EczwpnU1mQTsRCsPpJUVo+PS7ZL7JP/ceuifKVvQBVG/44/552j4c0baYrPW
IOTk996mTNCRZhl8LUsjF54r02dKWRnQF/w5+NK1AAH3ig5de0/y76mMUGRm
oWZh5OVyCx1bDqRWR/O14fr9mJZ/S+ngj0ndwU9tw4bovivxISS+rfNKl4lU
zO74QDW4TeJJ0DmlcagFXxUPUEwuEMh/3i4j+rkBPd/F6aWHCEjZ6Dy9njGI
P7G0PSFBTEhbr1n9/XEbshaDR0Q2kflrvMwx/m4Hvn75elWhdRTE82qLRZHP
qD5RemwNmU/rUhT2C+b0wr3l7F/Pb2S+cIidn+nuQrylAk/PLgbyD6TdX7Ot
Hk7fjT0Yi6R/3ajtfPdXOfIfplk8bqcj6PatnSZSKXjFxen0kZwXe/BZR2ZS
PwIVL60/6T4OkbiEMwbjtaivOqZzn50BLonjWy55NqDh6MXN0ZMj2Gix5660
RxnWlfiw7SbzcdrGNnohbw76xNO7Nr2mAx+FudZxfAavVRdNap6JKo3ax+dU
a6FwXiF6/ddRmPMrpMaOtoPLtN9HXo2Ant2vK7OZbTCptO/y0xnD1z83KmaN
6lDsTCuxZtIwcn7/plBGLVxUYz7aKTAxwncrtCb7I2Bwff3QCQKspozBpd0N
+DQSG2dP+gPdNd9CAiIHMWw/K+f5jIGMMbG4IbNq1MsetNr4ZRSHNqmv3srR
gJK8poENG0k8bF5ne5e7EeoMmQZ5TTrs91yRt8npwX9i7po735J+qTIvszih
Ewo9G4W139Aw6XuqSX1fOWwvPxNdUmaAahfKY3VyGKFX5EM/kv5w2w/j6JX5
elg73LPgJfepUO3v4BcDsp/004dytxPo+XE+uKOkGJYqsU9HPhGQEY16aczW
Dcouq83PDQgkGRpxWu9IAn8lkVJJ5sebL7M/uOn1g9/j9+aXU+OgPL5f9Dag
Enu3To3xkH62aq4uWMS2BQam6Xf/OUODwsW6Xo+Lbfi94fgwvzQd8XVdUp1D
5VDP83VRMCXr81SU6vGOwUpuAtWazJ/m5e9Z2hSoGJc8sWNxOw1c2W8OB8w3
YKtT62BONQOHHq3lcpangrXv9z1zyVGk/6JU6rF9xuorOwP47QlwHtYayjd6
CaejLLPiegR2/Tv1x4CPiggjzh01ouMg9H9dT47pgUBEN5unOFkf79adC3oB
WMgdjogi75c86ZyT8qAfsycpk66HOnDU6dbqCf4m6MQ+3lJryICI706Jko99
aNDarcIRQebn1QYm0is1sDEvEj2WT+K5wlO1ROwRLN8+1nxyloCPsdzVvKBW
uHK8v4sEGghDhmpaYjW8D8stuNFoyMsoCJc7Qb53pITeFXYyH6p4FNfK3kNa
gTU7jx35/mELqTyh7zBwKuiNJcknPPWTVL5VVMgYTuXOF45Cau5358ntLYjd
sl303580ZNmrbeKxe4M7lAu8PmTejVISVT+iUwOpFTvBO9kE4qX97ff/aSf3
LMKvOWIMPf4Lm1PE30NA477FdzJvWYkZ1aboVsLvxrfwQgqJ12fftaPONyLQ
48VKNOjo2eIqHDxfjLasncmUhwQaHn6L4CLnYeVD/AyPYWBEWcd/hjscaeMz
tpIk33LNTAdda8yHdrwjb2E1Hf45lNMn47pR8eXTdlmBfrzwcO45JduHjCMq
hcKLNPwPPUnolg==
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81dkfxskyimrSTBtlyxZjaVL2BxFFmSRZI7KVLRWRStKMiphSYxlL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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs8lGkfxieHikpMJatyWgppcyhi5aK2kp02p7RZrBXFS1IreSMUNqlE
WdmSHYVEB3LYmA5GaFgxjDFjHMY8z0NEiHRAeZ/3j/tz/3H//rmv33V9L12/
o64BcgwGI4M+/7+dBz6c8imohG+PUuwWDwrh72b45Xs50DT9+WvJLxQYA9O2
xtnOSPdtfa71K4UL61KWOui0wXaPQcbVvQTkbTqMB3MkyKEWj7K1CMi+HDpr
0t8Gr6v9I7flCPCbJq9tW1cBxndZpTpbKajONHI3nriHe0olPzptoqAwMcqn
DDvhExDJ6nWQYsS9tkzBVYDujy6TZ/9LYPniYK/15zl4sOCwpps5BaYgy/Gy
cResInx6N72UgeERkyHMuYiYHG7CTi8K+pq5X+rbOrDnbW9j/BoSn2JtLurl
SuAX6nLkD04fjL8yfWytBFiudzwos5SE545pTKnxsLh2SqJznYTK1fjnapY1
UA5bl6nfQ6K4WfOUEiFE6czArBkoeMz3Dsha1QVW1EjSoRN94N4aq2ojBPAP
srZvZBFg558Xurt0w8GeWvsjoxeMONMbWYEp+CrLGejypHCqiN1prybG+5WK
0/ymPhQXxy3ie3Gwqcgprk+HQkfe2G4FZi+ccr9oqYqkaGKk27FN/gGnNUU7
LZDCpMHQRMx4HZKiOt93NpLwl9YHHb3NR08aRz/2Nomq4YyMrkIh1GYPhXe3
E9j2dvL4s8FuiG9eiJ9R6IPvUwV9tZIqND9bMjXoSqFWlPwoovA+PE3OvXBm
UTDMUduewOYgotPIptqGQvXwIX236BZkD1NPl68kcWtdrzT8dROO9e/LNjIh
ET6aJ2kpb4SzwbLrSyZIvGnwF1t483Hxdl58DEng+K5LZ8Q7RbBw7/t+h4TA
rUbpQMFBAQpuie8zsmQI+VbenywXoUvdw3EIfdALkvtJz7sNcfrlerLPBN6s
0ItUXtWBCC9zlXmP+jDYduGcml0ZvpMGDCZuoPD6rDFfLoOPOWdu9UsvAk5+
sWcqxR2oSTFN8c+XIUmMy4lUI14tFTlUPyShydjomJrVjhWRZ05ahROIHi2Y
nl8pwoq1C0xHrAikzn3uMjrTBN3d1965/odEtXrBxxmHMhQk6meZmdD7aRcP
DZ8phc0yysc+lYLt24RPjzxeYDm3R7LEiNZr16r3N3qLYRL/JzNpC4UQxSus
LPcOTHT/rq2eRsL+956XJskt8NNtD1NKJcFumdLUrX4MZ0bxzSk9CnaVoVGB
mhJw2fdyuI4y8BR1nrdW1qDbglUS7UbB1GikweNVE/yf/LtQ+SOB1bEPMrXT
RYCU6eM3LEM4tHlOwY34Oi8sQjRKIvBO7OM7/7TAaY3xvi9zBKbXf7r078Ja
FAcY8TYsoRDtyVPxG6uHr9wttlcw7R9t4ZEg81b0feP2c8dCAjVtqmffH2lH
xmiX6zMdGaoVa5hk3TX8KD1d4+tNIdDltU+knBislUcqeh4SiBgL25jRVAap
aeyO3w9QEHHseBlBTzDQZj8X9j09H1IxFP+yA755m9jDlTL4zTs/zRDz8Uzx
tHtYCv1udWDo5N8isC0vG5YWSRE4bKoWHPgE0hZ/HflpEqmtAm6tHQcpp9dc
GjWj8GGNta7+OzHOFDUeCLnfh+6bvDS3V21g66qaR5cRaF8QslBqJkRz3g9f
3w30gbc2xv6PqSewUhnY3NhCojBNeti+5wVcC0u5vB8oOD/fHsSp5EP6YSJn
twKBQGW7yQujbdh7Ll/5Whm9v1iHvsNRDyCcMZv3K82DcQGDNcy8A2p+nlzo
XgqLpZZWDwkRqpx0W8ZNZNAwKn/xIKIBi7VKHEXWtH8OJ5qdFlTCJP+KfAmt
z+yhgI3r7vKh4VDosDaeRMJGj6j9DVxkXw/2dKL9dPFubXZ3aztWT++q4Ipl
cGYGCC2rGyD8Zkhptp+AapJFWYRbDer2V02sOUjr57j1zQJ+KzyDRqLHl5FI
3pxYgiUCZPZMH2WVkND4S1SfUPQK1caFUz9XEMjizY5EPu5AUGjMMwnNa/Lg
yaKY8E6oCK4+zCyWQX9vGu/wBA9P4urlg38hUWQwz+XIiW74zepxzOsIiJdy
iEnbR/hjWig/nkzn4fzk/ub/CmC8Mdnu7yAKXtyAS+GrBcj9NVf94TwS6amG
UvUQEUa+7tQ7sYnmq+tg6UL5F3D57cbmPbQ+9i93JaVk5iOlWSH4r10UFoyM
MpJM25BnET59l+Z5ymZ2ePJqMVTTGZO9LTLkpBV9b1ojRuuGrHi9bQR8H33Y
FGxbjSKHTq4BzcuQ6GNbqtIkWK5esVJ9TIaRgM28ZwYSFDZzlW2e9iAyJXso
Rf82mL53HsS4ULiev6I9wbwBRUu3v4qj+ylzKvuuLL0WVZ2ZKUn9NO++Tfbo
nX2Cx7+0chTXUbiZNnfvwd8d6I1oMNWQl0Gr7PVC12wehNEHLoBHwvdo3bEN
Z+uw7NMFp9r1FHTCLN7lMJ/DNE+iGxtBIYu5o7Xln0eonR8dN+FH99tW1tj0
/Q7I5Ks5e7eS+Pp5ePzgQwHS1+q8Ez4nEGS7ofEK3a9Oku2nfAQkkj4bGrQ6
18Gk6EsSQkmwmGZaxfVCjBrbHno7JANrRXD5vhU8bO284XyHIMH9Lfmu5G4X
DF9t8VB/SeH9OaWlN9tFqP/OX/41nfe3g5+K8rc1I5Vy2aFxmoROyK7brr4l
8FcyHF9N563NNvF8Dbsenkzl5tNKFAZ7NM7W8avR1x/8dPcnEu77WDp7QoU4
UnGgc5yg/drmkOAd2YAJXTN7S5o3P5yyZs9pdeKO1EYQdYPCyNqqllv5EqR/
W2Np5yzFmKzp/nUOH91buUN7rOn/aX5wtt5Wjsct4zsmV1E4FvFRP8qrDbrr
4xvMzWTw7WPz064eR9NcUVaLDwVzc97JRas78Weiyl8/MfqhEXriT4s3DXCL
G93sTe+DqT2z39RNBH0LcsMicxkUck9WWbvXY6J5IqZMke6/VXOxRUtuojrk
muZ2XwqsY8sJ1cs82Pf276wfIiB9wY/KteRh9JhKyRV7CutnzP1bLWqh7e2Y
uUhAwTe+uSDEtgOOBa+lKoYE/gf19suE
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 32->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lekblqWE0jYqKYe0WPJrUcjkRkqjwkgok4kjWU6y01FipozhMEay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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k0VW8XRoUoCUWGlBTpVymlCA8VSQMhhQYRqSREZMhQSTQgJGTOUEim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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk4ltkfxiVCaJEQpVCmJEsKQ9ylIkOjka3JVhgukshSaCERkVDCYCLp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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lXkbxlFJKMtY8tYpZFCq1zKacI6rN7vUlDXRKAYRlaxTtohXKhlN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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 33->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lekbx1Eik8LIUvJDyTFIVFJTvkSoMZJJNTnZ18audNGmSWKYLGGO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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k0FX8fFqUiJVla6KfNliRtKB5JqFSKJCTZi1BJKiEkRIRKIip7yE6W
7LJzuRfZ3Tv3WrInCemd968533Nmzsw8n8+zbTO1v2DBzsbGZryMje3/1zuD
F/iovoVQbalNWlBjQvfvelU2RwpGBGy0XYwZoMzmdM5EfsfRG/o4s5uBvIqu
esu5KrAlm9JL7zPBNml0Qr6iEwesnIXelzPhHTid5PmOAsfBY7zSU0wIEvPJ
LWk1CL1zieP9OiYOc6pwpNJqsdt509vpCjoqDPyaVGVqMWLQYCrX3Q8VkemL
T6zKsfmFx6S/IxMPtNYmVJdRoLGUe07PngCrWlLkmi0N7qk98ROZQ7BdnXyo
Jf4buG6vE28UpONOrN+jbJkW3LZR/ExTG0Dh7xUB3IFUsOkaTcRfYsBfUsHj
YnIpGjy2pcZoMVERNtkccakZa7Y9iqK9ZkBrc9Ds1JEW+HdfV/vzeBC8XALv
NTuboWy85RfjGB059M5dNrFtEO2zik7ZyMTXJ5PLRW2/I9+Y64IaeX9JsLWP
sUsALsZxrzmiR8BWR/L1xu0NEEpczB/8049GK0c5a9829LoVaRiHEFjkf6PZ
wV+LvUIbLh66R8B8oX3+qnoF0m++4PD5wUC3S5leq1Y9xBsi6kde0vGlxdZ0
Mr4LHrYBnOvO/0B439e0uaZuWFzT+KtIoyNdpqZ92YkyJFjKnujmYUKFvvp3
svInzGuKdcQaEbge+/hZtz0NHe4qf3f10RHBy/m7eHkFItSCc3i/MPDl0vo+
++IqUORuyeXU0HFqyx9hi7lmOAU+Vg96TEdgyIMOjj00JM31R2WsJeBec31o
PMkHej9Z+4KuEPBfwzzupluCm2cv5JgnMaH/UVA1/3obTLcmcrvMD2JJe8xZ
3LMZm1dz6dSqM2BwOjxH5mY7bDn7HIpiGFg8HiP55lQJhL2irvClMHDa04T2
U7QNrmcVG8fqGOC1U9K9p9aNDzmSO/KVCWiZ9WYUKJeDjeOO4j4lJjQ1wr4x
5BoxyXvA8cMuAib5FpyxT+9D1v6Z1Imr5Jm+N3G+IQHJX3f1w4AA78rqk9fu
pEDHb1Vf3nUCc8/yh/VkuqA0pWG8L3MAdq8vGVUcbYWji1TZ30oCza5Pix/v
70TEO3vLo9uHYF7h7b9Xuhlphkaaa2oIZM1KKZRwN0Gi+nNvcC4DysxG75fz
NIxOu8Ss0xoE28a9jxwK3+KQTzaH4GUC0RbzIe7dFbhQo8C9jTxzs9VL3qug
YXJt0kXlOjpctQsZugXfcWDBaTLtxQj8vx9ynQppwd8037PKzf2Y5fATrf/Z
jtM+fC2LMgwITtr5vLvWBdqFmhVK5PulImfEr6t1YbbtTvJdxX74/yvP/mmQ
DZ+4k1o7nhPg47K6bxlfC6vLsmqcP5h4s5//KOevTpSsH3JV/T6EvJW+O2wM
c+EWp/ju1U8GJo/Jep9Sz0a1VAZ1cJEBkzEpH4Por5hcYdn7+SWB6S6C0NxF
g9qPTSZi6Uzk2aTsbhCMxh81sYrwOwRGNTXyO/NqcYtuelb6LgPur/5b7nys
FTc/WG6uDRqCIN+JVkXpPqSwDvOwzFk4e2bVSi/FSmwqnc1MJOd/7L/3+vfD
2rGhr5HTYIGAmGhZrtDHZnCurq6oVxlEsF7R1SXHNlhHBj7FHgK3H/Z0/5Nt
wt/eaF7HAvLMLfmZrbQFvTW54Q/oBCQ+dJ+XTn+B+TmzeyrkPnwed1mlqEDF
Ck75p+lCpB6tWtNgHVaFOJltVSx3OoLsxLn2S+SDcjvv161QAnln2W2ypTvh
yPl5OG6KDoeP7P5pnB04Q1fmYv8zgo6hS2Hmd2vx/g/nqSs5JB+PZoy53XsM
sSVFvmFjAuxWK3NCeXsx5H7qEkttBMIUtvCenHoYWy9knJVnoj+6xiRE5z2W
BAsU2LUJjF/mjOz8247Haptnpuz64XD5l074xbdQ0KoNCif3+1yT3KjG8ypI
vxyT+BjGwufbSwXQpmLt9Zwn+4QHUf1Hx6U/uBRhV95zvrchYBBUw9Y22o7p
VWLje2YY8FlDb3AbzUNSbuwLt3sM7DCJuzpzvh17mi3UNdUJOH7fXJy0ogWn
IoRk+9pIvufSdrDPdaBzp77tlMgQKgwfWxTpdoGzvNDWW4cB0Qy3r5dSErBC
5hK32kkCN35MwflpN3pZ3E3LpIahHCH16HByF6h7Ap7ybR7GHq4tFOt19aCq
P6g/fJzA7BljofObm2Ebtb77wBwTL9Yc/vM7j4KMID3WEDlfk4NO9e3lH9Fx
7ZXDxCMCaRZKeh0fWiAzF+qtxTOIttO71RxVSD2QNNzEEmLCyHaBfSi2FOwB
+5zP9TBQtsATTr/djMcKH5yuWvVjUqTt69vjTdBL5f1WvXcQI5PbaT4aHTBV
SJSPvTgI0RfZvC5OwWiwOxtpfI1Av7JetFV2DUrKfvpO5jIxXvnft8q9OZh0
H/jjHEOg95brTral7wgPC3J4uawfwWUGWrGy7bD0rfNjqRIg3GyLg0LJfbkt
/Neauw/6p+vDbqflQvh9t5hCFQMxJ9tn13GUQ/2IZnPZPOlfpx9YhkY34JNB
gXVG7ADkj7FqMirKUKVzdrRSionZvi1f9EN6MCc2e2v6NwEHpWxq/OUnmDqx
cWjCgsCefVJ9lh4d+NdO+EddZsJh79W+Yf8uVBSFtngt9sDh9rGAo3NZyF55
r6xxP4Gr0zxru46lokQmvq7tI4FO+SxV7w1fofvJ6noqqb8ZJeu26B3vQAtx
5JGEG4n/r8AdfAerEchRNMhzhoF+4V/ruKnvUKrx6vd2XQJTE7Pq+oVU2NzT
KKqTZMGvtU7NqYGGpW9iI44aJJ9C2C1iiymwGX7e0y/PwMb3Gs/yz2RCZZ6j
e5klgZ2l+wK6bmTjxPqY7i/kPq722P2sIKgWh4JmSkWOMOAkf1T7xgQVvUtm
bb+SelHLZsO82UvDu4WzTj/d+yG6QkmSmCe/PytSh3czA8vvjnj8q+oA/3rt
ck8p0n/N18Wkkfyaf8VslLKiI3pDUeApahuWVtmInosaQkfZBZkcwVxcOD6U
JnqDwIefXp81Zynw8x5rOyhKh7uPUGbfYDyyKXfE2f0JSKvs2cNP4pvl78p5
/uoQ5k4ZvNUq/AKP6bULO6gEyh8qahUJN0OMWfnjTRodSYENht2PupHDOhxF
OzwA4abA2yoH2xBtlMDweTaEGd9SX7GKUnzIG1bwkWQghRk0nznUDP+71jV+
WxlIMg67q/qmDUaGoTz3xwcQtC5Y5MjnZmw1iuVR7CKg7XhctKqlDLdHRcPq
/jIwOGNQuI9oQQknt0qRCQtGwg6qXk+b4K6xtendHAFBjZupljsrwSd0wSHj
IqlfP/VNbphQkFWnwdy7mgFagCH/48vtcFqxXrv68ghkU/V5BDIp4HLPidJL
G0BasX/rRG0qUgVdbwdNMaA9EH8mTKoU2xcC2AOWsVB09GLBgTX1iHj93d/H
ZBC92eHU7oQOHK+3+SJLI/mnfIpyNoaCFcySq7vODCL6hKu8YXQp5JdvGZVv
IPe3TLLBpKwYp9ldCmLXExhaunX0ilwrbmdbP5Um/bsmXM3jZi4F+R2xB12f
D8AhKHf1TD8Vox4/QqvJ+VhbKp67EkRBA/XRlYO8TDgdamq78eg7ZP1e52yP
7gHblvkHJkN5kBAMUKhYQ6A6OH7KIvQLsCrNbKcZgfDgPu0VuzqReqg5/41I
J6pdbmldFv6OUZ/IUaoKA9xuW67O1tJQMnRvXixlmMQvOd0koR7PEx7edK4g
/bRss0XZ80J80w85uHIzE6L1x4MzXWi4OJvdMDo6ANkri6/7tmVCr0FSZG4D
gY2F3uzqBd1w89Yv1OvthcSVtD6PqGz0l3OqZm4nIJTFu8wvvBQ3PtrH7dcn
IO5Xjau7K7FWuvDZ/SUGdBW5lu/n/gb6O5trdsJ0rLJeKVUe3wbJaO2EBxcG
MbY1q0XuSicid/0IJnxZ0D1u/eVDZjUOs0qZcmwEOpTfWk2KlmOSYrvkkk/y
89v4J1v5SpglGUSFk/vCm3g/3HdFHYzzK73kQhiIFA5VeMXVgcnkF+aSVQRa
aY8k79R3YdFybcCRhyxcGwkV8qppAvvi29xoMj/5cHDklLx+gaHt0bYcpD8K
Nwwf3iROQW1uRsF1ZxZ2SInf+sXZBTPGLtOtvr2Y7KS6//nUiVM3I4wyfvXi
7KezG0pJv0hNujFVtmwQ5nI20vZ1bdC2K/LoqmBBzS9KIM6pDZF3t9sGJTIw
59/Q+Sq+Cj8U/eoyjjFRtVGkb56Xhhz1FQpeuQTiBCsv0j5TwZfNVLrLz4DD
REZgStBX8N9jH59wIPOe1Oly7gNUaCuI/bgYT+DC68zHKiMUPNz4njqpSM5z
oX5f+3Q2bCX/G1Mi/yfNq8Q8dqkWchM2xofH+sEusCxobUgDNhqbfdx4kwXR
9nUuPnPpaOO17ZA7RYBmtN5sXqAFNG/Cyp7Mw6G3b2rI2dWi9qiXzVNXOmbz
aksH7SnofigiNLeCATZmpOc93QLoszZFK9UTeOXD7xBS0gVXv4O5kSeGwR96
N05soBzhn7hk5p6QfFlw4X2EDsxwjO2VGxkEK70lQpzMPwPibpKPehmwe6On
GHI1BSoxm73tnhKQ/7cnLsA+FPW3E0f6ybxkbZG68xjzPTqHfqt26ZD6HGi4
Cj+bcSnMbGC6gomI60pPukKK0Wxmy59oTfYF950COj/DoZlh4BBK9hHBnzsT
Nj5pBOvyK+vxMFJf5txdF/Q84WyRzS5lSvpBlQKfyo8CsFxuWKhSCKjYZQc4
e4XgUW+8Nf0cmUcOfUx5eLkba8UtS+0KyTwZPOCv9TYH0qpiIYo7CehIGNYm
urZD6kraasOoEVTQd4lNTX6D1IJ5/VVfAs4+H3mVNtLgb8wf7TpGIP6ZPvq9
anA24uRyqzYWRm0lHxuwtSFwzblZigcdE9qfshSOdMDn0EpDTbIPJbXzHJi8
VYeR0vTT/LvJPG0mFHPYvhvn9p6/3uFF5pMvY+7mt1rx9sC+YSrZT1X464f4
CgohnGR17xaJnwrf1M6xBz7g/29x9TnynLVbXH37gReolSF+vCX9+qZiURxF
qQRWZ+ou85L+7/TwpOAbQSpErz2aZ8wNkP2rek7zaA1k3kwqvxJgItpG+0R+
RCcCTSv5arV7oD790UGfpwXfC1p5OalMaD+7n/bzZzWWK5mJmH8hILnXPSOp
rB3P6dcLY5MGMOMhEi+eRcGRFOLCfU8WNqUsj3pu2wRohe04lU3O0/zgYX3U
I87kDTNvEwtVPs4lequp+HOuHLGNAxA9bCJeGULm04MZ4wkUBmbPvxG90U6D
zpFlXNxn6IgZ8ZDQGaagueLJjLfxINScrQnmsnZIOCYaKcuy8ErmunqfEBWq
L/hLKlcP4WzuKV6BNir+edbF8cf3Iq30oNSwUDs8TV5EZPEOY1rY5rfIQjUk
fl/Qdw1gIOiWvVfH4FNUXYwv17Ei+9Wdy+48e0ugfPIxf8JqFhKyMot9FdLB
pmV67kA+gbdpiYs+tQWwbk1c40/qz6LZWoa7ZDx4m7KXGzsRcBnvoFmPNUPi
XH/8WDsdks+STSzeUGF8/869yGUMEA4TpidHa8GW3Pz508EB+KXcT1AUb0OY
1EOBkUcDyHu4b9+/b/VoHC09IFk5CJ9NezxLZLuh+P2If8ndYXhpTTuFS5SD
Qq9tinUk+SETZBi79xlMqgef3yD5MbW0Kub34W4ERSXF2c4MoqSnayWrOhUC
fMq92TQGJOK6Q2dvpeOd5PmeyUwCshquH+ZGYvHi38Ole7IEBI7tP9SZ3Iob
zZ477IqZsJauUutLLsaPzD0rEwgCE8ebLKr2dsL3+Of0KyVtOPbUweltTRFO
Syd+XkPqGV9DNV+QSAtU/kxqXqkm/e6a646qtblwGmqR27+DzL/v6kV3eQZB
TUQi3cCQQOrB5qw/+jSsX179SThmAJrV1+xMd2UhXlrg4Hky/6uOOI/fnaRi
i9ZsvsV3Mm9tDy1ufF4GMcHSTdQIAmdyjQq2HyiF5ae0gL/VDPjqbhWdn6vC
t6fK3vNKLITapz2xjW3Ejci6hf/+0vGtNjlxnOc7UvcXb752nAnboQUtQqYU
Bd8E37qR/fdA4Zf3iiLN5HOlere+DCHb/uWl6pVFcHGdETAl+4JsopOa4pF6
5B6/+DaXxC+Vb12N5uVSeFnuHzd1IPPKCyfP7W7l2Hnlo0XnVwbkt3jHjZ/P
RExIKMdKUp8cc2uCzySVI+dwarDq//V03cv95g/Ifs7cl3jahIECKvVkT1Q5
tL6leOh0k34yIPt6R0gVIrmrep8lELBUmVyoI/l8+mjFwrUHA6iIpXa0XSnC
mLJRmeFWAprNx45ldxRAj9HUqEXqAb0nWL1lZxsMsp+klPQz4GojzDhk1wLd
Q7v06lro4GVpfRqTSEcLMzG/pJX8n6iiZBXFdJjtcGzoIuejmyUw47GBhjKJ
Za6bhgmwlT5ouOt5A6y83zR3sj9ml+xs/ibUgQDvpG27AgbhIJz7xa2TitaR
m28/ZDCQVvHa7eu5Vui3RMrq5dBhIn/MeCAwDQkVhNFBsg91cLEFyiZkwrXk
wScPsh/I3uvL88zKwM3FA896ZJlQezq8JTm5CXNJ6ttkxBjo9uv3kbavB+vV
huUq6XSsG/rYK70sDqo2PH1uZJ+Ye/Orw+haGngr28bjV5F4S/3yc01ow6Ec
Ue8FbwKiQVmvYjxq4fxxYcUekg9bPzea36S0wmFxA8/18yzk3ZocenrxK86p
q6bGjjIguzu9o/1jMdh1vT41kPnkmvBE2eutHVDSvsTzNYDkv/yP7rzzFeA6
7mmjR/KjXkBYxZCrE/zyvya1tjMhIdG+ebE/H8Lq/wq8RAnYePo2FbeSfc40
W79oiAXzioCNo2HvYVqzZ2uLPYlvmFaAQ2cC8iTljftI/J1pW51PEtXoiZPm
kLFnwkup0eqxcwnUPGvy+dlJvzUzUpjYSuYa/+nFhw/GMKPxLKMprwE52RPT
S4kshLHtUtYtrcLuHlUbygIdimzhT4rQjtT8iJ4A/z5slP7QVUfmSbaXm3X0
9hH4H+WHJrA=
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlns41Nkfx10jpdyy5bLYdiu7KmxE0tstdt0KXRQpQiWbFiu1iXLXZV2K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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lWkfxk9arEkmUVlrRsgpypwsk6skQhpjKd42cYRIKglR0pmcwdvI
rhoJEcqWUsZ27PtybMeJwznPQyO8al7axvI+7x/35/7j/t2f+7d8r+vWcLto
7yFGo9GSqPX/3f6Or/ham3YkC55llxuQMIz7YUptZwPK2JlrvT1JxP5mpK+3
Lw1tyYrLrDMktDRGjqVe4OKYAcNrtbwQcTMOYeFl3bCR3FfIJkU48Lbf+ELm
EP5S2ptQtG4c1tJ2J7czarCQ47TpkzEJV9V+Dzm9dty3FUWphRBoZg1FyW7q
xPCBIodfPAjIBrsW30htx+hCVUR8NYG5D0RLWvYA7KVJNW01Iaad7frcngzA
p9muti1SiLRcjQC2AxdKdu0rzzSSqP8af+iE51tY6fea+CmMwt/QJrdmbRf8
fKe75BtFMHt3Mi6lmwPB4saif0eR0Itm7nZOKsLs3ad/TPmRGJzMOMHQoepj
ytdkNImgnEGrcVwqRsJSRLSeB4kNdq/U7hzjwSkpd+37ZSE0jRbfeN3vA9/W
UqVwiwhiiWd9kpK4+PFdoMusLoGa/h11Ls+rcG3An81jk6jlulxNCi+Ba5+r
kqU1ifRAA8VyXjfMyhK8v2MQiHXaRffQq8Cbsp3fIiVI0NcrejeYv4CShVpd
73Eq3yLXvl9XPcae89nseV8SeXmJrqr8QXBWvNlBZgtRY260KsSnCQXLl9F1
isCavX/4nu7NxbRYns/tEyQm9rKFRyr5YBi3MeU1R2C+bdOlQ1UckN+uv7hg
QkJAmx79LrEfIa2J9IOEEDE5EUGDXlzsqal7aRYjhFZBEC+Om4L3Wh6Kmu4k
vjxd90zKuAYx57P5QV8J6BXoF7pub8UXgZOpHMVLzPmD8eyPg/C8rdx7wZ3A
Bw5NfuFwD+SGEnalHiThKbKSaed2Is5dvOTnQAIPReo69IxuROarNkVpEvCP
nPBix75GyLHqcbNfSHTXbxzuvFKPMwqPC52uEWBVHNljYjGK2un5TO3yt9g/
tfmZtmk2DH5OKTUxJ6Hexo6qdnmABSmJoo//IsEKKWQp5bRA6vcjYWFCAmzb
d3mMeQ4YoSoPDSje7GhzPPGhOIxsyg/WpOJ9aVfuralqQeNs82L+EgHG3Jkb
AdMlUHBmu/HtKd6sA460Pa8At160WLCehFxq6mNBYSMuVyjnnyokkG5t15DF
qwZN6lXIFpJAyrYLJ7u9qyEr/lBchppnaPh0XP9SNx6VhwXLOosg4cme2Dtb
gid39KT7KD7+zvgpPq28D1H+z9wNOwi8ruKW5q/MhXp0CKnqROVXZSk9HZGC
WovNdGOqPwj5wrnI6sNTF96fyvfHUMFcs0VlbTYc9aI6tlL8lqaFtZjc4sD4
wIHBugICmioddPd7XMjxQ0+qeRFw7aSLJ5Tlgu/rMXf0IonD5d3/6RnpQKJC
tM7+PVT96Uotjm5v8aqWtcDXofiv1CJ/Te9FUcZPzdIDQrh+mnpiLWjG7hmO
x937BJQ3XLzUJDkAN+dILsdjDGTJt/oE7QowJ1JORbBIXIoMvSrBqoPU1Op9
l6KpeUcoPjprko+Z3ZoVJUyKR3UFH2ZIPb5/HKZrRychwRBTnZwoR5nHOVbi
Sio/weU5y81leHayziFQi4Tu6QjayRdDONRVkNWsTsI0k5kko1IIl/dWc+eo
/rC3pxrlPRjCzu/cvygbjIGWmxD9XDsf1Vyjy5+p86g/e/PDHXmYY70aS91G
6UkyorP123OY1c7+ftaKBNeefPF5ayNm+DEJt7xI2B26U5p7sB/XJ83HnSk/
XPGggX6cbMIXA9Ur16n3a0bXW0wHP4XfV/HY9XZUvM/klMpZHkK/uhimFhPI
3mr5Vm2qHaefEIpmsQQOuzP59z9xsM4q6euwOAmdyGedUdspv3vMUvGeESFG
Uttxx/E6WLQtprRdpfzl1vWFuSAuxjp6/SedhZBZEq5fZLYhOUeSzmokQGrY
Biwq9ECQFWpj+ZCAec5f80MZTWDuig+dJAjczZPVdbIZhJbNkPC+mxAiq43P
E1YOgqFn+t+GHhHkbDQW2mfKYH2I5DdT85ARXPEThnNgcmYmf9qGRLhErFsr
JwB1GdcyV1B6nzA7odg0w4NzitFskIiAzD9rwhOfdwCmoXd+myQgOBOYavxq
GGm7Nrsflh1GdvE8tym7H3L9vfRLQaNIF9t+U9OsFOfkXvd8MKP+n1P5xntS
epE4z+nxciNwTNVfJ72GBwFDMrrORITmo1Z+S/QiONOmfi+m+L63Sj6dIc3H
vc8hXZlmQvBqHMb9JsvgZfnQM/AzgaC0TxoFJV0w/tK49dcwAjGme1WPlbUg
ID/Uc5nSLy94S5Gudx/E1t5I1Z8Wwp1mG/uotQ/rZI2Oh+4eh+/mtGFmVj12
RBmLvRklELpLrmBz5QB1L8OtPEGEGrdqiWVrLvjBO7NoLwnY3rDLG9/BxwWH
7P7l8TE8Pb9XMMPoxECpyYd39wgU5a6Ij1yuRPLdfd/UPxLYdq7hpYUiD9uk
F4dPU/63MDbCzjfNgHrOo231VH/lZDcYfVzsgL9dC7/AlsCKqciujp0lCF5c
061/mfI3D60D+g110DWbLTu6hppH8kW5t5ktKFeYPdUKEpc3dLPuxPRgYSUM
2jkEIizS1nm/78e1bHqNTI4IekkdY4ZGr+B2W3/X30cpPQzSOfa3+jEoP+Kj
JSdEwCmpl54lxQhaZbGhYAuJVcsNf6aqNeL8cG5wVgmBfyoEoricIRj8OHFj
tRoJR8OQ+uYpLlpv7k9/sCjE9+c0E9QChkBLnjSn7RFCZ33R3VafajT+IfHz
iywSSgWW1x8rt+FAgE5gfi4B62KB9QSzETs4Dk8IbRJ/cSaZ4jdbUd0fnVvk
TeD9KqMit/P9GG7rnNRPFYJWV/2y8YfXkGQ6r2wwJTEXaKozSPFTbrTRyvUT
5a89D7ObbHqxcfUR+74lIfYbC5zVZ+pRdVrhquMWAlK37TfOh/OxbPheN1yR
QFhaITvZtRdpXt/KbMwI7F/uKY6vLsOLf+5pjFD6jP1xQkL8l0o8UYi/XjFH
IOpoaXSlXS3sG45XXu0k8D+LNrd0
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 34->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkbPyolS0TfJC0jocRIi1LJj0bLaBpKU7ayz9jiDE4Kg1QmJKaQ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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lA0bxSUVIkuvsrTInhStVDhEpV57soUklSVJRBFpkZIkSVIhCWVp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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk8ldkbv4kQyjIGiQnllxhakIgvUVTWyRIpzKSiIjW3hEqKMLZspUwo
ydh3xbUv176v137f96ISTaK0mff3x/mcf87znPM8z3c5cr97/ubKRaPR4qn1
/52zxsJ614camJi7KWgcJNCzl9foaEw3/PfRV2NOkog9Of2IbtuLOK5UsSAD
Aioj6dsiGgewU1hsJOQQG0nvpHv91cqg7fQm8h0XCefEmZfthgkwW/5pXpyK
b1V+m/RAkwl2k03/S30CAb7fl8Tme+A9bkp43WJDXszBOzeiHrM3XXw3vyYw
Sphafz7WB1W6prQMN4mhTT2B+9X7cCVjPMTKjkDwG0LQ5nUF3BPYR5UIEvkL
0+anLjZD5rT+x5qvBCzrgn++PDMApaUOutJDNlSW+Nu3ro7Bfdnw271JAkYF
+Xp8w08x7abP7eNAQrFW/Z5u9iDobR8P3/DgoCnUZTVvth2vkkLigmIJRASt
zH3kH8bH2M0sWgGBnKwvW2m6/dAT7jkaU0xgS7F/psM2BsyyJiatMkjM/flG
uqyhAOYCie/1j5EI31e1dceLXoSVM1zfiRIYrrBseeReD3lunhLvIyTGZzNM
v3rWIbjznJuEJInkFkJ9Pi4LLTPN7CuWJHIkntKZh4dgnnS79tYcifomi5k/
D9bhQPTUHsUVAserK019lTvRyRN+XM2YxObarKHvFxrQlDBWumxGInieRY8Z
Dodtqn2MGVWvpGp0hNaRVLAScko+XySRyNyrwjRqw8VJCe/IZALyS1Pad3LG
EMBbUPKrJtX/MYW4+yd7wTXPfSv0JnVfSZuoXvwA6GuTBXgt2ZA7+eCUu+4Q
ZL1iVlPeszGnP9QyzdOLckObA74mJNK5f8k2EBkDt+IetSwq3/7B1q8yJYNg
GVnpeQuSYKjNEX5nytBGikk27CNhHGi5dlfVAJYDYlOmikm4nNgmthBYBprz
q46NIiRMzF52egtXofzZj4wiUQ4SGZzzn4e7EICpY06PCRzwsxm8zhhFrBrN
4xqLjWXpKn3v2V7cHVqp8/IiwBeYF5LzWy9a1QteurWzobrVJd9QKQZZkq1P
4lxI9F4uVTnPw8KLrl0i3MxJhHRkpI7rlkObu2bk2g4SnGkWI1a3F3ZJCspf
pNmol19ds7O5B5fXRdEC/AiUBOYOlVu1YjbLk9e5hsRVQcL7M18nxKZ/0JIq
CRy0YH7qthmA+/b8JwqFBIQuGj+TleuD5+3t/OF9bNBSti92KV7F4jar2X+d
SFwaEQryO98BrX89DGS6SBx6WWPyRnsQ6smy/QkGHOhxFS5lvh+CxzVinqt1
Cp3zXKd0ttRDZFh81LmbgL9Wo4fQcCk23JK3+eJIosC9/cQfajVQKOY6JqxB
YoeLm7S/XRcEZycqmFfZ6Df8dTbw5x74qb42+HCYjYcMqZqJ7mok1mv9eiSU
xMMl/2VxqVdo4+vlXFIkod9wQex7VC8uFKxtdSkiIePgyvCxH4byD8OsaWoe
fjK8sy/25CM9xPz6Yz0SNMHT+zIV4+G444VYrRuJ6seq0Xqb9sJ893mVPVS9
ThzBB7SAMdTeq7CqZI+hifbVR+tUP85LLR1ciubgqcTZj5WmBQgt3O1rT+GL
7yhyhe0ZOKWTYCnTQeWLvjDO+rsA9l/a0zZ6kshbmyWXF8GEkuZETMB26vys
ta2yXRXOiRSGiA6RmFw3FVgr346bQRbNU/4EmujS6TrZmVgI17C0oOZ993Mi
/czMCMb+6JL6J4rEFos1daIydejoVokRaSewLpgvakynDz3t96Yvx1LzsU1z
OnOGhbQvHH7js9PwNVp9auLUjQ0iUkUbH7NR2vHpiPNDFnaKyh4oovg6tFY2
YqGxChNT1upiFP6urtybG/diQWNGa7OUGgHxpOE/Oh8Oouxx9yGhbA64j0nK
z0m3QV7yelc6g9IzkabKNPcmxK7c2KU0QEC4/fedX8cyIYcu++8U3y3/+rE/
LrIbixU3JHi/UfyckY58fqgcrBn/jCYFEretq55a9bPwyOeWSezMBFbpUxr3
w/rAb8RfeCaUg6IUhe25crUgRaolNpiTeF8d+U/lxQaw7haHCBzhQHSqwcj4
ZB9eZa1/fb+aANvYNH2n9zDID8rdktoE0o2f7k6am4B74Adl7UvjYJg3L4xu
GwZHnJ4ZNEbi5rGQ0ujiRvCc1rg7F08gjGuGISbRjTPPmwvXV5II088VvPK6
D4ohTd0jZmzwnaUnPpLsAv+VpX/CBDio1tMRrf2LiVscl/qAdSSK9qsKnTze
BVbTZ7cNFB6Ewze3qx32xW2lRd9rFL4a19slE4eGcb85Ii7nFYH6T4GDsodb
4LnX8zzfAvVeM9cWx5UicD/XEm81oPysb2T5TRQDrkpipTwHSTjeDz0ilNqA
1FhZ0pqXA+HJRYarSA3SE+O8BnQofdpB8p8tKsEeax+37DAS3EyJdx+sRtGQ
k6LB83ASKu4nQvcJMaFZO7pFjNLfTSeuJ7591oXI03c0pPrZcH9+biA3tBE3
33YHl8uR2JkgF6Zrm4wt8k/eitmSeFQfnLbYN4BNlm/1rk6woab68u6WwjJ8
HL1+n/2BAFF+6dy+XSPQ1F2xvcOcQk5r8XGhvF5EFb7fNqbKRnCl2XRaawnq
VTpT91B6wIkqsrgRUYHdDgUj/1Oj8Pv3nYC8v1ohtP/bwEQFAZpji1rKCTOk
Zl7+SZvqn3/+OkG+w7WIcrLba59CQi5Po1tPdwCX7DN4I4On0Padm/lIvRVj
7SZzDyg/DOMoL8UXFCL7qJ13JhU/Gm6orp08hCf5rvWOtGlo2q/bUNdfikzh
Zy7mNhQ/J3ykjzPrsXWXhIMX5Y8OHR4T566P4M+4zHdp9EmkF/dsFM8vQ5+A
xer4FRJRcV7KucvN+B5/as3d/SS0HHz931F+axHt6PYLhYeCgfiynB3DEFgK
NV7rR/037ihZ6o2M4JJmrKly9jh6DLhLJHYPY73TwvNXn0hU0i4Gtwp0Y9Zy
0sKQh3pv5ZULNOcOMIr9fQT1OWhjJrQt6jdidwjt0BSdwPuy8CCXa4PQnHL4
tqmLgPOIrY4VXyTia408uCg+/wdQO7fQ
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns4lOkbVvkpsdUuihxWJSs5n5V1kw5TQsiabE6hsh1QtDoocly0jtvK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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 35->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs8lGkbnlRSKvYTq3JIByWrjSmrwmWaioYvomTLOlUqOaSECjl0IGpJ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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k4VG8fpiRbUVESUaSiohBFbrRZWmQpWuQvhCTtqBCihYhQIrKlKJKy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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk8lWkbVkJqsmV8SM1RiWxRDF+qyzYqES0YYkhCKkvKUjT2JFkiyjJh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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81Wkbxg9NKkwknRbNvCLLyEjLKFqukq2SZCqplJGtkCUVGi+iJiUZ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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 36->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns8lNkfx9W2UoukJVvUxEZa5bXZXxfb9hG6sEhFURi5bG0o93QhkUiU
3KLEEBKZxqUIL2tcJxm5zAxD6eI8tWtXRkVC+Z3+eF7PH+c853v7fN7nWeF2
fI/nbDk5uVT6fH2r/NmSU5XTitvO2/MXpRE032oKDDjdjWV65bvjBgji+s4f
P6hTh0yRWCkmiCDGRrX+PrsFbka+W6xiCNLZH1v2dfegbXjwvN0eBuUb3m6z
0uThgI9bcqM7QcemBV+02ttx/idl/8WNBCYd1ZWBg5WYSqpleIcJJF51cWWD
EgwlGDWfXc4gNp0b66gtQuO8lSmGEwQuPzitnRoXQMeqsSYhgaBAwdl/z7FS
cNq5kfc8CXjP44O73IWQvJ0ZdX1IsLkt7EaCwzPws1tMAxIYJIzcsTqfkQLJ
00anXDbBRvnnqn3WEgz7qecH2zDQdNmnoT/Kx6U7t+pnhxDUpZQZzlWuxpOM
nSJfbwJF3coYzZY+5LGb5xqfY/CNw6hzb2wvXrwzFZmxGegbdlnPKRVDSZDS
H9BD96/zWJVr0Ionsy/OV8wgqPda8qgmtxNySvslP5USVC6MfySreYwzlQXJ
y2i/5Wsz0+T0+xF/QH+r6lYGEZ61etfbelCzbVBsb8/gVl3k8N4YMY75tcxm
69L++i1ndbRWoXbe2gjbYwS+d3oO9lvQ+MfcT9sqMjDmTB9QK2hHyCxtfmYi
Qf4nU/ubO8SYis+/qbOAgclysf98aRlso+c3e9L+BS4QTBuP9eBiEcPJpvXw
BEYyo/s8COTjc/fSdZ3W33KR3YXcsYf+Ck00/0Kx5RHVTuhJNVX/pPP0zktZ
rxUohrHKG+PCIYKpWrkOX81e8PwdtLwXMfBQm/jeRK0NQnerPnE6QcIGB78G
YR2sE8tv1wfSfttbKymqN2JYMr6vJJJA7oHS81PiLhjd8Ewl9Pzi6PMhGxt6
IPmHZX5SjwEnw6Li6usU9F7irami8/zj8sukuEABDBas1Oq4QjBQVOCy07gZ
S0wu7jAOJzA4lS3zGn8C9bH+qphHBFsLQxjXoGcQlqUMJAUwmBcV+0D/bAMM
HaWJtWFUn/3rV13+eBEJrwq5zvT8rMzBUoFXO3TV94+23KL68/kSusyxDfUF
jnc0UgnOyTOLZq6LsdPuePknWv/d2gfXeNrNeKugWySm8ZecNvyu4Zsm1Of/
23o2lECZk3N2TLkTLzq0m7JfErDGJc5lbTX47pDOsmGqt+Q04eYLTY9xXr52
TlcxQbBLTM0aLQnyjs3MOzVOEG4ni/JeUYc9ScFhvtSPWw6m34yd1Y6sX9gz
DbRfmyPXa22ffgqW5UC2YzCDpSFzsj//KIG18QscVGFQui3nD6/WXmTI9iWw
jBiwPoRt5mvcw+T0tl021K+5ln8Llag//k6xMftmHYNVUtauaXMRJLsDNFtn
CHZyZu11iixDb9pZPKb7OVFawgaXGmSWDHeH+hLsfV89eN2uA9zTg/sUyghO
3nUwmnuoE8386YIwLq23+trI0rBMvEpdOKnnSvtdztq5f9FtTG1U3lx/iCAk
Qerr+m0XCoKCU6RjVE/+pmbdz3rgquItsTZmkOyeurAsvA0Rts5vlOg8RBr9
pkad9dA16Jq99CTlk4/umUXcx1iflRUl4RAccJgj4/3VAdWdUXE6NL7JmN8a
ZT8uDie8jD9K89e4U3vKgvTAnL241GINg+btKSOp0VL8l9/JHfNnIGsTSn3T
65HbFxFQe4J+P2vuqKzrJlprnY6MU33I1i12HDXuRNmLdtZTMeXV+7GcoIpk
aGgLZV9545tq+Vf0r3zYNDnWeQYT2PiFXfVjd2HkWnKJmZTgUWGi889Vz1DH
kvY/5TOwbMr5xfX3LngPXltU8oogbXtCb+RQO7p8ouUC8gje/c/PW7iRj8mJ
qfGsAKpHM9YKyyNPEL04yGJHCYHde3aAzq0S9LE0deI86PqKhyTsxnO4Ddip
5VUxEKQO+ivaNWKX/iT3GtWn3KWgNK3uciibSIJzD3+dJ0dhXVA3RMX3/Bv7
qF5tbp6bdKiD0E2rbCXVm0aV4ZGS1VL81ThzVJPyae2sX751N+2Hxn/mcAaD
5Rbekwpzu1A//cp3aJiep/KxrUCxFB7OfclpNB+BbvarKyuqoRkwE8L2ofH9
tzZ83OCD1T+aDRrRfrXO+7B5U2cN1rZOBcR6EZyKSuQNx3TCoEJee0MRwags
7lr7JsobkcJKz+8ZBMTdKD2nwkf673/YDtP8WFfqlnD1UvFvsVEbl56nvvYy
QvMlmKj4O7TvIINpLZ01GtV8uP1qo6tLeV/6Jr53nPKmvkGYJ/+JQPvEo9LP
B8UIn/w0t2GU+rnoXYwoQgLnHOPGOZ0EuvcfrBv6R4zZjjcyLlKe1rBPrf6N
0wCe0Dww5zTlPceieHx+N0LHMs2t+gnaPf4cGzLpQETdR10mm9Z78m2SS1IU
rDI4I7tpfuGvlZ1UM3uh1HvdMYLen40TeSpMch12nd7hM0r5/lOx5e93wgdQ
YJ71yu491ePQlJNjEhdHwxm7UjeCMxZbds8qaEUYf0UQJSYyqg6ZqtwXIDjK
cvezaILuq0nDYxkFWFWp4V5J/eW65NtLZeqPcG+pRxzrDMGne/te+H8QIjBE
MlFTQRC5oej26A8i/Bsx+FHlA9VP+lPu1JMaWJdbFu+ifOI5vidu5UII9Ddy
OgtoPZIwrc85kVDu0txjQevRvHvG/sTyx8hpWN12iPrT1sJyk0nKc6xaeqF7
78rXELwu9DwxIoLB8zKDd1QfLim73DjN/VBrz3q94DgDbYHFl4aXj1H80NC+
gt6PDgv7+NXmbZD1jfY2X6c8VdpQ4SQQweyNu1HMQnqfMfxtX4yl+FBRejjK
lsHT0HNpRxtbYDzj1cej9Xe091ZHySS4kB4rcKb+7Kn5nD9ZL4W2tmIhoX5P
VPhPy369BJpqv2GtOoM6JjXEKOYCPommnPewv/K80F1tsQjTvDVTRU8IJubz
vWYo32sSRfpecQT6rIHRzCv9aBJd7dcbof8bHvv9716oxxYts4IRysP/A9DV
3Kg=
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8Vf8fxyUrMsK3kigyGpSQFb0osyhpiBCSNJTRkFIyUpJIyaqkyMxo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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwdlns4lGkfx4cURejgUCtRORVLRJls30pHUdSgrSkiUeml3ZLtKKdaciqJ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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk8lWkbRqHlUD4jUkSIRknkU5QLY8kW6lCTfY1GoSFtluxLSWWksSRF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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 37->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lWkfx1ERmsSLiWQQES2S0qbvlUmDqBkpKkX2SrY0tkZKi9ceQods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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lG0bxkWLVKK88aJFRYgSpUnqVCQVKktECaEsRSVJSGUf6SVKSmSL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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41dkfx2Vs0UhUI/wwlCRJE36i5k1lSZGkbNGQIjHJmjKlbCUToUW/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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns01VkfxuUSJYqSpHIJkzQSGmLqEamJIWOkRiqSS+5iyuRMcUbCIG8d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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 38->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lWkfliUyg1TWKWnzhZo2xUd1nzJCfSoVGppOhGQrUio+ZCsZ66RF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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWGlcTH0bnnZSpHq0kXhKiyKyRHElSZKEkLSgIgpRlArRIlFCkhRFmyTt
2rQvo1QzzTRN+zRzZlrIrieVes/76Xw5v/85576v9Sw7cX6/mzCFQnESolD+
f53eqObIX8CCq8yKKTHjIQSVJAnXykXhZiHXuOwEAcnPUiZZxp1osFUqZFJ6
8GXia+/zR0xczLfa3hglQMFLrwqVRBqERteV7FQicEyj+dSkEB3B+XKufXVc
BK2nvxMZSMCZo2dHbgUQMAmrzr8R1ICa/LvSwwe58O4LMlZ81wFD9Qq9AbtR
LL6iu2FzTTl8ojUz1zjwcPPTMX1DUzrGfibUaMkI8EZScejP8k4YE+cC/q0e
Qvloy6ZWIRp6R496sLQHUfCmtVu5rxcR9Qes3pYPgGIztTRn2htNI37zmU4E
jr5Rim0TYaB0JC5L7xUBKfdp1inlKqSkbi2WkCcw58yab0HtbyD4Mtn03ZtA
lLlrYNeXbowXnt/59DsHup/u7WqrZ+PjrZCQeVsJDBsUmfXGtuBj3HTAlZV8
hIyvO5ziXIu7C7PDrx/gg9K77tXGuLMYtmUQV8jna0XJN/ent6EpOjOlrGAI
2rJ8qdIJOu6X+a+OzOBi7VOjK4d30PHvvRbe+PF+TGc6+ffV96Ok2f12bBwb
ccsPP3Ibb0QazUz+wwk+4pRsVYNPdmCtfFBkShcHoiu0ZxYeYkPnjTG98BMX
7kvsBn71sBDovvTtqoEBmKQwohcU3cGe48F+1uT7cGJrFS2jXyC0Sf7sVCgB
CxfbvBelNAgPz/h5mQ9CNF+moM+vE4d4bjPH5Piw0vyvLmRDG1YItTdVbBiC
Wrd6HCv/ObTOzzY8JfFi9iWsT6U+BxMjnC8X9xLIGpV73qQSj9NLnjTF+BLw
st1W0cViYPg1z7dsmA8v7UgRYfk05GQZOhXvIGDXblkn/LUHw+KvZh+/5CEZ
71Qi5vTAPVjM+1HmEEqWZGVwDTpgSzndc1Cej9axczX1P5h4PVGO7dNciGro
UqaUemGypPCI6L3PIGITr/ZqleNbhMbd7kjyfP7+HXF+FdDUixyrFyNQY/TI
357Zjkt7h19yk7hQq9FUdxOqRUZ1+zMrHoFv2cIM9dzXmBPnYiptQ4BhG6+d
/aEDjg7azVsiBxFTNE9GWbUK4ye/cUwi+Eh4RbcvVmuAstvrkAcLST7ck4pM
3BKHyZ4r9tVeBGQ3h+hXOzCg6KJlKdkkgERdoAbtWTtoc4+4hHvxULhT/pPx
726s6hQypcx8grjT+buQp4PjvLzszV4Bkmp8H9HFEuGw6EOUMTnvz0EXC/tr
S8H+Wpn8/TGBPU8FmcykOkhpnQgOVuEjr4ISPl7GhOfJK5sGrLnYFuNrp1XQ
AakjXtK324cgnmYj7zhWiLTI9wMxLB5Et9ENvJIKcDahxDCvlNxf2bbMbWjF
cEf4L5UUArmsdNWw8Ab4zdr4+PO44Ag3cuN5NVDY654zUk/gPEX+QFdgJxxW
tlq9fz8CyqENf7pHjiGt0YV6lcTbsR1PWiROXcIDs+zHNxwJFHnPiOtLN2HW
NcE72YrEn5Mt9Y9hFe7tLlB4PcnD831+KaNUGvLUXjxVMeeg+HyCg0C2A1km
m39mRwhwTJ5tw5DswCDd/96EBwd+j7nU5TPvMOfY40tumQRO7BfJkf2Phc6p
CnUDog+ep53fNdj349q/uhXfMYKCpj8VAkonToyX3recx0VcbtS5qi/1uKlb
dChUgQv10sm20JI6nGqZVYqL5WGFeMoNnm4X0sQ93WKpBI7/jHXbJ0fHRKj6
xzbKCEKCpziSctXIybwd+9KPD4t8ukO8CwuH0uMOZyXyYSajuuxJWBeczt1T
wQU+0t4qrIzOYyNjhdZowiUCqQNRnxX9mOD+6Qn1qSD1eHGLebicF2Ks1APX
HiNgn2fWU3yQjs33A1auXM+DYt62p/MK23F5Qf6Puv1c6Et4ruAyaiF7PbE9
6QMfwh7ltHDHOiSZ/9Pr9YSPqrGfaY17IyGZbrZ18iiJn2QZpSuhTAg1Vr6Z
wyGQLqe0b3NJF9RtVVbP30zi//24SF93Nsz0bnI8Sf7QnO2N3R7Vg7JGz2/+
Ux6spK2MX+/pQkSdtNyD3BEEW2YHeIZ+xOqLPcefBA9Cu8SzycmkEg44S9Sn
EaB0TQxVU+kw9Vmc+eePAIYuPaF5sfkkxE+rUSwJrDK6KKHfSMN0TxwrOZrk
o8xoVfX3ZIx+zZvcSfKH75Q9f65xMZYxC/zOOfJBvXoyJ9a4CzRZow/u+wX4
MqXp9vAEHb9sP7WkbBCAcuD5LrVLdFgxFm/7tnMIWVwV/2UfcpCdFVY6QeJt
nu/eX/2b6mDgEHSkRZqPJNnGWSfNPEhENZZoknxSPerpPFenCzpqTcnKNAI3
/bIvl2r0oCdgTbx1IgeKr5hWIq35eDEpK0uQ+KYM0fJiv4Zh7URKdZAdAbbC
7PAW6Xys/ajoGbOBQG/bRellVqQ/NhcxPdpIvcoT2f67uQlWDVoRSkf54GzS
2JPWWoXApQOMv1d5mNDSo+oYNoCq7XZ85xQBQxNhDRfDVvzS7D8ceYCLy5HP
N5lS+8Auu+pzJ2kIOe5hs3H0hzif0DK8+DCBuOd253nTpcjavz7eM5WHOed/
6Iib05G52kHptyGJP4kq4S17O/Hv1d/n1Ol9aHiZT/WdpWN5mNG80zY8ZDx3
fbA25T1MlpdZGh3iYeNAXEb0/hoMG15i63fwkPcgUmApw0Drl7N1DnmD2GIQ
2+VTnosJ4bd3fUh+2y44nyBYSseGxL/HcmVJfpteTSV+pcFHULtjM4mvAv1T
7oHbmZDMTA55LDqMQ75vByeu0eBqSzhakXxMSj8W29TZjuE/rkaSNhx4B162
iN3HgnzYZ+KcgA3K9eSPa3Tu4Q5NOjaIfB4t+5vL4docKE/e2WLsSvp76qDK
v7M9YPmfobbED2I/J/lF2r1K2Pj/tV1M6rPfhsa7SxyKkNlgH9AnSaBb8qRC
cikTv54qnx+XGYLZwNCd7UvZEGtmtyy6MwLdJK/xV6ZVEFmVrLKH4GE6leW1
W7sJnLOhtoa2fASVKi93aW6BTpyVtJ4RD/prHvf5ZuTh2tuB/CvjPFTlfDmz
U6kOLP13VotD+QjXDeyWn1uFZVX7DssdIvkpHtn4tygSiUH9JQscyH1b2vbt
If1Wteg/A5NUAQb/NoV/PFoFVxHJN/1knsqQ6Lnyh50JyaXUUxusCYTLT/E0
iqkQnWuTJ3mPh5Rxf+EvUqSezOkq+jVI+t28tep7RZjw2q9/5dbdfhyLLKx/
rhuLeA3tnzmkX0dfnazl+1OxmxGXslubgNrleB5bLwXR4tmOS04TSPh5O+Lv
IibsBivU07kC3Fy/MEtGqx3PXT6fKHHiIdspalfzo0Ywzi56ufQrAep2WeuC
ljaI/WdnMF7Fh91Wu42Hb2RDrfTD+qkCAhoPy9dsc69FVDAqJM7xIJjKJtx9
WeA3L2QP2A0iXT7y9CU10v+Y5fFtFDKv/B1bFyVXB9vmj8MKcwkktlSE7BGh
47Opur7B6BB0Nxn/cpcqQXfioEH2NA9BAXmvp8YC8bhQP1aHxEfa1XV/t7yv
hdd2Qu34Uh6Ec5WNOqwH8NGl5fJsOg/R3eA2S7VjStym1oTEX3FYUMlpAzam
7LPKDef1IEf3GruyJh+/vPNlQPJLS4urdMOpDGa3xzZuteKDmM6o0tCoh71f
WEnDUj4yvwY5ffFkIL2NoW7uwMHBu3sG1s7vhTkjYM6E0DCKDq/uHCPz2gP2
PhmTGAG8dmYPsn8kQeeoeXxsGIG8ZN1IV3EGujzlU+5SR1C84eYTaY8SmBdb
nNvsQeBuan103uo6HPS8cpT/io/iEuW7xrEN2JNqZDn1mwc3bfvqg8tY6BWm
//NiFXm/uKMJXawWl/tWXXt4hIBN8qbJ+1teI0R1+tEnAwIxZ1xZZyYZuKfg
8c6MxGOWulfhwSUdWHf8JWeFMw9xeSt4jlFN2Pp2XiJTgQeHLLsbJ92qoOnH
+ZPwjsTvdQfDiCfVSLgRWKrfQ/LrdQytorcHdEuzIWupUUj2+N9w0fsAy93l
Tem/CYTaxGXqvmNju83u4MMkP9T3Ts906XehQUVkg0lwF7L/eNue2srA9LP3
pUqiQ+i3i6I3DDLwKKGk/8pTDj7Leglvm0gG+5Gd0csYAu9vNZQVlTKQWSF6
+lIED1xGqNm5Ehqq7a29m9QFyMmnO2/MqkWVXqK1Dql/zEVJr3das6Goa/ua
08QDn+a/a61IO4Zq/ugy93EQPpV64/GWWpxSvCRiv5/M+6u+P73MpOFZm7rg
eAAHYZT/wuW9afC7/cq+g8xz0eXDiz1yGJixeMJ5ojoMk1Rdebl5DAScXlSZ
W8dD913e0w/EB0hb3l5RSeppecbmppkmOu5lmGq/9SD9LN/CdX95MgqKFDPL
D5H9w7nzAj2qHsdfHnTZKODBjj6UFa2bheUlsN5zgYAVdUTBxqoXX7XOLewW
cOEjKnckQJKO1YcS2osSBxHtc6/5oE4TqrKSP//MIfn7u22wWYz0Q7fM4P2j
HBi7Ro8tna3BrHpWAvU6D2rWRGDLTBV2yccYGX4j9WWxwWOKdxdOiZx1caAN
wWtk7qvuvDYsOVorvDKO9DvHa643L3ShJE5KcMNjEFqOZyTbjdpgt/LRpEvQ
MFrVO9P5ufWweaIQZr6Mi+XNorQICzq2qfl63iTzy9zvl8WcN9PxUVHb+F0S
gYvL5tZxJXsg/H5g1O+/IQxfr7dI3NSJ/FLd631HBZgUuDtuZHaB9YrDja0f
gbUKNZdt34Pysd0V7O8ERCnFJQQ5L6WJIsm9W3koqFS0ebaqEa4PXtlxZPhI
f7ypWItHg4LWcnM5Uo9sFHT1hD4VgKUd/68mOc8klbPz+kPSEZGlqB3uRuZf
lRoPxSgathferh9w5oK5MuvW1Gk6DtzSie0sJOBpFL/m1sgH7Fog5L/kPqmv
U+IJSxPrESMmsU5FjTyPXut90eUBNPu7Vi4l81ZcdKaaSXQZdlwd2/gjmYDE
1TNzGmXrsUEpXZ8py4Nsw7y/c+M7sNg84ufWz4NwnV+/Uy2EzAdquUJPUgl8
NZEVW32tA4fySsK2q3AwPiAjn5RZjftdFqjdQ+Ca0tdtP3zboFyrk+Jxm9ST
MNMZ7xsvoJEQoO1B5hETxUUhtbdOYL6CcJewM9nHXi34993pSujHugXPChMY
Y2olFkcwMHn8joosqb9zuIreJRofseZod7gFib91V59P5Iq0IGWBz4PVtP/z
NUd50o9G+kvAoXf9PBw7w5Eu7U6Aude08OWTZN9KmTkkW9aCvKKoSk1VHmp8
qapy+jR0tP20/C45CPe/8q35C1nwUzleffYp2Q8qQ5+92HEN9yv3ZFuT/aZm
pNQ0S4yGby8tdXe1CNA2e9HY6QsLT3L5Gt1GQyjl1A2fWdqOfPEGZxUJAeY8
Dr5zTS4Xr3W8TDJ0yPOMjd7soL+Bs7XvDko0qW/2g7bvZXLQbmiAW2SezHkf
vHaFeAfKWXX3t5LztembUp3Qr0fD70KLn24CfLvTueMmsxjRz0w+n7hLYFbh
dbmzHBsSpn3BvKBBJIVkrOUoZ2P4H7poIHmesW9IRETgB5g6nDze9pPAWunV
eoVkv1SHYnT+j0FIVDzdlL2nEBeJ5Qt6SX23e3hLqFqbgfrWAFPbBj5k1i3L
S+cwseT+KW0Fi1GI3lylbH6MhYiX94WlybwXOPnMI7erFqxdWWmh5L7m39Z4
zrjQCeUP2r8cVIZQdevI2+Nfb0DU4lHM2eMEpqW3WCeVZ4LK1ysfJ/XeM09T
sjuoDqmZeUPT5L7ihC0Y5eWJuHPsn/m7SX/vDtQgfo9U49NA6o+y22Q/6Dcv
i6exsfZyiOouUn/N5tF+a1t3wFgko7GkZQjzT4vMrTnNwnq6tsmZRQLI3Apf
+aq6Hap5yV7Hg/hwpxru+CNUiT/ly4NrFPhg+TyMFfg0Ia5ty7GePj4UY8Lm
7YrMgdW3Mywbsl+n3V7GLrnRiIOblW5rhJP5ub3JpEy1DqMDNUUXhgn4/P64
bKygE6O3J3e+PEz2Nzem2H88KtIuRm0oFefC3fPuViH3PvSHLNE9eYQFdxkz
iRPBDJgvMxi1OTGIrJsqTzTJfjq8d9/b80kCNEXWSUkuoaMgg/Ll1lkuumsp
i/dtacah6fQ1Lg58sO0MTDfeawQtdXtgTTUBdeoCSlETDSdffRlN9iH7D0s/
5MuVdmzey/30bgkPW4aLQ++3duLyTGB312oBQu9Whj8YpiP6TWSZF5Xkh/RP
evDRYsRMeB+unuLBdqffnlq/djCXGXi8rx0CUbV2mtrfDp5GHiv/OelXTgFq
l+cU4arV6iWnggksNr3KXB9VjHX7XBdzG3hkLpiZ2D2/A23ZCRFUcTJffkXH
wuoCXJD6eTD/OoEQmwcbut9UQfGebpWPJplPUXiuUJQKvacSRe///3/r2fy3
FXQa/LNDD46VDEL4wCjXO60T6k+2fjKP4MKcuqK2+3I3cpdSC1Pdh8m+Gfwi
ZZQNLzFf6ysmfMwRaj3a3VkKdmFR6gcXst+ITjovJ/tbad7JmbcP+fBrrQxQ
/qcQ3oW65/XI/CUvNcAwftiOx48GZwOSh2Gzvv/wQsc0NGwTEriSeffQLsux
INJvpUIqBekk/w1/uqX6XyrFZxt9OzEtPurC1Ry/l3XigW+WNq7xMJC66Bt1
ZRv2C9yMIhaS/S249m/0xyKY+RrvMCH1bfRmx5ZABhNJwjFqov7DiKH0qFzY
VoO0jXqbbOfx4DjQ9jeLyYDk4epv6b/4mGn4mCxlSeLbXVVc65QAog8ub6l6
2wWRMzrbKyeH4DArnChI7cAJA5O+giXk996/sXl0bxXCzHf06pP5u9chrqJ5
vAaDG7+pcpaTeF3dI7/SogP9i4oXSPtzEdHNCBBT6MNGetSCZNshrM15ZV60
rhMO559t89MYQJLolWpadRKcuy5RGaRf1Hb/XRWZxYCsO8u/ldQ7ZuHtdddS
2WB833ZgRF4As3H7617SXfgVYmnE7BiC7J8L2upeA1gh2lVn5PEZ/wOfQxPP

                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41Gsbx0kLoqMiZUuWNkvUkd03DtLJViJapLK0p5IQh7QhkuXgLRVC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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns8lGkbx9naVikxK1uiiCKylJRS/STkUDoQrUMSpZySTrI6qGikZIk2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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 39->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8Vmkfxi1RI4lJvK0iIxMZ1ZDGcj2GqRReSyXSiMqUJULWFyFbI6PE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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHk4VG8bVkmRiiJpHVIkydaG3JJkq2zRIhWJQpZKElmS5Ue0SkkkW3ZC
KckydsNgjBlkmzNjbSNFie98f831XnOuZ673Ofc6UrauZvbz+fj4bObx8f3/
0+sSpevFwmIUyTqMp0cRYNtukjAq6IT7yNVtQWeZEDNuKZLZXIbSaU85hgyB
6hmH+wvj6JARlH/YVsLBgFZ0kR5fB4z5Ps6jrh5EU9dm9arZFpQophZFGg1i
Ns/AR222FTaRrCoRLQJ85d9iNWQ+4Verp2PpcS7u6e/a4bkyDwofVmd03COw
WD1l2dehFvyTO/byxy4eDDe8+Smh3Ilnp9wT57czYMO+pWYU2A67irktu04N
4G9h3NAzlQ5QxG3K25q44PF9ONupW46qHyW6RQQHEgenBdxMmTh9cOTNiEw/
3LQtZjtp76BnVfBL4CkHoaX37xJWjRA3WSGgfoSDmQLv55zzdRjvjfSI0uIg
xexM3QqvIqyjXNzo4k5AZm+IesaSLvz4INAjG92H71bRmy+7teHPl7AKy2ou
xHa+9jOvZKE2Sl+dIjKAggj1nRvDGZD6lkNLLCAQWtYrOOpcimdJC1rD7bko
+3rkqYplFeTWnYyJWMkFS+K/PR/PJMPP45/VqCGBSw+btE3NK/GzcXdnVh2B
1XvO3lJreIP2gze0lh4hMJTV1PxaNw/WW7pGxb5zYHq1Uzhdh4Hf/yw1evMI
1NF2FpyoYoHPx3hP76UhmB6WPqzxrAP2l18La/p24eWnbO5JgS74RgmaiEpx
YHJZZ//wyRSotzHP5G8hUHK1V77vXzUyslsyGyc5+D61pMiLXgRJjY8aat4E
tE9Xj4xPZWDpx6S9KuQ59SDl2bIkFvqOWTzs9u5BX+NNN2mPUsQ1CjiK/CZg
ptXxT/59Gx6zli342DKAiMm6DyFjZXik1le2qILAlJ6BtERgJb7OC48wW8iF
c5772e6jdPiZ3KoVn9ePhN7AsFW/02Bo1HthxJL8/SYfR5p5BBxVXGyv2BFo
HFcvD1JloHjf9eDj/UOgCv/+bjXXBoXcD/IHpIbAp/Zyp0R8C8bXz+vb1UNg
T99/7x91NcPGduUkN4QHRrIBf60LFfX5zeKNSgSUJyzyl2d3I/hNyw/dpB4k
rJn28N1bBrXJVuGQSg6kX9yJ4bLb0bqgKvylOXm/0S91f6Qr0dAuflZ9Hg/6
R4wO+a2th4PLJx9ZLwI3i0ZW2ERUIPSE1pIRGhcJ8W/DigszsXis5DJDh0Ba
7y3Giwg2FLz61hfJcjEWsH3rZvtatF4LW133kcAye4Uv2uLvQdEI9vYg8ZHw
+/TM8sl4NNXkJpibEpDtfOGS0cRGuu+eOD5ZAh77zkRz7BgIkucNadO74DYi
qHc/NhfvHOdPRUsRqA38q5b1jga30nTFVdoDeNfzT7T4K4l3lwvy/dMc6Auf
XlRjWYpI9xZLKpMDhWtBSvG/2qBSp95tFjwMffoPjpEuFcsVIuaqyXn5zUM5
Q63lMHyxOiK/jQN6iJg/37zPkPNmTRxLIfE/prd/qVweFtdZXvJzIfDMeRvX
6GwHjhiZJGdEtCNO7bCz3INWWD4sEo3Q7ccKIXrBoFwDIvTeDE+Q8/nsX6rU
6vliujVga9U5Ag9adNNr/2PB8uvG5dKqg3D+QvVbiiZ4rM+scF8+iN2CEkJV
aR24WnJ0C0HeR25ETZryvgBWkkW96oEE6HP+lYoTQaCq7Q8JOUPuvwT5ClvS
YbbaRi4gg8BfTztLwVNM2HpVEc7ze7F1xWNarBYTM4tmTeMnBlBz6Yb5lv4O
CAuLhl55NYjcAuntJec+4XP3Jb1iko8+ZgNCmqSeHdb9rpAWw4NShdW/qaWl
WLjnbt+89QS6R6qiC2+woFFY8mH2/BDyXrBXP/Gtg9Mv198rv3BASf4xe4KR
BZlXI4IC4QR0pdnj1IoPKDNfm1LGJXA2g9/1AZUJrbVdLp41/ci9si175Ydc
OAgME78uEDhesobDyKQjO+da/5HHXFgon5yxMGyBDb3D+3MhD331d77/21gL
a3eer0MhB8ZezIn2e/UoPfPP4RGHg8iMIspIZzESvVKzvbcT6Iv34/hSmNio
u/ztN61BEodV04YqMSjbLBJnRurj3msXDHolGqDmtkaGKsyFmk9y9OOkdvxp
7DAZLiP3e0J5zNMzF0IP0+y1KQQqvFTTVP3r8f0WN+y3IQc6K0NeLSqjQytt
yn5Sg4OpqNPCCkEM/GX+kLT43Y/jYn9eq3+jY6tTk4RSwwDKymbePxWuhUDD
8Kv6fwT+2xrhk+DbAgvzQJM6x0GEUg4fVLNPx+i9vxdukniRu+U32x5QQ+7P
nH5pjAvqKvETlyuZGN/ufF+qpRvOyinKIw2v8UncONnOlYD6izlK7ZlarNox
vfIem0CpevD3o231SDrj3bVIl4M+2cpk/stVsHCs1jnRzMGa4gChjmVV2JNr
d1RqMRei2k//PpppwpoD3p/u1Q2CnaBFi9nWiYWn5xy92Fxcll2mcJ1VCZkL
DQIh5Pt+Xrpfem1YHS6LxGWc/saBmF3LCr/NLTBwuftQrXEIBe2fz8nXVMIq
cZ96/F4OcgN7pPZrF2LLpAR161rSn4QzDj2tqUbpzjdsbz4C368lqx7/lI0l
D48apjoQMDEX4nPVzMPhw/NWvk0i+ed18VsSwQSfxuvl4XMEmgIvuxWJdmMo
Urmn8uYAQvevcwvUyEeFvGNyynsCYfQLdVcodESWMXkqKhxoPbG7l50dhXrd
2aJf5Hz94sndvbxKJPk+GLZeSN5nsZOMmS8b0TNU75UaPJwVWlVIdWejvkCc
A98hxFlnl2uu68DlJNEP7jwutGMpDXM+HVBPUZ3+I04+T5mSz618Bto7vZDq
iyRfQxxN/ba24tsTh0XnpAagp8DncU6HiRhbamvsSgIUkQqaeUYKtA7z2z22
IuD2bWOYV2saIpMdHkkfIuATzhchmUNDpA8l7Ad3AL3vH0hEz5YjO6hQguHI
RWaeWJPNgSyIJe/IyBEj4CtQzN+1phWrJYSKTdqHoGl0/+GTundQtBVTDXQk
wDply7DMosPpuf+Ft0dJfao/9/GuXxt+Nmyry4oi8Tm2W7FRngFeofevxPYB
1C7nV9wgWQTn4tNcIRL/+oGj84Z9CpHdxrxt/pL0o4/GroUJrah/uslQ5yp5
LjGbt8qrHfZSkSkn9Uh/8u+PTdVsB4ux2IhvhtSH5zRnqXKSL9vs3MoP8KA5
ejHgN7sBM30rNBaTeKiNyvlU+a0M9LGGtt5fHDiOyby2SXkPzWfxCqL7CSjx
V7rrRjKw9n2syLnbg9BUDjQrKqYiquasKKRJfBYUytboN8HSWG5suRnpRwfr
Xnc356LXv1hpew8HBIs/X1S/HvY0TyGaAhebZ/Blwd9KaAefabRMJZAZ9DPi
kQENwhQ/S2bvAM676G1MFKdD2iBqR1k06Z/rLa9f3fcZ1RJWwxt7uAjSW9UZ
9rMDiVv0cxSPD+G77s6xHfvYuH8z+e/HnT1glZ97YuFSh6zdW85W6Q9gmZrE
mjDLFqydsy27fZsH+mP57umUMux1TYmyf0Xihavf2mpChfT07ZFCTS5yQtZ0
DxY2Qk96yWJ6JgfvRoSz3kx1gpaz4tTKuV7cPB7Mb/+pDZtm4gaO0Dg47vLI
YOZWOvgo2VNUTwL3h887dDayoBdHW/jCfwhrOg64MwLrERdEpI3e40LzWnyW
JJl/vnfGpSQcHwRf9eMuFTc6lhGah4y5HHiWZmhdOFOBJ6ntqt4kX1hNtXsX
MNLg2H5TNYb088CwC27n5qg4LP/xoeBBLiL1xsq2xbRjwSgz9Py6Hmhfatqt
zKJDgLlu1/W0QRyjq+wKE2ajdKWxrOvkCBI7emLVHnQgKMJINMSVi5NDg5Sv
oomYrytz9eYuAiP+AWqHijtQ2njD52I9D0OiKenGjz/iC/Vuqh6Zvwv8K5R3
VjbAOebNq+f9XCyWOODHz6mCdsXGEk2yHxysa9dZ2tUGxvnTPu62/bBjjO0+
V8rGeSr3R4TMAPpaQ45GWaShLPPW4wx9Aq9/+1KC+ZjwDHboyzk2iGVPRcqN
jeqg/OftFUKWB1urzdyuS0wwn9Rm3ucNAQPsJ6P3WShdYq3IYA/C/9+YxIn7
oVDa/a2VdoLkQ0Wq9qXwWmyzSd3WkctBjMtCT+udtei0dnU7LspFTNBdv9cX
mDDTHw5fak/i30/JOz+3EpcXVep8XcFByUTB3mT+Bjh+anh95RQPMduLylMf
lqKI9UWT6cmF/7cNnR82siAy7UY3Ne9CROeYh1IxDUEV0zsqSD7UatH4MiLu
IEVRfLWhNYF1I2Ie20h+frhvWrn/4BBKG+RX2lswEWnx3FSZTs5babxttq0V
wXPit3gKA6AoVR1PzmiHvsUmj4BQLjzDJaRsikvx/WwC7UEoeR8P5U+3A1Pg
JlmdMuNM4N7TVHHnG50Qmd8vdyBoEKuHhDto89rhHXFkidhgP4JrlnwgpN4i
Xbk32eA2gcqp4NaJlApQdxRQFpP5vVOqfp3RCAtyBhckQiNGQZ/oC3ZhvETF
QbGcQh8CK2yt+GoUqZj102ZSKBwI+xfKLBZqA+Ec0K4rNAiTWDk/7VQqkiS7
d1wn80r5pQmtrwt6cbv6l8qgbB/iDiVUCEiyUNKREx9kxIX1++aL+x6VIaFD
Xk/7CgHjvtWCqYoMKMVdWd5o2g/Nvh/OmaPl5HvzecWUJPNrmUmQ4faneGe0
wmyzG5lfseCU1ZJ2OJ/Ps3a9Rerpxy+6gmBi/kL+nGExLvimzI5N99DBs1yf
dvIkgT+Bk9OvX7FwjaHPjVzEgZfhIf5dC2lIu+3DVz3BxekZ69+MmBbErI6S
PEzqzy72aepFJgPvZm4d6iP7552hH9ezxrthPHTWo9ZwGJzuHfx/H39GYj06
Vixg4ezTjjPhA69hOc9d3YrMUx5jc6xy9Tas3UBddn3ZILwik/NSBplYbPjv
yKWbHNT+C5a6Y56LqzYW79U+kf1EOfPkg8RmpMePZd1T48Df/aB+SnQAaKrm
4zI2ZL7YZn8il9FG6mrPeVWS/36M9K6ehHaoLF3ktIbMmZm3soS6dMpBVX9p
rx1H5iHH5t3lsm0wPF+94N7FIcixlQvNzrVg5Mn1K1dnuTDuelf0j78DBp2G
758sHEPuvfjAfOVorFcq3AlyX1yzE/pdzzsQ3SDv/jCb1J9+qul79U9wWsQv
eHQ1ue+dicnSh3rRaC027praALvm3tlc71oomo6aFfQNYK78WDrTuQ0pyZm3
TUl8xbhZ8e5ot8Po2MNJG1HyfgKdGuV6qTjKGswoJ/vZccH1PAteC+SvStsm
8HMxVLlEaCL8HZRWB2yYJftEvsT8M/1EE2TrVuxduIGD1PHw9ZsVy3GMzzkr
lvQrkYgfM7SJTIipS1U0k/mNIh+gn1PQiC9JahdOqRCIuy14QX2gB4/GClXV
SV41mjzo/KZcjwehk61rXXhgLqNLHjKpxL70iA6TtVz8NN5TUbqvDd1jwp+F
yb4qMipxwi+tGcPKUXbX7hKY0beQDLFtgb+Skvxzq0GUVcx1pVlEYHWtn+59
sl8erzd+QD3aDPq3rX+WCAzCONpnw+8Bcj/Sg/12W3ik7l836VxahUTJ4o2u
hlw8fxuRWRRfjNC72YMUIS5M7J2z1iU2gDoSYzBL50HEQUjg6ON6uBqqCi8l
83x+7N7Zy+8YECp6GbhswQCcdbh778xnQk0k3VkhmYP/6j5+WrebDmunLe52
+v2Y+vViyrS4AOkLvjv4kXnh0WIJw/icLjCee27W8yDzsETRj6tOTHCZm/xm
vvaDKTjxZ9apA3LRBncDZXqx/f7MLgWyL56PuNHa3d8Pt+0jZQ9mkrCqhioY
doD0A+efYxfq6rDe9LOsFtmH9yZMO71vY2B3eZnYFnJ/An+vuFTdY+Iqn1OA
LZnvPdg/KLMOTTj0Q97omSUXL9wVMyilrXAfb/Rk8wYgaOwil763BjbvYv7l
befiVtjFO1p7CmF9Wf3vCNmfH/j/3bf8aSeuhe7RwK0+vHsYRN20kYrReFrs
WhcO2XdaddbPZkCvMcXX/BTpR+l+g3WOXdgwzo5Wd+3DvcklROd4OYj5Rmz2
QgLjzlkNdx9T0TjZ3v/7K7lfFdmME/FVSHBucFX+TX4vLhOjuusTYuixVtUH
uBCii6YkaJVhk/LzIqsmMi+zCZ+kq2nw7zt1+tkxAvwORV6rdjYh+Ivm1ad7
eWBpRBzaGFEOtd1ca19y32Mauv+te1WJY2XR7vluXEx9jz0yl5SLbicdsK4T
kLdsNhc3bUCs01jonBn5vJhmnKpFMw7ybu2xNeHB0FVlucYkyff/OncsJPPV
npc9dfqP8+G9YDgktJXA8/AWdnR4DQbkXituCeSAf2OKiKp2C0rAM70TRerP
ilyj7uYyUDyadDK/ctD4QcUq5+97fH3cMio38f//s0oDIptqcKVJQZLsXNDO
uPHBx56G+QbP2Up7CRiqiE8l8Doh62FTSDMZAv1PQUyqEwtjR4+FPVk/CMX+
s86cP2/R/bzy7dQeki9HpNWerPuMpFbPmrckvvcUx1ouFCX7aV613LF4kl8P
ZPVN9xejInIJf0UVB9Y/acxFF1mIZGjN5sX1gu/4+nzqkTL4n7qyp28ROc/x
aOpJhTqYWJaHd6twUXbydAahVwj/6qI1reT+guyVjljKMHBXg6gyvDuEknCP
2NOX27H/WTCzgTsEgcsNvbBpw+xuhaVaj0h9Tbh+ytqVgcDZ+lGrG//30z8n
z1/JQaeaT95F8qzDcLKfdmiB9rHxBXZkXuY4LXM9X1WFb/UCBSZPOEjPl0ls
utqNl0VNy7MFyLMKm7dpeRfMsiiJ8Qv6seuY5HmnJWzoxD85PxxM5sVqFfs1
qkwc/TK27cwuHkKvPVhKuZOCIbndurfJPKRzxsDiL4uJ71Hhk/k1XQg44b74
wDwavK5v9C4SJPm7O4UpYl2NApWdclQfLqQmDYor29hQD43KuzjeiWrvpfZy
rnTI2QS75q3nIEHy9wnbnkSM+9/tWEfmSedrZ9QkhemYCLhI5Alw8T9bYBW8

                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81NkfxkdJraxiU7OUe4baCiuF6pFYCpnSCpUsJUmhi7Vu65a0sbQJ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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4lesaxonMJDILUYatRCObuot2liHZR0Wl7GMjlKGSpDJ0sJMIUWTY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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 40->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkbPyEkohiUNdNGWZqRlPQrmZZv0ldGkpCyjISk5pTkkBZEY+gb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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VH8fhkdJChFZSkkhRZakBeWhpLL8qFDZQpJ9T0pJJamQRKmQJFvI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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk4lXkfxo/BRKLGjKbSkWQsvWPJUspy06QkNcfWSJKtJmuUNuuZGWS8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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk8lfkbRVmTlAhpE24icjOpqGPI0iQuGSXZCaWoRFnKVmYUGQwSY63J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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 41->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4ldkbRW6VSlKJ5JI7aVyipFlMmokuKCSJySA1pSYlybiMw2gol5Qw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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lOsbx5FTkjoloZIjUYOU5MgS30qh1XqKDrKVJaJQsmRXNIU6lESy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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk4lekbx0+ylExIEVH2yDJmMgmZL6UiynJJ9i1Lq6TQHpKfkJEwZUsr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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lekbxiUjWhBqikyobCNjylYmV0iWEuVnp8XYSqFIi5ThGCN7stRB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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 42->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8ldkfx5EiJYpiqKjkZ0SSaMF8ME2ENPWTJS2ye5WyTyW5ZMmdpMWY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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VH8bxiVKCllKIclS0iZKpNy0SErJTkiSlEIl/OwtZGmVhCiVkCRJ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlWk81dkfx5mrspRU4lqzTZaZlglpmfFRCdlFi8LIUqKGRBhCKWTKXmmS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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk41GsbljpSls5JiE7FyZJsHcmZfOkmEUeRwsxniY5ikkpKFFFxbG2c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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 43->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8ldkfx40Kc2vIMq2yJRlNlpnmosWnUJpKUUIoWyRTWULqhyRRSZHl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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8lO0fxS0lSlKWx06WkkqSUg+PIykpW6KU7CJKVEJIkkRUUkRRUiQt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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41dkfxxEGZUkLkcqEkkZIakTvOzSlyT5JJFui7NRFRclWhChZxlJD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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41dsax3FEiWxDiiupUCdjhRtX5ytRtA/tUqZkCnWUaDAcKcJRna5T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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 44->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk81dkbliVKZUmoEBU1GNHiU0lPM6MyRGjoZmkiIXsIRf0kiRaj7UYp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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c81f8fxY2KVEIqlayQvskuIzotDZRNQ2kgpEIKEUq2okikomRkZGaF
7L3dy42Iez/3coWMUin1+/z+uo/3497PuK/xPOdIXrhmYsvFwcFxlpOD4/+f
vNFGT1xCK5GWUqOdRaGDlb0lq/oCDQz50jiWHx2KJ92OlH/tAL+F5ocHlgxI
hCRESm3Phcps6IzlLAGb1+3WRiGDGFNcfNdaPArhOuuq3Udy0CUYXxcjRsBC
RujY9/Qe3HS5LXFGmYlrihVrXykPwjR6TufADwbkHHUkp/Z2gtY5aHL+Ox28
n4f5d+aUo/pO0M/l7xmQ16/y+uvYhzSrbabPkwg8utIoIxrThYOOnatKXg1h
7MGcyL54Gk49jHAOu0cgbWDwZrRrO54+/r7Ug0Lgkwe1OmDzAOYdO6K5/jEx
f1FayfFSFZiSuiNCLxmwMY76ndpFBSv379BuGSYKvirf6NrWDPtD1HfFd+gY
25qgcnx5IXKTFAISlAj0qFak7L7ShTwur9K5DaMY8j3LM89Zj6m2spOD8Qwc
N3zW8P7zJ8j/Z++9QBDga5WauLWiBybSolVizcO44Hp7nUgyBZuixasl2hn4
eYmq0FGfi4zTtL8e5P/j2Bf5p1alBDGJ3zdKrCLg9zb5LQd/FVI2Gx087EHA
o9zHP+JCHY5sCBMTMmXiRK7pS3WXNBTv8G4QO0fgT/5ec/3mHuSYbxpPNWNC
o7YweJ92G24L+lqlrycguFElenwbFaL2SYasumG4Cq1ZVybXi0yNM2KKK8bg
+lY0RpP2ETYR2kM5x5gILm4s/RDehCMhbwa365P9Lbe8YIV+uJY8HH96dwQS
aV3xkhED0JpwEdpF1sO77+SbvbzdmOA5IhfmPYpGbUcrjh9FuDYj9OhoF4Fi
iTa+MYM+WAx/nvT7xUDBElpjlEExnIaKB//mEMjbnxMV8LQH0Tnn7g28HIVz
6DpVtt9bCO2U/qppRsA03HkZJzcFCy80hnlsGDj6eIO7RGYNOjsntzSIEni9
YtmCEX8DbkymDrOjmag0FYiq7I9G8Rvbup2GBLyEODJ+1nfj29sdquZ8/bg1
c/aBzFMa+N+8fvXF8BMKcjcQ9Q3NSDFZejRTl+yfrX6d1ZpaEEl3A7TlyHre
bgphx5WjOWjeWpX8Plirhd38j4ru8xrRLn0jqOSpDSwujMGzEL0+QxsCIvcj
cq28ytAhtSP/ajQDidqipy031iM9oD99fS0Dovdk/gb87oNZe5+h/8Qw3AKu
EN1dNQh1o1yRJ+dZtCeoQH8ZFdrXy5dEmLDgZlZkMutRixS+RUVWIR2e0p11
P2YG0F8eYqoXz8TPyH2UV3zdWObVZnaKxoKUZwu3lWo7zOMpebdOszAf3sO3
GNANQYEbnMJ3xmARvbJmHU8/lKunnPtXfsT+WZsN3HZdODdx5XjLJzrSWjOc
3l3vxV57XdsTbALe/vVZSSk1UOt0CdtoQkDJQKSgt7gY2beiAl54EuAV21TG
ca0LCtfOnr+2mYnGA4nEQ5d2fPzrMdhXQYe7moK3nkEz/khXijziYkEg57wk
lYsKhfTWJ8f56HCuU489pf8WhR/6GJ/3Edh7Jnu3U3k8rFJ9Pu+9Sp7zZIJq
mClI4vw15rmLANfxZ3en8j/g9FsZMb7nDIg0d2y9sZaCra4mxcQtNiL1bb5o
VHbjjzaXJE/XMITSZaentajgGAlef/AqA0OcfPwht7rxL+NdZfUA2U9l8ate
Uz2QYvUFFu1lwo09nRfaWozdnLyik6UEqvM4f7lE9YMr+liKgx0DWw84TUQN
9ELn1o5vuu3jyPnSnNCb2wPneV+qZDbZ738Xz/oO98H0bIhM/Bk2PBQqm5g7
c6H2I7tWgZwPacG5qh/LaTgRJjHDnBzHi1SBP1KdNCzxsDab+s7Gg4/uQSb0
XLxwdExuyCfg1Jh468yhbqyszBRwsmeSvBl2oZfnwdWm/e4dOwKRrf1OXCJv
MVtarCfFQ2C+c+V/tnyd+Ec/axF0m4nE72t/Fbf1ocP8wXHRPWw07o18GOBV
h/JwrXHnPSwk/WHWXtn1HsfLx0McZQncS+d3/jL8Ca9iBS7bVjBAkSNKrHyp
kO+dFPlkzUD6/nQty1kK1tsb+mxaJHmwKs5ublUa8saffX9I8qj4nJbrbo4W
SN1ZK3GRvN9Nvsf+IzQqeCcFLqivYqOSS65LaEkLVNjbh4XJfnuXn9OPTW3D
5PRCYuo4ExFWnw+0aXZjfyhtycrWYcjVf2x17KhApczmD5pmDDQuhvs9HmxE
u9qx5a0k350faB1Ry0tBrGaDfyRZD3n7bu1bJg0YrDP/oZnOwuvE45HmE7lg
HRxVVj1AoLPMwGr0eDHEtxwZq95I8lXX12STRzfEtP86C14g8G1NiMexYz34
GchHjXzNwq73AeuDolqgfYKDPULqo8APJ985/mRQ+oX0HZTJ63NtHwiqVEH2
c6r+Ci8m9gZWPEnziMUOA1319SQvpjVmcn4m92CJ6Sd+9tQIFtdZfPr1oYV8
/9l3spqjsM/5+lkxZgCN/gq6tl4sNMfl2B060AVvJVEZjcoRDMd8STCqKMLE
y/vtd4RJvaC0/uDSjMXKk2kKumS9v92QMi4/3IjRtZsMVquOIta9x75mfT3+
DA1//UXqoUhyl6nlbDcE1rB1TkWT89e1UlYsvwrt8S4FBcakHskYfm3gTYPY
jmUO/+0lIMfB05Id142xs2H7BtxZkGZ/bk0WH4KP5mbbPIMxKEkbhm5g1+Op
iptFUQYT0+aNbbt8CkChHJm5kEn2v0N1w40lVOzniaq+824YhrEjBe8SmxFx
plR+YhMLzotcFXkNGRBVan8evIKAsfjeqcwaKg4P8ui6pzChtMeXUMrOQszR
ZV6cOgT0wp4+2nq8BcPH3sgbSA9DhCpxiVldiPf66rUHBAkc5MrUebekA+py
yu8NBBngWPT9LNYchWCXwPXtTgT8N9FsPR3I/baSvBtF+p2yWAmj69nt4P+z
dkcyDxOyfxpGx94NoDSA28d33zjkxT11on9SEOm7cGnbGgL2xgVXtRRrsfPt
3MK/ZJJ3eRKEikcidE3OZjWdILDm8s6yLWu6sef1R+MzJA87u02vHtVrwpzX
df9l5LytNIoy5/3Vg4XFm3W/1pDzQX9aGPO6EH92RiY0pRM412Q3Rb/SipVS
wW/5D7BQslOiWpG7H3NZrsVePGwMq2sMRulRoLDfIV/x6jA4EPEvzLsRvbWp
gmbqBCgcnY0O5D4cMgrYNPqMgFV63OGMWRpSY10ejpB8HZ7NzasSaMed6Z/n
tEPpIKLdSt9XUtAfnvhEQZr0GzWV19XuleLmHVVrkTMM1Mt0zm46PYDZU0vd
P+z6BKJH6IrZhn585Q15nLZIILFW68qPyOfY/s+BJ9yR5LP4irrAzmAEzz5W
8TtNQNj7VcZ/OU2I1xLp69Yg+8Nxuvyxby9eftTYqSRG8lDO/Ub2iRI8tZv1
zPxGwE1Qm+96FA2BZyYX2w6SeuBh12PmlYzBO+e17Y4QOHH7deplVypm66wq
ajNZuNX17mCxdyH4krK2RJH7nrPlAuG2sQWZLyMuDYaMQozT2AgjVDwbmbmb
HUJgyYa5cMOgfuwIiV8uYzCCb98chGuMOuFQJ6bvKsdApuXmZdwvBsAXvyuO
O44Bs/mWC/GhTZD5vT1vkz8drY3KF9WPf0R7G9tI9g3Zz3qlJwoHy6D84vfT
PiEmDO7RgrL8OrGtUqB5O50FP9VthBX3Q1Tc2CIqfYVA+COfpTbxvfA0SffU
WjWIkrmHe4s1OmGY+MTeb24EcuLKPMXJb8HPmawhSNZv7KcB/6u+Egj3+Jx3
4ib5Wfj5yc/V3Xglwk5XJvvz80yIGGdHIUr9fi0KkHrjFMW5bPNQH5zs9r4g
cgeQqZt0l7eyDQKR9eKifXQkUjpuGpgMoNNJqWQlWZ/GRAfLVb8zcOhB03wG
OZ98S0MX+AYouNakYys8zIaUvHc8ZnqhNrhtcv7aKEQMIwOys/oxVhS98dF9
sl7VnyW+sWl4mzi/ObqFQIJqio3l5o+4P1HbwiPFgLSR7uXNYZ1Y6siquvWb
3J+vxz7MV9XiVIX1ZmF/Fjrul2/do/ARXA+MLSQNv0CEM6SlircH3Wp6WVZh
Y4i9YX9TUvs9LE9ySKq5E9DQL3s9s6IW0vzK3KXjDLSab7l4+GYdYk7pcl31
Y6DsP2cfkbMVGGzNL798i/SLAtKFzIp+DN1NtNLyIXDolPif7m1t0MoTEReO
pOM/mVVv98g2o77z7h7BMVL//Tk6uAZ7kMHy2XndkIHdLmwZn7E+3JLQSwx7
SEfsfEze/HsqJjgMF+cmWEhm6k9M5PWjeENNdVcCA8E3jf8ECeRg4eDpudt8
5D7JtD3t+5IEWc4nf+hnSH0gDK1PnCuEbKhJMWWIgRzLxIV9T95DY1vrAnGU
5GXcLzOhsCyE8zyw8T1GYMjjs1XIYwq0o7JNfKZHYHJpcuhgWR/sLpYv3eoy
BkeHb+8Dx7oRZua2xlOSgQdp/wJNrw+gVXh1tifplzVGS4uTTrzGYMHGRc07
BAqWOctMDbRiKPX8Q0oCE7QzZiuufm2HkdmVnS//kvtB3V9Ey+jD/rBF8cA1
w/CYs6neTm3E3xO6kuWk37LQNOaGWx9uK1UeMTrJROj3rbvcsmgoEMo8ZXmZ
jaE9gpNKpL+2FFpYYh3FhF/itUXZE51wK9c4lmFMgOYXdJ4iW4F+fvlS8QQC
Zp8sl/dR6/D6VRyLh3z+CVstnYoQCvzpfu2S8WS9pTq2XlKgoV2uqMiVzAsr
xa107Sk1yE7ucs4NZMDAa1L+vEA+LsnlP+IlebdybnHaPpGCnQetY3Q2MPBM
NoXqSn0IikT0sjpbApmllbq+wXng8v9810GOwN0E9zLvcpJHcnmWNTdHUbA8
wNxYoRreVbPdKppM8J16P35/Xw8uPDZb1cceAe+2ISlv8wLs304rVLlIYO3q
znGl5wOoInkfys2A2wWfyRihdmx880VOKoiJ2KAZVu7FbAhPHd6Tx0vgyJd4
D+WSFFS/ev9493ECgwkvYogDH7Hh8bbYL8vZGFHeWkpQqdCr17FoXUqHxr2D
YdNzQ7B3ejUy2NKJbPfkP/QsCrhKSnrSZ0agPb2ce21WC5xMV+W5rmfinqJa
Qu/2Vjwejg4y3cpErfF2tWfrGqDkLJXS9oIA6/a9TUv9ajGrvHOe4k2H3g+6
ddaXj6jUSUp2fzyMvIcltH/b+8gcxJ/ZtIeOnN5HFxU7aqB4J//+M1KvCvVX
nbQfKYL0m0NGkacIxEnuGl9S2YIeRqmnvtwI6CqBq7krqNjjnl9kOUfm99+5
KkH/5eDDXJneIslft+OaT5qu9eJTkaja6DSBVbI6DN6PFIx9f7tU1GEE6vFv
2tcx2rAweK7j2DM6CjZJ3aEP0TA17sHYcYYJrRA1I/FtpD/TmB+6bzYMv+n4
xnXdjbi04s4mzaOknjpE8BiW1eJFUkxNI6nv2Vun7cK1u8H0/vvo+odRrFVX
X5JKnk3rNpaLObBgsPoBTWexD13jjYEc50g9PNk1PaNSi/BXBPcPTnJfL9Z+
fTJDAd1qht1SO4Zdak8FEmMqMVZSZu75ifTDEryqrY1USOmk76OQ83sgQe3r
dZcurL+2Qtk4lPRnQrP7X4fQEDdR9rJ/mgUlDnOnU4YpyEnaqr7bmszrz9ud
Xwl+xDmea8/dr49CwiyYWvgrDxvXKd4f+8uArDUc3Py7YJ0idu4Hi8wjim3e
r67RwHXP9dFyi3E0NsbNduytQU1z5pThUib+2A5FGOv3wkJZ3+Hw8xG83qE6
azJailRtQSmTJgKVuU+8Fy6VwGR5la+rHpkXHMOftYnXgZa7bYebA5nnrhwz
c8r5iAexD7YupzBxUXCZRW9zDYYvrytXciV/H1+/a2MNDc7b4jT/raDD4vRq
9wa3Ltyym8s0Vyf1OqTNUkSgAJr5bDsq6cfOKYx4GPH3oLTvsERR3CjyRmb7
nEa6caa6WdTvCakHadGxijY5OBt3Lq9pkEB3RN0puTQqymrWJ8tXku/LvsZl
KxELGwPNZestST535F8RXFqGHZdzJze8YyBg7uadu487YWb30/i8H+l/teou
yN8l8/T2LT/X59JxRGZt8ERkL6T1qplilz+h8n7oySHvDLiKNxZF+JL52sPR
cJbVBQ0r1ca0IgLDpaI3fMOaYbX/ftVlsr9GKbNDT2m1+O0/pTRXQOZN65OW
65q6ENP4TnnLHB0HvkUrePRQcUB1h/u+PAKp1RV1ZikUtBU7PZwRY+Fn9oLL
glYLOLRmbkzEkXnNw+uW/99u0JzvV6eSvOoJztm/vIEKiyDTjWmTIwhV+LrR
ZuolfMZEiSMkL9clXVfZdeoT9FifN1z7Sfo35ZvPJ5ICER2be/cgyR8R5g2B
0YvvkVMiv81nBxMFDSERL8izcD21bIjMf5WI3NdU1Y27u9etOkpnonJHqWXm
2EsUOuTvsSL1Pm0wK8axJR+vdD9EcJP+aeLL6swwct8tBQUyom8w0an6OmXP
qSzw2u0kzE6S+WWWJ/62TCLE+F+am5N+d2X//MRUdBUuBQxpR5P5I8HqnG1K
Shuan7p6WiiR/N+6arWayxCmnh4Xj6kYxZf8NS/f2rSBW2dVxYu1o6B2iEkm
efaDcs8yt/pFP2T4xNPZ/k0Y6wyM7SXzlJ+71PihcW/wyms7viD1UydajaPd
tQ2Nwrfze2VYGCZs5P09H8PbXPf74ZsEdsnfd9c83wvZhbyRLZbk85PyHcJ3
PwXl9qXKG+S+6R02Ut+wnob0Fcv+DvmxyXkX1wn+1AyOG7zhZ71JfVCP+DL0
qwHL/KSZAqRf4dhyM8k1IgFlLwSlPK3Ief01ZTSxUIY0eXrQFiapz9yHO046
d6F+Ycm91Yfp6BYJOCN+vxlLPbKdVnyjg2M45WygVjtEw6ncGbVM0jcecy7R
acO9ZzfPz55loJlzXa/f+U6kHHGz/0cZgc2S8aQPvd0Q6ln38N71EQTWzuhK
OVLAOmLq5WnOxH6GQhBHUg3MNHm3XP/BAO+oyvEfmZ2IEL5kqx9Hh4epsJ7U
8yLsueJY7xDMwP8AQ54GhQ==
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41NkfxydKsyXXLnRBl3VrJdYt4q3JKl1QIUIoxMaSVSjVUHaZdeun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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk41Vkft0RlD1ekGTK2hFGTmjeTD9IMgxI1tmRfswztElLJUpkiIUWW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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 45->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lukXVvb0E5UUWcakEppRQpbuSiJJJBIipFSoRBlkjGypaSQk+QpZ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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8Vf8fx6WQEYpoyExGS2VF9TIjqZSGlRDRklSkkBFSKqFQomElX2Wk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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk4lekbPiPFmMZSklBZkgtpGBSKO0uhjbFXKjSVaZo0dXQo2UaLyth+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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk4lekbVmkSUUlhCElUo4YQUm6lhJFQWQYl2TJ2KjFlDYW4yERaUGSX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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 46->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk41VkfFylCjJCQIhVKRTKi5lNSKTdSKUljNyhLWpQKxdiuJZFsGYxo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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Vd37xr2hJFPSS5KUJFKJMlTcSiMiDTIlNOhLyJBUyhCS6BUNEiHK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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81dkbtkUKRagxuCo7idAYGY8RUUkmla4xqCw1kSWMyo0wTcUYITLJ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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns0lVkflksq5ZbSmvoUoxJGZuKQYR7XaKgOmRTjEsrli0RqkppTisNc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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 47->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4Vekfv9ZpQfRDN0ypaChNk8xE6KMitJFf9USSPUuJmwxZkmIUZV/S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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8Ve8fRwjJqjTtUsmIFCFve5ZERlrSEpJKiEIhI5lZfSWjhZJQKiqZ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkfxi9Jpl9NY8sSpWWMLRUKgx4Ze8o6oVIIk5ItDCMlo1IJSfZu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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41Wkfxr0lSxSyNSoppZORpUSDupUlRBkMpUiSDCnDkIoWZKxFDaEZ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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 48->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lmkfNbaJmS9DhrfeFsZWk1IjheJIqEwjpY9UsiSyhJCMsi+TJVnK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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3cg1P8fx40GITSkQTISKYqQ1FNDNEgIiVJRMiJURkMiMiIqI4Qoq7I3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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41Gsbx2UrJLJFRCRLEUVScb6E0OJ07OVQIfVOcii0cLLklQoRCceW
eBuKVmXpWDKTrWEwZhgdy8xvcBCSThJ6f+eP53qu53qe+76u53t/7u+t6fub
8ylhISGhDHL9u5eO/7CJjmvC2UzzfQYHCIQuW5fMtPfCz6PW4L6TAM7PY2KW
1AshoWUv7+BM4MD8aFrPFRbCjcrjB6KGEVikn6O6RMMlvT2v0v0I2DyulbxN
70PlrqIUxcFhKNyU3T+0qxEP2J1UlXACzXn2Ti/zmIisv9NRe5SPgNTpn0UP
czBOk4s8yh2BRw9LKNGGjVmb4JXaN3lwSPfamnfvLRQ3qH47MkogrlRd1SGr
FckuXQk3dxGYuy0SeHiZg8juR91pSXx8dEk8UZPbgXLf0YE8ST5WU4oTdVo6
sLa+U0OgTWAsoNxU4sUrRHmlXxMm4zem2FZvpr7Bj/6VXZdOEdhqw9dnhg7C
5ByFRxEdwlCq/+8fq5mIz75vcluGgHIvNb5buhk/iqdVV3QSKLqsIa3e+R5y
A1mf12qQ+T8ZhfndaMc/NkdG418SiL4o+DbAuAan+n1ipsfJ+M8rDtRF12K5
PvOWiQ2B5FhPqeJoLq42ISGwbhCXUp2UenSeg7ZR0cyIfM9uYxStWtsNndzm
x09X87HRxfrObqlOBJlvV5us5EODsZpl20ZH+7nag02aBI5Ucs7PURrBU6vl
nVnmwyE7RFAm34q/Ur1njCdIvTPsOdEHWVjqX0+pcSBgUfHnV/qhDlAs7yr8
NsuHRNzrws+NXWju8oz4TxMP7I5rwRjvhGWEXZR/tgC2+sr1sV8bEPqzq3k5
Wc+CfOXEzVQmSqydl0fvExj6tbfg4nAu6oNvGLw4TSBxxzH7hKguRBq+VdCP
IOD/0VFmz6NmKEtO9Bl7EwihG4emTjPxxs1ml+soDzvKnA580KhAg0pOS+s5
Ur+2MATc+R1+2TYNBKnHmPFWSlprBW7YLJRLk3pvSJtm2JT0I9Yom8E258H5
Razb79c7EG9Y2PmSy8dPTwLtLt7KgIhFyE9BvgQI+qK3+mIzVuUQ/DF5ArI6
Hs/PUIrw4BfdKFGSX9k591vLkQzcMBQz+qQrwGqOVIiuVje89YXYapIEaI3U
McVTfZBLGN6V/2kE89TeHJYcC46tZb1DJwjYHtyiX1PFhsuCjpewzwj0Jv33
z052Iz6o/HtDvADhgYGb7jk/xhHdGjUpUn9PptV2vdJaUM00c9kcAvV/9tfF
rH0G/5MmPzn4EzAKj/9Fe7wfG/0sTPekDCD5aehkclADtFTDi8bMSD0smp1d
LPLg1sCtLCP5Xd3/pn0shY3vQ5ncHl8BUhw2LLpxGyH17TLCtgmgTq0Wqden
IfH6F5ZkMx/f32n3iXW3YW+sjdvCRgLtfUvK+Sad8FSP4/6XPGup6p8aNG9E
sP7RR67KBKyVwkxzXnbB3SqC1ZnPh2zqweySARr+x/BfaiJ5F/KenEvb9Q6i
2Rome4II2OWtiEhivUGP5+rkLCkCDld4Msu/duGOVXnxGRMCxt9zA08pVEFc
0ajHKYqMDy656nJ0HY5bHaMYk/W+9KxXYbMNC7ZC4mo9BA+VsftWcYxpYE5Z
a078QUAvwWCgMa4UoUohz+JIfzoWshwewKTh5z+rgpnpBHjbrGV4x+gwDZox
CS/iwzkn8bbK1254trR+SrTlY8wdj7gyL6Fo6nLUwYnAYwmD4d6rXDz0vDJQ
Oi/AzOmFhokwDqKlqBc8EnnoMc15z1B8j2M0+t86R/gYykv3e/AoDcJW03wr
kp8CJRV/szctMEitfBp0nA+hbxoeLN0SnIgevs38954ran/iZBncm5qfOP5K
wNzNd4NcZiZ05F5lXPchYEZpl5cqYaI0qSW2eIUA/bjO0VzHBaskOvFtIQ/p
6Tv7Tsy3wjzu7BT1OvlfV6WH4ydf48I4LeiDKYGKPrMM3SwO9upNScS0ErDa
8fDJwkg1qANMR9etBGbqUwbVQnIhtirr8j2y/8Z8zaOkDRugkWCgvE1WgMzs
r9ZS1lWoSUqcX7hI8i6vGH1nlA7rcsWgndV8GOi2R/WKNyCoTvQacweBgLOW
uVpnWiDXlHBs4iUfOYr9emKH6Kg4qypbLCLAmqaxSWn3v3BhxLpLYfMg3Puc
djjf64P7PbrGkD3Jq4fuzvEpOv6+y9riG0/OlzW6d+fVW5Bh/Lpqdy/Zv8bR
rX/QuAiXvlrGceUjRW63tp7gNbR9+pmKMQQKLUPyvwWzoW84W7IpRgDKys+X
zFhPkDRh+erFTgLCpeLJl/P7wKp2lElfHoaGnqFXwCYWqv2X8pKShlFgR3cU
kuyEVs3e7ScPCCB6ZzRYMZ8JtcnloYIaHgpWJMx4u3agK1NcfK+mACE5vZ9p
MwxkL4WytfYRuOkuEiCxk4VNWetf3RXjIWU0a6XDtU7IlZdLTJ0k9e1v6rU/
WAXJdPmI06Q/PDay3LKmrROmRYaPPziQfnp1wdyIU4fC/rb9pwk+Cr1q2wc9
upC8nWq49BcP2rKWlzXjezARHnh404oREKUfllx8GDCom9qf6SaA1MrZog8P
+hAd1uy3WZgHSZovj1pJh7LH9lmVYAJnvPQj8+TbUL2NoqFUyEeBqqpGxCQD
6gclLEzJ+RXpLeZbJsTCmry2WZNDBDLdAzL7Jquh8okh8lGc9POMwMb1x9OQ
+0/VXAHJq7LP4YXiL89QYnv8VBeFQM7FVwdOxvXAERRGiYoAdquyXZqecJCw
O6ZCQZ0H2fknOtW+dah0or+eInk9r/S8PvJ2L266usp0SfDQPH5+z9D0C8wp
p7T8Qub3XZn9g3GFiS1x1e+9Ngrw96pwvW/vuBgQEW59sY6PQ1tGj16apmG9
j7ZLdiwfizEe9MBmcj5/4RcuTvHhf+5sSshcA3aECarZdSRfVRaH5dfVQv1H
E5dtSfpFyv12H7s+mK139nm2OAJRnXbFbs0O1EjyjELsyH6hf4F063kIcZyW
zcl+ZDWlbK+Tr8XDCqdMgQqpz8O69H9sa3GtwZHbTc4T2SNzM77SLXh6U+bT
5a0CCMk2mixqX4D7TnXmJOlf/wemWqp/
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs4lOkbJjppKyJLbUW21ta20VjNErecy6E29CPKYRGRrJC1irJF1FqH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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 49->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lukXtqRVUYR+SYhISExEmVujRQ1qNEWDkEQixVRMhEkYxJcM2RqV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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lG0bxlFIRZIS8UZZImtUWjjppaSyV1QKISRkJ0SkTb1EiiTJVkqy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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs4lGkYxlFOm1QmsshqUiHEppPTrYNDJUoqixSbUzYRqSbEtiapLHIo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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk4lekbtlQTg7KksnWoZEZTIpX1zpKlbBllN8jSkGXISNkKoykaIYmS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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 50->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4lFkcHqG0q0hbqWWjR6U2l1AtqlcSttQqG1qbkVtEFLKJkWtJRNHF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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VH0bpohkq1CWkBR5ZWmx9KrblmhBVCqKJKGUiqJXRdIiopIsZc/S
Kvu+ZSfGMmbsZubMEIoKIfGd769znes65/zO8zz3cy/rHS9ZnV3CxcV1ipuL
6//XjeYsLRnzNlzhCyj4eYmBMAhq+VCbUWyzxjVXhgPpQsHt2kP5WF69FS9W
EoiunJwi+uKQFJSw/EsUgXKJ0/mP9tbBZKPwM+ZxJib6Er0bTnbgVKrYxl/D
TLi4nzdZW1uPtTujS/JlWPiROCm80qcdEiW1G6oEmWjQVs0z9M4HtaHtj98o
gcnIkJQLytVwFN33UneOhejHd4I9rvdia/v7kDXOvZiss7ff9bYFibcz/wYd
YcOlZsOEVl8rnvJtuz7iwoQi1xz181Y6mDuum+4/ykDbfa2BgLU0+ITytKYK
MSHP/3gX43sdTnj1rs0OYiFNA+Pe6IFp4h//X3sJXC90tD2yvB2TUQZ3DmYR
iIrnS+eNTYb3disa9SGBMHHpDZS4YhQ9/8rI5Gajzvpf3eXCLaAqzjY3XGch
X6SMGtvejDChnjg1FQ42LLvYZt6UgbHl+zYr3yUwtnhjtKCIivQlVqq+yzhw
aU1a7XQ1CcKUzUrm5PdP7BQxlpXpQETT/blcZQ4ElyoObojKxYEYZ/XLOwg8
MP9QyRtEQe+lHaw8Ggu3XuSUXDfNx9y6Vya/qgkMXj63Ny6aCr5dmXs8e5iI
1Illuvl0w+1PTOhtwVY41HjpfTjcC0W1nzGXVg8jTaKzWWNPB8ZFHfwLfzNR
rtkQtphUD9WqrgT+USYyXjTbNQa9xtfRgyFyigS+KOhf11PJh2ViRb52DAv0
e+7uMk1leLX3mE1ZLQvVfzOSDihnICBBRFRCmUBdSKux+ulMtClQhERCCIge
8tSR4+tF6VK3M0tLhxHvIdNz4kIjmpIra1NecvA04cHngIoWmEnvndXq52D1
9lUdzPFGeIebXXQXIyCzYmf8q84KjKl8L6EGs1DM5/tH2KUB9tuT9cUsGTgs
6OafhAr4KlyfVRdg4WVI0+t4+0Y4NUiFefESiLwk/yluRS76pZySvrwlYK4r
eVunuAeCNUYP2VGjEO3tmnL8TsVRWUe3NWuGUHXBLS06oA3O0q5G1fEcnA7S
kfUV6sThaB4l80fDUDC0zix80Qmt/u6/9l398Hufs0Y8qQi50fc8tgoS0FJR
OC95pR7Cr6QFircTWKToWVcmNGJst7d6+m8WCv32Su8luvH2xlrHrc/ZGGav
cCj27oag56YF7WfDoM8kUnlb6nHiwHq32Qg2gl/WzxxKpuDvzzKPyVIWZAy4
aQF61Wjq39jz1IuFTNmTvDUrqlE1/NxIoZjEt+3rzNiYLlg4NbUI5rKwc/cF
/iG1Suyr2Omq/IyFTYnnFtc4tqJzx47Wi/zk85dlxh0t2jDxsl2qpZuFAUZF
TKEKHYlOls/fq7NRWHTTUuVMHSaUD/g2i7EhM392ncRLCi68Ljw29IMNiW6n
6zaajeDMSfTk7WIjP2+t25RYERKm9eXNdxO453CnK8K/FxUH7TErxIBV0Eo/
alw93hw9crRBn42g9yEtqdsaESxSmi2xSCD+j2FjalENMjz8nFVDCeifCdyZ
PtmM5KjCGiVZsr+ybxMCu/tQdj8oharWjflkg1vFVDpW8T4PGFnDQfLtPQ8y
OunYXzwtvbCbgfwmlZvy3sWYKL/xynsLAYptzeb40zQ8bex4kaU6iAiuHe++
Z7fB+6xtWnLTEPz9GWGd8bVom5B45MzDRqVFy/G0Fd3I2NtyM/35IBzeyz10
K30EQcuFs/IOBGocH+/nXVKDXzfPZn86zYZ3ncNby9BmSGXa/m21YyL75Px3
1+omyHPT7/99SZ6v29T8rTgPH0e7rBzI9z8a0K24Gyl4ah2W2XSNhVjbwo9z
CW1oWBLmmDJMwHTPiVADs1x4dEeM6DxioX9Pw6OdB8vg8cwiIkKfgGFMBo7Y
deHW7zvRm5sJ8L1R3O/OpuL6x0f7aZ8HIbswEs4r1guj4f+Y2jrDCPeOeiz9
Mx+Fy0QOSjwm8Pt38WD3uU6UcpyFeSfo8N54U7VkWwvoOp0r9yuT+FjDoyOs
Uo1hWb3sKkkC9AdNbWPsRNwjXgoo+xHgPy+gf1qwGZSSQR33DgJXnQXUn5p3
g3v/4dZH0oOY0NkzovaiB6e+9ttOHuyBdeC+uBHuKoQH5oRqVrFgcnTiwrhA
FxhBKU86ohlIc6hMaPCmw+nun4SoCQ70o5Q39ya8x7ScdaCbI4GMk6P9rKkM
TE183jngT0BHP/LhkqEcNK1IjmGSeuViUC36TDAVlQtxmmqXCUzPbtBdt4eC
M919vLWHmXgnEXrj37ouHL0sbshtM4RJFz/x+N5POM4bcDXmAgHjzteOJ+Tb
oSgkC587w0iWW2p63r0Du0NSX9WVMcD/auQ4o7EST5+POlUsJcBTKL4sklKF
yBbGyMd9BO4GjN5Yt7kaW3ROFJlEk/+DR7N7AvOgFnUntFuAjcQG79qomkyY
/zH78aSXgO9GL6aVUD3arzFpZ0j9cTa5o7FOvBlrdWM9Q/iZ0I2X86McpuHn
V6++lCk2/Ji0oD/Tdfhe/m19QD0bHZYY0kxsQsOd674T29m4sfxlhvqJTBy6
NFdgc4WAQ0a6k6RME94t+c0rQCH3iZFmH5TRAZ7oMu/JHAZkJ6WDNa268M8j
9fhdUUxcWZT3/xBSDR1Jf9bFJySfxx5Zr3WsDTtfTObdo3MwUly6smFDG2q9
e/Xzbw5CLLUsqEuMhj1/KCvdNQcg/99ghad4KxzxVde9n4WK/4LlF3s6EN68
umGocQBpSvrnE2NJPmyfWlc2TvoH3ZXHU3d3YN5p6IbOGiaMXctCA9dX4JNK
e2PWAgtc19RKajKe4Wm+ex0/Oc8HIydykoxbweczXRZ+j4XyY+qXwKzG6aRv
VWUepF54xNeW23aB/lTMVKSZDeVLHSHTh2rQ8krAz76NQJsw1fvu3XaojPkF
6x4egr5/j9eTsFQcH/u1nnONgKMz+/Mj01Y0iI1V+rOHcSH89fVjdAqCnixk
PfzLxLH1iU0N09nwTfeZzzpO7lvTmPaz352IoqVonLAmILxhVXPixgocS11z
a0UkATl5xRYTdzqyP63zbtFnYUxnj+3FsQYkxPGKNtJZcMgyErN91YKwXWJ0
fX8mvi1OBOXzU6B3eouE0kMWhguY4X9Fv8AxZfRQ+G42iNtTMxpL6Hgw7Rr8
4R8WGsJOlNsafoFQENf0dBIbvrIcG57XZD+Zn7ZdJfmSMtViU6bdjCvSEbds
h5h4uTXpk92FOjh23bLsL2NB8E9S1S7ddsxud3w1S/oXyr4jTCtfUh8GjjUZ
TBEoPPsleM2nMog9ODi1fIQNimtmkxfRAUddHpWROyzUbS0/JubxBQK6tTNd
KmzcffHYMON+KwQpbzQC/iVQvbxWduxbF1bzxCddt2Rj0Il3pM8tGSIfOziC
t0h8Vli+7Ymg44fh/d2h3HSIjvyOmmrtxkSMRLaQ4Rj0v1+IcLZoxLzmAVPr
QHK+Ig4aZ0cokJXv0L5nysLgf8VSahEf4Ze1qKK9kaxXdn+7oHg5tKVihxa2
ETg6E+acFEKDpSDlhBM/A3pF6+QVGTTMt+6IE7Iagst6zSm9Ww0w3FWZmioz
BJ44RurNqUboUf5eHr/PQsrJ+n3Tgg1wX71jMvY3A2PD7soWD1ohcV1pXEqE
hfgEn3plSRq8Jp65nXHqx4z4PDPbMAu7OQcOhJ8g943y5m7RQDNmXGZ83N5z
4KRxqY0WUgPR98cO5zmyoV/S9bjyYD2eKr+2OuBN4IVKvGTyfTo8a55kb77P
xpVIYy/dTTmQSvO9OJVO4pN7mbadBFmPi5cN37/DYFonbx3zoWLLW+57Sr8H
cczw8eIFsxyMV7dk53MImHn+NyZlR4XezZIHp6sHEPkz/ZsWby6OZmn2DZJ8
Fd+5caNxbhsizDJnxSpZ2M2jMHyX0YZ30RYLdUosvFLeGDLzrQVtorR0TTUC
/cLateyVNLioH7UcMGDAmLukMaC5B8K53CU+Z9mISpjhcxitQrVHjPkCiafZ
k/Y1N9jdiJ7Xe5c7Qe5Pw7OzWtX5yI/qv7WcRkDCwe5ZdnctVBMSGFmkHjCd
3oZmHO+CVdFddh8X6Te51hy4NktFVXvBKk9LFprCT+lk72lFn0hA7cRBEo//
1JakriyFTMWqxoF4AvMF3VuPulPR8bA3bXUYC7lstyed3PXQiSwcnTnEAVf3
JrMK4xS0an+Q/kXu+4s6Fwt+vQ4sbH3vytvJhodIi5hq22e4Swz0zFizsfOh
8Z8bVAo6f+RdlCL5U8+c/nZGqgJX9G/dMZRhQ8G8SKNI4TmivwTIxtiReKst
1DXo7cOdZRf8Z/ePoSlNUjK+iMwPdaWeIW6kXnpXlPtu7YWs2byGWAILdhvE
H/JLUjFfNR58qZaNhicS06E/epC7zjkslt6HmndKOymK8fjbqKShepTAh1Ip
uR2inZheLWFwjvTbg5+2MUacY3FnuulKwUkCGg/aI28vfQt7fs3jkySetqh7
xrMKyXyHjv5O+SFkjIl/q5O4gWs5YYaZpwisEy9Jef2FCmK2bPDkyX5Emum4
rtVPxMBm+Uf3jhEYNvo3ImFHFn6lFixcY5Pz+TxyNNChG9n3MhYXmH2gGLc/
LdjcDlOFjS7JpgySz7e1LC+lQypcRXxsjoNs94WVuqBgxZLxq2zSv44FiR77
apwDnS0J9rsOkvqnerFfL7MBCqmfmy93MVHxz5F7XQ+b8MVMhkuF5Ls0bz3V
+zoU1JzrF31+ktQD/iFpqlQyuodcjefIfuT3BPFbvSjBbzP2ySt9ZN6wM/FI
SC/EmkkBHk8FUn+jbmq5VLRClcc6MYTCAGFyrT3tSju87/5xCPxNoDf73/++
PigHfV5dW0CTDeZM/409K9qw7PZyq1NaHPiZOu6RiL2KvBybeQvSr3EZv02Z
mveAfhql5hbZv0FrYTVNj3hIjRgIUpQIEK2x0hY+NEzkpgwlDw6Dx35TjcVi
OZQ4rqk9x1nQyUunafPWYYGlqF71kcTTc1ZM0Gcafj2MV1NyHUBtR1Ctkk8n
FNYdtroSRepbvO6L2FPdGL7JZXZuP8kXfkZPhabb4P9LXc7dYxBf9I/YBJhV
IGPRhCg4QObH7bw3hlIrYHXgk7KFFNlfbc+fB6s/IvxIqVHBNxbucvZGiJTT
EBXxQbyKwYHvY5HS1ANZiBVYnWFM5iMJi8HhwdefMZrjq5gZRObhzY9nV1m1
oDGQV1nlDJm/rZd7/jpdh3cTYiKVz9iIXG7vlhWUgNibS+bjDcl+bFzdWe3U
hegzGjHLwhi4/bd58J+jHdi+O6j19+ggbr272yixtxUejvtc/6xgYlOJycCu
9d2kLvc1q8mNYnrvtTiDd5+h2Bd6JH49mZ8p39/9Qi1iT61YzqwkUCkVw513
lQZh8x3a+8zYcA7Q8bRxLwGl0HX8HOmfjPf6zJlMUeFpNB/DVu5GWHHUyrmc
Kkwqj7EUJdmw21L/62BfBzxGUoc8Bvvg8ZAhN3qyHQmaeUNyb0g/4PImurI4
E4LE5JN6KwLvA7sfCI/TcXRpudwVIQ6sIjwUmKHdmNHTXaEyTWDCw9JoneRH
UEI21VtE/z+fqJkEkblQYuHConkcAfntPcZKD3LB72qxK86eQA/P5QwVWRrq
OtuM4sm88e/JH2F+nY3g7+96xJ06hEjx4zenUpux0nl0rYQqAavYEu2qdxRM
HOINvrOSA4eZMYHivhoIFA6gboINEcG03LCiOqQemv7gU0vOb9Nf1SHpdix7
ke+3cIMNy4DZ436cPCgqDM3dJvnn8LvLGRbT3aD6/ypZ+7EbtoYfCoQOt+Jt
kKDC8pskvzat2apR2Y6eFE6lPcGE3Zrh3QE27Qj8erX0YD4Bj9Ox8ZeiOsGS
uPGrw4eFadpCoVl1M7oGmw3nwsl8mzqU2vcxE2O7GKXFeqS++LdXtHFl4eEV
/80Rz8jz+1yLXt2txYXy5rVCfBxUHWtymvevxlvhYqOyWQbo5vYT1Q8KwNVS
vMvqLwvJb9yWWHiVYPCekZgK6UevfWMaBntQIL+68wofg4Fksxwvg8JayDYd
rn8iwcKhxweZK782gsu/TrM+jI3yJdc0jHOrUHFW2WDAiAWvzmdp4psLkdCl
WGBeTOKp6e4/205TYZDSd7GFYEAsbn7BtI6CA6l8g581CPw0+LnF93k/pJcY
FeTsGEWV0saD5Q41oGmt90g+x0Jz7dXgGNU++Md+O+tS9xU5Jr1/7yfQwCfq
oxZYwMav4s2hHs4tKFQ/EbI4wIZGOytFUukDqoWenFtH+vN4d4GcJddewbu2
t+I/8j759U7paaNWCO3gDbhYTT4/fJtLbICOwffWK8aoZD05PFtEM19iVZ/8
1s+mBDZ5HZqcWleHurTD0+rr2eiOb7nFt72d9E1S9PQTLJg2VGyvJvXPnDtV
O/8PyefP1dO/S1SDryPN41M/2c+Nrl+28HRC9JHHmdUtDATb2e17toqCuYjQ
LN0hDsztrOmj/9BQ7KaYY2b/FddWHdC/6FQOF6E9wYcPk3lMw3k175UCOC2M
SapNsRD0xrw6Mpusf8lv93P6I+D62Uj7tswdPdGRUudJ/Bu9V9o/86wKtbcO
SX8+zoHneI/P0NVmWDpwajLb2RhO93LrC6RCzO5TfHveCEwDw8/bGn+GjjWN
V8uXjYn0N1KV4pXQem+ic9SZ9J+micnBtd04+2Blc0gyEz1zzS3JZ6qwaS1n
3KuSiUEt9lJb2+dwjspYHWJDwHtRNc3+ag18NF98OTVH4ll7JNbeowW3FcvR
SPo1b7HMJ/zieRi/J7PewoDks6z3wYOvixAR46pcKMeGcdKl8B2yhdg63B/x
eC8BT8m3+1knPyFrYve27ftJfeDEsrZ9pOHJ0jCZ/mwWPOrSTarON6OmpnDz
kh8cTDBditfbVOO94KalPvtYoGStPmSfXorrckfugkHmlcxoKcfjVITZBC5U
kXxf3PEn9phMOWqGDZh/dUn9qGm00nOqQlqgsXUo6e8UcnqUbOKouMeQHKoZ
Z+B/mPovyA==
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs4lOkfxp1S5DCzOWxSkegk1BJbdLdFhOTUOkSRhFqxQuzYqFTbSiSh
0oFIDlEpRGJCIYchzQxSZt5nZtkph2iTVL/398d7Pf+8z3U93899P59Hd2+Y
a6CMlJRUBv39fz1Xnj5ncIKHkoHiSa46hRLTpNjGHB5elbtcmpgSYt/7wKE2
5XocYPQZlY1RqJKVDHJecKAxvOeIMxFik9QQh3OnDTckBVmrzhMwUj6GXDne
An2NN6m2HylMHZnPu1b4GGuSv9wYMiEIjy971u1yHyrt++pmfiN4Wux0fdCX
BxmufanGbSGsDy7+q6aqFUtqM0cvEYIEje7pe+nlOJ/f5cv0oPevmzde4fgC
J/OXhDasF8Emdsmpu39yEByaq7KEI8RScfGOJEEjrPZlJoWKCbSVNZ+ngAe3
BT9kf1kpQuIKasHD3EY4il73KB0i2ByeGGIv2wY/vw1rZqVT2MQUs03snsDS
NOmmmzMBYUoyDIU8yEnuFQWtEKCKUTGY870azhcP1gcdJ2h3n8aJMy/Rfvnu
u4hdFBa9Y9t7xj9Fxh/D/Z5fKewU535eG8dF1FHlr5x8IZoTP6ltPfQU5gy3
Pu8sgvXB31mZY11YoacoWn+Owspag5mKMT5cb4tTHnQNIjhN1sXgXhOmbfbw
WRSFbLPxKemBTlheeL5OVZ3gZ722xlsFXLS7sVzPBFEwWquwQd3qDRbmdb83
sBfCsLZ8u4ZiJ5LPZHNSiinUPwy0eMh9AoeQVWEXzWmecQ4Vd7wfIc0v13wR
i8Ax/Q1jsI4D1l6j/TXBBGlur3z3nuxFfyfx9PaiID+qH5VxnQdvFbZJwQz9
P9Ud7KbAwSF2SmGeHc1345n5PdsH0FN7dMl3mg/R5l62HO9G7z+6z8bo/oz/
pddqrdIP0rD6ZiJPgKm8EuaeKB6+puYUyJyi+VUx4ytP9CIs4PO4iZMY2w7b
novczcHWiHtGy6IIfmRUH7mc8BxH+jXz/jQmsAuoT4yqeI6U7ZdMzjIJVir9
4Ort8wobJ//0r+gWYMj2pO9jz14YTMnmvZ1PIcur4twO08dQZfYyJJsILlVa
3bFWbMHe1YEe77op3BJ+Oe3j3w1vzvF81U8UDl0t+nXasR1jkXPMvq2h4F69
4jeHiGbULjit+CyHAkNBl3lreS7k5Vwq9Gheh55+iomVeondtXWpahNC9Dkn
zNiIXyLYVIc1e78AJlvetvI35WOb7xWJ1B6CVePvkzdodSBt2xZ2sSJBa8vK
l8Vba+CTsLOp0obOh12fyPu1GZPXFMxk5ooQHuMfpBjYCDU5x1SdawTPLmuf
ibEZANNtEhFKQjjluIzOkeqCULSMInS+MT+adpoLaiARrCq1rSawsi8rW+sx
gOhhLv+h/FuEW48y6l60wnLpbekNQwRSb/SnM3ZlQq3J+7h/CAHn2tIIr9RO
1F9qEMrmEcQeGDRuzeNiKNrLlNgIUavsPke0sw6OzFnhRicoSO2vqdX85RXM
auxn/3FVCOd1Z0tHPFsxU3MwPWCFCDmv/IW/hLTg29GMuT6goE0+PAlz6ERf
z9avE7IEOi9K+uxXFiOrKcaas5NAjt/aNGrTgbutxilHaH9Y/BKk/eunPmzf
0/zcdAvBJpbxjZ+G6Xn/9YnN/U4wpGm7XTBShznVXVm1Jwm4W/TTVdW7cDbX
K/6BNIWhQjvXB4JKvIvNYIXSfSq5U7yMiqiDwbFEeS8hfZ5HZVWvS7noMYi6
erKOwkxK17yZHi5UGTNCv2E6j/thG9VKCkEsC1QMTxBUTa9PROhdVP+eFzif
9pOWVx3jfjAXlXNLIhpsCf5iTU7abSiH/eSVkmfutB/lq37W0q+FvcGGnIm9
BD09OnH/feSBu1nNNs6EguWO1x8jDDswqbXt8TW6387CaJmmrAbM5DyfKBqg
0Grxc7B9TTPEI54yTjSvx3oKr4vtG7C2/YGkjJ43y0r9UVk1BxtnGf5wtYNC
5IS87L4dbEwUXMm1MSCYZfDfdUUFLsz1pJjLIESkt1ZsGe0/cVK7nA7tW2/p
7KRKIR9jA7khddYCWFYUb2G0deOk5nkdy346z7uS5BreQzhaqA+07ya41u4c
LdJsxZOQ5Qc2L6Bw1iSgU1eeh8X52nPn7aMw5uolbyvDxaeLAr9FpQIofS54
5HGmG2uzKv6tT6XgzE75aZF/J8RL15xeRPtCx/nosn5hN95lL+yNoX10NtHk
IEobIRkxroo3IphiL89/q98CM9/8gUUWBH4yf/8z8jUdCUpBny4EEGS3jpbF
+L3G4szFDqNmtA+yx2pXH3sK7nE7Kyc12h+q99wWB9RAbKp8zDiBoMOy8Lse
sxO9f6SHbXYlMJBMVN424uO+e3HdwW8UYqatVAwje6F4YG5z/CYRtoY8PDXi
zEZcrft1p/cUfB6kj2S2crDaJFrfn+7TjZ98G8Tnu/F3XLZvqAOdf+QT8dUF
VfD+4HT6aSmB0rbho/dmdcAzKnibFn0fbm6N0D38kQudkqIrF4YHYe1FndJu
78f6nqulq6XFiIiPNzif1gtJ8C5hej79PrE+xLqAjaXDA0NzaX/0DB4+OKXD
h62C5jHdZJonS0a5fKgbypGxzVpsAd6F1Iz0qfFQJilVUPUUwrMqLSYivhM+
TyySPxym+Tlf8mB41GFp4MBkIH3eR2JHTlYcB3vt9n29WUihZ9x/vOUyD2+e
VUZ9MxDj1Ljd4tl+TXhb4qjNr6DAN2jOzl7ZiKOfJ4d3uxD81ndI3X9/G4rb
ZSIWhIngYO7QJt3JR3B20IUvTYN03vk713zhwP5iLsumiH4/Yt/UDL1uROrI
i4Xn6D45qYTEvFQfwN+5/rbs94MYDGqvE4QWYDQ8XP4RPa9GYNEt1/IOxK3m
p5lxKMgNOQ7s6e3DfFO3/zL5YviUuk+eOFuF6OpIY+1jBHffK79deLEDtdUB
4bd2i5AglSv3nZ+Bf31t1Tbuon2XqiQo7MvF9qlomTJ/AjUP881tpzrQIboz
sQ4iTBpe9uIW30TCMdk19fYEmZMazKQiDnS3uCXXjAjREvoqTCjNhQWzRML6
XQhGvq6FI7sFPVf4p/8xJfgfD9/Baw==
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4ldkDx2UpGYQW2oT6FZEKSQ2+lihKg7LdoUVZJtQgZNqEpCiyRI1B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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 51->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk0ldsbx2UqbotK1FWhTKWy3EJSfCUlSkoq6ReuOYQuMjS4oSKlrjIU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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8lI8fl5YyW5IolVRGqEiUN0JLMkpGVKQkRVIaRKSUkb1bSIhCssle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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81dkb1nSVNVxGY8IkS5KSRjNDy0NRpGJkadMgNUS6vzINuoWytEcq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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk01ekfx3WT/GL8LA2FUanIWBKSpfHWOonKpG4RkWyDKUILksiSVGNI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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 52->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lukb1SQRM7+sbWRJpckgkRKOESkjfWMZS3YKY8lSilGJsu8VokQu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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHk0VWsfJpG6mZoomUKmDKGS4kFClKSSREkoEpJLyZSSoW6p0CAliRQy
XZnneR6PmeOcfY5jilJdGb/9/bXXXvtd6937/T3jlrBzM3dYxcbGdp6dje3/
11aT46HVr8Kg/9PZP/s8gdJ38/lVgh/xl3DghWTynjb+VqBuezv2JJyKquYd
xeKvJzGpC2UwmVYIklqgQ2MmzdSUVQnZ9y5PbbcR8K0Q2GprXI4rC6keIfIE
uG1KzTWi8mDy0fHXqiQCzrmuwqr5LUixG3u5yp7AIu3S78VjPQgKab1zRJCJ
XcETB5PVB8C5tq/lkzaB2raM5o7OanAvnTjubkJHXFwCy7SkBluojRk+kgRk
I9w27LRJQvWYR2myCgHW0rWUOp1/YXaI4q44TYeRl+rLuCdZaG2vG5A0JhDq
f0zz9PdmHArdKHa/hYFcRd99sstNcJzePjnnSIBNjTrK7xIGY53s04YXCKQk
Wi3X7sxCr5tL9oIIARVONQUOwyqsGnjTWKBJQCC2ZzwnrQX+HPFZG70JdOz+
9mT3xVaUztpVqsmzEPGHuiv5wSc8CDt9bLUggWKpNP+ewW6YX2XGDf3HgPPn
lQn3xFbwFFW7zb0kQNT1f7o21QHuydapxo2jMPrn6O77kfXIMNzy/lgiAxH2
bXxHsxrQHfAxhJeXAaMyDYchyTKElazcX56kQ+eT6H9ubvUw4OYt/bKKjgiJ
/QoNoR+hcjF9vvQoOR+RjduyesvgWLThkqEBgWEx/m5X4X6U/X26bN8DJliV
vJckbxdg03naV1VyvfHIbGeqdQPC3y7/GJ5kIq1uzVOTiBZs4irQYQUTmKy6
wH4iNQPqI6miW6IIGAj21Jho9qJ0/s+56/MD6Lx7vGbUMRvmj2n9aubk90Xn
XrYz6sFvR/2Gg0s0pKxJX+sRUAmrWkrfnlMMbBq7wua3owzYRh3UNWJAY5tH
VlFHDRy0JgJF9Aho/GP+w969Asz7FiWxPgTERzl6hkWrsElcIHj7ETq4JS+u
l57OhhftdAWVfF7bKhAzJNaA6n9z0oYEGYjcXPWsp7EaHmPn9u0lz0dKIOn5
e76v+LZX28zrNYEtO4Jl21M7If95UW/4GA1m/xU/nHEbxnWHkmeXR0cgm5/j
tyayGnLcySHWEQQiUg42NvJUwLbf1HXUi8DHDoKxw7oTc5LZt4fuUvF0/zN/
9sBKxB0UfeirzISlXoSnXGUWrmS9+8NP4qs1qUhhV3g+xIPM1dnIeehEcKVo
mQbikbS6ia8tgWNzW2IWrAcAlcifvbEs+M9di/to049Zaev51fRulPL9fn57
7ilE3yqUjN0g4BF4fredeC4W/3j2RqgSoPhNGh6caEVozNGCWkcGGqW3mlpm
9qHzaPQet93k86/Jn1P4B2CzNabEgncEbA9Dxe4v+6NGN/aUGvl+ryONS+8Y
VUJrmdGv3kugwMhL770dBfeIP5qHTRlQD749z6H2AaF33qYJmxFwEAs7cpfV
gPgThbqRNQzoTbY5Tc+0Yuqg0h69+hG8LWMcufFfHzQ8haKqDo2BKtHuyf3p
HVYrzJ9s0ScQ+yPBw5bZhS26dJ4OVzoIqQpuj5tNyOFZqFcn8fNGEGce3O3D
hjqB2O5LJL/tFiZVPlZi27TBdRoPgYdfzmVcnS/HVW3N2jPSDBgTzPdfb3VB
o1iDolQziu3bKuSE2irhM/O33EYjOppn5g+Z6FchSC96S5EhE+mZC7EVhj1Y
pyagLC03gsh4Z9nDaEJkkMHEjkYC+sfdbBnh9dBo/KxzaopAbi6ft719Juqz
96Z9Ic+TpbWsHfaiF+Hyry4F7CHxcnnvjMR/NaDVujyJdqZhzjrncPyPFETk
/dEevkPireVVgudkAyziOO2MvzBhGzgeKVw9hHF97V3ys2M4X/jCh2AvQpfP
sNnMagZuWqlvHjLphdngqYr05+OYux3sEOSfA+vvXGqy5P6TI8FnrxxoxjWv
LfVBNgTSTRb3vszoQfI894f7tizw7z2Set3rX5j6bE47tZnA3Kvie7+j6kBT
2V3WdYeOydz0UVeJPnz77GFCaI7CPcYpPV4rDaW+hg9PeBJotpC8GDbWBTUT
AWPz7yQ/1k6f7CrsRKZYvjklj4UXGmM3Zj+3gL/4yB0jYVL/RwJvmqxQoKdp
wdanNQbbs9eLZZ2ewch11WQSie8dBfEOUtpt6I3p7JzVYcLdTbc9NoHks4y9
l/coHfEr3f/90G3AYK/V+ZgWAl7HkjNTPdtQuD5+95csAuozTw492t+LBfVC
vqjCUdzkDD7atq8XzL8UwjjaRvC76HMM31Q5Ar93NLW10UGVEw8o9enEYEmv
orEQAzkT2uUyexphoPn6WjgYsK9m9t6THoTF0OdAuY8jEELou6nV7TgY9NQ/
2G0EOi3eLHf/D8gxyoiUNSFg+dqMqX1mEDtTJ8RP5IxDNjIst+V9DR5xPtlD
fCRwc/VGtbHoDDyt6XvGIv1QdtPygyTuJgTxlqtaXmSAKVC6+m4lBV4H1q01
285C0J2+wrriLgjxe1jH6tJReUc2ZIC3DVJP7wW1knobPjWps3+Qgrgkx6P5
D2kQukr5HLA1HdWPsDl5PYF2fW/u1PBu9DWkW89fY0En4TZDYL4RdgZ7OdSo
VDwrfJL/5Xof8nxXrL3f0NC+xWZ9nnopcpzDj1fGEvDsbn0VmduCXA2V5oQJ
GgYksj0dz/Tikn867N5Qwf1C0dXmcCPMTJkP88LpuHdKt7UvqRdr7MVumT4Z
hnpp9A01Ev/uR1RSmn6QeL1VvXzyeiHk2bbn/I4kkCyw9ueSWz82VEY7rWui
wqyrOzDOrB7PX9ZOKWQwMGMSzHgU3ojmhSn/4r8IVJbkix1K7YMXS/N8DBsL
S6HejZlFneg5eW8DjxoVgj8dBPZa9CBXOMq1jPQTv9d5vc0X2lEqcOtXqcoo
ln3/OXkopA9XnEPFMpRHockm9F39ViVSvld1PrUk9W1Z9kbc9yaU0OTijaxp
kJ29o3MvoRtyXONvP3iS81FxCe4v74LujkD16hSSD+7CLWZWrfCY5ggs6B9B
noRJhFYyBRMj6412xjMQL2bUGMRqRDj7wH97XtHxe9MhWSteCjaovbt4X4OF
K4F71JljDQj6LrIpIY6GgxYrn5P4+zF9Q2/bs+kefPjAU6/lQuL9mXv+HVMa
dOZT9lAYOUg+zWF+OpH0v/aqhgKuPnCOsGRknFiolat7vKqxDQsD9x1205nY
blbsE8zqQFUoH4/aJSY8A0QoYaLFsHfh3HKYk0CCfYGx0/oOiNG0i+8X0iDI
8aHYRq4Lgz1d7Nq3mIhL6RK2tQ/GqSOHZ3+S/Ay8z8PQ6i+HQ+rvQu91BOLz
z85Vox3xicpVEu6j0E5eFD19nQIrXbusZnkq5q6GFXhn9+B81S6/7lIGUg5x
b350oh8U4UpZRT0G2m0Pf/3U1IH7Bza8ErehIf3NDsW8jT2YudHzaDR2GJuW
6Z5f20m/mTE2lnAmELf55s8QZiZWO+Q6LZN5lH/FLVTfsR7qW8sdCXKe4iaP
2b/ufADBX9VckmSe1Diz9tz04UxwJTzTtyD9IplTPvAjWzm+ud2w6BQlYNPB
yxnXQIHzNortTlkG5O9lKM0udcM4SOLqPsVxZHIqmI3PlaPMnyXo60tgu4K6
iG1/DW76GOfKCDFBfWGgGOjSico8NymRMRpYTq9NpD5+QI2+3xMRF3J/eWWK
wfZ+uMpzjxWvo6FVfriCPboSF6vXJIeG0vFNV2fsfHEnUq/Ov5oOYGIxm3Px
ikEZ6KmuW4uE6Ji5fiph9mIBAvuslzRekPlg/zU73bEB9NCV+jy16KiPC/05
sdiJAxkHbL6VMKB/fScb15kmjF93etnSTEOT748nEtwtmO3kqpqZJ/OawLyM
d2w7VPQP5thXEii8o9j+/Ho36j8Uis0IMJHrK6Fm41WDs69UuowXCKyW3zzT
zduNIHHpl8G/CHSt3yyyxb4dq0w3tr38wMJaWmjlhTQKwjdnr1mMYGK6iPNY
cEMH2u+f4+8IZGCd7z+KIXK92GL0O8DHkA7fjfZnF237kW8lmxRzeQA6fy5t
0XN/iFXlTsdryXyhYV0mUpddiRx5dnZ6BLn+BOWBqQsFNUfKJdzdRmErzKIc
dY+DtDqK9Q4TGNJ7vVZwTSfyDZgv1/2mwpZDR69kpR4zV3lYpcWk/rn2fHlG
I/UzUuxQ574JsO268XyXtRX+CqS+NCb3C+Q99GeDwhPEXhqbTiHxreMv0Zzy
sBzTV1adMyX7wU0z1ZcHuXoRqtxW46pERwKHP/+7hEIcXeQj4iXIvNdf4Khw
JRP5rzdlcZDzLhyoqGmwasGLAP//KpeGUfiRc2yF9NtvnzcP+ZST62XaviuH
tUN0ReHpeVUafHPC376JqAS3g+e3Nl7Sf+0q0nbat6FZWv3QynY6zERWkipe
N2JV9pUYP/L8G331j0c7v0XQhNceW2sCmfEdGS8cBpCwXzXKIXIYjebuQdbm
/TA7LpKeyT2EQI6mwKsRFFx/bwauX2Tekcy9+f4ZBS2T3pTuGDI/uSjbndnY
hej8SX23+DHU8sR/iv2UhfXUzMkYUwLW8z82PBjvxfaBB403cunoEs2aeWTc
g87epfDDcqPI1AhUEJfvRJntv8m2VYNwuefFfmaqG1HKAqp/Ysi+o6qw0SCH
gg47md3qTxhgpYUXldW2YkMmkRAmwUSj9pbfB3wGUW7/s27/7ik0BhwZEeko
hRjXZnZilo43H8eyeWPaULDTw8KZzGOf+s71LbG1wcs5JvbDFA2ZuY5+L/tz
QStfKZz8RurDbY+H2660g1l40yJolIkrD/ZylYjVwu6zstT7W3TImiXspNys
wQDVbe0THQYeJqTpaAn+jZPpNuzGpJ6oKL5TGrzbgme1J59LxNBhSS2s0olq
Rldh0BvLVgLrQ6MsemTaEHBLVyvrKxMGWo88Vby+gHKs1qmCzE87T3MeOUfq
nZFUpp/2Ih1WMmZ5XoFtsLo7+maZ9D/PrPj1fGtawTo7wq4tQEeu9O2OE8cq
cKSYwsNB+rl6mWpL1dkqOBdt261XQGCd9PNbfnPd8KtN1fYxGEFl171vBtYf
YMT+cOP0fQIW4aP7JZKqEH9JIhUnGeAKWVN+Lq8fgWrHxSJCyb704q2is3IB
DL6K5u93I/V39t33bqEOrD75c93noFFQox03/DZIx8l5oTOlumS/zWWu4Xvb
As1Dk/uEuxiIVW36yrvQhvX8smYNrUyMzY+tdjDvRPQpHYcyYwbiXmslLj+O
x3pD/YGgywSUkn/WJV7thKBNib+2Ew27q95GD8mQ+Moc16qTpoGqulByyvcx
NO1CiwRIPTcr7I4O2t6AvI7ykPXHGbhS3vZLu+M9HLKKI9pIftte6LeXlW3F
buUT+X2GZL6a0nQOO1CHgan+kdITZD+/KeYoExeFthC5msvnyPVL2o0yejHw
6akzNb9G4FEG9ffiugFwrfmhnCs8BFeJRH0/uUHoa+VyrXweRbVUxErzygDY
+x7nLd2j4IWCwjbNe2Uw6/n7XbQG2V8L3nkHe3SANiIi1fScBjZJfqWF8WDM
ivtv+P//ij+fJgzf7qxAhMHgvFAKAX8/RbvD1T3wMHWNJ6KomLwjJitu3ofg
sGmhkC4qDjLOLPCR+V/Uu7brZA8dgRffP97v4wVb5jlVZ5LP+Uojy6phfZBM
C+7NPMpAa8FxX7Q9gX2eeZ3bKbJvTLUYpBQVQ9cyNa6HxFdr1WFejbtNEEpc
b5W6nYFwl6C5Eq5WqC8dj7Qj9SPQj75Bae4OKmOU7w6T+O7U2RnEF0vBMVZr
zymS33tTPtfHG3TgsIeoT8VjGlxqNirqF1diqFcoJ8SbDovH46u6W9oQd7HV
9og5HT2PG9QeRbVgdYDtXRGyH0f0WK+1jKuF+nTUZmltOrbdkPzx404NjASJ
M2xqDIg7CS6VKg3AMmcua9S1Dylf2tQzXerBNVt0PLydgGZ+1SH1gU4E3aBH
8pB6tOu9xbFE11LkaR95q7eazCfys3Jdt9uh2nU5heo9CEuvUsfvpzPw81ho
keFxAptk8UsmiwJUEFIvHjGwgS/holcYBWbGvHzxJSzU3Qy5pMrogp8zddff
D6hYdNr/+uB4C1z80hv9A5lQH1NSsjGsxwthuTX9ieT7ItvxX+M8bBe9pXSl
hkDphaCMHLZ6JFisDniYRMM3yUeyRqxMWL9I22pJo4M/ephrSa8W7wmPi5Kk
3/A363I/qijHeOSB9Nuk3p99l/Nya1c3Dtoe3O47SAW1elJOPyIPkX/4L+es
YiB6rvrxFK0Gm+ykg72CR+CbtSZ19nwpFoUMdHZtJvsHbYPR01v1WGB8C2nf
SkD+xrKEt24HMqWvRKTSSDyHDP+cEmjHZNDixL/CDJxo3PHpVmA/2Nc2O8mG
0qC08sUmitTrPzdUfZ4sjGJHeEZTmUgv1m8+qnNZk+yrr0czXL714JPYm+ec
ZL6O0LO1eRP3AWXJZ8rvG5B+czTR49m5DjSIDb2/u4uJUPfd6u+u9qOh+Zt/
SxjZf0447y/QGcRaGYGSMA4mLLN6tKtJ/U1L0hD9cYEFS1fX172SbeBWiPZN
dCf98RUPZZnMX4v7l/Y1+TNAPfxMrfBrJXaJWyz9TqXj493OPGfubnB/TZPi
JPOl1DUnq7va5Dz5KL5FqTSIf1Kkysb3YEBFymrbAxosh+n52cqtCLDW7iuT
ZGJILWOVKm87XPfKrpMSZ+LeUb6zaVllSHkz/n52ktRvowDDjL/aEXbSR/GX
IgvUXWdsRX/lwOLoqT35fgSqecJcpWV6oFCSWLmR1OfaymzPuvB/UXhS5+r0
EoGf0oO/H2WVg9vbpJaHzAdxSk6GPi5fcbT7RJTwU3L+vgcST6vGQfaqZVTH
WfJ8Zb4nPlBNgu2ZHYp+FgSYylPzDSoU6CdEMTj+//9xYromMasB3248Z34X
ZGL1mgQns+4+hLqIcMsokn1KjX1w/iKZR3bGBrQwGMiumsi4xqrHsln/X3qB
dBAVtRe4xSjYw1064U7yRRO4uEe9C2mlSle/SJL6T78onETvgLbb939qrGj4
H1otC+M=
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81dkbpgxS2TKI6lKSUF0xMZYekyYlGYT0oRHRMIkWsjdGlmqQnyZX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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVWk8lVkYV8RkyT6DmEGSQsOQpMb/KrKWQlkqI26hmpqGlJmWq4RJUkOU
JUJSso/LXGvXUvbrutbouu/7ZiwNkolU07zz4fzO73x4zjnPf3t0/E+5HVku
JiaWRK//91K/b84xdF9ALP20xzo/Auos3vHxIj4WmD+ybB4RyBxy0E1qyYP+
5ZAFjicFN6+sxLvl3eCM1s3/oEyi8tCcrapaLdiSR0WxWynkZezllnR1wLVw
VvbxawLtjtbrZdZyYeJ8YFz/CAlWqcfXv/3ahiovTu0NDRKzKW9+VVmfD65o
xl7HnYI5paGf+pKHKxWKFTfpc6S2fbi4SR8i0w+xXFJIMPJy5lL0KvB2qeyL
8Q0U6l+PqvbUs3F1j3tKqD6Fa+wI3VSPZxjPeBWYt4MCa4qtOj2ch7kAtc9C
JwrFK9T6JqQaQNR6fdukSKG5LGemt7sPafXHrSJX0/cVcD8ePXMPKusadRlM
Cl6Jdg+q79XiZ16GFiFOgf/GJyFpjAd7yXsFVuokNBiWwecaeyDOjbsgFU0g
zCHgxO4YLtJShzM7bpKwVleLfc5uRLpF95xgHwWTickyTiMHSsuXxDNrSCyf
vBT9tUkvnKjFnqNeBII6XMrTdtSgXunYGGlJQXvy3T65zCqwnXqe1tpQMFsq
83vzQxv+0dBMo3JJmGnpl07FCXDgpNEfRr+ScDLf7QjpVvjG9kVXdZAozLTe
sbmej373jfz8PhJ+OfrGnQaP4BH759ih4xQY10ONkiVL8Nz7wI8cOwqhlXqL
KRP92P7ZrSCeMQqTqcVP5mueI0tpH5HvSuN5cmugZX8RXJvnGVE0P2H6UWda
a3hQcIx6JetA4M5pxY4zFkK4KsfEavGECHJTkLnNqEb0dU1vS00Kfz/vZjkW
92Odj/zl9GMktFc2mxqG9mLzZ5fWon4KQSOtG8du9eLMmOOI7QYCnvwGhn6z
AHw9WXsPIYntL64a3rLowbHWm11vfyLA7LfhnF1fDT2GeOEhQwpR9unMGbFe
mF8MdqrSIRATUSoIlO8B68teO6O9IqwZHDE4ZtUG1l9/yA+XUjDYVjVV5dKN
V7+HZTv/Q8AgzKj78EwDHLUPTrUUklAoLk5bo16HhZ35pRO6FBZ95jVH1Nmo
DnS6en4TBUvHI7qLKQIorXg0z7ojQjjve31vtW70TLZe0jxB+0GuSVblSgEO
Kjy8WrSXQviF0DeKcv2wctwfb0DzY631W33k8nb4nQtLuEXzG1eW/dV52UHw
NI4crosmUR9gYdqVch+zxX9skKTxTntQZ7k4y8W/0mxvlaMUuJa3fzEt4+Ns
+wLb7E/aryvXBLzcNIDv3QdU71UTaCGqPsWfov/3psQudBMBlSHjVl1RM3w+
Sriszqf92JGfus20A6IUq9aTaSQslYsPmAYPInKeGzEfQSBSYul13ZUy6LSd
ns4No/l+4qunGSJAUdi3CVMZBPasn9b4vY0LWXfnCyOxJBLb9Irk1R/iyc7v
/F3cKMw6rPxmmzUfHvO5D/z/IqHHKRnMyuDBT+7OnGgZiT0DcxUnNFvAr23d
ZBRCQvrWm/hlwhdgsldT44NCpHncP3hako+Nxd/8yJwQgdHMXVp7sRUbQ+Kb
D7yi9f1WpkUxth/xwQ3sqzaj4EbtdFKvHkLedGLJ2yYS59Pi2ZzaYYQkkrnL
Lwgx3nVP69njFpx5tDHyIofE1w8WpJbce9HupeJ8jS+CtE5VgZawHjcWqoYd
6fo8s60SnoqdiIqUsy8dJ2A+H4L3so2g5GXErljTetD3qVgZ/AKjqoVzQ7JC
yM75ZB9k8mC3SydquohA2ssLX4S68pAU06kgaUMidPlY8GbNTrgVfl9vmEDg
hurh67kqQ6hxJM3i+ULYFnsruHp3YFfXltomJgGWW5r64uoEmEcHy9p5U7BO
fmJw0PAl1L+0Fd+mOILFU9Fu8fdv4tyCG3vtIQoDo1L6qzNrYJncYHORzo+J
+qgtQs8G7HSV55vR/pMYtL6/wmIY2akzQUc7XiKrOu8r55lyiNkdS2u0ovtp
UNe99nsD6veHvp6dIyFR8mw2a6ENN1h6U3eMKTjs75fKKWpH4VN9s6ZTJOxi
snrY5gKke0qH73tIwPh9vs2G8AeY++I72eQfKMwbL7PzWV8Hv7Mzide/o0BN
Njxzn+yHcPZduEWSCDHJT1yYtgKIlnwzUutEWGVuHiFT14uBxEtK3n0iDLsH
qBUUduBjcbxHoSk9L8YLqpu+bEYG234Dt5aA1T6xzBeBAzguvbuF+2EUCoed
HWUW2rHV09ngwzQJgbVe+ctAHi4/HQ9iDtJ4W29UrkrqgFn/jol3bAJiQary
2x60I8ybTGZnU5A0SarVa2vB1gu7iY8t9LzIUQoLuVuPqIaDSSe1KfhqhP78
82wreGZetmWpFFadxPsjcUNgyiobrjAkoKZ/NvXGQAp8HV8NrDlM42U/cOOD
8iOorLDZEkLz12U+/Vg5gA9m0Dumkq4IrNgXf+9SbYR/XLLcyCCJhcDR5J5J
PiylttfvDKP1Vjm25c6nTlQGJzzV7iWg0H+ielBrGBr5/+Rm7hJhyW51m5dp
Naxcii/FqlAITLlmo/FeAHOOfzInmISYR7O2zOge/FR5L8Kc5uP84uyUyOUZ
OvcUX2Yx6Px6+JOWmkQFKOM1pxMdKOypjTGOj+6EZGhsdjI9X7J2sLiZegJI
nbXMLIij0DEqCjN+PwjbpvjfpEtFuPvk80zNIg9GzPnHVwUkbsZ8+hCXeBc+
XR6xc3T/ObF1a291V8NtQaPHcJyEi29YwFfkCHLqzCP2m4gQ4HaetWozB66v
P2gGnKGQtSzfOXvlU7jxfB/fTqHzw8vz3S0vLuRcm8R30fUOJRzBVBmdPx9r
VmCWwEDhNn8etw1L0SZr5xj/z+/ntulVccgaqVyap9+/+yT14arbFRAWXtyy
9jytb/9WnbdGDaDspz67NZPI7KhKCA1sRorV9V+2K1BIKlckK3l9WErt0dCj
/WJ7alxjoLYPFjfDT+cyCDgJ3QXeO3txtE6vqeIsCZ5PiuPscTbKFx5+lviX
xOtHW/vQ2QqpBc3yoQkC/wFYXcII
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 53->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4lOkbZqUkHWxbjbJlKanthy05bLhDBzmnVjlLDpHwS8raREXZnHNI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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k8VG0flkpCJUWSkFRUnhKVtUt2pSxRyiQhqSQVpZ6IQraQpagsCcm+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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs41NkfliS7i1CIIqlVSULRUvt7ZSNFcquI7eK27v3I5lKSSi6/3GKj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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41dkfxyWTRKIZy1hCyBqiZCa8LY2aCEnSFdmpTJaGHyoJg5QWGSQk
tNglZMhykbFc4dqu/d77/dpbhpqipN93/jjPeZ5znnPOZ3m/X0fB3d/Oi5eH
hyeFGv/Nh7aJy6by9SCyZSHhWCMXG/Z4JqQrMOEhJbmw5TABs3rRG19/ZkC8
gncu9AKBNKUex+u0YUS8XUkSjmOjrTB5tHuRCZXhn/hPB3IRafxawSujAz3G
GfOG10iclA4vLc5vxCvONSUHaRI6dx0tr8UU4UPAOnLTcRIvaJJm80IF0Oyw
HejyJZEemJA8YTOISkF6ZfxdAlqCW9O821+ifG7PQGs7gdm3mw02PW0Ggz8u
mWNHgMlT0T9yjoXEwuuiSRkcmFh+d+zqo2L0qdYoufiREIn5zqr57w4E7eLd
0i9Hwn9Bb+6x5RDEGH71ihIELmw0b44/2YrxUvXKw4kEFHbkHvgs2Y9xa9rx
HXFcMDrEvOmzNbC3n/rx0zkSZX1NjV4pSWjl32r+xykSlz7FSw4F10Ph2ylZ
hSckDMKVnWdrXoLH2Tz5iz0ByRTPPSuMF4iu/Gt/1FESkspOFwOu9mHOsDHO
g82GSJvlm5vSFQjMuS/tI0ki+WbV6vJbOmKCix/xJpLI+vakXdx9EoLkorvY
DxMw4dWWli2JRkPio7ZvLiSyw00bSb9ipC+Gna0zIhGp1uoklHwdme8adK+4
UftJm8Zyh/LwdI6Xd8iLBE+cz/ScYBsu7pSgubkRcHRQDnabZiHUalGiwIgD
bwd5KV8tJk6c2v5sdQOBxnmWj5h9FUzqFRWfHyPx/VcZFf6QQcSZft6rLcxB
z5qapZtzISxemtquOpJ4/Vj3UxfRhYB/za1/20idd1KOEcJN8A8neTJdSRiv
F5dgZVaj1CdMQvM8iSf9jKqSk6G42C0ZokjV0/DM8Nqb0EYs/8m53ClO4hY7
NSh5agwxxyPZ1lLj+FA8xZoabQPL6Nk8Xx6BFvcgR43dNZjttht0MSFhf6b+
UPQvdeiOzi1l7SBRVJA77SLKAkfjeUC+BAcFz7e3NtUPgX8hiP5Sjw2esuil
wBEnLBU63JGl3ucZTXa5ODyI+Mhrq5uVuGg1eRKUJzSBRyJesvekx8CYLFy5
ol+N8r2fZGvVSdgE2HbwzLBgFP9ripEHARMD52btsMdYS0u9feJ3EtXJQlnj
9xtAGIyEM/8hoNrn69cb2o3zLbSbpUcI/Hm2SzL4wyBEx2lflzZT+choGC2t
Z+HD0ybtYBMONmpbZ/6lVgOXH8wkQgYJ3GoYeDQk2YUSXQNRfz4CEf/cDZ3J
pvohfKBVoZaDosRN2xrWj0FzVo7u/IaNjNMSUYVulB91CdV9RVwIR2T+b//t
PiyH5ypaBZFY3iFXbnqjCDkHpdN9jUn8fvSMoV5ELyqfbTITJjiQ+lhn48rL
hNxbrnnqJBdPwq3aiPxYCCp6SW11J7H1XaN0T8AwYgtYKjVqXBTVuoZ06QzC
XT1B9HkYxYfSdxxlo1L82VtwOPMAiTMXJmtv0kZQN/f9Nh0hDtqckvNlgzow
pPc02iebqt8fU2YFzrloUkrQ3WFNYnZDYGy3VjlGRstqd1DxyXfMmuhVdoOm
2yrj10OAPT5QeM46H0W567al2ZC436006lYygIysbwICUgRYnBr3yHvtSLg2
0vwwiwt5qwuNr9bXYknx6T3H30ioehdsF0krRvXyfboHpd9qTT8xi/QBJH+d
uTUrRCC2unsgvJpF6dIk0s+Mjd6cmKfW21vg7r9lp/ZFEq5n0/d0jHciSyOl
QO8hgZou42iZ3F7IF3aFs38k4btR6HVl39/Q+qfKSb6WQOQGV1dXnloE0XwL
KvlJBLxg3Yk4kImj5r+MZp8kIbO5t/gQ9wWink3ctrSk/Nz/87kvKRWQLbGg
yRwk0Spz/hzfyBDyRAKnBWLZmKkxi9TzpPirvzd4lrrPkYpOwK0MWUtqwxZ6
JCJUnx1oDu9Bxj7ZqvwaErJWtox0nUqUaJ/62GBB8Wg4JCwuvxYu09kf+Sge
99zhUZ9b6AOnM96fbjeFGKtvWnSBZhho6D6Q+M+PUTe06o/lYeXSLtV+ql58
C1FHblq1o+hdw/vaTALugaY603tZUFQKfPiGl8TOsHVGV89PoOhVvNfoUQJ2
Zrd7A3eNQrLN/FZwNxt+OpwMz4xXsJbXYciWcpGU3dziJcvCfGr2x6z9BPJ+
W0xYqO7GhlNb1KTvc9HGPeIR1T0MpYXPR07EszFmVyKYxezEz2/lvxRT/mNb
afbLHWSBplD764jXJJiriUF3bMYRf/r3s+HbpsATLaJ0t3MSa++UO7xGJmDr
nvvlsVQWlGkaii0UH52yA+gNw6PQXtw+Ekz1n5GiYypi3oXcBn/FqSYCKVFL
5Abvbiwoat3h2U3CL7a0XEm+D56Xd+8XnuYiNLHMkSeYCXUL7yvS7Vxoejy+
nnuhBcNiXJNRRer/EMwMZZ9pg8MBfeUeARL9ge/qK75/iIj3VWkhFK/nh1aT
J1b7wG1Mb773KxeqDgtsfvs6tDWoNonFUXwVX14y/cxEfI+Ef+gKFwa36oyD
vmvAa3sV/4ExAutExspdh3ph3llNjIqSSJPNeCwQw4Tx134F/VwuXOeD1tyD
72LfQ7ewZSrf3TdesfcIDUHikYiuzwwbfL3yhWuvm1BhMWhZ6UMgtY6deEn7
JZ6r01cW95FYvXDdrNx/EoYPbH5KcqH6eMKs81NLOQ510GLqQki4T8kxs/+l
1pvr6reXcVDtffxoTjwTpcL5W7XXuNjolKzFe2gQvuvXF9IqKD5Fy38+NdOO
gRWFz8+7uGgR/iPVgTGIqpox25AcNt6r0KxU6C3YNR0awaD0KQLvuhU7OvQn
00RPapDQOnf79MxlFvrLjC0GFNnw4f4wwFDpwYmt986/3kjxfyc99uB4M94f
TVjM0iUxY7PzPq8nxfE8dc1G1gRkbQ21//LvQRXzgcgkQWA6i8Hoi+rFp7Xx
Ox6BlP5mcnKupfXi8KX934ZOcBFrejdSX46OTAfWZZ9XBF6Il2qM5PbhkP4W
Z8ODBB5IXbX3VutBzuJ5FaOXBP4PGfu3Jg==
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 54->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8VWkcxm1RNGnamMxMClNRDYmU8pShqxJCBtm3CpksWZJSUogsSbYp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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lO8bxW2RimgRUUmJSpKipDqRpZKiBZUt2ohCkSJk+VoiKkKEspcQ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81WkbxvESReq1DSZLIzslNYrisjYc1ShekaUFLfZRQg01oSPLy4hI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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs8lOkbxq3atkWRcqgIlbJiE0ohl1Aop6yMlbCZjGSL1DisUwihk2Ip
GSunZm05aySE5BxmjDMz877ZtIhSaZP9vb8/ns/zef667+e+rut7q50853hK
XExMLI06/799krwtvAV9SBoPG1XdJMK7RdmOwthhdJqrN12eGYXG2bhC0fJ8
0PV1s2d8SByau8I7nDGEqoxps+VqJPz/Tba2vNcDl5wDC0SFCBq/Bcob+HTg
rQov0ET7FeaTWmocZ0ph69uSFBxAQjEELyZGu2A3tex42LwIL9oj+pwneIj8
9817na1CfPnOKHru5Diykxde02UFGJlxFScPtSGCTPez/4VAjuWy1GbtHtgL
py4teVHvhBxbKekmdGU/0ps8QMLNYkGoJjcEEZ/9xMtfgFzH0j0FFUPwGfhW
nqE/Bvmh8GSN/CJctlCxlokncbtNa9MT7zbE3nRYfiaBgMa+8purcutxG+yM
NxtIFN8cm6GVZENNfMMJTzcSNWPpW23RBJ5RwjlZDRJ5ypr1hseq8eMKpvii
J4klyZh/s9cOIVM6U+b2KQE42vGz4xcHsFOXQybZi1CzWuFLyA4euvbMeMdZ
E/iHI1EfT3Qj64M6FHNFcNUrc1BQ4oJmZ7PMJ1UE0+ObOKa7uvAio9XbUZ6q
f9pVoSqvGv4vuXobbUkk1BmFBuxuBf2v+pSCagJ7eWvTRtJ7sW13VYykiwjF
pso/vDfogJSrW6Qr9b/XXYYd3o5DuPjDPonIO0JkWW3QWcsaxvlSMYdJthA3
WEeehn9txIk+tazCywRWbisPcjGtBH9TqtKiJgn2r/o5yrps6Mh21KZeIBG8
JFjapv8Qbe3DP836kogb9QgVMMfg9jH/2dmvAqiW2elx25ugf15+yreAgD9z
0lI+NwfGfnZjRTTKD2NSL19IlWCkmramhNIvuLaiva+xDaMLx+QEhSI4uoac
arnajbr2h0u8RRHo2gc5/FoeTJJHdWc9RFC9m63G2nwLb6aOdspS+ljdka7V
a8mGpuDV409+JNJWKfQydzbDpkPVdayL8qsZs9JkZT2cltgR2sPUPAJSDUu3
XIRie5+moweJZrEvId3xbVgtGrG9USOCRUu45I/ujZCYqYqxziJQ47IxQj+p
AaF2O1UjviGx1ajlt6wELsSfix19bEbConJd46TXc+R9uMu+eYKqtz4rLK69
B0+CMzMPXCGgSxTnf/N5AInvfpS1zBfirkDC0tjiMRx269yppfxjUdvFds9r
RF3u0XJWJIHwa4rZBju4CBVESFzoFcK4qWFQ2bAUZz5pe9DtScQqyRj36RfA
f/Mx2kEGiQa6h17xIBf3rOlSSg8JxDR6hexldWBC60zrz+kktLQKYqWv9yAq
kHlmrxIBh0f3zM0GnsM6iv/Ybp7qb2qr8Qr1fvzzMsr0bZwQpinf7Q90rkaX
pQY37CcS2Zfb0krPJGIhLlTXhPpfa9EaB90UHuyH1cYrxyn9WWE7hIo9WO91
WVGaIMB0Sqa1G3CRtSmcU9YiwOAhm5j5yUJU7IycEtBJRK065pXyOAhsSakN
QndKr1eD0Rw5Phj+k5crfhVB/qv5u/yqenTvWGvp+TuJlgkf2rNaPsReHzGm
TY7Dt0fFhohqgOstGXeVFAKWV9IPeh7IQe/+IzZW3iTqj8p9VXftwrrbzg/u
N1N5uqQXEfGsFr6ew9J1O0m4xA6mG61Ph5lqtV33SRLqf9JpVfQhjJOxb3c5
C8BcX2vZH8aF58IbhbsCEboferCyLfoxFHZEzueXcfivrmrQ767BjoRvO+59
JvCu0uWq0aoRMC7yTXXvCuAet5/R5N4MhmrhQPRKEmKSf3hdd86F5F7DZxGu
JBIfaLVtVG1HdHiW7PNoAoMbq/gJkQMQrJup5NgRMLWcFUkWDWEXx3SVW8Y4
aoPmicMvOvEo6rZ1xW4CC8EBQYWq5XC7NfC6RI9EibeV9PcJ/eg4+3GRRqN4
sIxz3b+TjY+8uT+6DlLzdnY0eixehmBWQKq8DYm+O6XOpnpjULq553nusBCN
PRrm9zT48HyfxVr6UwSn/eFczfhiHGLu6jlI8fvwRgsew68HMfn8UJLii5v5
lqLpTQ2gB0Wl3lGh/Eiq2zVMtOPMpS0R5e0EtLbP22Us8VHtOPv+2i4BxI5/
3UF3KsMHhuyVPC1qHipGamv8GFDsjL+vTuXPvfvKsf6kfhBvS2/WSQnAOBZc
qaAygH0fsgLNGdQ+ydHcJe3Fxd//LZ0zYYmgk6d41TazCPNWL/VohiTKfzEs
NlF4ARVOuVOYJYEplkdo7HQ9jieZaHZwCbCnd77UFO9DW8tWq1YNIVaGnxB3
EI0gadFdezuD4i8nmb5lcwe6z2Z4zrGoffCzzmTdxQocmvxHLsWByrPMoFlQ
SC/0P6TYTlL8tecanlX+3Anj81l7m81JjESHp3guDqCvJ+WjWYwAD/ptwhIc
e9DAjPM7ny2C1A/bOD5lfDQnNuzjWQlwg+34QDo4FyekBNuXU/wyzQ3utZ0c
xMSg8rKYlRSPF+qnWV/7IHPqfvRTcSFq2oYPS/7eBPEvGb4rqP48HTUMEgM7
kBTxVFwvjIBx+g2azvp+2M/1rBprE8BbTM3vzlAPJpobLhnOEPjst3BhYLYA
Dj5Stx9R+Y1gxK/b/nwMbOX03UdbhbB4JLeaeW0QGSssXFdfIyB4ejI/7XQo
8uQtGdlUPj3bzYMi51uw6PtTctEBar6nPt1yXTmC7b9rHD98ZAymaVFTVw3G
0Ds4dS7vtBAucb/uL7vfigvQoPtbEZjhhdnGH27GeSGn8K8VFG/bpEP2hXZj
zat5zWYfETJzAruu/d2J6cTTG7QvEChO/K7S+sRT1Futc07aQ0JCSeVLdQC1
3+rezQR0U3r9mS4dYsnHwurzrUtDQogVHC+xC8xEwr5Y/3tUnot/Nv/IlG2C
+/XKb4bmCNT706Q5n/4Cc7OEhLQTCVlZTl/Bk1Fkz02P6JYIsKIsbfm4YQu+
v79MKmVWBJlAAWND4R9IbT6VoUjxNkdRvcR6+wjEdZhsYs8IpA4UOcm2vcS4
B0smYo7KS43HzOgVLg6qaFcbZIjwP8n3q98=
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 55->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs8VWkXx49LUpShkhCRS42omUKTaX4kopJbGjWF3C+RkC5SJpIX9bpV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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lf//xjWkgTSMkKyMRJKQ5FIfqfCRlVFkR1pCouzVEiofIyoVMkNC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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41tkbxpkwL2mSskS/7BpZQ8LQrU1aZBlJQ40hKiPKluwiS6hkSWgs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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81HkcxnXIUShCaGVarF27ZZObnnItSjlzZKWW1ESppG1tmrGJ6HCH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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 56->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs0VWkflkvJpUS5lCL320yohol6YkrC5JKEQUUNoSIpIWSEjISpRIbI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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4Vf8fF5IkpLIqSUIqScs39EJLVlJmGdkV3yizqVJJdhp8hYwiihCy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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk0lGscxyd7C7c9IeFKq5tKZKlvomghpJJkKZRtULduJpVKclGi7m0x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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lekbxiWZIUlCWeYMJR1pmmpU0/nRRZYsLUIpimRNRpIUn5JMiyjZ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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 57->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lekbPiFpUSeMJFRSZEyiTcitRqXzU1nSKIokKdlahU6WSEQaSzqW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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8Ve8fFymbBiEKLVoou/K2UlRaEg0pDckKUX0VIUrDKBISUhnZsilc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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVns41FkfV2JFRViNVFI2olDkVcpHusiljTKjGkXWWrmOipA3uiwl90i9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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81Wkbxk/RaI4lSqUy2dIylJGlTS5zUEpyLKOxn9BrwojKklSWSTVM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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 58->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8ldkfx29jKWmxVZIWM0zSNBTVHdunGZSRJIz1Rzdc2UImRjItJqZk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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k0VV8bRqRMFYlUkgalkqQo8iiin0REZC4UZQxNhAaSUIQkpZAQUpnK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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVns8lNkflqSSJMktxarc2oqoddl6VC4lKdqkoYhFSZHLLpaIUrG22ViK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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4lekfxjUx/DARQxhLtkjWCEnnVmmIklBGm+xJlqmxpUnFIOcoarJU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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 59->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lukXRlLZUlJKsmXJFBHSTNyWiBqmpJgiIrJ8xRhJElqUraQkmsbY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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VO//xq0lVKKQdj6pJCQk4ZakBYWQFqKESEq2SpKIooVoQZJ8syaR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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lekbxn0aaz9aZlS2QqKobJHS5JIoE6GStXLsZLILUWMblSVH9goj
ESISWpUlEo7lWI5zyHLe90gmjT1Tyby/P57P88+z3tf1vW55J5+Trqv4+PjS
qfH/OTVgF79lBguFqtOBjio80KyWs3QyErHaurnU4wyJXfGRwStfe5Fp2XVc
OICLK8k7J4rOtCP0veW9gjIu5lerqdYsMnFFvPDc9A0CFXLZpWr2ibg3KGVg
aUfCQp0pa55QD/9X82ucCkisu87czHzVhM0Rcx+PzZMY1Vt+fW6lFFue9EuI
2pNo/+A4bXG2CpwTlaZ1x0nUMKYcV75241ZSbblrE4mTXz+rZwU3QYUn+E58
BwlTa4WAlL96wX/tYqcYg8BoZegMSzMXyGu9X+BIopJ2e8pbjQUpX8+t6v4E
fEuzEyfpLCSa/VPhHEKg7vNXi47yZmiZjGedtyGx41ikv05wPfi5+x52a5LI
TBhebmiohRnzQqzAaRJTrwvZ85t6IeDd09mfx0X4Ub/jHXQm6kIfSX5+RWLC
w6aFZtaCqllBZiW1Xz3w7xUTITq+7NYcGj9H4kn1rAZdkomcCMfntSe4UO2/
tt9djomU4LEBxd95qPVzyjMnByGQKCUjfW8M7awaraqwRhR5hNBHrxOgG+qN
S2ZXQN2gtHHxMAn7ax6P5mKfQO287KqCjSSe7npa5DvXCfJvWpOeIA92GrFm
EVYcbN8hpB2jzUP4L+Ii0zrNYPDIePpTEuNb5OmMG2xoOpp5mKwQ8PiQ2s4Z
fodzacp+IwEExhI876g0FMOvOsjoxiFKT/bEAfnox1ANehVi60ni0JCwevoM
C3Mi2Lcnhgvfx7ZnCvPr8a85I8JBlnrPD6+9W5JqIJL8tnNrEgnbER//KKID
NToiXbsXCQTMOmXkqXLQJJ5wy9liFHtHQ45PyvZhuN/6549fKT+lxm8cUe3D
wcjutU/1uahb3PBG8d4D+PZ8mdel/KK+5wxffuZ7uNKW7Ap9uNAX07dSSHMF
/+X8rF8cKH+kzZjUbmRju/kAbXgTD/OKmo/VBToRSw9Z0K4m8OkCfeEXhy6k
W4t9UDYiwRl2OX1RsxscE7FCqW082FjPRy+7lOBXz2iJ3yn95eqZStO0YvBd
MhB9T+mZKXrtR4NdP+jbFIOcmggUVfFHtF/uhHKJiMPmHBKCVr4RC+ffY2Ga
1uFPvZeWe2NHoHg7DI+U1Xq68jAxt2ku+Oh9RCYl2509QfnrNP8fir+1QbnF
WMFNiMTAEeX+rL4uMF3GtRiUXgdbFyPOX+/Diu6HoIPDXGSPJipFhg+g101V
a/vLMWjFu9mql9RBRtgrsQzUfWMiNP9HGchs8AyNpu6vCFzTXhPZCAmV6ryj
v5GwfJlfkhP6EsS80P1gCxLk+iJ6a1sndEWtLZ3dSUik7h/p3dsBoX2GRirP
CHxfNxL+IL4WA8zVsjanqPNE2RHyKy2441wt3RpCQjRkzJPsr0fEZMwBcoWE
cpXIc7E3DFS6eE9vKyXAfO8Vvv8gG9NbYtI7ncchfHRwTfPWArTs6P1Vgapn
7fWrSXrebHj/s23J03YMvqdff67oZKJcaG7yIYdEg0NcwhcTDk5NR2tsGCcR
9ZPK3a6LQ6i+LeMalUnCWKrI6w/dRvDdZFSD4i/BWW709UwvqvmEwQ7iISba
1Oy1ZAPYNRd/yssjUZRz44q9dgcqtscWvEkiIDPe9Szk+zv8HPRSI9GU0vfZ
hG2TPRN8zaIDttI8SFkH3zvZ142621EzVkFcpGZckLgT1ga5u0Z65ntIiCwt
jZnc6YP8ZLre2V4SVhyz+WLzt+gfj0odiKL4CUhxK61+iqEDrn6LJSRe3LHL
d3zBwj2GaUBLzBgqfOIHeo60gOXhX/NdgkTyJr5mP69BDDXf6uk/yEVXge+3
3KVGxB2WDtCmeFa6sH78WnI3yvuUfDIXSBy7+mK9leA7CAd3Dp2SJnFlJnj3
CKcSTgfaylnOJPhv3q5tpfLvk/7bk23VFD9WnkbexeV4NV2VLknxXZXYqHg2
sB+bN5Roc3Qp/WdF2z6zyzC/5t/U3RTvd8skNS89bAYZs9Vn7U0Cbrlsoutw
A+xm0mTyfxCY8J6TLfHuwc9tO7vOPycwG3TymDSXBQF+32oVTS4GSjP2Oa1j
4JKnmWCgKQ9+eiqujzawMNki8k7hTy74lG5P0fhuwfn0H8ZNv1P6ZaSqHbLt
xpadazROaXCRW77HMM60DyqBbz67s7hQWLPTc9LuKW7azBiL6VO8ZLBVHLMZ
EIzZtUomgQTby19B4MYg7E/5d0FrDDbB83lLUi34elJ2/6QfCTNp1pb1jf14
Xn5wxMiZix6hb+fapprxZ0qqV/0lAiEFq3P1OY8RO5IpzDQmIfMt+2VeRh/i
zD6dVdKg8qFY1832cCPidzZnO9JJLJkYLn5TLsK6phPvf6N4Mw5Y2yNDtMLN
wIDWvkj9588z/3Og1cN4Kiz0oxqVJ736fcb9t6BzN6lSiOqXOpdg8DaNAcOc
y75Fuwksnu96mZDSgJI4nU9FMwQsxZdPbVhbT/WPJLFUan2eYdgJyZUeFOZb
RFyVJOB94gsvK6wXSyI/DDxyeTiQIVBc5j2AQDsdjgHl7wMDhspLRv14suqR
eeGDMXwMjvj+NnkAYlrC27cljqFO74K1UzkdZvQHVpepfhjkG7YveTULgY80
nD4kENBv3n3VoDgLM/7ukilWVL7HKZY+yO7EX7NqtzdR+ah+dSHpqP1fUJtz
8XxGI9EiFLCoFNGIsDaGnL0exZteJZGVQvEwOHsulcrLfWl70zN3cDAln+z2
D5uHtYycVK3cdwgUeDFbbEpAwuvHGa0jbHCylbXkXhEopLkHC7e/gVOc/OBb
N6pfP2xNElK9iaGN4y2WtiSmc+VzIhvvw1bDX1ub8qtFx33F6F29cM8ONwvs
ovixuasn1VuLKr8rUnup+lfxc8p2Oj+D3Vb94efhJMRdWtlv6puw3MPU7Wgg
qfyP1ERUHUQGUxLVzlJ5t9HHZXTiOT7RQ6OXlUg4pE1d3hbSA5WjsS/aq7hw
WYg5LnasGV0RE+5OYiT+A/hRvRM=
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81GsbxsdWHUkhJyoiTqc6r4NsleWiaErJ0ikpTbbirY4kW1RHXooQ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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 60->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4ltkb/sKkmBpNWQY1mGqIMfo1ophuI2FMssSICjVZpkKEClnCIEq2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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VN8fVtmpaBFfkgohiZKQvJSKlD2pZEuFyhaypFRSiIhSKtlDiyhL
QpN9X8ZgbDHmzlhD0kLid39/3ec+zz3PuZ9z3nWjg5vZ2aUcHBw2Szg4/v88
F+jr732sC9qz9LQX8SxwiL4beonjEA0/cEHLlkDLaHWlUEIHUtRn7hqlsJFo
+OR+MEGHgmBc1xFlFqLCtW0XvJqwYY95+I9mNvaU5S4Iu3fgsQWdtglMLDBa
FwI9GnBnvmQg/fMgop4YRlknNSBt2liC2c0EIbIk80g4DRQd76TfVQSMvlpR
VfbRMOEus+Mf7yAk6TybFB17UBlRpPDvFhtyvB4CsqVfYNYdbXvyEhM8i7Fj
IX87wLs2tbZuYRBlBcMCC16tiD/fbXBg4yAoysv4xLo/4smi92R4PoGaIdHr
D2nNoBC92rweg+A9M6Vn2FAJhU8nr/FzMmHMPFNvuroMG1ceZ34pJ1BR988p
wYUGfSn5PN0gFiTWDKynz7UgMPJTiKEdAdW9793W7X6PIvpdrYJGAqZ79lpX
GbTAPfNnNbcWEw8kT+VonqXCS/R7Y9o2BqS241XcYBUii6laSmMEEvo81da7
9eDknPjWQIINdeOqbr6SLkg+6BnkqKNDZL9OQaBdK+bNz+vWzDNRuCvxiNHa
dmi6Nh4UvMXAXdfBQfvvHZAvuXXHspaBIDvfg9Y9bbDoq9/6884QFJxFKkyP
d2Bai7KiNY6Fq+rJ4uvC6EiWExipvjOAKdrGYz0Ob1GxED8ndoKAl8uapBnB
bphsNg3wCmTgdXHKxTSDDoz7xVtvcWRhNNbFufBOF8zuPP9jrPIVyp8f3H53
qAUtn5dcyu1kg3OJnKvD3V6sVOSzmcwjMCWauffyzhY80kl1LztHQIpzyeYm
szo8KKTlN34cRPEKN/UT7AoQz91ucSey0Jvpoq/2rgG9DrsjMrtIPE7ev5Bc
2YaFF252IZcYaNGK7LrWkob5tQu5oR4Eht/rPikRqoG9EX9CpMoQgnYJzrD+
3sa62DrKaWsCdNdAbu1vjZjp/y9L7wOBAWNN9rWROnCEL3ke7MKE5vpk/+KS
TgwolKtmLYzil6n0I7nxFoR3ptskhrARtc9y2WhKJvQi1d/mOBFYszMhe3NV
AeaLhQ9slCb3N2+KoHxvhZMW1+I+aRb03deHT/zMRGk+/7bKBAKlxk9yE192
4vDqQRtaRS/co+UalBby0ZXS2nyNn4CddIWFuEw6wmqFP/iEEEjaMyqVmt2J
Wb4soRt8X2Fn8VCUa7EWNtSWhP0abHzlzO2+zE9Fvbc031dy/5kZ38QbF9vA
3/eGb4cFEw23b2qY6X6Fe3ft6F1nJgSNRu+MPqPiv6e7bMfsWOBtaz/s65aC
bcSg0gUHAkE+PSPKhrH4JZtnGmlF4PMco4pHvwvqW7IMRKUYEHUMljkfVYNE
OR/DxVwCm5f/vF/3pBXXQqPt3dcxoRhndzRNthtqDk03A3wGYa3hcuv56krk
2ZeFXrQnYIJvcW0chZisuXijZ4SJxD0yEVEiPXjisUmm7OIghjPWi8s49+Le
KiW6iScBuVvPpjNlH0L2m0+TGfl/3ZFajfpdnXinW7kyJ5GNqc0P/uQ1NUPf
/OyfZ+uZOLri4N+kvE9gx29d7neeQDzBCO+lFULQzuPN4CsCe1d9FI661YHa
mOQL3dpMaF9UvVWGcuy6wLWwpZ98V7LZ8t3hC9L3uxbtUyCQyng+/iSxAxwC
vENuUwOo2dpxPp/dintSVjmVrkNwl/xq+3QwDZe4FDVKUwmIilcIy96jY+n8
cOIPUr/mTytx2lBqsS867cJFBguqyZwRMuuakCfwrNR8hoBjMd+EexsNkprU
PdyGI3hcaNG/sbgWzKSpAObiIFqqTLdfu9mFvTl/dkVEsJAhxuPLf7gGzcr+
Sjq9g/ggc8dhxLgd0ypFeeUaLDzeLuV7yvE9RNV5svl2Eti3ZtxM5l8F+HtG
XGZJ/FGXeV4OjqbA+kL1r+hBJs6lfFNYa9WBxLt8jWbHSH49CJDWP1+Fab4/
o2xSjzN0Z99pf6XBnT3HH3OdgRV2QXOjyq1wOechn2PDQmLKyQPiJm+hkLmt
2zyGgH4Z/4rctw1YrjIWZhPARO7LrR3OEwVQpjd4tYUxMWO85egvWxJP1Wmu
EduHMZr3LyYlqAlVvCvWv5FlIHjl+KRyXjp8ToelmQUR4NVI76w8XY+rhn9X
ausTaJteemp1Qickf3BfzLvUj3VvdNhLnvbiN7ffoW2WJJ55GOnq4l14pjXx
JY82gORg5pWPdlTEPLL43kLqe2p6Az5K0jCSqj92Jo3An6Ar02599djBu5Ne
K83GM3M5dXGHJpy0yqw44s8EnwP/wpWicoTcyR7TXc2CUVS9Nn8BBUZT+TrJ
Rwhk91jsmE5uAGVrqVCsLwPTmw8sNuY2QPPN4VOeruT9+wjEZE30QSJY4J6b
OBu+ByUtI0tL0NFNzVAk+WJZo2a4j78DFgsJ9ter+8Hr3BAprNZO6kelam7I
AIR+3DygMtaD+Gq+JNOOQQgezD6nTquGnut/3zqXsaC8yc6jObMPBZVno+98
mcCXv1e3BD+kIb4y3SRahIkSPonD08JUeGcv27C3hok1xe/crhh1Q7/toE8W
awiL0qkrX7K6QHdJ+fT++gDmL6pKRtjQUewfX/pz9wiEgoKZh/+2IsBY2Mbx
OovEz8nR6IAanJN6u0FRn42iHSLlsu1tyL+xedXfahbKNNo6s5+2YI3mXecN
BUyIikVWaGVUQu+x7ZMwJ/I9/FvyPds+THV0LnoXEHCiJCxNt0qBTinj6VHS
byixN17cdS3DCw5qnZMZAU8LP8Yp9wbs+C9cI2w/gcSMmXMfmOlonBPrjXEm
/Vt69zf5qXJU+Ssai9WwYKfhlNjOSwWv7Uxe6gMmXi067T2xio6ylr9ugxoD
8E5ee1nHIhm+yVYm20n/oYjID88rxsJvIO+08hkC7zwpJ7VG2qFuaBXAJ8CE
1Wzj/RetnZDddTWCIcLA7vWPjpZbtiOXImhbtIKNu++vX9hxpBicj0XC5sKZ
8IosdKn514jq8mG/LZaD8Fchlo9atKJi2afZ+bVsDEtpthzcU4uca759Ydnk
/tyH1K+bPEK+od5AoAuZr747+xd5UvHTwNxz1y4Gopo+iKlY0zD71SvuDcdX
mJULfatUb8c17rdey9pY4KSb8eg8a0XKq0uFEqvJ9XWVt2/6vIPSrtY4p5cE
7h5qOXV9QwYWBh46VfgR8P0ddrivpgUmPXzmRcvYoLLz5gW3tGO25UJbrh8T
cwsy8jqNdKRlUbgKnzIxnVOwSn1dL0qGH13920Og6lBGUJwrBREZUm9nhwn8
uvNYd+FXO27+PjP7+OQgpIbXGoxfTsavzX0UDRL/De+rP3+nUmDzLXVoOelP
H9SL2JRJClZVmilOf2BC5xf/Qcv7n8FfHm0kM83EsFwkTwDJV+1803bxlEFw
688tvrTrQrKb+cnlE0Mg/A201uc3QDCocSI0gQkJ5WWB4laNiFjSpHXbi4ln
CttGCXE6fkXOO2msYkEzmnK1RoSGgMum7RvnSD+M8zxqubUHsoEGi3+/DCJj
rYH1SdFCNKQGS7ST84WOSSk7kPrC0+Owwe47G8u+y78K2F6JUhmrlflPybzQ
GrXD+WY+OFY8pHkeJZDuGnlzXqkN/u0l2R1rWXjKk6e9opSK4nEXu9Vxg0hY
Gdh6+RsVvn6cJbEPmXjU0LRRuLAdRg3i5UvUhrDrRev269cq4fluSoCykuTT
B3rBU+Ey7NLOk5cRJvmqqCt47H4ZRncsppzxJfHdykHZUf8J41viKoZXsCBk
bX+mbLYTB+Hoo/NpBFG2ledHlSuRONOxSjKSiU1sxcnXL9twk7mzSyRgCBIu
u4z1ztCw1OLNNyU+Ei9zf+7/o9ZB1t62wMp0CHppLNWZnG60qv4OtPcfhsW4
trbBszYIyy75+wUkfsq2cjo2lCBEzHT0vi0L7w6u4pgS+wwXGx9dgspEzFL+
5UmJbRhTWL6iRmwQdhXmpXXFmcivnmztIP0xKuNLoaVYNUxieE/5fmYh6F5m
lE3rGZTy2Zc8J/uFNdeKzQthNaC+1xJzJfuEXCjPPd7JegytRn7O6CBeJ8m4
fvSkQfuFeuukzRDmk1TkvqzqgEpZ5OrpW0MwkRHKD1BKwnatsx+FST7lOI4/
G6ntwT5/duZ+eTZ4syIfniPxfFfFsiz1EhscwY9G9ofchsivka1B5P4dxdlD
JaFUWIndVvR+zkasrsTq8cf1aDl7bcPZfhaGrQ7a3SL1mV4Qshjwh4ngXqR2
1jXAMnTLBZljZH4L3HO4lqMEZovj9JEMJgYSjJJ2K1ZjnXvq6hbyfsOsL85t
S2+DyOxZcxH3YQTJv3Y7E+qB9rDQdOXTBIjLROwN+xyMbNt9nrqZAMfwCU3H
p16Q6BU48NiG5JM140OuKRVRUn89ix6yQN+cn3MksRhWLx1LXeOZUNOybX7Z
0Qn1qf8yJhjDkBvopuRHtkAufluIvBABbe+q3rSNNOSLE3knGodwg1Mno2Z9
J7r49lsbVDPBsY1m33U/HQpLTz3h1SHxQRe30s17Com67muXTQjUKYdkxCk0
oOJ2G4VQYMLVLXvM2KgevM+cj5/pHwR/TEyRH2c/1u+MizPd1A/1llDtY/Jf
MS7pY+jzdwS7gxKKtTb2oKqG62v+xn78idTyZr5rwq9SoWn+oyyEdNdxq5P8
q6283MyhQ+LnD7+m+8YW8Lz4fVlXmA3R8hShS3u7cOFfaPdmoU4Uc70wusSq
xfyoMy8PmReoP1p5Cl/FYo6heW+SzK9TCXlCCx/aUP+gKcKLg/TTT5NLDEZz
cOW0dPmxWTLfjApk9O0vR8a29b1naWS+QsVWYvQ1LM/aXRP0JvO6pI/166gu
rEkxclnTw8A801VOfKoS6zzUU3Pvs5BFC8jY+7wVWVoJHn2kP199/IInUusl
HPhnym3J9aMGSXOtPVSIbjcgxIfIeaqXD0tw1iBkNMDvciYLy9rlnm5RacHc
gaH3og8INHOnRRs9qEGho14pg8znvtXJqZUiFQjF23cmhWQ+d1b7VU6n4WjO
7mu26QxQNtGTlPvvQp6r+/Nb0r9aZJXUPqp1QGGGX2ZH2wCc7OzHTPgrYHLJ
yaatioUpVtSmSxUUcLf5lu+PJzA+1ymucZjMM7xHynYfYuHDgqSS2o8eaNc+
1r7xbBiv1qZPqshmYm5saG9wNAHp/YXvR35UQYzrS328LxPMhXWijTQKzqar
C+qsI6BXd+126PEWcM/S6PFdbBAV77YWqObDR1D79yo2geAvS42Fqtthd+uh
nr45Ayud30z2CdehTGlKTIyPheQLQTOmQ3SIm9hWOOqPIrjght6RoXq8ku1i
chuzMCYULtAT04U84eFDXjdIHldES88Z9sDuffC/r+50aPavDa12zgdLLNDc
NJPMG8/nDrD4auHstpMSwmDg3uTyKzxafVjqWuF4fqwL0uEdnwRCerGEUNpf
MdeD27LfFzas74fcptUfA8k89zyl5iDf2S7Majal7Y8lz3e/UtDynzTIxT1f
Q5npQ3DdA5uN+xvRwJLo59Ik+6bRFVOtngaseKNquvwiC1yzI4wfVBqeXhVd
Kls3AJrfqteirl+gwamhxP2PCULO+XTYIAXyhZIiRb8IFD8L08uez8Me78tb
r/gSOHvmzsqT3TXIb+Z47PCMzBfZoVs9tjRCs0v8uhSd1DvdGxnmzT3IOqZi
Pz9P+k+/VQZFoAvfKYtZK626wbjptyVJloomi6b0hRkWLBcVW79l0GGjWjg8
LkD6B9eQQwRnPZzzW7oHvIfw57qKiJhmLabDXQc2TROIVbZcLXm8HWoPazzl
C1lIVwuRfmmaD650IcmpMFLvuqNSqt7TcFsnI8HRbQivq5qcFT48hucPN+0x
Us/Gn+tM8CyvAfdBDds9ZgwE9R2SLquKB3XPk6UUdQIXORPULzS0wDvUuMbF
hJwvoHdP9v0mJDc3q9037seJ1XsrJtM6sWZLO/1KKAOqXEJ2HmRedlqnt1v4
H9k31IbXJ/jVYdYwa5XnblK/qlt8Yy69QKN3p/tvkg+u61yXSJu+Q64/1SEl
gMxDx8dXv5Asgp/W8LbxFQS0ltPS98S0QsJ+EYayZJ4+P3to/Wc6YnM7TR10
WVAU+lXYztEMmwR/s5K3pP7eOvQ+euVHSHpynKJaEMjqPWT2en8vWhQTjW69
HUXCXBuvD+9n5A40QXUbgaPpR7wGRenwbt7qmkf618DDHR/4xT5hR6Sxy0YN
Uq8SZYboa+i46r74VC+ZgU/Nh755zTRD9D9G0mdSj6XjDw85tdbCumTNv7Zg
sl87yNs+6yvAbZ9Hdo/LyT4VYfIi0KEZUx/153bvJP1suPl97A4tyLFDqpRJ
P7vrpbdk7a1C7DYcu5dAIfXQn27kQX8NlYlXyVSSr1dbr+9a1fgFItlBRVd9
mCg2L1Z1lO9Cwde9IZIBI5h/Ly//eogKpaHFGzdfMKAzOqXpe7ETca+dTtQF
D+CPT59vFGcbhDw4g2myw/C76W72278Qf5XPRjdxEZAwuGB0zKUOWjtVi1Yt
MCAVrztXstCMSLn61Nf2ZN/bI3nu2gSJx31S929nMVCUf6iwb/w9Xmq3nvQg
/UYqj+86fTUVCkfEtp/oJv3QKj48I+k23MvW7aKR80leOq2+s5OGi3sLDGi/
v0I/TO6YXH8OEgqaLPTIvps8UqBo97APhoIb4jm2skBZyg42G+jBRF9BOKc8
ExZrn7uWHa0Ch5HLNslJsv9a8ghsPeOFsufxX56QfsvpWr4s+XstjJRr5HM2
ESgKuF747yp5HjlX19nxE+jdm7900KkKGh0hmmuNmMhPuCv1OqQbqoIREkQ4
Cw1XdjnHSpfj91gW/7kW8nzVbNN+utAxFPbhFOvSOHQeLO98/TkODo6dtb7k
PKLpMZ5TuhSEv0m9avqd/B5JzJPZGZDpu/afvhwBnbmlJ1MHypB73HJsRToT
U03zYgqna9F+k/nsngQLEjF5H5qKGtHxQnPikjoTE0fu+d/0rQfju98Oa3Ke
/wHW/Q4F
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81ekbvbZGIpGG7JKZIjslUx1JaWyRlFAIV6HMGL8RSipUN01mLFOJ
yZSdlLGMyr53yXVtl9y67vdljMaWpDQ0398f7+f9PH89y3nOOY/WidCDAaIM
BiONfv//3W8u3K+VYmOb6r21rr0EIfJ5TwY7XqLGRP07YacAglAdszpWKdZG
Ev/HvxKceaUb+uFYN2SzAwdj31JwWLZ4wVrqxF3zMNd9BQS+fbvuO17qw0QB
P1KxZwR3tePzNacqcFpyTsLHlEDN4WnbtOcfGDLfdMrSjaCh2rui04yH89oN
Yc77hUj6MmMzr6QAAYJQxmU1AkHpUf7FhAq0aKzuqr5CsC2N57gijQe5/IR7
gqsCxH05UcvXa4Tlr0VDNXQ9jDs2s2UXj8H/3Krn5t4EjPTa5GO8Sih9XD8V
GUngY/hP/M2BTpAaNdnfWASrKbvhT759aDLsMdupT2DjZ3JzNrARSvPxigHT
FB4IWh+wR/JQ8j1johEEVjffmHgGDiA9J1ZRS3QUKRYFk0uuVXD5/hFLzJag
biylOXNVHDbwL7zYSOdPZYUgbxsHXhqDFXnFQgwVt1jMcgahEvmiK6ePwrHC
heKdylyIKTcfEimhEGm8xlxXfQAm6NiedW0ElQPVjm0+9ThnrD/3dS2F/bEm
tpuul6FJ/Fft6f30fEzeb/05jAMnfoVUxTKB8STD2n/fME6fDS40chhBXW55
2JHCXlyZ/v3VdTcKcp/GBisVOUjVN5URy6DAyVfdaZD+HIIN1+dG6Xr+yZ3S
NPBsQsT2xEBHAYFSTJB7RXsHckLMf2pkE2wJSGjbIajDusT5AMYNgn/bhuRY
S724+mRDimgq3b9UykkZTjWqVepXHNYicG+qSI2o6gdLPXDTpQwhSg/oiCs8
bAI1sjXH4iKF7+okZPs92QhyKo2z0iPg6ImJHV1XBqn8l04rwwhOvxn+hiPo
wZfLT900uUJw2FmN6ZE9aL+4cUmPT9Cb/yTeIIiHDpGn24NPjEL5eWJs5FAD
WpXczt5fRzA86RTzOp0Lp3pT3bYFCnkHJn1s71fgaPGbI4do/Dn2MkOGSzVI
0lKytz5O8KxsT3ff61bIu3ln7x6hME7ePfY81YWwUe/TUX8TvDUxYPSG9OLT
Tq/6hiIKRfpbmNakC4Vby8pFT1OI4o/JnRTlgX2l1l+2YQyx7g5zN0STYRAY
3NxK7wPPfGw0VmQQW+p8V+43pWAT/sz11N56hA8kaY0NUYgJsHByS+FDUjFH
S3F2GDkBHSeNF7mwLLxGLRtT2PLIaIXknUasKKtQcnxMYJF2X07t6yqc3Tep
bE3jcQ5mcVt2dEL6VtpZ+dcEpfxU7rrIXkg/4CcrRRGYSf058VmzHa5eTZpt
cxQ+qz/kXSwfRJIsI/OGvQD+t/Y46rkMQMEjSi7WZRQ+JKhrOfk1Nty5ve+g
3DDuFY0zKN9aRHsav//gQ5CYvtfwtfMAshwVwiv8R3D1cwkj5mAXYjqvtexb
GAVD7WjmNu7vqH2q1y7uRVB2IsTqdns9Ypwk1qpUESgMrmYuyjcgJ7u98xtP
gjYzhRiZ/bmInyi10GAStL+2C7By58Dvve7p6nMUvGQdMkVr2rDX4mHa4ksC
bbtvzq0V6Ye4nemrGmshct4nb8i1GsCaTXIRSzRen9r29C9bs2FUXJ9wWpvA
2Wq3uNpMP2Q2G63fJTmGlFmpY9byjUg/vrFYYEIw83ExNq7sT5zr+Cq3kY43
2p4dWXrFxXtc/jZ9C4ERVSCprJ6H8Kinb0NpPQlS2+o4U8LBz94i0rbRtJ4J
+7SfMdlQupGxw2yUgvO0Rb+yUhekMgzWS/AoJLwtn73D7Ma66g8+36dQ2GMl
4vyJyYVha4vxyjghLl1VtT8VNIAT/Mlod+EY7uGEdOaZh7Dscfpr3I/O73F4
vWV3BaS0psyq6Pzj9vrmYQs0n1SZi8HNFMIKy+cP1PXiF6XB6Y4lgqj4kGfs
0l5cW613vGOCwPW5m3X2DR6ORmydZY4L4J5UOlkQ2o9diweIqIMQMyqrnWJG
2tHySzw74wLBmq29E0aX6mF9np2vEEpQJOJOtm/rAyNNTkM6YBR+se/bvZ25
6N7lvmHlIyGkNzN3GARWoUXnT+klen7KsgvlOn9xcepVodHDaCGqHkdKjPT1
Y/wfX8uATCEuC1bt6S7tx5Pg9Cx7RwIT9RjVggSar9qHd9sME4T/dmGo7Ks6
9AQ/vPtenEA1a3pbFbcPcwK1Kt9ymn8cjcp3Z7swfsWlNVCWguDIYOEFkUA8
4Oi8Y9F8W+5S8qpta4Jj8ueRVkKhrdnRQi27GcKa818xpyj0h3M325oOoDmq
YcZvaAzjEdd1RJdeQPSZzfwh2q8SFQP+Djdi47c1Mnte0XqWtk9ix+fbDfgx
Py4jjdZf5xn3t2deN6KamXiy9B5BuUbw1x/FB/DqhNKVSBUh/hYmB/SqdIOj
2m9HLQpRtzn4eIxUC6zWXdMKTCJIKuVqJuc9R8/Srsxc2t/e1d4SVIw2QdtW
bKdZDcFQ6mXdOdt6xBcuZaq3Euww/ImZ80c77ux9xP/gQXCw1VIkN7APjm3W
iV5lQiTYvTnsrvIS13Lzi1dbEXi4lB6xM+UhLH882yaP7sc1llU6WYlhBzeW
gwrNN05Xj7Z9I2IvJ3xxpJKAVRkQOOTxEqv4VQeX/Wg//sHu2JnGeig0zeu4
nyTw/0OMVfKmG75ylmtSZkcxo1m0AT/cQmxQ74WPvgTyYd1DPT69yPn27uKi
C+2/U/ZNYhaFCLfY7q1Fx3He/4tIfsxGiT2/MiqXghYlkV30+SX02Q2l+ldG
0PCFjIjfeg5YzJWOxW+F0B8tiuGJ8HCoK1JyyIhCmaSHtN7NXuia365To++D
t8NxIWy7PjiESx5Oz6Kwz/LeeZWdTbCedPEbiaDAjZJciuW8wPxEm8RfEgQt
Yrv4w97dmEtt9XBypui75kD0v8x+CHMXMty+oDAhriijPNOIQpvoxn7aj0J0
A/ca1g3C9fDxLA16X9ZED9/vaK+Dmbzpu/lqgh+TM7S+9eZBIal+d/nPI5ga
LLPISG3GVpZQJHzVKP4D97u3Xg==
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns4lVkbxjdJKEYqFbumCVEoSRHlzqGDJlFEKJXDMCVntSPHUWKcohw3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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 61->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lWkYxm011FFMKdek6BqJyohR0cRdkRAaW5SlrEnUJSdCGZFk1CGi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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k0lG8bRiq0U0IyQpYWaSHZLkpRSRtJhLJWiuxLfimKUsjShmiTtEll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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx1GMZJv0a+o30mKJpjBJMeGDq7GNkahUZAsNFSOkooSkVEjJ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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk81dkfxi+qMZiuyjKNtWtncJWaRD2KFjRNUdYShaSshZSGkqVF1lEa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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 62->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk4l1kbx0mL0spMISFpRslQtqamvr1SUm9NE0oSoSwhFRJR1myFV4oQ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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3lUTP8bx6cURSWESrtKtoQKRW9fpbJEQiIiKgkVrUIppCit2qWVSki7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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs4lHkfxiVtbXYdCgk5bsWojUptOtxDpOMrsm+SxDCRHHIoppPD2nSg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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk81Wkbxq2VHAajUpG2QaWslVd0SaV4hZlBx0yWotDIWMqWKLTYKoRw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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 63->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8VekfvkwmaaSFfhGRMBVCSfUz03Onacotk6UFyb5VKJRlRJk7UqZs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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3kgVPsbxlXKUolQUtaIulGpROiR1K1IlGS7luIqKSFRIpUlUslSrqUk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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx6Ui/ZiRuU2y9IsUJqSaipIPcyMqS0VlyRIaZKsQhZT1RpYS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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns4lOkbx0eknxKrZVOkpoMGhRSbki/KZLVKyJlIpGWZNkqFRESpVESI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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 64->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs8VGkYVtlINbl0p6VSCimSW/JMQ1LJlhWK1UQi1aQV2Q3N1LRdlrJl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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k8lGsfJtVRVJJsqeioJJVkS+pSSYiUCnWENjqhJIQWJHEQEiVRyJYi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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlns4VOsfxadEJacQIirddCJ3RaGlklN0SqiQ4gjlUBLhoCJJRYxLfkju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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns41GkbVlsU1W6bRW19kcMqtpZSkrqVdiSnRbUSVlIrh8TnHJFQyaFo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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 65->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs8lVkUlYmK0CAVmpAKIzMiw5SW52SkGHM9kpCSZ26KEgmhpJC6Sk93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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3lYDe8bxonSJi0qSyiUhEpoE3clSSlJiSRRkaSFRPuCZEuSQn1Ji9Im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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlns4lOkbx4cQItr6SaJyKJLNioqir7WtQwfH6KhEOsiZxUSS4pqVM2lE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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk41dkfRjcVKluijKVFJq2URslLm1Jkm6RQyDIl1dXYB2NU0gyRiV+W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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 66->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVms4lVkbppG4apoUSiSlKUkGSWnoptTgKx0IY4hkoxw2KpWMTyIyziEh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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VPsbx2VLUihlSXaRCFkqLZ8SoshS1oSEJJeSSgu3LJUSKqKobKmk
QoiUfV+HsYx9zJyZsYW6XeFGv/P76/xxXud8n++zvJ/PR97d38aTm4uLy2UZ
F9f/n2MWD4Z5jTsR6N98pt6ADSnNeULYvhuzxp4Vj74yoEI8Oce6PIin6uNc
CcN9oLfNmg1R3oD2UDNr8iQBrpiypPfr8yCFQbPSvwlEqnB7WFj3oXhVnfaU
NIEjsbunfyZRwTAYLO9NZKKz72/tgo3dCC5r4a3ey4bDTf7tjwu6kDXuYb2R
qxf03z3a6WujwUiacXliR+Cczgu1qIF8CDmZnhtxJUDRXVofbl2AgMTepQY/
8v2HrvxN3yphVDWkeeApC+cW/eO5b75Bf6GPfMhxAkG7yy/XXatD1OGC6d4v
TFTbDR6I7KLC3yTka+o9JgLT9owUZXSBnfAiZfwQgZSPVR4eAzXY3sgLx99M
eB+LtKI2l8P21vvYsBcE6usPqNBkcxGydaQ2NpFAzk79mV+GJZBVCkgpsyYQ
e8NOXH9fFuLrM/3k9Qg4d6huGjhdCf3FFu+on0yo5rIqQo1qQPCd+ZWjysD7
pYO6nlL5GA84YbXOkcBP5saik2dTUHpt3MDHn0B139bNDpEFkLzvujPtIIFA
lYMPjqaVYnFzxGyULwtRATnP51d1w8f60n6WCAelfnkuyiptEKs8DZFSJn7+
5XZgvVwOQihcR/iukfW6JxbIuP0XOnOSNqa6EPjRUzvM3UlDhuXKz3liLHzh
PV9os6wbI5qWSdqDw5g/Kl3rPdmI2dzLhBSVgUTlwcc/JLogOly6ZzqfgZmG
4eQUrgK43w2dEnlGQOEE3+a1p1tx6qb9PrcUDkbvry8O7KzDyvPaXRHPGdC1
exJQVNmB7iVrk/A0BrQYYWEthwuRVntg5PF+AgMfHd9ms6hwOKBwdhX5vdXE
WS/zN61gZA5wYlZwIKIcfbTX6AtY9o7CFZEEDKcl3yu6dGHH40vio8pDEAsx
3bRubzaEI/bqRZH9Epubr0Abp+F3It/UilYW5MrTwy5dbkC2osOrgn4CMTn9
VVUzTXgfc3lKo4+Ba1tfrIv3GsD4uRs8UhdHYUSXvaPFP4w5jvP+mJvD8E65
KPn8QA9mzRTLZAo4oNDa3VuC03GK90y56F8EMto6R9Xcq2C1Pshs0IqJIKZf
yWBeD0wXdqe3Ko1D7oymnvZJChg23K3/abJBN/LqGxGMh5dg6ctjx8h4nZbX
6j/rxg1OYPyjTAL56Y03KyI74SE2HlBfR8co0Vs0Lj+IaPly8YLCMdxICm2u
au2G3L8r9HeEjcLrmN7CwfB2zG76jIYUAsfqxoQr2tJhKzkpbq1JYPzwvDP2
UrF8hY31uXw2+IOuLjPKq8WMXAARYUmgY96bMB7rxgfZO481hwhM0Xr3slo6
IB2Sst+xgQUKR9/6RUA7FBZd5gKuk/1aRgmI9S6BweeKzb48BHyzUpVU3D7i
0Otf8oW7CCzQhOabbtHw00jz1htpNkJuSf43Lk3By+CF2L4wFoRfs3/zSPWA
Lve7TUaXCUMFf8mZiS5Uh2h7Xekm59NCVz00nIqt7WEVivocmEa6/Rb2rIGR
ANfGVx8ZELnjMz2n/B5iB6tYPr7kvFf4pttXNEL13yu0pzkscBkZEbJhznCi
uqQZkP2w+nn9e5OuSnRmP+Z+J0PA5fpVLQcyHyHjG4TerCaQHaLSRXldA7Ww
l5TkOAK/wyifj21sg+ZKm5Pihix8OFn1Z+bYAMptRrXN+cn89tgYmJj0I/mO
Xn7vCA2xf5+QE3jajX+2x7xcujuCogfxXKd2VeI69d9nQvIsGKQYDDDvUlFI
K5v6sIaN+kd3mq1ZtUiq0ec7ncDCzMxz73CFd/BRMC+vDiDn/R6FeWoLDX0L
9lmG61loPWKxZ2TpK1wqEoI4jwnQTK6oDM32gLaHx8Wtjrzvy+UftryyACyv
9quT981SjpH4tCIPM90ru6y2EhDYGM+nbVePbvtOmTPFTOy7naHO25KLbSPO
niFnCchJmrpWvIuGk0lrzDaSR256izfV60rgPBfIazBG5qs14XflMHnex7Ad
bHMOZoc7T/Q4fMWQ5KXZUjMC3LbtSZJvKXDf3u/6oY0NY6064TMf27Hq32Bj
V80RyHnqLgbPd8CE87q+V5FAuPA6LeZUJ+hTWn2vyXncLRh3pWa6EwaN9Tql
q1mgRuWbytv34V5ZtPw1I7I+y3lXrm7tw5fEH7/1/cYx2dT0IJy/Ej3dQ56f
9pF8TudR0hjpw/6dT3gPxHCwLb/WLY3ZgK9DCekTR5iwMnp1YVC2B5atuyxp
68j5/cdxetlSBfw2nlVwbGFCy/Kaogp/CtQGJIQUfAhQc/uzV473I6ZeIvXX
GxZso9a+XaVMhbfuG1HOXg54DBzFuAPacGeNzZMZORbcdF+uu96TgYQyTQ6X
IYGNmQLnf4tSoX7by2rxBxu6Dj/Xcp+vAkv6jl9jNhOjM1+3Di51wEY1RMB6
GwfufKv88vT68XztoQieU2MoD2my1RRqgV2Rrl13FQN101n7Faw7IHzi5/aJ
iyQ/epYy733qxdDbpCf6OWyEFuGQ6p5mDCRXSzdEELDxL54aVB7AQugutYDy
AVTqSZZ5ufbBUGWW6A9nwOrc38Pxw9kQW37C9jU3AXcng8KNtRREKR9MkU/g
YOurYN70xR4sVxaJCohnw9yg0n1i+SAydDixxeoc0AN9hns0n+HdC4v2yCME
tue8VLziXIQnERvCwn8xcenVgFZp0QDSLiXPJWdzEBv7SaFAoxpuviZVRaQe
ELuRHD17oRkIzQ/++J6JnON6j00dirFVbfeJcUmShyJpvmojrVBYsTWlcJAA
3coxyHK8F4luX9cmKrKQ899kN39/MiS/MFqvkvyq9t2iXubdCEHj1cylKRbm
irTzCHod7Lv6pEs8CJh7KJhpZb3Ej3NRm1tOEFjj4Z4pZECBrjGzoYNFxjs3
c/9FBBXfrlj5WIyy0ZGtN28e1o7sNQX3kraw4ftwv5TMmhYY3V8mdX2JgcBM
D5f6qj44KPLZaMmPgcI94Nh64SMMw+41O70k+dEZ+1xtuB0Mww8abhbDuKNx
i+FM6ofPGYvt2vYErv4SPbkUVwAF/qU5yw9kvyzs0/os0wPrQu6Eb+T3A4ui
bXxXqLhserhrlJ8Ov6FYrZ5zfahSFZDQXaBj9+nSLp/L1QisDV1zVJwFUZWY
wFutXai3kgoaYtKh+x/1rmjAEF56P12hlMlCSmOWjoTle4zfnq1670xAhGm8
5CUZR3IyfTKe3F+rOTOrLjtUo22Dl627MoFik8+vHds7waYGF5T+YSBl/bjM
IXYj4obYAROnmZDc8tApY64Dl8YNB+zJfV7el6M3lfkFKt9vn/Y4SuCGnlJH
9YMoaDemP1ch881Ft/6crtWCR+UujbF3Ceh6XuF6f6EAZbuTfyyQ9Yna3B66
Z6ITH/S1vDLZBOZrNqi5CHUhdYtpaYkmE4Q03VJTiILrsyuoQjdGsTOXU3uQ
jI974Oex5DMsbIozXu1WQAHrojTzGJMBjxEzuaFRGvzLv58qWcVCx2hTapda
KdZc/teB3s9E4w9pyvF33cjgUzNwIThQWmv/1i6ChiyFpPIvL8bRtfRK7fHq
NsTO79Dpo5K8lX+msflRHaRk65yLPVlwoIWJRLk346ElV/9beSYo9Z2SUxPV
UHplffijHRP0yA8mSifDcT2rbvW4G4F9K2OuhUu9gXPnnp+rSN5Wi3bV3LhW
j42CNulmf0g++qgfMUqqhKDBeQv6FSaMubxTi0h94/7XfaW9jEG4mYmuqajO
RqJ3wD9LDgQmDT9vfVFFA+WEpItHEQdBQ3LDnnY1SKu/bPzlKAtTo0dqhH72
I2DU2kNiJwEx7k23lRxp0DFfleehyIFH21m/xncdmGvPGUqIG4Fp6pXvYgrV
GGhbFx5lxMIP1R4BnWudeDRp8W/euVGIfOl1czlKw9zxR/Jn1Jngso1ppA66
QsRHVJyf3DcShbZCfpdbIBhnKqtbSPJWvr7MNq0YG60lVhXpE2g1MtH2fFGD
SVXX1bmqBLyST2TRqjtgvSvg/RcJFnSl7znFh3biknl8hCudDcbKqMDuUCro
3CUPVA3HMMp5OWuo2Y1GqwjWIh+H1ItHL3xTbccR12ivlKRRmIrmhx/T/oQH
8aNyBRNMZA1dHru+qg02bz4p3CL1n1CPYU1iWxcuDt+U+PqKDcKkQOVEUzlU
LPioLnJMxPXsPh5Gb0LcxPr5pYNMiNDtDCfCmuE0OjYsTvqHx59TTDZLfMbT
lrcnXi8wYZ4j+HzLN5KPZVPH39+n4+GWu4qRzt34vSLafp8mmb9bCgekNgzg
l+WmkofkfpGQPe4kggLsXtvql076jWMF6pdeG37Cc37ti4kkD0yf1Jf2prfh
75u2Td6mLBQubjU3pQ0g6aCy4twNNijZZYm/reuw4BX672lSb99JzdQ7YlCO
xqpNedPO5D4J1t6mxymEX7g3Tx6ppyW0ntbLLZXhzraqqadtBExcThETa6hw
a7htE0AfBdfXoD+2tXcwm0LjFiD9nNWrAUPDhXQ4xO04pxdE+pvuwRzHw1nQ
yrt9+lcSOc91wVs2XCqDgKPRuhvk/NzJa3d/6dUB90+mBt9ejEDsw73StV3d
oLEMDBVvEOBPuLZvE18HvLJnY/7UcHAjaHDnUDgFiQ3EXDdYcGm2WP6XaQ8O
f8zts5khIKVzNkTDYgBrtWoO8PX2wHzgqtzRR014nrLSR4Osz+9mx/CMhCpY
19QyjpL80fU/bbX4OhebfDuMTUdJfXCdWHNo4SXG3Pf847OdvE+ZKY9wSztu
rTytMR88CrexnT/up9LweMepNpUBDpx1wnuKP1Rhn7mOuBDpNw89+C5/xaSP
5KA+f+8aOh4Ltk42faAgRUbQbN1VUj8fGbtSfqUDOuNyvy9HMPGjtmv+4REa
LjU2uF27w8bIQa2ro9adSDl8+mLXIhs/zKXfeN6lgVioni8j95VSp5NhdUMV
Ms/si1AjeUSPN674ryQfEj/jfnpKEehev2Sy9WM1xExiJQTJeihGhXxa86wS
y53/WmVI+je1G4Vc7AsDcLo9+eRnLgcCj1qrxR3b4b+xSY4g9TWXoN4mp+lK
6NbsPxAxR/qb1K+h4d9bwVupGBagPILk4SMZK+wLcSnSZ8f4W5JHrZn1kdRK
zNSMTGpZk/1cLPx48VInVkqdSruYQMeNqbWPdkb7YUg5emmE9IsyF2/v2qRR
ge++ti56pJ4K1N9+0Su4CeGndY7IDtFhlCpeISJOg59455YH8eS+Nl3/7NHy
PNidqh3bT/KBwbARd1frhoDSBZXbAgRqexqkCJ9OFPsebFYqGsVMvf4fHp9c
nPMN1eQm71uamdhI+9AOIfXj3f7ppL9/tjPNjqyHoFuhmgdZj6eZ1zZrhNOQ
c6pRkd3IgUvGmLovYwj+i9YsqWsMjBpve82+EAdXSpEGYUFgx5zphZv0HPir
MUSVyPPp39LVrQq6sPLEku42XQbExAU0vc8NoM5n3u5wIukvqo50jxc0INf9
rM1bHxashDKUC31bsc9mi++W4RHQrgU/cw2iYKz3Z9SrQSYWXaOYe21roCXU
dmfhAQtaGRvyg57Vw/vEsGvuBiaO8P5DWz1QDj+vuPzMh6RedS2QmX7QAd9t
33W9/Mcgdz1gOd/lIjxfbxawO5/AR7Gn02aKFKhz/06WUGFClQjPsvT6jMj+
N6v8mkl+SD1d3spdC5N1XbL4RfpxafmHjLd1aOqwcmsaIs/jGl8hKUIFrVUz
j2VN8l10KvfpSBW6D3/XsHUi98fHDD5FnzLQ9fRks54QUKVxR2cn1eJQXN4j
DVkmEvOc6+gBufAb+VO/eIdASbPNIcPiXphNODeG5U0gyzAlrMupET8a5Jlp
dFJPSmjEf72dguKLfrZ+pH/RaY+0k6T3IFyVLT+uRfKGpiSWc/0z5vYl70km
9ea2X8c9m5bRYHxUWFBYgoH1xxritWe6cVJL/0DIFwLOTrK6ArwU5N0J6qBU
kfw7dDU6uDsNNuV3LdJIfZ5vWXc4m94LwSDi6JO7/dBRoU7kXe/HXECHbVw1
G5X6q0vKzCpgqZHckNdH9rvwsq6OB3XQHV80j3dmgRjrcJvwboWMW6nl/JcR
OBxkZlqtIPV9WqT3ZhlSPwizdy3TJvVfyu2vov+OoHqP1Ju96VVY1u686ZE7
yd/4UKXY4H7k/z2Quc1+Eq5rn1FTP9XiU3xh61ayfjLE0Vd8js1Q3pS34//9
qHpmdWL+UivmqDu65L+NgGtcxGfBs4nUi5L2GRvJ+A4Xquy+W4TVi+cPJrGZ
eN8UyEOU1KMvOnvLKKk/6qc/7ou2rwO/motxoRMT3M3qvjU2/Sika9uq3WBA
QkHEwPpMBSrNs89L8LNwXSOA+m5DKSK/2nx4+YPUJwL0HY/3PIBggMHeDccJ
zFjtKnEj/T6zaHRlV+sgcnJao8e29oE3MkLl3TQZz00xnS8r6tFm8HePdDwD
WmHSr0b+akWq8LNUh//IeWlTaZ7e3492xfzvpVQWovOSSzp72xAqc1n8wST5
f0+3n7KCZL1vbY7gJJB6Z9kZnogkCjqOr90wv8gA5aJ7jA03BYTySe16FxYC
98sO7rYsQVWGE88yUv/Rlx+q35lbgmIrHfnGXrKf99/OMaurhMi1gFwPkm8O
r+vtelLL4VKgYMLDx0LngYud/rEN6LH1e/suncAcM9F5cMVX8PWosf1PsRB0
SXTpwPwXmLF+uewgeaY0mSJQ19EKtU/bbpwj/fXMm/sveLi74XXvj8gO0p+q
BtKH7s4VQOaFp+fyUCayY88rpfuWgEvIJiM4hkBT/Edt25B+zG7Irr0/O4rJ
JH/DxONUGD7+k1ApRu4b7+kDrw8k45I8c/8qkuc/Nw9ROHG18LBqkl2TSmD5
84BF+ax6xD60YM7cI9DLy3ta+mYPpA1GeWJkxsD/NfN9SxkVZjxTay84j0Dk
kZyIeFA6WsyLxfaR8ddM21Vsu9IFoUR2wjcuOq7f22I7T8+F3I91Rx+R++x/
9IwJsg==
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs4lOkbxx1ap02bUi2SqSZJJ5cstuIrOa3QOFTIryQ2pNZSRlGNoqO1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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs41GkbdvhEK6m2dWiJTg4RQ6lVttsxFaNZVGwqlLTZZQqpsGnWKaUs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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 67->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekbPkgkqqMsadIoql+YqcbWolu2IhWSUmMrsmslihwpRVlDhelK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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk8VO8fxSmKylKJQpaSKEUokpwWCqWUSJG9skSIUBGKKFkqIipKSEJI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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81dkbln3XNC2mUSQhlNapRI8ihEoxjS1ZyoQGFUYhLUYSEqUrS7ay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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41OsbxqeTLb8iSYt0rqFOyRayJdzT5pyUpcjSIiFZIg3ScRqkhJIk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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 68->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlndUVNcaxccgCEgMQQhFfdhQsADR5GkQ2BgER4lG8ixEiNKUFpQWukqI
CGIblCIBKQEUkDLiIEVAGeoIDMOMkGGk6rkEpchDxQJIjn/cdddd965zvm9/
v73PXeF88qdjn7FYrER6fbo/KNk1u+1qDVQ2L75q8ytBsm13dc5vXbi9pV+e
vYyBcX5Pz5A1Dw4r/FU2uREo/e/rP0fW1KJFMNf4hx8B19JIWmBfhF7juQNe
LgS5TPyXguECjJ/9tTbOmWAg6aXPkVQJMrJG9JIYgm+ep/pHrmvC7pt2Arto
+t7GWkE6nAGWULTH2pHAu+o923NQhO/dJ7aEVhFMvLFZ57OJD1fDxw59gQT7
jvebLS3LxuYzHG1tJwJXXXO1PiEPKeW3Ds0/ThCuH2Ouqd+F+MORm0yMGVhs
/yvg5rPzEG1rtLY/SlB5rvgL4tmD1wXnc6aaGZS39FnlF3fiMwF7zeY1DDrn
1tvGuDfjg8vJpOmztN/TjSqLu/7GI6740il/BiLR9XHl766DvdNv6RO63jiM
R1rTRTg3tSHMQUDAuuB3vPBNPnpi3i6Jof1vTffK6aisQ37hVq1tMQTSwkPy
XfL1+GoXbxf3NMHesFsrK8T1UJ7h7A6hz6oNG9NryoqwoEadbUH1dE+WxgtN
7iB8//irbFeqh4WiNM5ABuHeQHZeHoPW1rsqPpFN0E9K/ikhjsDR4wKT6s7B
DqPnh0Jpfe5G6584CcRInHDUVGgiUDjCTvzR4AnsPF8tZRkwiHf64mO8Hh+X
8xeZuwYRnDWaZxST3wre3qmFr5MIfOTHq4tui5DF2dhUXEqQ5W0rOcLvxMD5
sKWJLbSeOwbS01bteDSXxZ3LJkgb1rrPSSlBhYf2U3U6jyPCIcOQUD6+CTeR
Vw0h6LJXvfNtQBOOa/z+bIJDkMGarReLhGAvP5suySRoZjvFue68hX2HEltk
dL58A79cZsETsKL/8GsoYMBbrlXyOKoeG1SDLq44R/tdmKcset8Itawyl+OU
pwicPH6xoRvPNYzsfvsvA44vR2f1eDvuqg/Kv6fr7ws2StvKdKIKLqt3Ux5b
7U4taXUUQ3tdX8vHQgJ/namyIarnIvnyJt8LBDWtSrFTrH74JJ9/cOM2Awft
6XFb/wo4Z2oM5XgQ5J2KsTOXPEHw++t3nHwYyInWRE4Ed+OfJqVq/mEGHaVe
ug3vJDioXfp1H+UrgCsZEVm2gfVRf6/KXwRs4U/aYe656D94bS6d9pu0QcVy
QLkbRdk7TP+IYFBXWXfbd4EMFRaD4Tb2DC5rv59xHevA04xpYxNav/6H9eFp
J0RwSZgeX5ZL+ws9ZFVX34HXk7GS4HYCk7W7owuLxHj2i8mfM/RZLkdN1mv+
GIFjkx7eKgwc3+onXDO6gOYC7sAxysvAjHf9fc9+WBz84bNgvSGYqr3ROaDY
hvjveDp2NwgeOqe3aC1IRJKK/lA9/X67Z6iacuZjqA4/iEkapf5X0DjjUd0L
48MVbyarGBSMsFqaNaTQ0c5W9JgmeHzFW3RdS4bxkEdHqq0YZHzrp+vjVorK
ZV2d1pQXH0OvigeC++A9SVm7+gRBUK5pkLqiDK9v7RXnmTE4Nvht7MZYKdaF
Hx2bM2VwSrWmJ+SeAOVF5mrWlL9LYR6XUuwfI+PwOpInI5BtX+wTEZ8Ds1Re
Sz3NF5FfcbI7l48D5JDyO8r7Q7ncY2kNIoieZknZtQTnfdz+Y9pZBlmC8Ocw
T4JFcikBTl73kFpaIRdI563QdOJK25l+LIqa7yybofV7X0tJL6mEpke0KN2L
QDH1F1nahmZ0do9u30T9/tp8Icee5pl84SOrozUEhkYGgskOLi53Rhj+Tv0c
E2XtNZvVgNsjAT/4hxIEO62cb3eiAXe7jtlX0/yZ2BMQeHXP34hs+Whmv5pB
7savVxS/a4TKszc7Fajf34R89PqORfkdNJkclVJ9DzxQC7rVhMCktYl91L8X
PXUqZmNl0FJSL7PRoPOeHbeeExTj3kr/9Rl0/3p+hV9yUzs2xStaZVL+Yy7v
dNgYVYbJ3nD9T3m6vG1pxC83OFAUOjWEfeKDdY7Zp5oD87uRi5dQXltX1ZTw
zcvB25N4T+hO4HZKp87LVooUTW2jMTrfWpdkk7MfxCCS8nQe5U0tetK3wVaM
K904+c9Dgqh3N20kLlJszVPJb/Wkfr0RnfG0pgkv07zO6EUQcDITeDv0etAQ
nqzSsJfBQPTg9nn+XChfceXepPkqy1bzEBs+RLn0ra+6D63HTVtr6qAQz4Im
3r7KofkbrrFcz6gRM6jVDYqieSO/w0OqmYFihyDNdZQHz+b5S2ZbenE61jBs
VTed54zePf3pQnAvH3DTovk7otXNEiV0o/aU0nqSzyAtzHN41wcpJs0GpT9s
Z6B48aSJqKca/cWG3m4nqf/kDivPPmzCx4QBhed0P873ywP7xuqw6mxJSh/N
d0XnV7XNd/kIXIIXBWFUb1/lYLd7dZjfO6RzNZieJ/ZPA9KK+LC+YSVnEU55
KedNrSoV49JGV+lRIc0H37EKR4O/8Wt29ozYg0FcRqEtz6AdGmoLnwrTCA4O
hhYW2/fi/wELsxxfMDBVsPxyc2QX1AaumzrKMdjf5mygayxBs4mx08g/BJGf
O2saxInR93bYRdZPYNxWHM6p4WPt/XNbzOj++9IuyLZZVsKJdL9fQPlf2R5n
S3QkuD50v8SB+r1BtSvCpVCErmWCm/XVNH+dXql23hdhtvju/sRUgqpp2/mj
xu0waU0jTdeo/vNSv5JjPwRRuxab4E/P48+3hhgf5uPYnayBKarH/pxrc5nO
VRiNuuIv703/F3wzo5VeVKFmXsH672keRGi+/DmbHwCLhNWhWyiPAaM8yz1L
OlB9vm31wmYCc3OxaEdpB/KS17S/7CWAvJ4wTEGE/THhxZmUt7Sx0XRiIwJf
SaD7xS2C4TWyeb3e7RCt/b3RLJlgJlGaJbZsxSLdMS5TTJBwSYctdZQgiy9Q
qaTne8xigUWRYTsmhySeQzQPHRImTu+xl8LiBdQVFRiwuLPiDT+2QlSoK5FR
//0L8dfTCw==
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VO0bHkpRQpItS19JtoREhFuoT5LwaZOyJEVZU6lUiiQlS0pJUrIk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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk4lekfxlFTZJ1CRnRkSVJCDSV1V5YylpAGcWKMGpW1EOnXESrbtJCt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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk41WkbxxVFaLKcohqkGVLqoIak5UuT8lIke+RV9l2qkZKRpcU+jYli
jKVOp2OZHPsSyXLI4ZwT2atzzu+nepGlcEXLzO/947me6/7juZ77/t6f73M/
mmdCT3gvl5CQuE2t/+8xCtzkMrkGWC49NrnVR8D3c+xfE9uHIZbW6eyxE8Er
WrJxNb0bC9U5ZjpzYliMLvn/Ol6I9AjGL0wPEhIpuOo08gzVes4bjmQTiLKO
aJy1b4F8eICvejUBodFAn8r5B8jyC3CetCYx433Krb+1G2ZP6iKWhsTQ31c0
L/2RjaecwLiaPSRYBzL3Fu7mI3RHdd0mKh/Z2z4VTTUDkD96d5vZNTEC3tn3
tPmXYb/q04KWSyR0dg3YsunlsI6uhkYUiUc19dMugRyIXCK5CeVihNkGe+52
vYuW99kX45xI7HmzQ3rf3qcol7fztUgjURQz0lvpVoEBRyG9hKqnjGnBalXk
YbVBm7rMHIGGIwz18l4umDunHB58I/Du16ZV/515hgq2H4fmTsDiXMbg4++7
ITOx1er8TQJBIoUtjzz4WL9cNJ3rR4B5h6D5j7Vjw8ljZLoRgdTxyKjdUiPQ
jfqBlZosxr21PLv5sQG8C3ZtdTZ/DX7eNqNcnwowc0MV94eQMAz8otac3ICA
oNXBM1tIKKlYC/awh8B33Z8dyBNCwZ83bKM5ANZbp2jObTHu1j7ysVrRj2l3
SZsyFTEUjCSti8+VIMu7I7PJgoSqdlBsCpMBZxfFyxoXSBRsnriw2qsHWbQd
1jn5BNqLGbFfRvlQd/9AHjwnRkV9UsoyQTcqj4hLT9wVYzaz9Ozgx36oF0rZ
rZElcFLrxDpm/HM4OihLiyj9qxR0t7tO8FHkmqFGsyXRoTXg4yjVgf4F80vG
ngT0v64dO7XvPqp2GleMU/m4ljalh7lxsOCbv1d2loQw33K3J68dP+XNsP6z
l4q52oI/XDJx6oJ36nGqP5Nnf6Y/fjGKGcPYi/4FQsS42mefk72G+D86U01P
U/fVnKmfBhddhcORnFIxpmhWq/VUBMgzWb4vqYDS/77ln+8DuJiQ8o2ZTqX6
91M+c+fmDmhPV47oGxPIXfMqrcybD7tkC0ZNIwkPiymyuuAh5qZWz9OtSNBy
rhnYxLfCr4e389Usgc2N80MDcwK8W1wVVfGRwHvPoQPX5gYxqNlix3sjwpNK
8Yk0iUxc6Kq1P0jxR0uiMbaSPFzVXVIdukzAlCWzlCTHgrtmalbNSRKpcqf7
rIJ6UBfT7MpdQeBLEJni7vESKzzUvyXMj8Jtn827Z9ECyOd+Nhs5RvlrT4qa
li4bbw0001wovSWL8pU96QJcCd4YcTyYQA7Ds065gosDAVZd9zcQ+HS9deXv
Y3XQmK4NLWoi0Lqge1m5YwjE9dD9H9dQfrT48Z8tYZUI4HzKNnWh9N+ZtG3j
g3b8UaJNU+8noNC811RHpg+BWr6JvGYR7hsde6yS2Y6Qo3QHG8pPphXsr3SK
N0e5RObyoyRkvo5GOup1IWwrnfP2IoFDOea/1On14k2pdqJENgn1M3na4w7P
8UJJoUW6muLVfpeGkxof8UX1bGkXApy0awo2Cf049PDP6S2HhFCVis0e0W7D
py7bi148AqOdtNJFfj8+aCdpfbQlsO+95Nh89HOw267GKcSKMXy2+EBLdDne
9pWrNR4hsfAwW/WoyhD047SKq8pFKPbIL3ha2of9W7JOnZQXYnNuO1PraTXS
a3ukjPVI0AMnO79JD2L8Ox0jjj6BQY/Ww4wnXDRcng2i/UbAryiSt+zHMoSL
gzWlPSk/7dllOCcaBG2y+YLPPSH0vRrf7UzjQUL/TKm+A/U+uHrkEz2toJXn
TnTIECD9DTivPThYrq3zqeUGVe+theuyLhXQWXNanGNMQi487qteUAXsnY47
pdlQ/j+8GH9vxwsomsimhfsSYOtEXfM4/BI3A1P0M+JeQ2Yxa7tBWTMkF5f3
phtQ+n/T2PtPbA06Ta5nsh1IWJbXqh27wkfe9TZ39xgC3/zzeJKBg7jcaxrs
tU4Iev5c8KapNkxMOK3iVpJQUfIyftzVj+GNIWljbWJs8jfSHq+6iyveot1v
KZ5lNAYPqQYNocgxLWlQnspv5brIbopv4dGL9hk0EiG/GGxT0myGdVJy1O+K
JPRjtZfZ1jfi0vD0Z68aAvcbde9WLY7A+AfnZPaAEPyvkDSMYCP87eYeZ3cS
/CV/xpuCJzigSISWswg8uaNZFaEowKdaG5rUpBC/37w08oPec5Rumhy9mkbx
He6hZClTBu7LR3/LmpKYy+GZ6bdx8F51XVdxM+X/lfcUJQV86r2U4+yn+NbR
6NiTYN8Dp7bfpjufEZg57sBqa2rBEcG6eE9qXk0kLgj/iuPDpPgBK5TKX/27
wj6/7BcImWLMfpkVQWLVZ1pw2B2MZMxObKT0jZRbezjkyyA6V2Tb/NNA4Ibi
icdqSWycUKbH+mqT+HBzyVx31QvE+HSNO66nzqdp/n1xUzOsVJUt4qVINCze
WYiW6UXGr929cwpiGJvNGkb+3AzDpoyA/7VS9QdfN0kpKgEvYmZ9KJ2Eybpa
86tEHyQMyH5JcxFCfLbHyG8YRsz4jMJYuxiltzRYuz4NYm3CSLX9KhFuxVod
s85/CkaDZfjD2yTczF8mFnYKYK8fllZ2mppvNwTpnQcF8KF/f9T+IOWv5hZS
d6Abv0ksuyxBiiG2UWv4GsKnOGXzNA3FOF6YSK9X7aP687L3lcYY3D4nzzva
d+KGqZNtoRrlD67yvENhH6TO3md4RhA4nmslQ/srF2TD+Zw3ziQY0ycndfOf
47Db9hKdeaq+tjpRej4TP3o/irKwI8Gdv9X5pKULPW/KMte/JBAey1sIVBvG
lHUQI/7SK5Qe3BJTc7APvnERzExzAnkVWRLOK/6E3wBLKcuV+p+0C2vOsmuh
lMHke28isbbD+MhibxsCPsSUWDIJfFf6wTajsg0r5UriFeOp++stdQTnE8H9
2exFPMVfzPjoFd62BHQsS7Cpp+Kw6JBK4uoIZGpZqq9ZQtQ4Wq2cPtONuCDu
UPWoGB0dcVVby7pxZvZV4vexJP4FsQa23w==
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 69->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkbR4tK6TCJVF+ojEykmknWn0qYpu0zKhlT2Y1RouwxiXRIlmpI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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k8VG0bRkVJokIkIhUK4U2UusiSNiSUCElSypYXb2mTlEgIyZ41u7Il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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81dkblmYSKeugIUuJhiSyFNVTNBGKIYwQWRvJWCo1hESWaRGylSzJ
Ug03Q6FrC2Ur996QXe73XCRKUiSj3/f3x/mcz/l83s95z/M+z/s+R8ntT2tP
fj4+vhR6/X9fylJQ1jTvxxmJPcWMOS4OG85+3GLQiYBJEdsH5RSU/fMsnXg9
kFlTIHAzkYLiksPeItGb0La9y1A9QjBd84id/70JLUMHrG6UEmwWPvtH5RsO
JhJEko79RJDp7WU/L9GCkgifX6eOUtjEOb1r650a/HXNy8HmNMHKS7o575TL
cKv5jkdcOH0uFjDPXeCgVSmpeuYsBa9vbrGLUkOYyBe/nvP3IEy3bfrZVISF
IJ/U6Q+eFFghNWORl17DhAjzWjJGwRA64+jtWA05u/C7e58SVDCnTvK/fA7/
uOl/84cpPFuYVD4t0IMrjJ66q24E/ibLbt41e4rH/jKxuXkUJhu1TJPEWgGP
9WFL/ATENYR5w7QRuyzcXfL9CbZUeukt6bfAXXNoRiaIIKyr9HC6IQv7pAzX
OjjxEBbuV1ql+ALj3S84anYUHi1ZWwr3s5FwZsey6FcEzEqbjykv69Fun3l1
nTLBpWWemm4+vSj6rcb4T/lRVHQUe3fY1+OHPMGj99MI8iUYGz+lt6NUOl/j
eAqNt1zczzfkFRLKo7Q+OvOg817t6sTtbhjcnxQrcORB6lmVrfSFHiiYDVw1
nnqDkdRXmhdbe9Hao132cp5CVcxi/mWjJsw0a7SK3iYQTnKrtxHswpgm84b8
Zx7i23IKf4kfgOmYWuS0LQ+diW3nrgzUobjAY5mRB81PqcAvrWc64BabqpdN
UXCa2VfYmfoc7wOnNjlLEPDnMP/eosDCT2o/TkgK0vXqHN8RIseB+Ocw1owK
BcZUq75qIxPaK0a7ehUIfiqSeXdBqgMNB7tldlRTeJJ8WmznwWFUvmcbbIse
QWNtzanvWWws1z8b7qrLg0DJhfjEuS4Ysn57aJZJ4b2GW0pUXBeq1MrNo7gU
5nUHdPUYpfCNfHrwQTLNX0zolYgPndjtwKQ4hlycOmmzmz/oOUJv3plhaxFc
/lZpZObZCVmj7otVn7nYU2ssYjSSByX9Hqa1C4G3qqVk//pB3Cto11P7MgwV
9cC04zl1UEy7nMZupuCZLs45m/YQwTFbUl7vIpi99d/XqtJGrF3ZtjS0huC2
29YH1641QumI5UlpWk8J082xkQ1sRGadmMjhI4hNSDz326dW/HU0r3k1Pw97
yp8//qpUi/+KoobjewlMlz5L33XrR2r4eYECkxHwiQdMD8k/ge6qgJEZSQKG
wRrGurlu5I/xxk8q8DBuNCGlLdsO1oamzlwDml9Xy6pZtTzEJ3XYM2n+mkWV
Fdd+44AECkomraP7tT7FwmigCRJ6T999zCIY9ds74RTeB5GueeUd+0eQbiXd
vWd7Pw6XHJJX06HgKp8a/UisAOHJVrJ5rgSyj3f5qk4z4FBdse9nM4JbrZd2
2PR2YNmt6AbNDgKd2efJFatewEl/xrOwgEIhV3vxw8oa/H4kVG1kloLKJpFX
7MB61A1eD17UI9g+9ZW7tKIfsaOCqVd0aXwdFm+q/NioLA5PC7WlsF24QPa2
AxvkiOv6yeUEX5oSIzKKcvBsQ4yjyx8Ee4rax3XPBCM5edjOiuavrel1tBC3
AIVaoU1vDxEo5V2W+eVcBbz4G+qOKRK8+HeKb81gN35IvOTIfcZFlMwfAxUu
HPw4z9gst3sUAhbKZ1akdKLg05OF+m0UfmVbyhnOd6PVTC9ASoEL4bmFO6fq
e5C7kZv8kH5/SZevs4BKEnzaXIRG6fxbFy+TVeMNmPTtTRm0ILDSdlaUvVqL
ppSbX2R30/X73crnpUcXtobUVMdIcuGaKL3J7EIt9uWuTJ4Yo0D695/77tUG
9bje7v4YArmqw9qM31moZq8RvaA6ClnWZq7YJAvqNftOXH9HwT+jV1ch9yz2
p6hZadD5l0dmSjgr9uFA9mM7vdUEdYJ3Hs5MvICVPFeun75/Y4p0lufOV7CV
HjMTFR/FSkaAp+qDatzz4vXJ0HqpzN4dxZmpRVtV2IfT0QRv6h3OZLxuxIY9
DkUWFTQfQxaHYqPbcUk1JL2O5rOK2JpfHOlG6QYLvYn7FA7OtQ+XrO/H8b6Y
JduFIXho6YzqtFTjqWTegab19Hs+ZK9atKnFRJjJUb8IArPxMi17zW5s6LdX
PORNwLdi58/fGwMgGCyUrk3jkXnwj8s398eYvfhZ7IAdAYtvLVfoMBs6xhUh
M98pNOtTs68SypGpaHJeMoCOZwbpaViWge+ulU1fIkHfqaGMTlMOrDJ1Q9Rv
cLFzvklvc3AjHr5/qrPemIcGtSNjThntGFw3ly76kKDRam9ONl8HKu1d/TrD
ebAs0tSwlerBthu84KONI7A1iKuLDmOhSkhkNx+NN7stWVMstBRME8fWXEuC
v+O7HXeaM6H/bXlA31qC1tgVW90t2TjrTan73qPgoT8xaCNaC8kuocF3tB9t
f7RXsTijByoH7RedLtB+1KG+0byRDasKmYU7znS9FXWCjs80YKBGWHh5MMG8
ceAKd9EKMIUc1P81IThpK3si6Fo/0lQmlkXfGkYqZ0FratczHFnt5qr0lkJZ
sm15mQMHoj4nFz930XrJ8tl18XovBK3N3YynRxBr5fs87zwHAkkb3PfXUFj5
l4Jgc2EhmPI5yRGe9Lxod68R39KCuLkinj3d34Uf4/55GtiG1qgnciW/UkjI
xBwjswLK1ZFmJrS/ZwnddHmgyUH//Dn/VEkKEc7d6s9rWLCWNBeKWUX7y7G8
U0OCbfCuOna/kP5vFA4G7pQteI3JriduFm95aNewPtSmWIrQcZsvAvS84bP+
mn+iMAZxBnlNfrQe7N6N+mZ/6sN0cORseAkPou8rOXFj52HY2eJZQsf3kdVv
vzxhocbIVWKYrk/foFx98ngdlG2uZQZ50f34jzRzuqwNxzOyGxJN6fmREP+B
29yF+VQZlXA7LhbHm4MS3zRD4HFyh985HiJ4J2Rja2JQqOzHOH+UQNzwbc7y
63fhN+ow2GhPoHFP/JRoIQvFAV6+JeoE/wMWs78O
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4VesfxZHKUIZug0qFcilDFLqilqgbkmOIyJg5kX5Rt3BNGUquqVE3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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 70->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4lOkblihFEWUlHchKoYNhd7bonrXOpOSwQ0ItOcXKSkiaCh1+tm0U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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VW0bxVWGE0KDUoYiKopKhSjLEKmQlzJFIUVKiCTKUBGSVFIpkpAx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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk4lekbxy0troYokixFUSRJY2uoLynZCuGQLINqNIQoQ5ZSkiRDEUIK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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk8lOsbxodyUkmUZAnlqESl7WQpLmmjJISibJWlCIcSFTlISLKTpiSS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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 71->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekbpu1wWi3jZ2LKVsnYp91ym0o/lYzdpCyVbRCnsiQGZUkn2ZLM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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8Vf8fxyVFg9BUKkUXTd8WSb1klKwWGnYohLYohIpCkaRshYaQVRmV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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk4lWkbt0xl7OVrU1ORDELZmkr5SSRCJ1NZSrTw2ZfIaKoJafkKWUoL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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk81NsbxyckkuWmRdeSrcUlW0Td6iOKst24ZSwtSHFHshQmUnNLJUsk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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 72->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk81dkfxmUZkiUackW2MWqmDJF9ejJlEm3CFFpEaCxDoZpIypItS4kW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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k8VG8bHipKiSwlCi1EVErZuSRRKipkL0SiQpukKCqRJSQtIrKE7FuS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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81dkbx5FKg6KSiupKmoTIlGzNx75HaDFCGFtSrmpiREOWhGyJipaZ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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns8lOkXd0tsYkItklTKpZJCIT9f0sq2RLpR7iFaSW1FSipLZbcaspQi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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 73->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4ldkfv5ORIjFSSg0SKsrWNtOUT9Y2JLRRZGtBl0nTRpaUFu5kiSQk
Uilj38cWV671crnZI51XVIMR0UR+5/fH+7zPec5zvt/z/WxnpaOHpcscFosV
Rb///7nGQ8pl4UIIZbR4wSIM1jy7YWZW0Ay74nZWFkPgaVh+tDA+AdwBjWK7
4wQZfy3bnqKUjHoNucaVDgTuCzIizG81I8Fq/vyXRQQb2Qclclu42MuaMbvr
R6DUFORToRqJKXdPo1R7Wq83/Zu7aR1+EtHIUYoiKF+Of3UqcmHAr56JOUGQ
vUa0oOhICUZvrCnwYRMo3yp7tHayG0HmhxT9tzBgiT+QUjQrxJO359Rt3Qh2
fFHn27xJQ9PzXTmvHQmcR4vyRT9VYQ9nnWG6N61f7Sz1dnEU7ELtP+XQ/lHC
JTrZ5Z3IKl1Z8TCd1tNd73focTLs0zcZHKDz/Kp2eAwKibi44aBRJp33UZi3
fbuUADbLGudrjhHs+iT6wcKsGjnb65ng2wSyz1SLfbbUwoQXosILIYhW3BFf
Fp2D8vS4X3XoPEa67j/crW+A0eLIN5wMApPA347MqlXB2jRqTo8vAfdJxEnH
+GqsETeuOvKA4Hr/OsmK1W1YekjKVNSQgc8PH/zaaoXY6KBtOjpEILi26KHS
4W7ISG6UmznOQHzt1dPxRa8hEAkTZi9l4OYcJ7ql5xWKHgQmiYUSlD4yHdu/
vAT8whDzOneC8Sp/3oEFVTh10jLGjvJT4LU1sEK/AeLa8xR00whiXD/MCK43
IUhtKMslhWAq/PTBpPV1mE7SOVn1iGBb8MgTa+syxIcE2Qq8CP68yVZfZVEA
7RcNe1edJJgrMOmqluuAunNUSutmBp6JFnefXizEsyPh/eqUL3FNTuVAkwA5
GXOLL3UR5M4eW6xeWo0K2Tc6C4IJbu5e6tO7sAY8U/bXoxzK//qp4G027Viw
M9b8/HUG5t8UDc8EdEPLIPNsxGMG65Q/PZbXzMP3YtXqhacJdiuNCcILBWDb
Ht7m/J6A989wtLRpOxpT/06fnCSYELkQKR3IR56yhYztc6ofydW3guVy0JUl
4cui56fiZrckb+rAYX2T2hcmDDhORVmx/wlQ65i7RWyYwIcV3NIb04mYrvxS
lSIGv+8v1vTRa8dOfxs1EWMGrjzZx6+n2+DUmC1ebMCgf591/gi/A667wz71
B9H7ZkZd1Kd6UPR2CX8fTed7aji2dX4LajJdxNZSPFK2Hyp5/1GIvLer+Pbz
GfTJi+4OUi7HlNuE2LnfCdy+q7+zrWxGXdpUvi/la/qFkUj67XL8Rcaid9L9
U8UjOXzdJBx4WXM8nerX41dxLre5FeFJQ9fdJBkMy7mkHfNrAPfexIYtmXR+
D/batIXU/8ZqbRLSDHZ9z+f9UNKFX+7wbCUJA/XBd2eC2HxICWXizhUQPJwb
/ElR+BoW787PveTIgOct8V4qgA+Er/jDIZbijTMpDRWNGN6VOOjygtZXHTcy
EUbgR6XP2+5Q/xXyzVPs8uphKZBvYJfT/dj6++2rK5GrEurGuUwQK2uwVHNf
GRy/RosuPEuQ5imnFhTVjo2SzI2XEgxuKWX6tbg3oERhVlkvmaD+m5V3dyMP
Rpt8llkmELh6XV3x4msz1ItdL91pIDh6z/JLQmsdrFjPNESov1hnnPSvzbFD
0kyctQ69z3EN4UPpE8l4qMXYTVO85kyn/xbS8JLiFW+VdYFApu5JdohUGxZk
vPXrsWOgtCTFN1uxF/9x8s1TxQZgZLRO8kcvPjT/Ff0aXkbQ57U/5FVUIWYr
/DVGXSkfBmw9OD3FzVS7SieaL4cnI71DB5oh/1OoZUotQWuxV5fpeC1c/1Vd
fzuMoGn4pCI7LAspOwK8vjtTPPd/FRUT5COKO/nN+RTNHyvvD715bRCrWlVW
e5ZB3PGZjYF6lP9LITpyngRbsw1HJs8Lsc2+L6JXnMFxBRNZx/WV0M8bMQy7
SP010B69rbwMFmFB02epXkb3u+4UWV0IL6fN+15R/deW2TKfzwnA2+PwrTyL
5hm7331tEhet8apT/gE0LxTXfEzR4MPw2ufFffepnyNdqjcXNkPZ21n+TjG9
f1/uosr8EuwoPe37keY3t/sx96eMFty4CrPCUYLUA8uKbHaWYGTPpIMUzaPA
JLmRFT2dMKl0yHR0Z2Ajr68jIWzB5SsblD/UEXQOuhge2/oC0x5XNMJovpcP
6S80VkyF7hKVNWl0LT3R8NZFOR/RAYerm2n+9H/YfJ9T3YTUHKPfbGleCVQ8
y7bLd8Dre1FeCM0jp+jl3vy73ZhoMndL7KT5f9v6UO+DHMRHCtYtpudZfU/F
qzRT8eq5jNVftP7gkKic2Bkerv9s8bE5kvZ/p/Rx8NEtjEfIGhyj+rH9J88x
Ynkubs8glOdC37+GqwOKrln4Hh9g4EvX8xQSm09bvYT2RmNrKYq/+EHzJEs3
Ic4/mm0e06b+VvnTYq9dKn4Z50s/oP1GO83F3+nWIYyjb2pP9ewjv2j259Ae
aHpbSqvbMzBQ54zatfWgs3VirgHNQ8uotypTWjV4GleVlkTzcuyLg8bl3mwY
JBwx6aD9U6WkRvMWl4H9NH6OBOX7snHTvvtZAiTI20Zv7aN62m2fNuxRAnlO
LqNF/Xbq8UrOG/UCLBl6v6yb5rXFeYfxyfX5OBXc5n+D6i/mmsNS6dgWyGeM
s4aoH93vlSUKrvGwWcXvtix9zw/GJB+s9n+NU57HGie3MzhRm7PDwr0TmjZb
J55dpf7J1dt/7IQrYj7naW+g+A327emt55bhjpsUN4D2f/ataGc86cAVtq1s
1C0Ggz2bHCL0O0BW35tafYCBr43ofNXBLoy/MS+/cImBY1V4qd69RGibmZeG
Uf9G73ml9fPCTvSl/6I9HMxg3pOYZNaBEujbaEnX0vnbJ1r56yQqwPHwUfj7
PEF+Qm7mhb+bILK3pramjWD7f6O57zyagCV/kD9oPgZ6qi1x3pWFmgaZczIU
z72x3VM3otug+6XpyFE9Bqd1+4OPDghxttJiw7VFDCQVZhSurBAiuUhstJa+
x/8DYmG2xg==
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3kglGsbxlGEEm3anCzhVKg46qhwRUiSkJAjFbKUZI+yNyGHoqJIomzJ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs41VkXRtG4VCRyv026CFPIPS+KUELFEDpyS4ZS6TSMXFJIiulCUW7R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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lekbxpUsUTQnpEKWlF/JFv0IXSqFEJmMUpSSKSm02mYsI1mLLFFG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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 74->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lWkbJooRpglF2lGyE4qarjI+Ko0RvkiSCaEs0YKiDoMaGk2hQXYl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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Ve37xVGGaJBCIkmmUCllKFlIQuVFQqa8ml+RoQyNkkohMs8ZC1Ey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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkfxi9aiVQIMWHys4zRJGSrx5KlRVkShVBjmUFRlLVuxc0W6idC
hDSVJbJL2bJ20bVdXLLc7xcxloaUNOn3/f1xXuevc55zPs/7+Zwje/aClSsv
jUZLpMb/50GtC/N3BlgQUcv1WBtCwGLHE1tR1XbwMs6tSpmTWOVEZ7IsOXDP
0rCq+kTihOvRkDxDFlbeKLSW85D4texoZ/W9Tvi4OE142JKQSWHNis7Rscbm
4y0hJxKfLC9YIagHtd5DOtbmBGyUXXUZTl3Y5PF77clULp6qJPne2l+LjM28
Plv+IEH7MaxXur8MU0V/G6xeJjFqEawXIFoMj6lU74oQEvUm33Xm6GyUyGS8
nrUm4Fz/if9DNBOqTCPeGbNxHGYpCzDkKlGQ8OR+L6UvvsXQzn2uEWmVngGS
ESTY/nfvzXm0QVLO3JmZwMUNnRFP6cYK6KXnLEfqkHA4fiz05lQd3t+fhK40
ibY2jQ9XVOqxcCd4JdKIBP8ht2DHXDY2Km3bIqo7jivzXsnKqxwI9Z27ZjlB
oM00mHe9YCcu3NyzdiF8HGbxWQrSLjWouqnab11C4ups92DSgwHEaGu+UD9K
IKX4yNTTYjYgIWt89h0XK0kzguon2IgRWzOfaTEOxZTgR7+GtSH0mjhj3zQB
lu03/XyB18h5mT8QkkbCrqro9KJXBxz4tNMCoij/4g431zDbYVOupMcTQMIj
ZPvkxqdMTN8YmruZTOLFRB29QYiFxO0W7pcHudiQFl4n7jKA81y65b5rXNA5
cuWF+/MR33a9/RKDqp/WCE3xwCDG/vn1YZgEgQ2yXbf5V0vBcAkONbIm0SyS
eNFFsh8Rny17O6y4OJbOot8K78KDsonGRjkSPo5bH6jX1uHP7M9usqIkLIKr
R1t8mKjVskwO7icgwryVXRPSC78dE6mBeSSm1Dz/NeLrw98+0ga/5I4hrD9z
nfm6ZrhnVghELRAI6F64X/hzKc4s0BaPXyGR8c81IQNGK5zemcnPiZAwG9A+
kGJbgqsP56YjKR5ruTWz32n5+Pq36curFyg+TQROG3eyMfdh5Mj8HMXb7mMx
mosRYL9RfBNM8dJ9+49/tSq7cKdbajVhF4GheUW+22Qv+oQUmPqtXKxLf7xs
KNqLJx57fnnfMYauNtHzHQM9aBj1cOEx5EK+JHto9ssgoqpa2oaeDSPm8a5G
3cVS7DEv8XI1JFFY1thVH9CAWcX857UUj7QX/sEliXQojdp3aJ0h8eqxz/aB
8Xa03XugZqtFQrgl55XDVCeUt37LfNpKYDhwV4JoUyue71U9VwICFX5s32Oa
VdB82q1upU7V15WlXWXZDr3ivBBvDoHCDFU+Wk0tFqUCD3EOkHhj9eCIePQA
jIwD53UGuBS/W7d94WFB6aOSZdY1AnMHbLpyH7ExzT/D6HhGIpaxHJzWzcRb
n2//dVYn8LTHpq12XSsYYYT3q0oSeokm3gE/lyGd2TBr4UUiJMH11pusbvRH
mc5IUH7rGQ0V7/TvRJT66zaVwHH8qRi9qehDE3QrZKaTlgiUSS0LJPB1I3xs
aOP29wSUFyRY+xWL0PLx5KnzVB657PFkdXk2bDfNJ9mf5KLyRp5CfAEH9z89
yysUGcH1zRzPgk0cFP3gEbN7ROXhhsnsX2bZ6BoaV7BxJOGyZojvcVE/ojWd
sryDxnHZP+dz3P5eyB46NRvZTeV/05DGIU4PKiNmY0xOU3n/VOTg1N+EqJJ3
nkQo5dfnRbMvjo/hrWDMuOZN5ae8cF9UXglK1gQpSe8j8deSo2JcTT0qfrk4
pVxD1f8nDftVlGLc/vmqVBCJk1UeHWca+tDkGv21heJbv83R9Zt3OmTI29JR
50gcje2Jp3NLEOK9XjDiKAl7Sf6xHkkWlqp7kv1UCLQMrf32ZfE51PpPX6ow
IbGre4vAefTiaN33K19ZJCouuscZVJRAcnnDpIcyidOX3Xn89/ZgjY+bXx3F
W3+uyMuFrc/xmemwW0yfxO9NgaY/wpsgms3DeO1Jwrhy+JkGk42zD/NV7k5z
cT+n3MLCuRweVl6b3Kj7CoqcKZwIb4SQ+1WntHECrW+NyYfig6jfcPZHgsoo
PoapjlX6PcPKsEyQvQ0JE/0Nkn9t5MBZ+G1J1UsS6rs1bewC2ZS+vPrwGBfL
WxhdNTvqoK+U2LbLehyjbP605IxcuPU+136pQOK3OP0xYfVWWISejXF9QkDR
4MRLt984qGe3jMStjIB2Uy3N4G4GePV373WxIxHQc8dli0A3WtzeS304zsWn
SzxZDkvNCL5bLOp/j4Tf78aPSssKIT9pXPWVytfBfL6wXWN90Ge/Y5ZLcPFv
ccJ5QTUWqksr8+pjCQgUrBz2zeiEVnsDb6EwAZW9je3fA+sxnyrfLkzxHlYo
tciV7YUXt9RATJ6qf5tKqJhzK/7zWqwnt4DKc4PkUkVqKAIMbWIKKD21eBFT
9mA3Aix1ct9RPCZkD1ocCuwEPd0+lC+fyu/ByjnP5lLYL15MSaD8kCH5NUKC
MkG7Sw7IUOt9xaaDTW1fgbONLqhNre9fkj0+fL0ICtJ1+4ao++ftuNfA2tqL
Oblze+e8CNC+Oir9pBuPBc0CpQg3EvG0lRMF2lkYyXY0TaH6m8HoC9vJ6B5E
jp/b02E5htPWBhvtJR5DytlxPuA4iTVS2zfPHOmFlS/tD+vt1P5vbWvjCyi/
njAFU/8hkF5/Xckrsg90Hd2LLW5cOBsdrB5sKIDk4S/Sby9S/jXLcw7GVkAu
rzq7nNLTLz3VlOV7G9FmEYz1FO9a4ev1d26uAKf5TC+vLwmdjT/5dd3rw7zd
+nw3MQJynU77S3ma8C35T+ncQgIzmeJey7+1IzZdokiCek9mVPN/nBUuQthr
IXodpXeM744/w64PsUGSccbiE3CYFK1896EahqPtg7W6JFJy+tWF8rpwd+Hh
2px46v/it2Ry80A1Lm2bpIepULxaVtdtXupCZsOAVqLEBMrMu/RcIwch6qVh
Qd9D9f+DC2e837yA6jrhK32qJOi3Cncaf01FkpB5WLwziaXGtetn1DqQkLRH
oiCaOm/90oNYIQ5Ojez/rEb16/8BtZW9AQ==
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lWkbxw+KFiWTJZospdKmkyIN44dEjMaSsUQcsiQpqThTKnQyhMLE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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 75->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lWkfRq4sg/GhZSLVlykGQ41E6tzVWIYMvowS4lCW7DWVbeJki7Sc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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk4VW0XxjUJlUwJSWQoSqk3vKFupDSgTCUJlSKZCYmcSlIKiQiJKEJU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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk8lOsfFS0q15WQSqTiahMuUrkd2ZJUCgnXWrQjERNFSkSrJC3WdJNr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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk41ekbxkUaMzHKnmRUaKEIU5Z0k5KhMWWko0JZKjFkzaBFZOzTlMRF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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 76->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4VukbtswYM0yLqEkUkamJpjIkqVsTaUKEjKJCKoxChKxRJpkaVCNb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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k4VV0bFpKKkihUkkKEUETULVFCikpSCUkikhIaJPMrCkkiJaTMQ+aQ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs4lOkbxyekJGVyaLZQTm0HP5SWGHxlSUSkctiwdFibqBRLpPDLMUVl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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk8lfkepgZl2pPtWiKa5JAt0UyeJDJiSLbKmi1LSpkyzC1iSnbpxghj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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 77->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4lOkblu1AIjlkUmSkJTlWRNm9E6uNVZbYtlRS0sq5muTUOCZpszax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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHc8Vf8bR7RImqRCZIRKJYXyliRkJQrJKElLpRQlK30bRsgqIxnJFpGZ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk4lWkfx5m8Jk0LY+ZIxxZZkoxBi8n0janGHs2JGjSSLGlTR7xCtsQo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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lGsfxseRUnmVnLKlxVYRL9WJhCtrUoRkaXGQao6SObYoHUtlS5FG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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 78->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lekbxqkUmZqpQcoWg5hKmowtupwapcQgskx2ypIYSYhCSmKiRQph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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk4FY8XxilRKmklyZoWES3KUr1SCSEtyJqkklKWlHxtZZdQypotS6Ts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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81ekex211NeLKZG1GmRg0rq3FEfrYs5TByFLWkekMRhiJUMZYQhF1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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk4lVkcxy91M1nKlsYakuTSNGUZom+loZAtjMpEYUIzUsOEbC2UhqEa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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 79->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk81esWxhUhc9EW1T2KDxqQTkodetJEh9M1ddBtkFmZoiIVleFIMhV1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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk8VP0Xx6WUSIos7UoKiUSW9PhQSoQWSqVGi+x5RAptlDWFkhKJ9CCS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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81NkfxqXkkth+SJuyksbayn1TVE9NiiiJJbZJhSKEhC3tYkkKSUVL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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lWkfxnWylClhUg0mJ9GiZVQcZUxXUikTqbTZ0mQrSklNyKm8aBnJ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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 80->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lWkbPkWlxZIpSaVTyrQM05R8Pg1XGmRpIqmsdU6NmAihRYuQSGVL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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k8VA8blQpFkihKotCqBiX7kRKhCBVSSUJRpFIpkjZEUqiQJfSnVJIk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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81dkbvgxJkxbbNMhQqEEIpeLnoaFkaZFKQogsE8lgMKUrRDVjvYlp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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs0ldkfxlUqmhRGrl3ckmZokAqVx5RSqOQSIbnFKIoSuXVxSwphUoOK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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 81->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lVkft5VXKZKyRKSoMDMRE730pdRkRggjRWUfZUka1EiWEoVw6UaW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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k0lG0fFpEtqdCiRbK1I0mSS6K88laUiAiVLaVQaEFZUikSQlnKkgov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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8ldkfxyXhF2lKSfZBKVpkiSn5SAZTsrQMGaGohIxIxK2IJMmWNWtT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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk41Wkfxk/KMmXUlJESpSRNJktqkLqlEaXDiLI0lTXqVSlea4nKkiVR
liZOHMtgrBOypCzROSfLcRzHcmzn/H5JKoomGkvv7/3juZ7rua7n+j7f5/7c
91fV5dIxdwkajZZMrf/vT5VvR9rM9sDyqmEfW3YEOyISO0RFLRA4uFt//4XA
8FClyqHoTrBiisICXQjEZqjdbJ9jwWVDQvjPGwmQip+Pj6xohtpDeRUdLRL6
zPbZ43NVkLgiZMxcJPExfoVT9MmH0CsvDvc8TeKJgnuLuzoHGgMG4UdOEzj6
RspO5xQHgiSPR7OmBLQPSNHjz/Zg/ra3ZtsmMWKl6T5bulugaJDybKGdwC3a
Be3zv7zAcIFblVIgibuabEbfRAYMPeZK6ZYkQp8NnV9srsPZT5kF17aRCNAr
T/BTHUZdBsvbJUGIj/xV5rsGOvCpwSlcfSf1voNmifDVAP49WFjOUBvBSO7t
1DiNOmTlfLpnvpZEjGu3zzJmD6oyuVaZnmIkhfZyVh7sRXFiZUlJAAHT0flj
zL+7sajBtJGOJ/HHXoWt3bJ8xBpzzabvi/HnZT5Z8VmAa8FyjDE2ASVjMj14
joNvVTp9iSMEWMGZjfybL3HCJGDgThSBEHvXq3WzL5CRFJt03YaEr5zei7mm
JujW6B4fMCXxa+PnU4qvXqJB5yzh8JjArPZUj55ONTYJ6g2zvUhw82/d09wm
RLZXwsJg9mtoHuXRM2I4eOL3z39zIwl4laY60d71oCkmtv4mTwSJr51BrlnN
aMsnekgFEqTFwnWRchfif+k2sWSI4XzMdOqNKh+9gf0x2o9FCKIXMYx8uiFV
ZOFnPC9G8hl7mYHNPIQo/NkyliDC7yd15Ydf1eBIh5XCJWMSdK/MENqKPuz8
nZH22UME/RYiIiagF4212e9+fTuCDDsNdbveThS+W+J/eUwEwYGNX7MC+Eg0
TjRdyiTxzM3VbrN3H3z1lH96nzKC0N0TY6rD5bg2HFEqu5KE7U7zkv37mlAa
rrEQW0ig1EdyfIHVgLKn59KYaiQqzxzt6mbxULJ6v8GXaTFU6lTbF7h8zHuM
Tn8XTqC1gfMXz18IlaBlM6yeEbAjVJYd4/MxJDVRvSubhImJRavpdBumxnOm
g+6S+OHnbWOXn/dD/01+25AGAXZcU/LsjADE2lrvROfXWG4RvLxlFR9jnXe2
+ueJYL74jb7tXCksVyg+mwGJ6D9qFz+UdGPeMkrzpy4RnJOX5chbVaBtyD9P
xZ9EomrzpyXzQvC0gyOUt5AYmi6KvXe/B1fkQ+SC91L1RprDYmsyUT9ww93R
iuIdWdanV9UN9UKDv5YuEMgY3pZ5VCkd8ubf15dR/jn3OpoxP8+GdebDqMfr
SETlZu3yTW3GuOZ0Sxelj74Za5H59AkmtO5aTb8hUL4uXjPHiIXptPbdSSwC
Ld0rndOlO7BhQHu/ricJkW2zomCwH/wfd2pVfBBDvlQjP+UBDw95F7JIuhi+
nJp0s+AK/L31PYtG/UdmrbjWdCMPcjGdq//MFGGz9hPG/TIudJffsQ7aTYBv
28zfYs2DcwDdSTJEhA3XDykxHDPwIjTG5PuTFF9Lj3rj5604lCIjtXOIgFuS
QsYNv1fQHCj32ldLwPY3lYr3OS9wytGbbqNDgq32rlLA5OC8b5s4JoEAZ+C6
fFlOD4pQab/EX4T9Qi69aaoZl2g77Ff9ReD0XrbRhjcctDz5Nle4g0BxMtdv
/WIblD4+KLhjQGLMMtL08VAz5v26eXFjBKKqaV4LiU/wsleHniZP6fl3Q5mb
Yg1GcoqZ9DMkjhXNbAlSFmJUMypImjGIkMHgkjMtXOTMcnnCODFYExaL5kc6
wK0Muz9lRsDpQNQ48pLBSOotvHuChPFGa7+C650IzI0X08vE0NdjSPpRZ58O
CyVGqgilXbJpWr4J2LC/KrqA0sdT/Nk061U11hz2PTGuR6L8vO3gb5ldCH37
Xf3xLBKKLy8sfM1lYrmSlGDcgoSE7Whk1T9shKzVPZkZQ0JvMq4izXkAxaur
E9gUn01XL+6U5vXhfPue2ofJI5BRjTEzeN2KgIMJKT9Seg5tP/IutrMNKz6s
GSzxJNB79D+vbAyrcP7owQdx9iTWiw5rRBAC9MRoVm2k/FH+rPHbnmO9yPuw
LqSQ6p9ntERWmMIDJ0y0R7KGwIby9NVhUS2YKXh3sPutGE75/qc+7y7GD6Jq
mTBKj9C4BEHFfDtoLkOLPvkEFoarr9i5D+DL6FOxbguJgq8/3u907oe349WI
j/EiXJxzkyiVFMDQretWA2MEYwmufSsPtEJncc+EUhiJa5dWNdmc7UDBLpla
11QC95OL1ZfI9aEy2ea9TjCB4FW3pDsceSg2ZTzyoHgrGoiV09U7MJyTu7i0
msAPVxSCSj71ocX632/9aQQs15cF3KvkQesX8+jofDFoWtu3ydKeY5PRxcvB
wwRCdePpq0cTUR4S+k8+xeuL+MteUyr/m4alWd5+YtgHlmvfmayFldlVKZY7
iSUuh91yDnfBzIjd7pBLoH5ktsiGewtVriG9l5yo+VzRIUyLHYSEuomVxxYh
ghWbspeeFSLvefgy6WwxprpyAvVreagnr0dOUnkUy/foPrLhYsZ0H9PAkUCk
1MqpKqtebN/MZa9ZQ+XNcFJdWfQSl104u7QfEEhddrrLQaUKiXaEv5YkCaPd
83VD97rhSdPJf3uWmj9e9crFHs/hOadUPBFC4G6GvklQeyv8PzhHtEdTejVM
yGVQfn3mqPzbA+p+VUHSOp8d7ShluxqWUvn9KC0VnXr6BUpbj2z+6QaBspsp
vMJEPm5UaNsf9qb6bdhnoCjXBaa+Pc12ToQT01F2+pMCbN36yORkoAh8Twn3
hKW9YJ7L0CxYT8JJV6AkJ6zBqZBxv+/2kChRvmZr1teKiOOHWi1dSEwqGzde
KGSjMS8g3YLyZ7F1peJHmX4ocMIyU8uH4a122uGpVCM4kwf9N00QGN2dtdZX
sgd5c/1p9uFUHqTZQmVmBX517Uk5GULV/xIftaDMheyli2p9URTv1HndUbc+
XI1YsdnLQQzHQ9uVnIV1+CpsTyVzSPwPGH7Y2A==
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 82->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4Vekfl5Q9oiaVpMYakxKyNR+hLLllGiNrRAxNiy0pE1KGcittV8pW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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3lUTW0bxps0aERvpqQoUlRoMOS9QhFCSKVImjSpKET1lqQSpVAyJ0rz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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVns81FkfVuRTmzTaaFulqaTS+5ZsBrvqcWmjWNlSLosiobuX3CLEtGoT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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81Pkfx8X+VBOtUluOzREqR8lYm6iXjeyQHBlHmsparGRldZCQnKVD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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 83->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk41dkftsRUJBWFVJLMnaxRlNLbKGqIZBtMliRKQpQ7REpXhCyN5VqS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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4le8bR4omlVAho6yWEZXoI/FtfpHRQCkJla3MQqnsUpQtyUpIVkT2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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41dkbJ9ljbmZoIaIsSUYlTcIna9GkrGmZLJUr7ZaSQQgtP0qyJMuo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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk8lWkbFskySE1ZmlGWqCwx1dAXumw1GHEsLZM6DkVEODNUStYyVIPK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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 84->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk81ekXx5WS8gtJ1CS00IyUXTL4mGoklaWMZFKWGCNrRItCIgnRYokR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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwdmHk4VI/bxtFGqZBS2lQqWcqaJblJi0qSFEm2FKl8pUSFJDuhUBIK2YoW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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk4ldkfR2UnZQmjhrrZklREWT6SSMVYipJisrSomKxRihZFzC0NMZFK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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns4lGkbn0Qnaq0tX9RGErYt6YpI+JGS0zis84acKRraxKgUtbQJiygp
srHSRymUM+M8QpkhM8Zx5n0VIXTYWIe+9/vjuZ5/nvt6nvt3up/tXsG/+IrR
aLRb1Pr/ni6wPXZl5hVcgopMIiQIKL9dLDpj2weTPz61nZInYVlPVzlgL8AE
i/HTQ6cRLDFGI98M1OPSW57R6q8EnGXTb+Wtr0PKgSy1miASNFmpNT8nH4Vr
fhN35wkSfCvV+tmOMhgeR+3CYRLxOWXfeSe9hvhU/7X4lwTunlZ7nrW7F70W
liqzr4Xo4VhJFcwKIF35iHRkisD0O1JDbHuKjS3Pfgs7RKIhzatQLVyAVP+s
vIqjQzC8YMq8n9WKYZmXSb611HvmFC5vVyzC5rTTbnQ7EmUZM99P895g41lF
LldXiHJdq8i50deQvsNa+UZChCbLL/bsf95ArGpk0HpqBFGKa3t+MeAg0f43
f/VDBKIivV9db+eDE9zUn/1WCMPytc6TmT3YJbvOSdNeBLaataeUXBXuaP7b
PDpJQDHnP9dGR7shNe5Y7WEkROHgEwfJy40IsAkJ05knUD7f36iY1YJMjRs6
vRIklGqu+x/k9cD8WTi9UEaEM2eSaz6ICbC3fZvPkoMIPjzlnelnu0DTYXwy
+Y7ESK+Kg3zHPays9JzrMCMhb1VUkhbZheY4L0kJcxJM97/MskdK0JncobBW
luJjMeDgf7uMMT4RO6pB8bHxZ+mc4+0suOnQpc6NEvDQ26cpxqhAdf37p7mb
Sdh4XNSddnyJucEbHX0vCOS3aAgGxbnQmlX+6ndaiIATZUrVRtVYzkiW+pHC
V9J/WaNVxIf5Ea2BvSSJmU5rxsPzJdCWajpht0TVe6Uw/Wt5KDH8xd9lWYjQ
56K5U3kcrI15Z61pJ4J4SliLsQ8Pg/2P9wb9IEKl24ts8xY+wuKX3l8oHMFT
t9ZodbtHiM2yU/xoQ6LX+1FT1Xgvfu1jtoifIpCjosAyNuJBISGo3r5UBLXH
XkpzAQ1QJx9t8b1LIK2lpibmVy6sdo/trt0vgnvac8siRg9+VNW2+8tYBEX5
4VS2eyqCvfV5DBcShuz4oKioXqxi3ty6PCVC1mfbyYj1XIRJXyidahPC54DW
YlYiH4dFzp+vaBOgNQQxM1vTYXVAb9bXi0S668EmU6l61JoyPQcKSZDSMbMf
jV+DlH3pUe1BoCeBeJoY24y9vkPXVv5FIpVfrjSvz0XJZR1P362UPprImotT
LExnTP19ntJTyMkr+99xuAhlMlcvhYmQp6r0adl9GLYJWuFssWG8nd1Jk/bt
xhbj87KCXUKw2E8mng7wIVrI23TsHYEAr1rV9cp94ByJ7RCj/BEUG2P6kw0H
VWYRiVq9BFp26Iupe/DhqX0+wp02jFMXVUPX8TngsTQSjumSUOYnEEZ7mrFh
q+vyxU0kbGntf+4K5sNHxeBkFynCZvHVWv4+A7gaPBxatleEaqey2gPP2jFv
Gioa+kag4egjG5nkLjBO2ykoUvfxFS44Cz7x8GNioaanJ4EdHRptC679SKJv
K3+sQiJjxl4+8Fg3PExmtENzKH96qc6nkJ3IenCtvsSSQCzz9Z78Lh5yJ4Ij
JvaPYFH4rae98zUk3ZbFxnpE8OIY6L79oRS/ci9NWlB80G5kBtV94YC1QmU2
PUsEjbRve+rVC5DLKLhtZUKiYniV4N8XbLhed5k7c5Din/7Ok193HxL3TMUV
fEkcWlL6XlOuDp8kpUL1qfM2C9xNxtpc3Na7at30uwhRheuNrsexcSWTi68U
X4Gsqhe5rVz4jVXlvp8gYGki8+Xsmz54/Hba3n27EPEqhPNxs0GcWjcspmQw
gKSYUi2l4AqsMP371OTPJFj7P6rH5ZdB2SDYIpJPQNZQIXZbVSe+HlkIVg+m
+glZpnUQadCtNrfUpfw888xCbTSjFf9cXpMYTuVvVP3mw+ILvbjaGmX6/N0I
RE1a8eqCZ6i1lbJTNSCx7xZ3tMClA8lrKle8ZFL9qn52OOd9D5pyDZbbqTxh
lW+xoyddxav0xQonNxKTcg2NLjo9kKnZN+rgIcKRG+ZKnoMPcXP/GvpafRIR
g93hGVMcNNxQexgNSm8VqdyWM8UIlDS5bK5JojT88CEbWTZ2nBvzXg4hoZ55
ODnhGhdbbtkdc/Qm8D5akpwe7scVsnBZVmcYXNqSzNC+bmS0WYRJxwmxUSX7
y8PmZhSb2fHCGBT/bIlG5nQnIgvO3dcfF0F5aNFN63EfWk6OZySmjoDeaJ71
cZiDty5beqIWRTgv/ObBvdeBUJlt/P8GE9hq7fncQr8BzneTZqWWqfnjmb9q
JrsXo8df2g1+FSIpZ/3ifGYubnE+f1D3p/C+zbJWqYhGSNmmUkdPEkdqZMzS
81loinPUWVFG9ftHHIMjOYA8vpND+Rg134ymAxM+d2PXwz9P5MeQ0DMJcWfX
NYJ5f5E4SuFvkdV0tMakCyznj4JyCwKr45/X1UUPQraoxtXq8DA8fOf69nFK
Uex7ryNkD5UfckRr5w+V2MAsvqOzk8r73v6SQ1+eYdWN6ty/j5OwMjO647qh
E5wxH9mFWhLsV5EHO9tK0H5C/vbJDBJJRYgO2pcH1phNVQHFZ/Zi0vwT9QFc
yj1ZvKp4AEZyvEz9Q80IXFcXyHYiUd74JO6BRBNavrXT5WRIONYQJ27t58Nv
SK+7+MMILiU7BOjFdiMoO8acOypCfpfJxkp5AZjzxi2VhsOgOWakFSex4XdH
Njb+KoGN2rHOD3w68b7w5oqxPhHKDzis/Me+HJYGPl4xVD5kOvSs+8mhFw8m
1dRmdCk/WQwtzsUUofr6V99uDxKuTXdJP7kSiI3LvE8MJGGaIrFugl6NoZtt
tA2fCBgaLTOE96PxNMKH3udOIrGAOS8m0wex4LDCc71DiHqS6lS9IxwllePN
fpRfApoef7i7hofHrqW7/2UKwfyzZnAl5WfFji2/pzgR+INx8bsU11x8HM6Z
ZVHz4KyXVTSjW4AeYu/oZUdKP7alhg6KApQbOilMfyChyLpPL4l4A3povM1m
gvovfG5z0jsZi1zvsBALCu//ARORx6w=
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 85->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lVkYF0ZKqwqpxtZiVKQiCj9RhjJ1QzNM0iUakWsNqbhDWsiUBhlF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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lH0fxaVET5FKIkuRlJKleiLk2CqVkFIKJcmWLBWpJKHwKElpkaQs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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lWkfxg9pIjIqUclW1qSQqbHUpaJMoeyKCkNkSTVSHaNshzDZk6hI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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk41WkbxxFlmYiMsfRKI6QpSfbSt8JkwlDTYIxkRMTYUr2hsWUiNBlL
i0ILDr0I2bIle0445+DYDs75/X6kLNEiZPL+5o/neq7nup7ree7v/Xzu7/1s
cQ845ikiJCR0gx7/znr/dfL8mizG0HL+jPoZCmU+28drYjvRmjo2/DiDhKjW
j2vfqI5Ac/7rp836AsRss3eWutiLsv99Fr7EIRBoMOMK6XpkMEvuuBlTEM2Z
6LQwLUd+dEgbby+Fd4GJow2nmpDFfc0ebaRQXKNDrnvdDVWPfPXmMQJCG483
5Y70QU3kut/uaj42CA7YpUzU4KtezqT8CxKXLBy8BRocfFk8UZk3TUDxxkNP
l9whXHGIKJwI5ENtJfnMpPxjeNyxs153hEJV6CcPX14exhjMF7FHKbjtXvOE
GmrH4mJkZWgVCc9lWZm7OS3YI2phebmOQnvSyIXBl80gUtMMt9P7S50Z5zUf
tkDcvbMyR4dCLfe+5JWpBhxIDDiu/IDEvqZD/mEuLAh87az2fiTxbvD9hKUE
E/IVlYMhkSTkj15rmknqQqyt2ZejLSS23dR5bh1dD9PsPQ+uyVA4UpoRLDHI
hQ7DlXirxcd7AyXRfIVByInd/H7nRRLTToqRI8dG4B59RjTEfQztU1vm2yb7
UdgSgPA2AqxdWYVvG2+jePUrKbVfKQSoLN0SpuOp3fVOPZmOd4OSSFEUqwtO
1hsda6wIkPpbWemtHIyqGKwmdFCIlLVoKtxxG1VPHQWXnSnoLugc//KmFV2V
yUVtPAJxx1xTpobYuOJyM9FYgoDVn3+Irbyqwdwce0DDkMK2ULW5hi+dINaL
n9+nSmKreSPznmg5bG6ZyEgeoBBue+k1V6QXse5eEwGhBIRtWAs6dRxMTIsn
qdoQcFK1Nx6VvI3Zx/cnpX0onJ3euvr0vxxwslz2mUUTUPGa9n58uBe8Z/fG
zBMJCDJNwqpYXBzOGalXOCmA26E+Sz7FQFHqpuhLfhRs6jlWKulVULTmnQym
1+61GQdbczgwVZqJuhhKginyZsJ1uRfxjep/zBkQyP1xdbX/Bw5m7e8WjC8S
mHOntTt24kX+vMQHBwKRcmWnYy0iYeFm2CF2kkJgzQ7BA3sODizvq/q1gsCn
4hz76phGxP3ptUvmMs2Xg7GqvFMB7L77Tb56PwW5YDl1bdkWPFrS3SEtSsHk
gYjv4EEWRI87a/u8IsDvutNhsK4Op2aOGq+5SUFHSFj8iHo/ro/vTvJTI3GP
x8qLk2EiXCpY4UQeifiD+Qm/OQ8hqsT0iq81HydUr93J72mCQ/FY3mQYCVbM
C0cRfS7+IHfVuSXysZywtPxDWwW80ryfintRsHpH5E+ufwihqvFPVjQvK2Vr
0iQS+vANN703lsWH7hOt4J7qXsxuVts9SZ+fuW1Lo//OJhTknn+pHkciu924
gEhpAM/Ip/s1rdfQZbWMbTyIxaOHt47bjMHY/c91rM3VkHbDaKkenQ8tM/+z
+9hYOLunQdmZANdCQmNmZBj3xDMuh4vw4fy5Ny2Xft+PqNS/zyTg1v4fQfie
BDTedpY6Ted70LjOnDBiY2fzkum5WBJbbNGVzOjG9qWOoJRQCh/EzlE948/x
cza79fQAia6HJTrH1NuwnRG833uZRFU5I8pPsxN6B4bs7jQSmI1ZWqNQxIEW
y1Ac8wIYO/B2dv3QjqbBI+YxbwloGu7Kko5ow2pQuopyFQXN6yqvst4XQs3P
KPSDO81nYNl3n8RqMCtvKTGnSoHlH1fkNcJCAT9pY74u7XfCbsy2ZjbKTkmb
/zREYDL+uvX00gv4u2fq+7jTfjA1YSxz8wXESvo15OwoLAxY8CzSuXDkadX0
uArwu+BqWvjzbuxjhuqL1pPQiiCCbAt6oaB9tuHQJgIbZtdorGj0QJnJrP5e
l4SZzbSfeOcQHEuuxfBdxlGl7Jx2eFst5P+p3fysmgQZHbg3KGcYNYIQzWER
Aokmey/GDzzH1IahtTEWFO2bvJBHv3ajyGDNcjyLhJDv7yzNLw2Il70/L/eY
ROr7Zyf8KSYCSitcNjqR8DYZWjH4ZQBv58WGb14QIE7y1OV3b3KwX+Vkv74H
hU15dtpDdL2ZC09+Vn4pgI3Fq/HtoR1wWrXdNO9IQmV05pDUkWG06BaEu92i
+ZiVlYlW4GDvvPOjiHgBolWC3HTCOCiu2Mk0GRKglZQ/+zOnDz+uWyxbX0Pg
kWns6Lm+Dmjfi8vKFaH9PX7aij9Wi4ytDoW3xkmcsUyckkiuR1zQas6/vG/f
zyrJOj0Iaz3FU7J6fLBGVzVdFRmQNHiWN0L3h4EZ/1veCgOY2xx5m1jmw6Co
REp4fTemLK2o87Rfs+aaBzNFW/Dx71H7D34kXvp4+LKZffiF6MkrVCNwYTHY
J/pkDwbCYo0iXUmcZKzfoyx2FR1WLa4hNL96LQyvn+aqodha7SWdRMEhp1Fi
QLUS9f7/XG+j/TN0tD5Dbm4Qn2cm49lbKPxuIL9oktyPKAV/eyVTAgc/515p
u9ICajzqpSetJ7VZNVmpoBu1bGddJTMSLuek6zzlO+D5dJkfFELff9xWklpl
44FH9YzZUxJ3zWOVrAo7Ed3saZswQPfXbrugjD35iEpcZ6VP18+G72/IRGzk
4ZPBNkOHbAEUV8TvVjzrwpOUydv2Xwiosd/XuZQlo8DZIKyJ1uP9rfXVE1LP
sVU5Iq+DrkeGbfp4ggIP8aez2cLX+Ei99FqZs7YT3fm209/8TaEvXFvm6ld9
iDM6//chmjfvjwEemVQvyruyxYYPkOA5LBny+rqx0M9us7QiMTAQ4hgpVYFM
zb5ZaTq+03clr5V/y0WaCKV4UVaAgoDy386VsbBQ9UDX9jDNo/tfOY+D2SjP
Y621HSawtDdpdi6FCcdSk+L4Ofq/QmkXM6baUBoharZQSfOd0pCTbseGUYGe
dLomgTwN+RXdM13wLcNfMRIkkjyudweS7RgOG3M3pv8HxVzue7lDXOzgNZSe
+IcPj5jmzGyrPjDOs9cayZKQ9vm4/PBDM6KPZgnqUykUSv7Mu2HdBxvuhWcV
lgJ0MIRX+F0slBxW/e6vJyT+D6VkyqU=
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 86->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4VekXPpUMJ1GSJqMyRbkkozIl6lUjMUWRrirKtdxLblGSW6KEhNwi
pXIfiVzH/XTMODicw7j37SgqUwaV8vt+f+xnP/vZ315rve9617v2z2dczWzn
slisOHr9/z69L2JTNlcAgzLnlYkHGIiueJyvmNoGkY1Xh7kcAkODZFVz8LHV
084seREDXVlJE9WwDrCdD6mv+0Dw0BxaCZvaoNcxnP8zfW4Wk6vv08tF4pz4
n0zOEOj7u5WI6NdCuXT0mMCLQO/izrxFfAFueRRdkxJnUE7SC37o5CL5VG3F
f/EEChK/zzNPuQ/xRl5RiBVB1VPZvlKVRiS2LH5bEUZwoP39VZd/G2AZprVV
JYSgs+az8pfCfxC8cdWEti4Dno9GVftoBYTx9lGKTgTXA+76aiU/BPvztx79
0wQSejerP+R1Q8i0ORgpM/BrspCTiilAqJuWzIw1QWzTkzRlpVpsMLzN3nOZ
YGPvy6rlxrV4mZm29NElgjAlC9ntd2pwOPui0k5vgl2DsxeNg5pQXay/Z/IW
rWeEmXE+woNl6p7+2WqC2sGggyVvK1G/955/oTNBSbxlsYxdOn5Yvio+huKr
znLoPTtVBqufeoUtLgSBgm0xsyYcqDk66XsmEATJ93CTdwvw9uT8+DVvCH5s
TxwSdeDBZaokqLCOQEQjzz7XoAcijisTH5QxcJg9NlJRVQSWuKIRY0dgbJK3
+VVKD9bW7pXiCBjwm7f5l9rX4sHz4n/ZlL8B+B7R9H8Mwz8kUvfRfj2PMTXc
GN0JPaOn24+uZXBgZ8MCt9Y2eOe432jiEgQcX55tqkzxFgZ8FKX1jWh/fW7i
xYeV38AJ3zLav3YJZanUWgSVbIlk+VF8C76erPR9CNmDorZrKP/Nd9N0bnp0
wG3ZBvUjMgyyp9mSFepCOFVv2RulwCDObYGolAgP3xUC736i+MpZj5xSB9qg
dKP+v9lugvwbec979R9jIjTT4iuNJ3SQnrf8jRDT0ooy880ZyDjEuxhOvMB0
9kHjJkeC3U05moFJNbAwyxHf4knzj7P/LNXtw8IlYrcNPzJgle+7oMxJR2ya
wbxk2o86LeGTg9KVcBF9FrbsPAGryTG+ZWUnnJojwyulGUzPTyncwElBWsL+
Feb0/FuxzJtzIjtwaoPjrt1D9HsNzvDMWD1GhrpNo/wJHuQnuquocFEGjll2
NMESzyO9ytY9iDozsvh4BQNFXe2mpMw6RCw9nZwbRFCcmMRaZ9wFa/6aC72x
DMKm5CUWvRLCruk3tpUog/Ht/ceen3yItJ9+TQih+BvXBHCMUspR/eDp2jGq
ryhTm+iv+UIEnIvtTj/PIG1GS/HXsx0gjxvP35shiA4fFR33Tse6T4vDLGn9
kl5SF9TU+djbbeUetYRBRIbmedWtL5ClpfjpF8qf8uhvSg69fIwNH5L1l2PA
PvNFcQ54GJyV842uIjgcs+5Pl5R/MO/yHlOdAspPk4zU4P0i3M0svOZF9Wdj
KzrFu8jB0OqQSMU4Al3O4JzIbA66Ct7sFo+ieB3YLLmMVhxdek6T+4rAz2XF
K/FndZC8XMs7TueNdff7pFLoaUyypJ9qWhKY+/W3KuV0Q/59RV6mNwPVP1Ki
usx40P3I7RhOJrBa4lmwsigdAXWab69QfDV/9n/e6tmHUv3vN/LXv4aH2VTw
p9hqIKMleeACxffIZ9hGoh4yqxL1Bum8/+hxr8F94h9YRtRdLyMMohQKlizU
5SJwx19vxJOovh3US4uHOuF35yT74koG1fvSLS44PMT4+NHwQtqPEfvMq+Uv
ciHpbvTOn/qJQs/6dsUgITyDfzdVv0TjjRZYRU3n4bigwyqGvn+/Scn/+hUB
fLvYMQd3MJh5YzzDMWxEkv2J81VUrx4/phu5HRHAWsv2cpoqg26zMIcnkrWI
Wfhl5YcrBEUiNqe8XBrwQHVcdJSeX1xdPOt+vgtZ7624R+4yEAtN9ygKfwn+
2ddd1akECUGT61Q+t6Jf9z7bdYxgc1er+r2FdWB5FPl4uhLss/DKtpH9G782
qFUaP6Z877Wu71rAx/oDSpv+ek7gsGzKsa+0Fhk/I92N8pcm2RS762UHbqXF
m1WMEvCye4xD1cuQEX44TY3qx6PyjKvrPD52tkhkszsJjgYafrxzpx123exh
MYbg421tEw22gPqHYYyOJtXrUGPbnR0l0Jn9QyPrHMFQdU/bWrUKjMnzMyNo
vNy83vfWET0QpqrMSzjHYP4UZnyi28B6YduY+IngF1WOtYFxHha5qqR4UX79
7Kok31sKUTJ4S/OKKfWH4fomWeVaeB5b8S6c6qs5WBDD93sJ3bjwhMn71G/q
BlJXveZBPuWRVHIuAX+/tOkC0344ZYvvXPuN+mfGjPZZsXrk6vk+UgsmmF5R
NbpBOh/m4rZ2x2i+19yeSTObdmjPnJsd76P7j/Plg9KGVqyer9wCyne11swz
J4kncNTevzqE+m1Jz67ik2F9eHVizaWxKQbed5oXXLHnQO5MDL+SzssvSzba
t6xrhYlen8/3UjrfUl7/Lu15BMXBuYefUr0FxEYPGzlfRXdY+YdddD5G+uQD
c3zzIRuQ5dxB61E+Hf1t7uN2TGlt1fTlEShej230bWnAO9NXtf4RtD81CvFK
hIM4H06KQhbBssPSWxLLOViUflPnIs0facu5IsJuww7/uAvedJ+xErfstzC6
hJH5iRM6NN8u/R0TER0N4O5JOrqC+v13782GqfJcLAxw/WJwm2CMXV+XZNCM
/dfyN4XQ/VDU0phRENqEQJ3tVn/T+efGyQdrWHVD7J2a1DNLBjkvNDNmJmrw
1r9l2IbGM77q2X7ArQRRnPEvxxwIZFK1Jr0L2hF1yU3LrpfqzeKQ1P7ol1gf
pHnQm8YTLvL0affh4cYYuTacTvlylpJfKNuImu98JjmU1hOfsv5BqQA826JT
9SIMhKID7l4zHVitn7a+cg6D39m/Tff39qEga8RF7h0D5artwd/uNcLFKao4
g/6fCOxzBkKIAHMj/WI/bmOwTUP0vxMVvUjvDLquY0z9r8T9mce1Jzi0eW35
CO3P/wBA7MBn
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c4lf8fxpFRklUJJaOoREmhvuKOJF+VlVBfmmQklFXJCMkKWQlJUiRl
y8jes+PYI+Oc5xyy0pIifs/vr3Od63quz/W8n8993+/XLXnZ0ciKjYWF5Twr
C8v/f9V/phjXZHfAImU67af5OI4E+fm7TCVgtV5U94I1gXzBPYFvFZpxe593
PT+dgWvVasLH7Wphf/dqeRYrgZaNgmXzw33IkmrTaJPqBctM3yNN8Wa8nHx9
b08QDXz/jtw7vr0XwcmOQ8LuNKTrxFxZ3NwM3d5dimKydEw+/PJ+QZIK5qDa
x9a9dEyYMv4xv/ARd0eFZ19uZGLoyw0V+ep2iOSZXpQ/QcdOwfS/YTxdUPUO
F39qOIgN+oJm4xmNkMir3l4eRcfBSFe+hox+JEsIQNiJDsL7P+61SxFw1KAE
tF4mcFBTWY+3sgAu5/Oevq+gI/2c6v0EejMK3y9oFIjSkJswYvW2tBzbrfiS
6AQdLAmblKYfeWN5OmdI6QoBOY6ay8WdJTA+1h8qKkMglOdTB224Entsd+nr
NtJhxr74SMDpBdy06I2hNgQWTiXoty6VoHq1NN3zDgHK+t0vuHxrwX86/Zfv
KIEDr+xuaLM3Y7Wf4NtV3gTK1lg5sF5owaU4frGGQ3RIuPnPcV6oRYuS37WU
RAYSF3ukiV0FEDzuXlI8T54vpaXHG5iO9O3eOw1PEohgfa5r86gT3Dv6T93+
QMD3jGeK+DAV1L/WI40cNBx5bR/wdF8DJI4FGf82IaAZxSrvbFCNiGGFCLZM
8vncf/Rqlvqg/qHG1f3hBHYxJ+o9NAYgft1hcqcSAZa5Avux77YQqqUf23KB
gET4F1fVs93wUNE381ozAVdPpdHZO13QanBNdVzFxNk3uZR6p17cLIs+Pxz9
GfuZuy3ecFDhuFLx+VsuDaOjjzfP5SdB5/70Zr+9BDbEqD05YzIAfoeSg4/r
CBwpzg9VjG+HT3dHyWk2Biozi259782ErzHrkQVHAhcPzZzMeZGFDInXuV//
JUAz/nWMzb8Tq7aV/qRtYmB1ebt02613sKp29qBN0PEnvbYysLcL3E8MOVUq
mFiIdROW92xHvZj0wfwOJlgOmB6QdM4B2+eH+TWrCSw9TeNN1E9DxtUWg0/a
BA7HeXFN7eyAloTwPVMzOubSL635s1SAnWND3tEXCXhx8AtsZgxC6um6G/wq
IxjaXJg0l1+OPrsZkWhlBowH1r/rU++B2Pjma5tnCOxhGLJHCDQgIWFzCtsW
JiKeSn+10ihBV+GrnBUNAoVsyXDR7sadYqFdbaQ+JIZfJHsXJ0DcsqBEwopA
R5zMGq7wKpy2s6et+kOH9aVrI0dnWyDq+NXOtXYMPC1n9kSZDOFR3CGRt5+n
0BVZNm0b2QrLXcIaxvIE+n6V1f9aXw3ekj8pMjsIpPAnbL+/UAPJlSIJvQYC
Tq6Bdo/j32Ou5og95R6BLbPlH05cyYCL1FyHuQGB7FVcSjEBn3Bii31gTyET
tgPiUt7ePWjqkJymthGY+NXSJeDUiFu76/KtTzPQJ/d5S1FOEW7qhNA35ZN6
uqpoGLjaEzYrl7KFyO/nJDqXuudcP2RC9qXf1RiHnMGSfXp6NgwfS8cIDxGY
vjItn27bj5LErBmOFQaSC7hNtyRTMbZ/ef2dkzTs9jR62X62FzrOXIsbhJig
WAdMLy29Rax+yreN4QQq+QR3+wtFQCkr510DqV+b6UQunqUWWK/QZGK6GPA/
lSQbx96J/NOmnqUtdNyq27dZVrsTVlm/d5Q+IKDwYeJKxXIaqC72rFxnSP2N
Xis9saEV00ntds/z6cicpe/8rdGPZ6W97JxlE1jiNi10+9CC0Z71UwsvxnC4
bdT533tD4KLkK2WuHULfFFEQPkfFYQ3NYpbrNGy3sCncJZKLRckHIoW8BNiG
d7cPehTheE5wOy2MAN3J1CdhqB/FbwrjAo7Rkc+ftqIm04H5VIOz/X40RATn
q409eoEqrVcba0wJGO3ysROn9kDqgchNQX4a2DdqObymlSLNsuH0FV8CyhS7
C8nO3VD+xmlmeZSOHxmzFdzamdCwMDq+w530X/XruPbC1+CUvL42x5JA8CkO
8TP+3Zh1T4t4WjECfyWdnc/vDqF6u+zv5gI6KIyGA5H1vVBh35SirMokv5e7
caSPK56426rssiDgs+FPY09kDlptjJz7/iHwYflAmRN3FhRyK/YPaBFIolyW
3q3XAQEJwZ78YvJ9Nr3+tcmvEsw1nHKfqXQ4+ab99I99iUCHD/tvk/fHsnu+
QmmrG3gbOgKESf1EmBZVhZ5swpbBjLlHdxiw5rt+5T/nWqQWaF+xF2Jge6g0
47tCK/aw6r0N9mZAeCozmiWyHpWa/EJ25qSfWeont9qm45bo4748M/L81Ecv
Qm0+oPbspojAXALLrN0RjiI9sItO2cEMGYPw1YE2y4QuFCwpqlwwpeGWYr1p
4q4uxAw+/GgoO47K+8a7v5qnI0LYN+vadQLVl8X2G+r245892kGNlybh1ldi
uVw1CH+rbJNltQFYB205WJLbje0PVBPuHGRAKKBJxmemCgvmvdE3OEn90wPe
Gf5uBO+BjdL+Hgz88PaSDTuRCX4zbhmLmwTaWexXxhJacdbtZuXJAjIvvVd+
JkW+hVPJGqcN5D6XPf3IOvVKI9if3jqk1jwG0akJhfuBjSjlSDXn02VCjOcC
zYFnCC5Rr8UyQhhg2Z8x+7LqMZJct1k0kH4XfHrpHHtWN4ymHW7/tqBBYZA/
SGZ1A4wCLe4kx9DxoXH4Zl5iGyKstE2TJxloLrufXD1FweqCA2f1yffJruZR
NbyWh1MN78p02gmkW2ZoVp+oR7lcumBBLA0OwQm/91qSepWiJeTcHyV9v0Z0
kVEFifVpC28ek/mZlBO4Lb4DIdsuL7jWMTCpp3l060gvUvZbK28+yoBht5Xz
ykInBE8+tlc6O4h/a5veCdj0weauos90LhMfjEJrqkm/tdHyY93P0cH/0k/3
SdZHxGeUWKQ7DiNO4K2uvH4XGqV8BpZ46JASX7Uky9WB+OOCyTWVTJzoszJ4
qT8M9uOvZrPNRsF/nV+p8HU35DPKU3fuGMdUjZK6wMAAkm+bqB5m0GCp+rdz
bzsVEioqQ+f3fgZ7QvK7KbUmHJDZlCbvzMBliirvLUMqyTOH+PdSCTQYab/B
827oa6n1HvQgeUhSLLkuqxlS1/27brAyMRrrkdBklIBlCwkNKRAw1xAeitzT
i9gaKSFKMLm/BHo23JROwf30v3LZD0l/uY5HsBg24XSsv/MKySfCHn1170Mo
0JsLYr9B5js7c1azXZT0a7lWIP+xCVA8T8lzKA8g/EzWjUZtJubara3vHPmI
xUPOYUP5NLBka6TK2GTiyXzb+D0FAsVXG/ad4ewAn8emoGB2As91tIRz3lDR
yXnoMVvGCIQ25LtVvBrCzlTtYwPig7g1yxnA+7kLhzNex6SRfGg5c3NHTWc9
/viFrhNTYCCiv/TwN90q9CR1egU3EYitIxZ0EppAvTGv5iFMICBr2+5DtVRM
6j8lTrdMoDKxwpWzuBH/9QyZzK2no+vu8snR+9WgprJlNveT89KSBbaxNMH4
VsyIZw0DmrsVxhYqa7HbTDFB8QMTxnm/eVLe1WH1k7W9OutJnvK35lUw6IC7
Wi3eGzGw98DFuqbnLbDdKxR+M46GVGG91WF2bZgaPr2S6U2DTR37lZwjuWju
zOl7N0jAgClf6ru/DYXlLhQVGhOKv4Kn5ILqMPeGxsNtyYTWGcFtygO9kHgw
s2Ej6QcFjXy+38ZdyGCfrPWuJfNIZuIq9UoTakqCOGLmmOAUl4d8VgfKf2jq
7jUbQ/ZcmKijWQ1OFp6d/3Kc5EkW7WMXrxXgKLfe3zlZMq8pbDxT5/wAjlLJ
jWRes/fQDPM9G6F7k8HTMELmU/2TG3jSAROGd7YHuU+pzMcPpmwLwJ3K+oCL
zOei24Pxy5XvUe3QnlBvR+DnuiiHuJdU/Bhrbp50YGBA9Jp87fcuhOkPL9vl
M1FZ5dqw9tAH0OJZ08s7CWy0kFIurO7A6oyo0HGxcfi+r9OS5wuCe4/ZjlqS
V5IjfX618ZRDWTIkuu8LHQaxBjSbL31obFoW6XKg4XxI8+Uzt6gwt2NGCXrR
IBwksu+HWjn8lw32LpYS+N7pcuSNbCX4rJlx1DSSv7+X36bEl2LS+sJvgRtk
/v+82nOhh4I2M6Wxr500nJ4lmmeauuActjOYI5uO1phI73cutdDZVX9FfYKB
FA9ZkYVvfSildTOvyIzjau/fyQ6RbtyLXjb+GDyOhTyhxX3muSBehkklPSP3
/Ttd1kslGUhvzM8IlyRwV2M4Y58tFd6CK02/XtCwrKFiYVfaiuW1K296RSbQ
17nDbKigHKrWcrQAOToUnnDFftR7DuGjvI0F5P0tHMxRec3eBJfkRg71bga8
lG4kuse1wjRYwfPRKlIf80dqbxzPBc+hw5Wi5D6urKl60+BXga28XzXVWghw
vPwh+GNjD/jOFLyIbBnFco7ZAvepDmivv3pe35OApbKaVa9zP7bn2VqWbWWg
s0ti7bIOBWMs9IuvjjNhvl/Ytds5H6OCG8KXIgj8PpOYKurVCYew6zldr8Yw
2h6k153agoD3A+vfJjHx9udOxVaPPnzQvMzksR8Cc/VSjNitOsTH64oIficQ
SUkxYTnYC7k6iV2V1eMwMznLLfy1CCKU+eXYegI1GX5puwQ+gU+ntZLnC7k/
G1R92q9Twft3/Z0Z8r7lKtJj7VirECYerTNeRod9rqgFxZ/0otazIMolBiSV
nlQmCA/hWYbdjtO/x/DmSNKWdtkKqN6FeTjJd15/t7ayKNfAKqLl2/7bdGzK
DNEXb2hBkITYQ98HdChuz605dL0LD77VX6bbMLF/56drLGI9yD7iZk1Vn0Bo
1JUKm9QCmORqeXOHErjp0HiCL68PV81jWFtJvnN5P35Jc64OmqPWfjWfyX0n
nawQ79AHFx9PEQd/BngOcPV4hvVhcq0NJVFxEuFyx03140i/hD6jPm5kIK5f
lz10qAi5P+cWOJ8SUFn7Mf20VCOE81TPqo6SflhwcFG6UQxRVuXZa9N06HoH
H8hX7ETUUswmSbtRTOboxdSU1aNWSd7/N0FgTvZ7dexKGcnx5XpxjaQ+lC/4
/bKJBv8XXXIZEmh0NfMTMy/Gee2/vTMnCLhkqHc7jVZjzSo2R3E1kq8YT3M9
aJ348U0tyGqe7LvRFyXnb5zAfObraCmSr972ejofflCN8vMl9q7SBNTszVxX
sXXim2/hVaG/BNwzt06POnXgus7IQ/08Gj6s2/vA26oM/g5LazcaM/CgKupr
/mkq8v7LGzR5RwMPe1A6c7YYHeHVTC5yH33zTqHVxrZBXbDt0u02Gpg8/xXX
sFFwzk30+ZuRUSRv8r6jUdUBK9+L5bUmDGgbVCY/TepAhpwXu0/RGIa+PB5W
svyICcUEr36tcYya/CnauyYWAbVHBhrPkzw09z0/rImKktjMryFXx5AscEl7
W0Aezm0KP89K9nGfHOLI3DNnBNqo7eYln4/wHip2kq4Er5x0mboSHTrvknmD
EvvhOfJFcqqc9OuR9zNtX7sgP10XuSQ7BIoK/RbNvgDli2rRiz10qCVRJwOr
GuEXU501nMjEYa0d8dsvVmBetmLkizMBGUeZA/yvGtDDw/870Z0OXhuuY2kK
g8i+qD25KnwMERmZOXDvhuy17ZJr1/aiK/qM6p35InKOxs0eZJ9avc7A4jtn
Af7lvCHfR/5Xn5EQUXzQjhLdbnlRUq8XOSXUGVpVuLytV9jxOekf70jftEv1
MNr69QsjhQH2gQu0+uk+HDvnViVvwMRB4wsbH3fmQmirNV18MwFhncWgyNgc
zKq1xHJXkbzp9md+VV4jWGqpG1n2kft5IDnE60QXyoOck+PX0nEughkaL9iP
q658LXrp42Aptm+1MPqIvDe/FNxfkfn5N5tRc7MfvFtyflgd/ozglUdbmCR/
GEZpv5xjYeAPl8jUvvhe2NMe3F5iY+LVbDnD6TwFcU12+s7ryHmXUw4W/WwC
JelFYD3Z9/85tvnXsd9UDDpLbxG0GkOlgu/i2xVv2AT3Fs+Q95du5JpnMpqF
6iaTkNtuBMyYU/FSZ3sgpPpiL9NxAkIamm+jqJ34tY0W9l/IKBSWQx4QRqWY
Dnz+z1GyX08sev2bd2oAA9fXnDufOI7WwY3rwm0/ITZn69evCxNw8ir0yL5a
j8DzykeP+JL90uLmG9bqNvBw/Dmle4cGClW69VRWHdKbojhcK2mYq3y9R3td
Pq4Ttx/Hkfydvaf21JfN7fC6n8f9bYQJa78TnS2bOqGzrroobYqcZz1njXFH
IdLPxTVah5N9h6J+TZCzDhvHLhlyqJHzb+hl0Q7shs+fZ+KVZ0i9VBv4/swp
RFTfYpUF2c8Lm0XsFV98gnX/GZVfwZMomprexZ3dCb1oI5cacZK/77k/TBzq
AHuS3DkTZTr+mIv00ILSIaZ0fbr9MpkfB8NsN5S9h+SZdYcTQggERkZIKijn
YX7pk8u3aAImMwHOJ40GcK73XPysPNmn3HrbDZ+3wa253Da2aQwHKR2zJt1V
uDUSfIuD1LuAGjWpXHwAbNcFZ4xJPs0/KdpG6e0Dx/kS08awHrwqHPVxWd+A
OiO3TbpxTPzoscxl9X+Bb0lOz7bfJvup12fx4JlBdCo0aKWI0iCz+t7KKp9e
XHQYLrU3YSJRX2AL/d0AhK04hII/jaHKMbQzUDQfUtVxW+LJvshyjqNEW6gP
p3fXFwSqk/3YU/gf0Zwc5H7jfh1D8sjFVbbz0UJe6L4aEmlFzq/W+L30mkUf
Tj6x/li8MAh35s3XnLYNOLUst5RZSOaz+ovZJctoMAzpO8d1CHw1Fas4bFyG
pEBBz8UPpH8OBe89GlaEorin5Zo9ZF44GmQSLh34R5GFhzhLB9esj7ipdSGy
tqF1Qy+BuI7i/sNSqVAYz1SpJvubPEd53F3NdhwOi8269HEcXRzOZYcnmnGz
9sA1c3caJGZCRPX4SsErHfCKR588//ujyw5RVBBHnytnkPvSNuEAW8evBsjE
rKWpqdPxP69GD58=
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVns4VWkfValcIiE0JpcioppS+iK1kJKKitzJ5aMpE4VEUoPJZVQouUWR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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs4ldkbPbnUiAk1jhAdGpcudBqX1GBVSkKK1GkkZBRObl3QNCrTFZVo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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 87->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk41fkb1WIyRTEibUKypsXWTExHNUrIiGpUv0oIqSktCkm3IlsjhBRl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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k0lO8bxhFtFG3KUrRZKiIlJJdKSNZSJBH5SqQkSpGUkiWyFkqJ7GSX
rez7ZBv71ph5Z4ahDZWk/N7fX3Oec+a857mf+7qv63Nvtr164j8eLi4uK24u
rv//+qxy/U5cbEPdkPmViyvZkNS032ZoFQjb5C97XC4Q0MwRsVpXHgXvfReW
lJ0jIPXv7qIbzaV4/V1tYf1OAlzmEfvUFu3Fnoi+r7LWBCg53gznA01YLn47
JK2ZQONBxur721sxI+ekkwU6yjeOBn0hCsF+M3Rd+j8CugaDLYq3GvH4y5aP
O4cZKPd/u3SwuAO2PUyjtGomrlx+OX8mnoopPU23OCodumJSO5wU+6Ghc/VF
mSgb/kbmeoUOXfBONKD0RIyiU0T5kMSPPqB/Z1/tDTqi862UsgPf47EFa21S
JAPf9Rw5NUOdmKnZuoqynwUuqwI5C7/LeNJeq8e2IlAcvClN7Gc92qfTxSZS
COSkKJy1eNaCR95FqXsvEtgb5J1UI0dFU8EV3gbyLMxNvTDd1InHUypKUkfZ
kMqx3qJ8ugyTH+80KjcyUNnU1HtvOAscsYXZJY4EFrMMf9psrMfAkdVfZvsJ
JHtu/alfSMWkVrW8Yz0TauMPAu2fdMPq+u7o464EVotpnjZeaIf/lpkdhSEE
jFUd9umOJ6H6R1Sg2zXyvgv3M/bINMNG5Xm49lIGov0V1y+arAVjXV7Q4DcG
inneVdU0UpFeXGrzXxbZryQPuRfWLRDYKtSSqUpAZ0RCp/xaF0JSvFtLztDg
YzIoFVJ4E0rMbcrWZD+Jg+Hmy4fqoRmr7BvfzUCBZUREbUYDyhI5Cy7yTLgs
pSesNnyI9Ecu436kXtKvHzzwntmBbQHJLh18bHBzn6+hmAxiek0YONOjIPTf
icte/whuLZUDDP5ReH3gX6qypRnGNY3P8rvI+v6pnhS/VoEWj5iqQ1JMWJ3c
ZxV0mIKu8a3OCpUEJDva7b97NUP50q+CghUscNqMRWt/d+NxuUB6YCoD8fpi
a2+mpuOzkfK+5G0EBnaGc3GZdYI/8tB+pZAxCFm/ywzia0FY4uJbnq/ouHEm
7po0dy9E/IMFrjTT4HGE0Re9qAIh82lVa3UIrNy4KC7kcBeM1Obm13MxICM9
rbpbvAeCaw4raEfRkVP2VZapm4dBVwTbWRII5PwUNlOkIjLiPeebPBub7ERY
Xxnd2OX+6PzbxeT9ZyZ0du7sguN5/r9rqJ9gvPVkwj/1ItjN7fsb0kLgNy0o
fy1fLdoM5KrMzjAhXOK7QcOoC7L6fw85J7Hx4HOo0NeKWiz3kDCr3EdAfEz5
WcrXYXyxVN0WZs1C5M+4W1vMG9HFmZWt6GXA4chMFduQiuGNux1aj41ge1Rw
WvDefmy+5/srS4sNXR61yKNp9ci2pcd8IZjwUPWyfShCQYlIg787OQ+XuQuW
rLOph4ygcH68BAseFgENiv75CHZScsznIvB25GNSyUQ3QqcgbLaCwLaVR6SW
qXTB5VTnUxtBGnTNL5WOWOViS9+Hz8cyCLht7lAPCGzGwaeup5Q6GDj1QCYm
7i0Fy92urxc5xIRGa7zwV04lzq7aHLmVzcDYdAU91fMDosP5IsqGCHxTWBP/
QbIKvfEpRSd9CfxjEiX5Byox97JUY5x8P6PN1Bpe8WEcW7+2lpdvGGFWEjoE
bzPc/Gezw10ZsLtF/JAI74OM3+P+lPVMqFy8vrL3SiekEz1j+SZocNlmyv9c
rA7mkzei7XkJeDjtiXThewO9GwnbR8j549x188suakDCJ1Yt3ZqBeQ1YjyVS
ceK8799f5NnicLWed3gPLjZMvF5Ww4CQo4FmlR/Zr7077EfvM3Hxyiq+4H3D
4Mk917JxNx1aHfQhdmEubt7fEK6jQSC+JLtfzaAc88UCqpmk/8z0/Nl4oKQS
bguCS0rFCMgU8F5Lzx6E2gRvwK3jBPx2lXpOWXZA1qSoVEGLhjxLr6mMA/3I
S+/1Mi0hIKTZ4N7fkAXRryY37E4QeCy32cDxBxVSl1PntPYyIH4n6ecpnXLI
7z41YUtjoNlrwNKwOxTKEXKqFhZk/byXBCxiWuC0a0Vd/CkmxJdSbdpQDFq9
5+3NmQRozlZBB20/gEOd9GigEDjFU/3BvrUPk8dHfL2ODEMk6VDL0rcdeKE7
6iYhz0CvV72rZVAPDINu915qI/2f2BphkZ+PmuNBHrbkfRUviUqfKnsH0az5
r97kvDzNWtmznaxfLe3v8EMpAmUGR50OFneC00vZYahOIFajwDLUow72P1tu
D/GQ91VNV4kKKQOL9fpARD7ptwNQ1Gzqwv31KTy1wQy0T4RPbHlViLntAYYv
nhOgJ/zMLqG0Q29Owcglhwn1pETpJdQGPCjnNaN8p4OVGhNlFNVH6sL4Q/f5
MWjLNyhUyHQgJy04Q2kzE9r7XH+91m/H2tMjdcLk/PQcvrH5xa0ezKu73m7d
SH7/QELatel+vHWxYPV0jeH8yZVLQj61od7JTVAliA6fc6a2XwRz0L3ls/Rn
eXJ+rEI71F81QfuCzmOKNR2P/wj2bj5Wi1fveZ/USzKg5RO5YjZuGFfF9hgn
7ZyAwtmj39aaZ+H9Z0uRThkC9b+Tu2++o2Lxxn7/nZJ03D8oz6Pd1YslUvJl
S0m9f2FLmSU8HEHMjYIfbz+MwMneNHj/30q8vM7X9H4xE9tmcjNEjtZguZzC
3jtGBMp31Z0bSGtESb3bgn8umX9GA5IpTwbwbvf6OlYWG9vaNkU0fm0Cz69p
28ILdMhoPVRmvigHoWi/eTqV1MNUv4Tew07s/TlXKfmdiYyarOy3zV0o/3tJ
SlyXiR0xhdR4wy4odzbxGN4mcP7TsL5zTzS+XKBIhroQ+E/s4sSBFYN4NV8w
XMNHQK0tIM82thN7Ot3vUFoYkHOi/OI+3o+zIc9crENZUJ+JrnR1aYa6Smyi
UBITCncdNzxQzkB6za72TxtIv8QyP50qCryWP8i3vckAF+E1Kx3yFJHuD2zM
yXoDQ5mWB8UokBKdGHFYR/LP1kbTJY1ZqCxZH35CmcCgSkVV9f5hxI6O5U5k
saCSdH0yX/Md/nXtd5X9w0DI1kPfWRvJ+sSs09hXxsEWn5Wc5esF19E3UlvI
vLWzUYxo4G6B0uSnJWuWMWCaOPVyQKIVF+vMH+b1kHmi6ug9blMKWl8H5TbJ
R5SAZyPKL6moz2G/vLVAB5diRoDI5yzctu/KDyUIdI/46h+sHYBNSGF+rwkd
xjE5uotk+lHAXW0+ksLB9dLMVvvTVGRO1M+VFI3ixUfXjVmv8yG/T9z7K6l/
l8OKo75DBXgyrNe2yYmAz5bFZfq8eUir7PfT3UHmlYjGsYrwGsQdMajilSR5
YNUS/3HPQhifVduXQ/q5xfxZG8f3Xfi78grhmUj6q7vT0rfHEiHHYLO84gkI
uol+DzrWD6XtFpac7F48Y7qcyBiMhXdsdePZOwTeiHYKJF0dxIJwt6hn0ziE
LE/HtTg3gqNf0mZ/kvRPYS+BrTdjoKIYZ3DJnIDDc41uqk8Odh+2LA8UJuBf
lSy0U68bCtWCYVdbSb54ORR/nOTHA6tFfYzdR6FJl4iYEElA9HNT9T+kn6WZ
cF1wovTAXpP79UYNkh85ph0i9gUIMn7x4ao0WR93f6X6QguMVE3DbbJG8SZ3
dZhFeg3Up2GVcIbA8rvm2svM+sHpG71ijnHIvMhMd0ipwL9Kid8rgxiY6S0g
5sZSofB0zWuZRwQUWJZmmoU5OGfakZ5yncDJJydy1bcPQLzZOaZTk4auTpWi
L6MVuJyXcrFCk+QnU4kfM+4VyOH00X7HknnnlyIaNk3BUFUO12IyD3Nmw5XD
Uvtx/EkSVX4Vqee3PsO35qvgKBEbcnUPgZE820KmdRdsulpt7pN5EP9C2mm3
/Aj2mEUGyhA0zM+lq4W8q4eJh89MtCepb/uvcaU9Ofj8V/O47FMyf3gexWQI
N+NZQm5ou/0oNoybpLrSquBT8j7OnOzvGJ+OYssxCi5Pyq3RO0jH6l2W7jd8
+hB+YE6xwG4CPgUijU2b2yHrrXUgz4HkiQdZ98dvdMPlREz9PzUWou/xOmmp
VEN/Zs1qwzYGbv943X6sjoqoifOza9RZIDyrlJJFhtFjavc+heQpU/l0Gwez
eqgLLGmRayTQbufh+WNbJjTaj3usiyTzY1686OnZVhwuSLWpfcnErhaeosuL
SV7ztg7SJt9z6TD/HKf6HdQDPeQ4SQTOTdJuevP1YZYWSKsPYaOW23F+8k89
5hq0HM4tIbDLylNs/d0BhPBcuzxsQIO3yiFhqwsjSNRebfswchzFa9z0+Dbl
wdLZbc7OgPQL2U/sS4x6tDVbH7RaSvab5uXh2VCKtuTjfym8TEQvnueN3laA
b9uXsHRUCFQ4W41tONSOf2qm1xzSSX5fUaMvr/QRestMTqox6FguuFFWfVEu
7t1SWpY/RfL2ov+MKL29OPm8kMh+z8Ttw5Xb2qh9aPWLTzH4+gk/TT08erK6
0TWaGFZ4dQzJ+8+nGUz3QcFKay3bkOQt/sOcKNlIFFS4u6eS+0ptRMnQwz+t
GP1zqOyPEhMzOx/XJVg24VOKkk1fGoHmM7zClIRBaElci9x6h+TNWfeiFTwd
UG3hLQ7cz4bmimHLjIt5KBWo0MiYIOBtEGxut2kAT1oqLq/MYcO8z/zc+4/F
EB86OWVB+u3Ux+dh0meqIXxW7vCnWgLy8rHfGh/XQZJ3Taz4IdLvTzjGHDuV
BZNNpQMqJM+qCSYMxT0thRDncFDGZQL3Q91mE3/1of6mX7IvOY9cUldtd4+7
4+G6tKfLbci8219776RKE3ZobDTNK2Sg3veFsvrxPgT4ndF4+Z4FyWvLnSPu
tuF6tAuFNkXmgxCNrf2uFvKxR8xdY5nYojAd82xHJ0LoEkFuMSQvTbW+YmVk
YWoNv8pVcl+raqeEKz7oQ2CaymD7BTYauYTlwN+Dh7JNN69Pk//v81y5RrIX
opr+GUWLaKQvj/rH2FMx4ujWERdMA+G4uDMzuAu7xrjyRXcw4HZBlT/7UB/O
qbuc22M2Btr0x4rBnH7kyM+YnNYbg8Iz3kn/Yy2Y+xJlOxVA8lWa/1kq8Q5z
uas+zJL+QUnMS/+t3IY3QWKT243JfeeeoUr5yTKcd1t1opF8v9eVyccvbqDi
tEUQ1aWaDdvGU28ZEe3g4pXu66hj4Oolx1WDH9/BUelD/nXSDwezV+za842K
ZOU41bMf6fgX8oyf4CX9Y1nL9n9PyH7Ra0Wyoppx1PtQwYEmkrfEBZ70hrTA
QTYz0+oRHZWr/fbWReWAQp+7UutHYEURy6pauBeTkgvVVnl0jIlsCiyuaUF5
1srUi9V00FpGX36ei4GnYbJFrgnp59uPuXPu5CCW/Xm+ez+B9XVxU/esBxGQ
/UrUWnMUutLP8eRPD4Kdl0qMnmFAtKkqv1OlEPcOK65KNSbzar0ONduKip6l
P6puUEZh7d1jzcnsha7vXZljveT+3rD45L7kIajfN+n6c5gJudcCTWayHbCY
jPmpVc/C9YrkioUdQ3A4XfpAMJmNkN33VEd620DdvHDjiByBKx3iTnNkvu4U
GRA6vYiDOxLSSh0Lg/B2MzshLTQOyd3Gb4y5B5Dg/uZgWgETDq/bYtVkKGjN
HbQPm2dhcYO9+NHqLrxq6tf4fJdB7q3aDZMLPUjobX7Q+JuAytsIUa8t3SgX
aTun7UPmsbzbGunEJpzO7B8wHGGhvSr5Erd4Ac6oCQUbkfvYek1+ru/3+yG5
X9HWk9Tv3+kIZZXQIay2dTv6IY0BCpfBwt4r1bh4/rTErw1MvNm5y8ZHpA5T
My/ZDzSZ0Ey/c1N4w0PwiN9+Mkzu95p3I6wD6n3xQ2nmywx5VklzdlRuaIam
XQZV+wgLPg6hq/drp6Mob7unCcl/XJe+pfVs9kV23IqCVPI+AimFBxKoyeAy
LFmi605g7MhGKweSxzd1Sr1bpMrE3ipRLj/fBtyoeur3jELqX5qQy2uvxIzS
vcK1pJ4kd/e7C35OxOXg5p0vLhDoyrlz447pewz2HW7dKkAgeEB8SJ2/H4YO
i/7u+0pDpJOiR+SjPqzetHix3zYyXzwzvUe6i9A8IZawoZ0BbZEz5y4rVEG3
M35wkT+BvteqdivEsuBxtHu5EMlvmXYbdnMZ5ILnR0lRqwTJYzJy2QfGqvDv
JDvx3xcCqbYCkyU8ZdhSxNJ4Ruar/SvD9H2fhpHcZrJN1ZmJj8nuat8Eu1FU
Vr2r8BsLboUyMomcYZx+m+O0v4mD+/ZaZoyWXtR1iPCtch2BAlGrWB/VjdoF
pc4nURzE+wo3TteVwHDvaNIcuc91OH5Sq5Xox0zSIX3BGRaKbXxTZi/3Ivm3
VpAYbRQlnXkPPv1ugidF1Ow1qf8MH6usvxN1eKy94pH5NB2fbbb+fJnegLdZ
9L/saAZUrHellF4tQfHczeD/DpL1DQyF9ZYNQj2lw8kimoalwnM85nXlOH2e
GpChwkRJo2rpznvNUOKXDNsZRO5L/FrG55/3IM+/cN20/iC4zIt3zYfV4G6U
0Zf+WZLXjLvvvTeoRngXn86QAwN7pFc471fsQFRHcuR7Gh2h7N7b5/3zoacb
ZKg4QOBdctuXMU4broWKbgifIf0siprjp0jFwe5ldjH+pD8cEhpXzq1CV3R9
/J7nDJi7uy07l1iMHWN1UpnjZB4H6VLfrOuHxUvNxskNpP9aS565LtCKo6ID
k0HkvnNzqUOHdWkn0HJx34u/TIw4ywlMrRiCpN3jTs9cBhKE191x4u+C3+vn
wh1eoyjvvmdXYVSNHVLCswEeTJw0vGjHuVyNgmvVxTeDCVSfC0uoP9+LJ1iU
rS87Arrk/aKf67uhVx94qf0CDTNNjbY8pF9aS71aXdBH5ndKgltKfB7uMvS3
S1wjYLzuxedbEt1otAsvIWkG5gqJz74/JPldjU+efnsEtu1re3SeVZM+WCG0
ppVA5Jz53G6hLrT1ptwdeUGD/+b8rH+SAzBaa1lcnjOM1BAvtQipXKx2fWUW
qk/yxS2HKzZLhqAcwOFuO0vep6/N+YxXG6qt4/xcvdhQ8ftjK3y6Dkkmwnfz
7tPxP7ltCWw=
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx2+SNMky4deobKUSbpKUrY9IKEqrVIYWStOkXxOjn90gNUO6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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs41NkfnrVKG7XKtWJL7U40UYrKJa/kkqgkG7qxyNpY9CuZctsuKAqp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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 88->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4VekblS5IxUT1U4QyimZQ0U+JpWhSSSIqESMSijNShEo3B4MZl6jo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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8lN0bxilvaZMkqWRL2mRpI6nLnurNEiolhEq9WYooES2ECJEolShb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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81HkXxz2upbIjcqlIKiSLtpQsfWgVSRuJTWHlLhQ1idVjU2rto31S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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk8lWkbPhVROUYxkt2xfKQaTbYiF9qMpU/IZJSdtOEzvoqhpAalhEIp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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 89->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns41VkbPYO+oWFKNySFzEwoRCOTzBIzZlCmTE36RO5FFEOSpNuIKFI0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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8lO3/xSWl4pFSUkkIxbfFEhVyhLR5bEnxiAipJJQ1ClkjZY0WSZGy
y1bIvg/GDDO2xMw9Y61UQqX87t9f85rXvOa6r/u6Pud9zpGyu2rqwMvDw2O9
hIfn/z8P+OcY8J/uRr7bj3W+F0cQMEQI9zKcoT+UG7XbhoDiniWRzn3dcBJS
VrK05MJu10DlBpdm3EuxVc2aYOPDXx3WWb0BLDdj+lB3cbHg4j4eaNgFhqyn
43VeLnZIKrws2MQAtV/ySFEMG0v3uR5ft5OKP9LP7w7tITC0aUnjsAkdEm1U
AScZNqS1Ln4+UUHHAaZvoHzSR3QmRizMgI59SjzDf4W58Msd0JgMbkRX7HrB
lhIWijIdzE9WM9FydtnFK8Vs3N/YECSeXIKA5mVWik8I+J3bqLLDpwka2wrs
TCLZcFXtEjWnMrG4dtus4RkutJld3HepwRCkKRR2WBLoqM6vi6RRwHoU4K2z
lEDLKQ3zyIVuKDedVVe+MQLBhQtJ0c96oXe/sfCfajau110ooz+rg+YAa2ty
LYH7ZRC9sYqJVgfTG+WxH3B/fwyzaq4ItkVb1no1sJFq8ZbbIv0OJ30fnTj2
iYAT5aOflcUr3IxJMrK6QMCM33qjrhEdZkoNWVF6bBStHJ1kpHbjqIC8QAy5
/rxooF64SBPU+BoHlu8jsE3292s960FELY5szSzmgCsQcItfnIplZo+VnHoJ
WPUl3tI6WI82I/P4G2lsnLFlh+wWr0XAwIieyjEOKIqKLwbb8vHjQb3SUDC5
/m2Pi1kCtdBeRpcf0+TinN3HkGavR+gONg2LO0fAJWxHylhgC6LLN884ixKg
Xkgs6dmSj6SHTdZPxQhEa7PmzsV1IdBa279gkIukpT0SJ1UYyDx29abzFS7y
C7t3W3l2wPiJeI7dWxai7z6RN1xOh3PMG4/Jg+R3heam4IxuJMnYal2oHIbk
svMSP8ta0V/anVTxkoPh9Obj4y4PobAYsWHck8Cw5u3HAaYZCOX3V+1OI/A+
dm7n00+l4Ks27Iu9y4bx/eLdTf10/CmSqxWdG4XWQPnPysP1kLQ96nC/iDy/
LcYHxl1pyCkUu/7gKwdNmyq+hm3tw7A+r9Yiexivjw8Wugow8WnlyfNv9Lmw
LyuvsOYdhMz+yazFU6P4tFMwufl4F25mep7SlGMhgDZPtfFJwDeV6851LgTM
k9T6alIY0LrTGq7xcBhBgpeVFjfQcOfMd/5OQy4+TcU6CdR/AEN3fsvfySEc
Vo5TFHWg4eA/zfZSBwk4/yoy+f6qGpNruCNUTQ56Z7sCbqVUI/ePlqpKFwcG
+nXftnkwkGuf3Rv3h4PHwW7eA6DBRetGFD2Ojd5/VP7uPVyITenm1c8aCIy5
OZ9fPE3DWr3FzQtvueCJ6FXt/m4JimHZbJ01gfCRNnrwlh5827pn64oONsSD
KmW/K+VgfjahscOKAN8Oeavvci3YkecpEmdKkPOk4/HLrwbVr/oJgzk2hlOV
BtedKIDZUdbilWUEUuf1i1vbUpFCE7FLjyYQoKBZ/FK4Dzfddce8RSexf2XB
poDoLmxgbUy/ZsOBj/iOAA0ZCn5N1/IN3eZA/OTJSVffXkg+u704203+v/dL
YkB+NVq6K+pcrThQjHp4b6DmMZidhICnLYGJNq2CQZmP4I0YnK3wnMD6yf3+
81/oyE2NdnBQ5CJ5ISUjVISGCo/jNv8EjGJ6lKtjJJkDS7p5/MMrpP7Wl4bx
tNQhkXcBZ005kPxzUphzLAghXkzqzosEHsb8zv9cVovHFj3h05EcdGdfTm/b
yUBswOZtiyJs6IkkfNYlBlAZlx+j4f8RU1m3s1ekNWMdtcRvgDw/no5lpd/2
3IaV9TTH5DzJ17VHerZIVGDiZEO+zG8C0/dcRTa2F+Je+hn763YEdnTnjH5a
TIfwKffxNW4EGuW2BJwPouGtmMebmaIR3P97VurX71L0tSge+ELOywTvQ78s
5xakrM6cCD1N8jc5hXnOqhXx1h919d04yLqQKh2gRgV02udN947C27GuSP9A
CVwWwwL1Utn4vL+ZaczqR3yo0JvLazlo86wPEuR+gGrRzQWJWAKeayJEj+yh
QmHVoXk/bTbUI1gLe1UZkBbXibuswkI939U4heddmPouJigrzoH7Xpt0Pu8u
dDMfpN+KZYPyMMjm+k0mQkVvTOsmctDsa+aRtb4Ud7bvzrzgTuBF+XqLFwY0
nLNNFOo0Z4M6JCHtd7gYH/na1wqAQPyPTBPfCyWob5xWtvQjee1z1/+H3SBC
31dxRZMm4PwsOaT5Kg20H2oXg1aR82lomvZTtRwLge53lqST8y109NDpuAIw
bGbln3WxcZk6ZN7xtxdHHWZ2OR4heZLXtFhXnohdP5VyDpD34308lY//Qi0o
U31y6hEk/wpmfn7Zlo0CP3/DPguSr7LTMuG7kuDa0GlIkPczv74hMGd1N7r/
xv11+DoKe7SPzf0txUD21Ty1QQLjuWcN5ieo2J5xfemTbJI/u3wK2hO7MO9h
9ffrdRb80veK+r8aANRUvVaks5BpoOgSG1OHiG0DSePqHBizs26Kve9GmkZr
utwoF+qPxVW0bSnYnxKhNbGeg8L+kwd/KzfDPV3n9xd9Dp5Pudz6x+oDhhfj
PSgCY4g07Ns8/JMBeweBpmVCHOwUj6JM2NHgq7ZyJ4Oct56Wmfy/B/sxJ6JM
ge8oNlpmJVlu7UCYpWpkriDJi3fecoumwSjz2R6gS/qltsbMstIHXfii9GXN
jwXSXyO945dW5qPG4XuqbTjpb4bqbyYEGXixhP6hj5w/Ou1YuLn0B7zYY/HK
4+UoZP7LjvXgr4PqPrU90fwc0IIybtfNMWEcY6Vcm8EB35Vzq2LPdkNU+gbv
VtoINh0y0akqZCBcxaXPK5aL3BKrapGyfqw6OkAwH01hykJES7GgBidFPkQb
e7OwU80r6E1cMYY6f7RIHSD1pSTX+VnsFZZlRbjsJvk8bdvGu+pVCRLv+B55
p0BA0nqg88TWXkx+zVL8eWAMQ3sy9Ve4MLFp6ZtGufkR2Ktxp1LT6nDezSnS
XpaN7id3idYrNJirVQtnB31A2QCl0mI3DcOMT08NM1l4/DHni/d4C/xePzJ9
SfI7wihdNVdjAOtY78Ne/2Fh/6N6D/l1VNg20gzd4jlgTPmsEHJmgmIwWyMb
MooxAef+Mq86TCbodvR6sGCvEjRzu6wCn0t9t5wh/VebGqIvm5eIlojz8/bG
BAhjfRPtG1T4OCmnuZG8PDNwwd0stAfNh3MLZfM4sLf4rPTChopNGb+e3jrA
xl17PUdbXjqeD4Z/4zQSkEjY5cyIocNxqzs7p5kD7S1m7634X+BJe13mDJkP
AmyVlx/U98PNME2KKnn/sciQ+rm9CKxt8fG0P2y8Tk0bPPhfD6w2jdmYD43B
Yne752R4Mais1u1eNQQyf/2MiqL0gHf7S/6wZC6ELG/oLpXvQdT+88F7+cj9
8p6+uvNaIbgx/PctWkl9PQxblJzqwfTVmuaJb2PgueakkizYCil7vsAL21n4
1z+9UlxuEEqsCVf77AkQuvduX8ouh51YwCvrqwRW+Lzy+kTeJ+Xg1St9eYMQ
7DL9ZSBNw7+/vzuEvObg9vRFqabcfIxUrflGDLJR/XXrzmafdix3aShx9yCg
G5y9qbSpCz2irLKFJVyk9sX9lZVIQXVh5KsDDgRck0+Ee3jWY3lhlP4fcv/a
QceWrnlehMEq77yvn9mIetevs6KWiWhGV46MzASy/1e5fKt0PYRPBK4XIv05
bWZpwMrvg3iaZbShQY/Ui89y2XeFA3gh0RdpyRqBzBbqeS3vVtj5vNiqv5T0
G+Fmxy0DVbgfM3r8uxoBOQWPs0s2M2AQUpmb/34cqaEdg7yRBZihdDDaJQgY
2NdMSBdlwmizgye/P4GMgOl2yXP5kLKx6Lq2QGAhvl3xmk4D5CLCu9/wk/Nf
ZOH35kgjRA5aH+Yl/bSX+fvD6aQ3oGjVBqeQv/u5Zrw1/lALz49Hn/7bTr6f
o13KkntF+JLHM1xNIzC4+8WWnapk/vj0ZTxpGZl3W9TNbx1nQFSuq9np+Djq
JU80vf6ajz1FRqZLST5QMnVdZtMZODx1+P2jKjYUPhxTSr1aiPqxqjVvz5L7
od9gxJ0pQ7L1R/PFrQRqsmRPcnn7oGnxwiclow9nrtu/1hJqwKSqXsNKEw48
zQ15xc62ICdQLFzkARtqXla3S5bWY61gx5H2BxxI2+n7O4b24rGRRmWKCYGQ
dUeNpIl6jKU9UFlJ7idMy1H2eugH3NmxcvMt/gmUpFP6TlI60azQNBtJ6qf/
2WxgXGE3Gpu+/5fgysaOBu0zeZXv4DR3SEluD5lfLN6mDnU2YdWqeSufdgLi
+46sX/2FCTlprc9DZJ9asWeXTpVuFYhUqSpCk0CQxNV4ZZ9upAj0tiYUDIEa
ZhIhlUaF0JFQ1cPsEVRv7w6R2UhHR43/hedPCfyqVojbqzqA3MkZ0aXaZD6J
mtBYcq4A1hoaDvd9yHwheZnnfrUCAiJOje4in3fwNJ9cpXQvEuxKna1duKDO
3FxP96lEScfK+QJDktehx0pfNNMgZ9Ir7nOIA2d1Z7I/MfE/5pOjweGjqH+/
Vz7zSytm+dh2TeT9Sph/2lVxlomFL/pO//s+DMd3QmWJ+VT0txjtFTMaJTn/
/MYFvQLUqK551UL2r7XnUvM+5jYhi4/5toPMC4qfD13NRh4CB1zsA48R0BT1
Lv56owUrerd+WneNA5mvaRplmZ2QsHy/cDyfC8qOlyFvNw7CJbHgtWwNmf8v
9Fc9mqFjlDd5QSCHhdJfZ5p+ObXjcmuXm38iC67Vbt8cVfPBGlI4t3if5FXW
y9TYkl7Upi+1aqKxMZ21tjHKugWOz7XUX7IJcJ/8ebhJmwF1w4j0yxJDeL+4
wBDiUvFP48nn9EkuNGnrQgL/aUN5yqktcU4s5GseqhnT7MTotWNTERksdI7W
VTyqpGNnAPXouBbJN9OtDM/GdphTdgsaOLHBUduTaRhFg/PnlWOSJC/e/zA3
WPGVjpR3l3mErw+jYr5hOIbsr+y5Rhsjp16sY3+cTAgsgs/hY300QVLvdF6F
11u6oGj4tX56LRfN4gPlghEMRJ9w8fvPfgz3TS+563i9QVnjpOjYaQLBgcYt
kd8GUDqSYtO+m+wj9v8muGWkQ9W1hV5D6ilf/MhUnFEOXJoOVv5aTfaBT1Ju
vZ/J8287NSaex0Zte67o6VOtaBWbUJqW5yDYVldsNaUENEWBq1aVbIgF+z3L
uV8F9x9nPSzJ5wX1/Pz93rILlzac7QpgsfHroO3+7zvyybnzSFj0JSCUHNm0
yo2OeW/KqqcVXJzeGJovnM2AOLU0ao3bOFI8D/gV3m3Ay+G86CNXOCh4vqF0
nlKLid2+RW7SbKx9c7oodbINfatPhg5uJPnTsKFNrI2Je60d1W+VRiFnHK9I
31OGVsVG92V3/58/Z+yMH/SjNeL8dncBNiSWZ7GLBdthR5EqFtvGgvkvfh7x
j1QwKNszwsO5GJNlbLiXWoB+ucqXyu8J+F4S4Rcj+9SiXplv7p9JlGUsc/HI
zsajVzex/jKBqZoT/OnXqFBdxul6bcPGjMZmN/kjzbgkIDM4l8gGr7Xw0G/n
bgyfSZfV4nAwte7fv46LjXgh7GCudJQ8T6/G/Y8fd+GMXLG38aFRaPNnpcYa
pWHiB9/Lf44TOOyVWPlBdgDbCoLryu9xsbNId6HXng6V4d1Rv7aNghrkLuyd
/Rz7maeSG43I/LKprbp5uASzy5+5FauS/lOTtPrJixj0j56vc3MieTCdt/oe
ufe0CMYaf7K/B4gLHzWWTULtA6IvW4fMu0U2ztPXamE626Jj+5KNMym166hL
GMiIGLEfFyL7N5O4Uf2WhmqFQcr7zaT+Ps9/O7auDDPh79/t/cEGITT29VZr
N5aj3azSjAXL2kYbahkVUU+0vEUOcnFUuOB1m3IthPZZ8NYOk/5uedTgtncL
WidjxtX7yPWemiSVRTHQWXGIaejUB+U3vjlpud1Q9xwXPiRJ+r9+2C3nPBr0
182IjC0fxv32Z7Kqkg24NhzTeorkRaxn6ofVmjXI+EJfnZ1KYH9x3SHK3i4c
ebqqpPURB1omP+vWSdFxSd7sV+YwB/USsQkprT1I91hcqHw3grHJA10hoc34
TFmposrDgffjiLK9LsWI2zPwxI/M/0lFB7QVL3bij+dm/0tmHLiqRoT9U9SD
WtsZZvYAC6JJAQf4HGko0ZbYe2mOg+sJHN9bsdX40toZf0iY7P+Feccb1/TA
lbfu73K3UehdmouV0+smfVPikIzRCM7vaxyMXFUIFemq54sVBKJpMw8NOunY
b7K+6mE56X9Kg/cO0yrQUVhf6TTKhubEQ61ejUZgi3NK2iYOXqifeLyilgp3
qWe3NvcTuE6RMvux4IEEZm5YJ8n/XNOCWcnYMqh3Gk7lehJQO296VjmTigM/
mubUyb5w3DUnRKqmEZPPPfbymLHBehKvvWNbOZbuKVtxmlxfx/ySXbgA2Z9v
dSSfLufglmPG+E7vNtxdHbTRkNSj76nHKX6sdjgp867eLEK+X+rrOTdtJqYZ
f0L3OZD52SwkvCmlGrIrDi00kfo551hwclq8DSoVjml1uuR8ys4tv5dFxXj0
UYn4KRaUvwu8ORTWA+fizoNFe1nYscutMm9TA8pZtl2TLWyEI0vPkFEMsWZh
jtp1At29BSMX7jTjU9QD22hdFvYtE9CxGu7GpEHiv9NkXpY5Mr1+wr4BpTmH
Qz4FsdEr3dRsIN4JzcQNbxKjSf8cYA/rNj1D6TOHMEOy/w0ypu+ImrZijJ5l
cliDA36Ju9SIt0yI5pebTHdy8Sg1iz70oRlpIymTKvtIvwyQt5S6NQC+p6Hn
hrzGsIq1aa+SKBVV8hfz3rLZGN6xzKuV04puysLpQBsOzOrWx/of70Z/xtQV
I69RqOtr/TzyrB/BP0074uQJfOP8rq2bLcTVhuHcvEgCVLlk3dKEctje9rHO
TSD1u/2MdXLkawRfHVwFbQJ3gi/YX/xKVrUmJ4t2Mt/xzMknFVy6BKH5RONJ
awL/B7EcMnA=
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41Gkbx6USrUOsNGqTSg6bJq8kHfhqtI5JDkVyikWRrEOlSMoWYkO6
7FZOyUqtVUmoHMbkTIzBjJbBzO8ZlVebkkLo/b1/PNf9x3Nf93Ufvt/PWt9Q
J39pKSmpTPr9P7pZV5/Zuk+IJw1P42+rjmDX7yptEkY7NL4Iso8uIMiz3svb
rlKCeVZmq3oAwVLFcAXGlno8M1fIsHxP0FMf33Fx9B8YV0sO7I4bgfWj+xVp
ro3Q7I3PFn4vARtHVngUp8M8Ur/Bzpsg7YHiCpfFtVBpkbu7kKJQ7liw+Pkp
NhS/vfh9ryNBUL9liOmeRkxZ3rKxOEww31648lRqL/JiTteKblOw4I/e8PQQ
QMl1YnD1b2KY3NnP9GquwfVTI/OmDQRCpuWTFkYfNmofqz67keDhx95Hwt2d
WFrVVjroSqDTZuw/va4PpsqOJA4UNN7lOO5z4EHuUcaPtoNieOSVvf91iofQ
Qx6287YUPjF8h0QrOrBB+vjljgkKd19r2IXX8ZHldCnDalyEy8MdGvnRfaiJ
1/HaeVCM3buHvr7q5MBP7omv5iKCuMYLy78sEEIz0sa+Wk+MPWPJ003JPNSe
1dyp00xB0eTMossh3fg3nNFd4ECBXSzINsyshuG35LBSG4LDHieibgwJwDMu
Kf8wNIy0U0MLC483YVtAiZOpgEDb0uGpZcJzRIckx+6g5+V+ZXV+mCoHSSw0
8AokWCOhRuND25Ax8J5tHkohZOfb76s/8JEtW292IJECY9mqyPSbXGh77d/d
/zNBonxoQJioEj67lc/XHiSQZsouVBNzEW7EPSjdLobb4MisuKwRqvk7z2z1
Imh/wUdDJxsbEjy4HxYTyKY46w3rd2B2V8YfzlcI2Fk5m1TOZ6MnyvdzfzjB
ebMWvXHeK1CXhrNUZUUwimr3aWniwMY0rrb4J4IfnfyDFbx5EJhnPBaVifG5
yqeke2wAuqo/OSp/IvBkKRQkTN5GucaOj8v3Eow31mjY2jajU68lWz6EIPfN
vST3pB6oOmd0RvFEcJtXWOUmV4Z258IGJxBcVN9kXuPaCqkAj69pBhRGg7vD
TP/mw6hAatZmSoT7hly+ixof5dyNnp5aFPiF3KBLPgM46F7g+fG6CFv6OhOw
tgvFRZ2/KIvE0CidU8/Re4xBtchWmyCCKZfU2lHvp4jz/ypTZEggfibjcvJe
K8xEGYWHQwmO5rpHH3MXoKK69eYQRbAiehf54tmHifKMf/ONCPZ1fKG+PehB
8zb7cmWhCM15NYLPb58gJyOcMRpNEGWwQD31UhVqn4UKu5wIOh7Urz+3XAi2
2MvhuyYh6rex1E86cOCj+9uVDvqeQTuuZbUvGsTXKN+sptsiqClE5nRUDOLB
2vwuG4EIAyZ3ZcaFzbTO/RQuukrg0lEQy6hqQOnVpKAv9L261V8qavd2IHMo
7Bjbl4LZ4xarG7GdiNxWqV5SLoZW6fSo9oYujBYFvjm3jIIqR+vOwtEm6Lm9
btxeRZDeCdWtV+uQPV5JldoT/Ppy2qLSvx9zB23MH98eRlZVXutkOQ+pv2sV
bt1E6+VZ/brvUtswHajrraFFMGDgV1t48CUy9p+76VpPIa54+Mu4RwiGx1UU
K2n9lcX4pyb+2Afeueznhs4Ebq+OsXUnG/DDXl7nWCXBghPag6xiPqqntCIj
l4rhM7l+Pvx1J6JFQjsLCQWbkviZIw4NyFq367wM7cd3E2ancnS4MDe9Md0t
TUEvYkbvM4OP9332Roo2FIzqbiRdsy3BZM4Y8zitv1jtv4zthrrA2j72oltE
wdxw/7V6KgarjYNDzWne1QfFSk2blEHd3jOix4pAP2HuVOWqZph9TI0NXCKB
h0S6lGnOBiMzvTBZn/bvpydTZ8R/Ys46qVSFzm++trppzJIDuROa9w6cpufb
37dG6eQNbPbWDMin9X691abUa30d+LySQ5wwApOgXnXLZC6YFklP8+j9zChp
fQxI4eFi8pr3zjMSpMkM1ZxlleKpVe/1zXT+wzCftf80VeIXqz/XX1pFwAqo
yGZKd+OvkrGCkHj6/1AZf1rpHrhv7B26fGmeXZrziRo5Cc4zxV2udP2LKRNj
cXR/leN2zOgI+t7WbnpreU9hHJTJMlEnWOZ49J071YfX71oVZq1GIHN1bku0
XBdq//7ugFW0BCa8MIuJGDY4U11fk30IePoJfKquF1c2b2twIhLc0UHo/eAe
vFH8443yshG0/lYkXZHLQRpzdEl/C0HJi/czrU1sLKzIjamh+byXeeHcrDof
cw/Cqq6r0Xocdz9W8qwVMiHhFUe/UShQCLovsW1B4esnbUppBAq3rGPb2b14
bOcdyygQg5zhZcu3v4Sdggn3eBcFzanUA/UrK7BXiVva6U6gselmlOAuFynn
CpIGRiRgtP2cfuhTDxbkrkhPLycwC0789tO1Lrh5Tw6O0vw1D2yXHuitR9Gq
5EbDDQQJklm3Wo8aNLL+s0tGka5nnnXHbqAXb11P5zjq0v2aez2ukmWj3e9o
8f4ZCm75h/vzj1RDXjnLMJHmo2qD8kt1mk+J0seX5dwhyNocn8uc4qNwC0s/
SVsES9O7ieILXFSmae1gx0lgKte+Y7N3D0YqgziveikMf3N5yVPqRco+K3B+
paBybzbQTa0PzJVS+rL6I6jxc90xYN0NjrTa/Gba73l/593e3lWDZuN6i9U0
D4rj7Pr6NFsgKHsewRmgwBrbohpzlofzKblGVUIKZeMTWWXpDXh32HSm7b+0
H8Sna1NquNBd7mhwjEPAeb1+auOJHtSddJnxvCzGLwciC4rbBSjODVypAQlC
Z9dMVnq0wPcKs8UhgkJUGfPRB3k29jXWGf0lS++T4X9GNaYW8p+jM3UeEgw3
BgcaXctHh4uVfTWtz1UnWNLpKYMI8xK+kpkVwW52/F95NwE2+XrILVAUQbc6
9ohpfhcM7K+WaPxAoedFkbYOqx6P3vTuqfAjMHZ+G7vTT4D4PXlLZZeMYJGM
6N7YP1WInn7Q7eJJYJDcHxHBv4sKpmOlGYv2Y3Da4odFrbhltO2tsTbNf28W
55Z0BaQWs/TWXSD4Hz9FxQ8=
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs8lOkbxqcDpibksJvNIWo7aAm7lB/VNRSinHMKNTmVHIYmlCjRiUiJ
ikipRArrbJRz0iJjjMYxM/O+yda2WkrapH1/f7yf56/381zPdX+v69byYTv5
z6fRaFep7//n9uxni2j+Lbik94/PxT4CmmuV72iEPsC/DcciPLxJqO33urkM
bdiVFFR2qprAZHToZDpZCufCJdop+0no/8RruCFuw2kty5LIXAI1ni9sWF9H
ID0/W6n7/AhEDBNa9xYuwnl7p88rkvgsdVbqUg0f9TcT1G5Lk5hNeklvH+bh
bvOv7JUcEud3zVOPYjfi9CPn5FhKD0+xTd0kOw+li84+6dxDIkbJY2+1Wh8K
D/raHHWRoODX0d7l5T0g7QqNmy9IoBLkPaKk2IICXVNhzmIScTNVIaf/yEO3
r7DmuheJfOWzUhvUm6FZv8S0aAeBPXKqxv0jw1hUHNtxiDaCVvlp7rjVMLL3
a2hvXDUM9o8NX/kHG3H5RIzqKep/9+wkv9WcFxjNeLcxyInEPd+0S0/8exAQ
8F32658EHhSn13k+4iG35LDqL1wCnSePjbPW9qFMVuAXWCfBLfkc2eo7j1Hk
uEffkPIv/1VttfN5HowUHpc4HyfwV7tyVrzOICZ+GFpiu34UNWSirMi3G4Ib
Iz76zyRY2b/tzd7JLjgYGay2pBHYHNzYtO92Jy4qFTZwj0gwlppY0jivDaFJ
cYqfmgi0nnSz9azl4/jKJVpB/WLUpPVyYii/Jk/8ely3XwLrNeZbZPKFsBsd
9+IVEPD5mTvG5PBhF+oaTpsTo4ehohYe1ouFLvv3fPAl0Vi+k6ORfRmdJV9d
NKh5sHoN5IK82rDvwh6tYEp/dpxCXxRTAIbYv3JIQYT0PreTb2oHwJiSVLUq
SjAza2Uj583D9Nu9U99SCCy0CpTLzWnHWblLBckrSUx/op/5e5KPs3tLGl7K
k3CYs0izTLqKeqPC1gOU/7RxTdvdv1kj/4foFO19JOpdWcuLK17A3z06WLuX
BHn/YnHgT93wkjSPBm8lEGO8z3FD/kuEryphq2tRPHcZppFGg0jz9rim9EEM
lZntwc6HKvHa5touJT2Kv3W04tVlAtzXW2Ny8DcC942ZyxuyBjE5bjClrUMi
q85Q/krtSzTm19vruUnAojnlFtg+w6DccE7lfQLlPKKRwWzBOmJeUfhqyp8D
R+c6JtoQ915HpmwzgW0LHieeE3bAyFJOXLmJyo9VTIN0Px9Z0XHnTn0ToX2r
s8w6Jx4si8qm6uPFqPOd4npsaAMvVuff5l8o/VPsW2FXOnBW1mvBm48EHt+z
vfrM+jkqUzVCGTso3jmd/Yt8k3Ektn4kivKrbMNMl2OYANemfITvwsXYqc/W
8d08BJpJVQ1TWYJGM9vj2m5lCFn7nV7rSYJesTr+6MIWaPiPmjkWEgjfwDXV
jR6AdXA5J0PmNUTuNqyxdSWIUg7619CChGJmnSz/80t0aLvu6lwqQqTJ0tTA
oVLc7TdkkOYkDLs/Nm+a/xyo+jCjJiKQNcHLG1aqRpLVwLUhOgl+fIQrSefB
pGuz0ZkGCZKd2pXWM6rh8OPJznmGJC6qOsVmfBYgD0f8PbPEoH101Gisf4FD
l+SWVasTKJBxGcrexkMMQ9p3zI/Kl9GQUQqrHXbb103Q0wlobFmR31UiQNaV
2jc5m8TQX0j/YpP0CMwTVhPfWCQu9bRnXqn7HfJSt5TeOpMo0Kxz/kfIQ2eG
R3D0WzHyjqSe0/zCR8rqdaeynSWgXa4Vmgdmwi9WlV1N5f96tin9qctT7DY9
dkg6h5qnWQvncPpdTNeMFGi5kMijp/m0lj+HrpIri/QjEK0aJJvg9QoPrJh/
v39PQlNl9OPTnUVIfRNmv8yH8r8q71BiTiMU8lwmX1uTCJ6dWGrxTz/CHCJT
GFwRHI6wPxkvT8fOwFVuYR4kwiyjvusnPIRxaInJKpBoWbMmtosxCOPjF4fN
voghOi8JUj3cAmGmwrwP36l+eZA0LfOW6nv7+v9xqXlkWvUGXJDwwZy896qk
lPLrQcjPt0+2YlaldNGm9VTeSmt/63Xk4LqkbWZyL4n+T8oZg94vEBkadDnK
TgKuUei0ZdoIdOak9VptxaDb1ysu9mvHHoWY6vA7BCpuR/TSGvqhRu64J7de
jLAc7ZRU8VOMbqqS0qHysPBOwmL+xj6Y3CLyiMNizMiLrqyNeYYmAVeNeY/A
UiP1G8653dj4Rc3egfKvorFaqmmxAG32Dy3EyRLQPaQ5Z8yu40dBfYzpAaqf
2OycwxEV+KAa+yXBgOqPKmtBcWYlsqQsF7jqk7gR166qPNMO6e6oC68FBIwt
vmbOjQkgu0K+KeNPMYzfyZ5wU6zHXIhUuLwMiRODAbv3JRSgxc4gINyV4rmi
pCuirwvBGRy+R5QEp8fHAzZs5cNLinm8r4/iN8z/D4uITrS1jWVu9qf2V/uC
gwERdxDt584JofgaNg/5Kyy+D13zWhxE7hIwhUl42yfEjG735I3FIjS+OWpR
GFaBM3qXFQyo+5lPuufG32eApxfilkvtC0+3a6HyrAHoX56+araQ4u/9EUu1
Pi7kmmZntHaSiLfbGKlN9ceS7R1NsfYSnBDcCw636oVy7zfdncli/B2wMi3o
91Z4xY6aP7cj0Xa7bMWu0BH4S93SU1EW4yYrqGmp0RCWzlkZfNQYxbvTTic3
OQxhRQIyaFUSZHMTI2LshHAgtg/8mSLGjiBtvQ93W1FwVKhg84TA6bW7tPtf
DaNKZHi/qIp6z7Ge1rHlCRj8xtJ3pvjZcSf1nIZvPyy3ZoalU3nKPtC0KFKl
Fw99Zit1pSQonfF2CjZtQtSpiciDJQQEPiblxeQAvrHZAzJvR1HgGGO18XAp
rgt3hP5O9edwIt1D6PkE8YFJo3YU/3e9O82qijrQ2WO9m0nprVoWaBj8uQeu
z+vyK0OofeBS/qhyuQARj3JpDRSf50aMEg8ENMNhdpirQ+XZwWQLGnry8UBr
/vRVqt9Y/OTkh5llWCLZFhmoSfVRJENTdXsvImtpSe7mEvyg7hAQ924YnKRD
Ve/+IBEwsb/BnPEUg7LuQ4FUfv8D3dmgzA==
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 90->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4lVkfVYlMSBQiZaYp3YgMRWXJCI/5KBUp5JprqZGKSJQaZuQePiSF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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lf0bxxUhCZV6RAolVORRRkkfq6IQJSmKkFURT6FCaFmJIgqFlEJW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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlns8lOkbxoe0TkuOKYki2pWi0abD5JrVoBxaOR/bYWWw2ayUVkklRCy7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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs4lOkbnmIL1aYtrZIkVErlVD8V3U6L2iZyig5DJHLIoSi1CWnZRLJY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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 91->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8llkbNkKWShMT6ctHw1AYS8lk6VJTtmRsUzLIWgpZohJJCU3ZQpHI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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwdmHc8Vv//xmVmVlbKzKiUUEm0roSWCFFoWCWprJQRFZERZVX4lBCVEhGS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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs41GkbRio+OiqsKFskSsmWSNtNckxboSS0JSRy1nFpK5MtZNEi1FSi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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns4lVkbxn1IKgyF0ZCcNU41JUnlFiaFZCvFDimUUEaZGTNTQoRyLBWJ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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 92->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx4lCCSOkqJEZWysx1a/iU6FSVIpRI9mNrciWBilJC2YwsoVp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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k4VY/XlaR+UiRJSoYoSmkwJVqmSlKJlJQhY0pRxjKLQpIozYMxhCQR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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81Wkbxk/yTou8kWQtyyA1o5QlEVcZRcaQIhRNCQmTZqKxzbFHRSn7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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs8lOkbxqeSEOVQoUUpRYkiQ6S5Jlq0WaesVYmIXzmsU8ihNNvJFpUs
HYVWRUNYZMs6DcphM2bMOKtm5n0nKjmlsuWw7++P5/N+nn+e976v63vdt65f
mFvAfBqNdo06//86jH/6166iC7KM61UpNhKwfrcLNe4/idR4VkuXD4mF8uqL
LH6ux3SeR06rNQmXmCfTcqYlOMFQtSwxI6GR/G7bG+ZfePBZZ2qFBoniRsu3
Pcd7oCJ6Wm/DlEL79sTEuVM9qDrsWxYzJ0bUdvWdzLlmBKq50q5nEpDJPOzQ
miFAgaqMwa0hMcLkvUyKD/Bhrm63L2k3idj0W9r/znsG7p5DgR4jBJRp5bsm
6Dz4q4fUzzEJ+N9jmK0jruGqc4FsjR8JhYzrGtofGqA1uzHKYBOJnIbe9NUr
ORB2m7aqVBKo+/olbvkgGypb3XJnGCR0Qk4Nz0sRIuHH+0sqrKn6avnrS8wE
CE+0ea9vKUb98uGah/ICdBW2s25XS8DcJDtr5/grHpjZGE0eJBF3mC/SHxOA
texLk36/GE7XdsYmfuJjvUbHTy/uijGdOjfwwpuDpuFQr/VrSeSvcWOeqemB
FW+rO/OCCKJdF0ea9fNQrsPM41D95ibFbQhv4qBQ5c8gu2gS1qecV3FvPoeX
Ode2MoGAwcNLOdERXFhpNlyepe7NW6rpLkt5GKCpKpnfkUDOpEiQOlODrDXt
cTWUH7xZZYPshHLUVHT2uoKEk/vz866WfDiVLRAIEyVYd86/kRYhhM7gx0Ws
aAJ/MOTbJ7x7IdHYM9uWJ4Ke9khmQ0UdRuhHpyJ3kHjjqLgyhNWDjDwBjykr
QslrxZNxmbehaRyepudNInX0pXgfoxX2V8tcEkNJTLkLXctVG3EmI/PcqIiA
knyAE7u4C8IQUXp0rwQD/4jjx6wH8A/XQXbdThHSYn3pal87sGGkTeaOEoEH
Jadzmm06cS9046GeYAka3wf/sCCfj9UDTccaT4vRxZ81fjzahIvLY6UiCYHw
7kIP/V1NCF+aesFGj+LB7ddS7SulcGGVdq9kUXrK0Pl6JnwsbN38acheAs+5
s+lVaTzcm6Erq9sQGCwMP3bySj/2S4sur/Si/OwWfIps4SH/2v4o/6Ukmh9H
ZUyaNMHrkTt9yJ/yo92uqSa/Di6b7ATn+yj9wt+8r6zvwB2RafM2BQKqeUul
zjECbPIL/1VrSIT8bBf3cMVO1J9m7RjZIAZbJXnqckUTDq3iD3Sakrigkh3m
LNMPv6inw/NnCLCvvm0uPNiPsUe1nKcQYcrg79W2lVx4botxjL5L8eg0Vdyg
34ZbMtl1H34hsDXMMSg64AVCxxsiVtBJLJ+q2jHuJsT43nfy6xhiMI9oZKav
6ULjyssm3IUEbmwR+RifysOTtFOMzcFU3oMY874Vc8HwfyurukKK/Pk9h43q
OmGuacHUY0vAKba1WnG1EYq6u3vtnUhMfojXiT3AA9fr9Xoapb/b/ptdWX91
Yn5xxvkr5SKwdH0tjvbzELlxhYL2KgL3+m3JC484cJ9JIhXDqH7/OCQ35yxE
kRxhF3VTghfFM4c8I6tRkDraEKZNIlPd4dkVcT02L2zZH6BKwuFoX8at31rQ
8npRKl2BxLsvZZUR7wWQqt3+qXAzCbnQitkUfgUUklOrP38i0JsqVO4QdGD6
I9t6fw2BTKNqu7VjRbAv4MQm2lN8PnDNCmwWIlFnhufbLEZzVVZ6/d0OVOU6
jv6yXIqsEGuTgO85yFJsn/HaS4I16OdZxOyCOXvguvtv1LxMV3PQnYrEq/uN
CbMU/3U3YwKTj/ShPuCM4TeKj4LAdLWCJV2ImpYOHTgpQV3/x760tHaM5ppF
9yRJMOYf4anb3wdH/dBLq34SoWrYuMilsgmqmnnVnxcT4FmFrcx2eIK2AsNF
fdtJuI+S+RoJHWBovHnMHZEg0ndjyzPFSoTXcYN6E6n6ss2NlCyPIN4tbrca
Nb+9kpI6xhc/w4SCXJxWN4EUrvll9o4uvDqrNjFlRGBx6TUigtsNbtH3DLJG
Ap6ChWpGPxuXEl1XLbQhoZigousTwkfpXb90szkJ7D1q+oLmcbH4ePTmd7ME
ji1tuMVR4eNATHu9N0OC4dE7VSnlPTjtwzayOk8gNvjMBfMSNupYZdLFASRm
ZzWDWBo8LPOxDFxeJEHQq7Zig+PdsPfT2J5BSCBau0+LYVkPrf8dmm9pSEJm
X3+s3mA3fH9kEEE/i/FkMt0qoJ3iwYPbnPKZwNy4Z86ZZCEW1nxU8DhL5V+6
IWeTnBBHZXrtGB/EyJk+bxqizEMJ0yLziy41L/sMa3WDe7FhJ7tv1zjV7zGT
AJVIAWjtZSqJdAJywgVWfw4/xcOrxieOf0di7P6rLcWRT7Ddfu7OiDOJaQPN
osLbHTDJ14t6RO0HrWjdqdzop7j8bMnnG7YkhoJphTJHOvF02Put4QkxhM6y
DjSrSihbLfm6I5DEi7m2NXpMAdLsDGJu0yQ4rW93Tp3Bh/T3pVFzstS+kuE9
j1fKRcwD9r086n9asp2DLnONSLyYcNziDYElKic7VEuEcOFOltKPUXotrqV/
u94Is23be7uPEYjq+9N6maAO7lNPOoWLqPcu6XfrJHOgGWhRU55KIl36w61a
wx6Y9lelxxSIEPnzxpcn3VohOeL7netaAqzd8z7+O3wFRVsnc+IpnmW+rE7d
s7YeQRvFYa8DCDhV7Q2d9hVAmaCdWm8ghiIpqO6K4ePvA0bzjEYJMGlXFlWc
6EaB2zML6xARms82tX31eY5K709bDK8R8LQd3OuTzMcD45JR+jkCr2pj5KQr
+Kj8ljB65yW1D1JTCl/HVCB7TNNN1ZGEfttjnjCjD/KRmvJpAZT/zIbMEd5L
KChVn+DEv0QmLfhxrqQH5unfeUR4voJe7TL/rQeE2GZp83VQXowhHbf5Pn8X
4qj8Pz8kWVL5eRmy6WJsK7YR4aLCZCp/R+X2ErsacLdHUmHLpfLx3Mo/a7IV
pg+jVt8fIGA2oSs8eJ6L+BzPSu80CWw0WkziDfpQxi3N3e1K1VM+eUOmrBxZ
24+cdWaSOHgu+6aSqBlGnHW0jAUk/gNgpLVg
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 93->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns4ldkXx1VDaijXRvNjMHMooWmGSoWvoShScptRoeQ2iFMUIppEIUVy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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3lYjN8bxlPKtz190x5FKCUhFF/utNCGSpuEVFooylZpkYQiWoSUdiTa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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81XkXRpiKKZWtSfYkFUXJlkfCS5/GHkU1yBJ1qRmhdGXL2EmiRC+l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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns8lGkbxyml3ZDaWLsqp0iW0K7ToJ9CvGpRaYxz7Cg6rN6yKCmnpNK2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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 94->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVln08lWcYx7GSVVpeFsVKW+UlRqi8jB9SSea1zKKoiKFREeqQRFQqlIrW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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4Fesft2UtRJakTQotlCUhPkKKhCQhpJJECm1uy0VZyy2icqXsSyXJ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVns8lVkbPaKTpLtc+solk+TWZRoUzTrlFErijFSuucsUUWiMiEoYkpIi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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlWs4VekbxpGMSpKkRpIzTZlBmbZUtxCmJDkNsiNyztDBIERyaGiXMsip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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 95->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lWkbLsJE0yIpNCUkjOpopGLMJcnIV8qWaBFiUrYsM5aPVEKLr0i2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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VO8Xx5ElkqyFVkQkQlkSfYiokFYpvnZJJBUpUSoJKaRoISWJkqzZ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81Vkfx5UlJJFwR4sWk6RRIVw0H4ZKuWnRMiGhLDUVRUaPG1kaNJaK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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns81NkfxifNJlbKpS2RZElFZRHa8PjZaVxWudTaoVyqpWxitS6lRFEr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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 96->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8VVkcl1RCQw1FJGVpUkM1pGnKNyohDUpS00xSqChk16ZUIjMkZZsM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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHlYTO8bxkekkCRFCy2IkISEpLuihHYh2VKJikqS0irRhva0KSrxbdMi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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81dkfxm0NhivUSIk0tqtmlFIhPJU1S4ykLHET6WedJJTENCX91FhC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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lekbxsmSZmwzFbJEC4oQSinjsqQxKOUnhGQXSUTaiKQMMxXZWuxr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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 97->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs8ldkax9XkkkNhqChynalESrQ1mp9OTaWppoSKsHPJVsQuRXK/5Dq6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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3cglf8fxSkRCRGJaMlI37JChaNSSrJSShpWKZGREF8jZJSdyP4WSZQ9
iuy9L1eukbj3udeoJCRNv+f31/3nuc94f84579fZanXTxHYFGxvbRXY2tv//
9n6J6B8IqYWAUlP9aTUCLQ9Gg2961WOGb2p3SQ8dpq9XTRnO1UOI1eka+p2B
vPdtB67GUXHrsZf6Le4xiNnVb19D64LiLiH+Om8ClT6qH1NEO7CXS1ZE5RAB
C26Xzat+1iF2/pL+Dm0mnOJCW4aqO6F/MN2iSZAJtj9aYoYCb6AnnGPuHUlg
Ujy8TjVgAEXcRyb1ZFkwTQkaTY/vw4/e5S2U8XHoFD9aeNlDQ5yd6ttvBnTE
7LScetRZjz3ZVllhc3R4jx9v1uoZRJUAX/xCARORzm/vNbENISo2TtA0cwDa
NIll0bt1qLy8djPXJfJ5IYNWcy+o8NlUkiggy8CLjNNxBpF5iDKZLbwYR2Bs
yW+ryv1EVBociLU2IvA7uvXLwc/9qBlQS2lWZ+F3vIrYIeV6XHwfFnk7hYC2
w5ENN6kP4B/8S9HyDPl/Xe6U+0mpmHt3qrD2LIGQqFGNmogynO05LRnhQiB3
4ppfrRsFKbZdGeLPCSwc+PDhsngrEu2vDmMlEyFe+n/uHmjE8icJ/yRTJpLF
qAOb9hRiy9z9xrwjBL6ae/nJpbVDwCH28+WdLHwyv1x/uJuGfx2qelYkTiK4
6u0md6V+vMoXrToeOYHgIa3Cp8RraPE+3jfmxYTdzu//VfFQ4GN3K2DuPR0K
e1SyFJa60X2879/0XgKz6VHSs2FF6IhWP+NrQ2Dp2ucCwa8DsCp3nYcFgUfM
/vKQ0X6whTG//uvCRO4O/9OJ7v0QNcxU4T8xAQ3zcIM1s1Rgi/VQvz4TnxS0
y0o7WrE/IzPoehQDdKW+oZo+Cj5/XqfaKUBgy/UvXY3WtTBX99ync5O8v1tZ
jTltEH3f608tiX+A9o2AdTHDLfjnZFac6RIDvP0hrx+/qYU165GLBzsBqtPf
D22xnaDJRh//Jc/ARuKw7571vViz2OtSsYkBqsyqAveUIXiMCz8cTWLgQZUD
xyrpfhQ4Khd/cCTnfaHl8VffavAx/tMNWSL19O2qYZAVFRdNbJRnnRnY7z3T
cC+xE1634vMvObIglTleXh5eCZqvXzzFj4k/fwuSqttG4f3IyMUAdKy3tq9V
5G9FKSXJNoH0j5V54Q+JFyNYo/zivY4qFTc5FKce0/qgdtPQYSf5PmORuiLy
USm492is6K0zgcsbrrzqz64Fr0CpSeUJAqaUMXuZy/9B+9e28CcGBMQoDzft
uTiMTblFi1LCLLA97+ZdQ3MFZ11YhvxlAjR2vcHZuFIc+D0VL0rqfTHPTT1o
shuaiToSic6k/5q/PNScrkDi3kGRw6EMSH8+8l7chwojvrGnyy0saFhzHL3t
UY+2uvHipxEE9pdIZ0m1tGA6Y3Wkxw4G8n/tM9uWnQXDJFdTdS8CUexRms4C
3fgpOHvXRXwCY3cEox2mesGf7pC1mM/CNs+F/4RW9IBty+18+XIWaiLdrssF
xuF6a+XFQWsC5Yk1/q1HRzESHuXMXzmJpvyGmIC4HmT/U68SkE4g/6GHfH9C
OlilvwMqT5H6vH5Um7uiFEkK0tWfHAk8v9kfX6ffhNVRqq+5DEk/eS7cceZ/
ix3PJaafaBEovrcy9WxOOxrSqw/5Gk9gUejFel61AQiJflCrVB7D5PzOdUnj
dZgOll0U2UMgkL0gyuFCN0Rz1Ip8yOe92Kbg5T46jBX3946e/j2JSUXx1bMy
5TDa3M7zJY+AkUCzm9dQJ4jPN7RmftLx4uLJ7YX36gBPgUBfe3Lej6+msLHn
oMG1le/PeQJO3v8E8w69RGByodG7owQ+Uy6oaqykYHbUhY/DcQKT2jxjZ116
ofyeEWa2ktSHoX14aFEzNhbzbfai0WF3svZdlUcjCmT+ap0g56O1i8O8gjKE
0nkfu5llJmS/Oq4N390JY81fg+87GBh5v+6ufGkbNhkOjZtYsCDQVNZj+aYB
HCsTG+xyCQyl6Fzde38UKkUVHXtdGWDr+OsYcbAUOqetDRiZBD7ZOn23ZKeh
VH6sqH4reX63dHnOpsVDT3TY2MGOgM5Zh17JH0VomtvEf+chqQfLv3+V2Aew
M8xR9cTuKUh1aDzQY6sDKzGI7YMQOa/cM+meWT3w1bh+yVOMzONd7G8D//SC
8+dN57SfLFyXpPQsnRuC8g0Jr9FJBp5z3yptTm3Ek4798bY2DGQE9E5lpZWA
ESByrSOKgEdWullMchO6FiryWibHkb721rj7PyngOrVHWewCef8eQ9Zjrn7E
tyj8zvxD7hPJ/SVqRDskR4uFKw+PYYtnNL/S3Q68rL3kfYXKRBQrj82ovwWB
Fzdy5vxgQEe742SeVR/ePf0Za7SaPL/CSJ6WORr0g8Ob+leMICYqw79thALe
0rV5Bc8ZEK2Sz97rXQ23U1c0hB+RftZ7nXya2oPvUkmDvtIsCPqcO/ywpROx
JyJrBXlYmFy+crFPrwb6nve+lyQy4fNDWtCppQc9uw84cQUxMXY0o9y27xnS
n21XzTEh8zjQ5u2+HcUou+LYtOkNgQT2Rz1NZythz2N/A1/IffT1+Py6o0+h
sXpt4xEfMg8WlHYvylDh16p5MbieQM2Koy/nRHJRGn0+em0wgTPR0xKGyp24
4nPy+9VLY2AzynxTaqWEdY57nymR+aHudL/iyfUWiH+64JpI6mVLlJYzZGIR
RnuSkWZG+pEzcI1y7ROojurXP3Mi8CZDiAhKG0SNh434dD6Z5x6Lkn5svXi3
XDyQu3UM2jOp2haMIHSNfrN9ZUnqKyTGWjemFr+z+Wp9SR6p8fEv43K+h+Sa
NG5RMs+iks9u99r4CoHxFc+iSH2NObaXvRZ9BNNjZ631yP1q8+TbXuWgPOxU
I+KWk8n72VVHiqoN4jItU0HGaQL7jU0V2WNaYHJkYo5tH4FbuTGTuq0V8Ei4
GRl9h0CPOH/5iFMXhMVf6J9KZaKlc7EjJ70JzWp1vQkcTLzdFauvmluCq6MO
GjHdDBDpbzjD3VvgXm7if/DVOJ6vs+S0kurFgLqCmGrDOKT7qWLGWzoQcmMk
JDmAgVRLTw7T9j5QfXz83FYxceyPsZGmeieeWGxrPFnLwHoD2ZRskzrofstv
gyrJY+d3eyr/qcfPCiXLobsMTHaEvo2qLINKX+WC/iCBAovVaRLjVJxe82s4
979xWBQdMKqIqUGfhsHvR+vIfbwieFagtw9i7BbhBc50Mnc7ffZLRkCF/UtY
FzlPj1bOSLOOMlwnqg8/vkrqRzOqaoNxCSTYmlx7V5J5+8V5q1xJOojQ7tTk
kwTMCzIkV4z2QkglycD9ChNnPf/tanDMwI1xzltyJB9ISajxvixKw6GYub95
JB84+b0vO69HxdFNxaLiJ6eg32hz4uWDZigK3TqVYkX6wdTz7/DGCnB3d0tV
1DBAk+u74k/Oe8HIulDrBB1L0gNFN8+3A8kONwyOkPrPsbxuO5IAnSPTMcxz
BO72eOtvk6RAtvSZygXbcXyaCHdz7miA+RHlaT6SpzTKGi+MRlGxayvLnR7J
xOoftP4SuSoIqErtUxcneYwwsyw2p2COENHjPsqAQrosh9P9RvAEf2GtKmPg
YIyPwSupGlQ25k61TzCQLs7uf/VJB5paxe9WESxcnfGg+Tg9JH1RxFdGfs/+
Q8tnHA4OwrT28zGqMjnvfl6WP+s8urJMpuVJ/zw5YjIR1zCEW/zCLGbENLzZ
vZpE/2tD2Zl5meY5FhaM4zK3q9bhR5dF0rwiE//cY3cpKc/HTnHbN8Q2ArKB
5cYaTo3o8d86XVJJx52Z/xwpNsNQ84jaHDA/BgXT9sX9IX2gOXFqrOQdQ80F
5/rQlBdooxVfUiL9YWb8VjjAvRaFerkiMx8YiOktMj/sOICY9GtfA06/B2uU
vVrxUw9s07dTDHcy8HTHV1MxMQpcJ6S1TcQYsAhecbLo6QgSTDqTynJHIRBv
VsbbOYgZh6/WliQfCxJHnlb8GcS0fZ3wscL3MC1zLjbbMoAkqz8KkWbjmNu1
J5Yj+B0SOwZSTnMzwNOUnUpZ2YATZWvTfWUJjMSek+gOLYakk9RZlx2kv3u3
fCtwHYBfMMeiCMcEKh+8YIuvrkXbWOxkaRwDIY2P7m41qcK/FvEP3PgJTG07
mO2yPIy2abb+7+J0HHM6mkS/WQGTooVjnoJkH/GNdnl8vx6jL90SH4PMd4nj
3Wt0esC1cON5nzwdTq3qjkR4GW5I2uek2hKYb+V++7BiFLabDV3fOwzh8sL0
nZNzfRCVfH1A8PwUeOf5D91vbMdMegBaCxkw8z1qLBzeh8u3uUb9T7xHYaJ2
q4wOBRYN49MGrQT8fuqZs7uWg75udXQQHwHRATlOZ6E29C+/0b62kwkpM0XP
rvZKhCV0yRptYkLljKe9PKMJOdcGqP5N5PmbFH7za2vA+XHmyl4hJoiY6Eou
9WrUr3WI1MxmoNj3vBZvdC/s3PK+t4gycVzxzK6tkp0QUKBnmOWPwaMwzZ3b
pg6Pjzus16Aw4adz2ZSGaHiLSqRr/Z+nqMUJxRYlUB5tXz3lS/Kug0mhdm0/
vFfdUlvIIXB7lWji//M04uENawNiEBwufN7757qhwrJ78ClsEruO/Pvt+++n
2MV+8dI1cwIqw1/0vSy7MfbmU5NeLhPrgyeEK1VpCPSdSqudYsGc6TjhHtSP
CNmCA7xydHD5n2bfKF4HygqJgmKSJ+y4/UT3abzG8G7HH8d/EEgV2pz6vWUI
8c5CHePXGQi2ua07ltgLQc0qPdtgOlIMezJP6g5i/T7aMZrqJwhw/Dnc/acQ
PWvN1miRfNlrtbsiN4eGX68W5bM7JjDSpKXLU1QJO6Vzch3dBHgl1VS1jDoR
ZnBbYAfZJ/2Sh04r3PLAYmKPohiZlwkbLkS4pD0E/7dbp1TIPDz7KWahdncb
3in5yd1JYOC3UaDc6cBe/Pyo6ZxP8q2f6cvoKwX92GdS+a9dDguyidfOXqG8
g1iOyeprHuNYopQ96NrWgWzeoO5QyjhcRn8L3uHNwvmW38PGJO9r5ds6G6/p
wqKCtxpxnwEVU3/NJacRNNyw7OzfOgm2aN1X+nvboFm/bGjBRZ53UaaM54Vh
8MzJn3quNAEnvjnxkcZuRKh2nzbjJaBgg/NBBplITg22bz5M4KE1JXk2ogms
iHdK0uT3XbaZOZO2qhk/bzuVasqQ/ZBXoc6UWY2v5QsxNCGyP13s1xdzoKHp
lVJ4CMj94dlaNbm9EjazH8++HmDAq9X9zTEbGk5d+1lLS2ai9eMxa44ECl4c
Vk84Q/b1JiPZHUUTKaDq3fc9Rua3tN5xOTZ7KsxebUiXnWCh/MR4UYpwOb6O
Z0n98Wdgh1F49Wq5AWheSy2/ysXCbvu4AYoKmb/CopxsvxiQLX9x5N6zTjyP
Vn6txDcBtjIb7m8ib2CmGpJTSO7zjSYjzsve72B0s6HUPW4UuxzSK80Uyf6o
JSS5LoYOpfzE9saEDtAOXuqp4WegZmyyqfNpB7Yy1ZdbQ0leGVr34XpXG6Td
GajMZMHbQ/O2Eb0GRt5SIh/HGEg0fyQTGDeI3vPcledcWKRvh+TvJHagNCvz
xxUjJu62FzbUbCD7saL7CTEeBnbKR9BLi/sRsG+Vd4TjGKLcrnJ8nx5Gxsw/
FvPaH6Hh8sdN4kgp1jmsPNpG5rNdLKEusP8NZO9372U1knkoZ2/l/Jfst5Xd
Vjrkfr785euiV2QFhnua/X8okHlAjZvXyKxDhsjU1jtFDKzOyIuVjujCIdq3
sE1n6Vi4e2fl249vIDLnWhnGJLBC4bfF8uI7SEpqOR96RWC9+aWW4/r9GBNP
3rsrjw4jXV5Lt+RqKLpR7O8okn3qTlHYX/cBLBVNjliunYSTis161q9sVC1w
crtpELigVhGSa1OF0l+aM6dJvVG5PhCl73pQGqbL6VtG9tcGp01WBiM4NHK7
eVJ2ElvkEugHZjqwX/efTbqLZP+OalDM/EgFn+7MFc+Rccz2blpaDn+HD6qj
Jt/EWXj488KsEKsWu8N0zjWQfGSXMEF0hGdBWDtpUGU/mY/adndHXpVCbEYK
Iynkvt31M1g2qhFPxZrUPgYyYOq/2bu8oRZd7bdFNpL+sqxuuvL9yTu0BEqw
H4ojeWu7j8vMeDWIq75lCY5MHNrQMCEY0g+DE1P5WUoEKjUSz3VWNUPb9PNY
3QomBMo3/H29pQ0KO79wKXKSfk94Wnv0dSnWZ1Qq898nefuXxCetsk40WT27
ZxzMgM1CrMce5QE4cU1RfdJH0aWaOOJQXoFklf3xG0i9rG7mvj9fVgnTJ8yv
r0jN5a7W47RW78OFV1fLjLtI3rL4/EDfuBuH5PKCHNYzofP58p60kHe466mq
LFVEgJAlXi5MtSHWWOVRGxcdXfN87g7T7dAXn5ZmDtBhMmSavYq/GjEC4q57
M0j/loyJbDQsxd0p5qzTbbJ/O8vMR1/sQILPVPxsNhP5oXtmtLfXg43tU4wJ
yac8mw/JT+2j4JDMcxaF5DE2XcczOca3cVVDlUOR5Bs/wWhn7mslkOV1E195
gzyPRzMFeor1YPqupCY8oUNNzSO6JWwQ0rTbRts5GQgYZSy6sJrBYSUc8fwb
HVKLPxR27RtA0Jp1K4zDx8GbWJxwsLEZ3cfeM21imNgpICRT84KKNfxN8Tsc
SF56waE2TW9G+Tk9q5K9ZB9J4HW8c8EP9idyTNoukvvqvAZPEc8w8vcGPzG5
woJRklBzVgQVX55xPu4h96MWT6Ohs2oP1Js2V639wIL4FX3KDd8O1CXNKq7a
TPaPtCwRZYcumO9x3a6jQu7rJfu/Cx978Cxdx+bgWrKPXihn9Fq2YI9Edp64
O3n9+M0wp9RChBomb//iSL5P6KodVm3tCNu6vGRC8kYBa9p08D0VDafCRV2F
6bB9cWOrcFwVnoemerTMEPAuWKV8mFGDnTqneDPIfTy5FOqtd60CXDYH09eR
vIMOjuaTFi34eENwhqJL+tP5V3JxQyPsxsSquaNI3vyZRP88eA2mzu2Z4+R5
/A+PigIO
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk01dsfNT1KheKZUoZ6pnQJS/GjnfIkQr2ISCSSpyIPCb1KwyPPD3V5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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk4lekbx0UJMVkqSrIkFUZGyVJ8LYkmGZrG2CKiOUrily1bo4xs2YqR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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 98->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekb1lgm67QoEiozVJYsMwzRuSV+RDUlEaNx7GPITgtRp0ERNYmp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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VO8bxpFsKUuSUCHao0VS0Y1QqZCyJWm1hRBZErIlqZQ1LShRkpTI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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41NsflihXdP2KQhSFRElFJHnRggopV7kpKkRXRdxItuS2Kku2uHVl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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk8lWkbRmkamUNCpZjCHByyZPlsuWRIY6IoJWQLnyFLhQpTSKXNEsl6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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 99->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns0Vdkfvz8TU24ZJKSbaJRHxjAoCh81kvGKQpKZMNVkyiMqTBRKI48e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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8lP/fxUWKFkXWomzZkkopSh1ZolKWSmVLIeSfhNBUUlkqREWLKHtF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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk4lWkfx08SGipb2sgSkTC20YZvvA0Nb42EJBklOqLIkkMISSo1la2G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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4lWkfx2VM9ZLIUi4kjWTJlEYk5CtpKFlKGTRRREK2StIkpCYilIQo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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 100->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4lGkbp1S0Q2zWYduK6OAsyqpVv5IkpySUGjnEkJzZVEbNVois7PKJ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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8VW0Xxs0VCpEQQsYSQinSJWQoZSpJMquUQipUnigilSTJlKeMiYiI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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVns41eka3SMmOWhrkBokTCRTSkUOLRq3KDXZ2y3HSG45hSTjFqaGqWFm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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns0lekXVjIphAnTj2ai0JURh2SqBxOTUEqk0Kgkl8atQShk5FIxOlLI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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 101->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekbRhJZKtOmImOpmKgsZWbUrYVp0ahGWftZSpTsZafjZMZS0VCW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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VP8XpiRRqCRpISKUpRJaeKWSIltSJBRDEZIiEqKEfEuKRGRXIZTs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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVns4lGkbn/EJodJ+SCWfZFui2JQO2F8rbQexIaM2ySKUQwyWtKJILEWt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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs81GkbxlMqMVEOpehIhLbYFDsxl+TdWsfWSpZ9y1qnVFaicogIYZ0r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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 102->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lmkf5Z0aSzSmfBGSCembjFxeW006lmQ3MjKqyfJSZO1DoZBQyU5i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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k4VV0bljcyFRpUSiEqQ5IpKm7J3EBSKZJokGSqzCENKpGQKAmZhygy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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8Vekfx22hsaYhYyjTKNIqW6Q+CmmVpWwzKkZZEzF+EbKkRKGxhDCJ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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lekbxk/2aGJUfpImycGESJNMGZdihIyQOdmbQk4qRIlGWYahQ2Ub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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 103->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4ldsbPY0UdUlR3J+Q2zxwy9RgqUyVikualFmHaEDCyXjdQiSSo+hG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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk4VO0fxmUpSVpJkiQJr6wlpbqFhFa9smQrbZJsUZZkl6SorJUSQiok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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41ekbxhGZJiZxoWxtmpAp2WO41ZC10KikkiJUkiUNpoVCG2kiS4gG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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk8lfkXx40YstVPixgjIqIsTQoTPo0ka8meSsithBgjUTchRck0hixl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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 104->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8VWkfR9qzV4hQKCXRtNgaXxXVpJQZ1VQTJVtRpLJGlCVCIkuMIVne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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k8VG8bRopWoiT0t6dIJKSFSyVLhPaoLCnKVkqWaCEtpCJLioSiUUJI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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81dkbxy0tarSZSTF+0oyQijRJ+uFDGVosl2wZSxlutlAMohGhLI0t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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs8lOkbxiW7iCQ0pFml2EypUDJUrqiYnIqUQ1qnRqKPdFDRwVS7sULK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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 105->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4lGkbV1oUq9E6RVm1KtvJMau0/WwOlVSUnGuQdehDvrKZxm5o02VV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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k8lG0XpqJSCqkkRWRrkQpJuChbqUgKhextRJKlJNkqSZYWSpIkZKdk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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs01Vkfxg+hYlBuU25hXI5YJZWRNA9K46W8iKIhUiTVITJpUokkl1Ah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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk41ekbxs9EJpUspcTJMmXfI1M0vxuZQiQ72c4YhiyFVEQlKZGlXR1N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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 106->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekbPpTGHl0mS2SZQqWYUlTq1qqFxq9pI2UJ0UK2GMooEiKSPak0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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VG8bxu1FylIkbUqkEhItli6VLGkVpcVOJEoqqZCUKVGEbMmWbD/J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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk81dkfxvVDpZH8JO7NWJqyZAxGi608NSGTspRukq7KvmQJZU8yQ1Iq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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns8VOkfx62Eipp6WZcoly6bGmKTyuKji01SqNC6hErRSsomEevShbXu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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 107->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lfkex4/INdFQGZqKNpdJsqQaxHyoSMM9GdMioewyFcKZaCE3kcgy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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3cgVQ0bR3rTJJWRlFHeiJKIJD+VMlIRskd2spJKimwio0JLIiorWUVG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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41Vsbla5Kuq4MxVcfB6UydTSQ0Lq6kjRIZShjZkVKknR0JVNIGcul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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk81Okfl1BshEIiV6ImlQ5XS2/kSpTYcqyWIkabzNboUqGlVFasW2R+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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 108->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkfNlKZmEKNfFI0pWUMxUcLcjeVMmUby9j6KmuSOeo4mYoKQ+RL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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VP8XximhshQJkSiVCmlXqQeR8k1KJPuSkCVClpJEtkrJUgolJCkh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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk4ldsbPY3kRsoJuVxjhGtW5GIZSoYk0kXKVCpEqBBFoek2ITJFwtVN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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk4VfkfxzGFjEJuuGVN0UJiVCZ+vU0lITLIT5JsZR8q+3KTmVJZQkY1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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 109->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8ldkb10JKSSZjnUiFTGVJTanp21hSKUkaLX6F7m1UGltJETeMNMoV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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VI/3loQ2EWmTpaylDZVKvdqkEIoUwoeypIVQWZIs0UKSIqGS7Mq+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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41NsbV6Gb3EgLkaUokgp1pZIP2iSUba5Euoq0ocjNaFEJIUshhUKy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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4lekbxynJXsQoUbZRtMiuwhcpmUzFzEi2pESW4SeVokZCJ0ukmkZJ
tsmhkq1CMpaj7OdwnHMs4Zz3fdsUmqxpRvP+/niu53qu53ru+74+9/d+vlp+
Ya7+i8TExH6n1//3El3mg/pTAjgOKZ0w3CSEpr5S3O2iOuSm9ezK/0ji8bG+
M8Jl7ci4GRAXbU7CSv4r6cHoRbdkrbM0h4Rv307H+DcPQVG71V/tovCmwtSi
BV3ouXw1Tm0/iaiHtiZ5B9sxEDoe/c8ggaxHGvmfDuYjqObHhAEfCmLODzO5
uWG4L2GUKaDPWZWFe5+ntKJS5v32Zn8Ssc0ulbza01D+EMJ+T9/H2btrvtbv
RoVShcHdagIMJz2/o9IcRA7m7k1/S8A3aL2l3JZ8JPlRU+4HKESG8r+wC9ko
UbE2/0jnj1VjPXELCcex4NPMETrec0NpD/WJbqQn8AvPS72GnGCpz+QdHlrC
GsknM0I88BzolLRoh9SI/SWxZSRSfI7k5xwaxPkAz45k+SEEvtYSzrOfI31i
i+sDTQoSv19gHGH0ofGOKJVlL0TuP9ZKJj90wu2gYVJhAgXmmFQbL6kOKX2X
pEkFCsuXu6unJDaCY1I8rTNJwsNeMUGJwwVBOGy/rEAge+3XiiYWC3M1PIsQ
fQqGWrNK6Xo8PFkTeNXTl4C9BFhSVj146aWr/6WDQLjnqGHZXA7UxM9qLj9K
QXntSdPx1Jc4HhLmP/aEhN+KjvePFKuxhzn06303Cn0ptwoqvdvRPFQanjdH
8xvd3WujmIC/VFe8qKH5RLbVL321sRUL8yd5et0kEgcXx2w+0gsqqdBVQpGA
nlF+z9wmDuKj21m6a0jEW64IzNStg0aLA55r0Xyzbc83qXejvMbm8bW9NL/3
7TGJuc2oOp5k51hC4vxo9I6dRXxoMbnqq/8VQeJA0bbPn7pxw/3TRGKiCO9W
fM85msuBar3GkKwJgZbWM+mPepqhovODqVCZwlSM3zunvRxUe1k0nKXj5RuJ
B2935MDhudUPIY4U1o2MYpsxD+VlsResaL0wRx1S+zUrcczq4nSlNwWrISMw
zIbxKWUzWcEdAUPvrr1+eiUi21XNArwodDmEFdktbcFMBCOUfYKEsllwRMez
TiypHnVnnCaQyND2H+sVoHzVbbvo/BEUHDU9cO4hH7+Jrcr21yLgMyQ1YV0x
gJ3VIybZ3UKI8fmyX//Oh+S7mtVDtrQeMiLMR13/QvnD6zuZURRWjogsihWG
cGWbgihqeBDh0eFfOk9WwWBjmPQWTwpHNuQcK5nswxvb/M3Zb0kEinSUozwf
w8fuoru3FYX0EvOvk20sMOVMzy6h+Z8qa7gf31kLiSW3mwJ+o6D7p7t1yHQr
ZIbqnhQKCIgOq15UBAv4ydhb4Ezh0e+hdU5Gg9gUl+RTq0HBFz3fW+5KRc5e
d8E6Wg/MsIKU2YB+TPxyvCxn8QikapgmP18Zoev3ZZmtHESs/4r5tnNn4J8W
5rHyEAVvBRmLf9RY4JunFPtuoJCzZ9P7CLcsON+8kc6g9cncOhh3aUMz3ug1
yKqMk6jqk1SLuP0KeuLDU3XFrxB/cbz4V1ErBsSKciLGCShfUJh33tCNrKNK
3mW5BDrSnL3fKfXAbMfckeQvIjwwLt51Dg2Iu3fTOoPWt5TdCubXeT4Ewyy/
QIjgplraXqDLQ3Xv2HDjTwQstQ3EBMYcLDSmOVRMEFhKKMRdnunE2bvymuKq
FAKf3+wf/LEcn1tl9gctoWCaFb01PpkHc8GxRVxDIfoMPGfODNWCkfn98ZR/
SeSoyFeop5TDLNHgbxtfCted4ywtrj+BR9LYU40gChlNB6v1qwfBVft8hMyi
sLvJMeBATh9ilXmGh6PpeXWO8WG/70LGzJ+zaodIxDXfONCpxMXWSfPJ6RAC
7yTCdF4EVWCfkoPzwXkSpSb15ERrC2L9lsb/tEBCWGsf8Fm9A1PTHpdLWAQi
+eGTOU39yNSwzT4gQfeTMZ6quvEO6ufdXJfR+n7aaEbcn+Ijb22sj3coAU68
wbkoVTb+2ERcZ/5BYjgqILbx8CB8g1dv+fY/Ci12ak0r+9kwNSn6VF5KwNZx
vtehtQr2YyoVMnR+5f17Ghz+GIDe/KBrhbkI/gXu3CYjAWK4O/d5B7+GMm+H
V8KJBpza5vAhq5LEvhFnIs2pF1PJkbPZ90lsfue1dNfZJtTy8kpO0DxKgkP5
IR1tkLZYJdTWphB7qSuTca0Loy3DKWmWFGrX7b8auJKL+sak698xCLy59PlK
lx0HLgu+2oESJB4sEvt4P4gLTq8Sv7yfBKPdwnjhUDMWPS2UH8smYfpio06+
ZAXyUk7KDUdQ0DQYi3sWcwVSqWnniuj+MY6HVWt3dSG+frgzZBHNt/eZn75N
D+JPeFuHnSXR55q2KLSLjSrm1dHkTNpfAh+VrQm4C2dF2aoyWt9b/AUXStNe
YEr22o5fVUnYcoU5V0cbUTkdLMb9Sv+XwuSZtOwePN0U/zBYna6PO+RlTdeX
rL2nzHiGzidTN1O7ug/FxcEhFZ4E5p1abpLDbMgcVFs3Qc+zQoH+FlW3Wniw
Z12wnfZTqyXPpnc4gzCzFBjQ8xf6nezRt/sGYPSbQGPiOu3XQ5JE/WYupN9e
na28RWD5hjLeF5tSuJ6Ukyx1oRDukhrUcboN5++QEoQVifq5bKfbLw/hxtb0
yJ10vO8+5C0pb+hFhMbbb1UhIriv1XEpX98Cj6Kgn4sUKaxVrO0ZZvNw/t4q
u6DX9PuFDEuTrlu4I1/9Wpvm0bf13jcVr8dIqpOL1FpLYU7Na714XDv+rStc
HKVDIkLpVO6jnGbcypPpELZSqLe0Wx+azsfPnwRBu3VEkFKvac3bI4Cx98Qr
8ZciXON/uSl7jY0p6cXezYUUYiJ+mW4tbIb5/r1rFOUprP9ovKEwpw3JhZ8D
y/+i+/VMoCLRxEJijIT04T0USotqu/480Q/dmEYn+QEhOhY42SMfeJid7VEQ
7xGi5Zy6g41cARR0VfZfo/1CVnDH555MAx4v8wm+RfMOCtSJdUwXwC7hVKkN
S4SNUhmDtrubMD6f9MaF1u9/t1a4jQ==
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 110->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4VekXVko0EinpSqX50WSSMCblTRoplw6DJJUSSRlq5LjLIAYJYXIJ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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VI0bxSetlpAKFZUSJWvkVakjyVJeS6RIIq2irJGIlCQllZBUSFEk
O9n3fRn7vszcO2MsvamQRH7399f8dedz7/Oc53vOkTh77dh5LhqNZrWIRvv/
7+aoucbf47nQlZF80S5MQnqwR0XNoR8Dd9xWVlSPQE5nt1KnXRu+9UolJbBJ
rLAZuFIh14IfqvN3oyIHUHKi6VX7TBVW6E4SOaUsCG6892fh1VvwKMxwzRmQ
iPv1YXR0pAqPYjZ+NAgn4Klyy7wmtB2lfvLcXe/YGFecXRm5qxGXnshuOtnN
ROCXKpmnUv2Q/O3dMPuaA4NVfvdI4ybMCoomxd5gwG/SNLVZJQvp5Udof6wI
ND774PVNrhW3L78RJ5rYCO2ZmEs52IoDH6fWWz4eASdLI72nrgMZ4mvS+2ZY
2MtncT6xsAu37f9weFz7kJFUYCVf24GgzCqOQ+wgaPLHvY+FeEBzYKbxsxUJ
05tPE1Xu1yCGf3rsw0Emal+kt4a+70Ko9OpdkBvCm9SsQCHvTvxcxW7R8x2G
9ZySL8O/HGvvCoi6C5IY5bWTk5hoQU4DbcZYnUAYZ5wIXl0Eg9aWf2RTCXCq
VkvRN3aiiDdShruOmk/u0rvMl50w2jknwLhH4Fz5xbt60XS4Xr2waX0zC51L
3E05vC0ILqdfMsklYJt5zCNoURd0d93w87DloOfKzMd7c204LQzy+hY2fCfr
Au4P3cJfi8P5mWdJJJnlqt3+3gpC3yLqoSkbGpxtt2Z4eqHGTrWP1mJhfjQ6
LXRjI9aIbFwzlENirzT3livF1djVoKSTacLG3hf0zwXLuhEtFVy3aGEYKbtF
fp82KwFRwqcx18iCZd2U7xKrQuxFonMJh4kDspFKixW6cD9/2PRNMhO0zZ+T
17npQKlRsfDoGRJGt7XfOl/MhzMZmKz/kASttMEs/2YqnnQ83rAvgHrfa1Zj
D972Y2qknj8nnUSOg4ZhXmY5vOpvhuSLEPAaaPSxJ7IQl2nuk+ZCgtv9RxvX
1jZ4XLzYX3aFxA2TFi/dijb0qhzvvOdMQjX3yr3IuBJsDGuoVx4kQL8ufjXR
5gviBTIFbE+SEEsZPBdYUAOy+u+6y/JMSs8jU9bb26FJz4qopJ7nO5yg98yj
FVINxZOi+ixYBzQ/+1e3G5cepV9KONyNk7d8Iq77ZEMjdL6k0o7EgMKljkcR
PVC6zXNXl9kHOm61jNVWwt1H9Rn9PxaeWJyk7TGn/q9Peny9PgexX3crPvhd
BSu+Y+wiLRIROcalWZHlEIsz2PkyicCDrGcF+5824U+oyCcJSj+i7vudgr9V
YPbYp26pR2yc9N01xHW7B+QqA0a1NhOuqe8s2WjFn9K8adtdTOjeN/75bKQG
V39uybq3kUQXt91sb3cL5sPdovz72Viy2ez6p031+H5dPfh9CYHil2nJebY1
6Esw/CHzioE7x4ot7od14rOGs37vFAFeN6nsx0cakHYmgr9PmIXHwudcrit0
Q2Kh5HrEGxYitthzr9SpQ/M+P87ef1gY2vmqzsSkG7y8a7pa5AhUh1wLP6na
DM1nmpnGGQTUG1Ruil3phKXiwA3ZBCY03pZlS8aEYO7PjIcQNc+ug7oR08p5
8DNcnSctQPHoyt3xKvNG+Oq/XXPHkYGanFWdy4hO9Gf40IavEUi8u1O28GYP
tmYu/1bTwcTLncN7mgra4e3YGaJM8es8LF8mVnWCZhMVdfooB+fIZ789uHvh
6pbwPENsBIkLhofW76zCqTj1gW6hYcz9G/iCZ0sz2m7KRxk6kKCvXXS/iysF
pLystN12Em1Peo7sP9KOj26V6lezSEzyyk96pnQgpOSK3VseAlp/pF0Lb9KR
6zHq6ccziIz04A3+b9vB9qryZSQPoPPAgJXexS6M8uQRfpoUT7aeSNPLr4Cq
9PGY7RoMXHe9yFtalY7aroGdNw6SMH88NWDoVIOcmJn4fSoEdLMW7xu6U4Kz
Tw9VT/QSOKLaYpXL04FvYkdJ3eNMxEoeWBWHThhLTa9du2kUfXytlw9nNGL8
+bbnXMUsTEluqvlqVgPV9rtVE8rUPeYHvakefY3THLXHJudICN7QMpJ+24bl
F1MfHWtmo/yWrvbblRWQjPM70RNEwszi05njS2swU7mxyG+cxLmzCxvnf3Xg
5M9LhwhK39tZ62IkDIqxbME8XXGc4t/XebVM62Kwa26FtMmSCOVOVV1cUYHG
eMsd/CtYCBU3pdtqFkO+/44TzykSs0Zpj5aP1YHeUpE4u4qNIfd0MbuJJiyc
mHO9PsLEjv536ub+3ZhnJ3D/1WdDP+haS09EKdwYGVXcF0l4ZYjmM/RbkTya
mCfQOAxhiUVaITw1eKV1kd/9AYG5h+zjTpVpyFnr+EL4GgndnEaVC3kZUKH5
XVlmQeLYjsV9tsntOFOf5uOnx8KEiHNkmt1r/Ht+6MMuMxK2zD7ZsbV1SH5w
ooorkcBDmd2VKnsa8V2bPjeRQiJr0mHIidL3Ff9sbTj0QuXbmkNPYpvBF3tu
i+5HAjSPDIc77sWYmiB2J6lT+tkxSWtY1QRak9MS+eBhhOqKrifcypBc7hPR
OkOghfeU3oxWBWRqxDuui5HoEV5+4WJfP2g6v4tcdEYxLpBuevZMD242TrYX
0QdhnbJHoup1HJ6Y62x/EkpiaItRu57TbchzP+STtiZhvcn1h0FKObQ82hwX
5Kh9H1Xexx/XifsPxti98iTqvZ737q5uRf6SaJOdP6n73K/3TcM4FKSqjcRT
yl+8z+1z/ivbCf4cESnNh0NYofGmOdmyDbP0g9OeK0j41dmsdDnTj4n56CMM
OwKRKR8HGUubMXc1Qi5Xh0Rll3ZPaGMHUn2mDgssHsSauc0ZzevrYdh+Uj5u
jADTRcys2KUJR4w6+fSWUXwh1/4svVQAo+xpqb8fSGx7F8IilZshKXjE0VKA
iatJvi/3fmyBVUl8cyqVT8L8a9T7BMpwMmR7MbaR4KxWH5rxacFWP8v6S3EE
lrzK1jYxrEF98qdQQ5KFLr+lu/fwd0MnjLs5w50NWvRPE680J1zK9zzzhZrX
9uBrYnqFjfjNbWChEMGE5rzZnLdDD9yYZxm8nhwUO2plTfpmQ9FondbUWxIz
5+sT3X1bMHrvTWmVE4n7rV8y4m2rIFcT9JikeKov6rR0afdHuDosPD8YRsJD
yS5KYTAaHc9Tb5+g/DJkR6b0aEULKnquDqlWEdjuN1+xIJeC3J1ZSpeSKb9o
qy5MLyyCS3nqpyeXWXDtXeFdGFiF0ZjDfTRTFhLG5qZ/KzTisq9PnpobE09K
xWRPxLSDN5AQDIwj4Vyc3xDP0wOZ46+T1X6xYFTOuzldtQ3VgjLxJV4kIjVl
esytarDP+PXO/I8MOH/wTHzj0o7kJ8GDSbK9cLTq4d5mXwq/FSUBe+RY0D9P
mmkyP0JfXNpsqxEJfn4NJfOXtRBSU3av9mCBz//M6c6aCjzgPnAyp57ab/IS
QZGAVkQm0Xe9iiewTFU+7KVEGd5uE0/7G0Mgi6aoYSpHhylHv0TnKQHuVfPS
b2+1o5IRuDO1iwF7O+c25tkuRP+1znQ7PIRLcz/s3RT6UPoy9ZyLOAHhleM2
3Ss6ILvN5vcFbYp/7eozJl5l0G+McS3Ipng0fFfrdUAHdqWdZr2bZ8JS+O/2
YqEOzAlr9SGNRKrfhz9Gkz14Y8v88DqShOt7s20OBb0wJAyiQrcMwZVj9qzB
qxivpjbEXvSjeOYr8FBwRSt8l+ZFGcxwcPKgyimhhg7keV3MDNo0jFSie9Zo
ogNs0w3lp85yIPpf95zSx3Kctr2xvryLCdFjGZvajVORtFXBemyYQP1ET+kT
rmbsK//0z42rBJKmxB5rk0UwfalS9iOUuqcMA8drSgN4EC+sadlO7S+v8KLs
gXBYGzxIP25JYnWt5oWzY50QjFR733mLgYTHxu7uO8uhJiH/z45EEnNazL9G
/s0YWKn3vpLSd8a3kARd7nQMF1s/GDKkeFA8HrSH0gtXVJFI+hiJvA+s8w2x
pXhv8iA28QuBHwHNab7N3UjzcTdSGhxAr1TKcOKWJhjfviMdvmYIjjG3F2wF
gsHftOGeP+UnnnTtMGf1SsRuGeb/pMSCusFqhY7lrdjL9f0YyWZB43ebs15X
AsrI9Ro8lP+7rpe58ZCWj6NyKYtcvlO85M9X6SkoRUtxwHQptR/3ICWVS25d
yB/6OvLXmg1na/KNTlIzmGqM24/eM7FEn2b/Ur0Bfbl3Mzb4cqAQ6y+04Wsp
2oz3iSxxImCdLWx/QiAX73bst/eZovKFkbfyTFg8gr83vltlTyIqtG7vhuFa
bP23K3G3PuW3fXN6K5VKkfwhXSODxoJHAWdo4r82/FE+f200hYCB/1hC11gz
ugxajq8zZELt9JvYzU01UImPkVSh/DluMuDEx4F8NJYkah6h+CMcuS2iO6EE
dvtOJB+eZyHrO68qPa0TiyS/8/t+HoLHOfpP16fNmA6oadH8Q/nVrNY49z8t
lE67XD2DWDi3i1ETLFiF7jUlfipGlD97r7Jt2lEEdcOvTAbl5xpKv0T8NB4h
NmXqYP5pEglIFdW2bUKa/fGxGGp+bYxIxf7+KgjG7giaLKf8gXftREJ/FjbP
2xdtKyQQzZE8d1gnGfmcxV/2rKTyOE+k85ZlmShinhC8x03xUllHxH+uA6pB
kxkSM2y8jho/+tKyBb1tUUuWG1H5KT3n9aaRJiTVZhYpmlL3IX/EvM6vCzSx
oeqpHwSUDVqnYqyb0Usb/KvUTenz7PLi3eo1iDbLyVam5rs11Ev7oFgHPisP
NYtzU98jIsUwjM+BSrG8Tac7iWJ292Jj2jO8hY2dCaXfaSPGQYuyNiQES75w
iWUiB7FTr/7NQET720nP95Q/y4WzFF/Ww7NP9Jj8OhKyn5214mbrEJXprDK2
m0C26c5P3qa9eKH30IMdwcKKmwc0eevyceO1wWVPHqofPXePXqvdDQGno6VC
VN/lOknk3fQqQcS73oysqyxExtpp8XAGYbP1Mo01Ngzn4FaH9/b5mLarSigJ
IyAoeGosfWM37lzeJPf53QAsShQfRt+thmSKu4v4AgmL8oWbyh3dOCLRLZA/
MoL6qPaANLMEqNHVNK0pHjexXOaOnOlErFLMh23VDOw9/TzkcUQzFPzLScdJ
Jhw1TtzTKvuMH5uFaxaOkDh8+e6BDcbd2Hc4ZXz61RBe+VRwXoTVwLvUtmtB
nInoPazkGqIJmiojDvqfWZjZe0v+mloBKv3nIkKpPnYp8rJ1H6cF99wkhSpX
UPnro5ldwfko9Ow/5ZZuTvnhpvtcU4fKoFXYGz45T8JxXU1Ti1k5VDRty7TT
CPSJnihoTulFx2XdR3WCHEzslVNLbypH/U+/ybA+inerVKJZuXS4vXgXrhpO
9c390r7bvDMg/zzVtKWIQNkKG5MXov0Iphmf4dvAADevjMWhklakOF1b+6mC
g1yyem7/ilIYTUbtnpAgkeKi8Ss07hM6PkxX719OIjj4RtqxTY1wag93LKIP
4YBVgdWlde3gizQR+ufCCBwDQ0uCbnyB9fWIJ+EDlJ4SWlYNF8UiKYy1V53y
r0KHaDtd7xKkPw4/8MebgFgbIfsvTzcu0LO8HZ6wMOo9n2Me2Yyp+q4Yxx4C
zw0vnDrwoRfnE0ouJAmPQ+h0ioKGeDVCYycNXtJJVJeNa3YqtMLIfGzMmMaE
MF/60iIRKp9qux2Uyh6BhW9PpvDiFtD+hMwGvKT66lBky9OPVZCw99pXRt1f
1HdG2MMvJXD8taF5dQnl/2ppouJhaciddf+aEU29/6TcQ0/uUNT+DCrTs6Xu
jfQrz11PR7TdjFJY4DC8lPvq6vTaoWtXIC7Oz8HMbZOzXyxL8beta4lGGZX/
r7+bCj9mh/VLErJ/WJGo3fjB3vFrK+4Kb/G/msuGvdTTyE9Uv/TjWki04ONg
vPYb//ejVWD2vM87TWMj523AsTtOedgsJWiZxCEgY2jR6nanHV6bmN7/DbOw
OfZhgmh0E24dit5ks42FvunxC7HqHTgTNsZqOt8L+aiYiLxrWYhZ1LtOlPpe
j9cP5NXCcjG7vodXPJWE6bDaTweq7886rS6S7mMg+o52kdDZLJicOFTX1Evp
debwjwbXBlTmGQecW8/CnoGVToE7+xD49NyON7spXkmLWQ2e6UO98l+ThggG
EgXrBkfDW9EsI0ZXSx3EuBadLfS5BTvevLkt2knp1ebFotXNFRiJirix1Z1A
bX1t8b6Qd+Bd/GTDAYqni62fTF052gFJ23ILx/hhyHTJPrja9QkZagevO1P7
WOKxzHO2qwH8lg5Fe0SY4NqjstlHvB9bGIHyQRODiFKtLN1VmI7x7LCEtfEk
JiZWOCbeSoWdy1q+YaoPKIrtnn/m2IyJLzJBpXMMjA8sY26xasKoOSfE5jOB
iO0iGzQZBThsFSDo4c/CLuvM93JS7eho/F58foLAaI3xUlEdOv4L+tQ9mEf1
V+8/v7c+yoK3+t/mBC5q3yE//ujr6yB0uiNIgcqbuyRfnZXZVgj+9As2p1+Q
iF6Q+UY4VOM1l2X0yFEWlrFiVG/vqsLDa0dp3BTPNSLWLLyabsXaK5NnRCbY
eC/O1f6urhM3Qup2JW2g+lhi4mYX50KMD+lc5L5PYnOq16+akETQH8WFax+n
9DwRrlXs2o2TcUdogV9HwAlQF4i/WwbHdqG4ZVQ/io5hVA5EUM9r202eLydQ
vjVh+YEPnfhP7R6XrTEHitmxZ7htevHYRTH58MUR/P4rqB8p1YrgALOt1i6j
yKG5ns7cn42Ohdyp859IiHKfvzPl0I7HmoqS26eHQT90gG7uWQQ+lqPC4X8p
/ooNOMTZd4Otq1DrQfU3dZ0jcbt12qArcaLH1o2FRvsbjSqj7eARX6w4l8CA
WqtB2PGyUnjXWoovUHlMUVGG5nOlEqX3kn45FJDwbbiWLS5Ug+vTyp79fiyc
qtVLW5LaApbb2R4BIxaW85U/FEzrQsOr/bP+neNghyeeFZItgH73sVMvTlL+
3K1KqwoowNTyhpWZElT+YcSbTap9hnWVm68U5T9isVe3Sgx0QT+t5mnJdwb+
B2oQNA0=
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81PkfxxXVEiUdRqstkbVNi027qVUvyWod9etiO1wRyVmOlHVOGleE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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs4lOkbtghJOYQUOYaylXGW0k2hw9JhqJzXKSNJq2yr3XLoaAulItU4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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 111->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8Vfkbx41kfiGVsVVGUrYsyWiU5MO0yzqV+EUkyTJqcBlESI3QwpSy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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VP0bxgctlIq0L7ZSkrzK+kbdKhUSQipE2SL1RiXakKxFqciaPVRC
Yow1+74z9m1mzswISVSE6nd+f811rjnnOs+5n/t7P59HwuqaoS0vhUKx4KFQ
/v+bnB6pFhnVCb6KJdkvf7BQaJcSYNrfBbHVgw/GSzqh+0D72FRsB5If118+
a8eC+fGv1L+0UtyJubtTu41AS0rkt18bafA086Rtk2djLi4xV7W8C9ddNZYu
NvsMDb31G2vrGuFvqN89pM3BbMMhs43aH1Dfq61wdg2BTgVLTrleO7KlO7dS
X7IQOUJdaOb0IPgopzPTnI0L017Dl4zScZxS7d4RRaCiPy+xS60UBywHXQaZ
BPj7NwS7SLXB6XXDnd5YBowW8/gdZxeAuO3VRG9nIVri8R8BZjeUU/5sz+gZ
gbxRtODQ1lJcjErOFK8nIF6cMyFxLhlTVpXPHd0J1D5esDhLb0V07HMn3WwC
K5V/1oY3t2L18uOv2pTZoPkOiSwcaIP18p05A5FMCPLefNGeVglvgefvMsAC
JTrbQ1TXA4c228+LWBCIDArcs+NiB/5OrIyz6WODEqfG1xFTioa1jTZmgiyU
ZFjrWvBnYrwvqjDKgcCWV9Y7N5fUoqI5bFbYhI3UgBHm8akC5EU5XJjTJ2C+
+2SDvkgPhA+5Hrv5dgTDQzrvrZKjEONJlyu9QiCBmzvDU9MNfaVNZdd9GZB0
He8c4G1Fy9DL/IijbGSfllPm2d6A+kmbigJNAiWhcaeFd1VAaKX5EWMbAjQ5
+3aejY04/mfpvtk0Fpz2LaOMxlWh5khv6NFK8vrBoYIUnWJYJHKDBhZI/bZ/
O5SmHI7tL4v90v4jkKmTkSwjlYOTvhMi240J6KrfCdacL4GD+UHb6HwCNgxT
1h3TAVR7M2ZCZ7kwXa+l986sF8VhzOaT4EDC6aBSkEIXWgaad+Yqc2Ei7TZG
dezAS7tVoXtXMBBuSv3x1asWt3wKeLbLcjD/jOFZ2NKL5Jobc4NXGfCt7SJ0
ZFsxWzDFt82ICXVLLdt1OzthL2rjuG6awJWsHb6m1Fq4n94tk2xLQD3/9HKu
cT1OrFcYpI6xseYGQRvoKkHdxaaZCCvSb5aejx9d7IZBkhCvZBkDdTJ4pr+n
A4c123cVvxmG8RiTzhyqg9+x854uYSwk8+7Z9OdeNc5fz4+LWESg6NLEcWpa
F04bvvNdLsRG3Ip1E+dp0egV3L/smTnp38DYV+sFGlGfW1sUGsbBxO1UBXZU
O9RzpNZu1mHh1katubGIbqTdvi97ElxkP8mWtCSa0XQ7fyb/KwuGjvX+v0pa
EXHGoCXkDwc3dCef/UAH3jy9YOT3hoGhmzbL0kg/i1v9k6fgzABle63iSIQV
zAX4NWmWBLxLhu1TPetwKMhZ8a4zC/J3yg2/Vb3HxfkF/ffeBLwkY/UCFFoQ
snzR1RfqLPSnVUqHmpYgWTz4WuwAAR26xA8FLh1yd2VE55OZOLv11HNP5UJc
f0vfKLqSQBC4lMqhWmiItP5gJrJQa+y9U3hvC549jbvX+YAJ+yjaKVXmRyh+
HXyj6Ewg5Fz6+pJLdZheGzHYZsxCQkXYUnW7dmQK5Ka23GVDa84kyDiZ9Muw
xry6OtnP9vtRBqQ+8VeevNroTp6neXnX1F0xUMlOXCFPnhdivY1lmHs0YjZ+
NlIh+7lEdqT1lXYH3IPmqM8jWBBvtFvI9KzE59mVloXzpJ43T9ZXHa3HmkLG
s/knLHj/FrhfdLwXKocD6wbVh5FU2Nc9mdQKr++/Aq1+MeBT8u3Jpp15CFwm
rGd+nwBFRJNyvfUGjmudKbU8T+Ay00a9JqceRknyEk5ZbAxv/j6XtzYcGqFv
ZxabkvfLKY5ZMF4hcFB67qkrge7T6xMaFmWiQihPv7WawIXOnmTpdSm4+yN+
eIz0i/zXBd+2+Ew8Fsi6kEheUyK31+RtvQ8f4TX7Fi6QemSuUu0WasBm9x76
lB2p5wsZhrch6Sf+5u/+q5kwSFHR4X+agRGBF5+ELxE4d/SIi4BYCwqyRPwd
ZphQEeBcSRpswzJX1zU2FWwYlHxgVcnTkT7z1T9+5SiKRi8VneRpR5OP5UpH
azaCW8NNewWa8FL89SpPbyZoZd3XE+ZqMP1leVh7AQc/P6ntshuuxRnht/bj
BaTel9hvlDd1ImBM38inhYVLk35DVtrdsG9K3D9WyoYvT1hUr2Uvyl5X1V/D
CLbXjbpmtXYhtpTX02aSDqEqeTVTpypsSwm4J23AwoaQKqlNNjS478z1txgk
EDMdsHvgUQuKVtUIWW7igpbrLBu6oQV1w+o/Jck8F340JnH0Fh23/r5JVczo
h81aizy5WzVYmKbaZpzjQNrMOUNuvg5jP4//Pbyai7PR/41veZ0HxqV9dk+y
yOeNy5TVYnowbvLpwcNsFvw1NDtShNvxW2b6qH07GwfzWx7vURuCHC2p5LA8
F72n3cL5bg/ANvtKjcfqLjStcF4l8ncQ4nUTuww/cSEsqq55M7sbF2OEQlds
ZSJVoua1dnIuTgUe+PztOYGak79erRGmQ/DAxhNbOExMPFq6ZPdNOgwvfWIK
BZH6slaV73hXDWe90YCIXg5KynI3b+J9hmivPYOW9mSer/mmYVXcgdt7dGXe
kvXTDPwc9yILS5o/Vz8i/eFketdE+dwn6O51ng1mkP12Us08t7sG9z5Jut0n
8/3JtbRsCf8OSHD8En4+4cBQcLYgkWiDt2nAXcvrbMj8G/Lz7vcU3OBqmu4w
JKBquGyScqwRZ37eWCIwPoLgrjHVidFW5OfccH/9hQOtqXd7U5cWofjFvFrH
cgL+IpFF1mQ/Jjt8ac58XAyLVqb/aWzHwyRJ9g7GIM4ElvWYPe8A5cjxwgIR
Npp0pyptNrdApfWx+pdRAg0xvV49d9pxzHL/hvZ9I9iRJ3Hqx6IWmFRpDDUK
sLBHZNRuwKQLrvETuzNdGWh6euHg05tNcGr+fJR3Cwc61IbK+u8lcPygEu7Q
x8IMzyDvk+JGCD7eNhnrwIR4yqIpT7cQuKYs3GSReibR3gZsdq+F9AvPMkN1
NjRUFRlmmWQe8FnMvnVjI0smJExduwc629KWXV85AlrwoNrkn3jw87icZ5N6
v6Wpr7B8TofX4Wixe5bDUDXLP/c+pBi07DfF30geUX3gPEuPqYUDXULFi5y/
bbq0aU09OsK2sP3uk/Wsc6Ueohyiw5fvfvaJoUFsybcReedUg7wnbi/XjbMg
qfgztMyxBhTBK47Hn7KRoPv0RekUHd4+5jOSO0l/5Zv0KvGlQafslAGFnPee
DzUietzv4UmV2swFMj/WVPCFpl+rQbDLuWmtFyxkf1ox3ZxaChMn9dv8MwT+
kac5jfPXYXVPnF3SKzakNOuUfov0gZMttPzKDy42RNEtin+U4Qn9ICHqREBy
d8+/+3jJ/jr9eFY9woGA6Ax1RKQftvkhKaemPmP4FW/UId5CVPFVZLblkPNl
fMGNZlGGpuS9GyR3k3l3+w7zhFk60tV1t5ZKExiJ3Ev03CqF59YBo9sXWTAu
35H7rrAKgk8Hle1tWbhqa7UvV7QC8tYWi3dXsXDQP/M8Ta8FtwyF1Yu+suHY
cG/MhdOPkFXdXXXBbHCaOOlG7TUwcKHal5P8VKgu/a/02kzsj1dsK5cleeZi
kPVK3ka8NL1LkVvHQYUnW658kswXJY0I2SIW+O9K5ZmsaYBy/Mixc4UE3PSp
BX/2lyK7W+9saxsbqhLrs7wtCzHxeEa3Q5cN6YCtUmkr+rDL9cfvJzsHIRNT
SksSS8HsV6Lq5DkCtreJQkpeF6irPtSH2w9g9vopeYm8LNzktSzg30vAYuiB
rKRlG85kbWqKWs2BvQ2lZEd7EZyEXiQqkDw+K6fE0VVvQJahp4n1ABP0vLx/
966Lh4X2ixe3LpPfc21zbza7F0baZZYFX0fQbb6oq8CjFIpvH+w51s4ERT3C
T6uuHXwdDlpcRQKtreuNRMVb8dZLO5e6mINuYtu5eZVmSFa9ZORFsqBQ+azt
2p5y8MVf26RixIKmG7+9ZacXbpuU+VNIP+lmm/4uqqNi+sJ3/bA0kjf399TP
kXkjk2j8NkuJjfCp71f++j1F+xsds3Ty+9vKJYnez70wWJbcf57ks3u6XUol
PplYlB/GvfSJhUxNqQpL90RMGWqIR/uSfFZ4+MjX7gbce71C/tgoE4E3mft9
VKrBa52RQFVkY4tq4CaqfiNGOz8Wi3YxsEiLFe4S2oL0C2E1BxwZuF7gKKd7
pQXM6VnNpa8JSLduUIr4PYCg+MgmhgwbA0cOVBLh7SipaK+Q72fhDl/QXDhf
ObJuBuUMkf83Zfp0L33cjsKIJvkta7k4fPoTZZdaB4wd+Oaml3CQNRZgvovM
t9UZtD7uHBNy4fbzOyS7cG+9mPEnHxa2E1d2+R/oArfXN8rYkYWGTwXUbVuS
cIAn44gNyQclH2/bDcknQPmQeq7HGbJ/Fsf0iZQknIu4lXOGzBOD9K4DSSPd
EKlfvbhvkDw/9gmpf+XaUCD3cfTtMwJaJj+qB+M/4qcj1eP8JgJlVx+MioWW
on5wtfGKAyyMeG8j1rsMIk0vwbyAhwVBK+VYIdlcHLqW45XQTe5jNTz/vQiu
Rmv6lfJttWwIvY5O2qOaicbvsi4p/iR/aCxadtKjECmVj69GpBAwFBeXPSNT
Dy2R7Ng60m/dP3eL8UTVQOvQzJ32qyRvztrM8b+pRoK1RjxdhMCxqXetr/QG
4PDZbuKnUz/cSmSY2ke7EXi30+sch41MN6vNom/yoKuzxInvAPn8sZJpvf1N
cBMKl5Yj9xG3iyMBAwdyofXi6pZz8QTWPRaU14rrh78Uxyg3gIMIrvJnqaE+
2Nm9eQ7OCDKv8ERslc1GaqXBI+toko9inDgZ8y2Q4YgJnno+DM/A7YWG0ffx
TMmHOkbyW/g/IUE5fxqh87H2YjAPB+Z+DhX3T7wHT0vT80g9cv+VUfIoOBiJ
FnrC3lEzktfWzheey05A4JrSD7r3yPlNWZEnatuE1NW8Sh03yPmrKFCV+uUN
iCeeS7RJfhv4T+LuELsNehW700NPkPwt9arpLz0F1PKpsc3k+VHYu7SUt6QF
cnUhTB83st5E/+B/P+XCQ/SpJuv//Bh8b+xLawtUd/MGOv5io+QG/feujMco
YOsseUPWoxlSv2W0vxPzQfsu6BX3IfjD9Mumlj6k5lnPVM5z0cEnesbKqxtt
a7vyKr98xk2rysk9PzqhSuRE9/3k4pa5p4O+aS8SmvMd+y9w4cRfuS7uwwPI
VGf0LyXrzzz85QEtPA0HbdiX63QIBGawV5i7ZuOdac0yLZIHkhZ/yFzq0Qnb
tVZZVVoEmswMlzvbtiPcQuFF3BQDvTznRwfKejG+LixRrJ+DQxINmZNP+nBG
wupCvBKBm/k2RUtvFOHUR0epoVkC311EwoTL82F57VddB5lPt6T2Rty1pmNw
1OvKS3cuwjWYKvQVDfA32RdmGMzCUr3g6aazPSj3mNhSqDWM0JLnQ0Our7Eu
1HohldwP2l6WLnkdX4TVV4cjK7YRiLNRuGTW1obPe63HI7ez4bYpt+jl+i50
EpIcjQ8sxDWoasTIduJekYrE5ZPkvrrE45nxMTrcravV9riOQDz9w1sipw1y
jxeOurgzYHinpOa6Xz8Mmhgbn6p/wUglM3IwtQwXa1dFM/6S9V/yLWUEtMMo
RoCtFUvqsyHK/WxSN0YnV32RODWKYLMH/zGaSb9tMbijHEIgNceOa5D6CYe1
18w+JPnHwD6z2V+MnD8H5xNNS1n4zvU1mZUqQBc8TPz5SH90hiYx/Oox9oH/
mYMbEytpjXdspTpQfYpP7jLJG4LrhgOP9jXC9Pmlj6cqyPN6WaPON7kRgWqt
F+PIPBH0mE2fV+/ARs1HFJ/XvUjqt68a5ilA/5HY0/uOsZEkvqzmr18lou6n
FL9JZUPpRt/422V08IfcOeT7joCVeOz7/rfdaGqayqefJnlJhvWPY+xH2AU8
zMwn+S/pWyInd0s5HqXFGoR5s+D31yD9YEsrfFYJBO7ax0Lrrken7Et6kKFv
3jGuzIaow6Pgj2qJYJbtCpp5SEBo0DX6373RKM7ROxlN8kywgOTX+71JMD29
1ZZB5o/hpgQ/S/F+PBLjJtmT+eB49KnjEt0OiFoGb/6qMoLTQVpmJd29eG33
a6FfYwQlFFnRbbRulD3nm97awoR51b3Y0B2N4OZKil9+x8THiTFatGgdNLs8
Ez9bs2CSesLOQbgFCxzuwzMkX9atOn2x7AUdruvf39jxigHGzT+3Rt3JeabE
6jJcNQJPk9dUw/hXKHzCUjxL5mHadzueyMJSsk+rEmuo5H4q8Cs3cKwAEwrO
AZdfkf2Q6md4nCzE9+sF4yIkv7s+lOs/ktGFNu3wu3+/MxDele3z+1IZzPkV
/3xYTd6//P6HiiQqnNSCLXqSCeQ2/Vs8ZtWIs8YDqtX5JO9J2z3wjnfFj+uX
bxleJOfDkV31xOdaOO8Roybu4MBOI02QaleNpMnovn+KmOg4Y8oQWFILVf/T
mZr8bDQs3I+kufZA9IBRM/GM1CfDYVBYoQ3ckCpKfTIXhZL4aHK8C0u3uR0V
02aAX31AJYPTAjuxMHWNJDbmWnytHx8ZwKGIiXnXURbMnd9v8KhswaidE+e6
NwHFnB6fxtYqSG+W2MgeZ0JIf3FFXEI6BoN5TdjaBJoFeY6nK/XC3k/ebM9R
DgzyDUYqA97j+/SGILiQ+8DwBS8Fy1bc8jjRseQeGwGhtP2XZUm/ryOuPiD3
g7NMoSPBbjTEbHx03didhVSXV3NGnSH4EB2ru5bkjyPKAwk9zgM4kc5+V2nI
QIxjDcERa8c/o9wbiw2Y8JRv0Nx9qg7M8wcvlO9nofNlWX5TQAd+jxTaOTxl
IKRiih6+k3z/6g3Dpk4DGPwy6xyq04VJZUnvw/VMaFpWbh3Q6gC1Y7hPNYDc
dxysas84F0Lo84ePlSpk/yIE6p+G0CE1+UfiW9kwKHKFy5pX5kH27O3/blgR
yNmaOW++dgCCmbtKm0e4KPdP3T1pW4utXyQu+VmSPCjoHfJzfQNe+ukfd6SM
4H9zoTLv
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lekbxo9GZZgsZadBQpYMUlTqohOyjGiQqZREMUqWMSGVKYVEtNgK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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs41FkYxyexW7sUFSEklya3pMVWbN9BuZQ2KSW5VS6RikQUpZJQwobc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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 112->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns4Vdkfxk+liDIkpX6UGkp0IZdxa95UiImkGCEOudUclzAq01ANxZDL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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3kglGsbxhGKJFsiWyglS45KiC7kSKJEluy0SRSlhRCRSElIIkRyVCJO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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lekbxqVJ2YaEUIOErC22sdVlyxINaUGEbENCDFIzhFHRlGgmSray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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81GsbxrXzWk8rU0lRpEKlSLgsdXRQ4W3hKFmG9yRpIkvSCYcOSatQ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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 113->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lWkbPqMyQ4oihJAkIyR9WrRcMibztUxFTaZtrJEtS5xOprRQmCHF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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VG0bxyWJED0kUU8qS4uylUL5SbIUhVR2JUUhkopSIbImSngqylaK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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk41Wkbxy0NmkRmWmbEZAuFNjSU+hodb40UWcfaIYoUMkjJKJQlxSBk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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81dkfxnWT22DMjQgtlmIMNyE1GHlkKssgFc1kS5StUFK2Bi22RlNN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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 114->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8ldkbv5hp5YesKUvLDMlMNI1pkr6aKJUKU300UhGSELJPTGghEpIl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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VO8fxaXFVhIqZakoUpJKSHSElq+INkmyJVuRJSktVFKJEi0oS4kk
ZMu+M2NnjDFmbDFzZywpKqVQ/e7vr/vHva97P/d5nnPO+6xxPH/4jKCAgIDt
HAGB/1/HrD5pP7jXhrnz29Y8+s1F8DWHeuZ2Nsqz/pxNNucioopnPiSchqWq
q4IP6hAQFg8L+LwgHwZ31MbM5QgoBXrL+l+hwXLeR3b2MAd3t3vW797UgeM0
hulk3BCCHC4sYh1nwsHjzMkm9X5U+lKyRtZ1o5L+3jZgxxDsPQTnaJyqwbfv
8SmxPAKzClqnbtg0IVq/iGloyMW8HeeXRn6sxtxcjw2Hq7igt37J4T9uwS8D
G6nSO4MQf3xEvNitBqKahVBm8DDgxlm/92QRDJV7mG8XEZCxtCsLKS5Gf9Lr
+E/vCax2tD2feTwNiuXRN366E9B4mjHkFtKBH7e8771qHEDygpyk/L5WWB02
35jE46E67nn+BIuN33HiXFe9HrhKuMaGP4mD8drqdcZHCJRaHtuk+jYPL6K1
vvgI8rBpVi4wvJUFimyctUgCgWq5qYRWMxqWcQRP1WpwMWt0Yfz+2VKYFEk/
NHtAoHAtY7jCrhCGYi6hXQ8JBP3aEH/9YyVcvm+fa9DIhdO96kp8bcNEM39L
8jQHx/blmNNCO3CZZtIXQ+fhcB4KsobbIfm3wbjs9SAMWVsOTIV/AIeg6kmR
39ehnW/tSUuGWaOOSqY9+b1llSeH6iOQu7/J9KMrgenqE2+j5Olo3XLISfsM
AZunh75dD6bim47k/iBPch6nxDndms2IGxXamK5MwGDPxSqBz/WgxC42zR0j
ELZ+ZGrp6S44ik5kyivzMOkQUVwg1ILCwFdr+H0EBAqmxI0OkfsXSDcyDeGh
9Pka77Av6ShK/3NFLJTAAEdbJqzrHSRu71lIMyTnu7hx/vo7DDA+f10xLsGB
9MVJuxj9PhiZGTYHswaRt/xITks+BfQtPpp/krm4u+7m85GOTtQ3qQgmLyMQ
Yay70P1ENPpWtArJWBPwknr2wyrhA2L1d8w0qxGgMYrHxmkFYCmHP0u7SiB0
3ktzOa0GfDPV+PzbjouUzSYVQ+eZqMh9VFDTyIKPf3fG2tUd+DUpzqCs4kFA
PXLn4p7XiJj5G7uQXK/hNVO/VKaaYNCzo3ZYi4Py4sWCL2xZ6He66rZTdwiJ
m/3Wa1AicLzyue9lcp7OJct7w4xpyJTUZfznxwdnYzRrw5JyKBzNb+CR+5Ml
oGWSH10J3/evh6U3EVj/syW9jqjHnlP963xKCEz8vK3tfLEeEj7T7wgHLtYr
PMv7xCzH4DlH/gZPHmivbaudTdMQJHuuZoUJAa2oi0J/c3sRYij28prZIEyO
y2KfGxV6DlF/Dz/jYjQmIOg/ESpOagdsX3aEh7UxJytm5EtgMmG/aFqJXL/B
X7m8DDoGE+m3TIsGIffKsTn/by3WCodHPBQk9SVcw2WIlYLPa7bskufB+t5K
bpEHBdnrl1zfoMaHzn2FsZqhMljuznx8UpeA5PeZK2u86VCe6/5eYXwYGlG3
dzHfJOMiZ4dajCmBXyl/l7f3ULBTeZfznhweLDJEpF8dysW5EeUPT+sJ7A+z
2G6tmAf7oqcWs24EiOJXaQ/7WIhR/SFjKEPuj7iP1b+pdFztOMbnnyYQzXDy
cVJ5CheXo5azXuT6pvrn1nTnwvbZXJ7MDKlHvciKxHYaove/oNK+8GGnK6lC
lLOhsW9F1r15fGRyysrD6rpwWMZQvspzCGvlpLnl/LfISxMo/fCKQHD/j5TW
TZ0QO+Sq4uLBwylHP7+Ybx0I/o3pegPSXyhxRlI+nfCfWmF5XW4I55iztx3b
W/BFuN1j8SwPEnOq/UVFSkC3FpufYE7qixbn3jD2BJPWHlGMUwTsD2R2aXJa
MT1+7PGRs0PQ6DO6NvObDWHnLz85M3wQlI6E+LEmzJvT6p17ho+IBcsn223q
sTcqMlVkOw/j/RV68ZJ0zE3xUTq5ig+Nqpfu+xTyoH59r22KGYH6PaWttuVV
mNj53SdoioCUzpUr379TwXlwLMbTkkB/YqBnZycd0vqvOsv8eVDze6p87x8d
RKXvc4e0YVjNejNpN5Jh85//nSpyvZ3Mk06oapH+vv5vmFIUH2HFG9d+QSMM
1EJyC8Z4eJFwa8kz/TzcO/Br8GoT6ceiEoF1S4qxlys82h5B5stvkYJB52Jc
jR9Wu3WcgFq/SdvZ0xRIKhjYV+fyIGmp4JN0sx2s7qUpH96R/tPAFoNBDoju
I/If3hKwXd5rLGzbgqGP2qIdkhzMp1pLikSyILr5v1FCZgSNr6PGOD7d+Pqr
MU6vgQcNxUD2NqUCxKtKb0vSIpBjn3a75F4Hzvr91Oq+xcWcnT/8/A7UY9k8
p7CZRB5i1Wr9a94xEbIk/8Uy0k/0smPqnRYy0ev3Vehm2gCyAhuYG4UK8Ve3
tW/JZgIPWhVtNF8y0e0iMOHxh4POCzzTu2hDaoKKr44RgZRQ2bd98/rwvezm
99p7POzP13go/JgB2pE/u3RaBpGuKvCUNp8C3zcCC+8zOEhP25LDnmmGaVWo
yYmzA5jI9ijaM9KEfFuJ5QxSz+ltrtO61HZEbbX1ohzh41LqrkNm4TS4xVtb
efA5IHIeFkrHtqFxubzf9UAyLylv5Tv8O6GwtUK5pJ/AXnevQ2Z0Nj6J/3FI
MeFBTGl4vFKIgc1/N+k/GxqAgaPSI9HuBujNr2FokPlBUWq+l2Dfh56D0ZLz
OwbwOX3jeYP2RlTrh0ccSuFAJ+y+5YNlDchSo/7J0uHjL2W0IPYDDeVqDtRH
N/gwiIi6fHHmDda7al68d5/AzVvewpPSNXjfdmhl/WJSrxvSve1tO0F3f3rT
a9sQZjucru5v64V9cV/2sgekHo2uNLLH6/HH2i0g04/Muycf9Kr7qQgr+Pdt
hyoXc8t3y/KyKehe2WYj6sdDWEas2kGiBmU5vn1yAWT+vFmgKudKh7it9/dx
ch6N0ZKNXIlCDA59rXCIJ5AnJl4uGF+DJOVAqZky0k8oZjzzA11wm47qjAsf
xOreI2OZqMSc4SqzXTYElp0z/dS2lQmbvZGHfKMGobPgpdw38zoclTetWkXq
gbVHZnCsowUH9TbEHanlICQ/f1G3KRtUC7MH5SwedNxsglzc82Cw3V54WwyB
xGXPFA+x6/FQl/PH6h4HrGyLFXOkW/E79sqoeg0XZXdfmzzNpiNSRtiQQeZT
S1rFrkt7WqFgl8S8HcyFgB1CR+Ri0SxxLqLZm0DlntyQP3vjkRqfo1JjS6CJ
VSevGFSNiEUFydeYHOhZfG6YezQXk95XUreeIGDBlZQK0arF09xLIq0lPLAq
Ymj0zc/gQ4g0hpP+4VkbcFpkAR29x7LN3H9w8LZr4v2SLyQnXT5RdVCjD6/9
mrN2alPhdELwMT+BC4lSw/onK9+AaxUpN5fMg8qwEL8i72o0BF039a3gooG6
JljzVid2dBVofiD54WLYT5rtp2ZsLrrt6K9P8qR/n9BXtWrobMk6c6KO5MVY
wX4rpUqYrviPG0/6yWMzl5nTjr2IPRy3VCa7C17jNy9w85tx06J7Uv0QH1+F
Fla8caRDbvBu5NfT3Wg+orT0vEsjYnpflf5cz4XatuYAVccWyNFTBSkpH2EQ
9UQgMzkFyqxPIjp7yf2/Ztyu2lkJjW8i6kK2XKxu9Gmalr6BV52emdOk//3Q
qOplPyiHS5zvglIqgTRWeVuMdBvmvX8vKFLAgXawTsvsFBWh7V3GrMNcWLZ9
v/ZpggHvH9LrdaMGYPFYTlfxTBJ8fGXrv5J8KrBIh2gtCQWxeMmpSJIfrHZd
nSeBJOj4Jax5H0jgtZjzOU4IHXvNy6iB8hycOt2jIM1moTmFsXtuBA9Uu1Fh
8wkmMCptVkvmkyG1P75icS1clw5l+GYS2FWQXC15PxPHI1Y7ZaqQ85c6MBcu
pSGsaqMSheQjr7rJ9p1uDLzNVGBczyPf56Ar8bmhB5lC3k/qd7AgMFe9lq4R
gUgB/dWvyDwOvjzleloqA/zXSmVvPMg8r1U+8fYiFee29cvy9ci+MPErcayw
C0//+b+d78WF0rVHZ42sS5Bil7dc1piHfO6gWlAHG8oG18umfTlQFe7dule3
FekRt2dFCkie+Oob6E/yw2Kl8OqM3kEoqIhXKs70wHTJ2brEO8PI8d1Sk17X
jjBG9ZLsdxwIMBZ/O5HZjXjx5Vo9JwZx0Pr+t9sSnbCL8M2//qgPl4L6n8x0
Z0P11qzme3I+vd4Iw8mLDdjgZV6l/4iLtBe3HVKl+7D15SZNEZ9+GInLTHiF
sVCZEnrweMQgXmceXprl0gGdBM96IpuLiYrVwdIraFiqyy5IIvmoUnioSDs9
DvUvhDXdzxMw2ZW+QKy8Ezs5onFrNIZgYNXFqbavhhblvsmbl6QfebUmMdWj
4dlz4sZdMv8mDVy2xHW2405fOCsnigfHV/OTWo9WwV4upCOT7F86z6w3srK6
oe7eeofeP4zSLGsboZQWLPrv66CGAslz6VGTNgIfMa0YKHiV7F8HVvY4Jzi2
4+Cre8t2xw/irnIQuzOhDpkSUW9KbbhItdzsKkH2u1+330lSSH+Qc+57OuvW
iWCRM4/mG3FxNPQxvex9CxylTekq5jy4n5/5Fe3Qg22bAjLsSV98eOwfc/E0
HZ5O51LXECRPTPzrqQ1MRWTyffq0MYHU1T37ZLc0YF5Vo0QO6U9tOtFzRM92
gb1cw8nUcwDCW+c/tjCmIunbx4CHfRzQXpSMspufInjriFvYBZIHKuc9mWDk
Y17ywpdzHhOofXTj1MqfNbD6lPrOknwf38zM3/lcOwynFlR48zjoPS1ftHJt
J2aPWAaW3uQjJFnRqrWhCU8Wz8/YN8bHyksVloGDTIxsk1ZxFuHhkvZ4zl/H
UpQk8t75SPGQZz8q8+9YFZwKNjaKu5B8Ni7XekS+HJf3uM5mXyF5YHzL0Ydm
LCxcYT6ykuQ1L7+PLlhYgv2CpW26h8i+ofHKxk80H943igrllpD56shu8Tjd
hoqnMbSfZL9z7TgbFTJTiD1HVI9d+kLgzPi/MquxLrDq2qlJPz6icXa4ftMZ
FvIH5uWsHCfg2t3HHrjZi8m6W61DI8OoarDsmEpsh2BrzsDRjEFEr4g+5fOB
jdYp5wt7Lo1CbeG7R8419dgaHrp8swaZL9c6HvRxU7Aqk7JPVJ+Ac1rEmk+e
H8FUoR0r5rNR6b4vWmj5RdgbqEdpkv+z2mDLVn/JfCiyfxu9v0LgzkjR7hW/
+nHGzm2z2wAHhnnfzzQ+o4MeaX03QoWDZnWJbR3jZdh8y2TJmc8EmCfTssWu
dUOgu4a5vGoAn9pfSq25Q8HRA35U7wYuEluoH0LmRyK5IWb9R5LPW4lac74Q
G/rSUbOBJ3mw+Tvcea23FdrzOwfOx5DP+2u9k19ehA/PKczdZF+wWhrkfCig
Es2TZtOHL5N9TGWFbf+6Zjyr3fN5pwwHQUzrW1GH4xA2W1r2jvQzqsKxy0wr
FljFX4pLpkielhU1mF2WC4XhPAXpfi6Mm13fOXzvxLbP9z0GNoxA1K3CVlut
G03akrNKlzl4+f6S3rrENnRtKYvy2DuE2tf+N1IzspDbZLXXaCsBXWEzvZt2
7bj6kB2+iErmCc1z7gvFLjCT5ZWGfIchmX1g3GkRHYJd2//4fhvEvtZVC0ae
dCHhDvVnkgMbcpbSb70kEzErcIUrReYvS6WqLfJOPsTZ2BBC9nED7TSLrQmF
2KrtKBIlTfJRWP4jX1KPiYlGF3qpHKytiGN2a3chdDz93pxELjT9nngeAxPX
bRhKKSuGMGZX0i9xsw0Xf2iIL3rBxbTFM3f9knZ0n366NesjBwoaq/gpZkys
UjhYlvOWhyCJGc2KzxnQu+txwpHsp8OptHShT9VIf6d5qu4JF+6rnPtt7ck8
VRvpGVDgY4GFf7F1dBXWbnHfSTEi+9uoob5fRRbiK3XXMEi9/jr3+va/K5no
tXQvsCPPE+tvYaueUAcmXuSeuTDKw12D3BRbxXKk/HheFMfg4qD8k4Dfxt0w
yXWue+lN5n9J/D4PRi8yX+6krhIdhbqsqkK8Wj/qA+qy/QOH8Pi6iNr7HV2o
TmrODYkh+Ves5YKnXDvZk0+y0o+SeVAvvTdjvTq6VB6/VrUj4KiveFR5OB9W
14I1luZxcVtjv7X5325o+zyvdc8dxfCwUO9VejlyvZsXH48i9Txy5MfH3c0I
ch+KNiP7CMOMOvDvXQGanCmu7/6Q/zevYudBr2ZkHtCazHtO9rsHx72bBqOQ
xhu3+Emun4XgkoWCG0l/KhAUe5s6iJYEqSSV1U3gRIsTNFkeav+8GGDE1UOm
UuGEsiqBSD0bH7OGXniZBT1bKzuI7pDjERvGKUhcZ8vRI+9Lfvod2X6IhR3C
F/q38LkoPyVVVbmyDga7T37/Qs7rdenBcalzBdB5vsVI7BiBrT/ankUNsKB8
YW5TPaUfmq6uV/QCGlF/tqHmvAoPcuGlLv7JbASXJKcFFnRgX0br25BF7Tj/
8mJLsgUP2x8WHrDgNEP4UdFPV9LfrmY8bAjAB9xssDOunEuA0eje1zFLw2W2
5W3qmWHYqH0JCZfKxpL7Q8kp58g+W1DXuzk8Fl8sb+qrXyIQ66qflM6tRmGa
ym7bTpJ3Pn0st9uUgMX657Wy9hFQpp9bVE7mrs52Oc2UcrI/uos+/0Flg78h
++Da9XwsG+oX/BfajlvCUj+aLbkYE/tjJLiXghsHK/Vke8jz/zzWJeLVG0jb
TE4xyL5lEFJ7QEutEOqcoAQBCZKvU+cYh05WQG6TjVu/A8kvM2GhK4LLsa/G
0lezk4tLAS8+qF+vRb2s9l+xl1wUdl0ovnCrFvuLL9pwp0n+2/GtzHhPPmgK
u2TkNhLo4C1I9znHxIM7ricjSH6dXuz9KWQXFVkfaL1F9QRkRNyNm69Q8ODq
Pc+5f8jz7XJ2w+mrHQjkr/+pK8BHw8Y5ZxVNO3D7PPvytf1DWP1ALqVcgAKn
FucK1Tw+FOscUwQ9acg0eaN+t5qHYftlii/lUrDSN3HGhTxf9MBUvYzd7WBn
FF4f3MXF/wCUmR2P
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41dkfxynZ0iJbhn4Yki1NygxFb5VuxhSRZFBJdoUJlZrKWErmWkIT
SmOnLFkaOyF7urjc7rVl+Z57p6KiLI1pme/vj/Oc5zznOef5nM/7/XofNVd/
W/dlQkJCf9Dj/zMlkMwZMhxCladfAUkdg0unIdMgh434qRW3a9UIQhxk75VG
j6I80glD/qP4TpHpqNeRjEu96WWpzgTfRjqbJGkNIBnFLOU2gnGjMwGPtbOg
ptKy8osngYu+sd3j4VYwT8rtvxdAIJ9v42y+io0r/SxZuQIC8aJvrjCvDeCb
nJCCgXg+2Hf3RaoO9WNxWaj8090EddpFdg6RLRiv9dvwVodAY7zB6vZAI+b3
zQdVHiYo1NxUemjnKCZkpFYWVb7A1OKnV8Gzj3DUlZFlGkTw0Z/hHp/XAY29
OY73sglCx43NFs2iIH+hfBuOEUyblmcYzvLQ+M3f9QoCPiLNatKMN/dicHOT
0mNLPko2Jn2Sb29DfnjRotVmPob+CTTgnO5HzEu2xucegtRdD5tr4gexcEE8
NDOLYCZ4jIcfMyCRujP6ryME+u2Kewokn4NzIGU8XoFC7pCa8InrbNzcHTim
78LHnKikhslrDp5hhSePRSF+xi3zZmUflm/8+lntM4GZxxHx9ZrPQHrqN837
ECi/VJiNiu/BQnfUnnOFFD4qbtLRTh1EWmxat67fJPJX3v773Ro2ko9X9HQ+
4SPGZVgt4ScWytscJa6UUZjJyLjVodsAW21VF5U4ggOxroUihm0Yl52wrhQh
SDKYnioRfY4Gfk1ggy+FJZZmu39jK7oOT0UnuxIY6Jz2Tj7GRbB6e+2JxElE
rAlqouRaMRry9tzOd3S9hU77m9vDEfRA4Cd5gsDrQV142fkufB/u9PnhMoLk
kZCgzKgMVP3leUbzOIEq85x343QuLl30U7j6M8GPuWLyjxqywEzV+XDcjmCu
Yc0Jy85+vH/l8MH2tABlNW+Cuek8zO7Y/QvXi4KZVXXlyaTrkElS6z9ykqAx
KvvNA59WZOpnG73aQsDLtUjSrmUh+nwmK4Oub9zipy17HZ7jYO+f7H+uUnC4
aKnCKG6D4Z5V43deE3xHsC7pdhuyxk2yBIoEQtdudC3/oweuczmVBXMEh965
l+ucZoOtxIz1ou/XDBbdoVTFRpNQULvMYbofUn/7Gra2wedqVDtvkr7PXkpZ
tXMI9sVFnL51FAbIdjV7sTxI7XdiOFkR5MzqTree7EfWG/Nb4b2TaLRrsDM4
EAGLmH1npWh/8vYELHP2rYH7+U1GPbT/Q/08+vpswhFvfMnsCr3PeBw38i6J
C3t+XsRTU7q/699vsWlmYbXGVczG0v0r8HeommlFft3mEjGal+OlUlW71Ptx
Y6ZpxYgYH3dVWhfu5vDQti9U1TljApEHor5UlwxD/fpi75npSaQPD9U3BiXA
7kVK/DitT0uzwervqzhQCrr4WVObD4XjBtpDo01Y9FpSF0+hILXXXK3EtAtx
rH2Bs+sJvmcl4u6GHkQ/Ugw+m05h4xa3qJdHe6A3JDxZ8HESegcjrFOyB/Dw
mt/G2xtoP4iKzce9vAN5ppUdh+ZHfKjOtLR1BMEHtDN1+AK4KHe6JDam472z
ajOL9seIj0Dj3w0diNU946FB6zGSkxoWxuXC60lOg6iaAGut5afH+gbB+11y
4+A6gra8bQqeyb3wYGbu8TAn6F6I7fW40wJ9fd/lKi4E0vtCZRbsn+PKhcz7
HpUEAbrW3lPu1ahJ3WFxzpbAyZS5v7ypHexbjK1fKApXbg67NchxULI1OcA3
gSBxbNqwSngYOL9SaT5wAruQOSGczIHTIZZS5zSBW53ZjJciB3PFEmsoLgXx
UxGTy+9WwtwsTFn0FK0XIz1M4nI3XL14w5fkCLbL2aV3HWuHV5ee3AN1gtGV
t2WK+N3Yavd7t7MRBYZxsXDAVBceSPwp0lhDId1hl8nR0lsA445OPc2r3sd8
VkNhK14Ge0wp7KXzyffyLv3/9WCktTdBq5gCM+anZdt06PoN57NurBUgPzt2
MT2MC/P7922WtCj0VreJ6BaWQ4GyPiziQeepYXWfY1MzOrRW/tslzoeWy8YT
LkVlsDk7Z+HhR9ChGTUYcq0SHuyqFcvptRXPYct2pxFsN5EUtjalELTAc1Kw
ZWNJ1K1IXJ/msWJnb+3PXHxXp5Ene5Q+z/1Vv/q3dviY5VpamtF58rVge69i
LvxsZf71pvWuSg15Z/CoEA3Fn9TnbGjey0y3JXLzMNhiYyxC7wvFSArMX8bi
0w5N2TBHgovud71+9WQjpzn4F6dVfDSqHcjV/SMebvLrpFbT+fNa/2lDev0T
MKKlJTXFaT6id3va8ll4USVIO7KKzsMG1eA0/QqEKG2Vf3WI9r9K0EWGEwuv
f/nrTlcuhfW3JByFzzZDxMQ6oZ32u4mlUE3Szi5MO8xq5K/gY3Wj916F7Rx4
iPECRwwmMN0ifLlkHReuid4PVSNpvmaW2JRMPr6MiHN8fAmYo2qcgzJlONFS
kVVB6yV7a1Y6Lr0JDJPynIVuCinXJvwFTwZwbJOo6I3ECdRd3iymd5kN18+C
U+/pfK2zujEhmd8KDftDTEu6/weV4/pJwDCopxXauuVjuB6RPW7UNgCLH96H
2ehQqDi7EOCydgAM5dzjkTzaD6PeuU2jg2g7YxU8Ej4BWTMT2+DgCthtvZ/H
o9//MUPsrdxHmo8y62WutP4WtfZR9a7PMBlPmFpz9P/idc3hVVAtQvuMx7sj
CARyP7u8jONBOj65K+QehVhJ96Wo4ecQKkpp/o1JcOHc2pznRjxIrZDunWzh
I/CHdkffmH4kBJU2v2maRMmmU9Iz0q3wWdUx/3qQIOjkswgl4S6kjW0weLSf
Qkf7U3EVdS6ozvKmuHuTKPv2pp6HLhc7JqoVxfTp+lJ++9pTz4FkzNHVhV8p
rM2wNKzUy0bHtlcWLv4ENWT/WZ8PveBJP3EWfkjntby4+cmEAWxO0+yJofnU
OpJeIZHJwlvUC148oWC0O6FLmFGKGs6wnivtH42Hq74ssZ4iTLlO7tIHCtv4
exLcpAZwYzHpU5PcJP4DityzGQ==
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns81GkbxhVaFVLYrSWlty0d1mEdkp1col5EpaJ1bqYt6bCVIltRJBqH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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 115->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4ldkflwapDBLppkJpkTBMqUk+FYmUGCYJyTomoiYhiSwxirrST0WW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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHc4lf8bNiqUilBmJfGzUlZUdEslKhoykiKFhkpSSGRntZRISSSbZMvM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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81VkfliZpGlvDULaWISRkCSmPLUnIuHbC2CpERQpNQxmi3izJFka2
eluQimQba9Zwketa4v7OpURqVNNY39/7x/mc/873PNv32eYZZOPDy8PDk0qf
/9+ej44VuAe3wZ7HyyXtZwpfItMOvRdhoSLrx9U8ew54rJjmYwUM8JZ1eAu5
EwR07Px1sWwAgtHlRXcVudgq9iZOAIMY/ftxQN5GLoJbDhxqMC7ESLz67WVr
ggVRaqLGrRGCzl8sx3QIvqw4N8Vrl8NnS+CLT7oEvP81KZwr70bk9YzD6pME
kfXxex1SmZC4qb7g5EGQ85OHvF4KCzeyxXZ13J3Ac9PK3/p5xuD6PuienSuB
XuBOBd7VPlh3Fb8NHuNA4+KzyFjzv9DsPhu5aEhAchpPbD3Sj1/5/WQtDhKk
T88bWdzqwFDPHUkZUwKeiQztnB3NsHfkFZ0ZIei/G/ZO81QPvPOnm3OmCLzv
a0+U5JbiocPlw+FhBKcTpMuzXB4ir6RWlmtAYBXDt/25WTeOeuzfIsdPMPnv
2alsyX4w/d54JxpxMD6wb1eMSBuMszunHscQpHhF5knk9eI7+Wq/3hKC2yOe
98xGhyFSIhQ6nv8GatfaMsJ3F2OPjNStxOP0+0caF8+E92DrEPm3+ilBgXaE
/hfdfrB9s4+oyhKEVPhb5wY3ocrlbIxGA8Gz+Sz/hdl2/ML0d7l9gOCz1CYx
3YRh+AhlF3W0UchaY7fTyIyN73nPbm89RaBkcCKr6VEvPn+f28Ls5MLx6SE5
Bh8TTg8mWe/iCZR7DU3rmjux5fZdSX5/mh/Huuh14S2QevC80SSVIM/TskH/
SileLRxPEjYhsN55hhGokIeSeafmJ7Q+dp8lxTf6V0C+ZCxQyJKAY6PSH9M3
jElxWREXUAgRs+6xDx2D0vAsc/3MBBT4PnHLgpow+W1ibecLgr0/P5D3LhpF
vH1aRaAGF/F81eff7ejFtpA5powhFwLXvNilxS/BvJE3X5xJwWM8R0b4QRu6
tTeO+32i/8v3qK6v7TXiNyvPG85xkUUUQ03jXiG9onn90fMU2tdZD3/I7Ifb
CfWuL7Sfvc87T8n8px4trwSfdK0ncHbY4Bdcw4SCjnqMdguFTvvH36SrxpD1
o9KtopsUrlUJ+yun9aGhaOpFHoNC/vUIC9eUFmRFfa05ReuTskH174WtHXjm
6F6pcJLAvuiSJp/NMDQPan1UYYxDSZmx2/1iH9S1jd+FvqMQYKA9a8LPRPdn
ve18tgShKe0/HPi3F3neCJI5TCHSKOlRvdsZ2Dwx3ypH5/Gs/v51DpVMHM3X
7vQTJ7DdETPrd74fVPW2KJMzFG6eYzsHrm1FSute6bBVCmprXCSU86ogZNFm
Jp1O0M76INxVzIJTUtJBwTGa/xWPeoH3DeAzcazq2Uvwk1xOk+fVpxjmixeN
OEew5WiSJS+dv6bAm2x9LoHwqx/HTyb3wq86fRenjoJZZiFRX6lFtHj/pY5A
gucBQgO/G9dAvHC3VGcKwbh4gIr0ujJICJuVs8wIEuUfinFkn4KdG9X2uypB
Lkv4rO29PjgL8s+9LaYQETjtGD3TAwnjA4una2l9XTZpJ8gNwOC41AnXZQry
Zc3WioHdkOpDQhed93m3YoaPKRO29XzHHybS/LiMLkfwdkFZI7805j6dp8Mn
r1YNdoI1uHkybobCBXvx0HTdSlhXNjPN6LzZnjb80LKvFhLiIjqnj9B5Zz4X
GRDKxTZfDRElL4INiQeHLUpHEf7Mt87ZioMrlo/l+D+1IhL55R0/EJh+0lQ7
hn4ckJ48f1mUgqugua1eXDYuyPZ/nfEl8C2jpDWVByH8PYtMEwK/kcuSIXmv
Map8e5+lDAW2SPykgzcLRRlRO+x+4MIjratHhpGHpsThinB6/u55p6Vss148
v2x4ZYscQflgy9w/5gPQWl0SGBzkQi3rQWxBQzz2fLNR8zpGcLGeGyJpUIHQ
ztnhFW+Cj05qOU25hZB5OXe4047gw6Fqxtq2QcSbunGSORx8i585WJcxjBjL
YKugYgLmndeLGuYtsD9pcmqmmsJpvSUDo1tNYM/XTg9W0fzc4P3HpWUI+uyl
KZM7NF7Plm2/uXWh9abmwrI+gcfZ96nW20txj79E5CmNv1krmW0n2kvv5YjU
ynYK5JDIxnyDMSzBQvZkCEHPudNjuksDSFN0tOWh8W+oqq0yKuvEHV3ZuuFC
itYhqOzyziGoGJNzL3km0MSfX6/1oQmZKT5Eyo/gElYZes0sFPjL9nktToLj
vm6iwb0UapFzzuO0nko9z4RLzUcQa9/qKtxL+0PuTUDNH0y8VvrM3FRFgWfa
MPJ+axiyFxeoZDpfX7+z+rPkMRMvl2Vn98xx8HE6bD4zqgTaGe4Lx+n+0Nw7
3X7JphXdIocTc5gUWJGpN921mdiQRQU8MuAict9mRVeHP2Eyu713nROBaorP
VOFvtN4qD73c0ibQX/K2Y6f3a0RM2vgODFEQfXdORSO2Hcl75m/8MUGgkKzz
57HuAhioN1p1H6L7643R+6CCNLSl1vuG0HrijCDjpWMvtCoViv0WObgq8J2e
//4usNkvVqdpP/aslB1xut8MC+M1v6zPoPtJIuJClM8g9h+oz/86RaE6vGJk
z/5maL5+tZxI83shbNbzr0I2GKqb7N6rU7DqtFVJcOxGp+XbbVpfOHjYqMtO
tu2Bb2VEa1IfBeWM2I5rcXdhMKDJmAogkHEyTBxKH4TvDYmGatNJqBE7fXfl
RsRkzq9f+4Tgvt+8aYpkBwq4yyuKMRTSKRPBv9tY+Hg9SdVhlQumVrbS57kh
vJUXviDF4kDGQD/urXQlQi/1uCgn0PivqX7dxVOL6enoK1EUhfEnw6tiCa3Q
V3QL1KH7NC0oWN4muhqJjChnMUXaf4UCJZVTabgbtyez1JneP4rlrTreNSh0
HzleeoLgmE4yasIHobsiFHbmV4KZzBTB67F/QS3gSqKjCsHW20uLvGszsHHk
makC7V9Rx5+vC9izEaMb99ML+Ql0RY1ftolvwdBK4ajbGno/XlTKjN41gNjx
eUHHzVz8Dzn/txY=
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk8lVkDvmGkopHK+EqLcfmIYrhE5T5otWRUJutoEmMtsmSJEioJWcIo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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 116->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk81VkflkHEi4wmRZEtyyivvGnjESpTRlKKxk4ThmxZymRJltcIUVkS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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHk8VF8fRshPVEobKtqTLSFtHpSizZIWFZEliVRKkyRLWQsVUUqipJA9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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81Vkf1mCYxEhIGFKWmBYpCuVBMYWGUChxVa+MKZq00ExSZCtLKbRY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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk4lVsbxhGiU6aIEEJInBKJkjtzKYpCIvNQfUdppDLzkYNCpjpUIlNs
GUJF2Bm3aZNhm3nf9+Qk4ipJ56jzvd8f61p/rGutdd/P89y/rR4Xbb15uLi4
0uj1/71JPiTleSMLVJbH9w1/EihdlySmfaICTD/xOGNvCh7OMdNH7VsQeFJf
uVSDAtvIqTcnpxmzfE5pb11JKP8GZ55vg/iSnSdYF0uAJ7ty3qGSiXEXZkOj
DYW/xFIMVWMz0JD4r1K+EwW7HeuPCqxtQqV7nIhVGYVV2x+McO4OWLauHalf
T2L57JVvTX/3Qls9rttZmEKxYWrqZcFOMMnUfB4rEskNwWyuM30w1a+flPac
RlTnmTQBoy5cXeLu2r1MQM435riwTyP8J/NlzJpJMAU0V16J1iMt5la5iQqF
x1lys6msfBSbldr4alPg2rW4cbHgBghXxcMrLvR5st7F7DEOVgNNqO21U5iz
erSX8MuGBvOvkjY3CrYXZ4a3HufAf3iTSvJ+Emdkhr6Hh7xDZmpEYHv6NB57
Lz4ILC1B0C7ireRVWv/ZmI8VRiO4nX7uUPVuEiFZaTe+szrR9rTIylyCwqVO
nfwPA80QGHdU3PSFxON+oT/OD/TChKtWUuwfAhLB4xui1XtgzUhca5tOQfSw
45G6sRIIbPusNeZM4fafBdAPqcLvWfaLHEMKxp/KWAZ6vWgUYrjHFhIQG1FT
rPzRgoZaZkeBJ4VXj7bMRaYMg/rR58hsmcKdXkaSZNYkoo6IMh+JTYIj2XqA
4TwEAz6tcCtLElJx+kOepjnYem07M8GOQsXEd/MC7reYDTZ9FWBF+6sua8sN
HYS4ZOyi5QyJlQ3r0y1rKkEwUi9JKFLIGfQb0ZhkI57fI01qOz0Pn3/Kc1Gd
KOF4Be4dJLCqTbpvmi9HWkjMggztR2rz0rTGrkFEfU3gtQun+3Mi+GHY3A1k
jMtvs3SlECTW7fGArgfBT4j+OkBC9muLsEDAS6zm2mtq0vXUiPisFWJSAevG
1M5BAwqWdtviDfiHMDJ9MdLv3jRqNaIfLuQ0IcMw1iyMm8LiEYMvLtdZqD35
prv2BwH1u99ucr1gI1Lbv87iGQn2aZ0XqqFsSDkuH9qzh4SXWWR5tw4LEsVO
goPnCAQq1JvMc7oR7PD39GUBEhG6LYb7SgYRxhFy8iGmcGC274rM9gFUxb8x
qaP76X+Edb2mqxUn0kJneY5SmDYZbhNlDCOC88eNnbT+mcY91pO2vdhkrag0
w0v//0Nl32jHKELaGQ3rByYhULFFvz2Ohef5NhsD6DxIbTn/LW28BVM9h2IT
50kM62o9ZO7j4GTIrLPmdhL8SZm+8d4jiHcMIV5ITUNa7UarXfFzjDUFFxRa
0v6Hq21Mi2i9rgfejN6eQlhNoqhOYx1EfBXSgz+RMPVvZe0634spmd/Gfh4m
sC7wQo9BPgeaTdr3/yM9BX8T5ZniHV24JX5Fmt1CQlw2esfCmX64vAvUZGwl
cOHtwbBTnUws3/OP1wwlUZnV0uOS2IsgtUmhwRckWEGSl2SZ/SgWLliVm5zC
xvLdpdzzvWB8dLZJ7SJx00so8JeQLhTk8NnHsSmI7O9/HHmpDNIu1eF+FhT8
r/nVtWQWwfRWmNA6mldux+xy77CHcXDenU9i7xR+bvn5oLu6F0P78vk0VUl8
bW7pU61pRVh0eeIGOp8GPLlmhvJ9YCwd26ckRGKzvLFtcugAeLMSrfs2kzDP
G3gSvfUVlNr2zHXT79e8qpU1W23DKffAA0GLNP+CXi1IfuhF/Da53yNpHtZE
+EbzpI6gqGtJi1d9Eo+NAi4qHH+JXR+cBSW+kQhXb33y/kQnfhO1MJ0Oo5Dh
Nn2YeaEMdwQ/3VY6T0FA4MTYZHMZ+KyeZZZ40f74+RwWsnqx4CC6sNuLRJNo
kWJ23jt42AQtuvaQcIv+Rb0/Ohk9Ij5RP2l+KXttP+ed3w2ZuGVZF2kS12cj
ro1Hc5BiYurqxksgiO1zcKPmKC5pDc/evUz/93RltN6+Dq9fr/hPLZEQaeBT
eMJOgS5rs1HsGQqcL9UTvtosVBEJJanvCRzXSXrz/mYNRJ4O2yQJURDjzrSs
GHyL5/9mrpfpIKHndEOOnduAqr6fVmvHSGyi9AJ2Gg0iNiHknnDSFCZ67jA7
3LsxVy/tb75CYM3oGj6dvFGsvlE4b0HzdP2MopeqcguiVFW4zOl5Sg/TMzt1
qxwqw0qNxH4KRaX3XSOutqPQh1vI8CyJQOHASHHRCigerapUofMu4n51vvB+
LowH/HZPu1M4I/g940FUP9qzJPLM1UlsyHr6TW6RBR+3cuXiYAouDk/Ocgm+
A7dngSf/lSlY9j07Fs3bBF6tz/mMPLrfMRWv63OqcPz1FgmDaApLIS8uf8zo
xqM/r6+skSXR5tlc0uDXgQRT/b3VASRWr0R+tFszgA8md9Vm9tJ58ElT2Xi3
H5dbbQM2kbSeLIlPukb9eOhzcK7xIwU1nnB9dusQrvO5KJSfI5F5smXFdYiN
94Vh6UcdCZwy7vjg87IPs25JD1eqCUz9e1nfqTYFBaPZFi8dKTwpvicelToM
Rm3ec6OySXj5FCkJy3OgqHc88eWvExBYIvUdT7+BIrlcc+0vEi5PRU4EhLGh
U/DH7J7QacSLz9nPFJbhrkj7WnhQEJJ/XxZ9aghLDzT1vHQItH1285hobYa/
kbHtzjoSP5NmbpZ792CdxvzkXmU6v2kWR5IfMuEz8WmdAz0vKVL+vf9l90NM
5p+DYgfo+uzQNhp6wIbFMe5BhhoJ6+8tI4cYbfg9WSxLx5jOa7aUWfxOFiYe
6+i2H6J5F7u6P0NoGAr6lR3CW+h5rYnTkx1ug5iyrndCLImghcD7MdFD4NHR
rdM3JLDfQcTbtmEIp1sr/lE1oO/ra2VNfHmBgGe8mXfFKIRufX7PtuIdEnSV
1a6MkJj72qbCfZuFR4Ps+8Q0SfPrumdYzFMwrkbYn6bz0118qW18Iwe+Kxdk
itMJcNprdfbtKERxTp/t/XMUErMCOaXmJdic8a62geanaW4pP/vHEA6nhJSx
mqfALtsgLOdRjJTltVVnrSn8D06irt0=
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 117->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8lWkbx7UNRaihlxZLCwZRyCDjJ2WpV8uIKW8NJXuaSIiIJEvWImNI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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2kglGsbJi2kok0l2aKkcmSrLF0SpY5IWdJGkmRLJ0XlSBRZI2tZE5Il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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8Vukbxl9C00oh1UQmQ4Ux1VCJXGQtihQpeyGTkX0ptNgiJRoVBjGa
oTBkXyLLG7K+tl6vsb7nsYRf4SdLY5kzf5zP+eM8n/Pc93Vd3+d+vrvsYmzP
y2AwntLPf2/G1XbN1dFAqIlNSk/YEkytrakr7a7DI7vi8gAmBd5rG+ajf2aj
OuCFRHEuhW5et21nypkwu/t1l00Mwc1h0/1rurpxoUTk5KexIRg27H1gldsH
y93sX0eyB9H0ban2ZUEWjLeXhPu4EBz41qYQTBbc2NNCciUEppwLEjO7u+HN
5muRLuXiUkfnn+vM4qFgeCpjvxUBa1modvv2aojwvpsMYFNIN70yK29SA7az
l9HSmWHIlkaGHKvvxfo4pRmdUwSKMWbuz9QL0JrqaX9YjoBRY3TO+VA4+PSu
OybZEMhskzVjf89GqPSJn/oTKKwMdFV7x3WieEfD7ew1BH4S0m+EE3rwo2OU
4ewwF66JMw9KHhQiqlq1ISeaoNj0u3fZ51vwMiei6J/zFMYTsvij8vvAefxD
hJEzvd+tx2tVnXIh8tv4Wo43wcUbusHaYix809+VZtDORVT6iqqlWCc+flqO
fadFkFkdmyu3pRVTfzZfXBAlGNty9ufojW9hV7FLJjKd4NPKr3WDa9k41PrX
JtuHI6ifUBjQ42/E+6HM1XqVYeSV/sDjFMTG/xXdE9arUVCfG3q1HB2FHbsE
A2Is6f8NZu4R7GJD/EJq2xUdLqaCbjFWZtLAPDfLsThPsH2nWIOUeAMi85wW
VpIpnF3V1nh+uhGOj1KOB+8kSBY95bW2ugv2sZbjpbpc9A+4+HjNtcFA06XA
7W+CGFH1slD+Dtybe36M78gw/h4vbOXv6YXuP/4/p57sh1Aax5mk9GCIlRw9
DIIoKf9PTy9XYtx766hJHIFW8x2vNt5GGDk7DCflEiSuDw7lSPZAseV12vTh
QRBfiZmdN9qhLiZ2TekagaTPufC8oWQwqq7L+dH1Myb7nvqpnkGCdvyojDVB
y2rr1zLvalQIN3t2bqL7j2JIOnwsQ0z1MqfHj2DfPd/NkWaVmFFOlq6i8/h1
t9bq2ZYmqKff3UflU/BSCqm/FsHGATcPHg0pLh6OizWH17cjbloorFyGC9uu
8aGtxk3ozusqktpGwUpNv1VYlIXufdoyxmp0fwHyXo848VivJCsse4lAaMeD
P32oHIzbVr6JdSNoV7Z2CYnswMPlRdfRCxSOiop69dzrQb1OwK1kCwKDracj
xFnlcJI2dLc0JxC8UbAx+ko7flxxa1aN4kKo4p6/7vss7Hmy5DmrT1DZ4vv1
f+pJOOopbFlP+12/L+XIBoUcCPH5ZDXT+uTrF7NiXjERd1V4YYbOk7yL7S0h
RjvcuppUWkYoGC1+Ou4kUoJ0Mc+ZTfR6UQ+G1HJCLxRlDf0zrw9i+8rx1HMC
/Wj4zYSPO0Hz/3L09S/vGmG+d29ITzaB/8Sj8qi9b/F1cbEryYnA15zZq3ji
JQTq7qgGGdN+8L3Yz89i45tk3fTAQTqf67kcVXYasgu1l2ppvid1C0RK1f6G
AKNUc2KSglqnP8eH6kRzhnHJH6nDsH/YMNYnmw/+AtVlMzMCD85ulwUVDrxf
pXxpovUvDt/7OlSyFqxAo6DpzxRsTgoM359Oxh77+nnx63Q+lG3WmZdnYN+N
S/Y92nTer7ZI1hixIFuSs2aW5s/gZkavx+cmzJm5MpmjBIdiPlRt9GFBwSci
3TuLgr8fz+RgMBNq2yJ1VscIIvduNLynXYDnuk511rT+x+JXdGzKmLhcru0/
Fkug7rOvIfAICxqmJxDXQqF34InI2ts1sEuvkM/yIHjiI7hNT70SY+FNk87z
FCSkOw6GPq2BRtwH2Xha/4/zwaF9VW2IT9ObteGnwGCu83kc8xfsZldDg64S
DIYK1ICvBfGxY2NT6RT2ZEefOxDYA16VzywbVQp6t1o+9y7WgLefp90kisA7
4NqxP2zrkHg0P+wo3Q9Lg/+7v8hrKP7e8+w0rSdRtfa0Pt8JLjvBO1qCgm9T
6me7qHKkK8lY8OkRfDjBd3H8PAePTLKipTVHICT/JtLOoRqZYUt+WvYEnqzu
mckRDroFSmyk9SlIzcptPFDYBmfSXXbIkQtF8wNFX9Pa4XFh9OWzVAqk4Hb7
kbl6yG2JcDtuRFAxf+qxUmAntrz2qNhUw4XkCwvfOKU8WPE1hPufJsg5tnm/
gnEO1NzKIwXcaT+PdAaE2Rfg/Y0o+cx1BN9/uX/a/Fkb7pqUKXs9GYajolAK
+20NpOrCFpYKCcJq2pJ/epOP/EKDEG8DgtpE3+mDOzj4ZaNfM4wHscDonpem
z+f6rb4myvcpdAoLyk11tyLtHy3rvMxhBCepmH851Ihoo57A7ACaN+cTuz0U
c9EfKP54jQPBwozXtPrFIjg5dIpM0fXqZCsvdrzpwsfDNrNitQSuPAYStyw7
8ZKHaSTlPoRi98TVna9eI3ZJ3NiJ5tvGYSFq5GQmWuVco61pfvjWffGQF+tF
8eCOBMlGun7n3KqwOxX4ncXKMH3yX56vDOz2LMfHY8Ln5vtp/hKzIoucm+E6
Uql3sIiC54jw3E33Fqh4PNjm8oqeV2538vYE1aOUrWO6uYug39Wk98jdd/A+
vKrsFULzsubX+Wf6KZjzysqsO0tQ2nGmvLKkC+4yaVNVA0OQtRAX9LPsgVRs
hvOYwyC0UhKtOoK60VjNKek9OILKnPPLjcM9eKDmoq0vzoWOgL9WVfp7cMXF
2HN/UHjTrJb8NvoDGJfiT9T6U8j0u8grVdcAY8rYYjmQ1s/bJITr0ow8G4as
JT0f7ujtMWReYkMlb8NDozq6PkXqlzqNTnzPk6J6OYng6Ced2Yw7+XB0lP6i
eZ/236pxk4xOJQ6s1xawvk374z+h+a13Ivqs5N3jTAkizHdVz1qwEHr8pKaC
P/090Fhc1bQGL5orBnme0bwW2G1ejmPihycaQ7UK9LwbMGel6RcheYXcPBxM
5y/JdrFvSxoq4lYnKunzRKuo76WUGX0fMk1a2jQ+DKPnJRs2+5XhXtJ+vrYg
giZ+N4ddM42Y/2CfLEnn418vMcJu
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lekbxsuYkagwpBgcNenIlpRSwyVLmSylqTQSEcJEp6iU7VimJNSg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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 118->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns4VWkbxiXUUNrTVLaajyI1GecwTRO3mqIwjVNSGUKkyKlIQkrJISLn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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lG0bxlWUpChK5UtICKGyRTllqUSbhBbylp0UJZJsKRRZkiSJQrYi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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk41dkfxzEtRn6KsZYsJSRTSmOJeqtxxaQRLbZUlqxFdTOGNKGyFmUb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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVms8lGkftqwoOWRLUmnS1maoJWIrdYVWlBxCUZTD1HZEkdepaepNW7ui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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 119->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns8lOkXn4qiSEVFJGyh39qwP5XS9kXWttIil0QKKdpNdNsVlpQ2k1LE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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VO8bxodUshRJCZUklS+lRIq6kUhKStmSZG+TZEuIUlFSiZQla0hl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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk4lekbxynKqMlkVKIRMmGiJJIW36hhilQGQ5Y4JDTZkrKEJmXPTAmV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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk41WkbtiR0TTEzCGksI2vbJKJp3EiUCp/UZAktJMQhjC2MHKUwkSVb
lCwlRdZsHftylONwLCfbOb8f9c1MiISkvt/3x3u913s91/Nc93O/93M/yud8
bFyFBAQEUqnz/3vykK5HuxoLzA/OFa5pBExGlI5kNXNgJ+3IFDvLh4DzT2H6
BS+wftsF+S2aJHocFDmT+p145acsNlVMwPp3+bjirET8QgsR0jlLwsjWyVus
vA+ai0wHvQkCrNzSveq1Kdgf0MWVdyWxnXN3o++HUTgtDWxzk+NB4Fpia8r5
HAgb/ih81omEbH5zuGJ5FzRpAtezBEjkWnSpjOmwwaalP4gtImDkyzg47FeP
0xMdEnIgEf+t/0xxdTuind+ErEaTeMyTplXVDCB7y8O6pS4+XAbaYjkGSThc
0T/+5TSFT45gjXm+RFAxzbW2kIDkxIktxz8/R/LcS39xLxIMQcuVEF021sYu
aW4+SkI+Q/mqW+AQIqZupL024MF/bl+XkDwTChJBOvR/CCi02zh7FLIRKL1f
MKKch90rdb5a1t3wyFrU/m82H6pyjt2Hb/WhKLfH9nU7ASFnO7Hs2CHsjGZN
9Z/jg/b5zP3u9xUoWD7VPEH1wx5qUWUL1qF+RiFzPoTCm7GyKqOeBrqpnfsf
jiSFS8v+0Rc2DjcFden6EVDqW3FpCkjFT5si5uwp/iNtetsPnffEDyp12/+l
+HyVoc8MOdIGp57SPcUJJPL77dRiajk4lbBYZzRCYDO3Lnie1gz32L9EM2+Q
CHtueXmwcxDK8baBOjMTKN24PzzlwzPsjY/OHIwnkU6qEqZ/tSHxk27E5BKJ
Ib37TV3VLHT8Vi+aFkxC3OIQcXx0FJOpNLZ/HgkXiZCjApU1kIwvMZ5fJZDq
zV47mcvCjelM72d8Ao0WbcWq33MQI1TI6WZP4b57bhh5vAPJ0zeOGvoTGI00
M0/9kgHWA2nhiAskbJJPWlYIN0FPStdE+0cSCfZJZ4L6e/B9e/ri+jUC6gkL
1nvq3qDGuro5yGESkb3KHLGbd7DDrUYhlOKDVZZy/odPT9Ecs9i5+RIJ00bj
vBpzSj89b5R3Ue937su7nnW9RIDE59Nh3QRULa0zNZw5mD/mJmv5Ow/J+iV5
xoaN0JFbcZedJ/BNlh7hVvgK6d1nA4eSCbjLrfvuTnk9uM7X7gquELj228nO
UTsumCdrs23aJqH0Tl1ppLcH/vqzrUbTlJ6dFT/wm/rwyf/It5+ZBG6nlG20
GGfA98pgqqUJiY+PRB2PxrHg2N9Q61jDh+VcZNpWzQGEvmVsOVbHQ1D+kSEI
voS81tXK/BkCgc2SBnecRzDqLByY6M2He0LJ8vq3lfBJM4gLUyTRKtmsZBbA
hYqsz+WiQj6sz5zw8dLvgL0ip1uNTeBVIDFOl+dCQ2iPyt/P+Kh0XNtQHDIE
daOZzfRPPMyzgl3D1w1DVvIKd5sxgaChYMvdFgNIYSQdaqLqlSarSF21aAPD
4ePEagqBYeLihcvXq8EJe1Ig5UZCYGxV+s4+LkYtAz66xExA9V3mW8kgBm5/
+Ztu20hgHfNn05m+JgwLxx/UViCxqhsTW1jHRlPibe/7rTyYHjPdFNA/CLUM
vQsl1VT/iqs2Gr+0QiFUIxJnCAjMn64VUX2BJ9bBmxKiSOy+et3hHjcfUQdD
WLvtSJRGORtuUqnHsazC7KdTBHrEEhwUPzUhOnVnsqs7iUYJD9+S8ld42uIZ
cneAQKld+q0/xouR+GuG16wONY90IyemZCK6ZcIVNah5s526kjS6awg6e0O7
i/ZPIkhO09ZGuxZR3TnXqkxJeOtZf3Q1rIZHZBt3+3EqP/7XFqs0NrbeI5za
snh4GFDFlFLlgPHd5UuMMB4mc4QiXU9lYd7dwUrCgUT0g9EDC5xypIoH95I7
SWQqP9kSVcMGvdy0v1F4CqnmQW22gizYqhcvVCiTUHpkcOuiWixmGnaO0Cm/
MHIR9cnb14ihCXua6UGKf8mGOG7CfuzTC17b4Uxi+LCYt05rBbTWy0SrGJB4
/WfSOSyOIC7+wOtP2RPIr3abu7LSj2MmwkXmHQRyH+Q8Z2zNxLk/3C3NKXzD
94USF6Y7kMsT2lBlROCQvGLR13/ZsIzpLV1a46OzU3pZVWsAVt/z6rt3EJjJ
+1K1fZiBFmtWw9hhCm8OvSSsgYm979uKpwMJ0H5zr/LRewqLr+IW7vYkAk/w
GnQZDFhWpuezbEj4fdPTOC4+gdRXtNM3y/holxHx4Euw8Hcf06iVxceTk/4m
y3oPYZLrFWlG5dcuXlC/d7kXy89cvtJKCDhy+1W1lFswwvpzQCKZRLnC4vI/
zycQ5jey59QwCY0ciag+h2Fs/1H7nW8vH9s9vLJf/6cJYiHGz0PpJJw8A0Rc
w8dgOCrqYyjDQ9G299yhwgHEfq1SISg/l/EMMFO5y0R3mpLPoVACk0/mKo11
y6HdJOtXJk/CbHBrztNvg9gqRZ/UTKL8P078gEh4I8YSrfSu+FH/41clGXLi
Noxm9X8VOU9CIaVtZ+BKA5bamx2LKf9aOMEWbiJrYf5YzMO1ksSKXcR0uccg
5JPNG1t28dH6OfntvltcFByd7eywIlBvudJQXPAYZxzGkwouUvVj4lL2cEdg
EEs4tFQQkJLibUqN5uBG5l/Zxq7U/vK8Hx6q3wazMkFR3igVP6GotiDZjAuV
xnSPHgKRxmvhVlHN2MlunMmrJnDU99ud94w+tFdJvbi3g4/dBSKPWk6VYYOz
WkfUAcr/VScYj5Nr0WxjNTKpT81L2jfxhYVWXHq4NB+fTkBDILmjYV0X5j3f
1CblE4jboZ+pK9MLZbtfxjMb+Eim/fSwrKcVJs/eWXWqk2jO61b0VBhA4WzX
2Q5JAkk6X4cUR4Zgdu7AHCh/vKW178WoMQNq2oc3LZmR8LINFlmr7sJlDfuc
WYqvrCKjtHc326C/MYbagwR2C3dF/nsxF6InmeMtlL4Y9CveD1hhUNlmNatG
8Z3VX/FDmnE/Avs8Rq594ENJap6wri0G7WxTP+0IiQHp6RtB0bXw+nLa5WAq
iSfdbzNMPgxig6zn9UlBEv8D9tO/DA==
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 120->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lXkbxr1nTMlLSaVG2ZpGKtlqJEOX9CIpISJSkihbTmIqQkIMIi3j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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHkgVH8bxSdJC1kKLYhQIZWlqMixJaVIVCp7ZOkXkTUlWpCEIlRIJZQW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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81dkbVpYkRGVIRpYWKSbbpKRHURm5QgjFGFtCKJqRqSxjmGlUKBKy
tVGXxnLD4LrZDeVeXPtw3e+5aAhtxmiZ3/f3x/mcz/mc83nP8z7v8z6vpneo
o99yMTGxdHr9f1dgBZELj5owv95IifmYYOqDXeIJZjL2GExJ7zpB8M6a4YbU
FtiHp8it3UewLXKoJZPdig4ng2G2NQX5u5aVqyQaERZ8flvRDIXHevYzktld
2Ck8mng0m0KwObP01+BkWL07GShJxyOzdXXLAweRY3QpXrpdAIUd+o5EOg9b
nAsqB30I8pac6/hlg1ht+DrrWp8IVq77jyyWVOBvN3PJVjuCBr679OmoNvjq
aLY9oPEIEpna/j4pCK92Mm9xp8/nA867/dAH+7she3RiCJL3vN+2WNeFwLf5
vj4LFBJeflU8f5wHZls0v7SXgutBryMXB8pQy3NWcT9PwJXTX6n2by8KvrOV
D15D5193L7a5rwt2HmpaA2EE87+sGGCkcfFaakID3QQW1gm7Qh9wYa9Gtc91
UvCNWupW7u5BhoBMmFsRxKhWNC2Zp6GkmOf5wJtg0UF+LFKuEq7aITv99hPI
ztipSfqw4blB1DmygWAv7+3CNg0OJl4Y3LkQQMDpr5ELiGzEms2/sYg2gWpg
zLDzrR7kJPOpZZkUFmM6v2VqcUFmENn7F4W6usoDkkZ8SKpPP11xj8LSdv/p
E0s8HE0q3+CqKsIXY3s5aasawEl/8NRrBUHS303KMoznsGk4GPRBgoJTtbjf
89EOVCzP7rplROARG1x4/RsWpI6nPZ0NIghZqZ7MsBpBUIJEb1eQAKal5kp3
b/ZhLj7eX38VgZe//O4I12xwY6YfO3jR+GM4nFS9G4jyeqze6Emw9dOwXVgl
HzmtimaWqeOwEOZypFt9EZf/mm3xLYFY0yu9jedC4RlQf5hDv48/ptgvszCA
A0kKecIGOp/TyX7LDfoxEvfFv8GzQvSHkrXLDvUg8XAtxdhMQcC2POW+yELl
VUWONo3fNrZq2VxoIz6X2G/MUia4edjp/FavdqQHS4hPpdF6mYt7JWjigb9a
u3eSQWHnMZnNNuY8vPEsqY5wEkGJ6add3diP/pclwZ0yIthm66UohcdDO2th
9wiNL8ZZ71uuagQ4o19m+NBnEpuqkLl6BB/Z6qsuSwgQ4CZ2yezJn1DkVY2c
maDzqUl0t79UgW7GiuOxBwk0nA2OXklowNI+l8i1dwl+WveP6q3SKui/jZJx
UCcYsI81WfjUhTUDe8u/mKJgE7PG//mbRgSan2SzLtN8TcXJ5RzaBlHVpQkD
mr/FSpsR54wOtKdk9J+g9W+spBYf9N8QKtJOxa9/JISgN738yWkmvLYU/CHr
S/BZ8xN/Bb8WFRGMYk9HApXbFpMfVBugnj/1TORKsCT/X/j1iQZcSX6snkzz
6RqmX8OqfI4tZaUslrIIajFvnpx69BB55xzrhQ50/zqIR6+/mQTj6ObYeTr+
pnhfnkcEzXej/3hKIYVkTu/DzTI5+H04wP4KrY/P8bxsy8hWRMjdy5mSJLC3
bNVbOVIINdtNUi1uBIw3++skCoaRf3/7ucnTAjiJXh8t2NeLj7kdn8/EUShZ
XITh4S64eltlGo8LselLhnXMpjZcN/mqMZBJ60+8iV33ORtWJqXepnR9frH8
ZOn3WxO6fdUfauYS/J7XVNdpPoR9MU7yx6fHIRaSv8BkN4F9o3qfu4EIptyy
fy5F8nHu0fNZuQ4KA1uzNe9o1EDfbuiSYTJBwpUEcS0vLjxZR1RqthNIT3ia
SXs1oe/7ES2dp/R/P67N2mvMRefY+/CsH0SYCTuY6OjGQYgVg5xbSRC9LsLN
0KoHEe+HdOeHKKjkmVpQW5shYbtm7Jdy2l/ORG0aX8rFq9tzN87S/qlSYGl8
IKQFmT6DTYk7CC6Hp41pSQ1hTM9/mW48QZnvuKzHz+2QrSjQllEk2J1jEviE
3wvvtsCGKxW0ngx8fj//YQimxdEvFUIp1Lzv/2y+oQ0K3oH6F4wJdl4Mt5GW
rUDnuu1FPncIcjwm/zhk2IM0LzP3HUUixPvo6DJXtUJ3WCBR+C/NR5TLB8WN
rcjfrqk3d5Vgl7zv/c6ZZhinqChzEmh9VnSnveu4j6ucoNhqup6eGWZbbroM
QEWlLEDejoK7e9oyts0gCpJ+zPU7S0GBYWxmyiuFde+z4rW0n+coMBoTlFqg
8ZdS4TNNgrbAHq2GX4cRna6YMJ1J99+Qm6HGz7GIsFQw8PSg9Tk3z5B4VokL
Kp3fF9D9Hen1wbR4Cxe2JsydVZP0PEj9mNok14fLuZ3/kI8ijE5lCbSuDKLH
cbbMpWIcLalZVWfTuiF18d31u4RCm7GFbODaYXwvU1r7zkSIHSmSreFVbeCr
PUppof14YHNvwdeN3SjEydqvQ0QolC+PYwqe4s+EORfb3whO/iDj3cPg45hz
9R/fKNH+frr/lIb9CxyLOqvRbEMg8XOR+HqFVhSTl86ugxTtpy86bkoPYE8D
s/69shCzfx9MnCrh4caKrhfLGoWIOXtmfvLmYzQctF5ojyX489rSs3suXBh5
GaZGGhLMWfx61fkaD4E1ybf3vRLC9k6Qw6s4HmaDm5L0F4VQIKt1i6iHYC1a
uJXR86iNqxvRvYsP67fZS35lFBreOe400+uBx7ROfW+ZCHYuJ3uo1n5cbEk6
M8Om0He9pKrrPg+52rum0ULh4cn8l21mPEi9li2tYtLxg0oWNjiUQymiYfoi
XY+JYxV5Mbfr0ZBVdIJF60vsp1qXA2GRIG+v3Uqi/crV5Ehp/5p8VF1VuGZx
ip43cz1cQdowVtmJjx6OGgMrpWg8XJsHjhvn47NRCqoB6fNs/wqMsg6VOpgS
2LHPFr24yMOpv77c1r2RYPRt12RndTM9vzSMzAPp+3LWus26XOyBTqqSNJ1f
1sC9MYUe1LQ9OVxeJYRkud/udsNBaEm5pl+9I0RebWNaeGcHGAbnwo67itAp
iviueaELvhPpFhauFJQ5D9RPpw9Byih2Ljqa5tu8viXUeBQ36s9kdO8VYKAu
rT8jm4eA4246mdUU/gfWWLxF
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4lWsXxk1JJ6ck0rBzhCKhsp0S6lZRppShZCjDh6hERMYM6Sjz0HDS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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 121->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk41VkYx1XUlEhZUsMQjaYZoqRum2+pSUpFRAuVXYVKskYkS0yJbJWJ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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VH0fxtHeo5KQLKVFSXgsLRTdPEkpeyUVhShUspOEUKmUSFnSokSS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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81dkfxqWMUrZGl6FJNWok0UKaqIdLZcgu/WSJirIbUcYaFWlUV1Ky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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4lXkbxlChKfuSJYZQWoSR5dNtRFGdBmGQXTRoIkXGIDLRIktkZBtL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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 122->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs8lGkfxofo7SB5EdJRZG2Rdrd1KFyxqYRZJCVlHJpaVMzqRJJ2LYVQ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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lOsfxpEWQh1Hi0LKmiPZU5xulYpCKpW0WKIkS0lZKkmlooRUyF6n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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81OseHpQkhRaHOESSrRI3yRw93ajTImeEspPllKXDiFIkjdKnuKWI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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4lekbPgltKlNClCyRLIMotN0YNbRIOWXJHsYoQpslDWkOc6UkhsTI
liiFSDLGTnbnOBw753zfp5BkSaWU3/f7472e67mu54/7ve/7uR8F1/Mn3IUY
DEY8/f5frzoHClk3V8OxtFQhcjWFoqRjVSu2VaJjIjhvzJHCXo1/mtWWN6Nx
2nBXykMC4wt+XdoRnfgWSzSHPCaxbtOXNu2/a6C0Zuti4koKPUOeLLnVxeAa
NehHbqQQFLpM5OGdTjS90nsq8YcAUYm6Lg8qeHiDWZbZfQIanKAdoVIcLETc
ygpnEsiutNaqs6pAiccejevuFGbS7ALLk7ug8zLf2TJBgMnnEebGQTx0v9rg
fDqRD9VjlvOlPjxcbjPvUhgRgNeeMxgeXwPVkbTOrX0kbk+fizQ27MGE/2uX
9kA+Nnns1Cld1Y6Ta/TUF5UI1B/60nThRw/aEgsnL13nwzJpZp1EfB1Y4USn
qBMJ5u6suZXBTQgQ/c1mewiJkv8Y1k0727FO9afyEJqfhsLwWRvZVvgGMfRm
tEmwj76eiTnAhcfJ71ulZSnIherqF5YUQtQuc3v3AQrCs4trWtntGJ8lz1jX
ERDvHXt29ngrnEvMwiJukuhcPFf/5/Yq5AqdMY0WoZB8OPDBUo1KeB5f3u8l
TCHTxDLm6Wg+GAa/Sh82p/D5E5EpKd2MA7Yb9q3XpVCqmW6Xeo4Dw78Fhuso
EpH5Xzc/SODAmyn8JRsC7O9Tyiud7MdJCeKYmSMfZdou889z+hB0YuGinwMf
xaeXDoZI98C9IsAgrpaEr8Pilun37QhS/qYcnUggcixZpGiqG2PWWj6sRj6Y
9+cvHWpoQRNH/07uOxIjC3G3xOMb8exCtHfOeRJi+gUTS51qESD2MRJnSIw+
1buyrLYRSa98b4maknDt0ld9n9iB1b0soahRAhaiU4cQ0YvUvLGMymQS4h9q
5I+dbccvKYF+pygC8ntmdeLGO5ByZH+RkAyB0SG3HdW5JSiTP2iiL0NBajas
6tGKbpz7cUHFO1OA8iXZvKLHPSj7hisvLOj/80M2d9b240Z120Vz2yH4Vvwh
bieZD9dL4YFlrhRSc+uL3EVT4B9bYmjhQmGhql1VM7sYK1O8WOlWFBg/Skak
iPOwSTC0KKX1F7VkNbNsuRjNy7jpaCpA/C+vGqNW98O2I6+4xnkYdncOdFHM
IZiZhbi5SQlg0jR+WfxGMx4PP7ruF07C62PE1TVvumCt4GwQQfPresUrvcGB
A5Uhw13seyRstJOkVW3KEGDK3JC+hALfizOgGVyO+kn7E8M0vnev2ULlDDbS
Uy9Yp6mT+HL+4MVnR6rw5a+qU6kTJCpiv74QKJYj4leVmEZNCnc0s025pcWY
Xz69zZP2yz8b0pvFrjXA++2iqHsBheXCT/0vdvPwp2+tRKA0AZu1kSW10y8g
ai8SLkHPO3B0ssru92Fy6YZLZ5sEcI5sdXnk14utCrVCT+Zov+382H1Eswev
rv88EZHCR0vN1qP2T7oQsqtFT7aCgPHzmmWjRh3wsVBSFkhQkHDfnbTjYzsy
Gx6WPPAhQeWORnGca6E8Vx3hpUiB/UbkF5+KZ/hp+eAS/5MUiL0lY/vV6tGm
NmWqvkDP91i7mT8pB0tR7O2pYxTkPw8nO77PRUfSP/MG9L4xVew7lVvqUenB
m/s0QCHS0u6RcVwhtrFkZtfTfAQUxjaGfeBgZ2OqeR+TxIW8F7KDm3sxYta8
ariGwr37PtGP+4vhm2Xv1r+PwkfJffL+TS9hoXN7Tp/2w+mw4O9PHw+A11ww
zlorgOX8cYVvei8R9mtQ0dqrFA5e8TM3VG8Ct9FCQoiiMDqhnJ0cUoVV2Vy2
3icS92aOm88NtOHl4D7Vfy1pP5MtmUo7WiBlkTPUsIsE11Z7qfyhfmxJ6vEp
dxtB+ULBuGBJB5JCqteuFCKhLbzCuDC/DF2NSpn76LxV63AxHtdqQ2jRKdsj
UySGguP2XA7kImEi+K0sna+8UM/Wk3EtiJtifvDgkpCZqvrKif4XvzPq04sM
KPSFMfy+a3ChP9J5ok6FwNe8VQpW/r1IsV4/xggZBK4dflsq041Ds/WKxd8I
GFm1BU679SD5sk5osRbdf3tlejM2C/fLVxe/p/UQPqUbouBRBcbkLo16ujdS
XqIhr/oYcdEy3mU2FPLfuVv57M6H2u3Wsi47+v68Mw4OZzfjgpJkTQ+HxKZU
FT/qJQ8esuOsUDkCe6P8GcrJ/QgyDLy5cd0gUq7rydvReeRfmyTyXouEvEqM
iKL/DdQe+f3TdwcKvg9nHG9rZOOKflZzL61Xw8ZtHFn9TrT3W/F+6PPBduLL
/XzzLpI8Ki8JO1HY4/S3UY9mAzI8NXXTaDypcwVKyQ9uIzcwvTTwDIVNv4mp
35PohYnaitfX5kmo7+2111nsReV5I1fD1wRmCl7rC/p4uJ6auNtvchgBJ2Xl
PhvkwCxgtUiMNwXtu71VURfpvCL+DJDaREHL49+8/5I6kdYtuXxXMAn+z1lu
uuY5kPeRnnhrSyHqU7yztEYVmFu4R+YJEgM2KQt76zuQO/nTX97dBM7FDYlf
Yg4jLLWjq1WWDzNx99jFhhpI6ilmZ/mS8Gf/cdXWqA9dzq53uOnDuLtR+blW
dD/WVJRPPF/PR8DEjqisj2yQ1268qfxA57U323SjSzsq9r935FQTkM5Izw47
+AIGtprB7FAKZ0sGFfsseDBJ4rDsr9D7MRYz6fhfGaKb6jxFukj0+hZMZ30f
wNFNnazCzxQu7zvsuEafgw3BVzW9kgholztuOZubD6ZOjU2CHu3XZWeOD3kU
Ycoszb2O1mfviKhAhd2PqJ05JtRpARK8HzC3G9ShpXlxB7OMxA3p6sbj8Vxk
PSHkc5eSSDEJXTwXQt9fr6fKEU4EGLnKMqaBGWg5eqPViUlBLDeS7ZzQiqva
ukcDFgic4DI/SSXXIjZTXWE/7ceBNLndai+r8TX51oKYB61HhoXVl/42zDcq
Hm2i885NLjijfRUPleo3N8emErhroaD5qLwIQ6MtO5fE0HgdTeaHPg9h/qys
tm7pMN46SEakxL0AQ+Srg50nhf8By2m+Ow==
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 123->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekbPsikZWaUUSFrMpbGT2k11V1+MjOYIjFk7diS0qHMZAbJSJHq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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHkglPsXxnFbJEVlKUu2SEWhunVtT6mQJZIlFcm1h0oSKgmXElJJkmQr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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx5EyiFBpWux+JUuyTKmMj+xRWSJCZVRCSIlkSpQtxTXKEqoZ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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4lXkbpqGMpZKobyJNRlR2H9OCW5FlLEmFRjjDSSGKscyQLFMhGUVZ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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 124->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8VekbJ5oWpJ/Kkq1oFCVZRrtv0RQmuklly3JTyV50LUmIuklZE6KE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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8Vf8fx5USFVkpW7KahKT5QjLSsJL6KpIUIUlIQqVIVplNKzvZKiHZ
yrjGva4Z9557r9USUqjf+f11HvdxHvdz7+c9Xq/na539JfNzi7m4uE4v4uL6
/1OuIXPm4FgPHCk3vm1fPgE50ZN/DXdUIK7zimzteSaWlG7/xi9MR+rP+V0R
ERx4cjmLXghrB6ffuSuqkAn6XL+4VHkD5pue+4iDiX1/lkXH3OtBgLBxxpq2
AZRF+ZWG7aViZY7SeZ9sAp+lOsrYv1tR9fa+vm0ogZWVCT2VXZ8gbTZBff1y
GIOfU8Xux3XBhX/YWOnsCC4czPo44FaJpL64lAMWLFhPTTNZUumQ4eofyPMk
QJPT11S/3IFioZTrd7VYmBCdlVwd24iYk++C5H+Q518fqHHJKAAzxPBB0i4C
HTo9e98y3mJ5YrXb3xECTnmy5y6s6Ubyx59BFWIsXLCOa1WRyoIz1YQ4YEnA
+kzd2TyXN2BQbR1ctQkslCtMavB3Iag4S+2hNQuGMb6uEdMUhOzeb5H1hAUu
028ZrcQhsHfsdlxqS6D869olPkfqIOF9qmV5FBMJEuWRybpv4fG+iFIwxsSa
ENHmW1odaF//e5UVD4EhJ/fViuodKH22w8urkYXvGs6/7N+/g0WpQI6ZAPn/
p9c0GJ3uxmiPsCpTloDyjBrRxemBjdmxJT29o/Dct25aTYqK0qgEp8+SDEj5
/pzU18zCyvMaRyriCGw1oy83zO1Gftrf8PXLGfC0XLBxOV2Hepm3mxcPMsA8
MyowY9GCoK3m0Z7qHDBVRNWfc7VBJprWqq7LQpBcvo37vTa85IuyMFEhwDaO
a9iWlI9zJZtPbjlGIKnr3VC8zmvMe4gtivYnYBqZkjlgm4M0nX0/TA6R9RQ9
wiWxUIGVNT4vWmgEAjrs7G33t0Or2ZCyRZGBUT+jJXMCPdidu6ZEyJgBc7ci
mQ93KHgRPlDwuoeFITXJp0EKLyH4X2hk4ysCh3qUnoVtpcDd0/255jUWTG1M
H6xu7ED86zcH3XIIyKjVIc+0E9Ne/DvqM5goz7l0eOTkJ0ggsOTcATa2Oyxs
lhR7i7toPqsjQcDH3ok1tikJtQvhp87aEFim/DD0VjwV1Icrss1EWJiPq1eu
76tD592Wyup6Ajy/+zj7u8qhkCD5xTOYvL/gMUaYzAdMVWs3MG8x4aDWZted
1oiOuDWb3g8yYZqyLdBVrAPZsYvptJVslLv7lVxZ/QlqdQ+2/bNlwmj0lqjl
jtd4xNsuddiAwFHbo2EDknRYnjpyTKiZg6Fnp4JUS9uh0uCbsUAMIfNzx46Q
I2+haY1+4QwCKWlOfEXc7fCf2RJ0i8qGZpH4LLOyAYLbnvVfbWJi/w3J6hCz
NnjtK3HztuAgbrQoYFtRE36MuyR4e7Fgt/pi8JaIdpT5pymtTmHBN83ALvY2
DQ57ZaUTyH18kXvB4/TGXjgEeMo4trDRwH/jsplmN5btnzp/9h8TzfW8gots
W2EZY5K2opuFtU3C4zUqtZiQvHyVrUVgvNDq8bJ2KrTMUtTGMhnQHH26y3yq
FRu6chqoG0YQ4uKxtfRqG3TD4+S/3h6CVepOz6eX+zF4aCGr98oIuM4sTAU6
dsNShdkWLcnBc9P1dlJ7aah/WcZJWTGMXZURjKjOanx7/K3B/xYLluXL01d9
rUetePMOqbtMcKmrXEu9dB5qlxWHzO0IKBWYRFvxtuOl4Gzmfw/ZSArSqxIX
eQUGN6u+7yo5vwicSNNLRWGLh3fERQJvnK4qP/7djKmdDVF36xiQ8zHisU7u
hl+h6mvZYQ7s/qy4GNz9BEsW5/dmkN/3pwYI7JWkIUbYw+j7ejYM5ajTA+9K
EJfzlO/nBBNb703898uMijgNtmRlKAf6jerBr/LbYVyh7zYiNgT6rSJZJdlO
WMWIaJVxM2HnJ/pv/7p6HNu+doNeIYGpDkGRuyY06AasO/qZMQSVwOXtf4e6
YNm5P/XVHAN08zyPntcZiG69MFRH6lHuxwDXVJNKKJstnjlxjoCKS0DQsr8U
uCrmXxKXYOHQW6P1b7+3Y8okcoLvBBuH/cMXX+XthP9nrsk3+SwIR35tfLKj
F3/3y51409GPUNl0Rha7D3vGz6QtM6MhW8LEkNeWCjnrmWVffgxD0/O36P6P
VdCv+83voc6CT132Xse9mcj0Ppgo5EegibXNW/kBDaF/UvXUIwYhHXNnzMqv
Bw6X/HoT1QncSo59Yr+mC6/UT7eei2OAZ3Rr2fXRTnyPcqUOtQ3BN+rC0f+c
u3FgeDiv7gADJ5cEJ7P2tcCAs9xNSIuNzayMDbMFjaCZpst3HGFiVoaL8kSm
G6pMye2O8kyU5vnHiEZ0oKXd6rZ5JIGI10PFky00qBcuUTQ6x4TwRvXkxsBU
BN2nXt3pQmAkmCHxwOA1/oYKeE91MSFeF7iTb18VCuZeBkqQ9W2+Vc4RoKdD
wCU3OJHUu92ZUs9CMyjkvvP91JZngLc+LnelfBkIVl5hjjeBWplZ+eKyAbiu
XXHP8MEAokTcTnGrpsKm5ZlpuBmBKsV1BWeYXdC62mnNfsSG9Slt3m8rGhEx
we1+1JSJiw/9vmpsacf+i9x+x6OZuNtkqx7aOgjnas361nUEHktSeAs1upG7
03/Qe5BAJlN3lmfxPUiFHL1IIf3NqHbP9NPZd3j63K57CT+pz4+uh1wS64GO
4RwtqWwUs0ImE7HjJbjGczGouZSJuB9F/x0z6oOLdCYfxntwpGGn1KGFZGwN
vFsic4b0r335vIH2TXg9tXVfD1ggjpxVOyjeAetPYjLWvxjwSw32md1SjYQk
C7fWPhZc7p8qX1NTgMbT7lGUAQKlznfii89TkBY5YyrSxEbbU67jKUItiJLI
TX30mQF9pUZ0bmvF8fPjlwXekn57U6JVprQCDULSQ7e3k/swEJ+8Wuo9dDwG
N6dOELghv0Hr4qJ2FIppjVjasBF4+TQX3w0KVqz58fjxLQZGGnQs6yOKsD68
VtHiLIHR5Vnxpy2oyM9aLWjUOIykLWONkzHVeGY/GW7jQMB97qdv1IYCHPsy
aiJA1lfOcTaEh12O3qcyEUmTBPzUvx1sLOqC6fR8ZeEmUu9tblit0PoA+rcF
5XAPFvn7M4IRrUV4+F1pjeB1At8TNwk7iNLhz7U886bjCMLm6qYNZ2vgXxuo
4OVLwIpn04d9dAqGpNI2gvSX0o+6FiXudFxdmXSGf2EEVRb34g3L7uO+krSx
oiMBjWu6rpIBvVALeb/yle4QTBNFvyg43ENY75TxYfJ+in0lV76rUPCWfaw8
kpwXz34PVT9aPZZHEqPXRBgkp33vFXTsxS9pP9nbSgTqlZjRfy7Uoww54ilX
SP/3zVXO6W+Bz6ODQZIFTBB0lRx/jyJ80pp6yxVFzj/l9YLtykL8VKUEONgT
eOE2ZsWRyEYEKy8iifycsuoR/3RtLUpXrAl2WiBwwfdBsv62bsSLCDsOupD+
vHBIMyzgA8I+77aPsCJQeFVEe+2Jaoh4R/4e7WdC5TFX8EPqe7TeO3zLlOQ/
Fcuwd3tOtKEneoGx9B0B7WxlOR+lZiTLHXwYHE7ej0/aRaO3AvNKHrOPyf3U
+++PlTJXO7rs5u8wz7DweMvvY0OFfeD8Uhs8mknybnnNHZdPdeg+25U/F82A
Wdmi+UTldryWeJL8yIGJQXHusV967Vh2nHpSu5zsH6/N3izHdlQ7bf95PYcD
7Ryd6oPmTbgmnWX8QJLsN22ph6TRfTT+eOxoTfqNmz5TNnEFFRkjSvV6Z0h9
riIm7lI7oGkQMKLuyIHLN9a/B+N1sGjmL19ay8DL5dwXFM/Q8FfZ6tCv/GF0
dMQ77ThfD8Wy5Esnj7PQPD/csbSiDVFCpverNVjIFBicsf+aBBUe7oOj/+fX
LWpBN0VzMFXFVJw5Qc7rnksRV23rce2+64YXNkww5sRouc9o4Bo0oh17MQSu
F9sXT9f2YMTJ9dRK9REY3RHeVmHxDicZIm8S+5jQIX6G3pgi9TX71TH7WCYi
k2kKSjYfwaNgNH6HnE/NDNNVtoF01Agr2+4l+6PtOlzj2vkRzE+DGywqSJ7l
yRri6GXhbvntzU7GBAKtuZMbo3pR5aueUc41hhmBSO3Vzz8h9u4hQnYFE3+3
vOC7toMKX4EK/ekhFti2Yn/X5dFgODH62WuYja6tm90XWbShvFFeNWMDE40v
TDRC1xbBbeeTlyGzTKRnu6Tnm1BQOxHPf1OPgL4c/fjnLy0Iq9BY6nyDwLmQ
+YPfTneC55ryYGo9B9ZcLiJJq7qgo6ArfuscB6Veygc2/qDicu6ec6tThjDS
ysdmmwygXlzC/rAbG4seue8+7tuBakrAoMCjYYx0no36sagUboGu1hV1BF4q
y/3ZJ9mM+5MG0eMGLKgIXnqo8KQEYexkMzMTAlyRj0KXdt7DseF79EUkb2pr
8zUPb+oAo3aXlZQeCzzZLzZJu9ERc+5RvviqIVRFqY+lpIXDN7dd+OFpAgk3
haQbvPpxu2mGa6yV5JGUyi9Hv0Th7E/z7+Okvy+1WP1ip1MdYtvzOj8tsKDz
Wf78kZVRyIqsfB51kuSZ+GTd/SRvzztLjueS9VU8HmH1HFS4PDnAX3GKA4qj
5Ujg42KYNUsuoZD6MrJCQuXCaBmsXv6YDCHzBMFVs0worRYW3rphY++YuL8v
+uca824kelX3691kQyx6kbPxUAd+RPa7Vs4wIZXetTtiSQ3SQiNylU1IPvYK
qNVTqMVWsW6ue9dI/dAX2rNOfwCrxC8Vj4T1o9eJdqb2IMlnzzK7GrcR+OvK
52CU2IGdzimJTpUs0J2t2Un7OjHOGNJb9JKDmOp7BdZ3ulH83drTd+sI3BVD
BlgF9aBr8w9EaZL7uEePW97TGhvvzRV3kPWjSUTwlp/rxJSwJ/FKmIlDihsD
NJeRfiG1dt9SRzLP5maZG2t24qPBfrcEdwbCXiU4b82ho0tpbfh5FdJPHqk9
N5prBo+QV/78Q7I+El6DNWWNcDVZ4tS8noXfgTE/51/2wT7Q18fehoOqwKCi
Y9Rm2NATYu3z2SguWTwjsaEaPPQ8wdhWJvz8goc9g+vgvMTxVOsOAnU77D6c
IvNeun1/gksvB+W7Fz54faHAqOinQ5A2C2EaEuq+n7vRuvOhxqIVpD8tnpb1
uVYKUxPGAaWPJD+ML1AnpErh/2mT8ckrZL8TgqxyrtPRQYu/HE3m2ZfNUeu8
HZrxJFM1pozMR2MLsa/cazuhW2ycmBk/jCnnpn8iNu8RFVze30v6labQ5UkG
ow705fmNrgMMqMlWTKv6leJo/cSCAplPKeutjJjH03FhzHhdAjnfguFnKM2y
GZBInmPYk/21taz0tdvfh/yqjBsi0cOYVbEqSDejw8TfDGd2jULi2C/Lnqul
kDP94dQrRaBVS7n7gjINnl/GlNtUGQi0MOxtuH4HopNWGpFk/05H3P0uca6b
7N8Bj+JfZD3bNdMXU9oRlNfkeYXMZw94ornzWJ14kVwzPwICc6vfWS6b60Tj
LvnK0WUE4mpPSYj9joMEzcjm9nFSnxU7VVz/1ON7ZKSFMMnb1jrqibbSNPiX
J1Z7RDDxRsY6NTC2G4OFXWlPXRk44EpXONPciXRziYuGX4ZhXfL1z6RkFqw2
+3rN7CHPfxKRsK0kD7sGC80Dc8k8+kCdR0a2C8056tNlsky85KngbqygwdJg
YeN1DgtqX+tW+XP3gMewKih+/TgSD1/YGztKw24ma/WqnBHoTNxaWvM+DHNT
v0LoJG/d+v7pSiRtAAINrjuz6wdg6kM77y6WDmsRloVrIAEP7qh/kTF9aFD4
mt3UNYyCP9d8eZyoCHmQoNedwsYUdb/5YAgNJwcTPub4DkOteA9PRv1NCJ6Y
FHQh/erNM0p7i08DTi5sr37lzYbZtUvCV6z6wNKtkThD7leS9OiVTaIt+Me7
9tmcOxP6kux9Co1diLnvbnb/CcmXn0Vy64dbsOdu/DdHkuf4W9aKNf+lonj0
V/Hk82EUj+3dHTNBRc7+zTE0ChMfdwdscSivwkdzq+J00s/kI3HDXe89RDfn
NvCTPOJgx7oVb1MPW2fBU3vesDFPY3UORfXDeJj/m2QjB6YCwyOcK20YUesw
SHhCvhcvPLqSqIH39oLgZB0mOcctBtXD2TD/ZOWQTfK3hINxpalXNz7p3D1b
6DICywTjAPq+Vvz9cHAuspKJfEWZ4/k7ymHxS1OeIPPKrFR//q8PdOybXSLy
p30YcrNfqaU9mZBLuDaa4EHqecPw7rluFzjJTHcYkLxhFnLESP5fO/rf7HCN
jCL7G/tBtVC+AnK3N3B7HmQhZuxbUN1cNVga3Z45VJJv6/hTmQXJyH8Wb7TW
lcDJzEDpVbQ+KJk61/P842BQWoF/2qUfMk8ybx9wH4docfQ3J6M22PdFCijo
szCfpiV2brgOoZknf68PJfnkq/AJg4EOCF+x29Tjy4ZJ7wPdRfataBRW/SUe
zEGCt+ZUnEEHXhGNRW2qbJTfi6B9ffARp9fskUtV5qDP+91hh3CSB96O2jZE
0RDWqRX/QbsNl151sV+QeUblsaz/urwKPOiM9JviZ0H3I+3b4Ps6XNzwOUC1
keSP+YsU6sEiaD6eGV1G1rvxpWKGiH8DVLWa5lyXsvD0y+X3TzZScGO2oLoh
bhgnqmLduAdpEDq6McAwmOQziyoxXqUPsDRSsNOwI/fFVD3ae3c+/N15Rw/f
IXk4+NzT2JUUbC01es+9MIQW6ez+576dkKD/9DtcT+6rhn6EAblPyw/xNthp
MWAguxDq6U2DQE0bT4YkA5vXu7iEkvk9bDKb3/RCL3Q2qxXkCr2HT1D+3scS
BJRUHaUiIym4dKRK7lEeAxK55dKiVv2IP+2yt1uNBdPSgpKApm78E+WYBXGP
4MXcYi6lvmYMyt6bvJ7IgnEZlS8ivR3OvaOzku5s+Eh5TL7WbUXKOrEbu7JI
PwoQvbbWYQD+/FmjO36ReTlyy/mbfnToJF7ftLLqM7jkpxqvtD5CunK4xCkn
gsxdJeGXtJvwQvnP98k+Al2vJbMXcT5hxJRP0kmAjVd8Dr+deTugfkObK4U+
jP8BI9kHng==
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81dkbx2kRSUrCoJEl2RKlUuGjUmiUFhKukHXSQjUSooWUkDuqsSUZ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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk81VkfRqpRdywVorypSNEihFI9mEyRkIiiLFnKeEuUkEoivBrMlKQM
CTWh2816ce1bomzXteve+zuWQgppEvX+5o/zOZ/z1/c5z/dZ1rqes3YXExER
uUuff2+9ryHXh4y6EOBYNRniScHwzKEq37AEcMGvyzQlIEyp0iW5rTAbDg34
5ZgQFpZyzUM3XqPNRcs5q52AH2MS92PuPn4UpziEnSB4mWTnZfyNi+m3zXYT
MUI4X2lLFl/IQtYkOzPSkcAnvHy0ICoLs+Wt2YddCFr3yv4qFc2F/bH6hf5P
CBp+z7kxns6D9AmFeHV/Ib5zUxMpFTYyqw7HZoYSvHUKUClZ+xIzgfUm4s4E
Ckfz3TfVNsKDSfH7WRTKfC+5mkbWQMwlQnvTewr8fBd7p8YO2C/jyfi95WMl
Ws9eHWqG/7trnIm/hPCwyjdw+NqBLXMSD5boC3HycNaR5Zlc6HMfiW56ReP/
ditc04uF7TPJ0kpGBGy1R9fvjFeDlCq68Wi+jM3b35mdqEVLk+IANhKcln5a
ZOJdhKkQtVWeDgRdr03yPnM4uLwzXF77Kv1eKp4+v6sHKlE9NtE6NH8CfVZH
YwbOeHdLGVkTbLTwu6ty8jlyTTd0RPsRPOuammGd5UGDE7TCSpRAxzJ6o2db
HSpvNQW6BlPoOnr9paw8B5Myqotk9hCEydv3KZnk4VC7XZqiD0Gwyqew/PBq
uI5M7W2YoFDTzJie4VfgQtOLmDllgkjjuuBe0oyRqRzRsFoKuZxFxkQ5G8zN
igofwglCGl1UqksfIFNlpehrGwJn79u5T3cV4uWypQsiFQkChK+4u9vf4MPF
jZ0RND4SMakrn9SN9jRB4Nx1PgJi49vGdraB+A8ySrcK8e3pgdqfuM0wYHx2
2CI5CMO/brc9uFCB/WvmU346R+HeY+Xruvpl2MJL7e/QI/hnv+5Z8Yw+/L25
K0LiOB/GwSJXxtVbIal1zYLzVohIbRt9qcuFYDFVtm+RJbjDaM01yejGvpjZ
H1GvB8CwZEhsnmvHiBsV/SOdwEIxUGRsdzvKuozRvJ3Ge++3UX1eBzTtNNQP
HhaApXnms3hPL9LrJHnM22/Buu+V2mKbj+L6+LrlO2k+rDMWB67MgsHy1fua
vAk+Zt7Y3pLNg9l6hVhxJyFmXM9d8cuuBMuM07YniECsrXXstGofrFunPcey
CbSiVu1Iiu2Hlly6dj+hoKyuPe/UkAa2nOXRWFeC0QTF4HTLN/DdfFP1QByB
hKKiu75zB07FFhm10/+ttve1e/6tHYpSG6cXR1NYsdKjbTq3Gv43mZnvL1Lw
ybARX7ytFC+tv/HTEgiyy+dGPlj14N44W/ydlRBDuY/DTecHoBwomzH6XADz
/EwBw6oWkWY3TRP6KYzg44K/jzejNKN4g0O4EIw/z53TlCrHgW0BcTo0vrLB
7zXPfDtR07evviBXiGsKinsH1/WiJXaBeKcGvY97QbqLn1WhZzBHb2oVhYe2
cREvNtVDU/FgyXlHCh9rO1fL2j7G2MAjt8t2BEltF4cb8rl4x/iU+AdjEPr6
89asvE4EcXjlStJ8sFe9kfCN48DNMHy49xuFMOUKlVMjzXC9K5uocFmIquDc
UoF1K8alWsqfLKagZCkDy8FOpFc9rxJOCOHPdLZUcq9DzPEO4+6n9L6nav7Q
XVsJOZUHzqHbCDx1B3hN8lVwNak5kadK63nRm7wtegWIZael2K4jSNm1wOjP
qHrMfomaPyc6iI1Ju3XCaP88kg4Mcpyi4P2H+nX3SR6uftp5dOVVAZz44uxq
9OH7juR53xMDYO4tWbN0QSe0b4tkPE4UIiRDvidXuhqRVovU7xXSfh5vLeqM
Lkd+0qodc7Re4l+kDA+L8uDT52OZZk6hImt3T0VjLY5IR15wc6HnNajNDm3q
xeUPhV4rmgcw5mHwLkGpGXnjZuqbvCms3P69cGF3A0IVAj0ZBwi9d6Yxf3cx
NA+PHs9eS+t1m4X/v/5pOhDs1bWOglb6yzMfp3lYUjA6a1QmAPGWr/XJqcCl
1Tcl7RIphMgUHVSNbQLX7uxIySmC71+fRWSf6cNvAYutmIx++A3XhclEt8P0
f8rc/BICw6XdN0Y0vaH+80VmuBNBzrZHcta8KlzQUTO6IUbnEX9KUPIrF15S
gWU39SkEffG4799ci8G07A3rtWj+59Xc7NVyEfJXv8RmOm9WVD5u0dOrxBa9
7uVr6XyMw6XH2gvLEWT3Qyyxg8KdNDtTs3QODt0/aaaxn2Aup/BuoC4POztt
r+W84uO4UviLzXt5mLPma36Q5aMr+aerme/ZOL9Nf2ZsH8HngYnQmIwWbA2Z
ZP55SoizcmUGfNda/FpkvufIMoIplliIQlANkuJTLayz6PnDaa530hvxsHt5
Z4MTre/On9mJ1i/AuzWUoudJUNGmw9rv/Bo1TVlDt54J8eWL+X8KF8QjO8nP
aZruv/eNTn4qCh3gJDMmopLpfuqn0hKvlsHRw7DoNN0HWtQI2/UQF1EO9TlJ
hgJopmytcxTvxQa3EsbBrQJgh1+1UkEjRpK/2MbJDqJvdPZj6ckuxCyaEik4
xseyqITygYUtmH+a+kVthxAt+XZT9ytfoXDrkoBJe1ofIzkX1PfmoUNVY3Ct
GoHj7clXgiO0HoY6bQMHBQjtt/X8pJoBC7mLP99wJ2B1aOosaUjHyX1ibqMG
9P/veltz1vFQILujxG09ja/swfI59t9Q8S5nTIDgpvmbrg1RVdjvbrn+K62f
VKVHrdShFlQe3X/m/O90X1dY2d2O5GLZlazjFqcF+Eey5aJNYTHuZRfk5lAU
2McMWEy/AvDNIyJjNAjMlELPh4u0479nWxUzIoV4LzSJH1FoRdtnVoS1khA+
v/kFhUn24MKgV41KEJ1rT2aC40sSUGGTEFVF8y2e5eC72r8Fky5hjWt2CbHO
w9Dtq+NrDM/o2vzCpvuc6RBgNVKBUaNrLyS5FIpZjIfdve2Y0uCs71sohOGu
xM6u+DwclR19a0br07DC3LhYuxZLqkdfxX2ncPqwmsyTDQ+xpmb3gz10nrFn
PU0v0f5LFZW4Rmoo/B8ir8l4
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 125->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs0lVkfx10S0xSRVzrMUMqSlCmXCvm6hV6ppgy6yZRcDyMhKZckFSX3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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lG0bxqe00GZJKJI2L16EVHrDqUUbFVpI9kpIpGxRslUqlaRCKiTZ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41Wkbx7WOSJRlGiFU70hZamQf38ZIzKAminRCkhOKQyY7x1ZZ0ojO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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs0VfkbxlVqVOiYyTUUZboMZQyFUY9xqxzhIAyikkJyqVwyKpeSxiVF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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 126->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwdlXk81dkbx43R6s4kUk1UlkgqSzLRND5RQ1OaonVK9iVmXCqSpVy7hIiQ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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2kglG8bxRVK9iRJkkpKsqSUbEdSSYWkQhJSSSrZlZBSFFooJFqtSQg1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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlWk81ekbxk+WaJtJ1iQRiRGpEcZ2yZDItMkWskQioYiISUkiS6TJIGMZ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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk41fkblbSoCNGQVGpSllQqjXFzJNcSypRKyFLUVUKWiMoSWozSYg2T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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 127->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs4VWkbxvVFyhiUGJ8ODp00JKdPatNdhFLJFCUkbXIIkRShUDRNY5BT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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VG0fli1KaA/tJUv2JUJu5JVKEpEWFSFahFSKt9BCKaRkSVmikLco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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlWs41Vkbxnc5RtlSQomZVEMYBqFJ3ZQ0qRyKHOe1y6EcKhQSphwmoiQ2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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVWs4lWkbpXJIplQITWMrojIxIQ2yEJJDGrPJsajdRBmHwSb5JCMZpEjI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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 128->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk81WkflWwV0mJaVMg0ZYpKwqvGoUyvqegmWpSIyhpDkfG2TKiMVJgs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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8Vf8fFhpKQ2V9W0ZRspVU8qBlFYlSVIhSViQzkSYVUoqMKCsZF2WP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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVWk4lVsbpiJFCI1HEhGiHAkJt1Q+QySaODYZtowZjtRXGgiR6ISQobap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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk01ekfx2+2JktjGRnXZG2RpE0i8m5TRBqUEMpWDRGVZYxtpCIxOUKL
jGRL1ixzG8lVuLqu/bp2rvv9WjISWWuMft/fH895zuec5znn+byf9/v1UXO9
Yu0hRKPRkqn1//31U/+Lzlp/wdbTaybpFAnH0iKp+5x2TK5fTB2bIjBd3saf
P1ODtYXT/fYnSYh7fVvMGujEutJfFYVWBBCh7Tfqe8TF5rTxKYXzw+ClWUjx
4rh49EF/nxebj3S6Z3jz9k6Mb9FqO3OagKby+i12yn/D+cLEf5pZJJZjZ8QH
33FxKubFcOq2YaT6zvtomDAxYK7us3GGgKRmpbsFj4dF7syYRy0BaaMyk5p7
nbBQFEuyvTAMMlVFWKeQiePeU86DBQQK9Z1jMhebUbuPfo8XRCIvk798a3UZ
OIp+Cr9fJKG8+3cV+hIXdi203hCmALRAl7sLJtfwo8P0F4nz1PlrWyuOM97D
odvzSJgyifjeLXrTPw1ilhH3ZOPkAL4GeId5sesh+dFa7/QcAd1CySCf/ndI
mLt9pozqL0UipsrlFQs02pUqaRkSfCdrtU+sF1Bo29DLMiChmtelE5+cgfuB
pvo1lJ62F3poWwVcfCdsc87UToBo5r+Ctes64BYZdjmfHAY3dWZw4mED7vDf
H96pTd1vJLLUt0bikJztjXEnEunf/xIUhEQ0H+9Xq6bqp3Hu7QcquuD6Vm7N
wZFhGN3QmjoWUYdnL+t91tqR8H0s6szpeo177/iHEvRIfNEPbZsaLYG9aOyF
TAcSS1qfdmv//B5T/S5b/9MgKN16wgcMOxAcXDpQaTAMTRfnOL9P1bAWY0rQ
vUmMO6jQ66s4YJ6wfs1MIuBb93SsQus9okale4oyCNBMOpXE3W7gkZ6P49g5
Egd6wzJOeSSg8JapzTaqjlhSl1j1sBOMfNaSkycfzNfyy6e0OBDpeJjoLUpi
k17XizSrN8hfZdwzkUKi+0tA76g5E2UvL1eypgkEzXEneRszIaC1OBi7kjgy
e3s+yLEJ9sExt3doEui7WDCXVt0PXqOd1dGTAmhp6yk6KDfDyqVPPqaKxHUX
3wDR0F5w7npOu84NQTpE6blC8p8QN/ksfvUECZOx4JH1Qu342jIrn0MfAWPj
4hjfrwJnFpVHFNaToFVIyQbWeeLSaa8EYaofbdE7ns2LPAwGtV2RXs+HvoeV
zcqbRkhvDzUb9Sdg7Xh6s6QiB5E8gz+KbxLYkxvHTbHkoeC2xmgI9T/86uLZ
P0xbQDLcvR38BUi1K9PlV9fBc+j1zTtfCfyUkr8zc6YLsjdFvi2ODuOIVp5/
WzcHfIfE+ebDJHa5FM37SrUj0yNBprxPgB0KbkIGRe9QHkNfSGZTec6MOHbd
LRfObzP/rXQnUXFMv4t+i8qz7G+SShiGNm/ppP6av6CtrBx5L5DqL0g/l375
AdTHPzizKX/51LE44VLZkJ+cCIn2IVFurPbqrG0XBvlhObMHCDiPiRZnCFch
1l7Uq+YACct1nhYqTt3Qax9hlVYQeMR68uE36VZoFYu8qKeRKF6T1sZ+3A3f
+C/Lh+oJpPrz3l7RaMXm+t5jD6wEUK0POr3nYwpG7xgUjDmTKHEaYDzuaQfj
nFKotjkBK9GQ3Y4N7SjNDpdJ+pXy444ztlPXe1Fa2m7R5DuCV5zPnUqNJbgf
Tg9QdiER8+NBR/ZQJfa63zbPTaJ4l388QXVXHdq12StOjiSkWR5+k/I5CPv3
hpllBInY8WVLsx3dGPfbEEXPJrAUN3R2PLUFutIxdULqBOyajH3F6hggD55f
EvlI4EA0M6equhjlDmsapdaSiNRs/lr+azHoN9KfrrlJYro9oEd3cwusF0r/
YRwi0DDzoeuuGhO+/UPcrCEqLxMrGg/Ip3D/PjqSZksiij4om0ErwRENw2G/
yyREzrYaFSS+A7OTNVlnTsJCJ67PtJSN0Md1vKizFF/3rh7JLeDCtdZe5hdd
ATiZZ5bKssphbTgd7UfxKGJCN+dhciZUX5V2sNxI0CM1oiVsWpF79Gv5qDiB
F9G5Wf2KPOz8Zpxc/UCAOXuvXfPrWbh8tbP201sBvruV1ldj04DnnOjhWSES
E6HZUgbyTWhRjI95Hk8gTm3pmoZZP3QSVsms1R1G5lB8axC9g/KdVrvWEwIL
NyuE5d/XI15O7XGuOgkmq6bmc0kt8vLDjntT78/e5rJxl1U3VCMczPbupfRw
zyphbO+BoeKfYuFFAli6LuQcpvx9LOWLfkaxAMsRREm5ARsbtsnRLqkRcD22
83DgkzbkPdo/x2sh0NpqPr42vxwJbe6eRkcp/dsWzMQcKR6Gh84/K6L8VsL9
pMPqgMm+JUHpbgJvgnyOq3b1Q14gNZL+cACdK5v2jggqkHZX1KnKkkRIv/OJ
PLMm/C25UN3fLAB/omTTSsMdbIps/GxI+aeMcyTsnNZLfEyseCG4T0L3wbNP
DrJsFGl6798lTYBpfLVS904SljvWTb+keHF7VqXGRrIV/6w7H+yrS+LE845u
vWo2PiuPzIiVkBCjbzKQaejAEo8dX5AhwM/pktOB3p1wjOzDRd4wwhzTHEb0
G5B86ds1R2qejCvullbdX4aV6hWre9EkMugzo5cPVmNOoHS+cDUJFePxU8se
AxARZ9d9pyJAzs490osUXy7QdfvZipQ/qgY+GDa+wS5ruwmzHgL6Wd82EAH1
mNSIWvkiTvlZri/g0KVGRDGUFLdSvPnhlw45+9FGuKgMiev8QfGkXeZiOIML
j54GxpNwAUxj//ObMWHBLzjY52QsAdV7xewDm5vw44zwJg41L3+WcAuLLePB
+euYb6UhH7QEg6M9Rf54pvDPidWUPm+mkvIU9nXDdpusf1K2ALpyfQ9X2jjI
3nFyTy6V//bWrvnfRjsQXZtoubBCQPTjtdLApLe42jA75gUSuZfM6UE+Rdje
Uxy5meIdIzAvLE69HumFKtffU/NFR8WC9QO3E5Uh5QdrpQSQElIh8pxrkCjb
ne+mRSLQq8voaHovhowOiUWkCOB5/YSr9MlG5DsPFkrbEDC4vlP35sV2ZP0p
bGrHJiHxxC3naDcXTW1b6HujCPwPsC/DHQ==
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 129->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lekbx6kYGdXQaVFCIUm/ytqk9DVSiGyjISmhpLFWtjAle0VjLGUy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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VG0bx7UJbVosqSilFNmlpH6SEpXssoSUJyRSeVCSrSxJhZDoUalU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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41Wkbx5EhJSGFUklpDC1EE6KvvKVSvNomHUsKEYpElCVCIpmJEqKy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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lWkfxlVMNDTRkN5k6cVUFCYJ4ZIsJ9mTZQgplESkiBbClCxFaZSJ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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 130->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8VekbV/lNQpNBlmrKqCwx8ZNMKX2bqLRRRAZZo2tfkigVpphEZLnW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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHk8VG0bFiIR6tUmWXorFKWyRLhsJVHhJSKUyFqWKKRIJQqlqEiiLGXL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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk41ekXRxhbaBNGkWgkRLY0+GizZAk1kmxZkqiUopCshbKELBUJFVJI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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk81HkfnyIsLVYSqu1wdMmdcr6VDgqJVSLMKJsr16bIljNnRdGmknLX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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 131->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk4ld0axrcGKRWdBjRQpnSi5OijgVsynooGKg2mkFB2ho2UlOFLioqE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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VG8bJipLWUtERWVNQiXi55ZshQhJpaIkbSgRWSJLiEiFJJU2y1iS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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81Okfn6wOFfEj2daQIkJSJKm8E7WOyJXuWFFK6ypExEpytFR2NYiV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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lekbxpUWU0YhhTFlisb8KmSZpOEiKmSroY4tS6ppmLFEKUokCZUw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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 132->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8ldkfFkYkSZTq0tStMTUoGUskj0r0QcsvpEIaSSptQ6iMENpJlqTB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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3cglW0flkL0GglRiCIzO2lwSSorSUiUvF4ZRRpCSkaRFKmMiLSMVELK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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81Vkfx2+7CnkKyaArTbaENFkqn9QkKkuRJEIJZekWxvBMJEu2MfYk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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk81PkfniIpR0o3RRpXohDbhn10bGJdoRIlKUQ5GxaVpRRli5RNKNHk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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 133->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lVkfR5K2UZEaU2lhFEVlsr99GyJtaCFpYWRudqKQneS+omIIqddk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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lHsbxy2VJS1KUklKZUlZTjv5KrK02MIplV0JlUPJTlLoqEQhWcqR
hGSrbCEkzNhmLGOyjJlnhpI1yVrv8/4111wz1/P8fvfyuT/3ZvurZk4CfHx8
1vx8fP//VHj+62FceAMOVuSMVN7gwFlYbqPHvSpMB7isKSY4GFsueS5J+S16
Vo/HKKoRmN6zcrLAth3+zwZYPXEcSCzd+KMphQ573+SqZ0KD4LPTibxbnIJn
+jlGO44SOF2gSiE2PIUAQ2Qw/xoB32/O9tTDX8AI/Vk71DqIa69Trt683YHm
Jmu5BvYgTNKfHbXrLIHoLcugvI8E9t9XmfP72or5qRq9d+UD2L1WPXyilYLY
+q6NK2vYEL7ASbgrWgzRj+OTUd85SH3z/b3wtSpQSjRaMp8SmIxKWe1YVAv1
nELuBS02xizEfSwUyrHkgbmF9i0CEvmLjNrCWiEmYtNVz2ajTfKGzjKpNmxt
Gk713kNg1EfUaXigFMKaufR/nxBgHNC0v7G2A3dZFvSbTTx8v9mu90u1EKW5
/yWOSRGQEnjl4jVXiU1vbSiaBzjI4A/SoW19hu7F5nYsOwK2313EOy7WIzVH
jneGw0Fo9JU9ngldSJP6oHJcZgDzW/Rnjoo1Y6WSY7vmKw4+QHBgc1cnFJmB
MjNhHAwWLGSPbv+Ir0Jm+XZUDir/NjYx1UjDCbHx4HYzAsFlAXF5dq14yfIx
1TMi0PLB+HPdAB3+vB0huSwWFnVW7W9WeIvGy58cF58gICskG3c0qxLnIg0v
LyHzlXgn+elyMh9Gvw9Ix7znIXj5qF93yGO4xaW0/75A4GdWafgboQ6YhVHV
h6kDiNoz/67w/gs8NTkrKGBIwERKeU2jfAG8P1Fzfm0hsNXm3nRTah18tXe+
jZXjwV9DO3c8ngb3CR/Pc/e/QvrO7bpch2I4TjkrJXcSUE70dJlSr8GHxqPS
6fE8hAbodDGo1di0JYd7uJLMF71071knCpo1M84xR9ioTLcblpp7isbY0SHK
OQLc814jBUaNcPa5fK34AQedU5RfG6q64HLKUnSNPgdHVE/umd5LAeOM16WR
4zyc8N0/o0g+r3Dk3RvtDDYGL1tc/fnnM6Qk3jZ793ERphxRdOhqC4qKvBgm
sjywvtTeP3z1IXY36Z+ZO0vAbUfWtu9L69HbR6GdyWRBVddQ8cypTOh29pZm
nCdgX3RQUiy6E86uCw3EyX6EKGR+V2S0QLT42AqNTRwEuwkHJIwFgmXlHfzB
msCMfptTOqUNiim+sccYXEzHBX3+ptEI7cWu58eef0XltDSzbe9tbMmTT5Mg
339ay3qF1q0WmI++yh8i86+88/dOQ/Nq0Cd/scp6eTAvrNn9iUbBpIlK8Atv
Lp5FXRlZWpwG9yNTU81k/Td8Zh72udyGLUoCzbZk/Ce87lSFxjFRtNH2OOMq
C/nXR4RdVhfDuL2gVTaIgKZ38e2bZ5vAeSnYV0y+f8L9+rXZPiZ22NXf+7OO
gN+PrYnEFgaoiZY2slqDiFxt4Ho6lAKbvFqWggwb5e5pal3CNOz0XT+6UZKF
P29HpzzC28EqWR8dYjqAIhP3ye/PPoHf5zbfSxoH4X1HhKtmKtCbd1hHS4cL
VZfLWJRTj9rUhqSjrwlsv2+ZxlpPQ9/JJwkvczl4W6B/7EQ3A6Isz5ouJw5g
NJek4vUSGtm9TSccCUhWzSesWNcO+W1Px0zmCBgkUzQuOTLxX7Gud9YcDwnB
4Wqc4S9I3SSgzxPsR0twuUWBYiXUaUmq+6U42GzqL3ne4iPU2Oal0fMcPJqq
5fn7tmL0qTef1SseqGyvo32Wzfjnh/Q7ThcXi/yODCehCc6m9d0Ze7kwOM5d
qn/+HUTvFle8kSfQ485nYt/YDtoTNwvmNBcK3B39zhqfsP1HPr1sC4fMT+lv
x8FWbHE+tFVHkezn57rrFSWpGNA+VpDuwwWf1XDS/ojncNmqwhQg82FQ6fSx
4GQafM0fWdWaEmg7oRXfH9oF1Z2BrkFnudgntnHD45/teLjb+HFiLRuSL/p6
Jzf24jRVKC5QZwgSb+q+rFBmIvimiwZtfw9MXMqSBAUzMXbJ017KgIB2SEF0
fugbXIh+mjJqRUB39/C16Ro6ZnMvLnvxlOwfOe9v4RUfEchYCDslS+DzvGiw
8dIvONRUtlT44SDM9EM+1DJo2J991/g6hYdUKk3mL9kqVI6ZEta5BHZt7pwT
3RkDTf0jeaWWBJhTFKmdH1tRfqxquCyL5MutdbPFSrmYFUzW/UHms0pz21CZ
dSWm2cfPRi1wIPzPHUNqWRCi/dRE8m3I874uHbQJiEWf8WEvXTIer57I2Fe+
7IOHqBRb6woXuWKJNk/OZKP2EE3E4QoB52YNjXynRNgv8glUI78L2B1ITue1
48nc3HufHwTm89Q67HK7oHtcx/fM7W+Qliq+XDpCw7aS3y9ukv+PP5zXvvdx
EUZ2n93A2ETyOCQ1oOlXMhRW5+5NPE3AzDemOvDBF+xSahJcO8+DVt2D8dNy
nxDvqXXklg55vwAVy1VpOTDUd/CLIOdlpWBVVHJCMoKJZ/ELJwmwlNVeX/5U
Cft9Wu96jLiQeCBqYWBVjpEM3mVrJy6mpghdndAOvK2JCDOs6IP3Hfu8tS1t
mKnLqPWisfFPRtaM7W4GZIc9/nBTB6Hgxmfl0fYJHmedkgN/kPP/72jb4jEK
lPT27tMg56X7uE/MXZ88GORkq8SKkvMr+09LFC0NU86Mf7T0CFih+2SlAR2n
HxVU7/mXwMple5qc2rogKJfhckeLBeaGyPvdVp0I4G5QEns+BNu0C87i5dHQ
2BHiIWtO1jP1aOgKjWu4YB2sLkfy71G58MHf/9WisNeTS08icFFws4MZswHC
CoYPzcW4qBvwc+noLsQ+c5OjFa4EYgs0rl8zoWNJ/+i+hhEe+EYvrhW0rMbD
zAylPRMELLf9DNjNZSDlE//2kukuCBjKJ+SXfMKztiUnl/4mIP3VKXflBxq2
TLO+Mb3YJIfTWw0To7Hl/Uppd3KebFFPmVlMoyFq3T7v3n4OdBULmMo+VJxt
YUx8LewH6+ZF1vB5Onzmt2e8P0jOH6edLw1smJi3VTbgkPV5rrn5ZpATyftN
ayuW6/Dg9uLd9fm+DlySYamXtpLzdUplaE35F5i/1/fu7B/CpGM2caGsEvNW
h35keXIxX/0zy+GfTlw/rRt6SYmHD1aN6sFyrdg17rG0J54AJQJXna2/YM1Y
2MmEXBYuUH0SfB3KcLrfVeXzLBnPRr85+1PVKDPee4T/Khlv5dUZ9mKf4R5e
NLFVlIugcrtlmtwsvOLGnVKMITAV3eW84Vcu+Fs/a4ffJ5Cb7P/vTGo8Zq/n
5ZheJvkSZWhUp9yMjbFtfLlF/egY6or0CaEhe8vltUIKXNSuWBaT5VgPU/c7
ujudyfs1rJP/epSG1LBHh71WDyBR73BxbAAD65ys7WOTelDxZIBy5EwVZK4O
RqoXcmC7WLpssLIVlo59Gg9WkXwt0Tmzb5yOY9bPK2K+cTE66SfSs+MTjN5N
7xT0Ie8jtkmr1aYDCw+cdDRzeLD9ecW8gP4QZhSlO3lnCBSuPEA7Lt9JemhG
VPKrHtQdkJNwSH6PrczNubu1CXjvLimhBFKhYF5v4ryJDd/OPUFzu1sw9Vfc
c94tHgzuRHO/F1CxSm3Gw6yQje7yGYNGcj5t3Rjpk3qD5O8eMeb+el+szLAI
vkrOe9XAoztSdRsx3HQgpDKzH8nXtlf7TlCQRlCrChx50DmSHzAmUoUDvx42
9o+R/d01/MTPIAm2Ve0h/mT9R08annbObkPKNYuMCjMeOjbS86uPdcI7cXT+
TxcL6SMl3KC/WiFr8e3McUseBDVeve7yp2PN6nrpWdJPipgil7TN2sA46TE5
XtaP72IXbIp0SJ8KcmteIH128FrbioQjdERKa63pGx1Ag+2B7bmfGYgIaLq3
fS0LuxdPR+Vt/QIHfrGWvf1fcJqPVuLrXAmxa/yRcpe5WHdlc/x8IznfnrP3
1vQRuD/+Zo2pAQWz25aKLSd5xzd2VLy2VRanlobnqJL8VfTlpTIG6Zj7I+0x
e6Ub3gw+y3uXusg+vr9SVbULwWnbxFmvS7B+c/ObsecEFKxCXO29MtHczq4T
iyP9NECkxHQoB/bGjx4OlBFYVZE790e5FXwLUwV6O8l6qV0mpKD1BvcFyxTG
ZAjk+I8ES1TTcc5l0bKZK/3gc0x9rWmThB9j82/anQjwazE3mPFTkLhYdNcs
OW+luKtKlxysxpqvY0v31xMIFVh93CguC0zmEsdWIQLLm/UcOmrboH0my7+y
nIcxO5lBzosq7D1lvF1SnZzXIWv9juyJgZHB0yN2pB9XVsq4Z4XkYXi9uqWY
PzkPvui0LZD80d/4ZNUncXJf4S9PlP9OhZjj+4+lJJ9aKPyn0k5QIKEoZNPj
wcG5TVG+/B7tmDrr5vQ9moesnenHl9u0oyXhwwid9DX3gZrME0hBnxojIZX0
7bKaGb1bPl+gXz6r92L/IM7JuqvW6HYjV6Ui6pHcMFjzv4rcn5A+VbVZ07aO
A3O9E7pbantg01Wj+Cu4B+yt/R/lXMh+fHHk2PEJkp/jXHeldZEQ470OiyH5
l31Np6DkQhd4S/zt2vMGIbmjS8elvBn3Tv39ewnpi4mTVIHtBQ0wXP1cUOgb
By23cj4mzn/EbKb28BsagaK7Wi/jEujIkD7sOO7KwrsSv6/CEjSM2D8Mminm
YfC/hhnjDQy4fZnROEY+z0S+7Pw9vVqseuFk/pzcn9zMPCkljgxIuytlZo8S
UHFQUbX0asRfjrt8P5H8kth6xTTiShXix51u3gzlIj6ldPPdSSp0X638la/B
QazCxHpVtVbE/HnPbtPph8B1kVN8uZ2w7xfcdPYAF+HNJmI0vSo4iY7GhMly
wBens7DDKBGJba/HRch+PJg9Fj4KGh4pML/dSOFgwPVH5k/5FiwSqOq/d5gN
hbMRfspvq0CtNj1QSPImYVZxjcUPChbRnvb5SHFRFWp+23iiifSX2JePRfth
4MGJ/vk5H0VuKn/b3SYQpn11W/hOBmzsyhdHBnVAyf+Bw6eBFtw/Pm6Z96Ef
tucnzkjRnqA1Mqt4MekPbqELxavGSqG03GH8ZjwH2nvyvt76hw5pe8NXzHss
8CW/68yVpmNkq13+VwkOZKNmD2pdfY6k5XsyZ/aS/vtQXFaJj4bIX1buxuS+
k1GkqerBpiJ5bAPLcJLsPw2bvuWF8eC9Tmv+fz27FXp+9D76Bf63Pf36f3Ph
tpQW25vSAms3+cGaG/04Nex6QDeKDtPIYqtD8lzsV8uRDMqvgaNVe8zJCS56
fms/Gc5iwr+2aNBabRBuVM2KO9tr4NNTU9xxiwPfimeHj+vSIEQwuyZm2HCz
MEsOdqIjKmJqNaOJTZ7/LC+CG4HQ3dE9eaRvPpoQfePET0dt+SL/WyYDYIh0
KM16VuG7UECMIIXkj77ZlNFrGvQfrzNdtEDyLvaP53/Cn1GoeilOJ70fhoGe
NvVLqhDwLlOQR/qzmLSz1MvmRqy09O1YR/plrpDV9QXnGsiEZh+uuMzB73Uy
sZwiGr7a7g17NUaeZzRR2pugY/WuJTJL1rMxX5mspjeWDtWn1ctELhIg8uUv
3if9dxVnrkb2HoEhUSU0HGxCqHrrc9HMAfApSF2PCz+LJX30VnGSjzdfvBfh
ZHUjOpHaxf+Q3De6mdlm6h9Ro24QprKHi+ADXVt3kDzUOj/NS/cj8F2fHjC0
pw4rFGULn5D+o+boJDGc3ImGBbeImrdsCL1aLdt3txAqU6u0H3uR/HyV5pln
1wJdBvvejVAOpOusw8x5VMAmPaSRyoHCj23NkldKIbA/Q16czHcL2/ryxt+l
WCbRZ+oRQfLmsfHpyeM0XI0K62OfZGGkVoYzpP8MqhMZrMN2BBYt01euES1C
oM+KXYxLBPYb90jkzX3A43/dyyYESH7opP2ns/Qdtm0MvkN4EnCU1PzwuIyB
ZWHZUphnwXbm9QFXSi6iFmePFB8jfw9I3+YyS0N3/9zM8IN+OAiK/PtM7jNW
hXZ1OG/joE8mtv5NKBV3X0RIClWTvivAGRQXY+JZk9E3vU1tGEs6l9++ho7A
d0r14rU8aLctPOhpfIuqoTHVRA3yfsOL4xdtZyCdetnPLZqLXrUso31OvaRn
Xch7XshDyxtx3R0pjZBwYv6XZt0PRrb1EVnFT5jM4fQ4SROQmj62obKOgq1B
Yw+pZHztqw55D+6jw0Xv0Mf91wfBF3Gx7a7hW/gt7HJdvpKMx6Ei4wyldDiY
797UScZXQF1l/aPBFqy6qmC0pZUNKUkpqzjDBpTxLCiuNf0oWlrDC01tRYgV
Ky03fBB1GF69yf49vKybpKxESB9W9+l3PtQOYkW4uwVIP9x+U9xHnA7Pe/GD
N3P6oRDx3k/bNA/nJhQzK/8mIGGRS3MQokO8657llAoPTEe5avk/H/C1sHv2
WSAXzjfOHKz1eI9IxdeCS4TI/TqoqDz6NhMZ68UsZmLJ/hhaPNpiRcH6hKd/
uZmzscXrl+Pn6TroWMU71Z7jkvlszptc/hHbt4fVI4mDMb8f+X3OFXjXe/uG
aSQBLZklQ8Z0sj6SxtqSY8n+utXUW0T6oO+K/flmo70wdDVsynsRC8dbP619
yHoyfuDUI+RFRXqQ4mBxNxsPDji1/xXajSDhbwlz8mycjlFlhdAZuPNyYcrv
BoEx6nmRug3lKPi2OamGzcEDh2Pv+/xacHfJVK0Tef59/P9e0qnoRO8it3/N
SF4nH5TXWPW6DbvfBMY3PST3CYFHj2z5vuDvfwVLhaI7cE35mpOBJgPC+z2y
Iy4Pok3aLDXYpQXfWl5tevyEA2pDjLO3Qh02btKfsiTjm8iSVKpb9hYy580P
/v7NwZWoskA7+nv0xez1L2GRPn3PdZu6PhMKc8VDF099w2TDWE+eeCNqVox7
iJD7TejtoOPV62ugqcvpv9tD7k/h1XvD+nLwvHfJiUNkfWnqCLvq99WB7rmr
IkV5AHfFO6YmnzIhJ7pXePEYD9FXzz4a0u7GpaSmm5NVPOjmPjYPRxcKs7oj
ll/n4n8l0yM/
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81OkXx/GTVCplo3Kp3FuWakvS8rEuEbFWg0JGlJlFJJRKUoskSVKu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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4lWkfPpVKGBnZSslMm++YUKRRcpMKkyxNE206GXtJxWCydELKkqij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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 134->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns8VFkAxyfVJo+NzZa1sii2VhNborx+GmrLJtJmSy/aKYkkDS15hCST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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8Vf/XxVW+lShDhSSSzIoiya9aKkVIQikVUqRIA5VIJGXMUEIisySi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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81ekbFSkhIcqoRpFG/EKDaDGHFCWy1JQKyZJlCJOMSMnPVpEaMU0i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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lWkfxokWS5YwZJlUiiilIWrKxdiGxkwhL0ZZEy/JTDLGJEspJSFr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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 135->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs8VekextUxh0qZ3CIMMpQoiW7Eo8YMTZpKRSEhOSQp7QyiXHYmJySl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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VP8XxkmLFtmlrFmKSLKF4pFUCEmKEmmnkGSrkEp9VchSiiRbESpb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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81GsbxiWhg7ZDibJUEr0HJ7RQXSEZaRFKjkKdI0JMC0papZA6tmzJ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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs01WkXPsq9lFRyG5L0IQxFRHlichlKGCK6nEEliYqYspLo4h5Gkwmd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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 136->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwdlnk8lWkfxg2aiqyjHEoKNaaaNzUV2S7RomE0SVGZksYyyUSy5czEkO2V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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VH0fxkcr2hRZyq602iql0C0UIdlTKBL1VLYeopQsKWVJeipJhago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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs4lNkfH1SqbZVcsi4RbTb35FJYn0wbUW1CLYtsmEpIWUVShBiXlEu0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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4lWkbJ0UL8kUZGUkb0yrKpEy/w2gZIVlq4owolaRCKdt3rFlKZWRk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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 137->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lmkXVvjGpKZFxRTFpLK88fqaUrarlBJpmiwhxhYaCSkiCklGtjRk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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8Vv0fxoUGCmUkqaRCpVRKS11FyuMRyioyHiFKKKWBcpdkJSoSCRmJ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVWk8lWkfPpStYjAq2xRCmhaKCpXrKJUtYooWo4O8YxuhkWXkbQYtEkYd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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs8lGkUnoSEJNlVWZdcKmQrZCProVBrNymSS+6UsKUL5VLaSigJISuJ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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 138->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lWkbtp5pLKeQTA2TyvZN9ZWlheSSpaFo1KhkhJAiSyQJqYwiW4qU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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8le8bx09pkaaUJCNCNqUpHxUNohAhWSnzK0WRZEVJGZWEJGRlRCjZ
e+95rMQ5zzlHSBp28Xt+f53X83qe+z7XfV339bneHyGL6zpXl1MoFJNlFMr/
f8PPbT8oktyAhZUaEsdaCAx8q07Rf92BK9aSWsKLQ0hcF95+QLQTTYNaxx7k
jiA83yFYOLkUWeHrmqdDCVgvfV2ihPXCkCPGbnCgB1FhPO6/aJ1wStf7/lZm
CCpsArpdErex6bL1uTljAjse2bpncvRi0ZZ5dJybQOu+mj2e5gWIzVIrE0oh
EG7G3jS+UAdfjWe9w9douPfL/JLkkXYw/hVFmTnQ4M5mf9vuQCWqc/Rjtt4f
hrUVr9N37joonMm2+51Gh+DBercHFysxZOEpDBs6Tu/rkSusrkb0vqpfTBcC
jRcVe0WSWtH0Xv8qNX8YKRbfn2g4UhFu+LYqJ7cPaxzOhKk7dkHp2C5xgQkW
ROIOTFf3FeGvb+SJdkNyfXDah23bK2EgXdUS8I6BnNkJm4z3bbDl5vcW9mPg
/OEnzJkD7dCZmvrmosdAclqzs6lQKmqVRa5Z3CCwisd0vuhQH2pPbYx1EhuG
WWt0wBfb+5g9QPMqNyOQM+acu42jEfGWDBexcBqs79UbO7ZQwTE0/X6fxFcY
eJaGBN0pgkG863KjFXR8KHlj27aTCk2d5mW650cx1NzpPf5fNhbTM+u7cglE
H1s9/opRAZ3JuKHnxxgwSFfhPGXaAjnpqR0/aodBsRCw9aztRuEnrkfsNkOI
tuwSDrNpg2OyjOKCOQHHvOZEp49ZeKTING0g70cmRU3Fd7oEcYsh3Gbk/vax
xvs9hUsxvyHzfpQwAwLS9UT8tnr0qB06aeNKB0XOflNw8RvsusWrfMeJAKEm
8jBbuAuj95W23V4zgiGBN1aDEYnYXH/7oOsVAmlzXFfk2KgIWZdo3JsxBAPb
KxVsw30oHPw1bGzyDbcKYwT39HZAIeRIjNkxJsZb4eHNU43GVXNr+WQILD78
niDh34bT5yeVqLl0WK8QXzR3+YTqj2ZnmcEEpn6MP7Ppa0ffoqvQ2TN0rEj4
slc8ohq+y/95K+8j60XTavqn04Ys46rZxCUmJh17qzmn8tFouimpjU6gic2Y
v2auHpsLAs30KhiopaSIc8jHIkte5V+gBQGKwSscTQ1H3NoQ8R2XCfRU9Cct
RbdD3y5FegMPHQr7tG84ixZA545Zr/8aAqVbrI4GG0eg77NY6fNbBMx2aRRI
Z8ZAcmPCgBLZL+Fp1pv74vJwUrLszEwSef8S3/84Wd6J8JmRVKEXBMbyxee9
vFtxIseQd8VpGs57byqen/iMy1KXNMbSCQiWr8xMzK1An9KdtWaKBHbx39lz
dH8jjpedC9TMIhBaOsTyGGzAg85PIvaHGVBZI8azT7MFGwbTs6ivhmGi4DN1
c7oDzIH7mt9YDKh/nObwe9wKH/7HpfsjhmFc66X/lKseW8Ie1Yuw00CnqN6m
Xm2F7j6lo1/J+nfStFR1B2ow9IQi3txDR7vdqr8dlgOQu2PPdbfmG1k8zTDP
Y82IaWZPu0r2r5y6j9Eu60akL9jl2C7QseX5ar249F6csOrqPUTWa3m0qMHw
vm7IbWnNiz3BAKVN6dTTzd3403LJrtpqDOMIoUV19CMk4I1s7DYWXK1tBh3N
SnFT9aUk05RAfZbhs1/bmpDiHXx5im8Y0dZXV1MyO5DGxz2yKMbC/tCeK4nm
/fCcpfgJuNFQJJZvKiTQBLaC65jsIWCwadH4DHsx/BVvcXDM0RF6dlHY+1AV
AgSO75E6yUCj1YXJ/sheLO8ocjeVYyEm6OytM+4duGj0pCPhLg1Zp6JlQ3f1
w8D+nk2JzTdcXpcuHxzaCYXVIa8sXzIwmL0n6vW7LlCkrD3kWQRqNWuU6mI6
UTf778DRN73gj/tUeOpGHTjuiEf80aRjPL7mzTetVuR8DaSzaRBYsbL1msL+
NhxRfe7rx0VHdnZy6v2/b2FPecGu4kyg0Nhgm8VIPgafDrtevkDGf+zGSaPj
dXA/nZpxL4CJzvvDZd+4G3FWxOOZWwUdPipD4n1/itCQbRe6N4Fcfz+v4t/6
TsiEViqlNDDRbSzHUXy7CqIyjXl7qxkopzhNGV5sQ/Htvq22J2jwfZmrGx7b
haghdf1xsl/WmDl9LxGrwIX9y4K2/iDrLVvw5GrRO8wvnI0JP0Igxr03QWI0
F6snhCTiyecwoWn2T6FkPdtqrxBVw9Cvuu7XyKQiYDDAfAMnHZl2Lu5atgPI
bJI5nR5DwKRROp67pRWb2KYy58j7VrqYovW53QOny4827yT7Sf+C70Ovl4Og
nhxfe0iNidbFdeEzZWmgp54XlgggYCW9ih5W0I2Jmw50q3QWfO/OTFjx9qAn
zmCv1t5+ROu7utx1a8Px1uynMgs0dFa9KKuR74GOtnNi7SEWLqyv+TlS0IXQ
XElj84ekvirc2KCp9wg5v89djCf/fzpN43XKpmbUn6514G1iwoDqeyvVvxD2
60RvEJdIPW2TGrB4UY71L8Wmlq4xsbFV0lDEOgmqJ3vYiZMEVNQfrXF9GwQO
l8uJZ0h9ljr+t6X2dxfeD8td8fw1jMJF/zEZwV6c85/bXprAgrjgGrW8xmzs
qq0MGNAjECRn5F1XU45rNmFviRs0RH+VK1nt14aeqfSIo3cJeImxWZesfQBO
3TSTfHJ/A4UBOR7ndkiZ8oXF/iZwPqiQJZxchv0WbnHCuxj4IOUqvjO7CyOd
lMuT5HsF8+pNBR1UKAcvuN7bzYTg1MPJgWVR+I8/07HhDoHl9k/KmGP1CLW1
az9nTYezbs1dalMDjhesk/19iQ5FR8F1m7hz4cbv1PuonsAF9Y9CYnN1iDBf
GZPeRcfZxjX/Tr5qx9bBxZYiIRoS46Nvyol1IbJI4N7q2iEMxNg4l29pxEf5
512yTXQ0Xtkd9DQhAf9p7y5me0rqJ8+Qzre5alQvwWA1Ge/VoIOblibjYHvG
/bE5ef75KkpAdlIfTo8rlqerkfwja7txtXc5ip/pz8jlMeBmnauXNduJAZZ6
JIc5Ha2jia8rZtswtvBvldJOFr5nxQQH9FKxd+8xyZG1DLz/Q7HNNG3FjeNz
y1YrE5DLvEHEi1Lh//5RhYISC5yhUd8EnFpx2uRCp3gtHT2fLiteUugFb4CG
WvwXBg562tk9XJUIWSN91TByvsiZrVH0ptbgnnBxbWEOWZ+/g1/Yx2ohHmyz
etqfrM/jSd6V2h3I4aJPDZC8w6fPH/mBtwn2t/Lfn8hjwrbbNNxorgmcyh+O
WO5mQPDB9/9aJJrBnj0RNEvGV5ik5+BzvAahbFNSu8h+53zxTrjdtxoKtYqf
135iYMSLx5DnSjaeHLDx0LlPwNy036xFrxuWieuk372m4WxmAH9geTvMvJNv
v5xjwHeH1/ZxMl83p87u5uH+gkmLqSRd30QMp624qSFJwLczovBTWAe4jvm9
iSXzFX71waX87bkw8nqVmPKB1DPHV0685/qwTOSp4AkFJm7qEIIUtWZMOFYM
vLcbxMEI9feNRA2OJ7bZtj4l57e2/Qenbd3QSdyt8NlvGF5vemuy9z9AxI2o
DarkPE6mXJgWFCiEkktPyNxqBoh7sRo7g3pQ7Zg4NO/NgnCc8UwlqxvLpISS
5ksYKGY96IyvLcO0e8fnC0M0yA/67awa68eRMFF1hwsjkGZIeV1NKodYxfMV
CWZk/BpHnB3/K0Rs4D9tJTKfvPZflxZW9yP7MxezU5cGxxVvudxe1iCz57EW
excNoYbXD53h70TzFnmzJy4sjOo6nDuoXYdr/ae51GXpkIpSfH2eQs7HH86G
/6LpcIz8Jzh5KR4vjGzcDQwI+H/pEXCN/ALVVdlb6uroiBFJu3w1pB75en8s
l0cwwGcgK5M/kgIHtb9OnLIE9v3RDIrnz0R0je8v5Sckz1lmSbPpxmFibMbT
gMzP+7IVSeudKjH1eldLaxfJM9YPb9nviUDQd41n3nYkr0Qa8hm1lcInV2CU
c5qAiLmw6u6oWlTXfrmTKkXy91vBd7fbitB3xlJXpZKOZ4Ue0ukp9VB21lO5
5EHqywuhn+yKZVh3PFZDvZkBj/iHkgMK7RgPeq3esoeJ9U7Doo0xrYjX8X7x
4RkL48cc8Gp7AwImDYsKt5Pz4ZCf2rW2GjzZefPAPlEG/OlT818qOqHqLJrj
tEDet1zDkpQN9chYGc2eTZ7XJPmDZVJPG/6kXt8SkTsMi8MZQSe+dYCXyh0S
uY9A5O9m2sHGTvh/dDb/ZE/y91FltfHXg6hZzHwRpf0Nlctu11iEdYJ345JV
XzYDpc3TRY3u3RD/d0GkqbsPgqGv1j279h70fH6N37Ykv1p9+UI9V4tPtpf8
5gfJfO24InH7/Ec0tGRYfyL5c02HM9e5gkZIbzhz/+N+FmovisiuTy7EhMHS
NSsfkm9yYuRn7rbhDKf0ikZncn5c8Bw/dO0Zbnse8vS8SOCdTwj3TF03vK6J
+Xw/TkOUSGYNu103LuxUlL83z8KAvOL3wxNtUG/W+7nHnIGL9xraV6R3QzX0
z5XtzGGcnDU+attVj7CMkW1FJM+1VodyZD+vRD3NMeEF+b38SEmNgBAV6bI3
4baB1EFhienvK0sRrxGewUnm52//V9ltW1sxrkttW9w5BJHgI3584aQ/zJ/h
0l75DWkGbQ/YXtYjaYhPmceVBoN/1tl++Z/w15lHOlmM1H8b7kOUV504Ti8Y
m0oaxtJ2q/4Mt36Mvks0W72bhaOGhzNa/nYjZ6e5R+HWMQyOpJToHSnFybPj
l/LmSB4OCM2YWmhDOsM3994nUm+ESkZd7lDRrPH1p00ygZHa3RkHZkvxJNAu
kGgjEMLkn/p2pR3thO7F1PVkfSYqz76ZzwIhxt6/zIbAcY7vTtcvkPM9P3/a
npsFLzfuf0FNVFDV42RmlVn4mbj7JN29FUu8ut+KfjEwMZe1ILSrF4xRbROO
biZ8z5jmcW2oQ1Z5brF9MANfougfgoRKUdO+a1PeIB0Zv+iL2R86EDmRFfKD
5EeemFG1ea8C/Czu+bBbgIA73zmt7uEemM3cfOAsTvrBZVVMrvFyTDtFxyy+
JPnPL6nJdXM+5nitCydJPb/rqacf+LEGuuUnIu+NDWPj0kxkuVUvTBycUZJH
h7ilZbF8eh6M+JuohzcyMCSy6VTw+lhEp+45akD6CxWZtNOLe8vwb5c5a8tj
kp9+BVx1WupGuPVUwaG8YUxmc1J5E9JxfWvKMZfzpH+hdb6SzO7GLnqz4bLg
YfgkPG3vcKFCZ3ovf9iuYaw5Y8nVWP6ZnAt11mr9BJ6mfzTku96OwxPpR1lM
kl+iZrYsd0uDl3RIzmFy/pd69P3HGVgA1+rcjesCyXji3qkatd2Hgv9+nb8k
H/k8dr+4sqURUlCOECT9JB/DznVxvg7qCW3uBStJ/5LtrOnm0YvxlX9aHv0Z
gcqW0Wc/HR9gp9MLuVxy/d6/6dw5pD+5FMnKsltB6rEnl6+LUxbOStzRNpIg
9cqqSZpJ7UGc170DPVrkfergYve+XAG1isqetUMEAlatcCvRrYJGhu1CiScd
m/QdKA4+rVASZTtgbMDEGn3Jws3ncrFh1EzJu4GAceL7dTLtvVCjjvgqyZC8
+Hxce8OJZBxaekt9Sfa7vyvlqGxDPvjOIaqG1NsHl2hpLm+7UKhlYXLiziDO
v6B80d5RAcfZ1MJjPkxs0SzitjatQ8xofUu/LR1D6wc3z259DYpyVvMWsh6l
l7+IaZj44uZgoPQoyWeSJdmmmu19cFH8VdbjPo6ED8OrdI+R/VNv+vJFFYP0
g88vx0R0wzE3R9/VoB+lcs6Hu/fkQlTbsTrWmtRj3cvFe//kYjR652IZuV/k
zEH54369+CSW83FPP+nPtcSX1lnEwGJeTek2yUePb3QOZZ8cwFup0jMe+QS6
59hM2LY1YMUjKfuMjQREr/twFHZ3olblUMFBCqlfym0Xnxi9RbG89aw6Gb/Z
4opfqWMdcAiNG50po4PzuV1fd3UX2E9Oa9lwj+C0LuuWcXMVYgKlTfQYNEwy
dEIy75YiTkJ0IvQMef7ezGcO3KmoPvYubeA66W+v7NjW9ycRxbojbqfJ97Ot
ae4JHlngHPBvPUjmW3VRhF+7JB9F3/h/CheT80PAbrnkQBPGNkmt7/1MQ2TI
gnjX9h4scEl3b+Vl4bOKmFd+Zx6e8HFRjUn//ED4rd+72DIo6f+gPJmlg0bR
5uZpaIOK4bRAi9MQzF6Ubvxx+BlUJJdvOKhPILEoleNZ+QBcrwiun+ccB5G/
T6DRvR3KrhFO5uT8iZc5ZXVLqRveCXUvk38yYL+1zlvjRyVOz8ja6I6T5+me
vkw//BqbPf067a+RPBaiFBLo1gOXriiN13I0ZGq+laL/fQeajM89Owfy+/ry
Bs2MYmxW5TlgnUxH1KFLtnu9s5C4U8F+IJ68fy8Ds6XjUzEqk+zNTvqLjp8/
PVvkP0PmISzVXxOo4peQvZRCRR/Xzblrb0eQ98w98L1IPnpXqWprV5G8LFpk
a6PbDoNq9lKfAyycH2dutrB9jqeN4Q5JRmQ9si33/zlcg/WDb6YDPZmkDrVx
8nH1Y97FdXtsE9l/JjE8L8Pq4TqoV2v8kAZ1E+aV0LWNkHAZLpvlYyBFqyKj
cudXfN9BVTaPJv0jM6TwKrUYozFn97WT/RiuJbZz390PCA/++cJDnuTddRe2
RlRm441r0sHfo3R8ph8tCj2ZiycF2QGrKAxsabx6xPZcM9x6HnH2+TJBD3u0
WXKyA1k8EfEhYEBbtpidK68XD+7ojl6tZEHTqUtCVLYCo1zn+e/O0OA/72vR
pZuNuM2c2j/JfqA4VZyuayqG9bS2btwWBqKc93MnP2pCDNd3XW9NJricJt+b
dJN+5KEuPz+DgfaXNmsctUkukPR6lWM4CB0Be0Vb0o9Wt2qu3ET2T2FwMr94
NBWBoY9w1oMFE+ngX3NjrbAw9Frp9ZWG/dZZTjwBHWhaZcGx8gETQ6luVeb2
Pdj8MST+8CE6jE41rJKR6oH/CbnN0sdJf1D+i23EshlvVbnqPykQcKBustaJ
bcMA5cMabR4C/wM3oBHu
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41dkbt9XkJiRky1LGEvnNSKU0PtJQYycMCr+0TIttJJMREUmUPUlI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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk4lVsbxgl9xVHJcMhMg3AaTAl1C5kjQxSiooxp0El1QlHIkRNCJMc5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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 139->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4VWsbxpHpRIM0ExWlVDgqc+7iEEVJSmWe6csYJdJR30nlkDgZOmkQ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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VH0bxj2UyhZCJKUoiiQqQl1aCEkIIYRUkqXV0yIJyRbSQkSixRIx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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41WkbFg2iJFu2hCZLskQ0tm7fULJkClOibNmZSCtfTKJSUjRCQiUj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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lfkexylRFCoZW2TKklHTpqYJH0kMpWRLcm0t3NFim8mWRENMdkkk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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 140->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lVkDNsO0cLNl7CZJZW2yJIM8pZRJjMrUYEiKIRHDSMrSF0KyZU2k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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2kgVG8fFRXtCCFJ4h+lLG0qHGSrLFmSLYlERIlkL5FSiuxaJKIsIVsl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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41lkfxiXRmLxTRL3qbWxJtkalVHIbS2GkCKk3EoVmLGXJ1mDsxBCy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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns01Okfx6dcklzayD1JHZeSaKVIvYktW6pZKnJXspS0LllFTLbaFW0u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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 141->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns4Vdkfxo1UTCV+jAqpZIxMF6mmQvOqMDGEiEiR+7iEEn4ohxq5k+qk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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4lQ0bpyiklJAXZSSVbNUr66clIatCGSEhRVaKtCShEpKIhKx6JSF7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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk41XkbxknEJDUSCjEibdSrQjHuOtkqSkgpkYycIZMcIcboSJS9srXw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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk41dkfxy1lSWnaMFRSsiVNVIPwblCJFNk1GXNJhlESJtRYRlGWskey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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 142->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk81VkfllBTaYw1E2FqEBqSJgmPxpooIxOVLL12QumNQlnKTiYikWTJ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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8Ve/bxU1JlJQhSRISZSqSipakDCGRJkL9VP4pIkRUoqKSqWRIJQkV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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81tkbNVoohNSQSUgZSxmjkinjJEIqRMSQ5Q3ZskyTSlFRkhiVkl32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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns8lOkfHXbb2qVyjy6oFKHcitalk1RWbBfRijCuu2UrRLSR3FatxKKY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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 143->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lVkYxxFpZaKalAmjUhG3VKPIL1OKUhNuUcoo2ZeyRZZCsmeukm2y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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4lf0bp9TbHshIpERC8hbR0AcpI2VlJSsjKbJSQkmRRGVUFCLrVETI
zl7ZjnXMHOc5x0HolYoov+f313M91/WM733fn3XvuHDVwH4ZBweHJScHx/+v
ovr/PDdrise97szQfDcCufpjx33bK/EuUGHjRBcDsw9U7Y9x1yP3yfjdwxpM
LDOuddpb1QOtAo3ymi80JPzdWPfcqBYunfL2lR8ZEHCRiE68Xgnr0F0Zly0Y
ULKanGxL7IZScYd8zLcx5L0I+2XFHMDt0qiezfYEKpM6G57zNYEi8dZIK4EB
ThvfA88zabCOtd3q83MUQ0LyGoV3u3D0hWL8nTQWdsjMVGbJNIHbOiw74haB
co8xm3J6Atr8TTcLOxBIlxAPcrjZDk7jxFmxRCY0gipuWdQ0YWVBimi/KgMc
KyJzLb7mIVr6irfcbgISQl1C2Z/KwH4jY9j0gYDecnOnB3ubYHRY2q3Vmo65
02M1jgFlyFOd/6pdTWA2ozWlpKUTwQ7bD1wUYSO4uSK54nwLIm4U+9gJMJDK
q7h0d1UvpPfmP7Q/NYxN+zxKTi1RkOVy9Z4EWW+Tc4qv5akO5GylTP5zdgwf
71zViSzvxg0uxqC2yQAcykXY6ql1uHDp8e6BNAZUz2xZ10WlwX36aWtI7BiG
Z29vjRCqgGhalbJdGYG3RwwMQl8Xgnqw27bkGwMr/RU27aFU4hei9qROETBs
087wvV6ORaP8dPPjTHRs7Vm3dXgQknOcuqubGVA38VGpMn6D1v9CQw/IE0gI
85EwKM7BJmwz+XcLgU3f1cudQz6gIK2xy0+LwH563bblhvVwrPUNO3KQwNET
32KtagphoL/KeUsJAwNuj9kdqxKx/7RDTasFATeFVQYxZr0Qm/tmbmo6DH85
o+uHcl+he/vooesXyX67XSotu90Krl1Lxy37GNA7ofNml+5bjG8T9Qo7T2Co
+b6SOKsPBe2Nu36eG8O/Goh8kF6KJnfbn8YkXji4AnIqG6gY+8xp8dx/BLqX
KyR9KtKwZrfVBP0mgeRxMZqXYiWkst8ev5rPQMJa56Ie5zComeUE3CS/r7Tu
fOyphgr89D6YUyXIxA0lY49pnxrI1ASe0hAn628qmZ2z+4jQpfHPL5cT4IgQ
uR+ll4S51XyUKSsC0a70NQPcmXAZGWqItSNwwz7j0PqBYtSa5CXJyhHQPLKk
S3nfAy76hwzeSAJPPKVvz734CNrVx/N/XxDYsGlpuMidhv9YNvZHDUcQzNko
8uBIM1INH4ml3CXP+6fRfJQ/AqkLbBXeKwQKXodlduwuAY8aJfzdKiYq5XPP
yffX47VNsdLr+wSsE1J8tkolI/orV+Ep8t53ZcWh218+Yy6EnZJWxEClogmX
3PggQu2zhykS4wh9cNzpxL4KuFwPuZQnTKC6abe3lV8nzh2ZM8jbyUJu/fPU
COFexIQ2Xl/MJbDl8ku31bntECl2Pnqbj0D9zKoDqgMdkPQLqjX8wsSWhJP8
6ZuboMKQ3tdzjIFdzdn7q60/IUfYQHN9NwGrzcLnFkWo2JmqMTCkyYarTHrU
8rRyPOIJ/Mm6xoTv3vxC3jd9OJJ50WxhBx1yJ70vcHnXQPvCFeHuWQaG9UWK
OONq8NfLRjzvGRPXox7vfinUjo1fFIQVfOiQT+CR2bO8EeMsVS1ikUC8eZzW
O756TJYEOPDlEJCZ/5AZ+ZwG+QwbUd8ZFjQbOvfE2g3C2oq3dmEvHfUPV7fu
jC3Ax8pRQSlusp+VKq82aVPApfWwyMSFQPiNWouCzi7wC85RvDYz4T/1n77s
HX8M9a5U57UmwOrSVlf5QEW6ivnA2y10hMnrSK5U6kTkxIyzFokXl7hyncnf
bfB6MMJhmM5CqvmxZ0ne3eBn+fVHR4/Cjn9lmJ9KBd5wh3SuSiXxrdTk1pqt
hiDh7ZeVyPclD1eNcZ/sRqv7nWR5gyEQd/OHL7/7DI1dv8NHjQgovxiqrbag
ISTQSCi4mYm1+5dc/y4NYqJwu4hC4TDOUqw4WbPdUA2XDvtuN4A/96gx1GUk
/0I5XlKPDkPO++yAhWEpntx29h4TZyD5x/aP2k403NVck73Lio2bFz6fFxVo
w76a2pRAFRY5583KwS7hcKlqPmdF1m/XY6NX3ZyHPdK5BoLjDMQWKAiWrKjE
/tVJg9NUAnEYc0/aSUWMvuAFjRt0sMWZtGs32lDqebr+V/MI/BsvUfOF7kPe
vUKWTfJTz6zHVoc3A1ydPxb100n+lRo0c5vmw/R4rINOPYGSAWrWPZDz3rV2
+yqlEZjOZPysti3AN7k/482XCZyN5BA2jGrBxMoNuaaDI5AZGXgcot2Ds3yX
5djWDJS7fN2dWugMxoXDgWFkf331C7bf66vGvYOIsH/MgOYZXtXiF/UwaGB3
+a9iIVb3R6TTik7kvl6u3aPOQHWGYs7a1lrwnXlgv6GaAeum8LRIhUKcfDrS
yFvBgFfr/VLZwm4k623K7b4/Bnf7kfAJtR58auq/L2JFh4dordHy1d1YM/wu
q2l8BAc1Asr37GlC+vuKhYPZBGTnXRQG8upIfQ2f7z1J4jGm6Jb5VAwWvS8q
rTMjsG2l9qlLMVXYWXi3bPwrWc8L/lO+1yOxSu+viQU5D0+cDt+kVoEDKz84
byT94dL65f+tN+8HhdN71IHUk4QZ0W6tk31oZBZyVusMgcNLKDEh7CO+umXr
5pgS+BZ6qe38dDM0X2aE3vlKhw7tXXjQrW6YTuyImZdmgSN3UZwjwB1lvc6J
upZk/xidi3udW7BB8IfS3ygGNs147Tze3YbxWp0zyv1MqJyQqwzeGAmX3YIp
Ou4EFsqM6I9H+9HiX5p/RpSO6FLeyKCf1Ui5Jq/0379MqEdeDnPaVY84xX/3
2GuSejLx6uXZ9C4EXBnxvPqGDq6Zf2xndtfjJveNmHXHmLgV6miWmNQBvqiF
hTiCBZfxIyvuJLRgOiSW2U3q8dHkHs/6hRZoNi9uHvQfRckWHzeJuS7cr1r/
t7OahfITMo7jIoHoywrp1LAh8Scbt3BatADr+s6WL89mwP95mOP7DCo+vuVj
Hl0iwPew5vW3hDqwDkoaKAgyILn150J4dC+UzILm/LrHEXLCXkvUowcmJ0s/
MUVooEQ+LAnZWYeov8aqqVNMWD55fs05ugMLBkXTdyij4NuVgFtbeuEboGbO
chzDzaadlBg2Fabv9dpWf2fB7uAnlxGXPuzIDrVf4U9AymLDchenLpTvjAs4
rUzgXMBh1nm1fhK3j7P+OI8h5s+VzaPCfdj5ZudYh8oo8m0ry+7JU7His6h6
ZMYI5qhemlVyjdD7pCRTIjkKumeJ3sLVfvw76Os9+W4ED1nqfE9MW9FGfyu3
W5/k58Hk+fDdgZCzdDMuOUfggILibwEuKoj+tgH3UjbmxMeC+5fl4KjncfnV
ngSmNt9XrB7pgEhLwsnoeBYspfVT1kt/QPJZk73CegQoPuaX/rEsQ1Tje28/
Piba8jznxJ/m4OHZ78/idUl//DW/K3eRhkO0So7mMSa4W3Mbq+2K4U7hNAuh
EYh4K0x4Z3ZiJoRndKp6HEr7nN1MrzfjZ/zsd1USf54+cYHHBNoRG9NhdSaW
QNtUqs6L+5kwYN22z/Ih84HDC1mabgOiM5R3PY5mYVuUMK9CdgtqOZ9OnOhl
4daky95Nd4ZAV7GWf3dpDM/XZIp5ZJXBU2uw7cYhAqeM0TfJPQiJ7Prk9eF0
WDoH1Dl4dCK1fjpRDiQeit3Wp/ZUIahvSuVvLQMF5+yqPVybEejO46f0aARK
HrzS/iwKwom3zfaapL7xv4w4sdMeBfQgw1BSjwTULVwEGeW4mHuoV6KSABFj
UWRF6nnXVq+tSYFM1Ku//xOZ3APZrK74j9HdqJeuSp0NaMW33u+XTUZHoEeN
EbV/mArv6GkjfjJvma9hbz+f24kV+ed3S9XS0ak+s3aW0g5toQWno3QCjhab
96648BZFElt7psl853AxI0BHtQ2tlj0fmK5MXHG6eHi5UTeZe88VhEjT4Zp7
c85ZIBEtlSUf95B6Yqe3LEJ+pAimm/Z96vYi9afuqPzsrT5IjFi277AaAIdQ
kUMRqlCbcrn4Ganf38oGAza4PoUFd223GOlfvCukXnserkK3loVT9+IIrNvU
8o5JV4LvcYFa0XpSr9jVgi2eZ8EpEfzFjOyPhFSa1B+HNlxp8ZFNnCP130wn
U2ypEK7GgSG/rxE4tKZo0//5mkVUdmltpEP0Tu3qfYxmPDrcZ9RdyUChlhXt
ilgP5p9JLP9WykLBqsYTO9S7ICu117qicRiSPfWvxcKKcUCxgfAn9YAiX1Z2
8V0bFpsU+LdsY6ExcYfAYfdatAkIK68boaM8RkOIKzAPxBDvCDcIsGkxK6ny
vRj7GMa3YdcYOLLcFaPtzCByc4uREXl+WdpOgU63Xiycz+Mp0qTj9vO5MiWR
etRIn3DpD6ZjZrAmvsJ1AGfVR897cTJR8PBVxMMjOVDy0nVuaSDxJ3BTTIU2
iJPJt/r6UxiQEwyLclsfiGXvoyVPk+elaepQGt+Vkbzj+vG0mAFHAxOhh2Wd
ENQJiXvkP4Agh6RcbnoPDL8IK7ST+G1KbhZPVqlEnK7z6G0zBmyzBf67d6wd
E+Z5mb9WjSBh6oVOsh+FdBWNwGpyXwxNzC6I92mHn/CXdK5gch/r52eo3ilH
kR+R0mdI5qH60jCJB30IK56Ttc4Yhad9RIrhxnao2/z8vY9Kx9eqgTvXTVqh
UOfI3ihI6m+SRf3BvizUxr+2d5Ei4P/BlYelQkOY3cK2KDUyb6hs5kx4mIeh
qybKnxMI3Dyfy/PkdznO8d77KXaDABfX8wuTpP88HWSdtfhKYIZqkr6erxUc
6+ee9Nwm+eW0ILtGrx8K3JLHON+MwUnfVfSkRgfeIqtY0ecLWihnGiNs+6Fe
sMYryYEFSfEg/o+1HXgtR/8U6M9GUO2sfP7ZNmRpnvnHuYyJUO5DFkk3umDK
jpM1dybzufmVVfrvqyCj7GPIViD3wTdja1IeUaHRID/tyE/i3dpjj+eKOmgm
dV7SsmFCdC2VCI5/ir9f3Q0cjcl6b3kdiPJtwuWyydxDL0n+91uwyjUTkG4d
kLLxOImnNukjStYvUa66hlpjQCArMWSqToL0jGC6lbsTgaVhLheBX12YaT7Z
GHlxAOdPq2vv3khFqToxyL9iBPVmeWrV0r14smN/NqupF1ky733TOCjwpU3L
zuqQ/IpTiOvkSISA7bqmdBK/cqcfREuWtuGqMb/KLJsF0Xs9+kn51fhV+MGI
h8wnEp5OW4/kt6H+SXjXoB8Tx2XljT4tpyHh4KVfXUJjYH/c181jkI+qTPFb
WWQ9QU2vVOb90nHxYSbN0I8A1XSmJjaX9H95ujrTahwtxiJsrvoSNERyf3/W
TOqHxIqVXZU0hB6ZX6fNM4ryIvFDg1HxKDCljfOT+HqSflfTML0eDbbKvzMy
mDgQuDXtfGUH5lr3CBTWMKGm/aXu3EYadltoZAUzGWj5zWt6cG0n5tsGtCkq
TAhlVVim9ZVD22PTxFI0A6e+JuVwHO5HdmSY5DTpx3PKybelMjoglvKsUmmR
jeY0H7Okdb3of5ymfcWBwMtPqR6CS804pKxjs9d2BBvE1h4+MtyM78tkFnJ8
R2GqU23Xt68X8TkaWaJFQ/B8JmNZrliFgOSSwV2jTMS8V5i8WtuJ+J4G5Zgd
bFgHty+9zPmE1Ilv2X75BERLjttUyxWg6Br9cEwEOW8z91tFKkWYslLf61rF
AK1DKnuKRoPurutuCesHUfTohEqFajeo7HU25iUsXJEbdO2trIKOWFVAch+B
d5rV6XIzXQg0eRBygcS3+nxVbaxqO3xXuWpsvj2C0KODSl7relDl2Bz2JHUC
oisZ1rEFFIS2FgdSVUm+54sJToW0QU1po3CVJQPfmnrqPfg/IO2BrfRNUm/G
5TLaSmhd6I6T91j7dRh82UJ6vz63QZsSET8zyMC9zaY1l8X6wNmksv0m6Rfy
F6KO7ncfwKa20NTjUSzM8Dnp8ln3od74m8idJ8OgJEqoS+xLhODdCeMtJP45
ivX7vFKTkTv0n0ChPoHUA4/IVb0D8UGtHnuYo0if13qnZJgA01eGbQ/UyOdX
PF+r3u+Alqmuyuek3g6cM/Cxc2+FRIf4eYNpFt4rCBZ1udDQt/VFc8WGfhgL
xvNoKDWDL/rnwZk4AjbF2g4VCq3YeT3k1afFYcS/DYzYM1mLtROC6tNrWODq
k+HqGerAo9/tC6Ok/qy61xofPNIIgfWu28bEGBBtuhdyeqEHy2vaLUIeMZD9
LHXrzVc0fDtOZWx+OQxNytIWteBqOP6wmcv8NgJJdckY96BedHpZ/1D3pSM0
PNjuS2MD7t9I8Om9TvLzwRfX1D9+CJ3s8DtnQc6DfjqLr76HzIdCkx3Zwyh+
8j1XKmYIMkWc/k+dmCicrl5HU+5AUb3lpz+tw3gknJ92sbsD453vHI/fYkPu
70SMLk8JRGKf8kTpMCCzR0Bnqq8KVz5zufiR/rlWdzCrqaMLZjWqOosXSX+N
CGSHTCYiKPKA49xpAkPK3lJpibXomHr5oECa7HekUGvUxmtQtFWUqyD3j1xf
4+YGi0Tw7B2Nmj1FoFqsVa9wWxfiRk3F61rJ/9296lc914KgQ71di4oMzH2J
+yNV3gGDugWuaAXye/Hy5cMPIhEqLMFWsCWw7FVhlM32QfTV5VhySrPxyjNS
frtnJzSvXNduO8tAwvxq+H0dhIm3Qw9H3jgO3eOiXN7QCcfncUP7ZQjsHGd2
TS2rxb3lTu6570j/CB9c+/hoF9797hOOURtF8ulX1Hn7UmyV7P2lHE7mLQuT
1S3NXci0yjU/v+ELTJdpJip79aO+Wn11zzM6NMXnb3cZlsP6r+eSoi0TyWUz
6/+c6ybnRPvotHoQvu2LBzeJ1+Is72QZzxtyf5B/cpKtcx9Hcx2/65L71Rh1
9IxUYSfyttjrB80RWPeGq9Qtpw5rbpeWplNYkFurpNwQ2IC/wR7cGlpMON53
uHratA+vzRS9no4OI9tbr4n7yEsUZfBHTl8lMKtQZ+Zf04MfL39K1WaO4n+g
nBHw
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs41VkbNRW5hZRy6QujiVLGyEHCikEm11SjDFK5flQ0I5ehGJcQpSgS
MsigKFK5nNzlmkuOcIic3z40UnJPzmR+88d+9rOfvZ/9vO9a611L8dQ5W9dV
fHx8t+j13y7qVDcwpt4DDRNjh41MLpJ8x0Myf+jF9BuH8Y1pHCjkc0Ulv+Sj
wb7YeuIEgeC7yN0hTBYqptb281Yo7OabVt+gN4j6jeJvnjmNQsElSn7VbDby
ekld+kkCvuB1douTd7H23WDsekeCfkR8+/xeFQ7t//GxYweB1qfa8owdTbDK
15kVSiBoZm7PtQmuhmnfySaGJQFLbOBbkVo2lP3mDSIXCSSadxjH3e2DqX2m
lt0JCtDiuD9gNMOk0ehkfApd3/b7J/WbyvG07dVHFoNgzk+pcji1C9n1naEy
ulyU+rkH50y3w/j3MMb8XxTMznG97auqwWnk1JgeIxgPMjpdcLcT6gFi1UEh
HPC8isUDp7vQ2Rji5vwn3U/8AI86X4CEiZwlUVcChYvg8UmmQNDE3OlHD4J8
hyx7C4VKJO+Z/LxBlWCIvf0Nl9WFrUFTK4rWBM6Wl3eObc5B0O7Ob+VpPAvk
Dq5sOcwGxWrU1pYahe5721dBjW3IPGAtwFEm0Phop/J9ZSsM4m60ZMVRqJFU
LivZUYZXpWXvF7wIdu0e6p9PKYdBkt9CfjTBwYyX+YulPWBLF3ieTSOYPHr1
aczvXfj/0/h080sUpGWSty7fq4PGfOGQYjWFt15jV97NdqBFRq20W5aLUJUy
RibugPfewkvZnaBuMWjZIG4AFqo+Gkq1HJTaJYqZrXuCUwsXl29kEuhIjMuK
rm/EICdZKmqMgKcduKbkThuitnWMVPE4SEi+ZLD+fDq0dFcTDTsCyUR1Ksy4
FhEnG5hnbWh+fCrXpDnU4s++xR+Khilk/jTuryyWipfGXbXLLgTHXhee8RF5
irxZE2WxZIIv69ybYpdrYcrzZivNEBwxMYs/PNeNaDWRvY/fEiQtTWsfeNEI
C18hz3g/gojN+6RO/pgN2SlO1q80v6J1Cg2b2K8RHBnc4hcyiqTgYgFVk1co
9Fz2vaxLQPI/Kc9V9qLSUEdjiD6XxRmdNpKvQcSzyu9cRygciRgXsI/rw+aJ
43mMeQ4E+D4YPxdqx6DWPPPnRApM57UKpy52IeH+ntDfHtL4D7orPbLug9t6
rw2mHRx8da++cc3iDVTCjofqyxCoW+5e6VnogvxnqR5dUwrr08r8H+Q3QDH7
XtW8AwXjI7xpZUYbGMIhOXO+BPb1CXu7q9nQlNHd/SGJgCFUFH2UvxvpERmT
rY8oEG1L68S4VmhSMqq7PnEQzdgiZ3W8A1XfNUxKeRM8YBpKHxhoh4Rnrsue
HbR+22PeZPdUIuM8v15wOME7dnWO3L5uur8f5J8wCU7oOwlVWDOhr91lM7GJ
4OxUA1P+Qh5MrWQcrx+m8VJacO3pa8Jr80hRJqHQLGrAd9WahRnD0lcNdyns
Wv3ILnChHBKHF2P8bQmm9tepNi51Y2fYl0sGnzkoe6aWruLZg7zf+uW0FQg0
6w210540Qa1BQLgogyBcNKw0d1sPnBZnWFqvRvEHdU/6akMPImSm61kDBD4P
K1gPGAWQ0KlszDxDsMnKRuCDFAuZ0a9D19H+cUa9POspGcDm7nM3Rq6MQiwp
gM1f2gpvoRkjtRYKIWnuHdl2vZC9cjbZdj2FUJPAD27KTcjlPC88Q+vfzfCR
/7U7T7B4gDfmr0iglyprGL7yAlE//c9x0ojW05pr81HVTZg09hWfvULgX+K0
fnqMhdRQv9tdFlzUxBd/ilbNwH7qYK8lrX/p72q2BYjS/mC2pCRCv08ZG04N
jyqBofOm9Cq6/hQLneVQgTZYFQXGh4USfBI/5iWyNIjeh7zpma8UflndI35h
zQBu225om6L9pCxCZadkeSuKVPTOFn3PRUq+btOFv+/Bqe1Q3pw5ra/IwFMe
MTUQDze7ePp3mt/IqJe+OQ0QctXeHCJN+6n12AuhgDbYRX3oWtpMkOV9q7vO
tA2xbnvVEnMIEmxP+at792HVhOnWxCmC7rc2pRZDvcjTEOa/3TCKLbwrhduN
Bmj9Ks5a7KeQ5j718caxl5AuCjXcfoaLzGc1qkfF+mCfF+W46DGKqnCprpyr
bHiHBpiLhHFhLOTTK9bRBNmPcwp+NF8KH6WM7hdm4bWcbP5eOi/0Rq59IzLW
AC0zuTEZHwoVAS7vec190Lv8OctkxyjENQUy9M4P4ebRGJhYj0IiRc1y9UI7
vEzlvGVraXyYy4nDlWXoV7a8eWILgZw2v1t2dBv2VezZsGBHQd3C+KLUsyzk
ZuUJudD4dxubbYn/2gLN4tD378QoBBx+EW5+uQKxAczqZnpeBZPehvsX9OPC
RGHqPxU0n4fqrdiNWajZuVal/wJdf6KvwBl6/tf0H3z6YoECu1HBTr6EhZG/
HzWzkijw5IXPhvL3Y5IjMRR/mIO8MKf9HUeqsaTLc5s6RPv38D5ZwZv0PLBm
1db+lzeeuq6/uXki6YRs3UE6LyS3fm/z90QPpFeO/qNhRd+rJb3TiqlCa2pv
uf4tmu/qglXF5i/B6W6pf7qTi68m59Lvr+pGyyWWvgM/Qc0tz5EFbgxUtsX3
ttD/eRySOjCk045xyxVWdiTtt8m5j3dKDcH2r8e2t+h8t5+bSTvoycYfXS53
BY5zUOQhuzr3YA0C5rY9HD5PwKmq8XRypfmwyuqeo/3qg8jNvIb5foyuHPHx
XDUKmwFnpy8tfRDOrNHs1OFgo6a+1t0dr/Hxtv8EofG+LsiXLNnehaU++SiG
MwWrJcbXWsYwPr9UVXKeIzALdHwscu05fi4emHGh52Xjw113bK83o/Ut/1jt
EoUHncu/Fgj2gWc/7XHrCBdDoeVjvya8gZJc8DP2eQ68Yzcwnikx4RA7YvJF
ieDtnU4Xj8hBPLlWr1HN5kK455vAWMUUlHjqDdSd/s8fT1912FMH5ZpOwX/q
CbwecGxf3G5AULBt/3MJGm+L/TXX+x1RMq/yyx4av8yx7c5FY21ga99UYNJ5
9VzSWFhRrBv6WyOTdLMI/gUgjr9X
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41Wkbx8XblCwhkaXSlKIkhUL0RRmyNZahGTJkiyJKE2oQyZIIJUZJ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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 144->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk81dkbx29lJkl7MTUtaqQQSmpaJh/8pM1wa0gZZCxjSbaICVkqDArV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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lf0fxumREe1SSZRIqWRFZVySItIiFYqGkaysh0hmFDKSlZCMlhFC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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81VkbR6hIKEODUTeyjYzJkpAv2mw1qCZNluxaBlmiSEqytFqSoYwa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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk81Vkfx02W7hRZCq0TpUi25tGG8bFVKpXsyVzakK1LWSpT0qBk7GtG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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 145->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lWkbPl86kmVSEqEo31SjKEujQlfS6JgWS6LFRJYc+mT5+tFIjZQs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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk4VO0fxklFklTqVSmytSmSslW3JC32JbSQfWtBIUWWqLwtlGSJVJIs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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81VkYxsVMpJuYaVFRsiuRUiTTo1IjmghTEipLGQklVKgsg0p9MlEN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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk41dkfx1FRaNMyKiMik9JkptSthreLZJCliSGVvSlzRTU/ZV9qUEzJ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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 146->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVWk8lWkfliJOZWqQJYnSiYoiRU1vVztJXhlRGFuIimSyhEqJscbEUShj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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VO8fxSU7lRAlW6IoW1JK6SAtdkm2VIoiSyW02FNKJW2SIqmkQrZk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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk41GsfxoeT5SBapKKy1cEb5eCUjLpJorQIZWkQGkcopo6otBwOLUp0
lCVCCoVSB2Ob7MY2YxnLhML8fqOylETLm5P39/7xXM8fz3V9r+f53p/7/j6a
3kEOTEkajXaHWv/f97mHuDyfG4T1K059d40YpMte84rYLhSuPz88zCEQnvHk
3Nn4EuQfOf9edJ1EdY5up6vb3zj619r9Eu4kJHc/Dc+W4GGqrLXNRImEfYU3
Ld68FWY8K13tDWKE+ahb2//ZiOduCn5jj0n82JxcTj/agYaI+2m7zUks4oVJ
dLwrhFqyR4DMaRIu7ZoXHj7m4/Qv2j6OMwTcJD2VozMHsEpW8YvA+g2cz20d
dv67ES3Sz6UfZREwu2+WUUJrwZ2E0B3B3iS6C+PG92gIMNEaKlE2RuBK5d7n
gzb1mPZypzt+IvBVTmlLo6oAZjkLfnz0FiPGS/Yfxf0d0Ip8ksnXJpAhEDjJ
P+Ihwl308uptEo9HDxY7vniNKwWSq3WWiVBp8uLaJsWX+O38UsNJZzHWSkdx
6QXNuFOvt0LqOAkyvNekuKkMxzkuKxxvkHDlmwQPvxVirZoly0KKROOs1cDY
iS6Uf0rl8WMI0Gz2J52qboekJmOr6Uoxwgcb8i09WiC7QOZGwDkSyauHr1oO
lUDpxiy70ZCEQkdUSYvPfdi0+4SVeJJY9bbduri/Bs9OlYQEqpBYMpupPD5d
hlrj9e45dBIC5sbNNHMBTPOcPNl+BCauHv9ZL4SNBElLx1QrEtYLNesCXftA
j193ccRUBOW13CjDgC7stP6xJ9yQgEXhGYMV8jGwOB5do3OEBLd+lcGWzHZk
53VLmA4RCCu4G3fSpA6L5BVO5tcR2OXbp/p4ZzNihY2MnXYUD1Jk5/DXZNgr
py0qcyWhqXNnrkpLAJ6gXHWS0uvcw0czMy45ULSzm3fdRmL+5vKm0i39qD/I
ldVoG0E1LUbvhXMfZoslzpsOkvD4hteuR+uxceWrYL1lJHbYBP5nJoqPql8f
W7//KIKQZzch7KmFf1rF7TqqftOE5zHL0Ls40btPZ9SDBG8SPvO0RmjKrG2J
0SeRm3Wf1R7+DL4JSuIRBgmtL5falusNYP41xz6yjtJfrpLZc6wTuZW7fGrm
CPyxw+ZmLFOAiFmmVqIPiZp4Ce9EWgc27CyZceoXYUjx2iEjYwEUak2mBXsJ
5DOs1mgMtmJVUaPiZDmB0oU7HBcHNsIiX2zh1ESCNk2LSmMHYYYV/FSB0vNr
eb0x5wkHGn9psWoPkni4Q/ht+4k2XHXuTl8aQODWV627n2YE0JpfGRjCIvGg
/psvU/0fbJfL0v6xkETc0HbWN8tCyEWdHfQ4TGIFMc9lXu2BlWP61dspYpR6
Tse12XLgGmJ85LQqidQRidA/MxqwkVdm0/SQwKKzS09Ona+F8+gNvelcyu8u
L7KnB9NxJW7uVx0Xql59S6l82QBCnp/pkX9N4HNDuSJftQtm8bQO7S4C9U/u
sXcw+Qix5T1FMQHv1G0bKgwHQJeM6KiqECFpRXdRbnon5iXVNxXnjeKW0OjN
v0ZCpBRpfVzVRyC209qh9Ec36obmkuiKYsQlsPZ1svlIeXl9/VZpqp9jMex8
y1YYT2aFaWeR6G/LUakqaMGVa4tsI6l+H1qdvFXapR+F6f8wuWbDmKI3lOUZ
FCIjKCZI/RAJ2cjA4As5L6CVf2N9L5dEqYucZgqzC99Ppvr2F4yCUZh72OwN
B32nvldEW5LI+InHvSVIRDjL39LKj8TUOfXkD7s4GF5W2rSb4jtpSZqmaVUt
ch9oXNaXpvo/YblSlqwDIQpYvz+AxOE1zq7s+k6YCDeMODmI8DXw7vjvSVyo
nvRNHKDy8d+BDdwlkVyc3W0opUv1r/S2Lk8yrwG2Se3RSh8IHNj+SL9erhuy
rKOtBh9H8NZHV6fAmQ+J03Ist/ckvsevqcD1euh/N4g4/gvFkxmP7X6eC3MZ
s4iN+6j3an44lXqgGr7c7Qe6tSm+fIKMB262oa/o736fZQTkjg9sUKY3w6Ho
fgJkCPhLqSVuauFAblzp4Owaiv9igXTNvR5sevdBVYYlRuL1vWKzxFbcky31
cv9M4LR+evlcbj90hiq+jfKp/Lx367TR4RTsfu975wzltxXX2bQgAx6GCgry
5RMJGDLdEtVmMyk99o3RqXN9w+x5+5tdCKwaZjByRLDn1ATx3atRXjetIp1P
6eNXsuTt5nbscaQNSP9G4BK/ybiXzYGlZ2d2uSaJlNDwqdCz/fBa0vahvUsE
l3eV+61Nn2Gzr9HKeopX3afaFom2ndBfJsv7XEni0MjEYjtxM5KvzCgH6hPY
2ZNXafpRiAXWNA+ncEpvFQmrgsoutLbPNcVmUvf9dCB2KJsLv+YpVgGTyh/N
VMcybyHWWAx/0ZQj4ccMep21OhPmu56F8Kh889NNu6jdW4cU7cWqc3sof+r3
Sker9+K5fXrMF64IKX+cYV3gdECu2ahl7DKB9x6jYQKHPhhlGi+4WCCCn/O1
/35+V4pdfyrdv5xO3cfJ7o1W82Mo39TiP6XyLCmmYZ3u79VgHOn2mU+l5s26
um3+t4qgOCf2ElJ5Nl2rGVBxpg2+0XGH40dI+Lt7VkeF9WOKbVepIRrBRPu1
dXoHOnHkl9QAlowY9NjldJ89PWDYDOXVWIghNZx+VK7pFaLfuqjf/VUE84RT
DKaoDqfWxpW8pOabm6+/aODnLoQslY86lkag0NPt9TirArGfVXq64klMrKqo
9p1qwEKVRraaghgWc7ZFk0QJUhaNM/IekXA4uaC0g9GJiOaHdRXqFJ8/SU74
qtXgvVypgSzF60DLWbrZ8j44lv0uM9s9gkov+tPghDqMCt333WggEFxsIeWa
xIOh/RoHyZ8JjJH+05GVHTB7udithfp/lCo/YNhR8/DC4cktsr+REHpVReYQ
7XAN3DahdpFEZZytcKKtHBFz7DeXjpGQz+7reHCiB0vTg3Rl9Sj/4W3VifFi
0LL2p+45Q/FzeZmt5VI+8pOKBh9RemkovMjQ3vQKwz9UKgZWi7FtU2v0OK0W
oV2Mz8slSRx5+SDsh0kTmh+OTyzgkPgf7zS0Wg==
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41dkfxy0zo5QsLZYSNYqydM1QxtJbUmMpZOwRkZ1IQsuIFvk1hVEZ
pBGTpSwpRrJkKdu99uW6LnWX7zcZSyHmWqL5/v44z/njPOc557w+r/fnbPMM
sfUWERISSqHG/2eRPAHbf0s/bK09gzr9SRjH+Wica30OQ98BH2I3ia4xfS3n
pg7MWjrdizQnMKxrfzSwshoF1qOpg8dJhIuseWLe2wj/9sQINVkCvWp2dSVq
rVjjLmKfChJyzAvuhqP1YJopJ3Hvk2CfUfbbvL0f+oOqWhO9JAqrKyRrp1l4
W77wfiWbi+FTQ7MGYiw8/lbSy8KJiw6dW0/OkUP4OL58cedHDsZS+ZoP0weg
f4AnXbmRC1Pa0tz43lb4XJjYxbxIIKo48WNYdw2C/jChJciTEIqPbgoJ1MWb
1r+7tNyp9ynd/ag63wZjsvr3N6F8jKX3GcpY9SJMSHHDQAwBY8W5P1ySf8eM
d3mHvQsJAY+lunB/AN0SLu0cGQKseE7aJxYbYyyTyr1lXGwZu1f11LALBZv2
utzVJpCbP9jiVtqJrI2b22Y7CThs+PnStdEhpA7Ez4nHcvEd11p19EwTyEPC
xA0mAWVhhryhUjKWHRJeFniQkBbqzxD6qRumS1eKS34kIHX4wIBwajP8PMau
ccIIxDAO1Qzv80PFn2JHT1PvcX3w++uTa/vxcM5GW3k1D67TPcdz9wxiRsFY
9tw9HqKWVzWVaDFgdl5qS58agRI0GrDSOyE/Ej9n0EEgfF/L4/JYNsaH2oU7
Zrjobee2VTvXwdY/M8MxloRZFmvY6+oQpOhLZj/v5cBC7K3IeX4XVglN5X8x
JCFuF8vz9+3H8/HLoS/G+bhQ+mPSuQfPsCB6P3wqlARtw5205pWHiNgULfqz
I1UPK3PuYHU1nOIFgipvyq8zypKSlwcQp0iU5poSiLcUOTT46yC2V8odk7Pl
4VTt4pLvShfFe+DW2fs8bE3YGnt7qg2XOBvJe+EEMmI8t2lk12E+2LtDX4sE
V6zrutXeFgQ1hz79uofAyw3RJsaHmiC+TsnZxoqEMt1WdrKwCqGtLef7ZwgI
uQTD4WsvgswD/jUa4aGDkemi8iwbYwSbVAkhISk0Gsi73Ysv23XKnufzoDby
SDkriwWF206BQd48TDT6dX4b14Qxp+8rXotRfiVd7pKisbCF05ZctZ8H9cea
n2qUGmCj3hRy3IDEyNKn27J5DcisWjuRSvFdFbkr4q0GHXpb3S+67SRgUSwR
9c8SE1/7V73+15SLm5VWBr++H4LHLzOsuL84cBDU6fKD+sE0va/1jy4P0XZH
dq1PZGFR7FRvmB8XHrRru46s5MBl8HXGiDMJm5EyDy/VInw3lx33cA8Jqa93
y2LkHiG36AdNUPXzyLHWa3/WhuIII6PLtgRGG04NMDOakbbuHfNZDnWfk5Zr
5Lr7MSttqB7jy0daplarrEQpEm6k1V2l+kVXct6Lz8fbcPVcl0qzPYGInFE7
5NHR1h3698wWAq5TBVJZIXXILQhf+1aTBKuS3mNX1oP8G8wPgngeKhRZBZ+L
OtFRPKZ7cQeVP5/IzeVfrkBHJ89o+wkSKg2WDxifW2C0WtWhuIlE4D9cVmHU
MF6d95JQfkki2jPHZWMDC9PB3ePBrZTvrybH5L9rhOKtrOdZLwgkrVdZtCzt
QQCReYB5ho/nT78pGovqwTaiqezoERImv0gxzy51ghB2fLRzM4lUd+taz9l6
zM04q76l8uW3whgUXs3A8O4RC7dtBCJXa2rFvO/FDpOlsgc0Powjxx//JJkC
fU8Lo1qK90ToQTO37E54Fon5xR7mo+e2+RVv60Yc8Tn2+AWNRKV4zfpzzDcI
cndjKFQT+GbBYu1N1WYM8zROTFD8WvrUNzXmV8BpxVUpRJlEVEaOq9ClPOhV
2jdbUf2BW5EiKrTmDjzfM12u2JF443r/8KuaerA6mYVK1PklegL9YMsuaH1K
avPlUPxtJl+t2cOCaIgWk7GJi1srJ50ld7ARda1EMGnEgylx0iLyCx2pvxkK
olcTWCcbLK8yzITsDqG7GQwefHIuJi/798Gwo+zGj7U8rHOey7oyw8KJDjOZ
Fmlqv9YdHz/tDqhNtsWnKRM4bGWgp6jFRCohE2PA4SPKPEjC1b8NtNPcz9VU
/zylc7oreTeVTw5f8Po6gcXq9XNBfj1QDRMtZDvzQe+PjxAt6kbA6sRJ1xoC
anIv9/+rwsCbWFpQWieJyHdHDnLMeuBVe5PTak35WahQ8dN8Bywz+X75FK8/
r8udtqC14EmNhlhQGeVTUqC2nB4bPbPlvez9XBiPTtuombRBkjYv+OhAoGuN
jEbKgf9Bw2W5aQdVbx23239vO/MG+8RUqyRCCBgmfsj5VqUeqelmSZZ/EbjL
mdXRHB7C8VpGVetNEjG6uhnS/CKo5kka0k2o/DPvVdsqJ+KE9vr3j9xINAnO
jgg0n+HY2Zw7CdR6wtG43OrmfgiP+8tdY/GQt3DdtEidBZt7D2I7eglolET4
xJ+gw/i0Z8BZFwJ2Sr7LF74ZxA+OT5Ts2W+hIa7avq+7Hk5R33f98pKAXq3J
V4FJN8rTTKQ1kwkccnBZjqK1IsHFyWur1Hv0pCpOvOP14azEkKiBLh8qNbHs
eZFuLNBX3eF38xFqudthOPcpFOXodqfNSRjQg6X9Tg1B/1W+aFwogSvBfgpK
bd3QmsrKny7nw41Qdx2vp2Od94Tr1CYSFfFhLNtjDbgjfumgsA+Jh8SniOxb
1ZDn7iz+/gcS89O27iPHXsKXId6Z9ZHivegTU+Zeh6tga4sxKJ6/bY8WLPYj
3apm3aZ3PNBo58tXNNKRd/DIhwTK96nO/Y4BcS2I8brhoHCDwPQZEyOPJy0I
90g0HxwkoSYlLyKLUvA4DdOplP9qBiqBKq4XsLbLbHCc4i8e+NqxIY6FFJm0
wlJ7LroV3JQc29uRsnMpnLWBxKiMuNn8TTZGPuzazPbgISa9aPFhejl2hnlU
tRqRCNJuyO7nPMdCgewBV+o/U5tpZVUHlIE/mdK3zZUE85oTK6CzD+wUTW7w
CT6+HKqXLfBpxF909abMqwT+A6E9xYI=
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 147->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs0lekal9smhWYkKoWo5HShNJrkp9IUORgmkUQiEhU5llTjOqFSMqLk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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lf8bxmW1rUTJDEXJykjR1RQiktDSkFHZo1SKr4iMhpKUSlbTKKOM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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk8lGsbnnaKZEgpJSJSspQS1aUPHcophpNdNJEUWq1fURxCISJL2VJ2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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs81Gkbxkdaimz0InKsHErW6SVt4aImh6IsRS1ZNY7JqYRSEkqUEpoV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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 148->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk81dkbxy83GjTSJu1ESWkUTVT0yShpaBnlhrEvkSQ/kzWJtKksxUhK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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2cgVY0bp4QiUaneSkOyU+ovJH6RGRWykxVpqJAGSRKlQogykhJZ2bIy
Ltmba1ybe8+9thRvqdD/vJ/Oh3M+nOd5fnO33XVDhxVsbGxW7Gxs/z0FdIi2
5fYS2Ga43DeXIOB8GzGvYvJxpkHgQLkMASOubhNHtj6YiINb0H8YYVNv0oWq
s+BblJrOb01+H61/ZufzMDhvX8ccP0/gYtbvkgccVPys23k2Q5SFRrPvkgYm
VKioxudmFRCo/dDiPMnWCfFEVaYnHwOPxnwvsiW3ItiFujeRSkfYiTcug27Z
MJGZXPm5iYGb1/Si6bIViGMhO0WMiUfibdGHdlWDrfOPy9wIA6Gbw0tWc7Vi
YrVUpLg1C8XWZ1u8O3uQpB7o8km4D96HZw22Ct6F6vSN32+sCJhI1Y69aGxF
11SL9bbjdNjwlPwOutGCz3aPPBJt6KDZZ4XfMvuC4ixhW5FVTGgOmR400u3A
YPJNnY3eLIxk2ER0q1DB29ZxsKJrBAqj7kIlbzthVvFnVqKdif8ZvnDuKmnB
0+zExqbDTOQKbpKmVVJgoeGktvIJgdVW/Md82voQZxncnnRuHM6aukp8Cj0I
Nfk+qRs5htDD3AplVe1YDHqg0CrIREaO4s65MBr4rFVMA/IJeLfa0/WeuOAP
Z4QvQc6zcM9xskarA9fcYjc4DjOQSZ1+lP72I9IjuQiL3QS6dEYiEwO70XQz
16ZcZxCeEXSOh4IUJPdl2jr9S4C+/snJDQfa8I+V3l8/KQIKTtrVEfM02Bv7
h34UJvd590ICl2EX/hW5opzIGoHw0RSpc1VU0MLPtH4jmCi2Lzp2dW8v7PKN
Z0/7j2HYI+ma+ONiLG5Iv6idxgBl8xJlJj8FdTqV2hzBBI5lWrMFHG7Fmre0
4pgMAgWnXs1Ln81EyMF8cxdXAmZVTk5TyjmQNXlg5hZD4Jp2w6vM4kI81F+e
7JslcGDBN2ZaqRuOG9/biMaOwqpe8o5ldBfsDc9OVL9motXnjNw9pVqkOBk3
nlZlYdU+7cx9DzswJTX5xX2OidMbKszeLnajMevq/kmfQXj9aE/QflyN0ovO
h2ZUCGyUtDyl3UtB58Epv+t9BLzW1g8vKPXgo9bPWg7TYXAXtk7E76nFreyY
kJkyJvwfHtwgIklF3HZTLZbNKBQKvrdcsWxFrvGAjkUIHR4THOKSU+2Q2e7O
pVXIguWj3ny3kxXIXrskeF6UgM0l32yPqDT4O7Q7XTUiIJl7U1iMjQa/u/3v
Q1+NYv5xtffe51+wiSebS46fiQ20Iovh/YPwaKCvF8noQ8h+atCP5n6s+eeV
hqYrC1Oen3NCfQfAF/tzjbULA5c/rWGLpFRC1J3e30EhUCokV3o2kAL66M4+
/nQGXMc4GZ5S3Ti6Qs41XZaJNAMP9jHpVpRxJktXyNJRI7DaN9yyC1KyZbfy
yPsG0NTrdvBVoLZI+NIiyfdrXNx1Q4kDUL8csV7hLw39ikMSZ9Z2Q+Pyi3X9
Ud1wHfWffTJLw5CdWuuJKQZOF0ZdOJ3UgzH//9m1G7MgHvXQ7Hl1M7ITwv/+
NqCjIMo6K3ljDJQoNtb3DAgcZQVFPGyrx+LIUlLwESa6VjQneD7qwIfa6cpM
fga0JerCNUo+41joOnpIHomPfEv57LAC/L02Eyc0ysC2v6bT6otUfPgcXEQl
6IgwtJLg8nsBzaUE0atOBMbnly3fZBVDUTCPt2KOxOe8ykB68BcMsvdPZYoz
MX/de+lPej/yiy//1DEeQ3EI0T5xoQXsxsGb8wxGkSnF7VuoUwTe2E6jIF4C
ldpx9U4qlXAKUhHhfMNERXbpaV9Rkp+Ga+5+uELiXZbe4ObTCUNrg5kv5D35
b6v4LGxrQ7F+596l8yx4fw7NaHnsh0+pN24sW5D8jDFw4Yurx+bo9KjGdwT8
B1YYKWmXoeRRyGX7ZwzoJU1c/N9cC2IfhQv9JfmUvvIIn05aJ4qCxicO2AyD
Ff3IvC68A5f/oVVllo/gVtaNedUqGnY/lEswYh9FAQWPM4JbELU3veerygiG
W5+l1d2rhb9bh8PVs0zsXnRO7hqh4KSW6OOJlQT07UbUx1+9B/1w8Tv5kwS4
p/NTf3KUQ+shxaWojpx/k8/jdZpNsL/Y2KtSyUDEqUSRKotGeLm+30TMkH5i
cSBqvLUermftrqpNjiIvXO/gbH0X+Mz2fI8aZqGybONXY69yrAj5lqLdx8Ah
Jed0Pfc2bPrt9aNJnoED/Az1jk1v4RZ2Ol76AoHGUZmkNvdCoNlYrMWbCf0L
AlFH/JIgfDmNN1CLgFpKrFZZZh/cmLujE54OgyPwxe12Wi0UY4Oul99hYmLy
qdUEbyduBkXfPxfPxE6hnW3PbRoheGiRR2oPA57pr2NaxFowrm+XyjFO8lOb
/c6WkTakFMinVYuMoMObV9sinQqN9A+2kaQ+l6SK5tjzU/Gjq1T2vd4Edtz+
s0ZLuBkcEdliyb0spPfMSn/a3AcjefkfvJ0TeFu6u+4ePQ+T4VVLwaTfRp3J
mP0x0YfAjMff1NoY4F7qSTjf34ADQ7sdJsyZUPjD6o1PqceqhfR9wmN0zLtd
X8PDngseIw2V/BME2Jb67qyzf4+JTYPjJTcILNqmhlSJD6Gk7n6dHc8wlk15
T/8gOnEi8M5Vzy+jGLzdMBXHVYWthPzEVXLf0rds91nHfMHlSP7oU9J0cN6/
STzLaoei/fLNdl8CpzbbFY+rVODwfJnuW1EmrLyjJtj2dGLbk6QzK3NJvRdz
MfPijIHZHGXdKKnnXWcK1m27Vw/iMwJNLrAwnCb+8lBKE2Ic602mQ0aQuTpY
sm3bR0R4dLLOqhPQrnHTVvpfB5Yjr0bPvCbnOdfyw+NWFSgf339c9iCwzsmA
fiiwGpt3+fSYkXziGPqk8mupAWsXr22QTqVDx5JNzupTD8I0hO48rmdiykvD
0KPuCz7j6aXcdjqCgyQnzpS8xav3y+ZptqS+m5tp11i0obW1Nv7NIgO18RGC
sk8LwXddfkY0gIBnmuXp3z3duPaEOiCuS76nMKzFfzUieib71IUoOnYFzN+t
MHsCD6XX6wyMSf45CIrq32xH4ZW9lXbzBGbDiwOcmW1Q1jfVOCpIh88TwX3R
7J0YO6DiOPuIgMU59ht8NxuwR2LqSXACeZ/nmlHipL58Ldc8eV6MgKWr15ra
ogaM7Vot4kfmgeHNB95/jXwJYkV3mYkl6R9hvxLjG/Ph8TrPKcWHQPWz6/Mj
sj2onsw3vUJl4alnZUxeTD92Zd4ZlrvGAD/l/rZLR5Kx7kFz7DTpP9wmjYGH
BDIxaYWEbmkCNEbItuqEdjhxLjbNBdAx/II338czGG7ez3xuGxJoaj9aIvm9
GqyO5aa/65lgKyh4U7gmCq/NTEquke8VqDUF/UXVUK8XVq85wcBkfFbeuVuf
8Dd934l1wuT//bbiWOHQiTI113o1WQaSCIH8qdpe+CTNXHmYxcAmeeVt6+XK
YWYZGFtKzl+j94NPgL0HbuZbWWESQ+BLl7t2eSMV+zYydP10R/A2YdivTaQM
atOfCjQ+ErBN1mwsy0+FziOF8fanBPgSZniqV1ZhEwfF2c6PgdZUHtGCd33I
nsnbN5vQh0Y2oattPhWQauSwSB9k4sD/3JP38mYgrox6Tp7Ma9ULPWdGdNrh
0lgf4RHNxFvzltUxgmGIjBm1MLxE3kdVce3c8TrUe/LnGB2mw/CusMO33HqM
CE0bLRWR+LwRvPN7Vwe0AkdlCBJv/MeSOW/0pqGPU4BbmNyX9u15tm77ePA/
E3AKNyfQx5E7I1rTirCVFasS7zOhfSbpk7LyF6gqqLuUnGZiQdBj+QKZB7YK
iDfFWjJg1uuUsJORi6QyhT+V5Ly/0pcW9G9TMSOnm7pE7t85dqHB4MZbOHEv
Pysj/S7wa8FuJ/FObOW7JHb2KxN6PqeMVI83woNnTNZ3hglOYc4whz0V8LTO
vnz3HwZ+Pts8raZSB/EHfgm7KgmIG0/9WuNRgZpLXtmeXEzsmtdMyZ4uROYR
HwNBct6n9brGJppd4ErxevblCQPdTlqjCREDiFf6fHfVbwbmE/i3JMw1ovlp
WFpU/wj+NZXefnxhAHl7rnIfKiT9O+zX3f6leCgsm//wI/3vnnRpfmdxE6yG
C+9yPmSAZRN4W/FQG14GcxktvCf5sMPO84VDHj7IKIss+pH5kerofK+iGGNv
jvDFDjCww/xwj1RSJ6rr5Q70uZP+LuS1aL8qB+n7ZL5+vUrqy4THZZE9nlio
Mn2cZ0NgZ+ZqNmUBGgL2HYyTUWAhpWq4ds2LDqg25tEe8I7BS/WF72rperS9
/Bod/4YOyl7ZFcmOYbh+53Cs4CkCiaUaBUYsGlI8dV1X/iH3f337hfm4Dwhb
925iFYnnagFerqWDjWisUDrAsY3MNw5dL80FqUgKubn5F6kv0u/sr49MvodR
48wexf/yiZIkIyShFYsWoSPTKkx468qvNgqsgR4l6fXxaQaCh87V8GiWgLHG
oWC9DgNHrWRc325sxVDY8Uvn7ozgwk+thHZWO1Iy1im5VpJ5ZXt1/rXTaYg/
ZW7YdIxA6+pDHa4Pc/B32SrIktQPff07nLITOfhu2m0pR+Yv7wL2YzEXvXDY
Qj/CjNxPQXC2Px4Xgvt6V67pWhK/Lerf0190om7n9qeOmQwQUka7HHmbYXmK
UFoSIfB9O8919hyyn2kaWadHjOKNuOOdMz+acSvkeI6v4H9+d1EpV5aK2PVm
JmvIPnXxN6+ddxoNQjPcylRlFk4n69g6kfzr/HiY40UiE7cKo3k5eHphEnnK
RyyR7JuKFzKkhrMgfXv/hsbTBIr/mRNtSu/AS51Kzs3d/+kln/wTmUaILsjp
qP9lIKfKk6V5rgcTW36qKg0QMJjICxPq70Bt1abCibw+hNoaf2mo7MetT3v3
XtUewwGJfRKxZJ43vdLdV0f6k512TfxIZjvkZRoUZ73JfRhOsocwChDnkLlH
Q5fA+x4JRr3cF/j5jXmqkvemWHa78vW+Q/O0eMNuUv/Yut68ERKJh/rPB09G
HxLYfa6F70DFIEZqTAT4yHzpvdlixL82BSvk/2YvaJJ4Vb2lX0kpQG6gC/dM
LwErat+T7awu1LprthffYOH1HnNHi/l0/LtQtjgoS/bb9cL4J46KxM8WSnMk
v99G/jD2Dk/G0Q3uTqqPyXu2pzyKXfMKv6vnzTNJ/WLbX93e+7AcH67fUtxP
zne0q8Y67EcptlyOdqp5xMDDIuVPkatpwJUgnRd1A6AEaw1fkmgBXVBD6Lna
KO5dmWG6zZL55nJtgLnCKKqdYpq8n/Ti2sYXDsdtx7H97s7nH6eqsKVLc6s4
mY/GrvtxPxuuQS4PPZ2bl4UPuVtPvretR3y44NpvGwn0D/btMQ1vR1dhl8i5
Q4OwOafoMe+QizcPJMe3NJD3vSXRZhVN9i1vNedsCgPDiceEHNYH46KW5myO
Nan3w0oBs/bdqJAKidrlOYrWgoHbvjdTwPmrWsb9KNmXq/i88qS+4J/zG82L
yb61uOrI7MKFfvwsqhIqGh5Fe+w0vetzDVS6pLs2mNLhH6imZTrfD/VF98DH
vhNortmxdu5sBzgvtgzOHhyDNu0k3fdiI1akP+cP+smA95/Zw6onQ5F3x7up
y57c7/uI7kcrH5B+RsWsHYHXejkdgsZduCgy2+xmyoK2cJAL53ATZMPT9WgZ
o5gW0fuseZCGXwsRYvmm43BXXkmxfdmACpVXMUGNLPTW37eqVeiHz8+Q04zq
MTR9s4sTf9kB+tWPtonzw/Du1h4WO0qBeMuE0qFlkp8z4fcX/GrhSaMUFpB4
2iLpXu08nwsRBXsh/iMEhuVfPX35mIq8AF8vr3Im6RcfTh07VIrwETsxhykC
2xeFxXIUhyASWprluaOaxIWo3hGOaoSqqY5lTTGhkiime6K5ExXWRqpxASNo
pO4JF9jfCpmH029SyHzWH2xTmTRIxXYF9RTBOTrKRj+7Shp2oSuaS2rv6nGY
fe4ZSt5RBBmF2KWYYgZivP1nbsuQfeD12JV/kliIuyjJGiH7WOKnJqaXAQMb
dUaFzj7NwmYpDbdVZN49sWNW5/WaDtzcoGcucpAJSqRu93rWU9yL3ShbTe6f
u2NbrotbFZLiJXnZ7xLY9V0qebNXBoQLOU9p+xO4dcJJQn6ehrnbnnrXP5F9
MmNV9PkdHXg2aXn38PoRVGv8OZEf+ha0izOW2qQeu0edqkvp7kAZpKp2VTGx
VYm2ItuwAcfcNjxzovzXXx3P65zvg6WE/ZGI3f0Y/CHsl19K3jvWXD7tPQFn
ybYNCbFkP3FxzDxK6pd6/v69cso0uHTZMjvbCSSpSl3YItwGmbQS3z6yD4ZN
O/4OcCsHQyyscYLsAx0VZSas5HbEWaw72k3yZYvOhxvdtm3YtlX/FT2eDnU3
Zx7nd6T/15zTtetjYTZNzVtqbSm4lD5263EzwPvSf/jO1XfwemNwLJHcX3/y
3ndc6yhwMEg5ZaJC5ocb9qslyDzM1OlbsPk0iu26W5P+DU2FDa/S8Rmy70tP
MYau1FIxFJko8EiRiVpbAQHNjxS49JWLp44zYUHTsnbwa0ZAQ2pdkxIDNvsH
nbImq2D09cYN9zt0WOTL+C9X96JYbdXLhPIxRN1pZC7z9GB8ubNGJZgJ16Mr
qgRetOIsG4cbpx7ZB5dKx33lBrBx/dnlJuU2UKQrNL9dqsVctfmFv6sYKJBw
Dfv5nAqJuaLJcy9HQYk6e784shmiike+iK0cxXB4TeuIQz0S+gZCkxqYOLor
IIFTmdT7tA+f/mwdQbBiRlSdfS16vv/7uCeexIfGlohNtjQ0TQ0MRVT1gePI
Hppj1gBMN4o0q4a2ofSWqPvNvVR8Tl1QHnFhwtNIwNbFuQrX8nftWLuLAfaZ
4+Vqf9uRU28c0+UyhmvHBCr1hSogaLl7fVAHqc8S0baFiX0Q17h38/m/kzj6
8jZeWmRjxb7e6VekfxkptlEjtzZA/5Ch9zceMl/N9a3s8E3B6ZBdqU+cCdxO
DVioZfWg1ZOwNf42hLGyzZqK28oRwd6cWk7yi3Yoal4ipwZ2ht8Peqcx8X9J
/h6g
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVns81NkbZlq3JLdySawkRG1KWf3E41JSuSxdXFaSdEGytElyrQxlk0pC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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41dkfx2+o24gWk1KDLJVlmgmRmHgzk3UqS0byy64myogouzuISaRF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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 149->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lWkbVlPjlCRlmRotlomRkbSZlAsj2YZIXyKSkIpkUnYJCWEkaw4O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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k8VG0bVtFGkSRKpUJaZN42W7mkksheWUJIklLqRVG28hZSSQoRRYuK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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81PkfxxHlzFkoGyrnjtCq1Na+KGG3IuXOFkKiMlEiyRGZJCGxHUon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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns8lOkbxlFRW6kUsUjaVoeRHHJI1sVSIacsEol1WNVatKRkd6lIVNY6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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 150->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk81ekXvpkSbZaIaUVlSXGRaiQPWvj4kZCikCxDJkWpRCLrCJHBtFCK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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2kgVA0XxylKUSlLJUVFScqaNvpnKZGiHknITipL1oQ2ochOUXkiyRYi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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk4VfkfxymPbcygQdRkTIMxyNK0mGjeKpRUSOqWGXv1oC6RbIVKWcqS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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk81Pkfx2crraMUUSNqHeVqW52OqFdp0zWErCKVI/1mWzasxlXIulIS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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 151->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lekbPsSYmqOMiUxMWcsMZUnSoFsLZRiZBoWRLWUsIUumBWGUbKfI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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k4VG8fRkhlS9ImJEoiUslWd1pU/zZJQpJ2ImSrUJZISZKtkiSRJUT2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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81VkYxm8oKklNU8pVlrIkjZSGyKNGRZmrmlJhbKkoS0mWJDL2EI1Q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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk4lekbJqJsiRCVtWUSOq4UJW4mhJAUbaOyNNkqMxRajLVB6TeDZF8S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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 152->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXlYjekbTtPQzAg/GhOpTiJZCmkh6S5r09CmfZMWklRDizYl2lSMUSkt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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k8VA0bRZJEIcRbIluIqFSUnJRKwpslyVbJ/maJbFEmKkuSJVIoJZWt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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lWkbx+1DvEIabWPfU2mqScivsaaOBlNIoRBGmyxDykihTZPRRiJL
dnktoeGQLUuW4XCOwzmcczzPwZRBTYSk93n/eD738/nc9+e6rvv6fX/XreF9
3vmUmIiIyEPq+/96RbHAuZkbCXoDa33KCRJu6wOd5iMbQU+V0Hc4RUKBp/a8
diQf072smpO+1P4mD58+i3S4Ha9pMXAk4Xu+Onv5Ziu0b8ckuR4XQuSxqPHH
30thka3U98aBhOS1toWwpjYUz2X7lDMI9K8J+8z6ngnDpzpB1upjWPSmLdL1
OXCLs7mpYzeGK+7eMSNeQxhuU2G+/UIgoffCb67MPkwqeUrKUfUc+ez2H4Ev
B4eU7ujmtvKgkP96wFO1GsdTrX246SRaRYeFbRId8LYizDyqCYhsnS3sLs+G
xCO9h54hJM7ps8v7aFwsWu0fru4VIqGnvuDqTAN+TR7UvXeTxLSn/aR5CQuO
gtxQbR8SvXSe9NRoNxh9uGbfSsJQoow211aE1KDXP+cEk9CveMnTGxxGdO76
xIK2cYg8Oeuy6OOC5cGGb/d5keiy4NAyLAeRcuwg9UPC20b+qFRsF+pvLicN
zROoquYX1naNYuru3Kt4SS6u1yXGtXsNQlQqWv+QKYFZWsa+iqpMhMaH8SQ8
SCzX3HcKH+9FRNaiMPQ76n7KocoHXXzQmVyXk0bly+te+9f7wja0xnuz9EAi
yLY9T4V9D8QJq8NlniSyHScld/zDhdQbH1/NGgGCpH2ddk9lI6IwYDb2HAlp
F7t2jmI99nzHXVVB5QsMKI+M0RhGCGO/PfFCgCcmkfa38lmgras2lzYkYLQn
Tq+D3QUpnQWasSqJYj0NB/O2Xti0RqlbUf1b8Psw2mHJRu5KqopV/DhCX+yv
f3GjG4dmXqyOdRBiuePgu4scFl40626plSdw/43xVppMKyZyjhydLCURoVHw
Y/nhRgTfnFFNovg8Zxsk3nyJAQNVNbG7EkLQUpaerSy8xhpG4Ul3dxIieueO
msUX4YnDaE1YLMWrTYDYeF4ZWFZ6X6JsqHqUG2W/H2jB6g2JvzpGkig9fUHx
QvYbdM5PKBmNkWD7OdI9TDlo+BKlSbcn4bh+192UiofIDq+zcKX691oifI/W
Ygv0pU/KveMTWPXrnSpR0V7YDmuqJwUSSG9NLJVJG4JuSsJSyT8kEm8kLTR9
zcO/AboPRqh4E7/kukYfHgL3iZfaqXo+nllpyn3e2YKq5C7lFao+fnVmTDsj
AOviH2w8Sukp4jghODbwG5rWMB8rUXpI9x/seOjDQYK/5voZPxImn/ZLtx99
iSz6z0tO50k82Rk3m0BjIVqoUWgROg6TyDZ+pVwdnLS8CgUBVPwf+t+RZiU4
HLUt3c+YBGM6338ugIGon40WzUwImEr9lqGXw8Sr80Nbih4JMWD5ziGD04ik
hFXb+RQfIs8uOZqV1cM0YIfAqJNEKEPr1NfAYYRuXlrJ2iaAsp3YF04zCz23
zlZWCAgMPJxSuzdJx0SZ7WjINsovd6a0JVo7sXosatKOmgeOs+Wuu8UKUJUu
/VzRhdKryDvB9FAbVorjd6Vcou7b9ajse5c/YXGQGRtxiMQNPbvTTYalkLjs
llFO9XPZw0Rm0xkGzL/dbMR4O4Z1g0my7fV0jNxxc2ZnU35TdhGIOvUhmBi1
s/QT4snW4AqjTBYGgrh17bEElq89V5D7wEa6KpkyOkrgakzthj3GzXCciL4n
+p6A+aiNVwyHCd6KwpSL9xjE4t2if+GPosbnaNY/KSO4ZTXY5Fg+iDVZl8O3
yIzBqHZTSxxS4Lg2nf8XxWN8gPoWGWsGlnOl5GuiKL6Ktf5+tLYFStb+HmoL
BNwpVd8qsbGZFvCHuBuBCw0uKTxPBj6yfM3NzAkE3HD/7KTLwgeLvU931pCY
xVtF23cVkI/incnJJfFnc/WnNK1h7JtWfO8VwYckPzD/iKAH2lf3VkwnE5j7
VHCk36Qduv6xKSFMiteivxbtD7AhX07oP4cA/OCIjRGeseBG0151UXx7npFd
fKo1hNTVP9T42QrQYvbjbcPOHvT1z5AKSyTy6+T25D2thPJugXovpce50IJV
nlWDWLgU3nnXhoB2aIfcfMsoQotXnBODhWgtN9jcON8Hdp3Yge80qH3hQLZd
QA/qnbY3Bp4SIiM85e+XUSOIC1540Dc8hv3bwrmZVVzA0r1K6zYf+WtUNAzK
mqCt2ad+soiaB3XFd9y2duL9q+h/nTcQsJ7dqD2S2AB6E//6iesU35ctCkVp
WWgIFt909SDFm0/EHpfhWhifdd8kf4wE/VGFeKJUL7hRoqzxVwT2ib9LOxN8
FYerVegy1Hz5w35w294lJoJ8hxq3D5H4eNr/p1TpRjCWzAaT3xJI/JrsoPbj
ED4qHOaePSKAeYOPw9QlJuxknft3ZhJQ/yZwgGmTDRP+7ZItVD6326dCVBRq
YOm0VTQxkIRU6R/W/g/ZeMPUmROn+slmW6t+K8GE5nt/v5QpARRCDAoaLjaj
vWyVWuZxin/JiACxsjIMql6vk6d4SrOs0lG26EUyTyeuRI7yf5pheuRPvZDx
TJ2O3SRE/mf67vztHAwMudfs3CZEruvwspawF6lbM4qbBZRfYy/nP5CLw/ld
2fiG0jtIfvOHA9Q82tWz74V0mBAnZLlyHiOvsUNsh2wMFZ+u7rxfua4Srqfz
l/z3Uv7LC/ukcL8c9c2RG/aakMgV8mLHMpjo7rinkqNC4MqM+r5j5kwEyyXN
P44n0F60oya8pwdeIj+oeIYQMN5wN9aWycEd3pRa+Llx0PQyHn/6ykVbwXxV
LvUeyj6e9A46X4fUIr/rOTRqfv7kP+N6pAke37SW61H1Wnq3zafpceD938fT
eVYEhuMCm+dKuzHOq6wKMyVxxdqTX2F8BSWea59lUufZ7oYv74V3QrHHVFZn
ixBnsn4PEllh4Mxb0fgLVSR4JRtrVxuMwKCGMDuryUco8+KxWeNebJd8dfya
OAGF1OBbdeGVSLJ0i+UdINE4EdnVv44D64Tu1/U2PDiStX0JxZWQYHT43Kf8
cMLgYswN1n3YloT7t1A8/Q8yE7d5
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns4lOkbHjqQQw7ppMkKoZRDibal25ZQUtLJKSKhAyFFq50Qaqm2iJCK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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 153->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lWkbPlOjRWWylRMRsmSJdiWuFpMoUjGRSLJVpEUoCkVRQlkrCsUg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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3cg1e8fxRWJklRGkVlGm4zQOMgqlCKpyOxbaZCUkUqShGS1kJmyt5It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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk8ldkbv0qyZcvIEsWoSGIkyfY1iDJqLCnLLWsqQo29ITf1kygpW4rS
1CDZyhSRJeu1zr32rrX7vpeobG2SMu/vj/M5n/M5z1me57uco+wZaH9sBY1G
S6Pa//vTSXzGV0yysbzJu1bWlYRFVYr57Pk2tO6/zXxpzIPRwgmmUhMLy4Vn
N3V9JvEgty7P1rIVut29n9jqPMS5XJj/2puGO6wV0X9Q61tov2nEf2xEfhVD
Uv4RAT2jia0Ni53Q8yBUqzMJbKsvqc+wr0G3lLG0MxVfri8g6Ls2GW5i8WLC
1Dg4QlqcN9sGZf36ayr5JNZj6WFYxwMUTRUW3ztBYuzqktobdiY+yrR9q/Ih
4W2hfrnfmY0tfrmHht6QSDt3fb5QuAnCYfSQS/Y8MMxSEiX9G2GgFeYheZ9E
hcFwkO4eFsb9p+hXqwkI7BnHCmYbqpfKCdeXBBgTHzNrZi5CNsWOtehOwjbZ
79dl0ycwEu7m+x5FwlTeLNj8ZBdMxUas/trHw4ks7gT76zBOXaptNloew5FH
UQukwhASylTd5OXG8A/dV/6oPgfHw84o8Gy5qH+lF56ow8bBzMmf+LZxESvL
POGymY3wveaJCZYEDF/dEOy4wcaBAVOXbRoEkgpUnAVMhrE3PKPhvdgIONNl
Imo9HHA5ORHMolGUs1ef72czMR1z/7pCM4kCUfFdhSmlkDJ8m2hkQ2LedKvj
70+a0dfRrcUgSMza5PxU35oFS7lQ5ogXCWuDpZDEmWZY6hlwDU9T8SxZ/V3z
LTj3hOsxakuC5Ucf4IvlgOboMj0aT6Axa6Xi4HI7jp3ccDxHk4RZHmvX7h4m
BhyFJNJFCci6StMcD6VhhYa6TiiF5/pnF+cl+AfwM8NcYaCdwIF8mfhzY4Mw
MXDY7X+Hi4XHPmPk5Q4YmIdX7dQlkXnRLHVj6wAiq+dervybC4bpO5E1yWfA
E+K11RwlobbW8UhQSjYscm75r6bupxYn/a9Ldy8s776/VzNFQNt1n85r1VLo
X/Bo5EWTuKE+k8d5yoGkg5QkcWkMDn79HSKOrxCS9tZYp4sLNT8VMelHFJ5j
lWyZQB6YYUzlo34lUCoKLdZ0IfHxmrRoHacMq38kwCOchECBZsnAUBeitugq
HggkICoqI7H0Mwc3RK5b7y8gIR1QeCIgvQUm7BDCoZFEyfa0nL6mOiQrpS0W
Ufv90IioHJ54hfu/x501oM7vuXtvq+qhZijH35871U3xb+3KGA3z06j4MfVu
kMo3843mo9DVTPyd3KR8v5wEQ/GwXeRxD0g80Br5TM2bVnwpNa3shUGwUn2b
FhfP23ZUjxxvx5eI0zvMdQnEJfleHFRqxNAp3jczHqXvybX+KWdqURsbNmpU
SaJTMykptYaFrNGM2vUxJGglnrlac88wXzqn8sGNxNkw9XX5mX1YV70wWEgQ
eHxAtdJ4koXZYs/dXpYk5NxGtD7dq8FxxQ9TKR8IpHw6uTV44yDcAz3a+cdG
UGRsNN5i34vddOYGxgQXtHSXt4tHUrFmSHNNqQcJPvd1cmFxXdjsczPKZuk1
JP6nRxd+2g7VPb8URxUQeFYgeXeidhDlYTTjpLlR7J/Ts7kS3wNfNZ/WTirf
hurgS7JxLGzfqJDEVeEhQXzTrxxtNty6zI9cfcVFeKrr7YBnvfhcIP9T++8k
AlKG1j/26kRIr3VHaTSB0/R1zpcnnsPkNwG7+4dJmC/m/yKr2oUrx+wIxixV
D3Pc+jfzD4i5LWQOUPVOMoyTsskpQ4XOVv7QQyQGwpbMU651w+Yw1za8hADr
xB9GnsopyD4q3uBO8d/JdWM/73gz+OUC/wwuo84z68hNXKpDkb6Uk5YjCZOW
vzpF7/aBXjgXEzhD1c98wHRGpx/aoq06UdZcJC7kDTMYZZA9OLvJyo4E/R/N
MsFN5RiKef7d+zaJhpZIc5+IIUhrBzXGsgjYZ1gYrfcZQfrbydhX315jPHFG
78IAG7oiGRFGjQRs5Wfe0cUew6DYYcPCGRJ3aKnBt6T7wewpML37hgvWw1Oc
fVWViBFIj2VmkLhpfVn1dGQtYtdF43IFxbecLLnJokTQ7becolH4+XrRh3mx
bGwfy/n0sIfEkHeQdmRSA5wZGsO7L5HYmJXuKROagKfyJXuyjlD+7XUwi8VN
gv4QJ3sV5T+fZc1yRNyH0fPvxHwu3xiaJobeOaR2I95D0DXhB6X/J14BD7sf
w+h8Fpt/LwkHf7M1U4J9UBZqYGmv5GJ0w6ovavIcrEm/I/uQMwbBZy7703Z1
QdHQWqesiuJ/aNMLZks9pKVmpRYDKTzOfEfqjU6sl6k3bpSj+CfXa7PTsAlu
dTvlfUMp/Mb8V1oEDUNm4hpff/Qo9PsMFbfZsOE1qNko/J1av7DB4nlLP8R5
UcRXCwKrFdVrYteUok6jxl+Uut9k5SUP7VWdaBVuWTLYRmJqhW8AvyA19t9p
uj2PxBKjx3e0rRsrgkaUW5UISHxa6hd4nwehH8oaUc4k9NgtZu72bPg5ewsF
TRNw8tu/Rae4EkPSLAnOPhJWL5bzNUx6EeIhumqA0uOti9kTjnQOZP9UsQj3
GQet/m8yXOAs/nlgwU2m9Fv70rTh4McQqDQEpclS/L3iaRBjspKJ6/u8LSOo
9/ANTXuyTroZhJRa8HQE5aeWco643Q4RJ5MjipkkDpYdVTLp70a+mcKLL2Vc
OL0Xtc9YakVqIMdfNIGA7vnCPd+4fTCeb7L4oE/gxZtpGYeyOmzdPKX+rJPA
uZ0VCld0eqFjZXxyRpx6f7Iz4y+crcAVY5XqTZSfZm8/ufidW4WEe4d25FmR
IIsF3dbJVkBpxz3P9J9JRF8uvvmgjo0JK4GgsWQCUu1CyU52T/A2a29znT7F
/10RvwW19SI3Uyc5XWYc8tbWhycCONhT3/uBPc3DQuS3w0xpFnqf5zs4H+CB
buVfnrJ/BKIHPzOWX1P/DUf1Rw9/7cM2OYXcY39xEeDu/07bfgjzDn8e4Ise
x+xNS8ktj0px1W6D0/mNlB9+tvUuKGVDbTf/U18bHpxGJ8fFG9uhVn6V4WZC
6eO8RoxBJBubvz5nuwiN4z+8X6aI
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns81NkfxmkliUiybuWSW3Z2N5Rtkx5Jyi4Ssi2lSSXZ6bKhNC+kXyqK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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 154->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4ldkX1mVm6GcodYZQLjFjdFPSKOrVjRJFqaQRHSSVSK6VQVLUISpE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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VO0fxifZSZQoeVHJUsqSeiW6JUW0oF5LL1FZi4pKKRJRKVlKIilF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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lWkfxsnSW6lMb5QaWxlLK5IkdVnKNkSyVfZUlmzFUCJlK8n+njFi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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns41GkbnpBazVohk1TrkByzorUSboRqY7NhnOWwnZV8H5JSEjkTmwg5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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 155->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8Vekfdo1pKEkZKSS0b2JCfpaeq/yQNspIElJJJUKWFMO9KUUqGqQ0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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VP8bhlWyhyxZUrZ2a1R8C492KUQRJSKkbCkprbaiLKGisqQVbdaQ
0DDWyDrDkHXOmbEkSUiofuf31/wxc53rzOfzvPdzv8rOPlau83l4eBzm8fD8
/zNru71L7PNimF5OKjo4TGDOgk3b7l2Lpvy+3161JGhRdVH3BkMRP9dVquhC
oo+jcCM3MxO95z7UGOwnITCa3XC3rRrsmBdB+ts4CKJtln/z+gts37k6MMrZ
WFOZp6JmT0fMVUNPYYKE9oJUJ73XrzHUceLRqlASsrYaewSVq3Fmdc0ejnY/
1mwdz3l4qRkPZEqsEgRIyCuqH1Xz7URkidkC/u5+sKTyBDpXlSGCbnRTJp+D
VN8iv/bKZkiM7Cs/n0Gg798v7G95gjzT9Fc+viRuJIyEfexqgtYVd23h9wRW
JP9rO5pRBs1yoe3KshzY2cjweKey4LbzqyVzkoNjsZEnQ3VL8bvZtfFFBgnj
Ee/47NvZ0LCaEy87RyKVa6Xt5lwG0+EV6uttOVgjeHb72oZ2kO+C+u9lDMNY
jHjpdKcKbJN7J3cdJ9FU4NrAmJ8Nh/0HtrFfkrg80n3qYmkXbkbHF/nUcXFs
p9CCrjuVyKHX+SVEklggxHtVdQUTVjetgrZm9SL5Rd8xIYVWCHU2rZq5NICd
UeVVbradkH89HTuYwgbP7X4jHvkIDMwTOfPrCImL6YU67uvpUPXLOje6moPQ
0Dbj2/pR4JV92nqY+p5HxjaM3k3HVcFV5wdkuHCadXiuuaUdbpeqN3oeHMDd
vCAy8QMTMeZLr4lN9UO78lNDQV0m9umknA7you7/wfHp2REaunrj6nsbCQh5
z/3RGehE3/L1epXRXMQUNencHopGwF7d3Gl7Eiytxd9FBcphVCp84FANiWN9
JzQNLd9gQ8uGieeSJOYHpIjEb22B0Z6uw3xTBAZn1TtDhh9jvTp/9z5nEhLe
cfvC21og9XMkL0mawGmVvDHZj+3YJGjKFx09COPaFXcUGwvRFqNw9PsQia5I
wSHRNV8gYlDMvH6RwAtHdkWaVCvWBWZ4hdj1Y9DrqXzjzy48++6VQKT3Iz6u
x4RQZcCMJnZ3GMPw5GiEq2bSYJCzzDfRkMTf05kSSaV1mPc79oaw5QB4/Hab
eNXS8GHd9V3b50jc+sEVXhZPh03nMl9THQITfBev36SzMCfIdJPWH0KgvKi/
eXQNmPHZc1uuEzDeoSe0QTIf8o+vTJ2/SeUhdU6qQ+ILfmsN5Q2ySJiX1/3Q
iqND6lbmXZoKAW3NO41KylUwCr0UzMMmILptsVzu9y44hxi+v6FEomGrSp5t
Qw+erRsYpmv0gff1j6MM71QIXTKQSvEgofT23IkA7Sy0dIYtiZQm8bH30Mti
4Xb0BXStX1jBhUbIY2Epv2Y8PzC/we4PgSZR8XqH8ma0tbe3hjCpvOwd1Xt2
qg50/w9rFXQJmGQclf2jzMTFGC5vSmsf1HeRDm0W7+ClH/3+mxWJDXFLRyIk
KsB6VDtr+Y9E4yaP1OzEToTodbfTMzrhribKI/uoFf5a0U5OZlzIGc8VOAbT
Qe7Xfx/GQ50fM6Rx05dP2P+k5pzXzz7MfR8aaJosx8m1nEtrdTmwvyW9lr+n
FgnL1SUbaCTc73eMqN1gYFSxQ/rDTypvPKLKjwe7YLsrPGQqn4R++YbGnncN
2OTccWYCBCpOptd31LZAzvDEMwthDi6EKlyYsryPuO0Ci4rPkoh5E0i83fYa
ny/6Jl9uJWG5uKPwlEM7DnqY2h5BP0QcfOI/l9bi2o4j37zLB7DfW2nI4mkX
Ko6pSKwY7oOsclySpwcD8d6LlC9X9+Hgilm5DWfzwJdrN452AjVnGfJnTUpw
lzaWmKLDgU1zqpjg9TbkG6mLbVhJoP7jrF6VeyP81zUWJdZyceGFhW9tRR7E
Tiz72JJNYv+boZcRE7V4fWDi6j55Dvg8Da6NedThwqIU/qFlBMbOeBp3DbMw
6lauHfuDAO+v8ZKYmGa0uB57qqrBRXFgx8HKZ+V4eL2vgYfi2dXnxO1lrs1g
1bDM1QrYiLnbEa1bkw3h2Oodb6j8dykoz/s9V48iTYtdl9MGUf9zUsy77jHW
HfLSaD9D8TFegimQmALm13m5S22pvGGHybyZcqjEq0vPo/JSE2eh3Lz5NeaX
zGgPm5NICj9XscivGsbPJA0OF1HvTzNIEPnWjqtFluE0nV6Eh/7dVe1UDMmN
Q5FNwyRaqly16eEtoPHssPIk+xGw+87Rr9pMXNmz5F70RD8eyLa+5f3ThPRb
/8K/J3KwYb1pvun3cqxd9sQoM5Pqp/mORpXLuvG0euLINeEBSO1xGt/V0gkR
/jd6Pi5tOE1r3bCppARMO82usd0c7LcYa+tVqIDKk2vbt8gQMLAZ0VqeVQXV
1mDrvX8JKMVPpgdsvoOWAQ5/gwM1H540tspWa5ztkdu+3JHiQeKDkTHnAmQp
G92TPk+i0Nd4fb3HBzyevJ/sF0cg9JSWRvarCmzb6lks/JSArrT+ztudzdjT
qDh0kDpPAbfJ5we/1IElwOC795iEuBQxWPysHcbqz4ti6IPUPE/JTgTlwrtk
ScSHHirvE4fG61ppUA2z23jShsSqQxLcLSItONsQdc84m0Dqjj2B9R9rkBRa
papny4Vs6O5kp7oauAaOnjPTJMH+ZbBFUZGFMt/V1v90WHCP+vqZ2VsMPX3e
oQhrDoZvGGrJyVWg+6zDiMppEg/v5PyXLlwB8wyRqPNpJLKsm3+uPUlDg3b6
LD+dyktpBxGwmQbP93zPnbRInFlYKDRRxETFu5efjHWpfrAsPPVoOA0hvDm/
VpiRGGOFLV24pBwjopsiB3k4MBj/d+rWlhJ4n7h8aiCCxJL5nTZHDZj4ZLg4
KMzjK2pipd2XTr6HW0mTjzVB8TFtfy9fTi6sjvKIBVHnn/p1cdMHm0TI++2s
z7cjUTOb0HXfpB5ZHxZFJSuQOK64wFOB4r1z5pmx2F4uBP44F58q6oDCiQMC
Mea9iHGWtjqwuAGVw4NCD/gpnj0JZBy/0YyuoEK1WzrdMAifCfxeRQefXdoG
ywNU/sMX/pF82oaVBz33HZEeRlyW3R81s3aE4kC91O8BdEqcueo51gQP/y/f
V5zsw/SntPseBh9h0H2iyduJg6atjCsROS/Q2epf+DSImo+s2B9jRo0Q6lr4
9RhIqCQk1B61aIG6WJjkxWIuaMKe3RpJmSBSU9XlqD6u4Tgc+CLRi/Hj3FPd
4u34YlpAV1X4ArHQqrD7jweQdcfyo+vfClzsyudvpM4z0M9A+IwEE3LhIffO
thJIch0WTJeoxzW+/aG/1Qnk6zJ63KToMNCIez5ozAFBWjETtFrBfD7uWNLG
hnqR+iP+gXbM2rfKhb3nILB10ti2h4EdKWNPKlwHYXvJJGWJZyF4DAOFHRdx
UL6y7Gh3HBOXc8sdjfII8LhbG9d512Pd+6mbByf7ka5TX9H5jIU8c052p8oQ
br2Vsu541wY1xd9Ri39+welDx7U2/20E92jq3A8Pihddf5f0hDBhLD1FmqVz
gYFvjn/4etBycF/vt9W9mP4Zu0wujurTlezeS5RfbhieN5pVRkc4mfxicziJ
idaQ7IrV9Ygof39F8iABVo98MH/dZwj9SL/sTfV7rTOtrfRQLezuXpvpeMDG
rU8F+jU1TDzinvuVI8dFuNao8ROlLLBTfbm9elRfRPCKXD/WgfiNhVMzky0w
Pse3T0ssDoWn6VPJlP/tUnXvH6byNvc3tFCCl3p/etannvQ2aJlc3O41n+LH
8nDJzQ/skGl4myeCyq+xqGa46a0SBFm1JIpQ85w0oVGW+4yBYmnJqNGhPrAj
0qZz9Jphfn5lxINJAt7zrdgy2zrw8FDbgTORQ5iuoS1zzy6DkFVEgj/Fp/t8
ird3B9Th3YpErQUfSBxOzu2YLG1Hh6aa/TZXDnLOLF44r4sO84gdZU98CSxN
G84udWhBxhEXZXmjQYDwjIusaIVbwUarp9Jc8By++d9NHm/0RC3tnqGeHyb5
L1SgqQVjDIUKnsh+xPALGzdvLIGSu2nSXn/KT5onVVtsmrG1SspUpKIft/o+
Rc3KP0Z5yAfxskskzH5U94id7sGc6KXR4eXdCNj4q/F4KQMPXUx5XfoIJB94
cNh6LQ2c6qEVRS4cvF7D3fVwdR0E+Qyj9MWovkk4EriciIP3UFZzvAmJKkZy
5596BvrzT3YWbqR4+KM1rj6NgV1TJly7r1yoxyz+FsQpQ9ntV7GJaznQN6lM
X2iUDWfewOEYqu9YevnqS562Iul+U5tpF4E1/mTiw9wqHPmnal5A+aqBi4VP
Ha0AhfuWZz45RfF9y7PZd9/K0VXmkhZymJqvM961boVhoNl7MbnU+WyOjfWK
c61E1QuxEKF1BFLSy3h+329GtMmaeTN6BEa+yqXNLG6Gv+eHW6XmFA84R3TP
uhZh5HXquKETiU+sZbesa1px8aqL1r5XlB8pF/+V8W9D/L8b34ITuGBlZ6lr
1lRBYfquxVrKf2yzUq/xhzGQmpr9T66pD//VvBvR9W5G8GdHD+l1JKz5Z6oi
Kyg/PeLZZ+ZBIDBPtCnYIQjD6u25wZSvewm9L+++QkdNsM/Y8VyqPzLMKwNc
v4D3rM25Mq8u3Fj926t+QwuqQujtdzIoPzHbEOM+8RGWfvOT9lF8fSjTmz3j
24TiIcWozNAezH9K16Mzm1GcfTk+czEBqRUZfEWDZdhWOT/TrZ7qC93cgtnL
7YhQ6luynvL3lVeymXN93QiMr15+aA0BlXVpO1MSnsPv7qqdjhRvA+d2LTAI
qoLLx9CZgDwSFjW/nmac7sCD3aOHFjixofOAV890TxkElxExP9RIuHQm8K9K
YMGItt5YMmsI4pKpkaytRZi4NGp/JZPAbdbVO+oG7ajNSRG628CF/Ysljz43
MmGyx1nWRpQN3hPDjU6rerDpng//Tu4wQj9bbU+xbgPLYFbpTtIANO8pbpET
z4Z3ZuwlX8qn4isX8apda4WKoMYfFYqPPgudRpU1OqEWMe/mreW9YCT481l8
aIKVy5/Q7QOUj0WHekbZ1GL6QojsDqpfXYTVLpTIluFvXbCDgAHlu9Kbzm7c
WA+N3z88VI0oP7GyZGb8eoLU76b1ZiepfWplVvozlTbkFsiYD+0YQJUNB9G6
LMS2KH1P6R/EBWN4NEiXgZ+MNH1CJ3Dw8F72cedyiJcLV5K9BC5MXyhb09uO
BElX75bofiqXw7+dayifIr8drnan9uX52ht/TjIgvujB1W+p/TCRtUh6G8qA
uj23+bxtH3blM98vfvQO32v4HBZQ///mm3u0qV+NCGu5t4VF+WdqgIdZZAYD
GRUSbuRWLpQ61UT9+eswnmOuOGbBRmDc9IWC1/l4+Gl5gPtHKt+Cdn6b936G
sdl9ToIzB+IDgwl65Z3YYu+Kn2wOfsn0Tbh9bYTc+d1aK8QpPm5SyrLT/Ixg
08I3RZPUeQxGsP1tEuAZsjpT3Jqaz9gUJfuLxVj27aB9KeWToee2CD9/3YR5
Mi+TF+pz8OqQKHc3df9xrICSyWdfkFryqmdorBq37+Qb+if2Y9tezru3RTT0
kA5nbWUo3p96tPlUUDXMnUxPF+ay0acoIZPwrAEiX4OuWZAUj3znEk/n0LHL
ZTpVSpni+c2fi89/q4fD1nHPDk0OGCksJV32SzT0r6x1zyCxRmJ9U/m9VpTT
qhMvkWyMdgTWOwwzEF7rS+ym/GX5/v3BR8DADdNmY3EvDgarvYI777Mwbmyk
dz6Mixqm3bVA3lwoaK9cb0P5wN/NfbqTQ58Q3+efxuUSGF0/euXJAAMWvFd7
z99no+nAHqFSsyJ0jnFFHgtT8xe1feKhWTkqNNMCRXIIbNr7dm1FWzPWlPGK
7U+i+tNntikx9BOK5wx1Eno4yNCVtXwm24ielfqrV/wk8DJVIt2Qyoslubo/
5T2J+mT5WLuZL3BqbSTY1P1Vyd1P3reegRdlebMXC6l9LVssP1C3Eqve61R6
XSRBn0n54zPJhPvG2aVndIZwOlh8wz3jagQt86C3rqZ8buaVhM+eatiuTXs6
asrGP7P2UrsFrThBSxiTriPhuSJW1AIfEPPf2qsK0QSm6YsZT0s+Yr9qiL1B
MMVzu461i3SzIVHtyfdJisTpH2Pjd+IzsOZdWuQ4ta/ypB7IUD60ChNTBjfV
qf7NWX1h7dTZVnB2OySfWECAfezVRKFQKUb+kHqWdwjMLQp2Sd6YhlQhs/ap
WOq+dbvm3pYlI9L/n8I+ik9jRw0N724ugGbZaFrLXRKDHvNeRhrm41OjekIW
1a9NrhVRsaaPYe9aZthC/b5FY9pBv6kJrMZE60UWJHrqC/JPbqvGjLzLIots
Dm5sFUyYuN+NAy+K98qtacNbeu3F3+HVcGb43PR/Q0LK7qef9U4aHIwSa+xE
OdhH+niMXmnG4wkFjd6XJMCwu3fYsh1dGweazQ5wUBxjnvBwXweyjpyyU/jX
h+yQdEFxmwZUWei2PaklIKI5pJfV0gbtxP8a33hxoayz+c+7bx0YY8oIhlR/
xaDKktZn2rm46aNW4POchNBwKO/40yakel8sTbvCha2jza6Ne/Oww7j6yf2P
JKazZl7uOVGBa+LZkzM51Dx2xa6LTnyEq+8Ehjb5kOgrDIkeFynGQRWCVeJM
wP6rhofU/EbcNTeMn/bhgDY+IbJ0yh/HK/Y6njlKYkX6w3nhETRYWnMlpqn9
QulT5U2Hr62QUH2j80ZqAKUn3j0RcGtAdMafEV0JEuluwltk11Wh0DHM9E4x
G8FzfvxLt9eBYxmwYGsPtd91XhAj/Bqg8Es8du7QAPQvntU4xyqAyvw0z4gT
JETif0eO6teiKvHb36VebKgOrla8ptQMjfOD/FJbOagubO9NWcfCiOmromWZ
A7gwPDOgOZcPx2Mm0i/2UPkSTB/QXWKJqfDnt0WofNW8/p3Te+YLjv2w0LH2
6sWYrEn/uDwTMpukVR1ZHGj1d//6bN8I2ybG26OUfw8pMhwlKf8ySbohMOvY
B+3ruf+tkngNP3FdpUbKd7qyrs+1BzCgltFgcUG+B6LezwUlqXmzWi/gm27K
xf8Acwkfpg==
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk0lVsfx89V5kOKupVZ45VcQ8XV0detK+NNplI411zEcjQSCQ2mMhSi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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlmk81ekbxrXJiFKULUJSpMhEIi6EMbZDw1gyhUkmEUm2bB0VadE/Ii0o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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 156->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4lOkbRkSbalYTsiOVsqHDsp1QbpWSjT3oZGOdKscabBsqiZCUlUOY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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3cglf0bxikkRTIioaIiSsOs6JKoNJARCXmzehuiIRWlSVaK8KJSJDTI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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8Vfkbxy8ho5IrS2EaS0rS2Ic2H7RYRpNdNbKXSGoKU0woNAqNdtmy
DTOSnRCydoW49l3XPd+b0jJZEgm/8/vjvM5f53Oe5/O8n8+j4HbG+jg/g8G4
Rz//f9cJfameb+6HwOJXnyXB15i2dvWOmuxAqo9FfmIJF+FpgjkN6Z2wTNrr
35zJxZaFrO7R/C6Ex756bPGNA7miRzIZ5S3wtU8NXC3Ig9/TVW5XrVqwj7lD
7kMMhbCugzULXDZqw8IC5dsoqErErBBy70aB0xWOZh8FnSqLly+tWcjYYR+T
cYdAZbdn7fK7p/BQ3lkgrkeQcuL3jVFLJeC8PSZs4U3wDHbqr95kwku02Zt5
iOBrgeYW9/t9OO9dNKk6RJAXJqDon1kKmYTfjLGWIG1slGXV3gtVi57ECi4X
ZekH/7vvWQBl1WNNes4Eyz2Vhva5LBxulrsf6k5h2POkzSX04mcHfoY/KMgn
/lk785INAW9NvcdJFO7s4xcM0SzGktTmf7SPE8TdXPy8T6sXm7T4qyb9KcQZ
TLWWsFqwsbem6th3BFIKVVz/Ajaun5IvVbIgmHujOSQ1XgaZFJvBm+8peBjt
iS91rIFzbMy9X1kEYeej2HLmw8jYstIoK4WD6z7Sq45d64P+U98MZhgPb/b/
rL1J9hlG/9YT232KQDzJQSkGfWAy3qoJy/MgbaQSfuFVK2av9KemjVCwWx+6
ksoZgonxrVHr02OoPGL6XmagEVaSAWKUJUFTX8MLQf1aqP7iU+glR3DzbANx
GhtGwZqu+wP6Y5Bf+8UtKPAFso0P+srtpUB8kvIUFJ8irs+bl6hDYHiqI+KN
cyhS7CPEMp0IOCUXbc1Hq7DzgRWnh64vpZWndS8nC4mT+39qDiZYGH3PWjHS
iUT30+IzdL8njMfC+TgvcO30C05wDa3/8OWfcGnHBMe468x7gn/8LW8u5A/D
rnftvw1MCgz1FvNsw2rM8B1NPnCYIHTVdvkHEv1Yb6dmcriWizRWpcj5kg7U
nLL0FFTkIlSPHFIzaMKT1zw1gwiC/GSV2Xv5+bi6J0h312UC6Si9LfMzbAwV
fqyqm+fign6SljOzDgLsmcJ6JoFbvMnMT+d60abgzruaSRBppvFJ9ddWGDAk
v7cDzauNd4WreA2mFwbtKlMIoqP9sudD+8Dh3/q7QiwPCa4OPHPBZlicXv+c
vYr2O5JF7ZxswGz8z1YCqQR/NMhMnGuqg0npGsnRXbSfz1Xvu492o5yZJ61G
8xHawy1YZXsRz5fuXBFyIQiped268o8OHAj6jhssTIGtNpg3EJmFNOPjUp3u
BOEjP0aLoQA1wRp+Kkdo/bqfPhuP9WHXuJ9lTAHth1OYAy8pDu4HB7QDvQi8
J6WS7k41IFl2+Xa0OoH+npGK7I3t8LKZv+AQQcG3uLpbeqYXXHHmqrReLiYU
1xl3XWPjilHC9kxDgon623NJG0egXjQq4zpPoKiZPF9a0gXf0f5HFed5EP+e
EdMx0IU7x8LTqUoCywOO1tW5I7jWEKh3KYpANCRaINy6EfJmvhv6kglE/uod
5W+vxYE1R1s/qBDofIs2mxzsx+t3S/aBWfT8U6wUrLeFYN9hx+0J9P56s4LW
BbXVIaR4j73XOdrfhWsB56IrkSb0OPQoXd+ndNeT2xRboZEBmTs5BGKlWrd8
eorxV+i4hjTNj2mWn0+xcjEYlSYargH0/5lmwuocNiyDuAWam3kQ1rPqrHd9
iaFL44/UrtL86G/bxZJ4hkRHgxu6DgQbimU/m68dxAcVZpuZ7BjOtTcO3Q5t
wymFqSNtLRQ4jE0jK4z70FF3WnVRk4IXv9e00lE2oidj47VCKKzWJcyTF7Pp
HMlOF6X1NDa8Y4SbssG/16bp4k2C9VVR7DrBAmBxQc1xL4FHT11n+UIHfJRq
F+fo/Mvb1uxvONeDkue/1BX2U9DQqi5I9aDzKtAgkFNG4f3UW+tLE/nY3HGX
78VZgguq4nXm5XkoHXIiFjRPOleKxjdJ1aPx7ERAYQyBdU6u4OXeIbikO3Sb
ZHIQ2ZsYtcepDVd+W7NJbDM9v5kzVRdutUOrbemZkQ0PLqNrri4kpUOZ+fD2
vCOtZxk17Fg+Av2s5Vu6YVxYfpC1CV37BBGHDn3ILaLrtxwJ1rQbQnz8Mn/K
OIFa5/rdeWs74S+utKN7kQuN2TOz+z8+htq4g6EvPQ9Mmt5461ePondTEm6P
CB52tovIlg3B1lTHcZvTGO58PF+4X6gPjc7XR1p0KcxojNxo7xtEkKQC7+41
Ljiel/W+f1KEwObI5ZU0XykmDTbV+ZVYISlpl7CDoFtUdVJbqAnpEoeCnzdR
+OS8UFVR3oAbPU2zKjIETgNFhW8EOvHXoqm23V4umhhuOavFamF//IePZYJ0
P/MZXSY6jTBeqFmaaaWwpVn2MoPTjT7R97Fv6f3srN86Vbd1AJFF6nxt0xRS
vklrzYXn4YTDmQ4WnUeBJ5T1oyt78E7/k4IUnb+GHIMsz9/SETxrHDHuQbDu
lonNl+EeuJllfnlVw0GGv2K11+t8iFRpjOSa0HyfLU7Sjv4XEcqLBuusaF50
TCuU4hrRbBm3EG9F369XzK3Stn44+1XCeAu9Lz7HB40mhAfAKG0QVcodg+M6
qaDPfHWwTeV8KtpJ36tpRWmRf15CfF3DmDB97yQmg2MVuloQ8IDfDXQe29oc
KdQ+34HDqjMit2n+cjG9HDvZhQdmsvbS2RRc/vscgT4W5uZ+1L1K+9tZLRxg
4/EMtmknj8YOUOj/YXj/em8WEuIy3Yr9CdieFWaJ/7IQbjFzt6acvqdPAnyz
WspxPTjtdLIR3b94+Y+LIr1wPqQqPljBRfTqy7q3khqh9M17RzetH/231Q/6
29sw6OghS3FpP0TKdhk5lmD3GN+GenOCljLlzx78w3BYuuCRKkF/P2fd4ri1
AZarQ9RWTBEEkCgWEe8E/9ebteF+POQ89ClykmsHe+n2xullCk3Jlmn53G6M
OQ4O8u3lYZvKjI1kQSck1b1zCul8YYi4ig40JuBTvtDCXXp/S1xmXO5qV2P3
l8j9zEkK/wNWtLdd
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk41Wkbx71lkDmFhkx2KhpDRNL+VYYSqUzqqGPsOiFJlhZkeE22kWQZ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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 157->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lWkblmJkssQkI5WKqSRL9TXV0NUoKkJjfJISypZdmVIMIusnqZDG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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VO0bxpUWeZW1hSQl8RZF2ZJcekkqsrRQyRJZIioqSaWSPRSpRNFG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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81VkYxm81SRMliats0RQVGYkW5klZWmQfJYrI2CWyZFK2GtMyRPYs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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4ltkbRhSJScnSGGWPTGOym1/dFIZqZCdRsqRkiRgMKflqypgsCRlU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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 158->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkbV0OolESlbGVtUUoNk+XnI1IpKoUce8JBmDRUhoNMlijmqzGN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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c81fsfx4UkaZBEVEIqIyqVhJdKGSEtK6NBaFhJMoqyc0tGJIpCUley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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8VPsfxicJtwW3uKks5ZYlXbqFVPTYrjWlZInIpXUoW4tsqSSh+REh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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4lVkDt5QtwhTGOlIkS9aK0M9SlqL6zIQsZewaWyGyxCjKkiTja7OG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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 159->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs8lXccxzG0qCSSooW1htpcUq1lfcgmZMhIzXCSynSUcimKUnIJJdFh
hXKpU8itKcn9uM3tOOe4U+j3nJUKuZRZst/+eF7P63k9z+v7fL/fz/vz+Wm6
H7M/KCUhIXGdXv/f9bL23IjbJsAe9urW0ToCXhb3uEddFTKTyfkVvgQvz2sF
hcg/Rnq4X4OmF4FPiNwD5821sLs/aGkcRmBUMLx4djgWUtNqH464EQS0v73v
v12AFkeh2+5HBBJ+26VVQ69h5tR2lzj6vsZhgfR2RQHuv2Nv628iePJle4YN
vwN9DXeU30gx+LzCeYXkxSqs1LiWIR9IsOebqGW270V4E6mzuOgNwezUX/NX
CjrxW2b/+O0FDO53/JBT6NmNENt7F45MEkyk7bw6VFEPA8NfeK+CCYTGX3iw
0IecbZtFiekM3szrvTbedBu8SbW871gEkRpbbln4VMF1WdBUij+Bw6zO1kUn
RBAtOusTI8PAbpec1IxmCLjhOamg/Se+YHUdi+HBtcNt08oAgszwivBFpR3w
WltuPd5B8FDymtOz4DrsWX9e/PYsQd2yeNlfsxqh/8FiQOUaQZqHLKuuph2T
spK6I68JNlSPyhhn8GHnoZFgVE9wem42Oja9Hw/5f4xfcGZgpTfNOZBG62uY
dh6i8/9m0zJgO1CA9WI3f3kPAkHTnTELNRHEQ0P1zoME3HcqXweNlyDhm0P5
SkcIxuzYfmcN+JDNdMy+UkBw/9JGw213O2C+0SDlr/dUn8lOtUKPFOxJPxi3
gu7D+KWNmUlmNVyq9h4LOkUgXc1N1dTMxqBil0HqfgKTMP1gh40XcKbBZ8yS
7kN1bqwwpb4XnSEXbasOMrjVb53ncLYHewyb/VQtGJhMf6N2MDoP0V4NHEfa
r0/94U0n7LNw2TIbM/R/XCY5qWVVOU5Vtp/be5TWX3kpuZlbjhuzeZac45S/
17LDGd7N2KEkNLG/ScC/bLYlSfEh3BsTs8oPEgy7xho8D++G3V5T5eXuDGac
v3u+L5GHIdNKz5LTBOELdQ1CjlVCvWr2+G6qV2f0jRazFBGUrX3Djr6jvHex
jFYFNsE6Y1T5hzT6/w9XLZ03dUJiSNZ2Od2Pvaf4osuX3XgecmG4mOoRnT7Y
Jx/bA99rc6e6/BiMR9q7+D1uxWjWo5aOW5SHP4NzXZk+qHMTl8VEMwj+kHA5
0PspXMPmzR97Ezy2W/vP+qNC2Ooax3/sJ7j5k+1ViaZaiOLNb19NIJhpM/7q
iX0fprKTj3zMZ8A96MNqvJuDUqkhzXh3AqnB6ZP6aT34u1/pFo/DwDj2ATta
tRl5C/PVN9wjOHGzOGW6ux05n7qum48SnDMK93ZJ4MPEI+D3k0KCMyMf4zUv
1GOoRdQYFEMQY9p19++fRJjIClTO20DrDcxvsa/pQfFdvvDOJ8pzAJuRedWA
PK8DToZZlJfqm0HHTbKw2t+0SorywH9ttTGxNRrG3o5yLMpDnBtX/oAwE89e
FEV1/s+T9s4Rg30tCAmwvscqJLCLUhr7t1CEi1PvWe4M5Xn/2Ybi3H64uy0W
KciLUXxJ9fDWX0QonZjOENM8WHLSQD+stAk2c/4XZ1MIPKTvjgtmOjHbGM/o
thD4dm8MeRfVgx0xnBfs3QyMBP3r8uJ74bdDc66RxSCVdbIiVYWPjlexS9jZ
lIeizbsEG2ux/Rk/VCOCYJX+SgUf+07Mm6ulymky2LtbpF/96QlcW8NOx9K8
a+gquRrh1o7edpvef3l0/sEj6/7UuQOZV/wN/nT+/L/ZdRoVtRi1vOmfc55g
0KJbRrUtE0Z63lvG6fwLd+5fVHaxEs/V55o3naT1Ck4IhGf+Ak+34aN2IkGy
8Nsalm03Wl64Fn4ZQP1j6P9ygzkfMQUcJzHNz6Xi2+qKRvmoHepNv3+A+n3y
HlNa2Ql1h12OV3QY5LtYW+uNPsXJGN231sdof1tlHU2dWsAUWeWzKI8jnkln
ZOU7oFX/q/vrDwTulaeV1h/tgc3bLwwip+j3CToPhjOdsNtQQdKA6mcVIbuo
9UY31pRUxEi4UL5nirVUcqvhlREh3EXz2KLEuLI7ugpLyvzP1lA/NY/NZk8L
RNAdH187NUPztP2E9mcTPLyUcVIJjaZ5/Y4z4/B5F1p/bcsKW0rrTXF8mgaK
cehp+0KxJ0HCz/MtYUI+pvUPT2tUELAiG06LU5PAVtXz6KT95PS8+ULJWIgR
Qe/ChZIMpK2WD93Lbka2QbR7GuX31oRepTCxERo9fVyb6wTa+z8d8mEXIs7p
39oQmg8/bihvam+pRy9/4Nt+qrdcYGa1+KEIZoXxeavnCZ5+L5GuTp7BruTt
Od3VYvC88riBUt2Y1W4980KFQcjv7YasuSrc5KyV+5nmyecjkuoztqVwawjj
pP5OEBS+s5ZX1IvBr7a9zN9H/fNGu9wgNBYj637wZdP+65NypJW1uqF+RaO7
Yg2DV2Ur08KKeDDbHeqaTPc5cadlICahAQ4c2/H31P/avlfbohpbIZl9afAZ
5bVnoLI2eq4ZnmVRRRP0eU6ig2du14XxiS7fPyQYqOgriV3+EEKqL9hqJ/W7
RdRE/d7P/sSZgFWKeTRvRaqurIHLbdBKfjSpkEvAVktfIWFZiaRnFd6nfah+
k0LF1iXl6Pj29vtQyg8jI6+R/fMAfFh9ztmlDKol+GyFFAEytJ7LzzbSff+j
VW7tWAvP6DB7P3q+Lo0LZTk/bsN5hcKHZbS/pPkedo9UFT6+9q+/Qs8P1tb9
a0yrC7CuOXd+AdXDIjBPZ6llKbzkecPXqL/q1NIPxVg1QLKtquoenT98WDfi
woIaPGiO6Gqk+5E+rJhj5twIVR9WiUocPS9i3HPrNvOQ/+P3H59HEeh6RRZt
Hs/HVwr2el7UH5Gh27auudKFGB2WY4EdA9Un05IeeVxU8sZqh6lfa8riJbUc
+6GsdF20WMDAIyiXA0MBHH6ytHwyROd7mZK1j/r9N0Hygh1PCE7JfB0wLFmE
SFnzwBm6T9X1c1PBctngcYzOpdM8PnU7t+zRUy6WctLEXbR+xKP3HdomnUjn
KuwyW87gP7qk2dA=
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2kgVA0XlijKTio7Za2IUoo8XhFJWlAqW0SWkkRUSEV2JRWplFASGqNU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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8lWkbx6UMWVJNtsk2LfY4k0lK48e06ShbipGlolKR7PXmpYZGllfq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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk41OsbxlWiRYU6KpGOkS0VR6ks3ZLsR5aQhEKWFlosOaEp0yGFjoSk
CGXLkj2VI4aRdWbS2IeZ7zdpcXJsR1r8vr8/3uv9532v636f5/7cz/urR4Dd
iYUiIiJJ1Pr/rrqtdGNsMhc1tVk3sjWEEP3sTScfNaPDzr0pQpFE7t6cvfIv
yzGWdLYw0JfEaZnGG89UeChqnnhpm09Cp/Nr+mAMD/liimaD+ULYSAf1mS94
i1mGpr+2tgAfW2jS+epPYBgpFn/tKIlDP+uPbeBnofDut4tXrEh8LcqR6S5l
QcI+oEPdgIRZvUuf1okurFbO/lu0V4AdYnL8WvM3mFiWyH8RKMSYmo+Lwepu
LG+8p/7ukwC6gQ4uTPYQwqrf24WbDSDxo6VyJJ0LkfIVV0f5QuwOXGVffKQT
Sxy0o+aNCcj515KqVVx4GIxIuMsLYfYgIkV80XMYPOpv0NIiMT5uWui8qwP0
8IKjIToERHf3iSgIq7CT0V18KJTE1M3xyZ1trTj6Nc+9sIlA1765I2Ih/Rj1
vaF7bKcAxwYi++7nxqLG62lm23ESzZljm3idDcju3B8SmESAHkeTaimKxQLb
M7Ot7iQapo/HTkW8gauihX3MEIGM8JySJ/EVmAg5H8bZQmLOOt4y6h4b5b3e
1TNpBAKjlPcyzzVCW9A4tJ1BQtc5dJ2TJx+z2SoxJs8EaGwVuyKt2AvrinMp
TLoQbJ+Xa7cH9qOninVksGMINklL9CMPd4OhXNUZOSdAERxf/aHajXeqh7P2
Ogix4muf7oOtAyAmwnaEcgSo3Woq7VbLhBkvurLFjcSAVgXtYX8zpBdMms52
EqgazMlpvtcGq859fPUTJIwOvme/62xHerlo3aOFJJiXsoJ1NneAy94d3XKR
gIdbUs+UIheBrf70TwICEs8inj70rUNxw8K3ddT5iReHRO7UcGEzpSEbcF6I
klP/BYucKMGIx6mDv2iTuCg+VOv3y2PUXW3r2nOBhN3quUcPlw/g7veWYLof
Hz+D71Wr3O2Hn0um6cmDBAyZx8xal9yHcCb1ZRylb19Nf9wWTw7+6nANl7Eg
oMxOzl1fmYjHP6U2fzpMIvFoiMaRfh52QHNxVAYf9EdW0nIX2jCTtsAgNZBA
HU1GdNQ7Af9UuL9Tpfq7YvvHbSZmveCpsVSK7g/jxx4/y3+1mmBl7ixWaUjC
Pvb0jbSrfVimXJJ3h7rv6aUcQ5zvQ+X8livFKiRoQSGnFhoMQOTchiaJ20Io
Rq/Mazw+iG28eBb9Hz7CMl6ZrjvYBE1WcbltP4GEoX7WoDQXFYz7zDviBEiN
qV0izxpxQMOr8H4vAaeAyc8bd/Vg2cEz38NqhTCweDubcLUVCelJBrvTCegW
ypo6G3Hw74LksBKhEPXpXn8sjumDfyit/AdnALKpfi6KMxzkuuYZrTUUYtIk
13Lamo8iRp2rA5MPjakLIwVZLEiqJahqHSJRZFtQ2nq5HT49T3LGdpAoX/rw
Fl/rOQITI7IeeJLYdPirymnpLmgKzGjH91F8+9BSGZ49EBUc3xAo4CP/omXV
ycJOpPIDNgxS7xnXT5+kudBRad390t2VhMgXNfFj8WwUTYi+PxcuxEfLBIXE
dg5OvfeqPVBGYnhxnPBkZie0Q/Qqb8cJcfpSZlpYKB9xehyXyrhhSLL+FA3K
bEGubu9+vhaVT3k5if/o1yOsO2QPvZYA0+E/cd6PZtjpLJwjJAmY1phIyvpz
kZgx7LZDT4i97MciYlYNmLWQHciPp/R0tqQ8Xl6NV+dc3xs6kAi7UfDmgkIT
wm+GWrK2kShYo+ZBl+zAGZ8K9fWTBNbNRct4lLZiAU94SV2SRMYSzThd83ak
1pR9cZIgIGP+jvbLf/0oLxlerNw7jGClmniFXb2wcdkaeDh5GJ/PfnnXTfHe
Oq3wJKiFwNF47+QvhxrgkD2N5VwCVn9MW6+81YEoub4AXSofvEe5ev48LhTZ
ZbMRNwnMOq81+/36czyQSRl8JEXizxdBe9+e4kLvXMzTFZeHkeltfLm3ogW6
sx5KiQUE7N97DNk79eH1p+pZbYYQSRzvWKFyGRj1Fl4MkGB/6NFb0cGFRaCS
bNl+Ao7eYbdk777G+SGjO7ezCWimr/dtetKD83usfzCo/PBab/TZUroTPt9f
y8TJkFDt1X5j+JyFZXIaUspU/Ut2tuR+V+9Hmu1112zaMMaHU/LzLHJxZPfp
tXlUfTddS7WNvFCMvhGeX6kTCUl5E/49nTy07FhM/G5K6XmqzQ3NyIdoC5zH
LUic/S6npD/zCtdqjHdeofSmdAkKJbfXQkY8PLgniESbyIFRMUYLnlr5Cmbb
CfR/cTISlebBbZWfylinADddIn3WlrOwYTXdWcqSBCNqartmeSlO9JUupVF+
r7ZxZOt8YuFitK9tKMWTfb2bq+3OJsg0KkicXURinaefY+O/ZXAb+q1DnvK7
fjJh1x7MQ4J4QbnnpADr3HvF7eQpv8XyVRxXkvBZM2IT8nsXmKxwKY8PFB9Z
baq7NlWCsXGUNk35af5AUKlAiwvmpwy1zxso/1swRqrks5D5YYw8Q83T8djq
O0uvv4bR7kWFxo9JZPb9tnCqiQMiRJ8urkiAv8YtLTT6DdjLUjb62BHI3Myp
1vDg4q5b7cr9DUIccjedibzZhZUeD+7PfxPAQeGUjA2nB/N/OS6Np3iciuW3
2jfUw3zmeummbwR8mu961RiyoVQxXZn2ncCSuMPzrLRqFFW7LvpbgUTXGtpL
qdtcnDS67W0URYD1tNqTGcfBooq2sXvuBHINzQO665mo0y/3jKfm20QJe7iM
yhNO8da/OL+R+Jhw+U1tzAv87ShqYvSFQPRMilO1fzdGHsx7JhUIYGgyY2/9
ay8SRo11bgwKIdlw6da6h12IGZkefuYnhPHxjErdkFdwjxJftfkDAZttOZv3
SzyGnCivPNmHxKj8x9KOmkJ8a78QYeVMwlct/4D8ZBuSrue4ua6ieGVKvJKQ
b8eSn+7tSmeFCIgXM5VqewLFudgTy41J0F3pJ8umuJiy6j+TuUUIq+2z2XL1
dVAy29Ifs5r6L8Wv10u93Q2PbqvVxUFC/A9NR7sc
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 160->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwdVnk41dkftrRKmzEUk1R3JEWRJNIrUVqUlt8kjAohVwiF7C2kLplI0Shl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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8Vf8fRrLKiiQVoqSS6Gs0PaRIKCupKClSCWVVZBRtQiFbQoi69mjY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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx5FRSSXZShmllG2YSoziYwkpkZKtSAgNgwaln2KiaaRCpCHZ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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk81PkbH5aStnVUdJAjOlA/lVRW3otcoYOpiIiMVc7IsZRjaStJl9q2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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 161->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkbPzP5pLEbMmTJklD2aUZSv/Kl7UMIUZFsUUeEaOyh0CYl+WQp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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8lWsXxqmTJFQi6pSxlAoNjgyHy0ylQgpRhohCKY4UChEimQrRoEEq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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk4ldkfl6GkBZWlKGZ+FIZRMeOS6YPIboiRaKxZUmPvZuxqpsVWkbok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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk8lekbxo1RCdPY2iyDoYVKxpSGcB1MyBKlorJNyFqdUMNIKiohSdbS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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 162->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lukbpWQpSraRllGpSQwlSvJzGhqprIWJ6ovQEMVnihpCJVmyZi9L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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VPsfx0VXuYlSlkjWUqKNK1u9EWGSKGkhlShaCEVJXVmKIkKFK1c3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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlWk8lWsXxlVS6SRDRFIypsEQRaJLRYhkqPOWpJJE5mifDBlCSYPK1iGb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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81O0axlWUpZAk4Y3ozRJ6kxZLrpK1RRhrIaRI0liSSiVyqCjJSB2J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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 163->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkb10R2UcOoiNTM+ChLCo3qhzYzpFTSyBRCilGIIpcOZYuyJMkS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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VG8bnpAUSSL0QyVJkTbtcouUFpIkIVkKSaEoJCRbGyoJRZKy75Ls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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVmk81WkYvVkiYSyVFkkqIZRGZUqOGQ130IyQJRHGHoaGMlFIFDKFkkyy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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk4lekbtpU0MpYaWxsaMRHZj8pdQiqjg2xnJkJFStYOadVmSZSJyJST
VCpZj8iWNTsHx7HLOd+XiCZRzZmfyu/rj/d6r/d63ut63vt57vt+XjXvQMdD
YiIiIinU+rGr8u0Kdpu1wWBXnzv5L4FEm5jGHe/Y4Mg9XRxoR6JSIUkU6Tyc
yNH8O7GAQMrU7wpe+2qQPe81Vy9C4q3jGe8qUR5usz77WxnzwXKQ23ZAIRNK
l4fCXu4k0a9lZHHtUAXsV7aXOPuRUD/06mmgTCUcOx/sEU8ikf7RYWhX1jAy
1Wc9Q8T4yEiNyX9jOgrB8Zeh6Rtfoz+GrfnT3XIIXb/EbiAIyA9rPvSy70V1
suol8SEBJMxVE/m8XjRcKnlFMxNAP5cnUT/ThJQAk49GiiQiuE20vd3N4Iw2
x7R5Ezi/OvFDwbgfPpG3RvU8SVT8d/fDs5Ym2I6tnwv2F2AsoarHbP4ZhrKd
k8NcSOwTG449L+TAa/hKqU0NibRav8Pce50w+Lon/+wrEmyJrzkJt9uwjzZ7
aXMxAfHIh3ttTwzCz2aJr1wKgdQV1kk9UQXY+usAEWtNwjdm6eo7j3mwPj/7
uWgtCa1UgwXvzb2QZmh1MU/xcVrZLNZOsRtViW4iR+IF0GwPZYkENuLXwHmm
XAyBCGYFq1G2BvWn2CnxYiQuFS72Feq/QItLX7w7ncSnSh/tYZsyzL4W/6/p
IImvu725pWvKwBw3DiHDqHrk04XkpiYwGzf/eX09AU7E/qWvfUqwsV/3soIG
iXLmfRlxKR7oq7abffd5g7KAydsaBwYgFiDtcsZSANLvlNtpox6qr08vkmMC
mNgc3VDvNALNOGaF5PpRmK2KfdHzlo294q3DtutIfNtwI3S/fTeeC+ddA/RI
uFslXfWn8stsTje+H0xgCY1nt1SjEv+4nDPNNSehYx0UyDBog9u38bqFlVR8
08ufXbO6kRG4yP7hIgKxjv2Jc4V9iDyRyva5SMCtyNo9L4qNVfLblxsfI+Gf
94CZ3d4Fq2+GdT85EWhvTlBhrB/AFdVTYWbvCJD1/o9VLLqweOcaD88AAnSr
g5qeVm24ddRykc8CgSAWLaPQvBQK9qMmA14kDpSFhOtkZsDurWzOCR8Sbd8d
FkQlW2F1poJbTvG7EfX8KP0+aJ71ODbwkICQFtRx8tZzyMsKac5aJM6bF0kx
5K5jxjyO+bc7Cbr4xiDHbd2YVvW4ar2PxHTk7jdm1HmcmeUSsp7EYRt8C2H1
QSZ7h8zPywnoVa9oWhgqQ4+2x4V2QwqfpnTp7Toe4NjjJ8fiY1tT7bp0u0ao
hRbcvNBGYMLvfHK0NAcW959uK1gQ4JWyU60/rx+ya7tcN1Pvs3/zWO7cynYE
qpYxfcIJVB9O+aPvAhuML8LGxcYkJkRJd7nIW0BvhCWb0ofkx9Egv7w+2Dts
53Q7UP1gLtWtiyrB4H2bq4so/pbSau5VanORGK3DaZkhMPa/tlnaaBYGHb7n
KFB8tDVcfDN1cQO0ZD/Kz+mSGBPbsnDj/kPYnx2esHal6hGtY7opIhNL7tV+
FR6i8sf7Bl6OLYGJw5qLYb+RUAvSjRiOb0ZxdMSNRxZUvq25EdHxbLh88N/n
QOHNCW/y04wdxMhdxYyyXWNYq87lNGztRsrJ/ifFznxczU4NYi4bRELt6lae
Bh/5k8xqVkEfSgP4DV9zx8CaqQ7ZodeD24rKWklbBOD43Gi4VpKFqtK9R4/t
IbFB+OhUbiYXt8Pi2GoiBJJomjT2s26wJE7OjWcJkP3C8MqWGS46vJ0SOii+
0iX0xMw7H0LFOTztTCCJ3GobX59aHvL0hW4blQXI9zJK9DIuBN1/QLhzKwkR
09NhIS+6oHT3o6/MaQEYy8Yrmh93wXPTHm5HhgAHZwZ/JUq4yGsoX247xcdE
69Xite+bkBvqVOjbKIDska1W0aFZCGsTzTvvS0L2zkeD0PBH+CnHa363N4mZ
S65HEv96goTAp/hgSUJ3lRSNocxFkAmRbmhFYpNcnYqOfhVOF5xUTXYiMahv
81brTC+Y/fTquhFKj47ahbHWlSj+/Fw0geJ/UPf1dsXwe7BKD8l8SvE59ZTC
1FQXBx5Tly+HWxMIjLWQ64vLhza9JmXHZSoeGh08oFUJLaXWLA7Vv+tBaTzm
u27kHCwxWTIiQEt9tGkkh4eXfuorIqMFWOf+QmPyGA9ctfTS43+M4Vlanm6Z
2yj2Z2h07qP0Jm80sCU+PB9Nn+0UNSi8M/mSP2f/+wjtJ+X3t/zw81sWd/JG
eqDOC5jWWiPAtpaj75VLMjFtQA9eTd233P7IMLS4Bp/juNMW1DwZ6zV43/L9
CSwZSyVv7iIh3RY++mGqHx1zGV9oGgRK9ygarhwqgviUPqvmB//cjh6HZDtY
kdrCiy8I3GQo7VzqPYJs8RPeEUve4E5yltU/L3sw+Yz3pFaV6t9cqrNgvA3D
9PQjC2wB4vkzCbah/WDkt2jp3KT0lLLtSttcMTQ4J4uzJyg/i5nYKe05CJ0j
w75p7WMQYbbHPPjrAfzHjZu9KPylteu26D9owZrJ7damspQ/eJj2+KztRtbu
uGTHT3yYNAUPzZ5tgnaa7iMnNQIiN689G9etxnj+H3oqtQQOLtPf/9f7Ivy7
nOtUvZ2qx+fJ5yKaI8i0/kSs4g7BzLhTS8q+CPTV46LqOpRe55U6ypTYCJJh
TC7/hcSfe9KTAop4aLq1I8A6ng8JjbNph+qa4dvjsYKQIrBOjVbYNV2PBxN5
nvQtBBx16F+E3lxsjbdc0iBP1TuEVfiuNAeh/3Ndy6X+A9cSE+0yr3VD9rWE
d/OoAL8V9M/2qAzAJaX1QGKVABHORSWbGI9RrnzuuoktiV+WEeXPJSl/i2cd
nowl8Cn4xDej6V6I9a+44Pq3AL/XnyNsO3ohqf78e0DlGJRurPNq5mWCmWpa
TFJ6qL4jpXmcUQKvT1FSpvrUPP9z8PvUPAd6MV0lfrXUPD0WzLEOa4WTdGfc
D38TqU30IBf5IHrRXsYqil+ByzS7orQ6EHdD5WLyAqWP5VH6RseqYHW4rcEr
mPIzuxVJqWqdKP86Zh5UIcD/Ad4Bqtc=
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 164->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs4ldkXx91HSkm5TQhFNUmFSsJXZSQZuaT7oOMkSiKSTEWjIt04IbdB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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lf0fxlVGg5JNVoUkJMmIXGRLWiIVpUQ86pGGIqWyKmQ0pEFkz+y9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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lOsbxh1K2uRkyhJlz0mp5FQcXJVCGyWRaLF1RIpSlpOSyDaWkC1l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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk8lfkXNiFp0k+MSGpIIyF7SYznWgqFIiSKW5YxUcpIKDFMjF0qjH3C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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 165->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8llkfxlFhGKQREhIlTU9aJEujS5SlkbGMFpKlNEymlEi9tpFRGUS2
IaTGHpGlqOy7sjw8Dw+pN5wbWUZUwoT3vH/cn/uPc59zn991Xb/vORudL1i5
CPDx8cXR5//vR8JpbL87bJirLeSJthOw4uS3F4vWICA/vn29J0GHjd3zn3R6
EDpobqZuzGBeQyDmbmgJ3i5uurHRhSDT2UJEWestXF841X6UHAbX1IntKt+D
y89+FuvYzaBYbuD5urU8sCTVeRYiDAbbJj+WbOmF4tAq3c8hDCJZCV0aZmzo
vhn9+58ugqYhnuBPOa2wUo7Z2lhEwDv+Y9nWMA6ORvSJvZRlYHf3Qj/7AgfN
57qqGgUY+B988mz0WDf4F8w2x25kIFDFLg6W6YLmtVjnF5MEJGeF7SrbFmz7
aWplSgqBdLDHH9bqLZAQ1ry+/S6BEmt+T+VUJfLuPSqSv0gwu8iSri7uwOTi
081FbQTyp7RO1a7koXS3gsxadQZxi6Yx7xs4cBqRmrz0mSDY13P/+HQ1oHfj
vY03wbe/eMieqKgCK8Umw+QCQYpL6dCyURfS7R6V4T1B52hFydAYB7ZSgRLf
LBHMvQ/nL3DkIGDVBqlgfgbHZ0VmjTb3Qa5FW2PqAoOAyvVKE685CCr5cfzI
HIFF98bJq61cPArlhJl/IciSS3U5tJyDv04WDTs5EyyZOnMMFZuQFXFv1dlA
gn8Vf/d7E92NkAip+I3bGOj7nEjaXnMLkj90L9s6ENyRzD1RtMRFO/9Af8Um
BquTdhrdny5Fmop01LvfCCzzGnyl33WDr0nMrPJnBsLyvNtj+2qgt0duNugK
wZrTwcJJ5jxwz19aVljBwJdXmMAp6IX+8XaZspMMuDKs91caOyA8fO2h91MC
k/Osg4bLTdhb2Lj9fiJBld1rpQKzLERkWj2/5ETzZ3R/7zPDTphcuflr7yiB
uoZ9bn4fG+KJIRmhNQT6fecD2F7VOKQlV2XqRaDNOiLkbNiPaIP13UdTGfyV
7CGoUtaFoM1VS1EDBB5PRc1mMtOwT+7+E+JI86D9A+fd7Wrwj7cq59H9Jwd1
KAUGcTHYHc04/UPgqhDhYhdXjEQ3URnxX6i+IZYpwerdCJtxizw3QtB/bqRZ
7lotkmr9b27xJbgc3iXirdoEsaNjzmdvEtT1ZudpPalHm97C1fNXCY5Xqwe7
GnMwPqixN3SYwGj8eljXu1bwba+0MaF6BHI/fV6TEAQhXbM5E+qHjvF3ny0E
uXisPJfc8B0DefsEQwXfGsSYa7x18iMIkxZt1FXuwpWz6+ozq+j88i92xq97
MMQe/G+FGYNLAce9kw+nI0aT56dO9Yz6IF9rMtWMYa82xSt3CMa+WtinB3ah
b37Jz2KRwL2iqXWIvwUJFo87oxNoPUbbvgiseQk1Pus2l1QCPtOHrmb9tfCe
Fs90o/lOmsrOyNvAwab0fy9f/YYB+fOkX3VbF1wWvaJWCjJYGn1tLnSzFxU9
NztjrRnIjqocODD6ANdnOqOKqP5LnBiVPdxmHPISMR2/TfshaJ+k8G9cpPkK
bXFgMZjYtfOzXslD6E3MHzCleY4ZbvtDK5CNqNXxC2tnCT7MmUysMYtCTE73
gj/VS7hkPLnKsAQh943Fw6lfiYNs268iXAT9IibiVk+Q3qPU1tPARXWZsJua
IYPSnLbcGdd4qN2ayC+k8x3lZ271Nb1AyMyZpFzKu9vr3XesW1sHs/yG/mwf
gk+cDT6nbzRjvj/HOiKeoG+nqv62lFeYcrZT2kD5VGFgo6la3oFPzjvl/Sup
XnKHtp2WvA9id+edM61Xtql9KJVpx0kLd/t7DTSPZyVsd2c/RtvzW7sjz1C+
jW9qj1JtRcTHifRQul7/qIW1c3IBago7BFh0fFqw3qwujQ3e6cBP348RjH5K
rZ5f14E9se57FOj/VmsdY1Vv4mD0zMVHnRN0fXsf+0i5Urgaha4scKP7y1ed
NDzRg2lLS6aF+lVln2ASHF4GzQMK/KO/Uv3m1kpGrGuBcGd0o+V1yjt+62EL
+xZ8+2/OBS7N818iR7IyTV7h1OI2n9EMgrT9Dx7YqqVgKeBD2j5an5DqgM6u
4GrU1l/e+oz2Y5Puh5zZxZfg3PDqbkoiyPWULFP27UBiv1mfWC/tp5hyrxeF
5SAGzueV3Ck/X+3Q1A99iToxvVq3CMrnoevqB0tpfSOhcXXVlI9x5te+tcrE
8HeHsZPm+cmYYOD4PAdPuVvChLYymEkybp5T58FUaVK1dIrAQNDg179fdkM2
8B8pTzsG4lISSxY1PQgZY+ztNRis0Yz8O0OJjbyU5rEcyhMLo7Q3JsP5GPE5
y3iepv0fkdud11yAVgkbzXCqf5JGmkx5eA+u37Y88pHymuWZ8aFwezN0lvft
/0z3G+BzWUolhI3S+JORbyjfsyqOiAS0F2HBQF9RgM4vHXPDoT+b8MmjNU2U
fs/7fkvkydXPcWOHPJ8K5at2s9nDWDxF4plKVT5XAv89InpHS9lQeLWB7Ufz
kJUeoxU/UAbV/0goZ1O/piRLUg5cqkbhziO3r9Hz6tTAQk3+w154bV1OLLVh
MGBc11/q0I3KU7q7fhNn8K5zv/ecbyoMLl7U/5H6ZbRixb0lgUZM+CQIz0YS
mIYXyI7QPJkc1dbPLKF+2xsLOUo2I2S92s93aN7VZB7kNDm1wTZzd82xYoLD
EzPl49q1aNvk7p9N+XdQ0C41en0TDH64PLg/jiDEI9bBLp4Lt29mRpo20PPi
g/4anbEeOHZ3fPX2ZjA3dE5CpZeHt7+LH604Qf2RVz8zrfMS4wmqnvX0PPCJ
OLarZqAe1Tes/PVo//lMfr3rwDTAUTu6RzWE4FXHtDIruQuRfK/98usIrrQr
+qjHvoL3wUuHRXIoH4MMhW3WPsVj/eHVbjT/vnq6khMq9XBdEezocI3q7xoZ
Lq1QBWE16zBZyn+Pq9k7dNx42GvpsDFbkQGv47CPxrpq2Ho0xwrQPBePmxue
le5CqMHBq558DNJyGVE2zdtbwSr3lbSfsqzKMy5OUP3Vq6RXi9JxpYlT43vZ
WOB9sfovvW/8D26MvB4=
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3cglP8fN0oaorKpkPYwUkbqJdGQQsqXokRDkoQKmdkNK0mKbIrsmZHt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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41Wkfxo+l0IKRFDNZqlOKtMzIkrpVyNaJGea1ZVeWFkOzpDkSMoqM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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4ltkblopQCBNJZcuIlGWyxdxiLIUi+/YpRSoVrRSRJZSUpY/Gmoxq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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 166->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk81dkbxw2lKSUtlmjQlML0a1BRUh8hpcaShAxZSiFCZVpJwtyQFktK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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VH0bxoUULVRCllBEhUgkpUvSQjxR1hZJCNEibaIHeSRpkSxJRAgJ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81VkbV/ZlprwmY8kSwkiolKX4kq2EiWhEkZB9aUGlQqWNhJGylKVL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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk01WsXRq57kluIuKVDkSu6ppApjylKkojMV33cVMZUhlREoZRoVp+I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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 167->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lWkfxk2nUNOUnRlLRpsOWWcSxVVGBkVNb6PJRLaUsmdNSEJ0krIU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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VP/bRoqkQkgqS5ulSCUp6rYlImQpvkmSItkSpVAqSiVZS5Lop82W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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs01Okfx61kpxCLXKJyi5KEttqK3rYo0ZYiIZVULpVGyqZJqeRWloiS
csmlixLlOq2EzOQ+7maGYmaekW0ll5YQft/fH895znPO53zO+zmf9/v10fag
7z0uKSEhcYc6/7+jONigvakBFbI7FZNfE/TeuLhMQ6Mdw4FabyMUCcqD37nd
XcxG7ewbNfV9BOdch3oNOZV4FiyMKPmdICjljrvXSDc8f0zRd/MImr6qZN3d
WwmZ+x06+boELf3M5zt21ePdyF8nIqIINNuVZ3gq3dA0euFxgQiRd3XL+gID
PqwfmbZ+sxai7571jJkfB2KPpUEz9wluslMDV05zUW6gn33ST4Tf2FGy3MAy
RBGNLPm1BL46V1/Ue3Xj0udDspZPRbDxDzWKoNXDZ07RQgsJMWh7cucF1pfA
iv193DyCQMHpql4Pvwb2nNGVy7sJCiwTQ7eMsmCekue56KIItGMyOy2/FyJQ
uC7fIZzAObV7GX0gE0kuucFPvQjMbTemSuvlYJ36VOpxJwL/3OG06ffNiOko
HFE3FSF9cMUx8Z5q0Kce8FrbqPfPX7Lk9HlYqmjXZ76SwGRuf2xZRTkmIm+r
zf9JDGfahFJpTAeyLenTT/4VghHzz0OefivSD1067f9WDE/Ftm+Kk3louWMq
u1yJoN9Xd3R+Vxt8z75ZwKgX4cio8TvdjVV4VlDSH3uJoO0/tpRhz0tofok7
jjMEjP2jzDIxD/9Yy9yY8Rch2CZUcfWNLkje9jebjf8ISaVdizqW8FHreL5n
h58AxWs1UmLfs6HYb2GvWi7COdvJ+CWCOoQtUZb69bAIxjFbfRx8WzE7obaS
kS2GlfHUDYtOLjLtFJyi64Xwizx+WtKkEXnEe8/wVxGuNKrEWRs+Bv+Xx9vk
DxHklc4OusVlQu+83x6uJ4HeMscswxI2Oj492LXmrQiJRdx5jaQQdTGRxQ6U
30rPyEXmWrVg4TxRk9mUGGVurRM6G/koK1KYLmrpwXbnyP86EurBPf+9fnip
CLfckwUuXg34ONz7qX8HgTvjWjbHoBJWdwppRobUPJ+X2haPF8HovMsEy51g
afLAYEoQF8rhwRf/OiVExKS6QpZ6BeIGGaHV1Lx0SlsOp9H5CAlz6NBRILDM
SGSMltVAC7/a9ScTDN0ZaZ5wrMJPRoEVZvcIBkJ7cgdsmsE4dSx7PIBAVsYz
yjCsE/c/mJXSNPrwat2AzOVyHvyq0t7VXeuDe6pq/FftW0hLdDxgS+m5JKT7
sI7Wovxy/deonVS/xSeSDmQ8gXpn706BK5Uvvs3hj0MPkPKpjVw4QlA09BfH
2rQFmgaj+nN6RAhfY//ULISL8H92ta2rEUIznbX4kigfX9Xa5aZXE5TUSK/V
vN8KlWDFe5/NRDBM75eWetIFFVVrN/mEXjzfsOnL1Gseji7zbVProngwfaQp
uKEWoZvVlHJPibB3kBkjfZGHwyY5V8+DwH5j9y+HSzj4EaYV0xwuxvaebc5i
3XLM93wxN3gbAe1Cl8fty9UY3adrLHOB4Lp09tGTP5WgDnscVCg9TjhksKyI
h11SN38obu8FmXo4FrukBfqrfcZ9pag87xCYnDVuRgf3IqdpnOKFtKvqpc5M
dMdx644epfTd+jlv1vshbB8v8uIcoPQU9+adUW2Ah5jtEbmBgJt0WijdzMeB
Rp1vv9f3wlxCPqQ1pxmvAl6szuQLoaW9XmZHSABC7tVVaFH+TPvhvjOuMRYn
xqViEqh+Vbm5/cq2b7GtUMnYah3Bq3Z63yLTJqxa8eOW4TcRStxzYjyKojE/
Yk+FC1V/pfjv78yyDMpPx5NdqTfR2SyttKUT5Qf83dhUfl7QXI51M7pwTaij
bZLwERJW1deiT/HAibq5P91WDJKsbPpoXw3yN49t1vuToNrBZE3hhzdwsg93
krMjeKTmzjo2wcWb18y/kw3EcBP+53i5rg5Gtf+2zbAp/zMEQXLBOeiTAD3T
jaDw0arSi5xasLxU96dT+bKcxzQqtgpHujZrC43ymwQ2GoxL30d4/uyq7VS9
5/Ysx6TIJjjczd9+gZpf4rOXNXTfamSo5p4JLhPB76HVcp/iDNh/TPVN9SNQ
2xChYpfXjsEYoWssk0B+7fHAaz1N4BcZ+hG6GBEVsSd1tlWhya6swOUR5dcl
81y0zr7DXgWbK8VLCC5HLVyjlspGUuXz0wUUn/uemrnJSXZA8v2pff4CMdLU
LVjVCpXwH7aU+UDxbVLZqOxtQBMSppt36+8WI2zIMUBDOh/m1b0GFdQ+sly+
ZquWbBISA74bLqb47PZKg9eQ2YwTzLuZ9ynePFmRnqzeWAjWYW1v52gqDzYN
UwJzNtg62T+H1Yrgal8Z7XSwE97l/DanTiGq6ucdHPiTCb88XZfOuwRs14bb
Di6dKN3qnf1lRIC+tO8tg11dqNHfnxQaJoKMYolcwYYW5HjYP2O8EOKWM81p
a2YBzu1nHdxK7Q/67nKJ2uFWDMmNx1feFMI+aqb14EgCtggtUqqdCZZvaV4h
zynEQXvag15Kb1reWEhnVzWe7R+W/oNF8TPZYZOu50swWL+sjaX8aqmn5T82
zYRowdJNjATKb6/fXA/Z+QhBEWoWblS/B2ufeT+NqES2r8TcN0UEP35z/5t1
4iWi1R7eW0b1v2ohbySQr4OXWdkaWxWKl623hqaC2nF9btOgHrU/lGmvZGJ6
X2Hq7lTUIMWbVdrrqz0CPsB6pGzr2HMBjug7xXNNuzDnhmakVKoAT87cWBjd
XoSgjJy5f6yn8mNztn+Rfx0eLzg5+iFCjCevU1OtrBpRKZex48pLgt9F8bOG
RY2gm3IeXKd4UuWzwWqS2QqjOUoOUXdEKJXh90jXNqAWqnp7vUX4llm92K6B
Cz3Fmc/Gg9Q8Cq5BT+cxFgwzG4eo//TKBr+/sq4FNHX65MYFfRh7Db2BVC5o
Acb2vXPE8Nf2/sTSb8Pn0EZv9Xgxis82H+wc7cS0pJvhAqYQiaZxS4viqhFw
xTk6wYDAuHWTQVYND1Ue3IpfN4txTs6t3mekEWEpArvmfhGax3qyTQY74WAe
euhltwCZyclKDpNv8Zz/mOtJ5ed/nyG+IA==
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk4lWkbPxktZJQYMfaomZEpElNSPwrJviVSwsnoKz5apJAlWSqjkrEU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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 168->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVn04lNkbVpSSpJQka8dXIrFKrdpy02/7oFYRv0pKiIRFlKKUlgqRj4Sl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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lO8XxiflW9EiJbTYIlGpJEV0C5W1QkVlF0kpSZtdIUpCm2wpCZF9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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs4lOkbx8ckKUQpwtJINQqFVML6OqRVpBObnLIqtqKVopYQteWQwiiV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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4lVsbxknpkMiYHIpIKkV8hoTbQUSKMuSQ0CFJRUSmBslwRNKATmgw
5IqKnQwNpozZZdt2e5vt/b5vp6KDTKeUfO/5Y13rj3Wt61nrfn7PfasdCt7n
v0hISCiTXv/ta5Om/DdlsFHPKj+V4U1gSEXGM0nyHRpfje2JihGgVFl8PDaa
B+ayALURUQE22rSs+nqTjVuNIlItXgJk/h3i+XgLE9kbmT4tySSE7mVvKZBy
AneDoqGmN4UBJyFNhzouDrP4P+aXk/g6clp+1+88ZOn3hfyZQODh4R23H8U0
o/44Oz/ckYLbdJ2VjVsdjIMLVXOOUCggW1nlY03Y3ZOh28kk0dSwvzN5SSN8
nK8yDd+ScD9spy/J6sF0svA22T3D+OukkkLYQAPSXKSTCqUoZC6ILOEnDcBO
eSRD35iPUF3hl3GebMS+h0AkgkBOwXjKN0seovlVBxWNSBTHqXBV2ppgJK04
FiJKYcXvVq9M3QoRPXpdboklBYW86B5jLgvd8gp99eUE2orSrbrsW2EqsefM
2RoSIXqC3wa+M7D7E/OEmh4FVmd8YFJNC6JDj3i59pI40ndNYeezKiycaxhw
0aWwsdatbbycBbbNziZOOgntsP7MQ9ubcCL8y2fzIhKiLxaJfbrcBatthZmT
diQ0wqNP2w89RPLKWikNTwqEekDpC+duXNxc857zLwGh/r2/KAwX4ddjpxr8
Q2j9YmLPDBpwkCVe5acmT8FC1OfuLY9EKL0/Jv6A7s/qdcN6Jr4diO0dWWRo
T4KqaD177iQHsV6H9J/ReuzcINbueqkNWzmDV/hpJEojfFEgPISK3enLz7sO
I9a+IiPoIQ9EGWHz2IUPxcTx475L2mERpenNXU1BdW7TjK3IAAZTsw4PPhqG
tM39+ANzvdgTfJYo0afrbd9ntXc7C8nH5Y56Fwvgv6NXN3n3W2Q5/3Hz7gKJ
SCKwrkSlElpDhd1uoDBs/UXvmyobUte9iPSVFHxedK7c/1ctrqj4aejKUpjI
d5F2eFKJIynjez2uUvi4794//SndKOGdsXeIFyBHwvd4lBYXFf87sn1SV4Bl
igpM0fh+iD/XUVjXK8DPCRlhcf8GuPs9MM9zoVCa6zipU81D82ABL5cvgJOA
EfGtqR5uvsNjdaMk5qln6V01jchpUf7au5gCv8DfJK//KfTeBYzPq1OonzZ/
EGqXgEjle14KvhS8NczO7l/3BpEzqWmtV0gczW71/iDUgxUyepH6IOAh7zym
sqMdjDcRZi+WU3h9Wo5fsqkbSlzexssqBNKCO9cPP2lFypeZrxei6f8Vs6TK
1TrBMAttvEHruSXNt3yuowxDC4sjngXRfDR+WGd6j4PSp5az01wCobZB06pb
e7ApZPnBs0Z8cCoMm4Z7WtCy2WdF1jcSqq6nwrUdClGnyhCSsaP5f9dZovz7
S6ilGmKLA4W2hhO9fFkGriUKqbuZU1jMrK9SKWnGI0Vj5h5rElqZ+bXqEU+w
a35q/wdaP1XzbOUguVos36V8JV+OQrU+42+BRTtGBjb0CUUTKFgma8rYw4Qy
440824CEJ+dcrJ8dDykdy1dxrQicEv8mazHJxlElb5GOXgKKq/vMnv7WBcmH
2vtC9Qn4zJ9rURt9ibGFyfpcZwpCTlNjUDJHtOMKSQOa7wkRfVXGaTa2X+vU
0XkkwHk/c/2Xuy4gUXX8/H/+5M45crE0joXbHZVeEzR/fI2zKd2t+Vj2x3eP
x4EUOJGLFP6OfwUduTvui6xpPdYnuIjIlyMw6NVaLxUKSRLP+VGfGrFaeD5M
QZWCddno28L7HBhwJMLTrOj+q3/zsDXLR4Fl4gt1el4v/HbnxOWYbph9Civu
OkrAOq/FPOxBPQ7ylxWK8knYk+7ezc970G90Y3PIjyHcWHPmQS7Vicnrz1PL
aN6qHw/uHPrBxEi1lHF+EoGNFx+mSEUPIFpTZolaJIHTSzvnf6zkYZl0UVzZ
WhJOV2vDPXOL4blbvUbHlYKLHG5L6DfAImiH4ht92p/mgl4birHBNNG5ozTF
R7LzFUvZ61x4XK40UTWn/fEe38f8IgvRYkv/rJIhUZ+sP8tSZIF5i5+7QBLQ
ilu4tFK7Cysea5Wdp/mpdHIu4jr344JVcsEAxcfFyIumoudewVfl2MdQLQpv
4+7q56R2wnrm4zMJGxIWs090TsvXQTNdcjGRR+LzaoZYqk07Gm+1ZataEnCt
CDMZC3hF+0hiim02hb62EocBOy6WqBnZNqfyIRNiVLvfkYdZcSM5bROap89L
3/PDBjC95nzqDw0+cuqLnPjFrdBOdzye10ai8YqDrASDBa2af20qLen62RRL
4FCOP0cDLssFUDC2lyPc1LgYOKN5NNSRj+jZ4KUHzGl/bbWZznKgefPr4Z3g
lsPryYaXOTTfa5pfX2cHd8Hi9Vb8EydAx4e5DP4kBwsxvlTnZxJK8y3hI1Nt
mDas2jp6kkKVU9bJXfxBMOL+TZOYF0DPiVf4U5qDZ4oOP3/IEzj/T75G/4cE
WFCtGkJeFDRi9+VyPvYi5dDTpC+ifKjm1bkfPNSDR0YZ3inVJNj3F5ld8utA
SNeFNTrBdP6O/XpO2CkDBbEjSzvp+0KXFjTnTRrh+EdU1ncdCrNe1scaT3Ih
ErMjJuEugaop3q9r57joiwuslpkgEP3Zan3FCQ7YUyE+7i4EWJJWZ7ZJlkK0
dPhq5Xo6//7XWxMlx0aymJeBKf0/IbEVvY+VwzHH47Rv+C/vGUmlniJMVPf9
lZxGn5fJ+rN9y7MxNz8QJUL7n67BNifvAA4OzrBYDOH3YMnevB0y0QntLdOD
D3XoPO8KrxhMq8KW8b12LpMkrgmsviQc6AbHVS6qexWFNzeODv/c9Q5lPiFa
z40J1N/lF4nmtaM4sSJ9JJBEKtOPtL/Qi1Wxn7NmaH+4w920PebYdSi4KTWb
HqDn95fR9QnSdJ5sviajYExBe+pTvK5jFT4U+LAc6fertr4kxQNakXTz7sH8
JhLThYW2T4saERl/iP09iMQlW4+JQdE+lH7MDDXwESB5Zs3XivvlcBLukfHQ
pvsV6DobaXUTyq8jFKdoPv4PL8OwVg==
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 169->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekbNtGk0DpSUkapVGihaaFulK1SlmPX0MmeZKpBSAgnKiKhkhRJ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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VH0bxvGUqEiUhGyVKFG0KOoiW4u0PEIUKm0Usj2UUGk1IipLQiVa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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41dkfxy2FhhmSbSIMKiNJpaYMve1kkIQWS0Q/iklDUlPJXohsEWNC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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4lekbx20xk6WNCMXRlLVJljDUt5oII7QhIlmTFkRJRMjMRKESMjmU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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 170->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4ltkblmw1mkxmDKNsYxpbKpSt3BRDxC+hqQl9pDIiTDLJ/jUqoZQl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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k0VW0bxjXLW2QIrzmEpEiSIpfKUEppQqgkDWYyVeZC6kWRZEgpswoh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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx6VCQ6NQU5JEdJNUpiyl+RBZsoSyDFHRYr1SdmXfkmgllBoq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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs8lOkbxuVMIp1YpWQr61ArlA7ay6kDYamUbHJIG21t6bQOySEkh0JO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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 171->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8lVkYx2+ytCGRSGOmrqJGiKlE9RNtM9MgpHCbabGnLKOSrTSJlCkl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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHk4VG0bHyr1pkWFJK1UikSIIj9JkhAtSPYthSShelUSsiUhqYQW+541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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk41dkfxy3l1i9ijFCpwWAshSwNJt7NUIlGjcrSoiQyxpIZS0oGWcqU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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk0ldsfxpGkQSGipEgkVzcpU9MjSkgyZM48pEEdGkkZGohSVJyULoVf
ocxycOVEGY/pmIlzzvuKRE5FIun33j/22muvtdfe3/18P8+zFT1OW3kLCQgI
xFPjv9nNfn7m5K4+DIds9Nj+px9uUYynB5f9g4yN+W/1HEgsOpBtTZN6B4GH
cvRL5QQmOI25tZ1MyGYFi2SmEehiHFAL6WhEMJGXojnAA8vaYNyI2423ofmv
M8y4mDh9dHqlchvU8m/aJC7kwTg6utCgOh8FqYGFartJRFsd7FLa2IVzp8Id
c+xJ6M8pt8cywmD7zWcq8ggJsxVXHb37mTDx3fnlwBMCcdPuBmIfk+FUkNtz
yoqES7tYfaJSDewVenL9wklw1LWY9/QSwN90OVHWjsTmjtJWP9U2qJRf7HSW
4yLUf+jFt8HLEFQYq77jTELlu2o806gCNyLypeg0EhMrjJuntTrgdfhGkdh9
DmrkC0om7r+DXZTmdLo3AbMNrnsSgrswz19FnTDiIeh70pNte1ux6Febs+Ed
AjF+V3OFrrUg3XJi1l2DC/WrtmIzj1/DuGhJrft6EppD878OdzAhZMIrshUe
hKQc/B4Hs2FXdb1OgSTgRcs0rkipRkXUrbMNhdR6uVS1pWIb4hjKF6USuPgh
oRly/mw3hgPFtTdpDWKv2bivZw8LR/z59NHbBO4Of5VeKR0P+urInUxrEn7z
mE9tlrNh8XTPRk8zHjSKZ60lnvVgv/mMtO0ABxxRVlJ/eAXomkopxaUE7pf/
bnLe346suZmXwbI8pHRN1RjEsdGvxyZr7QnI9vgIHf2nF7eV5NcnfuagPmT6
s51gMwJ3zB+uSCJhLyzjHFBQivUuruWTq0gEiBi65WnVgtfQsDBQhgRPkLTz
KKuDWrnimxUSJB546C0VOVWL64c6qiz2kQg1nW43+xgDU2HhGT+q//rfIzyC
h+8h1V9wO4vi0fjc/HphVhUa61ZerhcgodCrsd2uJx5JUh8dj1P7E7mtk4KR
/VDJvDh05fMH7NaUy7wzUYm3kbqjj6IJWCjKOGq/T0H56HbRagsSpXl2X16J
9yJiQzf9FDkA/f33F20eLYZpZqjJpBmJSKcF7W9vd8JdPq1JOWwAWTMbo+hS
zSic+L0m7g8XFQ6CR3MWX8WJtfue17mQGLlgmGgV1oEZnwtbI9K5cFMRU00g
0rDtpje7iuLVQ2WYa5fcAu+13aVGWwmodXOX+rMakewb8I3RTOmvW/OgEx1w
l36na2HEgckUTTRNpRWrPxyTdy4mUSNnIKQQUAWXZQ6Mvw6RoIXal/fcToXU
rOclJy+K/5ZiD7FrLHT1btGMcCOQ0xhqPT3JRJmVi8MWRRICPNqjZaYd8Bg0
Ghp7zUVqmqXY8s4mtP89Q/gSPPBpd9Xjn7Sh0tDhbfZJAvT+iibW82KsKS3R
XkXVv/pv9+DJ8Fo8I5KSUj/xEOq2ZMRTmwFb14e+K38S0H151vLC7mJEnOEP
7gokYV5XduaHbCd6T2skl4oSuOQ5+ydIoAnPPZTDTLNI6J4RyknPqEfy0hCn
MxT/66yid5c6dkOfYxo4+D8e3rR98rawYCOvOFPyzT0eFH9ZxBREtUA6RHBC
wpyEVIk0zWmmDs3hqTUvfAjwmc9iP4wlwCszxnCW4l8jtmQou7QM5rniRZ9E
KL7SHK6K33uDrup5rfGU3/np+yq5Jzuw2ljymb0jD8JznwVHJ1ohJ7H42Oox
Hs6F9Wjv/M5Gz2v+XRNLAgIBpX0KIm7QmMw22eFKYrxFK6REog0K8hJLhbby
cPcF43TruTqMxLPNJuUJ7GpPl20O7MDWXukgS5dBSH3J3PBXbBOOjNPDNpXx
oCJ02E7LhI2oJYX6CTqUX2uP7d1zvBpB472zO/wJ/EycZc4Z5GGII/uGRvH4
s+W93+NLbfjh5q55g8tFzqff4z/NczA1VtWVQenNufnefzKOjv0DaQ8inUg4
MsQPXVdrhfq3BU7fHan8ZBy6bBTXCD/bCzFfCym+K0dvyqm+h1nRTDeH6l/w
koUBH/oL8ETS3VwqgkQFI8nO6EsYJpaLNilSfBsMKS4lvbpBW8yzDErjoJl2
LVbQvB1tfnHfTtrwcHLk4apq2Rqox//J8MsloNGo4+L/bysSpi47fA4ksOl2
rXNhYx/S60ekZ7IJVIzYjgZff4OkKZVDcSkE+r99T1xd9QFrr6RpEZw+6F/k
bXhg0g7Jw56e8ym/5NEqnSXXsrA9SbQ20IKA6UF3nVTRTCx/EO/70YSqN3HO
ep1MGZZUCW3OB4nRK2URW/Q6cbM/z9znMQ/61XqyZ2tikKDRYSVD5X9J/C3+
BvNWfI0gzmucIVDfNa+oXbES8i/Y9EaqH5Fl/se91Ssxwn2962AIlTeuJ75o
KxWi3D54qyF1/i1uguSr+20QDWabp0ZxEWCKQeEVzeCrP0x8FsrDk4YsNTta
H44sjJ8s28kBPcD934zudBwfM/5RcJDEyURuU8TXFhyZ+nPCeJiLqtda+5hb
3uFnnp64hD4JH62TQqoTfdgRLWQtsoEHtVId9yCfCmxjL9fYT+Vf8/TUeXP6
KxQti+j01aXyUcfrBmuIgdvJZrkvDlN6DOop3Td5Cz7/RCBTmPJ/xQ5VH9eZ
3e1Zf2gaFL/q6sd8ilc1QeZ01aEF1HujrIexltEMHwHdbJvnFI89d1kuc/VY
V22uHDtBQiRcKSxjHRvFd/fYlNVT+cHRNxQarADz1+aGWcqPqTn8IBND6n+w
3dX1daAf6rIG9mv2V2LNjvWV4vEEjoto9aqRdTDgZlzW9qD8JGDo1HJmEb5Y
b3L+r56xpAdj7uO9sBgS3+dlT+VRzYIkLZ10fExeMWhF6aVQPD5wXrQKNn7K
0i3DBG6RFxcvzSmD+Ex9083zJJJLj0afUiuCzgkd+XFxElWZzdqBTxswmjvQ
tvMd9X/RBF/GjbFg2jPP6FMQxV9JA980+jzWzxX0L6Tuf2yzkh8g0473P0zW
uv7i4RpLeK5kiI0B/zXbMzy5EBBdvK7ALRzqjy52bqP4yX4aWxbzIR8HUlzr
ZC+QeOmnmvJ4MBtZLs19NwxI/B/kVL4I
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 172->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4ldkfvyMyFU1UUlFIWZvQKCl9bEm0GFGSLSOEqNGUO5aoX5YyBiGV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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2kgVG0bRokKSURSyNLyKnshddmSpFfKa22RCG1EsqRNoUWWLBVCoaSy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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41dkfx42iZhQKkxBTSSUZaZmK8VYSERVJ5CYUKrJVpPTYI8SMtVAY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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs41Nkfx4l2hWS1S+XRShaVkFVJ5a3Idcjaco0QueYS/WiFYiMxwkpC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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 173->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns8VPkbx4WVJZd0G5dalZRLG9GmyEdsG0KtVJRQqaZy10VJLrkUipKS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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3dcjf8bxpNEStKkNJSMtMyoL5cShZAiaVMotKiEJhmpNFApNIQSDSpp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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk41dkfxy8TUSrpR5RQGq5InqKk8iaRrLOUZSyJspStGN1Kkl9ZMslM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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4lWkYxiVJltJmJIMkRZSMhHTuaJkIISJqsrWolLJkmbJUx05ka+Kk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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 174->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lVkcxnUpyh6qUZZKpVGDkjHUPPZUym5sI0SkUGqaGlkqEZEURqIs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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VO8fxSUKydoiIdS3hGxJSM4klSRESkRKRKmEpEiRbBFKJSSVohKy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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlns81NkfxqWSSohKhV0tISKlNCk9dnOr6KdMQmiNEl0kWSkqWhERhZL6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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk8lHsbxh1NHFJUzoRUZOkYLWPPSS5bUXRSlkS2VEKy5BUpSymcKMWR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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 175->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lXkbZkYkXyohLTiO0nwx6Ms2VLeiZWqSmiKVyDaULSOpaLW3kA51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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k81P3Xxid+2UopSgslEQrJFqLLraIktzZaUImoJFpQN0WWihKSkIQk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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81dkbx1VSFCKpUJEsrZM9pI9KTbQIUSGMDKYULUgLojCyZokQlcwk
ZCuKzKVr3y6ua7vput9zKWWyVIPQ7/v747zOH+c8z3le5/m8n4+Ss6fl7/OF
hIQS6fX/Xf3AA40ki0I0zD88IXAj6E65dzT5cA68LjGNHE4QfGjc5ms22gzN
8fW8d8IEXgNckYKZTOz4+EFJx4Eg4mOi3vt+Blgf3PoXhBCw7r53bilsg99f
ytVn+gUo1fe4Z6hei+6HtTMz5yg8jZDScwhrh6bzI3bwagrTnPKg155sNFme
4GKKQOayXEtAXhcOVnbJOTfy4b5yfE6fwYR1vfZkoRmB2idR0wsNHJSbrvml
lzsA7j/e3IaRIgyb751zNyLQ4pezAm1KEZe1+tcJMYImlRdhoy6FSIxOfrxq
I4Hx40Cu5t47GJQvsnlkT5DBL2PJpiXD+JOIbtlvBOUFGSrRVaWIiLuzJHIn
gWZA+up6EQ7io+++mDhCYe2gxOfNDBZukZQclyQKGUGJNyp9mdBf5mk6VEbn
f62UFLwuDyInJ6fKzQnWWMzkSRRzMBc2UFP3jI/1aXouzS1sGJn6LtrE5CO/
Ro03NPkaEa+kdqg7EhyuXu1vHdyGPSusknQ2UVD3Hckdi2bh7peJU+FbKWwU
anWIE22GeVQxxWRQCBrg/WeY2QYL83jpYSaFQ+Ktz0o0utBvoTl5JJYPdtwW
12ENNtynBwO/JRCU5sbG/X27Grzddg/9ogg8I/KLLsh2wnf97cZ+agAZ15gP
hJM74Rwfyj9yg8K+n7/+u/tnB9rNGi9e0KBgNu9+wJtQNqrE7nNOGQtg7F2v
pyuTDltrU/6jPwgsr0jXPT3BwnDYY6M/UgkUXWbNmrpTIXQtbfyGJUHO77yo
gfBW7JfTVRzxojDZ8MJxfH8pZgZPGGhcJwj0NltEjudD2nKjo6w7wYlTOude
xhcgz1RNdeIoAc9GKD546yvIqDrPm/qTYLzwzaTFYwb2F76L7V1JoJvn80DO
iIkJU6GWxrcUlvpdWfujqhKZP5qOW52i73Ne1SWxWiHhMMj/vpTCAC86Yf3D
amxeEsi/KEXQx1WQEb/KwsKQ1qtWtyis6spIZNzuREFmuf3pCAEyG//lSPdx
MKb0Dk2f+XDRtGnxM6tG5gHhhoPeBOFZWdOLS3ohbi9t7uw9CPcNIw7/iT5G
9tu0789P0vxsb1SWDC9ATEiZ1UtPAmpQKDvpVgEOheSrCHQI7l785WAAsxOs
b5qqKwwIZs7N/Pw40oPHOtl2kCdI1Nk116raAeOCDLkw+n5Ecrbj56wC1Bgm
RMbS+ctT7J5xtFjw2CsteWElBcngS+r123phurbIJ5zLg3vDvbPXZt8g793J
NS+06H50X+1TYtVBI+PTOqaEAMR2tMfVKRLu75NC02g+5Lq8A9O0uqC50CzZ
h9avR+3sYT1LNi6XTAiE/6BwrOLKHm1tDmS9pF/GvafwlTfwzae6Fw4G7Jff
ouj/9/y7z7u4CT1fpcapZIJDEtvSHT4y4ZFo6aeoTvOiKzUZIVqIr0FR4bq+
BHUN+WuvFrRDv5b5XiGOQpTaGEtuGwNPEjT6Wmiejd1MWtXE8qHKe/LkgDWB
drSiXaVWFXRlTY5HexHcWjBZHVLcCytmSIcEPQ/i1z6q3lX/EM9+KCho0fpj
uKXqxLRnYV+AzWkmPd/OPrN2LJutQwV3+tieKgoeWq/ulQ2xcfLcLb7LfIJl
2xJijy19i/bUT/19qwj0a64L1o6x4byrwql6cADrHffauqrWw3zEryxJlKAq
2jjC5iwXRYn9BnMfBbClJj7Un++Aj1355Ni4ANkcFi/aqQ3ZJTHMZn2CmNza
yDj5EuyX5x1RWU6/Vx8WPLqoALl2zYkOHgTCIxsOFJu+hd17vzuSKwh2Nrss
E1GugcrNmS9qarQ+fk+v8HyYAzvO0L3cMzQ/UhfPzI79jQs77TkPaH6kN7kq
ll/vwa58lQq5YQoHKnuW7YnqxHwj2bb2BgJSMeai3V4Nlx/sa9zFAgS6OIep
7umGQ/ijUsksAb7OFFIKRTUIUZSK4NcT2Bzrs2Nov4PrHQVD4Y18ZFT82dgz
1IIHBxma/F0CHJNR3+/9goUpv7zvX+l+uLjolI/ptkBgoFwf20chUElqWl2i
DwGOdpE3aX4ZWf29KcQbtsXndBi0n8y8nPBJ2sxF9u0rK1vyBHC6J/VrAnmD
1yemlz7XJDDZ12875tSCeHtRvWBvCjbs9G3x9H/uV7tkJDhCEHKDtcJwsgtH
Lz9hZcxS2PHix935b7rBe7RO7KcPhXXJ1ru7nrZD+2LFkrPeAuRDxThMsg2W
Goc4PQIKaovla+TPVkNsTaY1V4nWl6j49lpOFRp2tMxWOREIzXGjp//yxG8T
15yc6Hm9eEfqyRWzpdguaF/FY9LnVrcMQovdsE83WkKRPt/Anby2tbUVc09Z
TCtCMHxR+fqa/A7Yhp6TGDk8gE65ZQvU9Trwr9SqrBRbOr7EwPP+kCv0X6dM
BdDxcv5ndgo592LWjamy3GYIGYLPYV0xJdjOPr6jnJ5XCmz/5VbzunFm+Hma
cwSFsNp+k1aDFrweFj3TKiyAf+7u6j+bmyCfPy9lkzuFUdfRCJ5JJf4p0r5x
m+ajNDQl6ktGFRiGUj0/vlOI8ZrLfqmcjRSJkA9RkQR5dRWdnex2lOhGnrd1
4UPc1Eve62cPPvo/551qGECYbJD/5dXdSPxH7kuxMgWhjZI1qX3JWN0YkWx7
muaZF+lxybwbCxLEZMRzKXw/LyJyOLkDvyxRn3Gj/Zx1dKt9zroq8NQFB4pk
CIoF/eOnL7BR8JfPeasxAvUs46s3FbJgKz+13ZD258Rdp5c1+HciOzZzy7yY
QQiNlf70NfFDYPrughhaP59F8kLVRzlwS9winpxDkLkv1Ugijo2wmPSMWHsB
FIMsZ+a1haJZvvX0bdoPIiWVnnTqVGP9g6DNC2vp+my7PNO0y7Aw0GJK34T2
r/aOd845LehflbNlEZ/W1/KzT8WkepF+vtI4Jp4CY68sI2E2BCIWiZNadD7G
Qevncl8fYnH59Ux9up7/AbiCzek=
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lekbxkUqUTGWyKRFDZkszZBILmPPmGwtKJKxNkYY2iwpDQaDhImR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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 176->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lekfxjmFikkTI0qWKNpmlKY0+N1kTWoiqaRGshyNZJtQlhIqSfYW
sisKSfYRx54sHeccDuZUqudERZ0oNBW/Z/54r/d6r+e9nuf5fu/7c3/VnU/Y
ujLExMRS6PPfm3GF3LMr78bpbxLPLiQT7DhyVN7b8SlaYu5pmL4QYsGnr0XL
WpugXJ+u3HqS4Myql6u9VIog276BedeZYFOpZWbuSS78i7bc/C4kCFV6H7Zq
LhsjK5NMHWsJFixW3NpawcY7d6MDvcUEj6ZsgqbK6lBlxDGU9yGoebxQTilj
AGW2X2Q19ggxAuWGY8o58Jt5u73GiUDeOcIqxb0ab73WcEXHCGazdT5wG/IQ
Ix1ovegIQZKoI95Q9wlKtysOx5cRrHBZni+9YQC326e+3IoVIvPnJZ8lP12C
9j+lD13+IBDNxq5PmGrG4qiuT8ExBN7f88xytwsQkHbPyyJIiDs/uOTnJvKx
0bm0wuYTwd3SPa9uinrA2KY5vWaIIO7+fZ99Yt0oWFYgsfU2wbqsqnv7Q9j4
WapC0NlC16N3/KqccB3B+3IcX9PzojYrZbFV+EiCiQN3vhBlghdxSwVP0P6t
56F8Iv3/CkP+66dWnGVVqK8LIjCs/nW7xu0mZFsbe4UHEjg9GRTo5F6E1tPA
z4fpfuR/V26Sn1mwfuP0xdKXoDTn1iL1aTYWm174YT2XgHmbqWDDGYSMXOT1
2I1C7DTeoPrH5j7wNCwHG+YIoeZQIumyOBqRXqdeOtL9LELHLyw5wUWM+IOM
8CYCy4cWytukuuDTP5HDono5bvWt4nC7odoUJqkRR8BKWjLDnuhDkc6cN/Vb
qF6KQw03DNoQZs9YqHeeoKTsY4jj5yy0afaWZFL9IgIdxW2qeLAN3W7ULinE
7rnOVbsePUHdj9Ys3woCQckTZ7PZakRyF3yM+ZOe5xq2bN2WKrxWaTQfpnpb
y/j2zuaUIsVe1LnahcD0eZ+iQz0bc22anhVmEQQbH/xeM83BpeBow/IiArbN
PsZ6/zqY2gR1RVJ/MaZivX8P5MHgjIKqk6oQTtJtKWbvg8DSrOr5jda/Qs/e
Rm+2HyOuDRZPLYSQjT/EfaHNg5x2+Z/N7wiMmvd+V7QsgXwvs2mM+r1/SZy7
3SAfRsOVboGjBMUvGddTNTmoWP2h362HoEy08kSZQwMkDTmvwigvtS+khiQd
miD/vfK9wimCzGzX5rUfWLDTUM16Se/X16iuUxTABftt9LqlIwRqoWvbR+Zk
w1vHcNKD9k9RX7zl4GQ7Hitcs5bOIEiudDrSsZAHJvMfqeIZgk6hg2/ebT7u
aMWEyhCC3X2J+tZFFbjIGq0z8KB6HDx5UdayCAp579Vr/7t/lZHfHffHKDyW
KPoznkAsRSZiSiUcbDO2hznth/PaIjXh8n4ET+jGsM8KcePswl0C8UdwqTVf
kpNE+Q56LLpaw8Gm+lTNXc8JupV1lz5QEOAvzub5EqeEsPy3jbXo1gCaP5uI
L7ESQlM7VuqMqB5id07xev0INhjGb5Zp5sGkwvvxqkVC5Oufu5QyvxpDjXEb
x9wJeI0d4VpSAjy1LnylT/k9bTJRf2WgHZoTJMz7KoF2uRbrUns1il/7SH33
JGjWLapcG9CJRE72A0EJrSfE+NfIm8fR+HH1iC6tJ3PdpOovjfdxI/VA/CT1
j7eZotHl1ir89HX8lBb1V9mKmePG+X3I1rQw5zsIcTlSLvpaQzdWGNSdDykk
GF8vecLGk4PYG6L1ox8IhlJ9U/7qzYB5n33UBqoPb+PW+o8RAiSsi9qCACHi
3ijJeKSXY/+hpiuqTILh0n2blZ5x8MvJVSN+AoLf7ocOnO/mYA1fbUp/mkC6
U+r3PRce4bj+U/1xyk9adxlj58UGTPo4VGZSvudyjM17xVog2NumInaR8h5c
OJl9swFc849L9QIIqkQWjMNT5TAI1p7muVJ+r0reDgnqQX5jf1szjyC8vc7K
/N8e6H0pz5ug+fzxzfrze/h9MNM64KBM+T1lbT82sqMfbd6FVgr0e+b+ozsj
SW2oib489ob640J18vkM8TbIGP5onx5KsPDqoLipXyPMbbd1XaB51Rm9S8ck
fwATuxmucl5CRDy0Lnjfm49juulyhTSfz7B2RvI88mFaF5o7Qb9bn2ZxLRg8
fMrtYCb1EszT93/AZzyAXFPm9GmqDy9tsH7Njm587Z8oaKD5o8gPSnh3txZG
TsX+CpSXarGDrMOpXZiOFzCDK2l/PJ2P6Fr3o3T3ypzEcZoPBiXqItsGXBZZ
yoyfJrBzMu/6x7MB7rNqpgJ6X2mJb/qJaTy0Fh8TDUgIMS+08WhWeAvSFZW1
RkMIHviJZq9e4sLeIyxmjOqtnO1Su8e3D/LhGw8c0hKipHzvuYKAJzCYP2/T
/lLqh/AFeQz/BHje2yJ9mfqtqubLixdRjchPsNwwQ/2+IHpP6c2/+zAeNb+6
hvLqFF36SE3+bwS6hznupXk3MuwXOR5TB48Rx5JKb7rO801fPd4FC6aEXUom
5VmdKxdpMQjPGi3pVDo/Sp6H+JnZxaFGbpzjQ89jGC/by+vj4vBzxmAdzSv3
Q4zD/WOP0ZpZo748gSA2N8aWr9eBlf1XIv3T6Dw1PnrIa7oXYkcFBZ7LhbBL
TnZ0dR+E5Ykfx/38hfD70JhhG8SB47KWIBblOxg7xA3by5EtW/JHAfXz0eLz
D6eUGyETJz36zJ9gP89ffeZ5F661aeHZLQK3TX8lfDHiI4Cpd92JSfmO++Z4
ndWNaxl7ZzRyaT0qldk7vHrwWlbbxJLql+8dPtlX0Acl+wGteYp0nqgUDOdF
VGP03e/VobQ/5NXbq07anTise7fajOb7xmW1u96b8JHgFu7w1YnmedeK3zoM
C6EpHrGZR/ONFzUum6PWgrPJEmPZVG+9kxdTmqorcHLIKr3NjeBYxU/mupED
dP4ef5nqJoTDWeY5j5EebLLdmV/UQWAuSJ4hAzxoB7n9dG2W6rGrwWpUMgEO
OnZKobTfbFaUxHAJH65v958Zovk2pGsX+3f/HYj55Gwrp/62Evua5pbGh79v
zxz2QSH+D+FnyD0=
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VG8bViHZUkr8kiRKWdOCkltSSSURlZCk7IlCISmlQomIsqdFtmTJ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lWkfxm3RiLGHhjdlbEljLVQuRaQsNZbkVJRIeaUZEqZUY0loOmGk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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk4lekbRlLKMiGX5WQQCRlGtkrdhoNja4RSkgwtKoOhskSpJEaLzMiS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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 177->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk0VfsfrV4rFZ4oUREeKRXuI1Hx20oZFiVRytAgiZ6pXhF6kZBeNBlC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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4lf/7V4iKkqIiQgNFZgPlpaIyKqtCVtKOyKiPlRX6KPkoI1mRGRJl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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk8lWkbPg4tI30hnyyRSk2K+SrLlOgyZN9zUkqSLCNZkqS+fElkKZMW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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk4lGsfRum0oJIthjYiOaKyHdU952uT/VAqtCGFHJJIC7K0yFYkHdGU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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 178->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs4ldkXx09Il6GSUOaXmsoMXSTlMmr6qjCHRkhMI2OkQyMaalAuY9wa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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VH0bxke0oZAoFZESwpMU8vBcQiUJRZZCJSQUqUSptFrSRknIHpKQ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk41lkbNm0oyRBJUzHK+MJM2ZLKLUtDg0yKdySkLIkSlZgmEiIqSray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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs4lOkblnJoR21OJRQlFhttZSVbbsksyfmQVidGZEOUyCU5TAezndNG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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 179->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVmk8lVkYR4kWQooWEw1RkaHlltTflEER0tiaFnJVQpIl60QkQ8nQSumO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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VG8bxomoqJR9/akQSkhFpS6hUqFIe0SSQtFiSRKFEFKRrKmQbFnK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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlWk81ekbxo+TLamxZpkwNURZImUSucrIKJQ0DUKKREgKJUsh+hOVJiHZ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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk01ekfx62hjFHRlFIqaSM0kdL0tnUqP6HcqZtJighZs99RZCsi+snS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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 180->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8VekfxzHJJCpZujVaUNJm1MhPDX0kZIgkeRHapGxZJiI/e5ZIuIpu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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VO8bxkepJG2SUlIkUSokJNxJi9Q3FFmStJItpAhJkiRri1Ck7JRQ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkbxw1lMmVpRkg1hGTJUA0Z5CMtthpzkSVL9lFR8sOvSK8KISZr
lhbDhEjJkkY06pLlXsu9175m+Z4rWyIqyfD7/v44r/PHeZ1znudznuf9Odvd
z1l5CQoICKTS4/9zY76Yp3FJE5QM8vdLnCBYkfrNuEGbhz3L23tzfuLDzERp
6c+cAYSrim3JmhxBp1zlQdEv7XiYsdEwuHUE4yeGhGxXeXBvrZTX1KGQYtmn
OsFvxZZTTa1cLh/m46oO7xkcSDTGWC9epZAUqWwufYeF37NvqHhPjIJdWbNP
vbsTD49UmyWHEGjdEG7+6MxEU1Hg2BpzAnl22fjgChc1YTlBlecI9EUlm4Wm
2nC4Nnqhnt7/s0hfdGpNCzKFrTd5HCJQiOtcL59SjCtu1w8Ta4KslZSO+Zy7
sM6x+c7VnSCa/T4nVKwZyY6JOQc8+Mhxv6zfgD4M/PG2McyCQuKhor1nlZ5h
ofvuEVsbguJWm47eLQWYNfdfmrMjWFRsStod24R+JYPVU2EEAu5ijzNZ9egZ
vR584neClLsbiP0AB6mHSidKuQQ/S4kHPbraAWWGA284lYLhgfI0+f4OGA/o
H2dcHEXCKa5JL7cEDo4p/xRGEmQWWsvW1bMxd2Bu+nYaBRd/meghhx4YCSyk
Nj0cgYR+ulaJZgMC/aoS2/cQtP0qnd+ryYO8yn03h8sEM76Gd5xUapBTZbkm
5gyBaUWJV5jSc3g/Uz2eZkqwtDj+bBu7DXXnte93i1MYfmIixdUvw83LiZ/D
7Qk8/7EzVpovx2kZgeRwSYKFsURhC0UWbr/U0yrfyIfRW9W+tdR95NWppY+e
JGg9xiB4wYNH+mkzRjaB0YzJbPNKC8bH/9rq9ZrC1guCsbODDRBVC6ue7CTY
6q1tuezcDfHGp2e66HpL3R+QpW7QDp2CtSy9m6O4UG7EPLy/H6tbRQIjkgk6
igKrc0V6IDl4x85Tno6XZfXyRRcTRrwB85geAl+NCON/3Wowvhj7d9RbCo8t
ybqhvH5UbPF72a1H3z/D45ZvYoMhZ71YpkmQzvKd6dBpxfnHU/yhfgoHObyz
P6q/gvuMS12aN4GTm9Fr07kuXBOvqq7q5SPOvdH6Ru4AbtSqjEqUEVQIrZv/
78siqKV9O2ZrRSB4xG/ZJrwLUfPKeWtU+RAr8t81e64Fhhvf5m64SKB7Iexo
rXQdKiV2W9aLETBiMrbsimjGTMHBjeXBo2CGRYuyquvgI1sVpbNM4Za8DH+l
+jl03z46o7yd4NJK1KTV3xwsaxzrVmfzofT+QvR8Qwe2dzve+s2Vj+icyR0z
Lky4Uh9Sgj7R/XcvxFc2vQZO1XNOvU8I/Ouz1m4KLkFKuxXrlD993tSCxFkP
JsiSa9OyDMFROV9ldWYX0kpvHslXpiC1+alAWn0bIuf2XjlNn8+d7osP3c5G
RIKC465OCsT5yPmCRTaWrtb/sLSB1l9eNmpMqB6yHyUPK28jGFDszlJ7x0SK
QUBAMp2vsIlpmPHpXrAt16aOlA9jIGhW06Odi58frx72naBwWbe2f+NkBVqD
Z2OOTFOwCXkicE2EDeaLEtMvjnyovDBau7mhB7uEMwrFsocRt8q76rSPA9fh
IMGOtXT++hyEmZRBMfee+bI2gYyb9RtRFxbSE3nhgjyC2NhPz/0CBjHXMFXb
JklB67hbl9auOhRpb1vWvk3HO7zoqPCgFQF3Kk+qhlIQktko7S/RiF/nN7e2
9VFYGbb8bPtDF5INrum/1qJg0MHOe0m/t737Ts86Jz6KTYu8wzlMONz7qKhn
QRBXEsdIGubBPtCpx5uup4zOu5F1/Y3wHLkY1EX3g493bv49wWbkB7c07qB5
suZk5f1IZjNOJO7ooYxpvbuROLqHA42SqfWisxTWlKk7pgzV4tVX8QEWrU+I
2FT8WZFuxOfbWCk0jMBgJVspvp+DkL374t5xKIR+jXWZ/siDW/k9s5OFBGV2
FVfIYB9UFL+/lHCBggo3br3VdTbKRAViAnT4uPx4p2NQUR3O787OPF9MQUIu
dMw4Mg/V1j6rH8xofnp8qxY5kQKBzTU+p+h+rbPavXiW14j1JQYK7roEOu3G
NePsdtiQpAHXQxQ+T/dKWVQ14fO7sItHaT0kxg86R25/jorv9t6b86Lrr+62
v4VXPaKSU4h/AYUfN+RX7tHrhBiDNHNdKcweqL41FstEgWzjo8IMAsmuWH87
Ew4EqltCFCMoVPzwuJVZ2ITrdsfSFvtoXpJpIbUyLrYaG5oQBh9Jp5YiS593
oi+J8arPl4J8a4r7FCMbbLcdFeVOBJcd3qT6HevBDu3cB+uK+ehc4uWEjvPw
1V5QN0+OIDfjvVy7DAtv7tsyZD6PImthTGQVjzBk+FQs1pPgfLnMOaf0NsSu
6G3dk0Svtwm+8+tpxO9ata1eJgS2t8yU1K/0w6X/ofOGQAoCrG9i1QvZ+INh
6nvVh4Ard7OesdCBHzVcj3qI87HM1jj55zdcJPhtCx6X5ENGZ7OX37l6mM/L
HMik+X2TFREuu8zDpqimHum7FMZr9uukij6ErXRMjxzNX3YRy7BMcQAeCs2c
nT1v8K/v6qvj6f145DOpp/kTrSdLw7lmoRq39krmnZmkcOlg1Kq+UQsWoyyS
NUX4yPqQdtlf4TW25U1oRUgRDA/08XuG70KPl+mRTcebr8gv3ZHdgqPN33+p
KKewKUyk+185DlbbLn1Ky6F5cPWXvV9oP38u+Vd1SCuFfC2fQZ35AnS53zRt
1iAQK1eaNhPuhbu07Kj6xRHUNv8nwS2+DzsNfvnpi+swSp/xa4fiCnGGq75e
ivb7cV9TSTmlThx9YuDi5kz/B7zVVZkj9bBpWPdIbYbC053FFgkrrxDzku32
RpT2VzHPDy5OHdh5a19LpgPBJ9+EcS7nDVROdAdWPRvDb4b2GROpg5jUyLRb
EqSQabm5/YFuN67pNhyvMKL5KO4Vf9a4Gysxt1fli0fhf0ho0IeRhwDh4HjB
0wTrhMPbOOk5EHLMzXtwnPb/lpgeRj8XNxbzr2XQ/mP/ek7C6ysTpZl3TMSv
ELzKPj05EVqP+xfV8i/Q/PsfCXjR1g==
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVWk4lWkDlmVQQqnQIkoRKSRJk9tI9krIaKI40aIGTVJJqFDq1BgUooiS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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 181->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lekbx89UlrIkhXapjDMx0igjla+UJdPMVYaEZD0lIstIMSYNv0K0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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8Vf8fx6VCUqloSFJUZDSEUnrJKElIoiFJFA0JWfW1Z0mKkJBZIpIy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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk4lVkctlylsSRRKpUtSe4kGUvUq6QFoUUqauxki8oSStZMY40MEyOF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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs8lWkXPWWiwjflUswQKsmlUBkyxiLllsott9xCTWIQOSoqJiFMBoVQ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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 182->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk4Vukfxt9EpMbaKFmGphUZLWha3GqSTGRpGQ2pyFLJFj/0miyNnaSx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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VH8bxpU2lBQV2pCiTUhF4UZESIulkkokKglFKmVJthCSrRJZf0gT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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVmk8lWkflnpTxiClhKTGHmUrKrpMTJZBSoulKFGSUBHjLccYS0ykMqmx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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs4lGkfRohSmf2QDYlVKhN9RFPZblFJtZSGSGE7LPGVSUjjlEjKoZNT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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 183->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lekbxknKRI3UyCBFY0mMlpGaymWnMmWd0akpYznZ0mYdzTCpplRE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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3lYTP0bxltElCSRXmkRERUtr1C5K0miRQvZKyWStKC0F/FSkhYKJW3S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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlns81NkfxodySZLEppTUyj3lstpl61FZt4iipIvsGNJlk1xCoabIliTJ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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk8lekfRSgzIlpoSlrsU8lWSE6hCd2QvUT2QgaVSaFVKCoKTaSiQqhf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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 184->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4ldkfv5XIVqFFaijThEncbKU0H9OoafWzJKZBsmVQuAiRuUmLGPta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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k0VA8bJrKWVEiUpFRaJCFJnpSEhFIIoUJCKilrslUqIrRYQphCEkr2
7Eu2GWNsUczMnUFRfoWk5LvfX/fMuffMeZfnfZa1Zy4ec1rAw8Njx8vD8/+n
X390wU7THizR3hc1pzWK0dRjouyvdHTx8R4878dCg37T8va5HtgcLb0WXMnG
0A3dGw8ePEcvZ2pY6QIBmkKN4r0IKvrtl37QVWdDXO9PwanCTLg+a/Ed9SEQ
MOr23xWJXgjkmTwKcWBCZvXzzx0WdDx3zde/NjYCe88q6mtaN+bV/5Z4ynGx
32rI81hxPYJ6nmg2B7EwE+r05EJyB+5aGGko87OhwvBweOKSiZ+8YyFLzxO4
K3ZXte5DPyYpQdccto4gyeuuq+GhVmxa1GuKCibW5aV5RP1thWSK/rL5lVwE
VhzfIrGFBq8crvQWJwK9tRvlbOJfYeGxybLYIAJNEi2bN089RZPZy0Om5gRm
dpzs2hjfjAcHAz8+zybgl88x7fzXh/zsnqaL7BGISAUkUsTosLXsmCIMhjEq
ttoz+SwdPLn/DgvbstDrpRf8NZCCEOYrCRNv8v+i1WrdpFsQfil0TiuSg/Ij
l7lLDLuh9++xU0ARB01NjrtXFTagQEHHWvQXG/2bRokrn1qxgqK0LsWGjVrF
UiEdMQZEFeUs1aeGcN/EVlKjqgsZ616+nKdzsczqZLXq8WZ0n0pdclCBgJXJ
zu50tQpopJX8fNxKoLBiRb8bfzaEss3WfDtO9hPzcBe3sAXRO4c9aGlDcLG6
1mRg3QKWhdTeXnUOaH0KjbK3GVCJyZ5VTiLwJNj7s4V+OaLCrF/v7GFDLcIX
SttaoLBQ7vf2FeT3HiG31ojXo9l1T5MlWX/4jhsp8W+6oSJu4WkYyIZ8Qb6t
5ec0aKrd2mlKzmPMUPNBiMUHeOoEh2/4yYLXRKLRALUPiz0kI7P5OQi7V6Gt
zOrGoMu5mS+DXBR3yo8/eNkBk7wNg0VjbLgcXNUqdLYZoh1mxj/y2SAy/F/l
nGSgN2bhiMfeYYxRmTf7wlpBL+d7LVfHhNSBP3uuHmXg5Or4cJnXHIQ3nlrm
vbMUEm9a1OodCVzS5s9j3mkD3+vijWFGbHQ/DjWxnqTDY+tm4Ws8o0jQil8m
spMKq0YUfadzsIZZezNdjIoaQSFe9b0c7JQ7qCPdSkPdCc/BtY8IOIhNHb1k
1QmHQpZ3xUUWYrY8sgofrUOSf/LWQj4CXncXt4ztbkZe4CXZCm3ynkq8FbLb
KtCXmmCz34kNQ4d21RubacjmNFaqlrHhnbMl5UvqJ+Tkqv88LjAM/nuyAhJj
TQj89U5K25ADbtquc99kGOBZLvYlMp2JunS5t0Ifm7DjZf616ggCQb9bfqZM
1CNQ+8KxIvL3mFyOfVBJA9p/NYlRZphIEMjjH3Omw7n48EK2OQsRzrfo/B0t
iPyidYDtzIF8V+MvI90G1F9eLZJ5ig0jmsgF/0c1GI1TcDX/RMDninGWU3Q9
vKJLu2+TeMjMMlZ7L1eNKdOPKuE7OAhQ/yNmW8rA56LTTgfq2NBSNjPd0DmA
14b/hOLCSPwsfm8U+6IB73MWG3d3EtC0DXTx/1WGEpNgeTNlDgJ5JBXVTjOg
Mzjz2Ea0H9EVhhVX7bthlkzfIF8/DAr9wTmVFgbGXBtqxX6OYPu8VlqsRSW8
UjJrWnU5iNa7tzpGvxh5qmOaK3g4MMo4t3NlYj1cfx8yWF5HQOVIwjeNoGbM
HghxP0oQ8LBii37e3QOewmz3BdNsNNVZCZ5llOPutnzn+Hfkvhq3lvzjzwDV
XVex14LAarXKC6/f9+Ffe5X63utDGNpMrBSxTUTXIe6OQ24EhvS+217ifoBE
a6HAngACwpTIuNBT3Si3j9VzX0uAv8a8amfgc7j9y9zWuY6ARpmc6d68Phgn
mCYPsb7C10rUo2SgC9K5zLM/FrJQeorPfTy8H3N7KKOKzziYvO91/N+VVsxk
qJ+muhJYrNuRtiyFhie7tkhVrWahXOqSWYlfHViLcgy8njPh7i4qeJfRDdWS
ElqqFBcZIn073wu1YfzpDt3hODZ41jn+mDofDJVtghtr7QioRgrE7tvQBb31
W4/fsSKw/05Zq4JXP3qHFo+NhIzg0vRyQcYuGsY1A9W3pLDgk5Oo1T7egsPt
CrIcaQJ1TKPU6+vp8B7tl/zeRSDN7ap1glA1VLZcWJEdQ4DHae6Iee8NyL0Z
vPT7FAGjvbToQ/Zd2PrCK+uGFgf7JKt35RndA4dy+PxeewKrbm7/ujysE1Eq
s4KXrT4j9XWrlv7icmSMd07PiBKQu6KzL+xtMVxu3Nl7O53A8WCLxyYXGjBU
57+X5UDeZ55K1t6Z52CVVHLu7yCQp1UsZDFcjvVVGttSh9goviwROrKzD0d3
71C5LzqCiXH3bQOyeUiwpfDNVRMQOto6+JLdBI1zoY2XWaRe6Y4kHthFwUxD
6h0XUk9e0O8EX7PthN6xHGGT+FFM2xRzt3zqxAHBTcnxk0zIn/He1+bXDss3
tubnyfmcyTkzH+fchdDETvdNhSyIl57xbVpeibffjOQ09AnIj7rGNkfUQcvE
No4RwQYtZKqhxLIKE8PXcVafA7+1M1XJVJIvtqesSKWQ/DidFT7q1AqF2Sa/
GV4WLin3v82pL4WexcyZaQlyn12veFcIN+A8pXzO9zYHCzSV6aYR7yB10l1g
SJEAkewg2TZfCX6G7vD+BaSeW9cfWedCQ8Fq+pOFFC4oNczGmp5mlIf6z1Py
CTgGCDFaPejIjT2y6ev5YQi9+EizkC6GjJuglZYBgbBfpYsu9tYjQF8rJsn9
/3wXWWVQU4yk31oaKSSeJDwzYkoyyyFh9/rMXzcOhNSC1jehHfJJH9nJD0h+
tpWzz+gLRpqxT4X4aQLrY6abJ1+34svyuN3hnwms886gbjrah4ZWzxF/ZSZc
/FsF+TS7sVmmMvb2cSbsLU/LTh3+iNHAW1GSXR8Rdm2FUbJMD57YjafVzQ+j
hr2rzT+cgU8nFKLOk/rh0LibZ9a3BIGXbBveaZL8ZvD3q492GaTmNgpev0dA
7z93qez8DyiLD14j1spB3fMD66eq36AgZ31jeCiBVEsH55EnJfh5KfFiPJWN
4/Itd4+mfIDkkYt97mIczOic2fmd1oXZOddz9v4kPws5BuCDL1bvc0w1IfH9
l756TLafjhjdeNm4EQIGHSaqy8f74cCs57t1chBmPsxaYrISBbzsVVcOEIj4
82Uzv0I91nJ61yzZSuL7HOffmqkSTK6qfXeO5CuX+Kiw5JfFaKu8+dDdhdyn
j+jltyvKce3NiCBI/MWZrKb8x9sDAa1/sjyUL/B7vVV21XgEVgm83+jkTEAq
5VHejucvgJbTlt8uknz1tEZmZjEDAXA2pTozURV43Lf0Rw12rVmxujGcA8bv
2ltrbGoxv9C4oWgzgZBndqx1a2jQzol02p01jLD2GQVWJQ1LKLYFxb1DkLrb
Ypq0g4aQP0/TXpJ45Zmb3LdmkAqev8I3Ym248PE9s7JLtRWvHayIKAc2qkLt
fzZN1OFJ/Kjtxhgu5OfKtC8nv8Cmbzt6hVeReEtPJ0wkq/DK9rx1Vwip56ba
ZZv4BzCtOEAo5LIhOOVTESNZC78k5RM9z0m/krri4phRDUxCJooekvezqSvk
RdarAsjpfDfKkidgdnmXn2FyHzmvMsze5iLC79QSqZuN+Da+9eGhRDZW9t+a
lNpOB7HI875PMwtxU6WLuI2t8Dr+wH12kIXUvO+5UmrZ4M06Yn72Bqlv783z
/H7ToCvkLSlJ8nfxmyIRH77PIFpmf5+9M4zJKwZt/geo4Ggc78tcPAzx8vK/
q770ori5wVrpFAvy/jmnS0VpiAgzjqSQ84hmrVLf5pGL9e937XVSJfXM8F2H
sGUJklIuuUvLcWBVuOyxznQnqN/Vz47LDWLk8Tkl74g2mKSrVJ+0ZSPg6EBx
sF0j9i+04ncNZ+Od/W8BlccdiHg2ODH/k/QL7558d91OhV/T2WuCH1hwEIrP
aItrQOep/au5sQSOyZzY8r2GjruafrMNPAQ+77c/qezZgehMCmN7MxNB3Dqr
+SUdqDltOzcww8bzaoWn041V8PuxLupTADnvoVUly9iNWDnfP6hvz4FA+3rO
jxWlyAm5YfP4JBsTx3Qnv1MTgYQvGX4kHtPrT7+6SM7jm/CTCB9x8l67Ct/z
zTGQ8MtMbprUr/BbIr2pERV4dnJl0rtINlyneX1+swdwXGaVEMWDg63CiRI5
aT0YmX/Z9GI36b9VpFbNp7/FZo+KuPlHbDjYL3NN2h+KHvED623Je2z1cfoa
bNOC/QEH5tWNSL2auVHeYK0HlwqZPGXy/dCZMmrBgkLsa3Y17iT90Ob0XYyF
V/sxW7IoaBnZv0GlkorajX5kXoncEtRP4pvTwsO3Lw/EFu8Ih1oSz4n13GDR
+2gVFtd6TPbno3NiaolvGewOy1VtNCEQyM+fknSxDGZuPhWiYgTE5TeqF/9p
w/39vqUZJD4D+pVSRkV7cWlz0uDu0H405B2K/VjdiaRnU/yLeMm8YXD1R/Ci
XNSJXGuWyyAwaeg4fyexG81gMlX/kv4033hG0JsOzbwyyQ+hTASGLDb/E8ZA
dJhZ+FUhDpoXFC/fxUuF+asUuQwlDqQP9e72C+6FhdGRc0X0YZRXD2wZCPmI
99bUyEekPkRXvq+j0Jsx9dM1MbuYzFe2mbkZ4s0wH7PWgAGpT53SZS42dcgM
7x30I/lEZdfGz30eZfCa5tW+/IJAElVrjCKSjmXqZl/vUgg0BLTnVucyQN3F
62uuyIFPno9/uX41Xhm95q3dTe7jEF8nd6sfjoamxYaQ+5D+EiqccaYPYuys
8BaTL1AxEn1f8h8DGo6zmWpkfxLNWsEXbnbiYEXBXH/QCIROVPLTHToho/Hi
9FJynuIrxVwqdhRBky0sLmFG8jMv5T6jrxJPuEUFNb5kPxdUgq9rt8Jaw7Dw
lwsLbz/efySeSvpnt3Gj4GkuyaMyR16s6YFBxnSOetYXnMn7M1sIKgI63aL4
yDzpaL/x31bXWjQt9VRtJPPZv37VRqMbn2Amp/ps5adhlEU9e/qwrxc9esdk
vDnDyBu3K31GS0eH0DnvSBuSr3/LW3/NbcMNYcq1jA/kfUy1nTOvbkLT4i6p
++1k/csLd+ScL0CQQV704ZukvjqecXagtWFGcs56qISFpquce3kPytDKtvlP
jNRTQv9pGTekFy5f/4QcZg9DRMFCLGFlL0r/fXzzltx3+MGv9LSMItBtn1pO
0sj8pxdF+9tZDBPlo9foxwiUT0w5Wq0k/XLV18P9TQTsFPXlA8g8RrtXWet8
nYNUxqIT7+7lYHzW/838ZdJvnXM/tEmKgblh/Xuy+4YxLTIb9auoD8+bvj11
J/lAQO5+y5wiHeBLdVbXJPXSZEyasrYRDJVTyW8EuLh0v9JGVKoVbCGW3zcK
C45HM4afSnSC0a687nE9GwY6T0/YUEuwn7/16mAk6T8Xiim5Z1FBX2Q5di+K
rNe+RKeY3gFKw8PNZaQfCtjz1+br0pfgKahI5HEi61saffqgaz18hcfpF8l8
JzT6QlntLQ0yV2o3stlsmNlu6nKj1uLMJolbNnsIhEf7TpwOqUFAT4L4vgky
777XqbrX3IFt5zaeX5s3Ao1ytYzcjH7M7N/7r2rJMIZC2qdyTKux0LPG+nIv
6eckMwZLeUvx/Elm7AGSb2tkd8fMHutFeNN9G36JUUidSFAeU+1BctzmLze7
OZiy6j+bs3wAsWaWZdtYbOztPNHWl/IKmTzSgQlUst8K6edPvdvwR3GV786X
XEzE+XeLB9TAc8rAoZmPA009zZm2TdVoOnmn05rFwfrfMl48Zr2QjgqumVg0
joS/1Cz/TXSYv/TdZJMwgm6x0aSgywMwm3xMM1T8BIfmbyJt43Woilb/YX2b
jd62McF4+Q9oyh0IHMhh4oG29PkJ3moo2v9nesSOjfbM2JY95gzIm8VdFvg6
ChXGhEf5syZIbE92ZM6ysUjb8tOrl4UIurxmzfQaDkS+DXEupdFwP5xXha+G
C8fq9GCF8zScWnI0x32Q1GP2Ib003UoY539n3rlC+v0pUVH5JDpSNh4MfbuN
A2amQVZsRCfCqXP5diJkvlxm57VQ6hXGHt62GNYi9z+6YK/dvm60Tzz4nuA2
jO6yBhEWOe/NXM/6x/LD2PaMImjrRccqNS1jb9JPPLn1bkopk4ZZ1YtSG1qH
oaMboSRs24ItEvld/WEs/P0pmqSh1IiPp307HoeTesCXEm18ioGkorsf838N
4u7pH1ORlj1Qk0geMGlgI5Xm3GgVToXez9T0tv0sBDh53TnoXITIKzSBtr9s
5EUvzNT8Xo2oE3Y6i6ZYwLtXKcrcRqgO0BQLstgIy/BNd/3VA408CTlP3U+I
vl305bJqHZztiqrly0n8TRLu9MdUWMsoyVy7yAR/zDPtc4u74LVk5R5lfi5i
mF8qdY378ObodAy9non116ODtFpawUyyW9mbz8Tiq1max/ZVIOM/1si7eJJP
hVMs3AqrEBbhdWVpMxuvaIEnfEj+r7vor3HHdBi9G7wmoi4UQsQzff4HmV+l
LDcoya7tgrFs1vXXNixYTnqOuyc2IOTknaYZ0m+up+1w0J/rgk92gdI8uZ9B
k0pHyf4OvJUoT+X6DCFIKc8xcCPp0+9UVq3wZ+PIpynat/g30Pl6c6nFYtI/
uSbLqsy9g0bs5+k9hwkIGubyuXxshoiHBmPBAIHGpaEyJ/MHIB2+YH7IkNR/
tb6mKNlqPBhub9xrSPpjyTlN6bh8hByQ7s/KJfMXb/CgoFgfzF6OmF1xZWNa
o0o76fsbnO3MqTch/b6tQME1unUDCtz2VKjvYMNDsnmXg94HBHif0Pd8RuqZ
ZJnS9XA6XI4QLhllnyG1/4HnVlY3+M+8/FNozMSEy+alDZbP8FO4YT2vG4F4
v1exim878cyrutXpNxcz/2Le3DQvRY1bcNH+tQTeL932rVayC9t/ib/36mZB
2sq4s5D5Frf6Bg0jhci8k3uqzc+qBblLspcb32DD3SY0O7ToA5LXyugoHeXg
fy0+EFk=
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8lWkfxlEiO9NYUkLbUMlkS+TSkSU1lgkl2Rq7VlH0GiQaLUrWprzI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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns4lGsXxp2y07Z9lUJFCqFMmLZj2t2knUPIIW1bhCJNxFCSSEcVqW2r
SEQh5y2HESIUM0zkMAyT48y8b+kg0U4HfPW93x/P9fyx1nWt61n3b93rWbs/
1DVASkJCIoU6/7/Dvrxrud3MxrGpnobdDSREBXY0yYVFYDEGCPsAEkKHbRHe
3CrIxwyevOBJoupvpZ5oxhC2yyWK/tMvhmHAHY1r1mzQxA6eMiYEpBRNha6y
3eiJu56sr07A1Pk0u5U1BJ8m5eDVDmK8yeqQv/72Bf6eu6jSXk+AtbhIwSLj
PrR0I5OueJO4Nl03m9XajrXy50MCQwj4F3N1Cx+14UWwl97wHAFNKy/nqlN8
SDnuFcRIihFcPmq3/eUj6OOmQcKfJKQ+dc4ywwagXiK39EmHCBc4TJtD7waw
s2Lo3oyXCAXs/dLZjA6IGtq5evoErnLVGrUqniNczfyfE0YkliWc+RDq3olL
0tdmy4MI6M6sHZe714dYqX97zt8Vw8v913xv2gjoAVMv6a5CCFXVXq7Y2Q87
Aa+kWF2M8Yk4zquWZxjNSdLQZpHIiIhcxlTvhZOnzGGNERH47Ph3Z6IG8FFf
6dCbFQQWu3rppDJrELt3arJ/hIBvuJPO5+Vd6C2SGLxkTGA5e12wmrsAGgVc
a0MzEhL+AhPJrmdoplXfsN9KQrDf77JbTRs47c36qCOQkn1ic825EdyN4OOC
6xiaikZUd+ypxaOSGe9lziS0khgD9Vd6YGuneTz8bzEynN/SMNoHiaAsf703
YpTNbfDl/5mPepLWZrWLhPODhwdnhcOQbB+0edM8DE6qOF3wko8yGaOoNVvE
YHFVq1fsFeBHTMOhS04i0ASef3w50IayfBVzfisB2ys/1deZPkf1Siu9VRQP
x5L0h29EtuOrXkJLuTUVD/tDys6nE8l5HQtzX4vBdNG8zbAoRUzKErakA4lU
nZ5R7Xg+MpbVDmgpE+h+LKXzfSEbt3IfL6cvIXH3Y6K3WnUJbjh/22tE5Zcp
3A84VfccJyVtLdW8CAgU7TdpnW2B0YT35sNU3NAn/ZRxHRfG6mm/71lP8aLt
fuK19XPcryHn2UIC8pYykVGCp0iT3ZWkK0PCIeGXTE9LNhLO7Ztd6kLiOvdJ
86fJYYRcUOZNiEfxiqw48SS6Gw7Rqj8PUv26ESDyk75Zhb5NDDn3g9T8FKhq
ruzPRgdjf0TIPhLcnB+nuob64JBTyW9zovSueLswv/gppJKOVEYYk1gZftnk
vFM7Xt16EtCdQiIzetGPd/O94MTejrp0WgQz0+WsZGkO1jOnnB77E4hlfhLS
tPrw/nbSVRlDErZrLLy/DlciYdaI37KDRL9IYHXTjofhxr/m3baJQa95+2Pc
shsPp+Xzl4QTOKNoe9BXuQh1WtFRX11J5NloD9z/iQeuvdxNnxkSZllcnV4W
D0WaPd6sryKM+MboR+oOQot+oCieRiAqaNS48H4vUtnjJSf3kkgce19XeaoP
LcJzVqMbCCTtPvB8YOoBzEW5XaZMElNeIWv0855iOmBrQ3kggWdHchSVQnpR
3Tl/+I9jBCzPbAwu3tuD2NAPg0il/MBXbpGrvACHTFhH33wTIW++hzlk0I3X
Hhv3PaTqfdUqu5a+joPQYWfVVVEEOmZy6jj3urDdXeq3dxR/lr4Fcf8WXIR9
vW98tg+JsQ/l0gV+PCyILLIoqCFQr3J2T6pCF2IL4l+3RIuRdTXKj2bTj+P2
GT70EDGOyY0qfpnvQ+oh/XuLmQRyKx+kGxW04a9+TY5AgoSd3/WQ4PR2cI4q
/XyVmt9FtCLVREM+FC2jdT67kxgWO25ytKsC815i2CqKt+5VafOhso9g0jrS
kyJJYgjju8Lqh+G5hu48UiNGUFZFrFtmC9Z5NqTwdEjoZm6tVbj5FIl3XH+y
FxGwMTJTqnbtgeG6IQcFSt/u/buV3OKfYSr7wWSeOYkdJT9ecZRfYEfEgoMx
VmOImTrvUarbBY3fpBNYkgSyg18vXV3die0xv6dwGGKEXDEUqq8dBBqP7H4V
IIT8mrpak/VDEPw+GpufSKJh7WwMcbcDETyRYyBXjBTDOSmDE3wkxwVWBF0U
o2ale9ZhHhff26cnHEsIWOz8sODTtXZs8m2b+65N6WPOWHrHqB+ZUyGnXdJF
MJwPn55c1QnLyuOONv4kLqculmf0VGBZc85ndapfdleMZls2DIB1R/JX6VAC
jzbqh7m09SL+/YeRiDwRVBpNtc+H9mJ1qcP08kUkgpVEa0J4A/jUmmi1m9ov
rKkN5bRdHbAJNfgt3pZAWZiojT3YgGKvvIYdi0m875IK6vCl+HZjlta7kWgd
q9BW2VOHAfc2VU0GxW/a+NEHOX04fitaeDtNiH3JnCNXZ16go38fWespRJIJ
fSJ34QAmio0/Gm8ZA60yy7P7bDMGhYRHE8WboVrnnx5V/WjR0HfjeYrwsUai
OT6WD93CFXSdSBGWLZDlOem1wyUuTXNJmhhTQb4tRxobsbCE2zhF8dDxc+Dm
Up1eOAytP+kzTvn9TX4CKzAOH8+lb6RT/Cp7pzsWjPEwuTQyaHUdiYTN+hur
nLhIfBm0VKGBgJL93APfe73Ywn86M/JfEfzjaj+u/9YCZ9lCc6sNJGIyy/Mn
JYbx9oXVl8HTQjhNBr4tyxXArIgT9aR1DGemB10mftxA2XePyc9UvZpbZtOF
Mnwc0J1/JCqg9oO6STHjRg4aMhzKi7dQ/rY8coa1OQ8lp3YmmVP9nK6NW31d
aQhtTp8sCh9T+v2iOMNYMIQUsx7B579GULZNIahZpxnDNDVXh3ASMnm72eYn
etFnHS5rnSsC69DtmReCJtTS1++iGZDwUE1gp5d1oISWc2VPmRhbM9UGOmxL
kd0/5D6zneInIymJKehGk7/yQwtdMZ761R417WqGisFKVb0zlB+e3SbuzsqB
3NCR5H+o/0y4quy+MAUOLkV+0cmRJtE0pyocYfgByS75W6j3JlUSq5vK83Hx
23G9WQ8SloZtLmluz/Asf0rF+g2BW9JGKvRSal7D1yUTl4UYvmNQsaewH3Xx
1nRpyp9OMlXpMZU8pNk3ewo1xPgfuD69xg==
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 185->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lXkbNrJECG2mUWGYS4XskeVusZR82SZlWlDZ6mSZFsqEZBRZChkj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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VO/7xylbKomSssVHZa8UofKW4msthBQVEhWVKDtFilAUFVJZIoXK
mqLsshuMdRAzZ2aIiJBK/M7vr7nmus5zrufcz+t5369b2vGyxdllHBwcpzg5
OP7/twZbtJYrtcPthc26yWw6Cr61hw+ZdMH55bvgYD8CcmU0bYGWKuzQHt7O
FiCgnvP2D62nB0aGL+c0TzBxL6/BJyqiAzz6PDuEnenIO1DW8sl8AMcFXNtM
3ZkQKZE9p1XZD3ZP7aHOZcOwaPjwWEanD9+9BKT5Z7+BEm+T25VNhYPWyFBp
aT+Kz2ZLdh3MR9j7EIff3AQ06J+90yIo+GKcaPxJjwFW+bXv6zZ2Q8v+v6Aq
s0EsWtOzWv17oCJ2xXTPOzqKo7/xNUbUwUJt/Ot5dRZuK+cbS4h1oMO7KCRf
ko7q3eZ+YX97sfuIoEfoyDiygw5vmO2j4fxUqWjhaSYGX99+fes7FZSruvI8
10bxT2qo0fZBN+wHqh3GVrBRL0xcb9zfjGtOXsuzTjPwZZUZNeUBBS1X907k
Bw5hhHp03SslKhp3HWq5NMmE8fuQnFxDGuwL+Y2eaNLxestVnok1VSiNODFx
JoaAXbPn8CPzLpzyPZ94UoYNJTHtLKGUFHiqHh+aUSXg1nckcA+1CxFeSrXb
Rpm47ZeZoUvrxroCtL4SJJBEK9jPyuxC5oWEgrJJAv116sVJ8VS4GguXx75l
YMD9vmLIZQru2V3XYGaz8M5JaoLq8gEb5gauNbUywH9HsvlOIhVD+Q9OWz9l
gOOn91nR+QREpYT2udgTsLAdXftSoRNvGG94vYyY0NGT9skOvIXdV/usy04T
qPsr9EdkfQt0KsqWJ1xnovzgjrIUogHnK35O7RUnsKz4j4aJUwM6jXefDVvF
AmGjPZB1vxXWORumSzPI55N6KOKThdDNmFJ8rEzW4/YtFXmvCiTF1YwFHSOg
lYKNDO5XSHY8q+ioRGAvj1TAl+00uJR+ylsj0AXx9iyz679LUMvdenaNOYGA
zd5Oz9XaUOFRE7/GhgV3YyPpgxpUxOz/ISUcS4dzxSqhRgcKlKI1nd/fYGJ3
0Y1/vPGNECoXGdB7zkTlXssSFaN+aMUFWdyfGcHIjcKow8e7MHvtg+dZFhsc
E8skNRL8QFHO+fPAkUCIg+mLzw5UHLJfY9y3fgSL1AOv1vj3QdLPo0/iBwFR
Wkb8HfEyKHLyFYxsI3BovGttxuEuCNZRDnm5fsVH2ehoSPegTnvc4dwv8vyi
UwzmfL6gND4rIy2DgVWaCQfure2G+ubTKqEeo+D7kuL6ra0V7htHUsTkmaju
bTZXX6jDR/5Ay+9XmAjtN546w1WPZ3euJvdsJuA89tqhktEBuWsX5H45E9jR
ZGVvjjLwslZJ+5gxMF9+qThfqhlnw5jvKngZ2Fy7lLznYQskHmn8srg5Armw
pMs9XF+grH5V984FAo9mfY5ZydVDWE7GrkKXCRut5iwpzi4kZ8Z+5NNiIt57
8onCnxq8NDl6cUMgmR8DjS0XgztI3gPco4UI6HWp+Ke/a4TC+zKuthg6mnq/
1ca86oH4/04LxrqMItpzb2oevRNel2pdR/wJHAhgUIMNXsB43emQEpL3M6ob
bo8L98LRfIPf0HwPnC/yJuzPKwbVTeHhMiqBdr2DtecWC1GtudLn1VYCfAOv
2B5iReBqOCPhuo/ADXnRp1WbrNBe0LBRjeTXPn/XMl61OHC4F24esCFQe7Rw
53K1bgQMPFux3oSJlY4ixc9ZA7jPE78psXoUc6kOngmbyqGeov7M4jeD/D6+
69b0FgyGfjflVWJAXuLE/i1ybYicspkLziJAY2lHTMf2IXFajCFx9xuymlYH
PX3Wjp06nQIqRSQ/wyqBC5PNqBubvCdhSf5vv5oxzNmBJnPa3gldOri4DEqt
fHvxgebbkutLh98X10WFa5XYXeNKbWcxoGNybNXa4TdQleAvVbAikM3tfy0q
qxlhh2oT428xUL2omV2yVA7+cWl+bkMC5dnyXVcGHsJodri4yICsB/e6uoTh
DygIaPX6q0lAwuPO8nCVCjRNqM4LXmFAIc7Hd3QFBbpHFD7vCybXc++5kX2g
D48FJGPiFcfAFtc/uDa4BklRdSxXN/L8Y83fBTgWgS5t9Wmchzz/6afcSYpZ
sBi/6TIeR+DJ0g2dId06uN3XsLxymUAk61eGolc1pI7XhBh5kHyFNT3aZEVF
zf/0Oa5oEPC5d2S2VjEdIrw6I8fsCLAypMdGLdqg4RopL6ZG3u9wZ87rdzvx
IrhzT4caAYo8Q2LwZT3cVPzN14qR+/l1AVdqq6CbwD50vpVAq5Oi5NB8C741
zodrxjEhvGmrcnxFL1q07Aru+rIxRKMsvFz3EMGPh6VNTpL1CZ4v5+VuhcG2
+U0avizEmPoLPhJLx9REQ+U0yed4i+zraas+5MRF1UbFj0AwM1/yxOo2+Psr
Sz11ZMDa+y4leFkT+BxktQ9fZKD1bZ5c5kIfCCWn1q8KX8Gje/p8dEkTXqQ5
1k/LMpARZPA2juhF2GemnizHKJK+pA0e5mtA+MK7B3olDKwMUDk1fLwblT62
nDOd/XgRsytutq4CUe5nff9FkTwHVtPUVb5CSF+dr/YZHZXOZT8T+Xrx1t7D
VqaCjR0qoiPRkq0IjnxdIXSLhQZfuRklsl+IaC0Uc1my8Uc2YGDqSh8m6lr3
JB5jY7dER3xbWTnyvqslBvETkMkO5b5C8hn+oWaxxIQFE9nS2AjtZuyNsPfz
Xs7CuWy1XVa/u8m6X/KK2zeKaiqxwFLpxQtuk9St9Sx8NLWN1/HtwmDOkn71
bwJDXs5HZr36oN5hPxogSIf7n7TAQrMi2NeIz1sOMtCjUZrW056OE+4fCL+N
BN70uvglnayBUY/aL+U8Au6db7fkby7G6YULPE7vCEQtNWQOe3fCtjXQd83A
MFzfLi5nBLSBpZi4jPKMiT4RK0mpiC/43JHEZ2dMgCNWccvPWEPQOTZOa5J5
cO5yYZShdCmMmOt2zLsy0XN3vHEXZy2Gb3oFfvNn4p2LWewmyzzo2w/InZ4m
1zd3KP619kVRe8TDfnL9YtmpR6+2tiNcQDLSj8xjcWuj91UFbdCzP+FVqUfy
eVFXv/7lO/y+Jnf6ZgJ5PzY6JFfcrIdkwh+NLWS/y+x547u/ph3lDdoRp4tZ
sBEXUDHYVgHPlEZbHxD4oVfN611Vj7f676sDi+lY6H963/xfPSJ+Kg98r2fi
Z2fGzYXRFjS+lvqk20j6HGHCMtQn+3fwi7NW9wiE893n5A6qwsCT2FTJDgYO
niyJrdjwFjKNOc8HyghQkzZ+nuhuQbG4VGh2HB0c/UOftrDVscryQece8vv6
lyYYkWGfEVAs0e42SyAiMdfCMr0Db953rgl2HgHHV3dVWnwCuDZ5CNRcIv1l
p+Sak5/q8Oymq81dUyZ+rJc+FmuRiW8WnkH9VwkIOi06mAj0oCVjo+fgASbS
Pu4UNuTtgLNNk3OWPhOrjM4pB082QeX4Tfo2CSY4VGSq39tZYWyJtX8ruZ/w
/DC3tYb1sFi365TJCiaeqKce+PvpPSgCPDdiyP6jFLgyo8twAFQ7x56cA8MQ
MmddPz9MQ/SPRsm990YhKEIzMfHuxt7tbarar+hw+3n3220NCvhWbRu4IM6E
oGrscJhkGrr2ppe1kXmUHRT5UlymEylKE6oa3EPQmd2cpeBGQRrHi+JXZJ5f
zz0QV2jah/4x07UvhehYmoy8rJ3TBZ4l/79LT9koXzl1yo+WC4uOkGJO0o8O
ce16kGD2HtwNX/Umc8i8aG7e0SPcjm0X7nsQciOI+0/294JjF3ozxI3T15D+
Gti+RN9eCdU0sWgZEQJNM7YuCycb0bBXTmRvLRPqXnKam22aIdDFtRDeRNbr
TcnXx28fw0z2yInlZwlYtuUfq+ymoomgMRXk6JArOXTmYmQv+D45GQi+ZsHB
2fPQxXkq3vw85fXL6Ss0iAKBLOsOhAq6vv3xhgEDA8+P8SM0VFbumqKQ93Ne
fuU6bZ4uBCudefhLaQj7lN8kFB7shE5w0FeBJTbuKTFTHFYmo51pZhlP8j1U
8mby3OokiKZwhxq5EjAMChOIuNMPlZ9fv7TJjeEBY8uKEScaQqT85n+uZsKH
x8KdsqcHo2fkDVx+sCC3cKOUi/kBzjJ1FQZdpF+tdAjzqi5C9eixBKdKAsWR
+voazVTweH9mpxWQPN/6fPJ86zvEKMcnrvhM4J9ZcEioFhUBM/3f/mXRMeTf
/chguhlKiiGxn9hs1KY+zrwb2w5Cf/PCK3EGfrxeUDkymI+VrrIdbU8J/A51
OpJ4txafAwb3z3vQEXrP7IeYVQOsgxlf2ddYKGg/0y3MosHI/eLWXyOkH6QX
qaXvbMSjkjVrfIKGYfO/r9v7OL5C7IxD6VwoE6IUYftR8Q+YDpQ+vaWUQGmU
Uu3/zlRijjW+HuR6ywQHjfJlNMw9vK0i7fgNvE8sZp7oUFHxUT/NmM1CuZl/
6lzrW3w+qxjFuZ6AjuSn42MZVISKtEiNmA5il+1GsVh+KjI2E9MW2gQ+cBa7
p5xvgM2b+YlnwwyYjszL1WygwT2zYmmSQe5PP69f52EljGYeJhuO0aFU85d3
0aoLWtttO6AzCPX3jrqpBm049PE6d8UDAjwlVbLKd6lQkdhBdylkosoq6UAW
me9UI639T2JHMWh9R23viipcF0sKUFxH5u9FLx/RkB7Y3lEPZ3zphGe/bcLv
u30QqPtwqoB/FByL2pX547dBnPee5T9PQPf9HYN4vzpIV8p5h/cOI1ND3kdc
sATfuB9vkiN9paPJi1usgAIjMSMZ9jYG+HpX/ani/4SJabeENRYkD9fusR8p
lyE8N/cf5xYm2vfZveQrpmKljKFeBek30VtHgwxs6qDWnqfh84MOk9Dgp768
FGzSiStfGBtGneZcXUYTBRl71RvTAxg4qdcXEq7Uj+gDEjxh6aR/H+pJnR6t
xkyHumgeySvXyR29hVPt6GppDhz4OYQ/Efb7H9n2QtDz8u2wXnL+2V7KIbqh
F0Nh4/r39rFh757cltLZiz+T+X9dbjPx4G3B0cwGcl6O8rZMEaYjSH29u+jK
TlzK9jqYWDWIOHU/u7KOWswFyv8rCGGi2F3ZQcmrDNZcVEwmMvC3p7iiP7ID
ggkuzDayXzrNHwlOv1WOG+vny+ZamXDbd5MRGl4Nnm5tGcp+kpf9Sis0a+vw
8G/mCVMagcAwxWe0Pe34NqefcfYzHTEGXftStzzH/L4rroWnCMROHu9e2tyL
45Veu3e9H4LoOSezoloK+HmnTGlzZN5sypxRT3JD9eqWnGny+d2pyxq6LWox
HnLhpJEJgfmTZhllN1/jY6TnPW4XAmP5IhopmlRYtrQR+WReOi6d4zH6XgP5
R9sLPqQxEL+aSu+nNCL5nJfezgQ6flWz3TKGGxGRU2GrWszEIeHKVZe1uxDj
/XOz4X8MyColPbX+nAeFF1X8EqTvd9SaLAifqkSc3AxHmAITGnFTn1WVq6C+
cthYZID0u4BjMjs+PEanYcyJ6yqkPw25JqxIfgt7fZXTYVsIyM7OPKcod8JJ
6OZvji90JDi8sfh9ox1NZ1g2Nh4MXJBX5p1MaED5QuqO5bvJ95WL3hLdcB9K
X8JS68n+9C578lNudSvmO/ombuew4a/2eCJyIxXBZdmbK2KGQTjFdL2+1I8k
t9bzHGMsHKMFTqwtagOFc0TI+x/Jl4dHyNaLnXh87nCQAXl/z106uiqjrBfP
qwOExSls2Mn/d+QolYZlFmLb15D+O997g/Ja8AuYxSmdabFMDFz13fVqvg95
45qcQtuHUTqu+Dq2vBs7cnRGs66z8cO+sbtodzsu/jkwb27IxMXF7vBNTzqg
GaQwt9ZvGKI5SgKL4iWwzO1xLRYlcNiQT4h/sRNtCspOW14QsPm5Ve9d0hMs
i/vfcQlyfuKAidg2ohq3rC9zWmQSWBltUft9rAMbdm/bNEjyTeF5t8LtViEM
rvGdyD1CYJp/bKFxeRvObKk+uq2fzLPyN93cva9BD+U6nrXAgBlvhdWAGBVi
DU9+V7WwkD31j5c22wdnwY7k3AOj8Jpy4c2/UIGqYaYmL4WA2ayri1ZcOVT5
UyI2jpJ+XiTuObUjE1KlXEKfSB77nVdcZz+vQ86xc6F7zJkI3/NA3/tZLTxX
GFwNLyagcfdcHy8aEN8LKa8oMt/rC8Pyp3ow43Fveff2IYxkeuXv3PoRr3Kp
hQ0XyXmRYrdCc66b5OR+pIglyV/IrbUi5b3ouRY77HaK7I8SnV7uagkwiWRJ
LZgSiFH6PThaF4uow7tES8h+eCq5LqXofjsyGlelZCsQMJ1I3Fpyg4r+N/xG
qnl0mAckc52MrQMHh4aScAoLhzyfXBEzSYV7pbvWKrJ/lq4+qs0Y6cAFs7NH
8yeGIJC+8rqQ9n1s/buT9Y70r603NSx8/dvxPSvhAu+jETzUfO7U+aUddbdj
Pt0vZiPm14lZtd5kyGUpBeuQfpBUPBiS/7wUorlXD/CRPuO+9vSR5cuaMRhd
c4r7L8kzSzry3I96ZCc83+hsx0Cx6sfzPz3qEE+P+M9VnPRFyWrVjtEmPKvX
tdMJZyGLYbopP7oHer9TyztDyHl1puDUk5gs2PVXaXmXE1CVrayyNaRBZyLd
yDSFDa/Ahmy15H7kPTAJ3LR9BKkta5o9FjrhFW9IzjykD1vef/JCrQW7Ds8E
SDyiw3nZreq6Y6TPlHn5eLjTwWfq4STvVgCR0dbFveS8qvMv9WJlaC7EJ/O8
r5PzAoeB3XvrkSL0ScnI5jgSSLZ/35HWVwwyrmV6fBnYrGzn32vcja29q/sZ
9uR9YLs0Njb1Y1LyxTJOu2F8nXrqWUT6wdEXxtu75RiIurPnfHp1Ax4+0em+
RfbzhcWuROaBSgQcajUfI33/EePZtV/NvZDfsbyo80Y/6rbEz67a0439uYfz
NB2ZGAl8XvT8Uh4cg+wYd0NIP1Je4tA1L8KlvISzhy8QEJ6bUWYc7EXSBVXa
zwImnnnDoiqrE+5y9dbcz8j5V0Das+JYOxoD0+Ju6tIhnmcaOinZgugLx/+z
XWDi/wAdZBgs
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81dkbxykJYwlNSZFSoSLzi5tIH0wjRcjYJiVLFArJGoWYSGWkwpRk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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk8lWkYtTYYyYwlFWVU4tbcLA2yHSRJu2LKFpcwZVIkhIxSZuwxDFKW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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 186->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8lWkbx0+2zitjSTUjMqKR1BQqGaZ+mDJeNRWJUSqvoWSnLIWT0SIx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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k4VP8bxiUkIUnZEi20ixKSuiWlEkoqZMtSlErZlx9CSQkJyU5IthCS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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk4Vfkfx4nRtbT+ZJTsmWooioYib1tGUtm37NKvLialJi3WtEjDRBou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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk4lekbxyUj0+Yw2RpLVGNLiH5zrF+hMpXKkaKYymVky5aQGUJGlCQt
o2Uw2ZOdsu+7o9BxOI7tvO+baJGKLJX5vfPHcz3Xcz1/PPf9ve/7832UnX1Y
vwkLCQndodd/uy/PvDgrtQ1+gdZTi3tJMMW8vtdn9IJzsXylSzwBF4WIyCsn
m+DYcv0eO4PEvgqbdbd/bcDagi7N/gUSIqUqD3rzmmBawiJOs0nM8uU/mFdX
YZ9UZVPfbgqhvNQ31o95qO74FNfJI/CM4BaYWI7gYo/fzzZ7x1F/QyjAW7wN
qgZnfxp6RWIlFft1qrwXXsMyr+z0KGya41bulyzHLFGrxzCn8NqyLOm7Ti66
xXeeXnYWQOolq9eqgo2dRSq/trIoMDZuW/fzsVzohUROpPhTuO//5TUrvhf5
/+qJJAlTqA+9Z/Xt6iAOrrx68F38OAJ/UD86lNgDQXrGzdLHFHSUjo6Z+JRh
p16NheQ5CpmjfI2gohEwDa6Zp24fx1TfoKZJ2ACsxthez1RJsCalKkTPPIWJ
np1TASjcWiUrz97VjR0P3v1yMZcEZdCcnhBcgnpmxC2RIAqP3jy7ZR75AtG9
gjF9QwpuUcLzroGdCNnMzss7SOJhTcwIw2UEFsJmOfOx4/D1CSgq/JCOq/O6
rQX7KYSb39zA3pMO6fYhy9OnKcQ4rmpbjK7FHK/t+gllOr8LsvNLZB8UlTM6
bR4TSOe8Uf+toAcezhtiOAQBr+3ve5IteLB29BAS/R+J9y+sHRvr0mDWMrpt
zJNCvMSK8VRXLjKXd6j2GxCwZOkYpqkMQP/f6b++7xBgZgPjvNPPQ+A1SH10
MiXQ033JIk0sEy7Po+2KjlHIL7yXnoc6uNlPH/SPpuvRal7OdM+BWF2dTtop
Cho+gn3SpRzEFouzboUJ4BRxqL6z4ylq2lQiWAEUFMd0zr+t5WIiwHbCrUWA
tRcVZl5QBdA845/Xf4iCmctIiU9iDR5dNrL7+hOFYU9pBaQ0IeeKro27J4nO
8c3nGvgNGDSyC7rxmkSc2Tat6JwazHc+W2OtSME3e3/KXuVuHJNhaUcYkqh/
p5knORUFdxG1jZd/pfWUP3j0lPUYmB55lvePj6Pvbn2i/o/9eCt+YtrkewJj
laNcB3UOJp+1iDDFKFRtVEtNmmyF8S2+b3MSBXlJf63IjUPguqbrlJeTiJLj
sfVkhqG4i5senSLAfNPixbgVbNx9vslQxYfCdIlPyde0XqjtMpwqzqbzexAv
bXe9HOPDcs+F91CYUPBJje3koPJ3LYYnn8J3kp2fxMM4aAn1DjomRGCbWGyh
48p+hO69s8boPoH2UuKCJcWFZA3/8eiXcZSsGrNXyuEgUUT/yJNcAtVudh7a
Qz1waFvnv+QmgKOz3OOYhFx4LE83aZ6g6Lzdz5el1+DrrFbtKH1eq6Kp4Gba
hKSMoKDQLXT/NW1yLPthBCxVcvvAkRFUGxbfDtbuQ5aWxA11HRL65etSzmV1
o+vDn0anHWl9necmn9lzUZe8rbjXikC2TRFl+0szZs7axXEvkxAy7pK1VR1A
apSttkkbAR1+lRARnIFFOf8vDHqeo6qV1nfsG8Fw4suTi4sjSMp+RDlY9+LA
8LLfLyEENq1ZlGP5JWJKuCI215bC9lMf7szbDMK6Jf72jg4CcqtnK7lvh+Cd
6LEg607CLDRdVDN3BFe/qrweIMdxtyvDYb9RH34wFiyG95DIHs/+e667Ckv2
YlzdHRSUlovEtfyG8PSy+nuJWAKGZyjGLul6fJh4vj7fmUIcx9znysl+rF4f
7AQ9AYSk9EQKWWzEnPdsnt9JYaFMtLuZ3wGhNoUw3QJaDwOJhD/jY5EiNqz1
43EKSTZ6zm+ucDBQo7N16IUAh89Juy5/7gLHOMS4mEFC8fPbot8De1Ci739Q
dYHAuGvV2YFj2eiJ6O3otKDnScE/t9W0BzEqa85f0KXn7Uig7/7GLtS/vuOh
EU7zRZvFvUjR9XQ9PrNliYQ8rs+9HOVAwXZS1EQgQIyt16CDQTsMfWUVn0yQ
4Gsb37gVykGWmMw30VESay2thXq9G+EmrcQQpfl/5NqBS57kC0waGnhrp9A8
l0hQXPd1COyghaa+QAHCv835uFj44lD2iCiHnqc4plNail4/BsdczsjU0Pwo
UOtPyXgCaUVT7rftFKpXcw4HyFdiYcMLprYVBauJwFJxazYkpyoljO4QaBHT
yE52aMOCTZVmMO0322z46mLLncj2bisNiiHRqLmf2vq5DymR2S76ewiYiVTM
NavmI1rY3cuI9h/uP4fPXrBowyoN95N1HSSi1xxYceRRJk5xH0U0HKbwMNCM
vdWtB2HJ9mdVSwmcmpJqD9dqRTpjn8WKq3S+kWeVa1z6kW+zs6r2tQA8tlpb
vloaBIs9u986UGjXdXxFRHbi2g3xDE2a3/aseyGOTU1YjMvZdeUmCUb+zTH7
/EawywZsA+boeOOmdn/+2AudnNIoVwMSnE+ZrZn3upH2ydlsA0XgrrLSb1qH
GxDAKuu7EUWhcOZkUnpsL65saZyKrCXwRuOLeM7O5wgMKVTmF5JQE37/IOFQ
NRbSnJXCDGh+EmlyEt+4MN47km8jQyK5QjfquE0DwslNaaNZFNR4P3WdSOjE
ATlhDpuOf8xNQEX18HB46h87uT4CJU9kjO1dBzHvVtU4EUtiKV6MjNNrgp/f
0XveNbS/M7euPLO6D2EBSSE+TSSkVc0CZvLCsMAffcmh+Z4UjOKsv+vgbIWh
XbS/iW7Ond7HGYR6Qm3JoKgAb4dtrhms70bFv5u7Z8VpnkisOxdRl4kVPqa8
1TRv7J8UL83YNWM2JUhUiOapkJOKfMPtRPzjaJrHpO8X/vjYvChVjaUdadOn
3en3GJ4fecz/+s/cJyNSgEEpx0tSd3gwcTqq80fNONwcAp8my1UgJMSxbl6f
QnP1XSovfhCNq5IfHmGSUNoTbPWBWYLt1HXTcNq/Hk4ays1rNULjnFKoBe23
hkOt2T868yFd8urdbDCFyMTJgu9UuPCSbd8YaCdA0KWs8hy0ov0vvuzl+/T/
YYdv15b3f4FduCQ3ROv7f03/vac=
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 187->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8VWkYVpGrRtnrRoulJtuMTMsN9UhUJC1ESbKNdCOyRabImqVJSIut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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8VW0XxlGEJI+IkJISpUGGqLikTMmQoYQkRZJHSKIkDUoZUhSKSGXo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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41Vkfl9GQFhQyYUK2bkiSJPrwtoxl7MQtWxMyKkuklEp6NaMQFSoq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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns41dka3kqREo6SRIakSWlcyyW9NChJ4zIjUy4pzaiY4riGULlNCEmF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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 188->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4lekXlctkpJMxjahBVPSbkFFyb2nIrQZJU8TQQYwTcolTjEujQk2O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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3cgVf8fxkWyJW1RRIMUSsh6KolCKFSkZGU2VFIhERUiu5CWMhIqe6+Q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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk4lekbPoVSZJemZUgYJCJLJjO3nVQGySGRGpXSZsaSNiQToiyHNjvV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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk8lekbxiUjiiSiMTWUpUiWrJnDpUgahBgUg8iSTmkdS4pKUk2iKaNC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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 189->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lWkfxk1JkhxMpULJlikjIkxjulRMTYtSSaQsqRxZjmmSrVJhCjNl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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VW8XxW9l+kmIRgqJiggpIVmRqUKGBiQklUipJFOSKA2kSSWZSaaQ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8ltkbxm0VZRtGSkiWMtKUGUQmlyjZs0QqlYSSYhRGKiRLGhoJIdmy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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4lekbPjioCGPSNKiYQkhEIS23mEEYRD9Zs8SEENNUkrKXyhpiFJWI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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 190->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs81NkfxmdH0U4uuyjR1S01UULSzZNWU7upaHRhSxEqKipdrEuy0qiI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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8lG8bxZGkkpKlkqRItjapZDtEsqdFVEKytwmpkDKVIkLZQhSyhlGS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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8VfkfxlVEESZCqEhkuIwlk5bxqAYR0bUloyxlqcZS1nZrUgnZUnKn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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk4lekfxvGToWVooTIlTYliEI2QutE0Q9lmrCkxEiWNFH4VkzoJCTGy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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 191->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs8lVkbPQjxUUppapSUJEoi97Tciowaim9qktukC+UampoKuSRU0qdD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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lG0bxidaiPpQihY7IUlRaHGqUOQtpJRkKYSsIVtJKKIsJcneniUh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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs4lHkfxtVah0JCqk2WyLZaYmsd2uUebTlFJLJyyGlFXGUdSgjVrkQr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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs4VPkfx0lJDNpqkdtSQjfVFol4C8lSRMhtN5F2VWSrrbBb1rplZYmi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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 192->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lXkfxo+aspQY0shWo2yNka3tpXOHslUyTUQhGlvRgmG0CWkYGinR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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8FW8bxkVJi/JLKJUoSVIUIalLhUpIKoQsWSIKZSslSSFUttImKUuS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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81dkbtiVZRxRNiUxZsmYJbU/ZRmmZkS5jj5KJkjKWUIRqUvZCliRb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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns4lVkbxgk1OzVE0ZitJKecRk5JuEvqk8NEDokyMojoIMLXJyGTplHK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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 193->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8ldkfx2+2JMskcimNVDRKi6SSfIwkjcbWaiYSLRKplLSpCGnIFS4q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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmGk4lP8bxS2VUqTQpiyplIiElHIkSUJCiyWVpZBUSkmRyJJs2WVJKUsh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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk4lWkbl2RphCLSRJLkRJwUYcrPKFFRkoykj4REskSylCXJJyEHqSgJ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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk4lekfxm3TNM0hSwuhDinKxLEUabn9yhAZ26WsP4xBkSV1BknGNqdI
yZI0ScqSJZEQcXLIcgon23HIet73lfZlIpmmMe/88VzP9VzPH9/v/Vz3/fk+
Gr5hTv5SEhIS2fT6b5dp+Fs+L60LloEGESqaFIarBwqHpR8jus6nucubhNbR
0h9VIgVwLx+ruBtLYFjn2fSZkFZcKeROzJaQMM/TGDaJyESCRhqn3p2C/EgX
d5nTKLaqbN31w8w4zIPkbew1w7DKJ90r0pu+t8ruL7NtgF7FHCeZRYGnd7bI
3vQestLKOYtSFHaynLRMf+1E1oqru6vlKZR5x1180TAIlv+tp6cjCOR310X5
Bg1CSt0+Q1qWgOrHNebptS04pm1qYH6Zwvme2g3yvr2w1zqk6qRD4uyj/jYn
20FwNrpHahMkuu+QzBVLe1DFlZktv0OAURH2g6HdAH73eFs1RIixfK7VWtJL
CK+iqFHregpT55kurJ4ajJ7tWVimR58fLQhYavkQ5xrP/O1JwUd6pi03qAG5
J+W7ZHUo5LpMd5RFP0KEtedezlkSU1HucW1XBXDO8ckdtSYgUXZytkuxEmyj
+Z5faP2zR2Pia3f2IezDmvYnrwmonf7+05VOPsw0v9yS4ZJwDm36TfbCIEK/
Tm6pCRTD4a+aVaz8Yvh75G8IOEjBViffqvKsEHaXBubylcUQbjTwk9g0hJrn
CmodTQRsq9Kzlm8WITFf/uYOVRJX3OYvGe0Rgjfp+qTyv35CBbPHSR6sJ01i
bRooMNVbmDH32+G34/mkRzuJqJHQOeN/RLh89JJNkDEBvll20pGvPMitVd5e
PUxCcMTLzsW/DyM58gFegRSyZB0yHidW4ZvGusb2SAr16lOSjKMDqGoMMpKj
33fZ+fIY2WeDCE/OfD11SozcbuOvlUN3oTiX3fR5F4VeBQer3MFWXPjjlbdv
OYmkxGfJW5NbcNMiKKzpGwpjd981GUx34cFoiKfaZgo2pZ+ruQP9yAMhujhN
4P7W14lva3vRVh5vlXaQgKeuwYKivxBa5y79Gm1DYY31AknODmHkdrtj7z4x
2JJj7JGCp1gzL1RKmCDR3+jC/GwohJST5IVWPQITjsH6crXtyPB9xWaGkbBY
nWP9Xeggon8yTnyxXYycm1l7XdLbEFccJRL0kchZvi78zvo63HW+kVtvQYHd
Mzndt6oNv8XFy+/SpxCXwi2yu5aJupmRcbYvBWW1002HgocRrNBXL7WOQHRe
vlTztAjxU056O/OnIFdUrZqztwMpXB6jw5RE78uNtbrn7mHtTHbpcDgFKo0x
6+87CpcAj9TDhwhseLkprTG+H4t8xrW2HgqeDcalMkuEKCk9pblgIAaL7fHG
27QBasXvby9dSSGqqVP1l5UjUKq7/NheNIWjDmnMTqkhTNX4v/XpFqND0siP
VzIE2wM6BZsFU1AcN+TKfhkC561/y0WlKRTvd1Nw29EDwU4rv6/6JC58YKYZ
FeXBhR/YkUzrk5l3V+K/48P33IR8VQqB4K8Xx7vWd8KP8qQ6t1P4/PLe7OUy
HlpfN39bTdE8GYm4805JgG3X/tSudiHx3EaOKD3xEGM31+pzc0lwBlMMT1Xz
URLspiz6i4S2z4LiWnsh2Lj+zw46P7w31pNK0U+QylhWsnCBANu4LPjGMdpv
jLvW91NIUMUzrqPHG2CqOtG46XcKxqIkJ9YwH/9b831f7k+037Hr7JL941h5
w66mJ57AvroNj9btLMaePr2T1rS/zbNc9qsUReJpcGnbZZpn42J/zp+jQ0g6
ED5yK4/CqY+xWjuYIhh/ErE9AgnEhrhrb4+uAxnKT9FlU8jZuYf5/3YuCtWb
bTW/0HrYFkveHKiBiZwzoy+H5kf+5exnS3vhV0LYB1hRWHpYN+WGUTNCvnu/
W/05CeNV3VfLWgZh81BGY7cGiX2rtY9Upd7BX9pxjuOnKBx2fFCTktIMgx/V
pKXU6Dxr8paZLVyH423H0zG2FCZaXbLVIvtgyC3aL+FA57dtmFmwiY/B8NaO
DA6FjyRx87DCOI79cdxF9xzNRzn3/dcUC8B6rxfuSus9E/azwU3nDtil68+K
QUIzgufwc3Mf3pdz5vdlk5DgxMZbJZ7DIq+g4FcfOm+RqSaO6Afb1lflBJ2f
thavQBPlXlQMvYi3LiCw7rVh4Mtj3bCwTHespOtPvW/btjqvBKY8P0aKOYXY
3qzrQfUteNalU1BnRsFym2AxzmEASxT8jpjRfFXWlz25m+zEtTmvn7Ytpevb
PlDdJjoAxolavhndb9SX4tp8j/uIdO0PXU/7fVxJZujCUxE+eDsvM6P97VN6
kN8yUo8o6u2I0Ijmz8EcXYvmHrzpaP/03XWaPxaZRrkZXAg+ZAW4J1Aw/ZDR
oOFaCJu2wCLxbxQcJoVG76zLUFYtVEmk/W4aw5AwjCjDJ9NqBovu/3yq4J2d
30OQm1gVSi9IPFTxKhoN4yG4mJfeHUHhedXfzLdP7iDGmPnZnuaZ1pKV1bZL
+DihuUNHwKWQam4woDcxjLBt/u6MBBKF4c5+RmfaYK7JsWkIoOe1wI3Ji7yH
Yl1vr6kttN6LBpk5K3uRf+MjI6uKgM7PFomswCokFTxSDnai4Hpaw347qwNw
1tu4V5LmVeZR6dVDVei/pbVFg9Z/+Js9ipauddhc/Sow+UcKTZK8ByKGEFHq
r7jN34rx+/Wr8eu1x+DxQzIjk56/yity9g7ndUPtVMif0jIU9PS0tIf8RMhb
sHWvzSEgUh1zmn81iqTtx8IHTEgkdHnN2C4XoIsTPzk+QsLgem9N+iMhjk29
qjFTouAU0oeMDRMw/PJEV/rKOMSre0ZMIkTIrnittZ/mH8tVovXbpEK49KWe
abSn/V2ZGdu8tgpZ5x86yDvSvLP5w7Ls4xjU3Za2OJUSsEuIXcI/348EN/La
uDqtt0o+s2tdFxb1hZb36X7mjic0OvOeYlEm5dM5+v/iSRiEHtjwGPyYjslF
mq+2GScPrV3zBPluWzpezJNw3f2JFR4zjhaGheVtBQrzAZPTohVPkX1VP+8L
h8T7zTYhbLlKVMxsKjQ0pvAvFLysAg==
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 194->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lWkU1m3FEDGKibKNNJGEIvWoqdDCVMpUQpKKEGOPmBhqkrF3G7Jl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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VO8fxadCUqKVJEtJCS0SkjpIWggtsiSEbMnXGpKyVFS2iqhU9gpl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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs8VFscxScKPTxLD0mTUkpcJVJNLRVClEJKmG6EuL3ETVKJXlQSCYWU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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41ekbxhExWVIo2yRblKksWVLciMmeoihTYVJCKEKIRpoUbQijBU0L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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 195->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns8VPkbpmLstqXtilapVitdtCWpxcOG0IVc2t0fiRqxYSoVuVSyiawl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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmGk8lH0fxSVuSUWyV0hR4kaS0h3HllJIWUOESGmxtSFEi5KyJ5EtsiXZ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41VkcxhUmg2nkYbRoUJIoS2Sk5bW10CXr7RYh0YhSKWFUTI+lqUQY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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lWkfxg9lEN4Y5oNJTaRokgzTjCznQt4oWl5LJSH7W4RQKNTYRQ1Z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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 196->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lWkbPiktNChMKhktxjIxMU2T9UKS+kIlhEZSdmFSaYzGviRyrGmG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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8Ve8fv2WUUkkKpaQoCclIIW80jMpOSGbJaKgoKpFEyUpIg5Akqm/I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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lWkbx5HCSJ0aU16VImnG2AepiZ91piGFsi/ZJrLXSBQp2RpM1rIv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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk81dkbRipSNzHpUoosZakkaRQe3ExqKI1lkKJsiZBsTSqTtRprJaWx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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 197->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4VVkclTLpIldUZqY8e5FCZihmWiKvkopeSoooI67IGAmjlDA9iCkV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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k8VH0blpTCU8haFCopikqlUpckiRZUqFQqJEkihTxZKjyyJVtR2UKI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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk8lWkbNipR9s8oLShNgwopjTaX0ihL1pI0IVIU0SLLSFJKtiRkX84Y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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81dkfxm+qq6aF0AymGkrKDDGkNOKhGEuT3CwpFVkqka3GWEYhU0pZ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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 198->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8lWkfxk8SJVqkRpIUvai8llFD0kVRR7ImTTQjJPTqkDhEC6a3RaF0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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3kglO/bxUdFKUJZStbSZsmWUsmhCCWhkihEhFKiRb4thPIrVLI1SZJS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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81Okfl1BDk7PIbuXomEqSa7f0641NRTbkWDmKRVRsk18S2WJXsinZ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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs4lFkDpxLRjYRVKtESckklm/zSSCrrnsuSNHLJKi1ScomStC612qS+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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 199->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4ldkfv8oSxqASMag0bTeSvWn00aL6JbfSJoykwhSTJCIlaxRJlsQU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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VG8bHlIpUglJRJZCloRs5ZaEUpKtsYSiopCflCXKlqWkqLSQUlFU
iiR79n0ZY19j5swglRJlre98f811ruvMe573ee7t2XzinPlJTgqF4sBBofz/
N2JPUlZRfy2Ir5qdwV+ZKOk+dI6WRYco987cygE2kvTPdawUKofAdueHfFFM
2E4+5i67Tkf/0vz4H1osNO8o38kr1AsiW9fzuw6BoRg8O+OVDEPFycaWvQTG
NU1fsblaELrumtrdFwQCt3b96djeiL+yliG7lJj4gZAM4ZxPeGL+4v3NYAKe
ehkXB8e7sWaZda70ewacEs2d1zO6wLunSyhB/QvmdN2dba1K0TN7evj2CyaG
zj0TzlxGh9/ewRwYMeD6u7943KwPm169EJpVYOPH0AcTPbMGlD8qZh58y4Sa
5ANKYH49zKSUF0ITmTC2O7+65XAxpnguWvkHErA/Gxd8IKAF3N4LcVppBCTa
P/n8k2wFb5ls5sR3Fio/dnrVpjXhzLJMHmovgZk7dGEmQcc/+0DGRi4GaD/U
+R9WF0DtSIf3Ol8mvrP5vH7uJut3TBRfuX4El1hrtyfcaMXmw9Lh4W+GYPzV
zNg4qAopzJ1NUwfI+qYvS7fF1MKyx86Xk5OFFzOcF/kby9DreqMt/DWBau+r
fVSdbvj68MofTB2Bk1H+hUTLItiMTYdqTDPB7axgsMwqBz472d7mvUycOR8c
v0Q8BwfytxxOqWXCUkSPGWTVAjVlX5sBsv662H+frQpL0RAR361NzqvvVFre
z3IaMkX1Ls3R2JjJsvD4rP8BwTfeHfDJJLA9uiljzuEJdJMZ0eusCFAcdFxU
h+vh6vdJvUeQQNSbCKPS5BrQVPkvV5HzCZ8M0WA+KEDre40oIbAwE+Ppuijb
BXvdCKfKcQIFK8IaP8fRoe1Up5NN1ls541RhKNeMZms9ik0+C5GXP/Zw9HSC
KDl8PaZgGIRFucLRpG7sYwhuso0fw3Pdl8rrZAeQnr6VGLIcANXjtjG3az7Z
X9dmxfdkP55m+x+5lIPQseyO4Q8EynLv/tI92wEVOYPBsVIWdAPy9X1XVON7
y/3hS/EEutRdvvdVV8OuhpdvqzyBL3HT531O1eLai7XLXKPZJL7kDQZedkF5
g3MP1xYWbLlGTaMiWqFisf4n/1IWeEtZ+7TD2+FpWvdgQZ+AQHWmkPBgA+QM
m0u8ypmgqbmLNLx6hjXNU9ZsGQLUbVc3DTxpgvQLHtp5RyacxM9GHVkfh2sH
i68qeBBIW6HSyvG0A5yfFnZSeUYQoxE65GxdiblumuQ2JhNh2+83WXbQUVW8
I+9xKIGDk6I/q3bUg1DnNGnIYqKC4RDGJdWJv9zvTAxTmXh30PhzXNEjvNko
/cnYmpzn5ObnDPNcfDhRFVGUS0Dq9Owusb/NoEoTr+rI+wUzuVvS1oTB/hU9
jteBwEgx/1a/5V3w6mU865kZxVPRSP6ipnx4352JlV/BAjavUfTVqQe90ttW
8BwbGRc1Br9f6MZq0Q9V43MEdMdyvIe96BCROX5PPoSFfoEgLtrFMhSu+GH5
j6wv+NNQ16VnuTDWFrOgku+X6tLnrnOkwC+7wUnnPAEnra0eH6Y/4voSqs2R
owQWHCx35I10I8B6tqPThIn7G/YqvrvjBa8RK/ZfRwIcZkmhGSodGHXY8K6M
PohLYgrMD18rsLOtb++5ZgbeecWKaVY1YFDBqbLSnwWJo99W3qm/jf5zZaIJ
TiS+a0QnV2bnw5KywrU8gIXSm+KUK6Kl8DOaNJB+Q0Dvn7ReGyUFDudk/z48
TD5nPo7VaOjG787REa7v3aBoS6RInc1EfPVaL4uDBJ74LgR8E2jCiWZkaN9m
wKGs7e26fzXod+mUFf3BxtbqPYRSRjtex7pvkzrLhpnLJ9Ge0y/B2aRDpe4n
4OIwr3lCrwM5ZbSv7a/G4bX7w5Hv6U8RXmNXq0kl0KhpY+n4uRrFV54emikg
UDQ1Pb5o/hkHz7pd15IegvR7JQO//GY4XfSYPC3ARoJy5N6j7T0IFRWL2tPB
gETjqYnFqDIUqbvUu3QSME6K6hD5rxfcufY6/5V1QoB6fYU0Lw3bs0bX7zs2
inAoilxdaIJ62pXWI8IsnGlMVNon3QX96KLaWZFhbDb/HUJ0VMO7Xp+ddo+c
p7jQo0dn4iFZlnh98ynSL75f9pxY2Qqda4Jab/IJJO6bd/ld3o68iWOW74YY
CK5eZkAv9QVzWUHLseOkvuwWuCc504P5P5W231gDWBcty/xm1o1lV1NWjbsM
406w51xlFvn9CX6P3eMDOPFcSNr/Qids/zxuDHEcRlKFF804tRTiyW5X1vmR
/L6umtHN342C5Q67qU0sjD253yIV2obtW20W3I0JPKudrrbXoOGBT7TDLhMW
ak/qJEjt74NE193kbWnD8FahvjiyhgZOlwLXsd9MWD/dskQttRVx+0uKv70n
+fRR0qgstReOi2eXUicGodimfiXYjAbNvmKBQi0GfolTdF5rD0B98ISn9p1O
qAX4DdheqsZkb2CJrCnJn7V88Vb/PsLw83L/H2R/KvmE927IbULlftURLRKf
uV/WrumJpINy2fVeYxIDAbP7mrGxBok5KvU5QgyILd/gm3qhCy0tqaK39QhU
DH7oFTf/CGulx/+GVQh0Wrz7wvzdh5M/FXU9rhCIufnT6Mk0HYvPt/+qqyRg
Ob917Xneblw2fiLYQfZH8axAvbJ6I0IzEy44c5D5oHBvynhbFCYl4nl8yflo
7pB7e2I+AwVubv6xSgS4NH5InJBthqDghWHXEtKvN/aEypnkg67Z80xrPwt/
mUPioVV0hJz+0i93hvTr2uriDwKhaKaIulD/f95it/7iuRzc1ejLjnUl8aJj
7/hyWRGiVNaK8EYQkI1YlHQz+oRT+a4b22JIv46Zj1ztmYsl7yfE2tYTUOC+
te7csio8ao6UcdnDBOVdW8NwQSeMUjTLJZsYqN2Q1fK0vwQqqlYx2p8IhCq/
WGXfN4DDDtvb9MTZCA4hMl0+nIdkckI37RiBh6yX5n0S5YhXpOm7iRCojVLx
MPDsQreHQ3D+BAN5vib7HjSn4v66wRcVZD2/76xKbRzsAcOaY+hh3AgkXUyL
hNnteHZUIll2FRs6QiPyQn9qIcppqSJuysIXZZt8nz46dnyVrpOqG4ZexU+f
l4XRGDrxmptO9kN0fEmq+P4urHxMXNg/OA7q7hyzgLhmpK6aeX54jIGX9o7Z
Bz3awBumPrvwpR+Ex4jUIZFOBPMeCepb3g8zO/nkhYb74KQmfxp0J/VtQfYK
YXIbXLELX4+QfAx/xHiqH90MTX8T3Vw2A9VWH/PEBGoQbKluf/8tA8ojafUy
zHq465+plTw7DO78RkOuN23I/E358DiQiZkHsT9tpmsxoeyofFOZhR9n3/Z+
Mw6FUNetmKuO/8eX6IzMwz78Davb1WsyjMz8Xib37k4YU/9Y+JL+7FfeG1su
QvpDhkv71ggWGDupwzYprTC9sbHabIT0h+ogia4PN/Hxn/2RJXYE1IxuvuVu
zMXQ23SRkyTfbD33jzkXt0NnaIPf2bf9YJ9K1XDka8Md0ZKK9Eg2vm5q9t+j
QcdFiv+xX6dYWBkqf+i4cCZK7wkWCZL5dVN5m6BcVgee0RQzL5J6HjFd85O3
tQ7JqtZqYRUs3KK3wn2xALf4DB66RpB4YvBo8c/G4oKhCL8Z6Y9ev6tuNN+q
xHNFHs3XomzEvM1xiXnaAO0SFaGKADbeTA9bWun1Y8i4V/FSBxt+vcPr7gVX
4c2q5WInyLxknrDEsSG4DNqfCqX841h4Z2Z/yXDmNeSeOELcgEByutkHG40e
JGcJeRxX/IIpMSUuriddOESTTvnIP4BGF6MdnDKV+Lbi4hJl0s9SQvXnQpS6
sVlcKN5W7QvWrFeYWKh7Ai+9u40dpL6FL6+y+eFWhZs2JqdzDZlQ+GKq6ONG
R1Kmh8TGswSEVXWM9zUNQO4mj4p/1hhu1Tm6KDi/x/PUC2liYQR8xo+/1rGu
x5sdel4PS0YgQBLkpWYNzvgnRyT7Erj42cvPtr8S7cm6hfIrCJjpbIj2/tsB
/qQFrzRNBmwVdx7N62vHqGDcJ/QO4Ou1Temp12qxoeqZoMNdFv5oBrWyDvTh
1aF93i8VhmBIDZ60WtUGjXK7TkrzEMoHp/gcmbnolisU2W9PIO/EnvwnnXl4
J+JPiVUj8LfZN+NmeBUkZrf/2XSZ1O+FFter0TR0Vi61WLKXhdw6jtuETzs2
CG9c6zNO+qM6IyyH9OdGXiPevRls8GsV3Tnm2orHYv2YSCXgSvdLM1Nqxalx
jnmDHvLZ9vjzrQGtODRrqp34kcwHlMHjc8EkH1XDZXtJ/bjlmbR8UjsWXLOe
X8xIvf4V6+4kYxOH0O89+6xI/CqNbqMNh1TipcGSEHUyD8X5yeyS+NoEOv/f
GZNCcn6WLbzPL5Th0JR38uguFqzbvb8oNJeif5loaQapF5R0+//Wc56B9LbW
/wxJfrmm5GTaSOTj4W0u9uoZJkTvRqo3yPWh4tqa38fJfSgvUS2KsrcK3elz
4VclCKw9s3RL/a0mqEW0zA6dI/2+p8ThcGYzSuYO6bndIfNiJOc0Z1AWVM6n
CzaT+VhgheKfm7MZkFV0sAsg+eF1qGn9U806NK+qxd0/JH7VfGOFzdsQe85P
3/M2G6Of762W3U5HvZ1unvMQqdeJaocpgc8RMy2SH0t+r/qAi5Axfw940/Vt
Bji+wHV94U+fezTE5yokrOdj4tby54+Nc3IwmtkxFahF6ik/nHnJeXCOm++v
XBjBnc2XxtpKO/H46Yv4ANMxrLh19+XeiS7cMywI1loYg1l2zMMfQm3YNRLp
FERlQ7Ur4PeJixWY11nxaGCCAB9ROaE0TwNvEL3ouzkLgSvO+5sPkO87P8s9
qcBE0IuOZcKdrWgLUhU59nkEtzaePj5zMA+7j8npW+WSfma+UZpLOwaOb5VP
7zlB+oFeeNLvkgasfpTEUdPCgrCP3atH3flw12wVeFDPxMsEQ61QWje2DBsu
ZZH3D56J9OF2LMVfY9fepyQeqLviX3XxVaBekaIpReb7UZ3TupJf8pDgGchh
tos8fzCkTO12JSTvUTeJ8DOx6PAgsCWiFkpv/1DZHSwYnN86XafegO//Mgwr
JEm+hT+9NZWVhSCqW6S8EYHRJuMFLstqXPa6YHdZipxvasBh7xv9KN85nm+c
w8Iyh5TrrLV0xK6MP9lH5n/qc5O16jsqMDpqHPI6msCOhZT/rqZ0Yv5+B3/p
GBMu/uv9jOxzYWSwQJkm7+cuLRJ5ra0c3y24PVsMSH1882PeYksXlLYpGPEU
9CHvbt3eK3Z1EI6x87Um+00xupyQE5WJiOAjl7XlSP1fbbVddWkTZGLTb23Q
ZmEXTyF71rEIxPsggQ7ST3Org94bLy8FtfCaQWMN+X+v2E5XSSrO5URc/kvq
r67w5gPvauuhZ0q1KFtH+luYaPa2YxXwYGhMfe0m951dmWmfW8qwK05iJl6Y
7H/GoS4FkzJIL94P7FYm89Cqfjf/vBYoSNxYLXaN1PvWMyv4HxZjRKb+jxSZ
Dy6q2xyYeFCEF2+n4kdWE7j56EZa2ioyj5rsX6ZzlI1MHnVevfhu9H+f2yUc
xobk2O2rV2QK8UZ6H3W1DAuNu06elw8qxZ20+eU9SwnkFH3sz3KowcAJgmL8
jtSvRz/UOL7Vo4x7h2tnOAP/fRWB/5M2JFbOXqkWGgFnzoxHcXYZuOL2NvYX
k/uhVqakn24rrrmtdCwfI+s1yF+0vlaKAluLRSd5Ju4E7mTcpDdBpKMzLS+J
3Ic/Rx+fWj+I+hR+kYvOY7DkUd7073MRkiLDU4LZJP9fDshmPWnAVP6/krAj
bPCVDiRme7diS+Xt6S1a5HkSiXYzeXXoV9qSIL9lBNJle+P/RFegYF/rpUon
Fmhp991v3G5G7+CmY/wxTOj1DD+97JwDLZEylQgLAu7WFE37kF48WDTVpAWy
sOmEkvz5+R5ENn7eYto+iJlVYdsjH+Xivsp5gw4+kg+2GgO//PJAs/F0Y1LI
/eCX1enAng6ENW207godRVRyvf5cPLlM2Z6aU80m85/4ZcOd2rmQcyvzVj1A
6mHQkXDq7HvsUH1Xb29J4Ku+RYUPVy10CQtrJjmPndNXb0g19EGMWjfs+m0E
T3avYU3feYU4n5Yjz0k8hb2WXrh2n9wfmIUfrVxGIHF7cFF4qgncT8+9fx08
DJv/npvJBfZif++HvZKvCIgx7sfeyO7HyLI1Un1Zw/hxXG+dqUwNsum9EvKZ
pF5w+Sel3mwG78q8/sWXTEhIFDzesaQNqz8WcQySelrNsH41I12JCBkDo4sk
voJpwzd2t+Qi7Up1Ug6J51NLfq1P0W2Dj2ek9O8KAq9tHp9vEeqG/J2vVVNW
LKypc3a4J5cNqaKeDVNkPs0T/eK5W6UO7G02b9eJkvvpNf6V/+6+QfpUtdIk
qQ+TqQ6hOUk18G8RXzVE5nWKzDaJv78DsH0j7xt90q9o9n+dLp1uwKkQt0zB
RSa+WvLcs/Opx4ufbhestZlIINLT70V3QTjFnd5wcgSfKwWjH3eVgMUl+XuP
NAvBw5krD549Bfd7zDAv0p+C1//l2DxbD/OTO15zfGRiIfaObuGvDly0VWmT
orFh2m31if8ZHQ7vaS9ca0bAdo7dsuQGHTYJp9cV/GMi4Mql3bYbqzHRtTC4
VpKFXkmLbavca5EbXnNdMZnAgtSmPp89LdCybu/bR857/vZBzseWHci7Z//S
qJaNTybjntZNNDAG7Y6aRo2AMlJ4ap1qMqLrx/9EkXl4IVfdpVKVBgP3Jr6Q
CwzEJ7e00dTJ/eKXB2UFg8DzirgHzPZ2aLZoyCcKkPs21fV7wp8+tF/jeaRD
5h/Jc9l3nRLbkH2VT2xnwBAofkX22+zo0Bxt57ngysZCwj//yeVN+NtRfEmn
YQQlkwq++ak0sH0N3HbxscF9eU3xZoVX6J+T9hAl/aGGMt8T5EnHvt6rOa4G
DNzylXkQH1WNDrMG+fk9bChUyB/kGW6AVcvJQ+lzTAj3S2fE8zXDhW95qIsg
E/8D6kz31g==
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlns4lOkfxlWUqBxWJ0SEkOTUroruIUkHSiJWSRmt7SDaSLFIjtWuQymJ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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4lWkbR5nRTpmyFZmTDLKUGIkfkiSETplG2YqyjEiWb76SkJQ1Gbuo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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 200->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8ldkbpx9Z0nJFZipLUWkzlaZk+1omUjK3KQwjjMlSsoUWqYyIREgx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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2kglG8bxf2RFEUikoRokUIJpToouzKVtSypCCmKQkWWFhVKEYpShFSI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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk4lWkYxoWkhjKWomQpKqWmkrms3ZYcZVRSRJRIqBA5SoxINLZIJJMs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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk4lekfxmUpCZGuwrQQskUY2Sq3LBOlsv2ytdpJg0mNtbGUpkKSQbZj
UtZSjDiIEOGQDuccS7Kc932LqcaWUoqZ9/fHcz3X88/3fq7ne9+f76PoEeTg
LSggIJBOr//vj77nF2899wSple+me3ZR6NhEqLjufgIPYcXQJHkKdoe/BcVl
cFChTlhqDRCIGzQU3M5gQULorphbMgVnw4qxVZfY2NTptTqxlEI+U8jT73gx
VBX/qmrSo+A2EV6yymEQGuI5JhFGBKxLre6KcHvw256DOoq3SUgd/Xh3/dlG
lO2grpRpUFDRp3hMYw4+/vn3EYevBO5pBDia9nJge9v3c6QggZTM4fSG+F5U
ufq3brYgkH/aTzVGsgMda95KGkvSeqO/nnhS1Q/nsVk9/ikSpTvTQuIshmHW
ISLeWjuKAo2r//xrWoPMLbtcN8tRWI7zVys5OoD2gigx7/3j+EVZnn8tYRiL
OgaFUcoEQovatZTvcFDOKd8cVMiHrKPC8qmLLOhIN73f40TiCk81ZX0fB3nX
e9L8IgkoG2SbWla8gEzTNSubZQJhxk4CEbaNWD3cXOl3nsKlHG3nlLX1uMGc
Sx05R6Hp7dbUqRsdEHyY6GQ9RkIv1zHg9cc++HqrlQUvEPibu33Dpk9NaJu0
FTrgS8Hs8ocH81m16DNEME+YAmW7tSdauxpC4VIO1Z4UBKiaiJW3G9BXXcab
nyURXPU1zV2yH36a4k2KGXw0/mRZl+fVCre83WpMBgWyxTNabfo1WqOTQo6J
jIN9mb3RGmWQrZJqkzej73cr9kepiWTYfnmzdp6uv6L2qrxyRDuYYZdWl1Ek
7Ott8rresrB98oLH0mEKk4TVZZE1nVjutkhKofWbTmcF+drXobtLTudfAwqP
Wtki3XoDeDSwteao1xjMckc5FjnFuO3h+N3UmMIW898+q+1nwykr+/6uDwQM
vBsZqg3DSH7l58gWHYfLFxfFM30tcKs/KbdxnERWwXxwemA/lufWW50vJNB/
QlzXbZyD16a3Tq7zJKEVeN8+KXYACoxxQ/cgPoovvT8ZHtSNlTtUlyxlSEzK
+Yq+dGzHtm/ht607SNilycvkfniMT0UqVoM/UFCYs4jv4Ffh5R29XTb0e3Pm
ijbHaw6BEZ3FLh8mYPpDXYHWZi6k7okcD2YTCPA87G7kMYIO/cBSsWk+3Lb6
yvgvccFkKT7znuDDxXiIrR3WgLKXXTeK9ClIh5k0KlVwYFZe4+qZTCJNQ3Sv
7qtK+AgrRK+ypqDkW5IZf3MQ3w3Da2cU+DCSkH0Y6jWIaJNejYSlcRxPOz1f
t8DFrc0VUwffkchRNVB4u78F3eu1F18vk/C0sWVPxnMga7uB353PR5PTcZ8U
sSasCr93Ks6Ognro13On1zIhs79Voi6K7k+bsfm2ik5M7wi3CpWgz18aF2de
FCKF+1eK9DHaf4Lfan8ZrYXTsax0/j4KmbJfFTba1EO7tXlS5RDtFyUD+z17
y6GQd9e604ECKzX068ubXBg87rwm9ysfwTNG2ucbB+Eu2JWyEEbii8KitQC3
Crem8kzWCVAov3OTsZTOhoLv8pSfEJ3v2O0rJNdmo3Q4o+WoI4XrV2Uqj2/t
wI8sXy1LIwoXItbvetybgpK0P0zcTlFgD13lhLsk4NK1Ctc/PCg8TyC0l562
otD/QunzaxQmZvcw9mXyELUqtlHiIM2LPZ0hax/2Y4NbhmxqLoHO0UuuFzqH
kBzx5sEJJT68HPIV1Rd4yBW0mWqppP2qW1y2rzUHGkLSPnEnKFivK3QvLBmE
0139Ab2dJMY8FXMa/sfBz2lGZ2X7SMw0/ambIlcBWUvlkwm2FNrqhIXtLvNQ
L2yc+eAcH8rHnO0nCS4U/NguqfIEzLJbnN5KtCL0qIk0q5BEgoS/enzScygJ
s85HcUjEDUX8wg4ZwDpO3YTD7Dh8flC9yZ1/iWWByQulohQ2XH+9N/ZfNt4p
zWX53iBQrVjjyGBywdIJWLqYQqDXUHwwxq8XWoZrAh0LKOjwDqV8PM2Ai+FO
oyUvClIvVCIV0I8CdSG16j4+tpcWaez/xkOC1rbEBzzaz2LGzr9rcXB/kas8
5kMhQHOrH9ehG6WrqcDGARIZxpzmKJ1BtMntN56T5KNvxHSgisFGW4i59bdy
CoEF79MtHzUifaV6fD7Nf2Xv4c6z5xvwfCBzVTXd3+Ad/6gcnu/HkyVDrRdX
CXj4jFW+kxjAhhlhU6Y1ra92cPehkF6gfefGkUg+WDWHpO3ae7F7R1SiFYPE
k4WDTJtPzfAKEbpumEpiurH5SoJOH4JObhmqDiDAfFqbXRRegXeBZStY9Lyr
8qsK/6j7Cg/VV2bzX43Bznz2SFK+D1jTP78QPkmhT7xSNXBlO55zBSX0i0lc
tDZ2adcfwdMth57xYsdwTLzEPtalBHuvW4689ab9dGSqqtCZC4abuB6zh4+9
/XXKN/QH8VkM4Xp+JKZ0yx71SPcitCw25Ygxza8NebXS7YMIleBMlNaNY/sB
EWu5315CzpJRu1GGQkx611BCAAt2i7oNmgco3PVsMlj+1oKjukcsyDUURM80
8q7E1GPOPVX1UROJfDEj5k9//gXhe86aQnSes8BQEG3lIikvsE30xBvE1KRY
PL6RB7abx/lmVwqhla9Ul1THMB8rY5+YNozK+ImQxY2t4PJimJo0jy6X6aQK
/ToCSfc+E+biOAR+/Cj81b2Tnm/fV/7TS+J3Q6tnb4rbEX/t+rp9X0iEnV1+
NiZSh4iFO3fMaD6k62oRN3VH4XQ7F1QrHzqanlq5Jp24//mQ8OlOAmkykdGb
4kaRzIppGVGkufksMPGhaDlimFFfEgMo9PiImCvpjiDTIexO8NpxTOZk+I8k
N0Hyvdr0JM1nJzVdjv25PpgJbJMiaP4LmBYKKDaWQ2OoRUbWiuaX+YxF68UC
yJ6NK5y1of8nRTsOPC27hzqBMx+2HKfwqpuw7wprhlJ1hkuNGAX5Pcfmxv/I
RhC33n+Y5geRvCDbwR+CcFovk/1pFIvmdpGSK3goV+nMvlJJ53915OBsVy/E
n5uwC1RJ+J0Rcs+pqYdaP8Pu0wyJ/wBUZafW
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}]}, 
                Dynamic[$CellContext`i4$$],
                Alignment->Automatic,
                ImageSize->All],
               Identity,
               Editable->True,
               Selectable->True],
              ImageMargins->10],
             Deployed->False,
             StripOnInput->False,
             ScriptLevel->0,
             GraphicsBoxOptions->{PreserveImageOptions->True},
             Graphics3DBoxOptions->{PreserveImageOptions->True}],
            Identity,
            Editable->False,
            Selectable->False],
           Alignment->{Left, Center},
           Background->GrayLevel[1],
           Frame->1,
           FrameStyle->GrayLevel[0, 0.2],
           ItemSize->Automatic,
           StripOnInput->False]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Top}}, 
          "RowsIndexed" -> {}},
        GridBoxDividers->{
         "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
          "RowsIndexed" -> {}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.7], {
             Offset[0.5599999999999999]}, 
            Offset[0.7]}, "ColumnsIndexed" -> {}, "Rows" -> {
            Offset[0.4], {
             Offset[0.8]}, 
            Offset[0.4]}, "RowsIndexed" -> {}}], If[
        CurrentValue["SelectionOver"], 
        Manipulate`Dump`ReadControllerState[
         Map[Manipulate`Dump`updateOneVar[#, 
           CurrentValue["PreviousFormatTime"], 
           CurrentValue["CurrentFormatTime"]]& , {
           
           Manipulate`Dump`controllerLink[{$CellContext`i4$$, \
$CellContext`i4$368611$$}, "X1", 
            If["DefaultAbsolute", True, "JB1"], False, {1, 200, 1}, 200, 
            1.]}], 
         CurrentValue[{
          "ControllerData", {
           "Gamepad", "Joystick", "Multi-Axis Controller"}}], {}]],
       ImageSizeCache->{391., {195.75, 200.75}}],
      DefaultBaseStyle->{},
      FrameMargins->{{5, 5}, {5, 5}}],
     BaselinePosition->Automatic,
     ImageMargins->0],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "ListAnimate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.5457410558271666`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"PlotRiemann", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Sqrt", "[", 
      RowBox[{"1", "-", 
       RowBox[{"x", "^", "2"}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"ImageSize", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"350", ",", "350"}], "}"}]}], "}"}], ",", "\n", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Partition", " ", "->", " ", "pt"}], ",", 
       RowBox[{"Height", " ", "->", " ", "ht"}], ",", 
       RowBox[{"Mesh", "\[Rule]", 
        RowBox[{"N", "[", 
         RowBox[{"1", "/", "n"}], "]"}]}], ",", 
       RowBox[{"Subintervals", " ", "\[Rule]", "n"}]}], "}"}]}], 
    "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", ",", "4"}], "}"}], ",", "1", ",", "100", ",", "1"}], "}"}],
    ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"pt", ",", "Uniform", ",", " ", "\"\<Partition Type\>\""}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Uniform", ",", " ", "Random"}], "}"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"ht", ",", "Midpoint", ",", " ", "\"\<Height\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "Midpoint", ",", "Random", ",", " ", "LeftSide", ",", " ", 
       "RightSide"}], "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.545735735645911*^9, 3.5457357688302956`*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`ht$$ = $CellContext`Midpoint, \
$CellContext`n$$ = 4, $CellContext`pt$$ = $CellContext`Uniform, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`n$$], 4}, 1, 100, 1}, {{
       Hold[$CellContext`pt$$], $CellContext`Uniform, 
       "Partition Type"}, {$CellContext`Uniform, Random}}, {{
       Hold[$CellContext`ht$$], $CellContext`Midpoint, 
       "Height"}, {$CellContext`Midpoint, 
       Random, $CellContext`LeftSide, $CellContext`RightSide}}}, 
    Typeset`size$$ = {350., {173., 177.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`n$9892$$ = 0, $CellContext`pt$9893$$ = 
    False, $CellContext`ht$9894$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`ht$$ = $CellContext`Midpoint, \
$CellContext`n$$ = 4, $CellContext`pt$$ = $CellContext`Uniform}, 
      "ControllerVariables" :> {
        Hold[$CellContext`n$$, $CellContext`n$9892$$, 0], 
        Hold[$CellContext`pt$$, $CellContext`pt$9893$$, False], 
        Hold[$CellContext`ht$$, $CellContext`ht$9894$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> $CellContext`PlotRiemann[
        Sqrt[1 - $CellContext`x^2], {$CellContext`x, 0, 1}, {
        ImageSize -> {350, 350}}, {
        Partition -> $CellContext`pt$$, $CellContext`Height -> \
$CellContext`ht$$, Mesh -> 
         N[1/$CellContext`n$$], $CellContext`Subintervals -> \
$CellContext`n$$}], 
      "Specifications" :> {{{$CellContext`n$$, 4}, 1, 100, 
         1}, {{$CellContext`pt$$, $CellContext`Uniform, 
          "Partition Type"}, {$CellContext`Uniform, 
          Random}}, {{$CellContext`ht$$, $CellContext`Midpoint, 
          "Height"}, {$CellContext`Midpoint, 
          Random, $CellContext`LeftSide, $CellContext`RightSide}}}, 
      "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{399., {242., 247.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`PlotRiemann[
         Pattern[$CellContext`expression, 
          Blank[]], 
         Pattern[$CellContext`range, 
          Blank[]], {
          Pattern[$CellContext`plotoptions, 
           BlankNullSequence[]]}, {
          Pattern[$CellContext`riemannoptions, 
           BlankNullSequence[]]}] := 
       Block[{$CellContext`g, $CellContext`u, $CellContext`partition, \
$CellContext`heightlist, $CellContext`sum, $CellContext`mesh, \
$CellContext`integralvalue, $CellContext`outstring}, $CellContext`u = \
$CellContext`RiemannData[$CellContext`expression, $CellContext`range, \
$CellContext`riemannoptions]; $CellContext`partition = 
          Part[$CellContext`u, 1]; $CellContext`heightlist = 
          Part[$CellContext`u, 2]; $CellContext`sum = Apply[Plus, 
            Part[$CellContext`u, 3]]; $CellContext`mesh = 
          Part[$CellContext`u, 4]; $CellContext`integralvalue = 
          NIntegrate[$CellContext`expression, $CellContext`range]; \
$CellContext`outstring = StringJoin["\n", "Function: ", 
            ToString[
             TraditionalForm[$CellContext`expression]], 
            "\n", $CellContext`partitionstring, 
            "\n", $CellContext`heightstring, "\n", "Riemann Sum = ", 
            ToString[
             Chop[$CellContext`sum]], "    ", "Definite Integral = ", 
            ToString[$CellContext`integralvalue], "\n", "Norm = ", 
            ToString[$CellContext`mesh], "    ", "Percent error =", 
            ToString[
             NumberForm[
              Chop[
               Abs[
               100 (($CellContext`integralvalue - \
$CellContext`sum)/$CellContext`integralvalue)]], 3]]]; $CellContext`g := 
          Plot[$CellContext`expression, $CellContext`range, DisplayFunction -> 
            Identity, PlotLabel -> $CellContext`outstring, PlotStyle -> {{
               RGBColor[0, 0, 1]}}, $CellContext`plotoptions]; $CellContext`h := 
          Graphics[{
             RGBColor[0.8, 0.3, 0], 
             $CellContext`ShowSlices[$CellContext`partition, \
$CellContext`heightlist]}]; 
         Show[$CellContext`g, $CellContext`h, 
           DisplayFunction -> $DisplayFunction]], $CellContext`PlotRiemann[
         Pattern[$CellContext`expression, 
          Blank[]], 
         Pattern[$CellContext`range, 
          
          Blank[]]] := $CellContext`PlotRiemann[$CellContext`expression, \
$CellContext`range, {}, {}], $CellContext`RiemannData[
         Pattern[$CellContext`expression, 
          Blank[]], 
         Pattern[$CellContext`range, 
          Blank[]], 
         Pattern[$CellContext`options, 
          BlankNullSequence[Rule]]] := Block[{$CellContext`M = ReplaceAll[
            ReplaceAll[Mesh, {$CellContext`options}], 
            Options[$CellContext`RiemannData]], $CellContext`S = ReplaceAll[
            ReplaceAll[$CellContext`Subintervals, {$CellContext`options}], 
            Options[$CellContext`RiemannData]], $CellContext`P = ReplaceAll[
            ReplaceAll[Partition, {$CellContext`options}], 
            Options[$CellContext`RiemannData]], $CellContext`variable = 
          Part[$CellContext`range, 1], $CellContext`intervallength = 
          Part[$CellContext`range, 3] - 
           Part[$CellContext`range, 2]}, $CellContext`list = 
          Switch[$CellContext`P, $CellContext`Uniform, 
            $CellContext`UniformPartition[$CellContext`range, $CellContext`S],
             Random, 
            $CellContext`RandomPartition[$CellContext`range, $CellContext`M]]; 
         Join[
           Join[{
             Part[$CellContext`list, 1]}, 
            $CellContext`Slices[$CellContext`expression, \
$CellContext`variable, 
             Part[$CellContext`list, 1], $CellContext`options]], {
            Part[$CellContext`list, 2]}]], 
       Options[$CellContext`RiemannData] := {$CellContext`Subintervals -> 12, 
         Partition -> $CellContext`Uniform, 
         Mesh -> $CellContext`intervallength/
          6., $CellContext`Height -> $CellContext`Midpoint}, \
$CellContext`list = {{
         0, 0.10450609502931728`, 0.25295750087852836`, 0.30731950174178785`, 
          0.45478910314175003`, 0.6007339132967826, 0.7566334109321335, 
          0.7695800963484485, 0.8423913895164261, 1}, 
         0.15760861048357389`}, $CellContext`UniformPartition[
         Pattern[$CellContext`range, 
          Blank[]], 
         Pattern[$CellContext`number, 
          Blank[]]] := Module[{$CellContext`bottom = N[
            Part[$CellContext`range, 2]], $CellContext`top = N[
            
            Part[$CellContext`range, 
             3]], $CellContext`actualmesh}, $CellContext`actualmesh = \
($CellContext`top - $CellContext`bottom)/$CellContext`number; \
$CellContext`partitionstring = StringJoin["Uniform partition into ", 
            ToString[$CellContext`number], " subintervals"]; Return[{
            N[
             
             Range[$CellContext`bottom, $CellContext`top, \
$CellContext`actualmesh]], $CellContext`actualmesh}]], \
$CellContext`partitionstring = 
       "Random partition with maximum norm 0.161909", \
$CellContext`RandomPartition[
         Pattern[$CellContext`range, 
          Blank[]], 
         Pattern[$CellContext`mesh, 
          Blank[]]] := 
       Module[{$CellContext`u = Part[$CellContext`range, 2], $CellContext`top = 
          Part[$CellContext`range, 3], $CellContext`list = {
            
            Part[$CellContext`range, 
             2]}, $CellContext`v, $CellContext`newlist, \
$CellContext`actualmesh = 0}, 
         While[$CellContext`u + $CellContext`mesh < $CellContext`top, \
$CellContext`v = $CellContext`u + 
             Random[Real, $CellContext`mesh]; $CellContext`actualmesh = 
            Max[$CellContext`actualmesh, $CellContext`v - $CellContext`u]; \
$CellContext`newlist := 
            Append[$CellContext`list, $CellContext`v]; $CellContext`u = \
$CellContext`v; $CellContext`list = $CellContext`newlist]; \
$CellContext`partitionstring = 
          StringJoin["Random partition with maximum norm ", 
            ToString[$CellContext`mesh]]; $CellContext`actualmesh = 
          Max[$CellContext`actualmesh, $CellContext`top - 
            Last[$CellContext`list]]; Return[{
            
            Append[$CellContext`list, $CellContext`top], \
$CellContext`actualmesh}]], $CellContext`Slices[
         Pattern[$CellContext`expression, 
          Blank[]], 
         Pattern[$CellContext`variable, 
          Blank[]], 
         Pattern[$CellContext`list, 
          Blank[]], 
         Pattern[$CellContext`options, 
          BlankNullSequence[Rule]]] := 
       Module[{$CellContext`i = 
          1, $CellContext`startlist = $CellContext`list, \
$CellContext`leftlist, $CellContext`rightlist, $CellContext`widthlist, \
$CellContext`selectlist, $CellContext`arealist, $CellContext`heightlist, \
$CellContext`valuelist, $CellContext`opt = ReplaceAll[
            ReplaceAll[$CellContext`Height, {$CellContext`options}], 
            Options[$CellContext`RiemannData]], $CellContext`f = 
          Function[$CellContext`variable, $CellContext`expression]}, \
$CellContext`leftlist = Drop[$CellContext`list, -1]; $CellContext`rightlist = 
          Drop[$CellContext`list, 
            1]; $CellContext`widthlist = $CellContext`rightlist - \
$CellContext`leftlist; $CellContext`selectlist = 
          Switch[$CellContext`opt, $CellContext`LeftSide, \
$CellContext`heightstring = 
             "Left edge of subinterval used for height"; \
$CellContext`leftlist, $CellContext`RightSide, $CellContext`heightstring = 
             "Right edge of subinterval used for height"; \
$CellContext`rightlist, $CellContext`Midpoint, $CellContext`heightstring = 
             "Midpoint of subinterval used for height"; $CellContext`leftlist + 
             0.5 $CellContext`widthlist, 
            Random, $CellContext`heightstring = 
             "Random point in subinterval used for height"; \
$CellContext`leftlist + 
             Map[Random[
               Real, #]& , $CellContext`widthlist]]; $CellContext`heightlist = 
          Map[$CellContext`f, $CellContext`selectlist]; $CellContext`arealist = \
$CellContext`heightlist $CellContext`widthlist; {$CellContext`heightlist, \
$CellContext`arealist}], $CellContext`heightstring = 
       "Right edge of subinterval used for height", $CellContext`h := 
       Graphics[{
          RGBColor[0.8, 0.3, 0], 
          $CellContext`ShowSlices[$CellContext`partition, \
$CellContext`heightlist]}], $CellContext`ShowSlices[
         Pattern[$CellContext`partition, 
          Blank[]], 
         Pattern[$CellContext`heightlist, 
          Blank[]]] := Table[
         $CellContext`Boxx[0, 
          Part[$CellContext`heightlist, $CellContext`i], 
          Part[$CellContext`partition, $CellContext`i], 
          Part[$CellContext`partition, $CellContext`i + 1]], {$CellContext`i, 
          1, Length[$CellContext`partition] - 1}], $CellContext`Boxx[
         Pattern[$CellContext`bottom, 
          Blank[]], 
         Pattern[$CellContext`top, 
          Blank[]], 
         Pattern[$CellContext`left, 
          Blank[]], 
         Pattern[$CellContext`right, 
          Blank[]]] := 
       Line[{{$CellContext`left, $CellContext`bottom}, {$CellContext`right, \
$CellContext`bottom}, {$CellContext`right, $CellContext`top}, \
{$CellContext`left, $CellContext`top}, {$CellContext`left, \
$CellContext`bottom}}], $DisplayFunction = Identity}; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.545738917601346*^9, 3.5457390832424374`*^9, 
  3.545739152704398*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"PlotRiemann", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{"Pi", " ", "x"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"ImageSize", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"350", ",", "350"}], "}"}]}], "}"}], ",", "\n", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Partition", " ", "->", " ", "pt"}], ",", 
       RowBox[{"Height", " ", "->", " ", "ht"}], ",", 
       RowBox[{"Mesh", "\[Rule]", 
        RowBox[{"N", "[", 
         RowBox[{"1", "/", "n"}], "]"}]}], ",", 
       RowBox[{"Subintervals", " ", "\[Rule]", "n"}]}], "}"}]}], 
    "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", ",", "4"}], "}"}], ",", "1", ",", "100", ",", "1"}], "}"}],
    ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"pt", ",", "Uniform", ",", " ", "\"\<Partition Type\>\""}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Uniform", ",", " ", "Random"}], "}"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"ht", ",", "Midpoint", ",", " ", "\"\<Height\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "Midpoint", ",", "Random", ",", " ", "LeftSide", ",", " ", 
       "RightSide"}], "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.545735942443265*^9, 3.5457359969497604`*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`ht$$ = $CellContext`Midpoint, \
$CellContext`n$$ = 4, $CellContext`pt$$ = $CellContext`Uniform, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`n$$], 4}, 1, 100, 1}, {{
       Hold[$CellContext`pt$$], $CellContext`Uniform, 
       "Partition Type"}, {$CellContext`Uniform, Random}}, {{
       Hold[$CellContext`ht$$], $CellContext`Midpoint, 
       "Height"}, {$CellContext`Midpoint, 
       Random, $CellContext`LeftSide, $CellContext`RightSide}}}, 
    Typeset`size$$ = {350., {173., 177.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`n$9956$$ = 0, $CellContext`pt$9957$$ = 
    False, $CellContext`ht$9958$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`ht$$ = $CellContext`Midpoint, \
$CellContext`n$$ = 4, $CellContext`pt$$ = $CellContext`Uniform}, 
      "ControllerVariables" :> {
        Hold[$CellContext`n$$, $CellContext`n$9956$$, 0], 
        Hold[$CellContext`pt$$, $CellContext`pt$9957$$, False], 
        Hold[$CellContext`ht$$, $CellContext`ht$9958$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> $CellContext`PlotRiemann[
        Sin[Pi $CellContext`x], {$CellContext`x, 0, 1}, {
        ImageSize -> {350, 350}}, {
        Partition -> $CellContext`pt$$, $CellContext`Height -> \
$CellContext`ht$$, Mesh -> 
         N[1/$CellContext`n$$], $CellContext`Subintervals -> \
$CellContext`n$$}], 
      "Specifications" :> {{{$CellContext`n$$, 4}, 1, 100, 
         1}, {{$CellContext`pt$$, $CellContext`Uniform, 
          "Partition Type"}, {$CellContext`Uniform, 
          Random}}, {{$CellContext`ht$$, $CellContext`Midpoint, 
          "Height"}, {$CellContext`Midpoint, 
          Random, $CellContext`LeftSide, $CellContext`RightSide}}}, 
      "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{399., {242., 247.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`PlotRiemann[
         Pattern[$CellContext`expression, 
          Blank[]], 
         Pattern[$CellContext`range, 
          Blank[]], {
          Pattern[$CellContext`plotoptions, 
           BlankNullSequence[]]}, {
          Pattern[$CellContext`riemannoptions, 
           BlankNullSequence[]]}] := 
       Block[{$CellContext`g, $CellContext`u, $CellContext`partition, \
$CellContext`heightlist, $CellContext`sum, $CellContext`mesh, \
$CellContext`integralvalue, $CellContext`outstring}, $CellContext`u = \
$CellContext`RiemannData[$CellContext`expression, $CellContext`range, \
$CellContext`riemannoptions]; $CellContext`partition = 
          Part[$CellContext`u, 1]; $CellContext`heightlist = 
          Part[$CellContext`u, 2]; $CellContext`sum = Apply[Plus, 
            Part[$CellContext`u, 3]]; $CellContext`mesh = 
          Part[$CellContext`u, 4]; $CellContext`integralvalue = 
          NIntegrate[$CellContext`expression, $CellContext`range]; \
$CellContext`outstring = StringJoin["\n", "Function: ", 
            ToString[
             TraditionalForm[$CellContext`expression]], 
            "\n", $CellContext`partitionstring, 
            "\n", $CellContext`heightstring, "\n", "Riemann Sum = ", 
            ToString[
             Chop[$CellContext`sum]], "    ", "Definite Integral = ", 
            ToString[$CellContext`integralvalue], "\n", "Norm = ", 
            ToString[$CellContext`mesh], "    ", "Percent error =", 
            ToString[
             NumberForm[
              Chop[
               Abs[
               100 (($CellContext`integralvalue - \
$CellContext`sum)/$CellContext`integralvalue)]], 3]]]; $CellContext`g := 
          Plot[$CellContext`expression, $CellContext`range, DisplayFunction -> 
            Identity, PlotLabel -> $CellContext`outstring, PlotStyle -> {{
               RGBColor[0, 0, 1]}}, $CellContext`plotoptions]; $CellContext`h := 
          Graphics[{
             RGBColor[0.8, 0.3, 0], 
             $CellContext`ShowSlices[$CellContext`partition, \
$CellContext`heightlist]}]; 
         Show[$CellContext`g, $CellContext`h, 
           DisplayFunction -> $DisplayFunction]], $CellContext`PlotRiemann[
         Pattern[$CellContext`expression, 
          Blank[]], 
         Pattern[$CellContext`range, 
          
          Blank[]]] := $CellContext`PlotRiemann[$CellContext`expression, \
$CellContext`range, {}, {}], $CellContext`RiemannData[
         Pattern[$CellContext`expression, 
          Blank[]], 
         Pattern[$CellContext`range, 
          Blank[]], 
         Pattern[$CellContext`options, 
          BlankNullSequence[Rule]]] := Block[{$CellContext`M = ReplaceAll[
            ReplaceAll[Mesh, {$CellContext`options}], 
            Options[$CellContext`RiemannData]], $CellContext`S = ReplaceAll[
            ReplaceAll[$CellContext`Subintervals, {$CellContext`options}], 
            Options[$CellContext`RiemannData]], $CellContext`P = ReplaceAll[
            ReplaceAll[Partition, {$CellContext`options}], 
            Options[$CellContext`RiemannData]], $CellContext`variable = 
          Part[$CellContext`range, 1], $CellContext`intervallength = 
          Part[$CellContext`range, 3] - 
           Part[$CellContext`range, 2]}, $CellContext`list = 
          Switch[$CellContext`P, $CellContext`Uniform, 
            $CellContext`UniformPartition[$CellContext`range, $CellContext`S],
             Random, 
            $CellContext`RandomPartition[$CellContext`range, $CellContext`M]]; 
         Join[
           Join[{
             Part[$CellContext`list, 1]}, 
            $CellContext`Slices[$CellContext`expression, \
$CellContext`variable, 
             Part[$CellContext`list, 1], $CellContext`options]], {
            Part[$CellContext`list, 2]}]], 
       Options[$CellContext`RiemannData] := {$CellContext`Subintervals -> 12, 
         Partition -> $CellContext`Uniform, 
         Mesh -> $CellContext`intervallength/
          6., $CellContext`Height -> $CellContext`Midpoint}, \
$CellContext`list = {{0., 0.25, 0.5, 0.75, 1.}, 
         0.25}, $CellContext`UniformPartition[
         Pattern[$CellContext`range, 
          Blank[]], 
         Pattern[$CellContext`number, 
          Blank[]]] := Module[{$CellContext`bottom = N[
            Part[$CellContext`range, 2]], $CellContext`top = N[
            
            Part[$CellContext`range, 
             3]], $CellContext`actualmesh}, $CellContext`actualmesh = \
($CellContext`top - $CellContext`bottom)/$CellContext`number; \
$CellContext`partitionstring = StringJoin["Uniform partition into ", 
            ToString[$CellContext`number], " subintervals"]; Return[{
            N[
             
             Range[$CellContext`bottom, $CellContext`top, \
$CellContext`actualmesh]], $CellContext`actualmesh}]], \
$CellContext`partitionstring = 
       "Uniform partition into 4 subintervals", $CellContext`RandomPartition[
         Pattern[$CellContext`range, 
          Blank[]], 
         Pattern[$CellContext`mesh, 
          Blank[]]] := 
       Module[{$CellContext`u = Part[$CellContext`range, 2], $CellContext`top = 
          Part[$CellContext`range, 3], $CellContext`list = {
            
            Part[$CellContext`range, 
             2]}, $CellContext`v, $CellContext`newlist, \
$CellContext`actualmesh = 0}, 
         While[$CellContext`u + $CellContext`mesh < $CellContext`top, \
$CellContext`v = $CellContext`u + 
             Random[Real, $CellContext`mesh]; $CellContext`actualmesh = 
            Max[$CellContext`actualmesh, $CellContext`v - $CellContext`u]; \
$CellContext`newlist := 
            
            Append[$CellContext`list, $CellContext`v]; $CellContext`u = \
$CellContext`v; $CellContext`list = $CellContext`newlist]; \
$CellContext`partitionstring = 
          StringJoin["Random partition with maximum norm ", 
            ToString[$CellContext`mesh]]; $CellContext`actualmesh = 
          Max[$CellContext`actualmesh, $CellContext`top - 
            Last[$CellContext`list]]; Return[{
            
            Append[$CellContext`list, $CellContext`top], \
$CellContext`actualmesh}]], $CellContext`Slices[
         Pattern[$CellContext`expression, 
          Blank[]], 
         Pattern[$CellContext`variable, 
          Blank[]], 
         Pattern[$CellContext`list, 
          Blank[]], 
         Pattern[$CellContext`options, 
          BlankNullSequence[Rule]]] := 
       Module[{$CellContext`i = 
          1, $CellContext`startlist = $CellContext`list, \
$CellContext`leftlist, $CellContext`rightlist, $CellContext`widthlist, \
$CellContext`selectlist, $CellContext`arealist, $CellContext`heightlist, \
$CellContext`valuelist, $CellContext`opt = ReplaceAll[
            ReplaceAll[$CellContext`Height, {$CellContext`options}], 
            Options[$CellContext`RiemannData]], $CellContext`f = 
          Function[$CellContext`variable, $CellContext`expression]}, \
$CellContext`leftlist = Drop[$CellContext`list, -1]; $CellContext`rightlist = 
          Drop[$CellContext`list, 
            1]; $CellContext`widthlist = $CellContext`rightlist - \
$CellContext`leftlist; $CellContext`selectlist = 
          Switch[$CellContext`opt, $CellContext`LeftSide, \
$CellContext`heightstring = 
             "Left edge of subinterval used for height"; \
$CellContext`leftlist, $CellContext`RightSide, $CellContext`heightstring = 
             "Right edge of subinterval used for height"; \
$CellContext`rightlist, $CellContext`Midpoint, $CellContext`heightstring = 
             "Midpoint of subinterval used for height"; $CellContext`leftlist + 
             0.5 $CellContext`widthlist, 
            Random, $CellContext`heightstring = 
             
             "Random point in subinterval used for height"; \
$CellContext`leftlist + 
             Map[Random[
               Real, #]& , $CellContext`widthlist]]; $CellContext`heightlist = 
          Map[$CellContext`f, $CellContext`selectlist]; $CellContext`arealist = \
$CellContext`heightlist $CellContext`widthlist; {$CellContext`heightlist, \
$CellContext`arealist}], $CellContext`heightstring = 
       "Midpoint of subinterval used for height", $CellContext`h := Graphics[{
          RGBColor[0.8, 0.3, 0], 
          $CellContext`ShowSlices[$CellContext`partition, \
$CellContext`heightlist]}], $CellContext`ShowSlices[
         Pattern[$CellContext`partition, 
          Blank[]], 
         Pattern[$CellContext`heightlist, 
          Blank[]]] := Table[
         $CellContext`Boxx[0, 
          Part[$CellContext`heightlist, $CellContext`i], 
          Part[$CellContext`partition, $CellContext`i], 
          Part[$CellContext`partition, $CellContext`i + 1]], {$CellContext`i, 
          1, Length[$CellContext`partition] - 1}], $CellContext`Boxx[
         Pattern[$CellContext`bottom, 
          Blank[]], 
         Pattern[$CellContext`top, 
          Blank[]], 
         Pattern[$CellContext`left, 
          Blank[]], 
         Pattern[$CellContext`right, 
          Blank[]]] := 
       Line[{{$CellContext`left, $CellContext`bottom}, {$CellContext`right, \
$CellContext`bottom}, {$CellContext`right, $CellContext`top}, \
{$CellContext`left, $CellContext`top}, {$CellContext`left, \
$CellContext`bottom}}], $DisplayFunction = Identity}; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.5457389176325464`*^9, 3.5457390908552504`*^9, 
  3.5457391527667985`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sincloud", "=", 
  RowBox[{"{", 
   RowBox[{
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns4ldkXx08lIVMnU0YoKpVSQqRc+lYkTRlyq/h1QUlKZNSELhIhQ7mm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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3lcjO/bHaQS2hRFCG3oixZK6EQhfmiKQipJSdYkVIoQJUnapE1RSbvS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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk41WkfxpGkUoQiDGHIqCylQum2vCQkoxjbeywxbbJWskyUZRwjKkK2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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs4lFsDxYkiSRKpdAq5pOKckiHSwlFRKCSS3KKSSLqJyiWho5DcRcol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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8VekfxigJk1STCSE1aVGiTZYHFfPTRLZoHZKbZCKGlMSPRmRJkrGT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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lO8Xxoe0oCRfkVYpsiVJScndIjsJRRKyZaskayQthJAUaVGyp6Ky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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk0VWsfxw0ZlqgUuYk0XBo0CEkD36KBt7jIeM1d85LiquReySyUkilU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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81dkfxm+ZQVGjCUUhRgtpaLSMwkMhFTNC0Yx9iOwiyShbI3EpRBlL
mGsUylhTDNeSfblZc3G53++XGlJZyhL6fX9/nNf567yec87zfp6PvIOXqdNa
BoORRK//74wpE6ZppyP8a2NP/2ZLwSbO66BSxFP8OecvedWKwqjLqXFtyxbw
TDxrsiVJiL4vXKk0KIGrfHC1/SEK5XGsylZeE4oCuHUpmiTyJ0umRXt7cMyp
wyg1gQ9DqzcisaONmIpUZJVsp7BJNcYz68lL3MjPstc7QSJDInBP5foBJFia
M/ab8SAuP9XmMh2KAaWPHR9sKKQa9133FOyDi72J9CM2iSmJVK39Ie0QnNKI
DuWRUBALSDKxaMWFsdr638oo+MUq71v3rhYzJ9cMHHhNgghJiClU7sNPReEO
GdJjYO080+zoXIa39tVb4mQpuJ+9FL5Zqhof7a/Ge3lQMLx+s/yw02MovjG1
FbSgIDy0ouhzNgU/D7kmWrlQCHgduNUnrQ1N2Yre4pdJWBqrnr+g3YPCfLur
CSw+OJHqyYKbHkKz0zf9hg4FcvzBCku5H8udx70WSghUa/1imPTiJbK/aJ2S
YRMwjJDerCE5BJ7TfLRk3Ajy46ympZls9N3aMs9aIuG/w9hVQLwfrFKn21/1
EDCp3ftIJ5sLNSOtRyH+fCR4PaqI1OFgxkQqSYVLoqmn7v50dQdWeaHGGb4k
GlMc030ucLDk9nBdmhiFu5sv1Nx0bseiut8J43oCGiKZaRvKB9CUnCtU6EuA
PS53pGBLKfRk5yecTlBwObA9fhW9sF/Zs5rBIWCtdLrhH78uXHoravFUlIJT
JrP/oOFLCGQeXrd3Gx+KFTeGxLz78X32ff/1FXzYOZxrVi5iQyEmq1n2OwpF
s8zVZOMOLJHWDT8KkKg1CPg2Sr8LeZ98JzO7SRz6Ou39iWtdIBILbJd7CeQH
jae+p/3UXHvvCv4isb4pLMOxtBvZxzV0l2sIUD4yPmp3esH7m7mxc3YUc/GR
HEUXHvbGOP+hUzSKN7r3N9govYCKwMbHTp4kWJm/S2QPNCEl5WYPV4/E8g7V
PmEdNgwk9+xz/0hCjDr/ulRvGGUWysNV5jxkiMy98PS4g3Wuuh277CgsH/V2
cjraDNdiaZ7DIoEHLGXXfpc+JLCOm1yj/8su2CQ5IKcOthEm50OVKMzpWe6J
yC3EqBS3K5vmy0jp/YJudQXaBpfuCZ6m8E7WOCHXthvfDLKjn0WSeBj8p/Xr
YC64UZHmqZ9GoGMVGnziXRWEc8w3MdwoKMhKal4J7ca7UVvbHGkCGcywbZb/
PUGld65IHq0X5Pufu2tFD6ZiNjQamRCwGwjTVjYowj/kFf0d0hTU2n4b3JZX
BpuJzvAAc9rffoOetzMcxOb+HvXYksCP/ravjbM6wNxe/syU5k2tOH4o7TAb
5e2BGk8aaN6j5LjTQRxsLXK8uvYSgYXH8RP1+2vRnhExtYsiMeSjb2u/MgBR
Kxmf0QwSM48vJr7QZcNQ7sntY3SewtRykvyO1qFLf6wikyQxqtrPOOn4FHaP
Ynw9zChs8XnPEpJio9LSqNHtIgWVvJn5b7Z14rRw5c5F+r3xXwy/vbnShfyo
TlVOKc379lLljqOliJ15MFywmwJ3pzcv1Lsbq0PiPr2ZfIgK55as5bzAYf1p
z4lhEj9R2wqGfh+ACbFLvdWIQGd57yGuXBt4aUFNU9pjsLzUufW9Jhfse5tH
1vTzYRUqu9vgFQeMmRwtja9JpOayLw9r1oD39IPMn4MkQhZk9p/5+VdYLM6a
SdL9eddY8Wy9YxM+iWn5PtOm+03ISiR9ugwPc9SMZq0pnGInDO5o6YfYeobN
ZVE+dGazYywT6nDkH623eydJzLVMGAVplGHFXtts9RKFnpbreccjs/F56aT+
SUuan85dZpPohvPnuqH95QQU5SfnxxXaMVKibbKQTqItzIwpId8F9+SVE0xn
PlaHWzXWajZA+8pq24w9hcaXhg88jlTjh1vThtN0HtX2mZbcrcuC/ysDb8Nz
FDYGJ/DuF/ciI9AgtEaJANM+yWH8Qz28SjbFr12k88GepyRii7FwLNBYYSvd
h8Ic7mpDO9otm27Kfibw5oris0+3+xH+R0GB+TAfS34PYt/FdSHJ7IcDTCMS
HXxVLUZkO77jBvRWHaXwxmPXS6HhWni3aUb/Ss+TsE2JmxJ39kBwh3q3rScB
YnfDtYMK3Qj7FDg3dJG+z2G7byLkXiJ62T6mw52AwlZbY0+pYXRr397JuDGG
iMYsLyarBu03KBEzZQqKPPX/iu+xYbI5UCskgMKCaePqhsl/ofI9izehSkFT
OMhITKACC0pRId10Pr8Lb5WTDuyHsvEZ/3LQetxbqk6q+SCSHc5u06MglqIq
rJ/xCrb91z9oXhqBR/23xWkKfZDEkHSUNx8hRmNXknL8MX1qIv8Pen4ZER6/
pBI1sBa5bGjAoM+PhJYZhNZj/Yas1I5iEm8W26RG27ogf1jqo+RdAqbz/o+s
uS34UseJj4mlUK+zt+V6YC1Sf0jMSRamEP488o5UJgedc/L/7laj+Y8qKsj7
UAjh6n3J+RoU2PHeIqyA+5BNPyAu70AhxOytaE1qDl6Nj+WE03k38BIK5mpx
kCpzT6ZVj0BTfHn8nQsN+FQ5dyTFmURQ3qJWklU50iM6WuMjKeS17bWNyOnB
6Rv8qSp9er5dywzRSOfgWFPRx74nBPzSxJs9bfqx2U1CcDftFzM8Zt/kmhYo
KgkYJqhTkD/omP25phvW7p5WxQy6Lx7krRmszoBgNYMjSPMYezds4+gpDsJ2
mT820qWgPnBe4GwVB3L6+yvJbBJ7XGr2VEb3oSrNQ/TWOz7YKe5xTJVCuA9E
mhwwpjBxzZppb9ODgKLrz8+p87HV+qLIX75liHWzKC05QOGr1wlnxJqfw625
0M8vhsKru1Xplua1UD9n1RRC6z1/9fehKOsXmHHOd1mSo+CtOtuX8vkJJhLv
mKvTfrO6td5mtrRDYPnZmdBoOv8qursLCjtxSiJhB2MdCVmzM2IqIn1YmL1o
IbSdwEFtrzXigx0Y6REacvOi8D+/I7yp
        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lekfxs8UKqlmZEQl2pXIvueuFDFMhJIilTKJyQhHaH4IZS1FklMj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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4lG8bFZKkooRKRYmK7FFURyql0KIoWxJZyhYtPyShskSKZE+2Etki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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx7WMKSRJkWUsXSqTupZRqvFpbKm0ISGVjMZaISM/EqayZCxD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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns8lNkfx2ejtov4bbkVlUaRW9qoZOVjiyK5S8JG5JJ7LkW6KCqVsjWy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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekbPpmUbJEpmZzJHJMSkxkhNXQbTdonlaKfpWVSiBip7GRyypKU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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lP/7xanIVkop2aKkiEpKKnVK3zZJkrIm2fORvZJIWVJSqCgSki0U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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk4ldkfN0k10jJliiwpNRTZoih8KNnG2ggT6UYkJgxpNMyUPQYZu1KR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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41ekbxk8iW4pIKUtUKJQZxt7cpBmmoWLKyJaKElmyhWJOSUWJZixZ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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkbP2FMRMkc6zed0UQjmfAVFfLzifIZjGJUxpY9ZmQZ8dlSWoSI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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8Ve8fJ8pIGaWpUmlYRSWy3loSKiEpM5GRjJBU4iuhXaIUlRHJJiRl
73ld4+Iace+5aJAkK+r3/P46r/M6fzzn+Xzec72Nq6HdPC4uLktuLq7/P62p
aJUFRqG4GPm3lXmGQuBJme7nru1wW51kuffUIKxZas4PJhlIH3SQ/3qEgpSO
08sQnkwszF9SqhlOoenKUYl3cu8wk3HaV9ebwqdSRmHF62Sc2y4bk2pCgSF4
T9brWTOucM96p3X0gytZwJjPtQd9TIUGiYLPUJLTuOur24yMVQ33NR9y0LRw
aRxDMwNTYSvj/NwoWL9d4DzGKgdn/xFauiYF/9i/zYlTRdi7fjzH6yoH5lez
Qt2EaRi33j6ywYaNrmtJ2tqlnYh21rCcLzKIDIn1p4wG2+Aa82RSrP0LBOO6
Hy45Vo5aHrHAc+fYMAzuuaV7uxO6XYrXdoVRGNdfMl073YnZcx8dNey+4nFR
sfLftyVIOSA9e0SFDcvgykDRTW247p9uE72chShDW29NsyooxpgHpC5h41zi
ZU2drQ0otbzvKLuQDZE7mQuU3RoQqqoz+6mTA6nPlNk3fSakujVcrkh+g9uR
qrQhpwpk6fnZrbFgofNB4OMpmXZMtBmfGl7+BaMV+WkfrtSDGaHhEytHQZLd
cr5frwoRjnnt35kU6nwiascW0fFd6aXATm42DGJfLJb+Qe5vHf57hSEL0QNq
3dkvi2E3McdrI04hkU/qytK9NWjuSfOstWGh0u+ywvKEQiz9vuOH6jdy/9iv
+S06PTDpCKZsbvdD4REmL3s8xcyZmA23HSlEl+RJSOfW4P64aIai3ACikvVb
Zi8x8Wn6XDNDvQ1lruZ5Td4t2M1MlpdQ5GDmrpLFI8VWnHM88LKpjIX6mPC1
IqwmBC4Isv15awC/ezP/zb5kQFHJ6EDsP4IXU923HtMt6D159udTBhvUsSNm
grta8cSNo6q5lwLX/IXuLw7W44Bw5/d3d9kYvdZ+7vjtEqjInSwMW0DBpmdL
xA8zBnjvu//dRebfFPxDPOxQAvaoKl99p07h60Q6K2BjHX49+3UrXJUFXZf7
xVlD7ZC9yUsXv9eOWPfO8YkPdNQiQvF7NQe3uecPSi5ggi877bdlcCc0D5fK
qN6IRrWxMI+BNYXvZckWac4NSDr5X0SsBAsR8ZNTl30+wcTquLHJYwqXrbLO
Mrqz4bmq0Ci0mQ2VQvunU49aoG4wfMi8nYNKgZnR1JlWaAn0SC281A/+z/Yv
//alIdTJSuD7CQoXrLINEra1ozJksVRwZh8e0q1y1orRsE9Wg/uFAwWV1CW5
PIO5yK+yerJ+G+HL6R023gEFGE+4OxmbROF1mAeXXEUFVuquUTTcxkGjb3yJ
241SeM165Q3OETz5JcRHdt6B4lSEvh7hq8io57KPYemIfrExzUWHzGtFwBYF
uwy8jnnDV76WQp+89dFtnGqwfhv39ioRvltqcx6+78XAoqua8ZUD6O5dveZR
VS2atWpaDRvYyLjioRljngxV1jufuf8otF69p8j/ko6vl2aSnpF5GRdutOT3
oOPmmnYrkQgO+AMzGlzc3uPxyuPp68bYMKdylklejEd0OO+3CUvC/5iV+9IL
0pG73DTWK5jC3ZrDL/qjmJBbxBXrs5acr/9M/dHVCkgxfXfsNeXAdPG8Y7cm
O3HpFH7bBnOQekrv6O716RiKntuouZGClu/sbKpjOawnTJ8/3zMA/wtmHwLO
BOJRmL8+/2kKBwZ5xR8XZWHH3EJdHl8K5ZEX+FyKGyHvFn100x4OhtLN/Oqj
GUgr3PY75TAF2wd+Q3b7OhEw6EDbkk/4dia9cFKRhoVeBv1GNf2I/vXp6FRL
Jhxi5+/5d5+CwpeDBx+z3sCHLhqjTe4nYmxWd6S0BvMEegSYBJ8ZyT6Ng0OF
mOfS8Fi9hI2tnnofVFMK0dLW1RwUxMbDW4KrI27GwtBisUrfTQpuVN6EWl0h
DsbJyterc6BjdEt5VKsevWKiKjcqKRQ2nSvlFyjDNaEdlAbhV7ed2ScHpRrc
uwEG7QMHNB0br1ThBmzbfXJ83Qairw+Hsx+F07Cie19A6SD5X5vSNal9KbBr
8HvCMacQ9fTpqJ1PG+72tq1t5RrEp5c9cYdet2HL5onT9tJ9CMsZs5jT6ICc
qqmcwzs2ik/Hib2yeYG/ut7G2QTfQttaY0OfFGPfM+W9IWDjotyKIY2dVWiX
bFBQ2Un23XakTOKoP7oWxi5/SuYTkSe669QoAw3vXtiukeJg/kqL+X0HGzBs
2PGMaclCcd/uY25ajRgx0MunDpJ9GZx+teg8De2q8psfdlLwnI2uko+vwPUZ
y7QLBN/ODXIWz/VocBH0SS6I7IP/8VaFuvQEzGbbHvHTIni3q/p2PbkFn9c0
mSisZGFAYF/93hNlSBqudBog+xtN0eMpWFyNbt/g6lGCb67dryQUrjGhG/Vf
huRW4p+94hE03ghMLnulGmhFzt++tv1rSwvcVsiZ5RO916oVsvLqooPuEdm6
KILg10KsZlVtG2QOnt8wdI0Dk8ZVf0N86xGbeO0wbwUbQnIpZ3xfVyJNKEhu
5wPil2jRFpxXilKhqMl5qygUJxjdD/ZsQ0iJ6UjKJDkvIv6aqRYNT5iypceK
ByD5+MD5H9xh4L2aXcBL8O3/Q8KZLvkMoq80f9fbUTBYFBflcOUTVr6l9g7a
cxDm8PM77Xsdcle+j9QK4yBbyauov5wOkdcSY0HaHHDJqf45MuAAQa89IvHk
fvb3ajUmzNpR02MqpRQwAG2F0DeKC1vxaYnt0k/7yHfb5CbvjHSMvVHned9E
9GrDqPCv4QSw6TpS00RPbKwcTJX7OsBdH/7elLsTKdI8NJfDNdhXJiHcM84G
qzpki8o8GqrOSj8VzmHDLXsz/VgXA9JDz4yjeHrw8zcfc2xbCyYesRbJHhvE
0HbmzvsZqbhSxOf4S4rsUzSuYb1tDwYi//N3lfyCFaHW+rvnKvBOecU6HwE2
ZKrFXALnVSJDOV9jazQFOZqacpdUFho1fVLSif9N9NBLPGfbkbdvnfIS5x6I
iJsHMpVicXPTM1uK8D9lzMYvM6cQxm6p/y4Qfo5nLnl3ZqAXBZbzbPon++C8
ZPRWwHsmovwS1GRtOeQ/xvZ43MjCvM7eBJEiosdC9mv1P7fi+YjDI/XPg0iU
GVqpjBxkP1cJTE6jcN/raubrqU4slQifSp0m/EsqPh/d1QEWc+S3WQnxp9Ls
GveX7fj2YVht9S0WLh2XFT/v34B/F2Xp9EQO1Pev/uN0oQpry17ZHTnBgf83
kR2XOzIgqlv2yZrkiSEemw9JVxh4k9V4UdOdAy2NxUtY4zcgJRWSOWJG4cpN
p1/Vnk0wVGbEFRiwYLmB0tb4mIvNtadX1blSYIo/nj4k3wyts90dnsfZSOEe
vu5G9PiYfHFUZBuZv+ymZeYhD5C4INx8hOTNvBOTjGNudEi8z3m+gbcbzprc
+5940cFvtK13o0w/+ko8uh+YxyNA5W3Xxe0UsndfH7UMrkN0ucyXckUWWnMF
VAp5mPi6wCPIpugLHp1y7eToMJAfLraEvfszkirydsgc/4CUD7fY3rFEH0Vq
zM7Ep2OZd5vPjTsU5nQ1nxfSSiF3Jr3NlODTf0vuwaMDvlB1Oa44TfStSTBt
j0VWClqpp69srxB+u1PsrZNeyDI93JtC9OjHE71VNOFm6EX1ZXD6WRDqv6cW
3diC0Nj1a9/KsNCk5qmlc7QU1pkzVHMbG7ffvy6Xq6uCt2teWxq5/2Vj5wVR
n3NhGLh8jcVVgre2j4rChG/y5ZuFGlM46LNwat17MQldJc0ChYSvBo+DD1c8
bIDdn7CnoRdZCJodF+rn7oKMaXOHWxDBy/0hie7jNPSuylvrc4mCfucNttri
Mpz5pLBWdgEHnnUh4cOsYjRZDEZcf0lh19i+qHdH6Lg2s/JDQSgHS9Woxh57
OiLtv5+22U/yY8m1vHvpXZjk4zv9Sasfe2hFv995V2Cx18DcMpIfg1QPMg/O
ZOHyqim7M/UUMuTvbZiaX42VWct2DnazoZDu+NBooAzD9tQE2BQEIz4VnQhk
Im6T+brKhgEoX3DZZqBGxzHhVNllXQR//g5ywZxiGKWPT7mMsCG5y5DrzrE6
+P8UDuAa+n8f4BZ7f/EFhrTE7dacorDc/A0j63sTUlZsk9KsI3mPu007cmkO
+jxvRy/+zsbJxPrPvO+KofOmQsm6gOi9+8ubdcoxKP0Syy9I8lv34bkbMgrE
rw/1Lv24awBmKl3TMzfaEbwj/E7kdbLvzWu7nG49gsGb6k0CZN9j9kGPrta0
441Ftq8v1wA6XP0U37rnYlFy0rBZFoXnGxfIV403Y71DptdXnyEoWN2P2t5X
C3pDPm+dHxsHfnw7sdSWDlbE/ghpVw46UrX4zrdn44mSxMDsG6Jn+Sa/hl8F
wU9kL+uXBfHb5SK/Uqs+ov70+cvuE2y0Wqnw51TSoa2crfIkvh+3c5dd0NFu
hG9NgpMm8dcovVKBv069CG0+nW8Z8RWJ3nPX9jg2IsFrgBl0go2ItsCnHmPV
uHRR++GFdOKX2b57A50fwCada4zHiPgZ80DWwbBcqDzXaTj/f3/r1uETFe/E
o+qvjoyzFPwct/2p/1gC/Z9nlIoCCT/eNdgujktAXl8G70HS/6ZWz1k/bMkB
gyro3GJAIZQX0w7yrXjpLnUw15jkGWVLnl2MArQnFR8XXsFBsezwiskrJTDh
8ajPekryZEmIqaFrM9q6LwWsViN+Fm0cGXK3CoPheVIzJE/7PzkblhB2B70m
g5aJhJ9yd58IPvNqx2nB28G7Yodg3TGReeFUL35Pd0koPCU99hmDrv03CXTf
7Fd8F4i+asi7VG+IQXtCqfddknf5N26NSjUow8Ts4suJXBQsd8yPn+KrxVaP
uKGurySPPejt7o0h/vd8w4N0kjcdZieuHTSIhq3Br6WWJG8VBNjtZ1R3gtZX
qiDmwwbXKfuf1EtnSG1vnR9D/NDXRSYud6QVPyubyzcL9ILL50Ku489IzAjs
MuIh+uMw/nZPWfwL5C/xdVUn/N7naHHpln03WkS9u5qyB7DqjG9ORSMTkSaq
d+OX9uHQgR9XDV90wKtG7cI3lwFE7LkV++BGBUyG0m9Lk3nW811O9xdsRXLB
HfYWExZSedaejXxRDLe/wjy3VUje/cOlUelXD/oSxzeiFSxMXc04k/r2HfhE
RCfuSlC4uHDrqViSH8oWpBRrdvajNaFUfiCmGutT1fMlL3BgbT5ZmptfAwmF
Rfyeg2xIXXOIF3WvxaF7PI21qSyILlOQt7jUhSMG+ZN14eR8q74uzevN+Lvh
ZpP06X4s/tdzSlGSjth5018ESJ/TP2DlPWdcgqF5zITuf2zsEA46e8CuHV7y
Sqc6fPqQnXB+0cLsDkxtpunvuN8DIVtJh0hZBmKl5VyL3b6Q/LJEbcb6Jtw1
HacMCF8cSjRtZUOawXi0W4grthc6y/6aDAbnoNGPe6Eh6Ut3J2tld4mXYOGx
4zFyniRv9M7L3/C1DT5K/BHckwNoVWvMbpNphm7MH7286yyUfX2QtEuwDf1m
nyP6+Ik++Zim5Z/KQY/aPxUd4iebt5XVXbIvhmDIoSinb2xcmTESVE/pgMTY
mTg7+QFEh6Z4cozCcfQprafzOIWsF27DlQUMjAjcqU/dTvQtz7VjN4uOkYDv
Pv1E77Ye7+lWKs/FvBPZMcp0wqfpP6KbgmlY/FxmVLeGBf02k4rRj0VojJpM
WPGDwgrNWI+qdyUYPezjcdSW9PMVdzo0K0NJzq3s9SF6lWRn55c51IHY3Vq7
Tev7wMXbFrBrPAZLq7INzcg8is+7MDi3ypGf9GxSgJ/sV8XZaal3IXhFuHO7
xykYa+332Wj7EUz2nYhnX4hfJu4Ze+jEwBRrmv0nsQ9Tywtiqle2gRnifHlm
bggpYYfcjTLq8O8HTZrnKxvMoYT+VwkV8P/4T0if5JdaC/vbyfbtGOW77m50
bxBBb2NeGKr2gJG3ei6A9EuVdXZpeiTVGh5VVInQYEOr0Tl5rDQZCyrj90jL
Ez08KKsYpd4Jm+CWa3y7BuGV1qbtp9GJ9c9Oto+c+ga9iRMxItUpCE3wE5bU
IPpgqaS/ca4Vl8RzfJapf4OcYnizXns11B3/5hsS/704P+4Nb0oXknUcAw4Y
DeHoiuvDHVeKYfsfM2gR6QeCHgZH++y60B1oxDYR7cGuztXio450iG0P56zS
plA/Ur41orgZXLWPpoL9yfzs//sX2lFH8lWWeGYjhQHz4Ixpv3boDvPsvPWH
+AnNRP5S9H3IBH8sW3COwmy8gZPT6yqMjiiKTa7iwKPldvT2/SUYNEnpStEj
evdqoaCYQxH8O8dXGyqxsWbbotf865rRV+F6/88XNp5fpolclyjHm5CSJaXk
vDE235rW08UwUT0gl7mVwsZrJWrrQ5lg1N7oEzIcQv5pP7OdWxhY9bzgS/Bn
DlQkxOd322Tj8gm+aWsy39bMqAanhg4kTAqFy9VyEJ2z+mzdphboei/XKf3I
QqLVx6HEjnJExbyhFRK8VU+8jFmXzYS4ypZl7kYDGB953Oqi2Ahh21Un6rYN
wHLk9wHT5GzkyTGblxM8Wisqw+FmOm4raR630Sd5oSuXfmf6LRJapqs7iN82
3FAs1GxmgEZ3KNqd2g8xof/ORsZ1YqO92N4nh0gfyTcfXRpQjsjsc1mGr0h+
tLhZ5POhEyHsO3e3rxqAEWO+ZKR5A3Ta7cxeT7Dglr6s1yDuHvaIC+U6kLwg
mWx44ntrLKoXX/+0yIsCNZh0PYC/DH3n1DP2UBQ6+3zKjz/oxhhN/8ta2ldE
SPf++PvyA1xCTJJ5SX92zygoUhVtwvhtt1ltsn+ZxJR2T6si/NJN/+xMI/3m
/rSr5e8uBD4WGB7/Mojmk8PSJw0ZMOW5l1ocOghnrsLHXV/K8GI4PIdB+sTa
kQ+qYkMt2H44bMHeVA5+xXvsN+9nkvcS7f6kz2gSfbY+U7kTf59KP0xl9cPh
gjOd+kfHc8eOhcEf2MjKWB3r6N+KHc0nnRzyBmG8YVAvM60Br1rOrgDRj/8B
qaQmIw==
        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8VWkcxlVDEmW5SiSkRknTtY4JPbZRNDXWUlTGUqZpyBJthKHNlqVs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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk81Wkbxg8vLUYykWSLkFPekJSldEmTrWzNSfYtDFKZqZlKWZskpuyS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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4ldkbPSQRFU1jUE1uuUQhSlGtboQolcrEEHKZMCRdFFFySf0qJd1U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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lO8XxpGEsvSNFkWyR1S2RLolZCtKGxEVUtmKLKkQIQqJSKukQvYl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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs8lOkbxq2kDDpIDkvY2YqKDSGVuiQsoaUkUQY5TBSSDsqWNoXa1sgx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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4lWkYxoUkRaTQZGkjYcRMGkpzY46YoYSSVISjhKFkmqbsZZk6lhpU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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8VekflhRqInWjqekXFSohU8NMY+aRmCyFETM1LdeSiWQbEU2iKCVK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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VV8bJZKxUBmiTBmSKSUqWSVFIhVliAyh0kRUlCGVEipJpqTIPEVR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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81dkbtkZDzEhMiWgbpNxMi6V6JFmiZMhISsMVMcnaolHEkCypbpab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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41Wkbx5FCKadRGJJjSSXbmIaxflMIkxkhjKwnSy69JDpEiWSLjiVJ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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lXkbxk8zRGVJcxRtw5ul7CGvqcw1jBQlKqTo0CFJRLKUyVJJkoSK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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3cg1P//R4UiTWSUVSKVCAn1UCnJyGohoyHtqKyQkQoVJfFBtpCRvbL3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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx1UzKhUi+5pkKaJImManhSaRLCVJFCqDQjOVGiSMkBlMaTEY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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41Wkbx8/I3osUImQZgyxFUxOpvmgTUyFTKiLVUCEaJilEIxqhRSRb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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs8lGkfxieHpUha29u0sp2jIsnYFda1qsVKGxvCymFeyjGxnSiSQ4UU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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VH0bxseSJZJQRCs9tFmytXm6JKESQhKyFEKWCiWVKNRTERJZEokk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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41ekbxmkkRVHnNCWmpLGUUakYS7lNYZTIlpYpilPSYufSLpMlCXNC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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs81OkbZWVtTal1KYVI5VZki5aUw5SElZq1LrlWbCTXDBXrUqEkqcTY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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwdlns4Vekex3eNnEIN06TIuOyaRicpDQ3JfEPCQ3FMDTluI5SSUm6VW9oJ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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k0VP8bx22VrcUuiVBEQkUovEVpL6mQhIpCylLWdqRUhK8kSUJCytJi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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs8VPkbx6eySutSpNiMy27bWjLZlMXSh6JcSgqR2066KWkXUaQlqVRC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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns4ldkbJVSTInIrFKUYJArjNpZynakotyQ0zsQoEg3dFDIjJwkhl0gy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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8Vekfx/nVWCLKXqloMOqqrsjUUJ8oJgwZezMqSwklKVS0aKxFRVFI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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3cgle0bPoo0KNRX9KUolBESUqpLJELKKNqiz0yRlJXISihERiWprJCZ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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41dkfxyUVmiQko5iuilJmCDfF/N4qGVvTWEYmhUxJClmKpEhlC1kK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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs4lVkbxrdESChla5CRKHTQIFKXG8mIlBxSkpEkqhFNySmRHCJGUYQk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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lWkbN+1SkaRkIkb1USRENfhRJ9SYxjRUM9nKUupYs2dL0glZMh0y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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3lYTe3bhuv1o0iJBkUqzYQIJcWVkNCEKDQpKklSGYqSJuVNoyFNKjTJ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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk4lXkfxu3RgjkjLaNNGTKKGmSbbiJLYaRCKLKHlBLGy2QruxYuIyEk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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk41Vkfv0KUJSWRStYaLZQtTfhYSllDM2OJIVmKurb2URRetDB6K5eM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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk81PkflqRDlkibxraS7eIntFlH9SjtlpxdsrGRo1wxKqWWFHJEUtGo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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3cglf0bxkWppIkivaEk2aMyUpe8vUJFVkNWsiIZSdKShCKjiBBSSUj2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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnlYjekfxjspkaaEksRgSJqhaRGGcSsqSqRS0jKlhBapaRNxtGgRkiSl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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk81Okfn2RTUmG1FuWolKtdWkIjb6KiVVLa3IayzlBUzlb9bEQnSUKO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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk81ekX5jaKoUVGdWdiRGWkLGUvHqlkJEpCo2ZKliiXMEWllIgryTJR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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VO8bxilFkpREFAlFZSmRpO4UklCREL6IKCSioiQ7ZSlCJUrSYivJ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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk41dkfx+/PlGVsydYikdwhJSEt4t0yFRkjS5IaJGsyys+aGpJMlgpF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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwdlns81Gkbxse0SdhOzmeiRGLtLjm8uqKpHEqSU4vNOpQcN9kMS1GtFNm2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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lekbllQS0lCZn5Q9SiayptwkThMzjBpFxlZKCEVIKtnaVFO2GY4w
IRmy/oih7I3l2DmH00TO+xmZQoYoDfPOH9/1Xc/1vtf13s9zL4+iu5+dh7CQ
kFAi/f77C1n4dvhWn4Nzmq+kvgvBCVGWfkpgA2KZYu/7YQTza1OWCRtwMLat
O3lVOsGn/BVXt/tx8ez9vNWQNoORK+SHHJ9GdDSt1fznKoGBjQE/SXQIT1b1
xg0WMahKKAwpq2hE+LuRAonbBKQuc83+9l8gkW05nuhKMGOslqm8tQWvQuRy
BdcJQrI2c9gLRZA53xLXeoJA6K+N1sZnsrGFv2pc343iy2LnrBsqgqQqOyDa
g2DnrPKJjK4CRDjtGdtL76s47I5USOuCbZayzrk/Caa8K+dWqA4gU0nZqM2d
wdQt468+7eDANlvm2L5UAu3ygKbFTX1IG9A7zOgx+P/FWFMTaR6E1z55v1aZ
wSOTj1pnY1uRfO/BUkwywWOPAzd+VO3BoTtP01LaCRT+YotJLNRA1yRiV0MQ
gelGrYWpB70wSo5tc28kUHdp0e0y5SHqxe5geUsGWXV+UoGijaj7yLnidIFg
k7/Y+WW11QiN4Y3u9yboNFnH+qUzE28jBQr/0Pmw7Y9vjpJ+AdXPl2ft6XyL
xu5YlaRxsN725l1Rir/GSEZN7lY7GJv1x94UENgW9n8fYlWMcNvvQg3pPHaG
rYsyqwqGjMqOm0aU3wOikUlDKVyopH2RsncHAyXb/N23C/pQrNDDDFM+Fbo3
+XM9SzET2hvD9iTwua127a1KH8YDp9I4OgyEPCIrdY91ImbLS1m1PoK0y9zb
8hLViL9+Y9jKh/L71Y8Hh62b0b+wuNj9M0GUsUHq+dJGrIibPfLxFsX7eVCq
OD4bTv3N6V9SPn0/zUSdkeagaGPTeVJD4BmrrTlqzoF6brNOTQlBYQRPWMG2
EidempnJ+RIMN/ko7pluR5mLyZBoD8H1+NCVMxRfyfsyw84/6HnIhZvBT2qw
QS5x22o/At7IWRGnAi6i3HoSnLxpf84XB7jNfKz0Xje1JpQBr6yNNSZcjTHD
4kc/0Pvpq+tEYh70I2i0dZftlwze1psPe7/uxJKCVIDJOJ2v4FrRnHcHDI61
vl+VQ2CmcFx5PLkasybpdkL/8TdTl7fn7zJsuf9gn+dpgtz7mgmKa1thUqyd
8m0u1XOvRfVPCeWwN7p/wfAU9df+be3PzpXC/Ka8WRStDwvudTfnNcBRIWL1
yUsEZTetU0d0u3BuqN41KY+gOCRHJ0K6C2Hdist7eQQvK8j4h7wC6BzOvVF1
nCBWRP/xA/tGbKr3Ev8UQfBbyU6WxAs+RFaObu/IYhBuPt0qf+0KRl0+TJhS
PRjOWsgpl7ZhxJ3Lysim/lM/srV7qhQTZ72cVSie4vakdmVWJ6xjGLbTCwK7
WrvaGe9u2Ms1S5cKCHQFr0Y/dmaBpXRVLpTyee/UiujgCA669W546GcSDLny
D4lJDOCslfTlz2E0D/QaJWPu9kCg5+HwoYritY0WY3O4CJ9wfP5ujkAk7+1B
GUk+WF/lps3eZTAsuHPJi2lD5r6N+X6PCZy0r8/NXmqG5qcqrmEi9fewnViI
VyI8vTw3lNJ+Zl4V6GzOfIUibddq5woG6S0vI64mJ8F6QgiN9DxcPNo5y46H
/qCI8rd2DLLz+RKFYf0Q2b1y9bwIg5yyfeYOQjXo3LI0auVPoLl6QfpiHRfd
7641NlB/5M7b3JN1qkXwer9mDep39ZSMWefff4ezpMznvHgC88ACCeMTfJQf
Fh1/nsRg35fsV46mvWBnSdpbviZYVubRmzTZgw1vHE+68an/3RZiLjc2o+zN
XxqyVwi6lYbuFCz+Ab4rxza4nkHY6+i50lP1YI+/yTx0mfrHxbBSU/whXJcX
57NpPiw+YfvnL/XCxuJ7xxwlBjsfWL0/K1wEDZaQNkP9byvLH9k79xBzE0Mm
8pQfqQ3LPRuOtkLV1N/LPZziL4zJVpXioomjJ55sw+DkJl8eq4yLGfHimI0L
ND/ixZ6KJXdhVHd0RyyX8l2d8V1OYip+vcExkqXvCwWL2jr8QfUdNirhlUHv
GwtPXLzbiyDZK1u1ljEw1Py6+EBAJeQnAw4m0HzIc/26z27wN6Q+X1L28aL9
T2qfyl3/G4SsP1rWUH/LWwayfl7Oh0Csb2ubA4Oo8KSGAM4gXq4qiEs/zkCW
MQ8rOtiD0SCDDcEdBBP8xSWV1zRf/SyMcm7RfM1q2HI0sh+94T/Pa6gyaKk4
Zh9Z1wGzGeHtj6ger79I2zh/l4s1sr+/H1oikE1z2hNq0ArP+jeMFN1vgTd7
lQ+p12HQzXLvRCjNgy8ybBZrs5A4Xdh2ms4vXMCN4LGiITGtYWVN9SR0/dms
048WSD7jH7uT1g5OM1qJu1ohqWt0/hV9Lz2jvFRRtww2AqkDI7Rf8VGXaPdJ
Ho4G3W1UusfA9Btvj8DpfihmvbldQvkrrV7jU1zeDOcVk4+PJhCoXXmdd0Gt
BfOKm6Y/pxCMasV8N+nSCgtB6nMPqjeDhXKNM4o8hA24WW4+xGCPT/dRF4N6
CP/pYZBL8+Pw6YRWiU4epk+b5c7S/NPNdMyMm+JiaaXB6aSVDGY4cXnWq5oR
3t69PYnu3/UbLNU9bepwQf/pT/mBVB9ia7T8BSXQqZJTY04SjJWsGROc7UD7
3ybLtlfTum+Hj2V8I6KSugZMrhGIjk9+0xz+EKUvVP6spfoQU6/8cITqYV/N
3Pc1MwRPn4vqBH3bhmGRhjIV6mdZgyrVAOE2iA92xFTEEbhVGj7cQ/enu3Rc
zaX11J9SM/UNOl344sA/yn51BKW9E6ZmoY3QkN72y1uqX8PxsZrNqTloKty8
LoDyI9plNamfnIPHbj5ri2gd1ns0+nRACx512vHc6P6Zqshx5MsPgOdwpDJv
P53HtictFcub8Ezv042eKIIqgWBHgtQgZEq+Nf7VgIGvI0fdraQL8SFeyj5D
BK5KY4MNU944PhldtovyfTiv8n9aLrW41leeUXqO6udrQXLbu04MRzaxpusJ
/gV1xMCD
        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8le8bx2WlUtFQKEpmUyVEfFIUQpI2QsoopULZEqFvKCOSVQoZ2WRv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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk4Vekfl0YKN6RlJJORJcrU+GWKxnySpUihVBjLUCQRYqxDISlJE9eS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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk8lWkbRpYsH1KiRcOgRGiSLF+5SFQyYgghy8kSaTJaRciak21EUhp1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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4VXkXPrlM5klRDdVU4jGh6SQzKSp65Tq+ITJIYkwql9yVyJ2SM5TJ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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c81e8bxslICwkNUcqIFEKp5JJKycjXyiwlo4hCQpJVUSpJdoXKLDuh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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81GkbxmfFG7KrVErJik0H3pLIFnUpskjlkLIlIedCWxMKUViHnCqH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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lekbxqVRKhJNUcqW7C0USeUiJSMiMpZIqSmF1AxZ0pTQVLKVRLaK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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk41fkXvmnGpBTJNpaSkRb7Mkj0KstktCiUXyV7I0laJDMoSyFLNI0k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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VH0bxoVoI0m7NUISWcru0iaVlGgnslQkWlT02JJKWlSUCuV5EAmJ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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41dkfTqQSWUK2W5lU+MlgKPtbQqWSmH6pmJJQImuWolS0yFakLKNL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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk41dkfx2+LqCxlnxBKwtwyaDGFt6WkLFNkKeuIQhEhahBlb8HMTVOk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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4ldkfN35KWaKNxtRoEbfNUpMa4pMyTUUz3KkYWSZbUm7ETLZEQ2Rp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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VPsfxoe6tiRJSC5FtNlSSaJH9kRJkbTZci0lS0VxJcmlRUQqIXuF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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk41Vkfv1Mj0oKi9A6iZG9IljTVh5gWFIMkS9mHLNkqFVOhcCuJ0oIS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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41GsfxlGRNclBSkoIJ4okUe4U2VvsWTJoO7xZOoRKvSIHU6QFKSSD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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lXkbPhmfIRmypogGrSo1SBPupLQpIRKVfRmhhFFCJFmGOmSpQwuf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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4lI8DF8oMaSgqNKyIRAP1aRiRyKhUSLK+NI1QCkURDWUlRUYhRHZZ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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41dkfx7lpmaxjVErJkmWiojLZft4UssREiyIT2VVCCoOyp6ahIhNj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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk8ldkfx+WnKzFihrIvJaGUClH4lL3UJKaimkSJLEUjXWVmpAhJt2yR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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4lOkbnrAbGbQWlbaNpFVt0klk61baotTmkKyUapVjDqVCtc3mUEmk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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk4lG0bxpUWla0iJZUkEdmSVDgjCtH2UqishRAqJEq2V7wVyhYVo0XJ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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk0lWsbxs1DHTNlcVRCISFRmbroQydDHFMyK5UGlFQ+R5IiCZnqIDmE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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41ekbxg9ZG8lyKGt2xqC0WAbd0aaSGiY0KTP2n6WiCSVL0qKQipJo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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4ldkfVypLkSyFkiUJM5Ut/YbGR1IprVcbRRG6opRSKLpadEdGhOxG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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lG8fxa35ZUtSWVKUJCSFpNKhkJQsSUppE0ULpUiIqEiLpFCpCJWU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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk8lesa3aIIHc4VuegKaTAlGZOWSkdIoZQMIdqHEkp1pCi2KamUDKkO
JzLEcbBNmYcM2TZ7G7cQ7e/biUupHDl+5H73j/f3/t5/nnc961lrPSpnAhzO
rqLRaMnU+f/dT9uaE6YxgitmTXP1x95DrNHuZuUAFxXdLxiRQiQKhgay2p6w
oZ3lmzy1V4BHN8tjNIbf4Nzvavn715KobP69t/1SKx7bpb5Z3UOgj2VklTE1
gI9kwY1ZHoHjZv5/H+LxYDmn3iEbMA6P+/N+GU/7YDnYcslGVAANF5uMroS3
cPRejqjtJmC4HOgeENqHe8cjpb3yCdCtrMs6xjjo0ua9VBLm48aMwrSnQi5i
XW8vs06RuDVf4nn3cA2sGyMGdS1J0OIqFoX25uHv7ZNfP7iSIN0k1mjktuJ4
gsmJbV4kgic9X3VnFKBwn3Nemg4Jzu5V968eLEfyd6acjC5V77ymW9m6HLg+
rxbe70HCQ68k/JRnDLYGPisodyOR0PLDc+JdITb36S1tvkhiISCV31T4Bxbs
FoLvulPv1uV4ns8bmN/7xiRWCeA3E6qY9awfUcbG42cCSfhsU5u4UFeGQqmz
o9m/klBiB4ZarWXitBp9fcVVCn9m/JrHobdA85B9d4Cqx1umX+NEV2Kq3Uno
FwpP5jUH+vKlXkQLya9otvAR+GWbmVPaMLynTh7cLS6ATobaEjOXA/VJaYU9
5wUwX4x4Tn4Ywec1K09+ejYOTfussuLCWvC4eyXc2wikSq8kcPRaMfG9O2oy
nQCnSmTv7jV1CFi7v97pDgn97Izz1pJdOMthfJX8m8BD259jVgYGcUvx8+Sy
8wdIh+VYJIQ0wKdpyV/tEMXn8e4fT+36MaCZlzoRQWJjjJZbajcHQvlzDPU1
BBRqft0RqtyHGZ8kDaYtH+tz9WMnrrMQ71ar8OkagXFGpOLklWJcrXsv9dKa
xLkm2RPR14ag+lTmtctaPvQse8rHhjiIp880aa4WYFF+cGx0ZwVWVHTcdPeQ
kL74WV2dVYVAA9Nh55PU/PJ9N5gvN2Gf9k3/ZBaJxyaTw00TQ7CKMA3bXjyO
TXOMatXVkYi4XNR4xoWaj+tatvrbIdxj/7iyvpaEjVD0dcNHXJhOl3CqFPnI
2iSjLGfSj5SbhwxYQQRUrQ5l3j7yFtMLlzY8cBBg5ETKrrAsNnatn14QixVg
fGBav6foNVJHf9RKCgsQ/5dtp3DCINIGVFQPVhNIjy1Q6OS2gD6XJlN/noR8
rS+TmdoJ7fnA3+z6STjWTIFnwkPlqKuejwQBnqEdTaDTjsULH0tpTAova3xs
V/QraGw3yeDZU/pUdwwY8mqBRteF3DYpEtPt4THFfWzM/vrf+642JHSDH7hs
+dSMHyljHc1JJEolhme/x7+Gv5ySs/c9EjULvlrzR7lwHlIJMS0jMGiXLps/
zEWd6vRizH0CJn28Lytp3XDYYDP4jxkBC5Y16ze5QZCVjJ/l9UnEWtg+vP3u
FQylXocetyBh5BouXKA5iF2MV8c8KP55QfduMBX7cS5b5EhvHwHd3Lqi6QkO
Il6K/RjxFyCYW6b8L/cSnPRboI9QeGkrBTVD8vnIUXozrnma8tdSantUTD++
hkdKqkYQkG4OtxuNrUNXk/B3vTECm4OVnPrnuPhHt1H0YAIfCeVxqTe+puKL
ytDqxBMksuqZop6eLHiebJg50UWgIKlWxGhfOwb4gzoxLAIjcbbeq/vaYZEp
hMtnBfBWZk8W6b2B+gUDi6BqKk/cLVta+X1Q3yC0sofKq/gzYWMvJN/A+aqO
cuVGEmV7x7b9smMUK45c3+D0UXg4hvlsZCVCW5P7to7ys1jxA2f90R70nax6
aLyFxPjZlMnA+w1QpR37vbSN6jdla78KNxGBSRMK3VTe+Nt+THIyYKEu4IVR
ej2B9WlMx4SLnXioNSEpn0zCTnGP2OK/u/DNX43n9Q8J80SpuynStVjUlvEw
0CQxe344NFckD1O1/tzF30g0XOvWyb54D5WxfzamU3h8zdveWYmxICox6BMb
Q2DpwTpxptEAfnl7a7bJjA+Pu/F60Z97cf2O0lBZggCzn1+k0XL+hOTuCA/J
KySOvPLKl5Lpx9GXs0ufaXw4RTfYT+gzwaSzLPxsqTyNF5fOe94JP4unhlIW
BL5tFX1hWtwNWVVmAOMBHwuRDN8NwkOoN28Y+6n0PQwt/7JPOziMHRV/pjvf
H0erVvllWYNerEp0nzB/RMK9wLp5MrEXH7xfx27u4cN7MG4X3bEDA2otyYJP
1H9pp08LylORzKjaWUzpRcmwao2nQT5IOIt0nKX49z3wyWVLB8RDZOsu+1J6
/Srj8q2nCw0cc4aDDwmL0o6jHjve4qJt4rqBJwJs2xRVVpXDRZGXqaxIHAm/
Z11ts5RebegOEiJCH6Ac/iV4gt6LLZzGEv1XBNiHncx+/LsWuYWPjxXLkzh8
mE9XPNIKWSdf1T+ySYhI1c8sF7Bx7Am/R3GJwJ62avnC0k6EaVV/vPqeQJ5U
nFz1xm5UjrtZz1P7SOzMzo2H1NjoDS+bDiql8k3uUb6hYAjv2lbSgqh8CjvQ
FqOrzEVcafOOEBsBNpVHzRU5Z0CfdipI+xyJdrs7L/nF/XCucdr+spFApmvm
I7OqCqh992eLU3yEuac39BT0o305K/NiHh8N7OWjB8QvYatDpUsYpQ8twQ6f
8pYaDB4IZZ/6icpTun2U6uoRnJrnJQsoPdKyEv/KCRnCF9vwm7kUHu/gig29
VV248OhWawClR4mPIZtCt7fgefvW00mU3+XjGiL80kpww7GkkEHxvzlV5baV
ZCe0XC0fRgRR9TXnIy8PdaDm4fpWlQ98uGb2Ps1zbALjCftOHuXPDC/vO552
XSirVFtIEidx0uRZfnNIP3iqZV2czvfwKL3ySbShHfYijkUD1P6/ZazUvqu4
EkeM5ySi7lL+kqt7En/nBiaCVn03pvrzsA6mM5/n4dL5nfvTKL6O3HQUPVY/
gHUfFVqe11B8Mvad8hPUYEqmJKb0DIls0UKPNtdRzAxnZxT78GEsY39Q/z8j
OEemGDXxxpB12Vt8zKgbqfPB101FBPgfl6rFkQ==
        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk8lWkbRqaMLCHF5BOKUU5FKNXoEiU0slS2bDGVJFuRT7Jk4qSF7MJI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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVWk8lWkflhpNkaVkSmE0SjWSYyJ5cZmJFiYKESFroQyhySlbmZmMMJWl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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWGk4lAsbFi1IKkopItmSStakuhUV5YTSQkSFdGwde1Ikh5KyRIkSIrKf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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk41ekbxu1ri0YjJGkqNGUpkkwztxMTicgykp2xDGXLaFI/oVC2RKTI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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs4lOkbx5UlWimFKAkpZ1rE6PRVSpoQRWtZQskUcqiQVH6U8+okYdNi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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4VfkbRwvTNZSUSFQSES0zMbR8RFqezIS0yIwkg/zIlpFdMeQia0JG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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4lf//tlMooyFJS6hQCpXKLcIno+wQKkmUIlEyoqRsyl5FFBkZISt7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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlns81Nkbx4efCrW5VVtyD0XubZsSH1GW0a+fS0pWDEVbq4jtQpRIpJTV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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns0ldkfxg/GJQnluAyaIZHLmJBKbg8WkpSplVQjdyWFyag4qdwbjaRI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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4ldkfl1Io0ZUpuVP0Y6LBSI2iqc9NQ0Yp0hTV2EmhbFERJRUppKQs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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8lO0bxW1FStZXIhIlv/aElOogWVLWROVFSLbKEkUpWSJJlJAkZF/K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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81NkfxmXVChu6kMiy6LJJRaui9VCj5FJqkZRr2PnpRm6VSy2JrM20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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk4VXkcxq9IkkoJRZlQ9AhF0TDpdS0tljJGiEiyRihrZUoqg4yIiSIh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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4lOkbVlLtEBF+bbQ5LZXaKEuJuW0pv01ZK4SVWuscORRRG0IHmhxr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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VO0bxmWvFJUipRT1SoX8ULRcIiklRZElISFZSrKllOzJ8oYk2bOV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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8lXkbxm2hxlZzoo0USaJCCeFCHCYqTNMiGhSFd1JatBhEQ5ZKEZoU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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk8lGsbZixJlBxbCG0ijkg5UrraOJRkF58ikSURDeq0IEKdipFQ6FOH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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4ltkbthSSaCqiNGEUJhkhqTR3SbKMLZGd1BSmkDSJSimGaox9rZB9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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lf/7xyWhskKTRDvhk0i+kheiiKxoWSFkKw3KqlQqKzMjUmYpI5XI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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk4lWkfxw8R78gWKaEkg5RMpGHI19FiCSOGRAvFJJUttIx0shRFNVO8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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41ekbxtGQRiXZ+klNIiKRyVLDuI9dUbYGWSMZjKKmtDCWskdMDZ1i
inQMckyWJMvpyJIsx7Eee+ec79dSo1BNi4r5/v54r/d6/nmv+3me+/68Kv5h
zsfEREREsqnz/1stNyYuurwTZuZu9qqbSejHJhSWmIyAI5O4ECQgQNPJslhb
/hCSl2en7EJJbI6IjAn7sQ/np/9hpDUI0fbte8mlK61YdCM49i0EqiwqGHw6
G5ZBHrsb1EhoeYb61qj3YEDbfAW/V4CNMambXpuyUB3zMSPIk4QcvYXztW8Q
fyTfUyxjCEDKST3jmfXgdG+rux1fCNaltiJzdS7KBKrWsCKw9KvKeebDYXh4
q37QvCXAHtERjtnoOOgZZ0R1XCdgu3PmCoNTi0IavT9Ql0QQd/XjfX7j+PB+
0S168TmKrLSPzlUNYL1F3QWWqhA0X63iA45NOCzdutOuioB9nefwCsVGeI+a
blW5QUJ7g8HQvEQPvlzX2WHBI1GmGeXHYrZDJiMm/M8iArXuqfPBL3pxx0r6
sJ4ECRH5Mzzfk5eRPh1LG6b6my9YJyri/AwjbT6LtBQCkot08cDdg4iIpWVX
lQjho39CT3G+H6lOGbO96wmUtrq9vaLWiq2frayV7pA48kMeq+GvDiifNs5w
vkGgLPGB1gaVLpRKbjMOrRDixSnDpEkhD3d4EaliRwhk9+YEh7wZQJvXypSA
PCE2fMMzk6QPouuafXrmYSH4LvkbGSED0I3Mfev0gsREi+fNNbpcOKjd64uh
5lXTYP5QaucYIhTUD1VWP8f9ZdGA/pjHsOO81HifT8J8Ulu8S2EYC/Fd9v4R
fGTmyeuU5bGwPsRA2ZxBYiR3Wvs1rQ++dZdoLmMCBO1m89bps1B1u6Tx6AoS
rGRTOTfeM9CDrw7o7SVR6EAzynceBK2uwnC/jQAiUc3xDhFXsedBUpqcOwma
/ZZd6U+asaEnMS5oNQl7DWUNwb5eWBxMMcyZF0Jy/oGI5dN+pJg11ztOCpBK
yGenczpQpr1aex/ln6XR8FadsUHMr9jytXaKev/FteIBfxd82h2pqeVL4tQw
seXH7U2YOvtMrkGZRNVIdveoQTP++Trl1L2WhHt6MLv9dCcC6q0Ml8eEmPHT
GyhZ/QjW6ava1lD+3rI3xDhkWzuOef+vppkpRPyDuAdk1ROQHY0HIyg/Bflq
uFiFVaN2/5xLpTMJL7kM9Qm9QTDlvP2N/qD0dN21dutnwYh85ZpB5UvnS8CO
OutudLKisg5dIdDm8HzbLyEtCPmztI1G1bnv+LS9nxpx5GZewveNBGqUK33U
vhlHWwLD59MBPmLDdT3evaFD8ifp94UeJFLjPO1+MuDCY4NzeZIkgdbthx6F
fOLCJF+x0vCREEVlf748pt2LUHXO56FFKr8MWuYheg/SKu7L27pR9eu8auO7
TyGvqRbYbkNAS/2ymcJkO9g5GmsTZgjEPncymeFVo3eVEeOJAeVXT9sqLj8H
TMbymTPU/lLHuKN2TTVYmNeK37yRxMwBkXINmSYcTJBRPRVM6d8nz1rkVYEm
MiRwf0tgu/j6epVdHZA3Kw77TYuEcpeM792Hd+HY1HtL7xAJrgt7WfzVHUw0
zZa/sScRHrbneKFvHeyL7wd/XiLguFF6TYoLC93TQ9fF6ggUxq27Ohs5AieV
E9l6ngLcP2DD7dYpQoSD0th+ByqvPrxpSy0PTJxTKnnlQyJY+kOed0wLGPJ6
Idt3UvvPFk0od69A6JHGwFgdEt+e2y8b7NWD1HfJMvx7Qgzt3deiavEIYyNH
isp2Uzx71B00foeDBf8tJuP7hQhZ6K4OMR5GSesui1J9PqJTaGskl1vRZh4V
kyRLIE3nX7EAKg8SfYHLdCeKb1K2Nh+S+6BCmxdRySTATqrVLDDqgZhUUkTi
CgL8YO2MYjUmbMZnvCo1SRweCWz6RbwGVq577cgDVD/iljzJX2KhMEYkGFP9
yFlGhdGihqCyK3tUI0sA6fyvWh3SfyHoos7qH4JI/PtY9nBmSyPoU3HWbUwS
bAnNc2YzLKyur0iRSqT4/wHq7vXFMI9dqTviRyLk6Xb98ZE+2JvdubHRSgjb
fiM7tlkFrjESrFR3keCn/mjY/KgJrReMpvPSCKzd6Ppln1o/Wm0aO/5OIfFx
5kKBtVgdCgqysuq6CSSHhkXfdO+E7Ga+8Q2eEOwLLaRkci/2NOgKFZUEqPWP
v8Sc5GIw5Z1V7RsCrrP072eiWTDUiOwLOEki8U1HY862UUSI1WuOOT6HSVfk
zhETDn6fKhR6U3yMNV81VWmbi9RN13dcoObhzFm66PHrMA4Gz2UX3STw8bpS
R/KZFiyHzr+U0ifhWPnblKtFF+xdDKIT3wvh+Lu3WJbjTfS57/ULoHhey7o8
y3rVgyedQQV2b6n8rry28mj1XXAHTn2X6Upi1lvm0sUvHPw8yjfXpfqT+Bh+
km3ZhMIpG7ED2pR/22/1lIi3or9N97UolZ9SqdHy0uBB+Mga1Vwe5qNQlq4n
t34Em97bvbzM4MPrNqMvZbARnPOTxxfSCRxr3l+XUfYUY6dufY5vJaCkuTVg
7hkHStxvFXKNSJzTb5Q/kdkO0e9kJ5kUr0WslxUk+h5D6ZhRg9QsAZE1Sx+X
pLohcfz45PaXApjWOLHM6KNQOvvEgfZgAjOl9y08n3XDZ26YUkzgyMR6Qv9p
EZjdepuGvEiYhkkoSjPzse6muNxnimehxLnpwB0cmKYF/DwzI0ToSpsbOdPj
cKlS/nzyNB+2aYmCslW34RgpMxh3mMTWSj/6NvBg6ZTfceu2ENXJdyOOGvRD
z+G0ZNM1yu8mXmclLzaApf9TyVk2xQcig5Dr5kK/dtFiBaj/Osbh2sWCThQT
uquiKwlsMW1s/xo4jDejy5w60wlcUZlY+PtjE4r6ixXzvSmec/yLfXdkQfa6
0sU6ivf6Few9FReeoFPc65bqHAHBificx+G9YJ9/GveNHOWvTfNR64zKcbQu
R8eK4nHm5v6z6sx7iNiVJPuK0u/IPaW/5HUPGg2OE2eDSRhOKzBPfOqFK3Mu
NPEVH+EG5HJ3+RBeNNb7mec+x39hw6/6
        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk41dkbVyka84spo5REYdKobpSZiA+KiUGylEFTlGuJFAnDcFtMWlSE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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VPsfxgkXJTuVdG0pZS9FRY+UFiktSDdLqZCbJVsqRKGNsiWVJFuy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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8Vfkbx1VkiUkooywTYmiTS6MsHxVR0bWFUBFmaEEqW+K2iEIabilF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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk81OkfHzl2KSorlSMlWYpyG9rmTUQtTTnK5mYpIZuKdIeSXK2S1C6J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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns81ecft36kSaTkNr9ChlhtSkR4K9cyRrPVkBDlfhk7JZeIpGG5tHJt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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHk8VO8bRQttWlAqiUglUbZk6UgLQpsWSUJE5VukkIikaJOKSmWnZI3s
WyP7PmYGYylm5s6gIpWQVL/399f9vJ9779z3fc5znnPOyDucP+AkIiQkZCss
JPT/68JTS6JO9bNRt0fVZaU7hTeL088uSmAhjbcvO/A+BSGra7+mbl7Bxtlq
f97bUrhbPrfVc6IBrmpHvHeLURgY8332VaMXejMOBVm/G4CQTHhSnaQviiZa
L10mz4vJT79w6lwzfMziDDw0KKQNO8roF7Wjqyt5Rv5JCka8+euNT3cjQ5er
uSeCD6FN6c+5PpfQuPzU7v3k/bCKZcV6RjngO4t9nL6Tgm/XfynLtBqhrCye
dmIlH03GLv/dfBuF5pCO88/J8y4n/hln3Y1AspvYrW/HKezrbpbgLkwCR/0Z
p/AKhb+WA5nB3o2QpPtN/vjLw6hxyIoXtbUYjmDNwm0+1swR5963ZuD2iMEa
25983DV9K+9s0A7+55cGDhoCnOPw9E9V9UAl83bT3j8cmNf/qF3cxsR974g5
mj8EqN8uN5bo1wOdj0rPhm5xEWAa28TueooFWbU5/x2g4Co7SyvQtRuGlvZt
H3z7Ifh+eI7C7CpssTXf8KGVB1rIO+2ZjxNwTcp1jybZ/46PGVdzzaqweuHS
Jb+syP5fOIWrCldgbOPcfJNtfNjIfIl5YNQBS4UchaOuXExvc9g1EV6BrOHC
zEAPLpzlON+Pf6bhRfEPVu8SCjl/pm+2GMyHo6hZlFgeqWc0TfldQie0fuue
9XSm4Oy/2nf4BAs2T5aW/vrUC03fm2b1nHRUjmZukR/nQfLLTL0VHR3wFnba
e4kvgJJWis68G+XIkNWdfbmPh7XP8p3y+G+w1Vm6KsSRwtwdVPBRTiMmDzRV
jvVwULkloUSPn48DLTeC3zXwYJidvGl3agLKpj2u3OhLYcR3uadafh1WLZn7
O5acV9FDcf12fRrWzr2gZnuIBzsRuXs9KQzIeWhEbN0mQOz0HOPIi4XQXvhB
9iyHAu11Oe3cg1ZIzpE17Q3nQpCdY3Dp8BtolprfZplTWDy1au00Wju20XZ6
BCZTaJdrd2jfn4Sl+zLzpW5TiOnZvvdURiFKHlVLH7nEg9Dx+XynjosIL1n+
8yrpL5ZeypaLK9pRaTRcHXKAA3GLh78nnnWjo2/x2NoqNkLWSU0+eMpGxpWg
AF33PriFVWe9+p0P3fm8tGgDCjOt2mZ1RXRhTEj4Sga/F+bWx3JXraqCtrGa
52NXCnbpEk8Ztm2Qi/eMEJflgHuMM6nBLoXottGJKTk+YsWO99BqU1B+cCvv
kj8FDY63e7EwHUM7spssw/hQHtQdui7Fhn7QgIqb5wCaE2+0iJbUwHP21qys
AbJ/Y6eDRh8qMNCqGbtBlwIlOusBe1oTdvdKu9eHCmBTIlbJWhaFL5121eJH
KAQUn5Z+vLod6mvuit55yUPQppjV8V6deKgdI/NBjIcNBTv1JGvq4SrPv9tV
TIHO76GVnqnD33RhH9k7FLSFdVy8n9XDf1I6Q8mCB+lvrYNXb5Vh4bbrP9bc
Ini5bRc3Cc6EybFGnqMXwfua89y8eDqsBW3bhxZw8a1+t1vm3jbYRsxhXyX7
oe3/HlXIz8T3kq2bf54h88g2v459qxpuZ/o24T2FqxLX9RgbCR8vv45fuZkD
O+fV/kNJNIymLi3xI3j3XZ7/l3GqDadEkxkL91Jwy7UzP9DxGnmFa71Cj1Gw
tfcUdrRn4Fng/uIWwn9HqZ+0G/IdEJrVVzSSzsfYw+9nJ16y0e+7d9rbVwM4
rPx38msTHXelr01ZiVNo7gviF+xqA81leFJDhIMFwlafSx6UwnuicOWce3xM
cItnPLnKQsPOR1679wzgjTjNd/XpXIgnRz0ZNqLwYp1i3cnAt/jrfzLA8DTB
K/axu2c1HSJxTtalpP8yadXiW+52Qqxx3I37ZhC0EQMGa1MTGvcIjpzNIPXl
pp7+wGTB4KXMqQvVfbBOvP3xZSENGS8nay0JPyLM4n5d1mmHWpvoIhkjAZqL
fmUUXaPjieS7be6pfaA93zjIEaQjquHS7gVrKJTMvWjw0a4Zf59PpwrX8LDA
sc3NzCMJw5EelKca4SuO3tDq7ISezUp6R0YX0lSocNfjNWgI3rEsdQsPb6Ye
zZzl3wrHABMNpnw/bDzF4m7WZMNq5wezZ5IUmX/p+yXD6ag01VEwk+IgzapA
fo50IUwe6sqrCVNIjroleSkxBhF7xHT9CD8co/cfC9jQjJQXxQOm6gKw/7uw
smluHPbMOlE26kCB8TFb9pdNO3Ze2NIn+5gPw2bbnEsKsTj93GcsgPB/ZPJZ
Xll5BlSWBGTEeZN+jVIzNPzKRtF6v/zqkQEEaFStZpdGEh5S/7ZYEzz0fGcs
6WXiS4ufd7KXAGLVUrliY4XYPsZ2SiH4hDkePHVsfS4sIJ3mbkNB7t+IS6hz
MZ5lrNK8XkXWEptOSJkHQbTld/Amgp/+/JPXpdlMNOrfu8X/Rvrh8pmON955
GPg8Lhu9gMLon1PMluoeFL2/vUYtkwNPrfKhz+erEJggZyLVQOG9A2OeQlEb
flh4DPN/ELxKavZ/yWvHh5Er35VD+lB9UGnd9dgezKk+qFmp9AWJ69NiulfU
IvTJv6EYKQFyv/q7vNFiwjOlMSTTR4C0b9OVGGiBLKWx9VUAH2m1/0R75+bC
xlnSxI9B9KKhvHpDSDOUkvjR92w5CFj32f5tXgHmJboeirtLwSr2bH/CZCua
J+VMxYoIPlsPPYpXZcNi2kLx8GIeNu5WPhyoHYqlOwMX2BE9C+rTdN8qzsTd
qWs7pSM4MJy7iP0isATL/sxdPyeawhTPS1VZpQInhVtpawoojK/RKuh9xcYO
vyVydoWD2LfiH/PcxVZY+LiO3V/fC5/Vr9w39jShplv/WMBKHhSVevon1TuQ
Yz2Vp1lI9LhVxw8rutGls0RC4VEPQu7/S5GVKITOhM+9jWQ+ydidN7fzb4Fr
YUGKeA8Pe18btNwn35tu2at6y6gPDLm76mIH2sAeerhAI5QHLq9LYWIvE5FN
icLTSnhglcCr+GUbbrwuE5Yw5SG81WiO14cW8D3WFvB9+Sio8vV+uL8eqy59
+rPjGQXd21r2goQu5AjPaxkjehoz/CfWmmrH+0a6aG4wBzaM8lyZ0Rasa2QI
33LkYOP6vV+HSzJAH40qtDch/oaWkml4sQzx96LDZyzmY/d1qdCYZ/FIHJuy
OnqWzEdmcX/9+AWEyU+VhtpRUM2QdHudySL46Ov/TiX6spV1V9qnBCLe3Wtl
yXrVYcn/mBwmrFQsR2SN+bA6Iv3BR6UV6ULPn1JeXBiGP06f4ReHoMX0+DOE
X9w8l6zcxHY8dpNbuqGdgl/choB2kQZsl7F/9pSc/8XVnTl6O3qgevfyCb/v
vaBXl5uEzGvA0cx08YSrRH/97h/VnfYeoVkXLbjTSf+/Cna+jyo4HrsQ37OT
hwPzmsoL5rTDPGLFvcsneEjZeW1tQ3MZTiz58GbWctL/8tM73k1vh/Nxn3qH
dgGEKv5WCBnew/sZP+LUSX/JlGb0PFKiI+by4pzL3TxM+PvELzGoAvMRP1vA
pVDg1DoS2FqEsDNycU+3Eb/bO3u87FoTpna9lHQZIXrmqdGvJVUL+rqFq6zH
if97NVHM29uFoKXleqsedcBF78luG1YGQgRnv7jvo8DrSxl6SeuB70itwdFd
XQiTqivYJtyM5KLxq+p5PKhG6NuPk37ccHFtUWXTAKYnng+0f078a2TUK5MC
HtLV1k1TeMVAzUwT2g8fHuiXPrlrqzzExYsLFHOcKORdcf0jVNGJ4rQk5hz0
g+5aEBDn0gplxS2OUzMG4HL5uKqmAg2v6tfqvI3hwVuT/vzXrDR4LmuW6g0g
8zByx/g+23LcnKG8mUfqIWO2RCEjiwHWojNJa1I5oLUNjSx37QLNJOLZfyGf
IKKb9K5wJQsOHqq2qiVcyNTaGaTodsDrk0noFuI3RpvPHI10KIeVSM+LlT0U
FgTO8ovzosE76FXTw5cUrMMTg8S/dcLFXS6h03YQYdt3/TYhflX5u/XStZ+J
n7ITeabMU8PsI5HzVU+Q/EDlXxc/y4DYl1cuS/dTiJ4IqnqPLpw2kRPVihhA
+SLVY7ufM6D458ph36WkfuXrGWeQjw1R1rMfP6agM3R14ERAF2QPbgjvOdsH
K9MzjvPH2qHc+GPxunN8yOnPKpU8SMcSJYsgUQkudOelfLVqaUG1yoXcAAEf
7OiE4czl3VDmKNI58/lIdtgVacBOxKo6P86ijaT+LvLiIjdZcK0z+yrD6UOA
xUcv6aB4JOuE9H8j/qGoSFLikxQdsoN/t7YF86F75dAvvYPdiJ0/vlPyPx5i
/fWN9tgxIG2YMMo9wUFs96lFb/fHYbvT1V3LCF/lBs8NmLjUY3JOgXaMGg9i
/idPd/+uQ2WCSXkjh48weqP9Vls25PJ1xjkWXFSHS9nu38nCa8uYJ5nLe3DY
8cVjGZca9NT5FG+KJ/Mo6E4ti92MkKcfkH+Tj0Onw6pP3WOS3HUi+SPFg1t7
/x3RbZWYubRT/SDxa5X1/i8Xhtajae9oj9FlLkyKX/lZebZCsKr0TrkqD1bX
nz6o8W4BUy1QK4fwf25dOCc6vBOac7qjSywH4G2ctfW8yyPYFuRnLCPzhr7X
bWgaFYe9FTPLRkienHpuqF72iY6GT5PjD0h+u8hP3WOv0I5pCd5OcjYc5Khc
333HswKa0WdWXg8j801ayMhnqBi6li3ZWiQPqLu/Phps1wCRuWUdwbVcqKfP
v7l6RztGxE94msryob+F7+JmVoHaXJVgCS8eDv6SHS3ra8eXN8oqBjfIfLig
7zLTOwgFbRue19hTGP4cO8+vqQKLbiTRGzV4eGxsqWVl1gXjLvMjB6v70Z6x
VcMtioFGd6d76w0FUNQ78C2npg0N5yUsvqaRfmJ43AkwyQJbIZypRfKUsqFi
q9OTbmQLKlWO5A1istXcwDuSCYbhmZVR70n+a70nWd7MhsRvqQ08n49IDr5b
N6s4FeccfT1zk4h/fXydHrOtGjusQykvkg/GLDLfR15gosQ2n6Mb1ofOlVOH
QgM7MG7plniARWF/5QVGr1gdti1obfF/Qvg3/+wOYe5bnLWc2swn/tdT3WRK
5zULrL64v65pxJ98yt3tWpoJ+/eLbXWmUbigeSiPW94FhrBumMOQAPKpPp5v
/tUgNjN/MG43yaceOqL3mdXoy489vFmCvD9VHNwQmADHhtCUpE0UbC5y47TN
aQgQ3qL94hEP1AxnjS3TWAjTNRxZyiL1epl4RkWkCorK/PLmFaS+n740XGcy
cD+tddeWaYRvb20NJWQroN58wPvYUwod4+sFusUF4CaLCvVfpxCS8vDzzwkW
Pks4S17c1wehxZMdI/qXUdQ+wUsm/mlAPVPllEgiTBwfPHxK8gBl/27w4uEK
iEU4fDcKIeskJdev57vQPLBZZ92KNtxtq3zJlCqH+fZXSt0z+dC6XZV+kpyv
K8Wwji1G8u9i2kRBajEWvPkt2nWJzK/mOob1Z6KHlMnP/nv9oG0J/fm34RDa
krIHZci8kineExV4uQI1mjEP0gp5cJC0WjmvtQPf17Zn0e0FuDnrUO7aK51Y
8XvV3Mg1XzAamcmdVOzE9x+LGzbvEkDu/Wj/v3OvMTttUb+IHoWu+C+36qzK
UdmXwBt7R4GzwXajlEYX8jRun18S1YfXriO39NPqsVyek7SD5LWgoKSFNzTK
UTrQ/e57J5l/6VqMZcfykE3lDl15RMFr07vW1zKNSE5VmO22lPiBmzbdq9dE
wNIpc7PaKcLfRCU5/qIK9Pz3Ld958v/3Uz/+iMyGDN3PoWkP4WvhySXSStnQ
t5gWGkHy0M3gHpoY+wNYuubrzT0HUee97053aitCxs75LyrnQLPGOO9ofTX+
mdC2u28m/VjGfMWeSodO3C1bQTiF25VOHrlX6UiPTu6MGu7HLtttc4efdMA8
L17vp+InPLGx+LqQasXbD9pvF4gQ/N/mN1ObcuHlWUnfRPBwbuGr6ps1IfNE
jUPYWj6mWtzV5wS14lZVQeOsT0S/+cus5wtlIuX9GdoNkgfZCfpPgsnvBVzJ
T7uhykeA0i89WW4QFg4p304i5xn5tsY9ezH5fo+Qit+nT2DRrmkyxApwfJ2b
6x4RPkbCum9pGtSDHbqf+Yfo2e1xtQzlODqOv5zxz76TA9fp5rzlK6vBzRiP
zKgjfnn09xr1VV3IcrqTNE27D6MTjeMh15gYNAzVLlWiIKWmOO/3uk645ftp
TW7kYFRpuMFfqhpGvzebPSd40EdP+xfbMHFwkum1uJf0e1BpFz3SAqZHTFLX
kX57ati2+utoLYa+LSwqDCL5PyfT/GxbKRzfPWC4y/NxZ7pxt9OiDugWbz2Y
UUn8fLb0rb/51fg9XUOwPJUPX7XJcLHDLDT2Z+5dGUwRnbUdvx9XiBEW+sf7
eQi4abr0mlI89n5f8SmJ1Fty49hMvdRqfPm2wUOa9JPu7KKYz1Pt2DEj+rCh
EQ9lA47859fa4Oxh+/F+Qx9YR8dHlsk2wiid+zVeQYCwDTZ2McIdYDuX+DUs
F0Dp6nCxmmkbZOsveJnWcKDjO2iu/KgQbGPmsqckX1XOp2sJxWRh0Chd9jVZ
s32v55sa0pCsxWk21aJwcPTbZUPjSgysv/bPkOxn403aPQe/dCwSX9UspkLy
6WhfVL5HE3706F3ZLMlFrLb82KqxJKQ/ubcsjOiN9fHSD5p2vfhlm5sgZvsZ
VLADTceIBZsy4arFV7nw9uPeN5tVhY+svMxdJD/nCcxaZ+oxie446w2aDMLw
smlGV24aVh9y3fmT6LVZiIR3lQMDCpFlXYNZxM8UGo0Lq/VAq+RjH7t7EF8K
ZdY6c9thvbSVq63NgWJJSPa6qA68vKJxOyBagCtjeU1RDSRPvDa+o2b0//9L
K+NNXDoRidof8VU8FDGFspb8akPKl6O3DR8IQFtQoNjW/hisoYsZ0URfQ3WJ
BR2swbXcQxKWUhTMd+j3OPOZiP+6ws9yuA/t1pYnVMTY0Nl2cnK7Gwf/A70c
IAA=
        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81GkbxsmGiiiHxLIVKZXjYschl0QHKlIR0TKdKCwRvdZam0OUHJeX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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lGsbx51S0ZGlUMlEJSIiopWfJMkpIaFIUzg0ScryqgjH0pAllDdZ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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns0ldkfxit0G1NSU6aLW7lMmEruaR4ZJKmlmkmUxiWZUCREJSWSkqgh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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k0lA0bxpFKCElSSvaXSlGUii5LlEKWQsiaLCmlspO3jRZvi2RJyBZR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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8Vfkbx4WZRBmpjBotxl4qpMLQR5NGJVuWQvYlolAK0QwliRhFllLJ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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk4lekbx4+ijbZDzZSsZawRM9miLyojhGkkypSyhJDKUmJQktSJJLKd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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lWkb1jE0kkiFduaTLTOlOEXlEka0TTWWVERlyy7EWItKaqyNDC2y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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VG8bxhGFUEooS1FJkWxlzaVFIluEwk8U7Yu0EYpKiwqphCTZSYWy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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk4lekbx4VEm1Ep04bKOkKFyQy+NJoWKZwQlWPsWxIVSbZSOdlGkoTQ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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk8VWkcxm/GMg0ZlVI019oMQsoSbY8MZUnW0aooZY9SslWSUKRGmEi2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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk4ltkbxxEz9WpRGdllslUGCdH4+VomlaQsw4wmUdnfarS+hYnQUKiG
qVFCsk5IZMsar53XzmsddJ6KIqGJRHN+fzzXc53rPNd93+fzve/veRSPnrJx
FRIQELhNn/+/D3g65A8ttYPl6DyjwiWwU41dd0SbD+u97uKdUgyGs+7y3og8
hFZdvWuVM4HxFU5wal4/5EX3yeg+YeARmfDCoaAUDT5Vty+wCRJcit6yIyLg
HL0m1+sIQejyB2Xac3nI2tQQftydQO60us/SUi9khZ0WI60YnH5sOPJ4czbc
xvVVVY4RPD0esJ69jQsTqSYpmasEFZsSW6xNu5HUaJ9Vv47B8oVdfltOPYdm
kFKU1GkCraY8m8BzSWDLZ9+fp/VZ/vRI7v2dRnAW4wpOJxLItM14z3V345oO
ny1O8xn3R0sfOtEBvktljs0SQU4REzC5vgs+Z9s1Sul5W0nzzGXdVPC13Gus
XQgiT4WKL9a3wcubWRE+SsAfnDVSdazGMhVH+9d+BMFzrudrbbqwMeGivscn
ggDN4IvLQOOv9SsvnSaQxl9v/NPb0TktZZWSRiApf8DMOqIF6jfrxuNqCVQm
CnVeK1aiJqmrknWBoHCCVWrR3A2TAbe8SHkGhnLLfDVvtcD47vhWTfr9jjMz
DcUmrTB6x9P9poJgqlEpUOZECVRCF/oenSAQYG34bSLKHzPvmlVA+Svlvdx2
a7YWfzju1jweSfl4TPdmuQ9geJ9BSK4/g4NPwx36BR7jEzcwln+UoH2r5dod
k10wtl5RwBenPDRjWvN7KrFnUchT7BKNv1HihrRxFwbOabnUSNJ9toYa95d6
OErWtmy8Q2CrrPXt9yN9YIvtnciKZXB4Bzu5icuHpGLzw94LDLzeOoWVJzYh
IJib+i6BIDtav144+xkM7Erq0r0ISu5oLFgcb0OGWriMbC+BcNaRqyMlPKSU
yZgW0vOaRqTpukS2Q0hf/soqPoHYrsuj5cGNEKoQD3lxlyBtTHj/nXvVGJ1Z
K7IimOBmVuXJN23J4GpsKlyi/aH0bYyhHqsa0VXxqiohBJMh6y75WvdhJNbo
H937DDhlH1yHVqXC9vKWXzWp/rP32iTMmDzY/jjT0udJcNsrOXM3rwr33oo2
BvvT/PldnqwKPqS8Q0J7zBlUWhX3SMXwseZk34tSGwYJebaeb73jsKdYoMSQ
5g9tDRTo3dCJQJVyyXZBBn4ZnHyn6nZMDsgHP+IRDAcEWXHk27F+al+fajOB
iL3ZnxVHOtC3MmmV3zyBXm6sJW+U8txNhkREGAyVPV9/+m0PKkRedM2aMFB0
Zx30nOZj4yFpN9NVDLa+b7G0iGlAmeitdQdvE7wU/TQ7vdiJMmdRbQW6L6K+
a8npHz6mHgtFaR9jUDYQqSC5dgCF4ekx+84zMOKIM7k7O9HwIFP89Rda34SR
gbh5MoqSPV6YUD5xgiM+ejfbcbZx2awJnSfj9TfzmnldqBXX8xCcIrCKlZgl
tQPwvBVZ2VXNoGZhvLavuBtju+u+3NjP4OTkKw7zYxs2vlKcMyommNCSyDHm
duB7OTmZ1SwGAjZaOw5Z/YqBDfbDOrSfTQsWN7Fp/XoRPO3nsgzSdp3/Wl6s
HFviXS7N+lD9J089H5NvxVfP3nfZUp5zpjfud/ZwYWzOXj15jfZDtr/xaO4Q
akyruYW7X2JgNrfQIIULZd2xsl8Cqf8Urbx71L4XnDCZWoUzDHQMc5f7+pbj
rJ9VvT6NL9BW+7QwvAY6r+ZSLH4jcI2WevdNShO8Pn5MEIilfKzT3J92XEFP
1Zm6XbRey0ub/57X5eFwfKCC6BPKZ4qtJT9YiOXJ+v+zo/OqFNSoWDbRDI2n
TiF2j2m/tZ+TvZ72HHZqmRxD6i/Satv3VN6swsH5qubv6PqHpGlPtwQebCJz
Nt7LJbinR7Sdv7TBPdO5KH2E+uHimdS50avwXmd315bmP9jxu2Zo0d/gG3p8
6aJ6ZZd19o66FiE63K0/jc7bTiuzrB0urfht6HN3fDaBe8ifUacyKtBgH7xw
4DzBrX3by1vj++FCig2+LmSgPmJu//vKHgwLv9nq+Z6gS86y+PrrWvxlqTuV
cYP639Sd1Va99Yh0UEhriCLwP7GCFSAwCIf9l3p/Wv0SWt5JcSmbC6AuWPph
0I3A42cnqQafSkxPsvce4BAc5ysNsiJb0bDI8hDqp7wnozKg8SfsJkrm0+h5
xMc59Sp9deDomtu3htF1yqk155/1IqzJ4pq2AYOvHn6XvGt9I7pfm+UlU95W
by/vN1SvwR4hl50/B9H+GOX2zIu2g60dWhA9RzB+wqT34+1qpC07mavkS/3r
QXqRegwP3G0bFqKonrJxrpvVbnTCoerbwhPKDAzCs7wUqtMhnT2WPEV5Dm97
oL7zVQGuFUg8U/Em0A/5YGo+nQ9lwZgNJ+l9x8lVW6vMakHcL9+fc6D+L7Za
wsVEivLmc8c6qN579HOlPU73wPKKoPqYBgPL1uRDko08tN09lhqUTHmGHR2L
SGqC5+erxyyofzsn/ZtoUdWIDxlWXhY03nI/E7NNyg0o2KOvJh9N9fY6fODH
eB6UhD5EX8yg/eDaGQ3VQqgtkSwW1bsu1aNnxC8Xy3vEOUGUf07icGrE4SEc
EjETNnrOYEDo2NkcsRqMb5cdPk/v3x35Ws/0UwdQ5i6vOOvN4GbCmvoLdQUo
0Xxo+QONd27s08JHxyHcT92tIzPD4NPWwGzzzx1YmWj5N4/ybU+9yMT5cRG+
Jc1bkPJfyoyXeyrfBV55s+oAnW+tMM2JbK0/cNbkq+zrVN8v85V5Exb9yNJ4
5C/9O/WH0UExhtOOc915gRbU/yoMG086ri1GzotMsZf0f8NJqubifplipItV
OBrTeqZe1hFBTiUejiwInT1Dee3XHfARDMFDrcFpSxq/8k6d7/ZoPvr2CtiX
Ur8bDsrS4RrWQmK1THT5dQKvjgDhmsx+8MIkiYMtg2xfZX20PcGhmIL+NZRX
q5nFv5/FnkBHNZG9yZXgiMHVpHy3eug5Cipcj6N+Y319C6uSDxXZhHcTtF/+
A2K9wCk=
        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8le0bP0ZRWRF6G0RISIRI6kuhlN0gyZ69hWRElFVUklLqlZASSVKy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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81dkfxskyimrSTBtlyxZjaVL2BxFFmSRZI7KVLRWRStKMiphSYxlL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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs8lGkfxieHikpMJatyWgppcyhi5aK2kp02p7RZrBXFS1IreSMUNqlE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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lekblqWE0jYqKYe0WPJrUcjkRkqjwkgok4kjWU6y01FipozhMEay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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k0VW8XRoUoCUWGlBTpVymlCA8VSQMhhQYRqSREZMhQSTQgJGTOUEim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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk4ltkfxiVCaJEQpVCmJEsKQ9ylIkOjka3JVhgukshSaCERkVDCYCLp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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lXkbxlFJKMtY8tYpZFCq1zKacI6rN7vUlDXRKAYRlaxTtohXKhlN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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lekbx1Eik8LIUvJDyTFIVFJTvkSoMZJJNTnZ18audNGmSWKYLGGO
JUlaiJZDRUrWOJY4x+EgJsv7ok6WijAlv6c/3uu9nuvZvvf3/tz3o+4WaO8p
JiIikka+7/9cFdOHOS48eAf8l67VRWGjw8DzhzcKsaDs5ufvRsHUrGbj4WkW
AmSLL3OcKUyF96ze5NQMP2XtrQvZFHyUMpvTH7bDNmN3iKKAwtnU3OrD2zqR
mDTU29hM1scMeV+ffw2nsh2SooU0xA4MBkSPtCHbOujDdDqFSrFF0RquPPSJ
B88v+0DhjoPPKlU/Dt6xf5rRIecbOxk8XWLXhE+3PYRDNymkROwWCqyq0C+R
pD0VTiGAPf7lN0EbWPe/uH/KpNDffMp11IUP/0c3S/bp0Rh31pThWxI9zFep
PxnSEGGXvNb5PRNr63dFjpN4sl7RTP3AVwjXLnM88JRCznSKyf2GDpg0nGEF
t1CwcOxPdPHiwdzO/djeYgq/mt9q+/hrO5z0J6vWjFDIl33evV+Vh5CTHMaz
MQotg6s9/1brwWbfd7JGwTSYxyqaeVHN+FMvatmPRRQml6ve+OvTfcizOFZ7
3Il/F+TfySmWwtSNbvrqS8FlrIQdVJyHhL3//k/alcIDZ3pMS68VzYa0v1gV
yU+ObhvjUDl0D5m88/Yn65e9zAxzyEasXr64pQsZf3Nl1b55gK8XM79okfML
PmXQ5zPqUVviaLArkYLeyiLe9sc8pGlyFOybKPgViXXfK+Pj6YCbxHlNGl7c
j1uS2QJkvHBcu2M38au61P7z2URYxMWKhBK/Zi9ttPUouAmx5l1Z1kSfZFlC
0C/rX0CuN0Sl6hiJh7UspGfgJez0Pc9O/0nyN2Ui/+jkS8hxVQabz5H8iHxJ
q5Zgo2pgUE7Wg0L8C5PPs7Nc+Lln3dn1L+EtfVGG/4YOJIcnULMqNE4XJ/Yt
314BN0aj3LlgCleunFSt2s/H3/sD9qr0U2Do2FEtRp1YkbXlv6u6NCZLHGWa
fDIQrxIWMkj0sgbVBGKvn6J4oCde6Ed4S+/L85GqRSs7x/7QGQoRRR21Ej/X
gOOmbm4TSu43tbkfHhePwiznuz7f+VAY4cw/b4DNmi1eorEUYka9H3lcaIF/
Bdp0CA8xqix68j0XZ64qf1O+Tfx4KS1VnlGLe08SncVPUUgOkBvQsu+DVbzd
6R80hpEsNXHOvleA7VXLExdcaLA+VPp8tizDLR3jhvvEvzVpWwcNl3LRUNC9
Lr6O6OXUJITP1cHBz2pU4jTh50HH533/VILfJGc+eZIC09rH4cgwD6mtasWy
xI/RpSVP2iYqMTuzXM2H+NV28xvrfGkNapLmv8YS/2XyDdmnLPgYyFlnardA
9J/5mnqi5AFyxw7oRhNebunW6hgoNiM3S71QN4+CvsXSQIWCLgx/PiwEk0bX
EfVy/2NsLD1+XaSLrP906SevGR0BRCt1zl1h0JjLy/1t63g9+i4asaISKIiY
xAn5q4KRcmdl2BbiZ07SVYkPRyph3JgovBxIYVfN1ppnW/hQ21q1YlcZ0VMg
UKodqkBBmqyvFpk3HBgW3tHowXoj5rzrCRqLxdVW3acqUTjiXm5L8iVSYs2Q
cK2DSrWd+lgk4Snw+pS3kAPbsBPth0n/sHufm2KqzobQWWn7GOHto1DUmxEg
wPqI8hN31WgwRK/9dVG5Got96m4+OkGhPuEJI9OnHgMvumOUoihYhzmdPtSY
hdyVsde1SH1FWq7d3ZSUgOzPngf9STx2Oz44hU93ozupt9zTm4ZAs/DWcUkB
skW4s6JuhMeau0lTsVlIVFSOXkL25227slJ0qhNx1vIfGvfQUJMU3XGI+IFW
SFcFUai+vue6m0Q7GD/P20y/piC/3zfLqK4e4qyil8w40g8yFS9Uby+B5iJ9
0R3eFKi5oTru9jpktnFDo2NIfX2N+WXeIBuehvKTpuQ+p52znPjUXswusbcK
HaFhF+QVwVn2Gqnh2tXUHzQec3OfrX3bjgqecXsN4afgyHFx58V8TMnvMz24
goa28U0vmTIBHJTe5zvvo3HpDzzuselAoK/AsVeZnGfkWcm+fRdCKvmZL3kv
LE5eyzJ8w4HFZPqcdAaFY+1RMwXTVXgbvW2BR/K1btPeU4uYfrg8bNW1ifgX
Y8xNMWS0IOYH/vqdFRSWTcqbpT/twl62Xt4eKRqDIdm1Zs/qUGgjtug8qT+W
or8M80I7PopnZ1k+pDBYrinZbyZAT+hbofsSGjk6UkNGNdfAkBPR2UfiDzIO
GlJOfoFjB4NveBB/fTY06ltGFGHU2nxnINE7GHpA2yqJj/ebjv7eJ0mj6tvz
utrz3dAVdxDxIP2wf8W1kdLjbOgIdz54QfhpKynaU3uLiyW/9bdoTZAxX8V5
vqcHUon3zFavo1HCEhRJSddjW5FBBiuF8L5mXHZpYD1GqfHutIvkfQi6xnBs
bcNRybKpiWrCr3hT8VtxJjJkNLYYED/u/HhhYYpqwbYcnRlz0l9sIlXXje3t
RKtlk5TbKsLT1p//dUopgtxcQawOqb8s3TOuqqW9iCnV+IfjR6Oyo6GU+4aL
tLZs5q+9FNSCr64tEC0G+96TjKjv+jffdp+wfAz3JA1jfR8KQ4omeRIzXKzo
tPPtaaCgUdr7y87mDpSHSsZOkPgjv7E0Yw7EI77AVft7P+z3UB22z8tG3Lzm
yaPE3w3CN/vNZnpwbvTvud0HaWxYYWt54RUfFrpX+5SkaTxQ045U8OTgyJD4
xoWzFDzermKuTRCgcHOTd6spjcMX14XVR5H+X6a+UWuUwjPGrcgWZitWn39Y
OHKDgpS8wdFDLTxIOS2OODhAYb1tgM0Epx16urMtB8l7yl70T4WfNB+6aglJ
/mR/9NyaxckKHfBTYHV5KdAIsZQMGe7koSwu3fHsEIX3091LAoqbERFktomZ
T/KxISL/XkwlwoznIjVI/T925qqW2vLwe3uaUiO5z2d8/8XPvHY4yAeaSBAe
S80DW/LtOlFhxhxxIv5svqzLib7SjcTO1imZVBpXHd2vFWlw4TJRGmVI+tn/
ARUVu3A=
        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k0FX8fFqUiJVla6KfNliRtKB5JqFSKJCTZi1BJKiEkRIRKIip7yE6W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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlns41Nkfx10jpdyy5bLYdiu7KmxE0tstdt0KXRQpQiWbFiu1iXLXZV2K
UixiWBWDjEujhoQZQ+M2Lgkz3+8oKYRKlH7f3x/nOc95nvOc8zmfz+v9/hwd
nyBXPwkxMbF0avx/dp7X127UGoDbkIPmzj9JVI8wzu9LbcSZdTWb5bgkimRO
KJsd6cOWM8yiSIgQYzjnywnswboIwe+MChHSWVO7Zb264H3AQfbKkBDar/fn
2zCb8HHXYFrxbRJ6Zye6/cO7EPC8Kp6WTiJtGUtooEjdl6JzSVAqwPf3UnKj
X3fi5oGTRRE+IojRnVd9y+8FrTjG3jhYiCnxfaP3mQx4Wondtt1LIi69psFT
qxeqx4ckSj8JoK+5RXv3P1UYTFolffYzgamVS6xTpRiYX1CFZDgJR4FjsN22
x5B9qN1DSyCxGB0YIp3ZDYePy7fTKgjExDvm7PjSDycrv9RN7SIMS32dp58f
hN7YLU/3ACGK5z/nuta14nBRQzCpT2B6+mCsSf4AnAK8zVscCBw4xlLKautA
zsUlMzwdEhuSK8xsrBvR4K3W5nOVRKo8o/mQQyce3BlRvfeMwJKGJ6L4DWzI
nAuUjXpHICNga8K7snrYHLZTJ7dS8YbejLLd3wVl0/di0fokFE10D8Y7v4RO
b+Hf9BYhZPO0cvpfVeMCm7hsJk3ittOhhrahflxrbwNpNoLMQhnV4DY+4r6n
n7+5SwAT2oOD5Lk+8JOsTh65RqDvvRabOUkHp3npXwt7SBxJO9BRxuVizipj
3kSCQKWabMKln5tRvVlG8rALgQmPS3/dt+Kj/26ljk8bid0rLVVs63h4ZvB4
QyydQM5I6u3S8yyoPA0q0osjcUbuv+cno4dganQ/qvb6MPIOZzJolQNILesI
so8jcGd+fcUaty4E71HYmVhGoniZ60mjozxUroy86jpFIoGs22pmPAiu2tu7
yt+E2Ho2StLdiQ3FW84OKddIzL933HuimweRdY65GE2Ej4m/Lc0Z78U/Y/oy
2bICMDcmuqTs4SFMXJmu/lqI7TGhT6WMWuGuu7B8jReJlp6m79ZpMHFVbjDr
1mUSgaEP3n7r68WcwEUQIEvA0Uj6bEh0N0pCtCB1msrP64imtcIClCluuaj4
B4ny8fY2qawekAeS6i54imCzdziyj9mH5xzd9S17CCjoVI43TbJhkulSW95N
8bHa8ZXGKA+rYxeVlj0VQTbgzt+D0Ryk9/oqyk2S+JNYTJqp7YRa+uKbWmo9
J6WktGFHKwSb/IxEJ0iIWaY5KOTUIb8ocnIFxZO/+t5Z2nQnGGEPfYwXCIi9
yQ96uTke/DLtZ/2HSOwptF6Kz53QjDTkfHhMYsu+un+FPD6YLCOtzRGjCF/j
GCZ+tAYNEfaNbskkphQ2MxntuahdljO96E7Cveoq68RWNlYELRDnpUTovmfV
anZ2AHsaXDxzDwqQU+0r15xfgCPikueG/anz2RorfZzK4P/V/NeZKySOLz76
VG7SiSMpMvekVCneMu2+OAVXwPnSzWHXQBLt2yxusK36If/qbtZRUoiAGt23
sadaYZFSVTAiImARv8D+LakXIWoJ3huCqPh2XAmo0+1B4OcvoZWUvu7T6el/
dvUgVaLxSvhdEtfXrvSOyufCh+MSmkPl73Tij3xPNxYsPf/Y56ZOgru0NVpe
7AXe7X30KoNNYDau4gb/AQMTd7Zwpb1JZBgIYmSFHbhau2ntd7YEYld1eciX
R8FE5UL3Q4qXj5+1rs32vcB7k+ech5avEK7ANFPI7YBXfZ9afTaJH/rjY6YK
G3C/XlL8C8VLwnhSt6FEM/zfrFlioEpie7REatncCwwrKI1WlIigYpF8pUh2
CHoJhtUeMkKoLJ9+Yyp4Af/UX7BtRACNdWXGNesYmNrf3pjmRqJbTp1hw+hE
p+b5ZVIUnwm00R5WKx8t4vuLUqyFSE52NV6u+QRVvbmjvxRSvFhYaND/YyHJ
d4LHnSVxtdwv1taehVkt0VTsN4pvyxL7+lUcsCImDS/1EVCbCNfKHuBB337Y
vGkNCe2lVYYT4QwkifUzt1O8axfE+dvl8bCEYEgnCIUY8SmIk5EvgfOkROQ5
Su9exTq7fi8bwOedGk99Do2A92FGo0SDD9ux7crT64Xw2PIr7Y0NH3od/VPW
P1D1SxTcWJztxpI6A/qiB4E6lt9MLsWbsv7GAxFJBPJlxFPna3tRK8PJ8CkQ
oPry7uTNzfUoPjrAzBglYKTvuEKY3Yn29b6d+7wIaNA0frwe04R4evTsy08E
BjdoZM3xWrH/1xvHkqtJfEnbke2wfAhN23q8X68WQmzup6U/211A36lroaZU
/cPqtHpLtZvxNTcmLJPyQ1nXPI1z1lxs4mnNqx8kkdR8Ovf6iwG0fMp0XiZH
4k5IYqXeBSZqLt8cltlIQsFjYdDTqxycJtqYLtU/H8rd4eTyszB+LO+1uScJ
lpejjVIIH2r+Zkfdm4SgB3TtNZprQJFwZ7D3KWr/H62cxL85YHjQrF+lkRgp
qfHydbmHufnsf4+HkNDfaLlTsZTysxOErB6lJ9MHYb8TrVXYtP9kgJwBCRux
E9olV7iwnxkbdfxKgn7Myebl2l6w8qbdLAcFiMqYUdaN6Ef2YeYHRy8RXNVy
081f9qLNq9l9dJcQXeoRho8qO2C/aTxUhdIX7VZwuvdqLsa0/vMbvSXE6pKx
L7W2bMgaWAT9SNVvOc3igYNUK5znFDw0+yn/0T198VRBAuye7D4qoPJZwgq6
oRf4DMHHC1Ulhig+jtVKP/u5A6aJXwcm1UR48/aMTIwKxdNGL2LflBC3i21W
Scm3oiQ4M/u73VT/fplcskLpEdJze8Nua1Pv4wfGWEt2IzlhdHXQcSpefm6h
7loeZuvfOspfIlBUbYqoRi6qY2Qqcqj+EepxubrYlAPzjMg6DRPqP9Ncqinv
R+nj1NjbjVR9u8o5qxpkatAolf6T+hESFn+p0z0CHkHJzTf6wvckDO0yOU36
bHSz/3nfRfUrMqsljz3OB2Ob4ZMPkZR+J4rv2RqzoBYV+EIxjPI77jfDSUk6
tC1KH7seJrHzt1hxp3dsZHC9y74ZE/gf8n246Q==
        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lWkfxk9arEkmUVlrRsgpypwsk6skQhpjKd42cYRIKglR0pmcwdvI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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkbPyolS0TfJC0jocRIi1LJj0bLaBpKU7ayz9jiDE4Kg1QmJKaQ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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lA0bxSUVIkuvsrTInhStVDhEpV57soUklSVJRBFpkZIkSVIhCWVp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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk8ldkbv4kQyjIGiQnllxhakIgvUVTWyRIpzKSiIjW3hEqKMLZspUwo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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns4lOkbVvkpsdUuihxWJSs5n5V1kw5TQsiabE6hsh1QtDoocly0jtvK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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs8lGkbnlRSKvYTq3JIByWrjSmrwmWaioYvomTLOlUqOaSECjl0IGpJ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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k4VG8fpiRbUVESUaSiohBFbrRZWmQpWuQvhCTtqBCihYhQIrKlKJKy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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk8lWkbVkJqsmV8SM1RiWxRDF+qyzYqES0YYkhCKkvKUjT2JFkiyjJh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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81Wkbxg9NKkwknRbNvCLLyEjLKFqukq2SZCqplJGtkCUVGi+iJiUZ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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns8lNkfx9W2UoukJVvUxEZa5bXZXxfb9hG6sEhFURi5bG0o93QhkUiU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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8Vf8fxyUrMsK3kigyGpSQFb0osyhpiBCSNJTRkFIyUpJIyaqkyMxo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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwdlns4lGkfx4cURejgUCtRORVLRJls30pHUdSgrSkiUeml3ZLtKKdaciqJ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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk8lWkbRqHlUD4jUkSIRknkU5QLY8kW6lCTfY1GoSFtluxLSWWksSRF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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lWkfx1ERmsSLiWQQES2S0qbvlUmDqBkpKkX2SrY0tkZKi9ceQods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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lG0bxkWLVKK88aJFRYgSpUnqVCQVKktECaEsRSVJSGUf6SVKSmSL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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41dkfx2Vs0UhUI/wwlCRJE36i5k1lSZGkbNGQIjHJmjKlbCUToUW/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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns01VkfxuUSJYqSpHIJkzQSGmLqEamJIWOkRiqSS+5iyuRMcUbCIG8d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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lWkfliUyg1TWKWnzhZo2xUd1nzJCfSoVGppOhGQrUio+ZCsZ66RF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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWGlcTH0bnnZSpHq0kXhKiyKyRHElSZKEkLSgIgpRlArRIlFCkhRFmyTt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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41Gsbx0kLoqMiZUuWNkvUkd03DtLJViJapLK0p5IQh7QhkuXgLRVC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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns8lGkbx9naVikxK1uiiCKylJRS/STkUDoQrUMSpZySTrI6qGikZIk2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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8Vmkfxi1RI4lJvK0iIxMZ1ZDGcj2GqRReSyXSiMqUJULWFyFbI6PE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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHk4VG8bVkmRiiJpHVIkydaG3JJkq2zRIhWJQpZKElmS5Ue0SkkkW3ZC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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81NkfxkdJraxiU7OUe4baCiuF6pFYCpnSCpUsJUmhi7Vu65a0sbQJ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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4lesaxonMJDILUYatRCObuot2liHZR0Wl7GMjlKGSpDJ0sJMIUWTY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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkbPyEkohiUNdNGWZqRlPQrmZZv0ldGkpCyjISk5pTkkBZEY+gb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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VH8fhkdJChFZSkkhRZakBeWhpLL8qFDZQpJ9T0pJJamQRKmQJFvI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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk4lXkfxo/BRKLGjKbSkWQsvWPJUspy06QkNcfWSJKtJmuUNuuZGWS8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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk8lfkbRVmTlAhpE24icjOpqGPI0iQuGSXZCaWoRFnKVmYUGQwSY63J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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4ldkbRW6VSlKJ5JI7aVyipFlMmokuKCSJySA1pSYlybiMw2gol5Qw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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lOsbx5FTkjoloZIjUYOU5MgS30qh1XqKDrKVJaJQsmRXNIU6lESy
ZCuNPVHZd2IY+zrzzhi0KHREnN/7+2uu97pm3nme577vz/fzbLd1M77Ix8PD
Y8XLw/P/T671nmq91/XoV0hXrvhFQHpniUWuageClFLOGKxgwUFa1eLA6QFI
Plo7V8M3BqraE9usEQYaLBZW8jgywV64Hbp1sAXrbQ2/nxMmIFV77YSXRwyk
FE5xHf8i0HdPfnyFfTvS+JVVFWrY8C4O/VSXXgaqf/xmXVMChk+qWofPdEHR
LObiKms2qKufyV/VrIKVwN7Brv1sTA947P5NJxuikHt25gyBzGTzOzeS3uGs
2Z5fLVEEXLY3ZYfJD2C+LoT+7dkY2pl3hdludWijLD5LuETAPTLskyToaKDq
US4cH0ezs6qCa1E7CneJHJosIt+/afUy5XEoPnX9/ceCFQHRSz8Lpqt7oDJk
1P+ybhg8M4TBo9fdcGZ8FfpHm41XZyKGmhPrwK+ROB8bwkbmoNlIa/wHSP07
G3VwkABl4IDfNo0ebBT+tSQbzcSF9gG605cmfGtbezNDnoVcjYkR/dle1Ddb
qzi+H4O7TNAEla8Kd4qKK/Va2VCettxu87UXwwmBA4KvOdAeiThtc7wFzs5u
cfuTxlBRcENzp+pd5BmEWPdcIPBRorrJbLQb3KLsb2eOjGGw1M8qM6cTD2jU
bFM/Fn6EM3jG1QfhtFJ11HhxBE+3rzrX1NqKqnRvh3gGC9dMte+9qKuBkON+
p0ffCMw3B6ftWqyFvFFBUz+NiSyuDbViUx803CSf65xlYjlpQcZoTS/2UXV8
ZQ8Pw8NCsee3ODqCjwW/6zjKhsjUigOJieVQ2sndMuvBAloD9+kN0SHkGiXD
+4MJx0h6r8W7Yuy02mFeHkTgnw2vFJqv16DqUG/1pt/Z8DS6wy3K78LTqx4G
DsVslKYKc40F6hD83EWV1sBGoVafXeyTJmRXLFzYcojA9JMf001/N4Lymeeo
8lcWTCUZxlq3GrEx6Iy5qSQbNelPYzc+aoSViXVYxWECPPpJprG8K9HWVWep
RJ6fu1Xs3Frfdng+8d48eYONx84Kzy6Z3UNyifPGjRYE5FMq7sXLtYPnuKid
y1YC0S4usxWGmWgyie758yLZjzzleRuj63EiYqMCJ5cFcodabIMeuM82RQdu
GsMYMTkofLMfL4JWv/I/NQG12EtvpoML0EBf7pk8RYDGd8spdjQHX+X3d7Xo
EqhwjZ4xK2zBcrFR6L1IDhrc90gSmQzI/gpYvXSDgBK/UYC2YT52b7x+3EGR
gLdRm+LK253IPP5ih2IPCwIb6pYWhzuRfVYl7dfgODi3s6vf9nThB+sLlvOn
UHH4crh/Uy06iNlxAVcWBrPeZCTbtmFy5/heixEmJnz/IyLj+uEjKnxL+esE
aKOKJSrTZdjgdqXbMpqFf3Kcp2rs2nDFM79cf4ADkd/yf9InizAW9deVTwoE
yqvlLh8ZrIL4kncInywbu7cMmUbuHUKMmnvgf7pjMC3ZqmC2rwptNR/nfC6w
sEVFe8CtphKhgbRG/o8EZgFL25pO7ElkuiWt5CD6b94HiYuvsPsh3SQ1hMCy
O690u3Ib9KL4PuwQYEMqoLHx5NlyRIkX3OC0sBBI+XTSdn09ytXDzIY0Cdi9
MlMZ51bDuPbSjQ4TNjbFuKgwTjIwvrOp8vz3AdR9HnQxyOuCwHNV1lIeC7OP
xi3+pr/EGmEirItGwP63+QyLuR5MyuYtbQkdQHL73mzZf/NRNWnAWHeEwPHA
hHN99h+guOu9TcEC+f2huFJlyQb4qdwJeFDKwibvznRN6T4kpovs93LhgH9p
87+LQTQUx8srZSQQeG9ACX9Bvn8tQ2Vb2koWKhhBEiYxH3DoqnuEzXUCFtff
ekXOMnCCtXwpxpqJ3i9TS6u/xiI7dJDba0dAoDVAe29kHU7PHeP+IP+P55r/
ktNWE8RqbA89Rvb39ZK9jPf6rVhuU7w31MOBaeuzHXxiXYhgHoqhjrEwv8fd
+2pcE8rE1j5NsSZg1u0/9KHyA7p9fJ876xAo/C7ce1bhLVy/7bh95STJ57Oj
ObY21aCab7u50piFHM3smG+rhqC2ar3lU4IDybqz7q4CA8iVtrXanjOF4rHC
wdtKw2jIG7+bQh2AsI79D6rzEPLl3g+lyI6j/Vm5e2QwDf0h1/7cO8OC7Mhg
wM+sHhypkq3bzxrGzKWap/F+zeCcOLY0eJ2Fh43rnHP/7sYuO6Etl53J/tin
Y7v4IAX9hedrPRwJHLp+8HbUnQqE1w6IrdhOIDumVq1hqQP2b3a8Vf/KweGE
T9FOQ/2YYxl7EC1snPK0MD+7pQJPJupeSE6w8LtAw3yP00cEJA/PmvuQ8xjD
rbCya4KZm8bGsF0EFuxqrbM/VIHyPa91J1k/TkeJnVJ2L7ReKsv+IMZhn7Vh
zcddnVD9vvJLshATLzdSZtfSWhBXrOHuGT+Gx9LBfje/1WN3XtqpZZJ39lcy
Pos5tEOv9K/DV7aycORKsK/9Mpln4n9durp6DIeqhVT79tTAnRrFc0aRhSH9
Mu0ygY9wVj/6JWATmZ/9+WK24algjju63nIn8PL8zF2VB9UodPn8VEiF7Mdw
d7EjifXgr93gtmEjAWphjutJeQbkIkOc82JHcOgAt1ZVNA7Lk8sf7G3J/KOq
Kb71TcNmRf0SIZLPxmonk/gqunA7UiVhRQLJF62xRW+5ahx1zk+PBIG27MzL
umc78XD4tvPbEfK8TBOZGZ+p+JWprSdpTuCx1mHXcw4MqEp+/xVK8jtz6sKL
o2LxGH7ueDXShiDrtOag6rMepP30HwhvHEOd6MLMZsd2BEqu8SjIGYXqu1+P
HFrpKCy00XK4yUZyjehMWUw6fja+Gj5I8llZynNFit4gels7xa3+4mC9SIbh
Ta1etBkMD9iZs6D1G/89KeUOiIh+7/PJG4cEJ1w4VbAH2loRdyJI3tzht2/y
eJQHYvymdUQYuf6hdZO1Ce7I/1fw+iPSB+5Y8Rpax5Tgh7FpK48lAbr569ib
c3UwNNAX0LpD+o50VGJhWRWqbgp9HnBgofAwMynkQBPCN1smm10j8x0TQTaS
dFjZHI14ZUby/u6TE3OCjbjrTRHSIfvNS4V1p2q2Hf+0+tbKPyYw2Jy2VpNZ
gWe6SUW5QmwM/jPcHhHcB1OJEsqZ7RxYFydMuc7VY2NXgOODISa6jxyTmW1g
4AtH9mjDsyGEhnKLdh9uhPsvBIpPkPyVPMyiPSqGW4Q+9asgmX89c8w4hW50
tOV6mHwbQUW3pufN26EQMJ3RHCf3Wy4jtcZOrxkyvXPmjtJstFOcJNvzW6DI
67U0ZUvmhYbojGxfFeL+U0wJkSfnTU7m7uN7LgiJZD5nkr/nd3svvWJfPeor
35//0kmgy85Hh5fcv7jje22bbi60t9BoFh79+O+9hSmGBkHQr9hfUGiDjaT2
vDXpD+cd5Cs+ajdC+8OCME2cQMmBdkPe+DZQCngDxF5xEPhjZ13H94fYUK+i
fJw8T+sbLftE5YrgSa8t17hHoEUs/LtTbD0MpdJtqJIcSNlyg7ItE7Dua1j0
CJmv+svuHuvG26FJqXLZc5+Dab5VPkEzTyGjFH3sHbn+ladHqad/7wZ2Duef
LZ2Cv//jd/Zr6sjnav2mEwRGPaMM1WQrkHdWpfpeOwvWBx3z54WS4fv9nn8Q
yZ+KZPv+QwIMXCTyqGGdJI9DLPrkL7Xj/MfNjIMpBNorY2NkVg7jpNl/ifle
TFCY1/3aM4oh3JVbJUL6stQOCXFWOBVvIv7QFSDnR/y593i3bB6moqzenu4j
n6HtRCnrQ/b9eZ1qKheeYQ76ax5nk35VT9sRTq7fo3Re4EMPBqYMa5+PjYO4
cK3zr/RiSEe8lPTzJvlizTXTPUX62Jv2M7KjZH+/Zrz+9rgJ0/tcu99kjmGy
L6yz+9YALMuSzjmu40Ki3/V2qsYQ7m8LrYyMHodB51O3fsU+yLM0JxniHNgY
DJ25ItiN+WiBp8HkvLVP0UpWfUzHidO/rmuSeVLRE7i/bqU7quIMsleQz70S
En/eZb/GqEZ594ATeR7m+8cGn9BB66KHeQyzsD7WUubExvfo+PDw6sA1As25
BvcrhhmoEA5dX9nARHTbAfHDIrmgVB198tSBwC/hPb6CVf3YxGdTdqiPCVqw
8dTTXS9h/bArctVtsj/Wb8upiC9CAX1P70AGuR7jFJ1dZF6vL7Q8Z0T6r0g9
ZVaRUQo/wTSdBXL+xH9vssk48xGUoD/PTyVz8KV/srrEk/QHPscuLtnP7omX
/kwl/eBVv9d0FtkPZvNro9pOFiI3/otPUSQBvzi+0fzUFtj0fdKTnxjDn8rD
H5JF2sCg/6H8dguBJ976vKOuLZDo4i4XThEI/Nnb5EYtg5LCgLpJGbnfcMUM
Xko1KM0fzoTUs1CZxX3E1GNA/G5elnZQH34xq0XVOJVI83RZKbOTDXGWzPkb
Ms3Iyuta9JUmUPxHqLZfFB0dRvXcKj42fjRmBnZersS8sZKeIZdAA6+NHEeu
EruLQijd2SwkK3gWPhp7jWfbHmiYrCEgqLxp+pzpAIxTaYon8iYRLWHnGrDU
heP1WcKRO4YhEeTFy8yl43FPwIXzW1hYp/yCtd+yH133XY8PaE0ifd+t4k3h
HTigv20qXXAcnvwHZqwfdkPY28d1aoQNl9C2D7711Xjp0HDnZAWLrPsu+94L
HxHu7RPE8CdwdMnqshmlGbStqbuUL7EQqr6hPrqiBj18xzaN5pH1W7Vb0Fsj
CeVKP8dyDAmE5tivMzBvxkG32XdW/5H1lx7WkdBsh2iGmlN3KhsxGxmj128x
IOkr35dpP4KS496Fess07NQQjNxynDyPU2GClJxyRNQ4URtySN+vOulfOFaN
CvnJMFodgURzh92bC+go4tsslejEQeFD3yPXdZswPJF5yyKIgzQL9sVMxWpY
6xy6qOpBwHbJ2d/4chd2ftnXt/coEyIpdSEH7FqwOq1WbdyQCa4TdB+KvUXs
+07V3/8m8zshuU8koA0WUpnzA3s4UN8/ca5WKQtKRQUEnfQN/uyadxxxkvem
fySViZH8njvnM1NqC8LQM8mX9LvLV3gWEpqqQcugHtzxk5yf6+djB448h9Z9
zZhTpD/2r84bq+WpxsnJmuNCFixI7VJ2rw+IRrbS7RFVMu/V1N7r2nRlQZw3
Yus2E7L+Z4mC+4s9UE45Yv368yikRgZ8DFe9RePWVHvvQJKv2hEn3Wx78IzH
yOmr+zjcCwO/z5qXIbblwy1pGQIvZn7qH6vrh9yL+YnP90g+DTSUq1Aq8X0i
P0iM5NNyVsJPu7u9EPrjgsqM9CQOnZLsZor5oyEyd9SE5IOwgcH9enUGvpbX
fX8+xMZ68YUmh4oBiJfnBKi5jGNYl9CfJv2Pcsu8sPPZKOht8iMbojoh4DV1
9l7cBExFll/liLXgSJGxkegPFh47SuUEPSjAlE7E7KFkAvn6cnv327aglP7J
RSuGwJTNadUfOzvgTbO4kEryNOH9/Ztaqf24beL2Rf9zL2TC3v1UL+/A0CSt
/IgCE3GvGzXNf9KRW5B18MRt0j+P0S2/ljKwuC3rdP7+CaxfH+h672klMs8P
cstfsmCl53VLTW4Eqb+f/3l12ygSNOf2n97YhToT1iJVl4339tdpvexutHUs
8fgtsvAfj02YvU4LHGsKAk5v4yKllfX6r6la3CmkBzVIc1Auor6FM92GFZv7
/YP5yfuzWGKp7MpyZO9SO7d3jICnw0e5ebtq8DfnPMpTIlA27/523LAHhVbH
17l3E5DWn36x27cPaaG9fJWHWSgfveK73aEJEd9uWAv+IvD5iei3c650qCeu
Fdw9RPpbyKF90intIKjWHkW3J6A/elhfeZl8Xzpt203tKawXvZp/WroDgdJH
3faQ9TN1lNuw2bwebXSZFldXJlpUFT6Pk7xoN1kypEiykHbBP/TN/W7SC5tT
64q60c5Lm660f4FuA6Un9WQepHi1KttNtEP7RfHygWw2+OdETPaJdiNy6zaF
o/WjEDf5+GeJRAcMyxb1OF+GYTxo+XNUiAEXrzCH7FIuPtv0OT+lDELYPGSh
+MEnjOp4GRYuxoKS62doSebrtaonhIF0D6QqZqrWk/eT+TSt2ucTDETNHxMR
v0WAuybfKv5pC65q5s9ClQNpIxPO76vouEVdZ7SbzDuefcsUm/2ukLjl5C9C
zl+V+oNNlWu7sPt1n9Jvh9kwHCk476VeBnF9t5EOBTZ4lkx8ruumoPSMMeu8
M5lHvf++MQh5Dm2rwTp18rySLw0FH9PrgnG/82Uf4SG4O6gI3nfogYyY8Jqu
nnFYU4scFwKSsPWRVuRa0ncn/lXLtY37iDjKC3oClYnQ8D+Nxi9VQUSmZUUE
H3nfrXkjS7hXIeIdV6hAgIVo6bc7wzbR0HsvknOGzKfR0ydj/vmaCt2TFf8o
k/x5k/3QROBqMfIvDnrlkbxZdU3WqK5kEKsCD4hQ1pJ+Zzf1ZJVHFk7M3Heb
9yPnsyhITOILA6JxLW7Z1mN4cPMEXZbeDJ+i2YeWfSRf1DoSfio1wixd4caF
fSwkPZfY/mihHv+eO0u7NMzE+vPqP0RXJSMp5sCpyavkfarIZDA+pQfmq7fe
0igg93PC+8DEkRKEr1n8NvqLhT+03vGXn+tHFdvRSK6ZCeuwigPLUfEo8Hk7
NXyZ5CeRwb3KQ4f/BO+2s7ZMSNguDKxOeYnDfJYj/KQ/xX1ruhwb1w3xN8d6
tpI+OyrPWm1UXgpT5p34NE8WamS29I3V0xElF223d5mJz4JBYc4eNfjm/qMw
xYj0u8996aeZWZBWjMolTAkwJ/0mXkl3w3auq+7yAzasDkp5NSvmomo8/YbG
VxZUOGOXaONNyHWTM9K5z8JB6azYrQ8rkW/X3ateSvrdm3VWc5eD0RXXrBFP
+qZp0sswT+Vy6B55u637AYFpo0hjzax3yFCK8FPgYaNCmhosremN4OjOi2vJ
fqPlJ1a1JtSgUTUtu3iBBX2FF10Zxj3QNf+RVdDKQpz7uzSvfDos/DLzTnK5
+B9hGBx4
        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk4lekbx0+ylExIEVH2yDJmMgmZL6UiynJJ9i1Lq6TQHpKfkJEwZUsr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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lekbxiUjWhBqikyobCNjylYmV0iWEuVnp8XYSqFIi5ThGCN7stRB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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8ldkfx5EiJYpiqKjkZ0SSaMF8ME2ENPWTJS2ye5WyTyW5ZMmdpMWY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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VH8bxiVKCllKIclS0iZKpNy0SErJTkiSlEIl/OwtZGmVhCiVkCRJ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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlWk81dkfx5mrspRU4lqzTZaZlglpmfFRCdlFi8LIUqKGRBhCKWTKXmmS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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk41GsbljpSls5JiE7FyZJsHcmZfOkmEUeRwsxniY5ikkpKFFFxbG2c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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8ldkfx40Kc2vIMq2yJRlNlpnmosWnUJpKUUIoWyRTWULqhyRRSZHl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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8lO0fxS0lSlKWx06WkkqSUg+PIykpW6KU7CJKVEJIkkRUUkRRUiQt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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41dkfxxEGZUkLkcqEkkZIakTvOzSlyT5JJFui7NRFRclWhChZxlJD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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41dsax3FEiWxDiiupUCdjhRtX5ytRtA/tUqZkCnWUaDAcKcJRna5T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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk81dkbliVKZUmoEBU1GNHiU0lPM6MyRGjoZmkiIXsIRf0kiRaj7UYp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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c81f8fxY2KVEIqlayQvskuIzotDZRNQ2kgpEIKEUq2okikomRkZGaF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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41NkfxydKsyXXLnRBl3VrJdYt4q3JKl1QIUIoxMaSVSjVUHaZdeun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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk41Vkft0RlD1ekGTK2hFGTmjeTD9IMgxI1tmRfswztElLJUpkiIUWW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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lukXVvb0E5UUWcakEppRQpbuSiJJJBIipFSoRBlkjGypaSQk+QpZ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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8Vf8fx6WQEYpoyExGS2VF9TIjqZSGlRDRklSkkBFSKqFQomElX2Wk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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk4lekbPiPFmMZSklBZkgtpGBSKO0uhjbFXKjSVaZo0dXQo2UaLyth+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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk4lekbVmkSUUlhCElUo4YQUm6lhJFQWQYl2TJ2KjFlDYW4yERaUGSX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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk41VkfFylCjJCQIhVKRTKi5lNSKTdSKUljNyhLWpQKxdiuJZFsGYxo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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Vd37xr2hJFPSS5KUJFKJMlTcSiMiDTIlNOhLyJBUyhCS6BUNEiHK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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81dkbtkUKRagxuCo7idAYGY8RUUkmla4xqCw1kSWMyo0wTcUYITLJ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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns0lVkflksq5ZbSmvoUoxJGZuKQYR7XaKgOmRTjEsrli0RqkppTisNc
UoxL8uU2Sg0Tya1w3I47x+1w0HG876tQInEYSd87f+y1117rt9b+7ef5Pc+z
1b3POp2SlJCQSKLXv7vIbEZWk5uN1QlLSqGHKCTeKyxQiOajirc8pXZjFMkT
wTXVxY1QXP7OtkCGwu9iW+esk53g6rb6l9+kcD4k8JTM+zrMtFxOC2GRSBHz
1bSNW2HedDK00IiC6GpAKvFrKyqO/ZDCaSFhKmthWP2JD46/5dqi46O4WN8W
dn3gMbaWl7Xuc6dAWSm1BSsKYH1r+bNxwyjsUmt3HLzeCJ6T/oHIGBJle+WO
f5DohzXX95jp0gjsTvC3D24pQW7NKEfDjoJ+0Hys9KNGqLCCB9nyJOQUtA03
WA3iZpaf7nO6P52AaX0DrgAplhaDr81FqPc551TK52DBb2p+5y4KDr7Fi9tS
2tGaamxeKEFCP2XaZexCDTZvDqDW7aPQpD2x7w6nFKlakvHkNgqcqNwVI4ka
6EYnrG2VpGA3bG6m87YCzvNnIhRfk1h/fJfj9NggJLQYyX2JIviofQpJkBJg
4Ysg94a3BDhshSYjfiHmoiNyYxgUWDoXM3V3NsI671aw5m0SxdErlbIEH+EP
5EoTJUYR0jU9Hj71BDGVdZ9sDtN8WU5mhSY3Qr7jzjfivSSUV0n9yTZux+gh
5zMnokjMXM+Pe1/agrzHNer9gRQyst5Ut5xl4XzA3bkpGu+MLqkmneUkNM2V
c8XHKJRJ8Z6qiltg85I896MfzZe7wpRyMw9+ytMJK+UERLdLTZzlHkDextDT
3pMC73n4ofzMKuTayTuoelDw/6Jz+O8MHnixF07zuQT2xt2z1fo0BK6Jhyi9
UgiefNlFq1+eoHe9af8DZwor1ue8FNIaoSajXLiOnpeANR9VVQIF2Hx/msF7
JoLodJLHkLIA5/ZzQv9Ln615A7Z+uf1gTBT+oWRFgvnEha1j34E0bs/fMksE
eKtyQof1m2G9IWptpxKJLQ/D54xDHkNa9Yj4Z1A4fNtBczG9FWbGdxv8fqf7
/yGJ5enOQeRPzx1d35EIiXfqcbqSj95/gsySYijsGOl8+A0zD4fdpm8k0+9b
v6znvb2oGYwn6bpM+n6737JU8/O6MJl4rOCmB4F94s9RrCQBqtoYCWJShOVX
4+4KhmXg8/o2N9L4Lq6kNW5/2A2vneqmbuMEmkyfDjIyhvBRqTeWK0fAZMzC
pSOLgzg5c85P31OQmBPHNT8+DV+zeJ8SGu9C02+UuywHYPhU/KL0WyHkJ3hT
m8a4OBN07SCTns+MPVvZX/7UibL6X3S6H5DwqZD80YLGyyM5bmvIPIkrqX8Z
NGzpQfT+iP/53CFxTL/vK9fCIRg19O5qsxGi49Ymh/o6PjJU/+wK6CPg9Xfe
ZKV6Ns6G2c1r2FAo9i2S5oY2woQpd1DQTuLhGepdV2oPruxfOKlLkRg3clTr
DxpGqPMX0wfPitCmmnBg5HkndpxXVK3pJeCfLbjGVqkEI/eig8klet7VPtto
Tt6DZUUvw9qfgkE+N0NTnQPugeZzFxdJOBto6N2/0AcNqxYmW0sEr+b4L7X8
Obglv87Al+ZPuu/wV0l69bB21e/0KSPRtMpCVcVjBKqj0n+xXIagobe11jty
AFsNBye/NiXhvYrjv7tYAJPspedlxiOIaLI92jNYgd983gy/sqf5YSGzfmMB
tJmzW5MtKKjt7gx8U9KMw2cedOYkkVi0zhXeq+6DwY955dcbR+Hmw1SSz6/D
NfVNK2OSYxhP7T99gqyFfXF7TMFLEn9F7O8Op+rRolXeMClN4W0yZ+mIbAF8
k3y8XrMpvMsx3uuh041elxDTnH9ofC5vcHR37cLpnKpGP28CG7evb3C++wRu
mpHxonAKa08p9jzkDiCCSejl0v0pVioJZmi/nTtirtCaReHYsLXim4YB7DaM
UveIIlDEiL2i0CpAj6lVuNnjUYiPr5sblh6A+bMghT0po2iidqSz4p4gQjVl
TMmUQm2kn0pPcAuy/7jETlKi/UDmbUKiUIi1Ti4H3ZWGINv6KHuzTz80Ts4+
C7cnwRozval8n4dPUZZrHDIJxHcPV/etFOCq+g3L0AAKF9js10cGeaiJeZGc
NEJAVb2/mBHXB0m719+uVqb1VO92dPxGB5gnHS8lELQeh19lZ4Rm4F64lKQ9
zUfHd9fi36bz8dn1P3tmZkXYpsJxUflQg4/fT0eEdNL6j/Cf4zt3YfVq9oGK
YBJrzgsDgvZVYa9xIGFE+/NABR5W0XnmmTWzUW1hFBZ7TkUaRXaByXPu5h6h
sHx3z4S2Uwu8Wl5cmZ2icLDX6Wsts35wdB2qM68SYAY9lViQvonWlnLSzotC
+EzD7do3vcgb08vcpULB4/DdpyXy9QjuCW6/0UPibbvw47PpboxPp42n7aAQ
6PQy8nfvPvR+jE1H2CjGWZKs0zuGwZSdPC98J4TUJd99pWH9KOp7P//gCJ03
jeYyyTUcOOofNwnOIuG0x9XWoIWPnqXSPO0NBHImOuZ0w2sAc2FAhzyFlDfr
DN2s2rGhPP3Uh88EtgTGz+uwShDdxjeboPPsfHVt/KrmGvjVXd45IUFB1+R+
arlsLxZc6pwYHQRCvK5lV2gKEWGTPBt3QgSOZ22ApNJ9xGVtTxC6UmgbGVK4
Kj8AQXiy451oAsbuxn5F8gIoFzm/FvCEYJJrrta8rcWw67tKOTGd/5zpYnPP
Epz9x2IyrJV+T6FAlpdVg5w/vOU3HaD9zC2//sXZWtxeyZby7iDBKFh8Icnt
xcCG4stbCLp+TUHfuUf5WP3zz2L1r+n667sPPXsVB+WnVw4t0PgrTuq/erZ4
FxvTVXW0vCkQv6Z1aEt1gxXz2w+29wgoy9ix84IqkBjmyfAp+jefL78ynI2F
T6ZGbBWdd00ZxnpKRqW4GXY0MJf+L/hXS+XWRXDxSFyi/rKKhC856pRQ2IJN
fEXtO4sUGHvtr3+1iY/jqWkTiWwSE7MOzTkuPcjnLOSKPtD63nZ06Vt2D34x
Utr22I6ARlCmzaDlMAqqck+8bxXh/zacwh0=
        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4Vekfv9ZpQfRDN0ypaChNk8xE6KMitJFf9USSPUuJmwxZkmIUZV/S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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8Ve8fRwjJqjTtUsmIFCFve5ZERlrSEpJKiEIhI5lZfSWjhZJQKiqZ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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkfxi9Jpl9NY8sSpWWMLRUKgx4Ze8o6oVIIk5ItDCMlo1IJSfZu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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41Wkfxr0lSxSyNSoppZORpUSDupUlRBkMpUiSDCnDkIoWZKxFDaEZ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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lmkfNbaJmS9DhrfeFsZWk1IjheJIqEwjpY9UsiSyhJCMsi+TJVnK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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3cg1P8fx40GITSkQTISKYqQ1FNDNEgIiVJRMiJURkMiMiIqI4Qoq7I3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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41Gsbx2UrJLJFRCRLEUVScb6E0OJ07OVQIfVOcii0cLLklQoRCceW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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs4lOkbJjppKyJLbUW21ta20VjNErecy6E29CPKYRGRrJC1irJF1FqH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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lukXtqRVUYR+SYhISExEmVujRQ1qNEWDkEQixVRMhEkYxJcM2RqV
KFrsCWP3Wcb2WT6y9Y2e164YkWXi98wf7/Ve73Xe6zz3ue9z7vPInXMzcxDg
4+OLps9/7yY1peQFYy4+2MlPim5ikBxjPeri0YjWPvNY42yCK3wZKSX5XJwY
9t952IRBpG7B0qW0UhSd/FHX6wpBf0qZfKxcL4Ykc8sVoxnUTLCWh8y9QfQf
K35Ye4lgb4DCxsv/dkP47sNL5rcZ3BX3dm7v60PswLkC00EG5VlqjULveqH3
m/7V0HUDEDb9eubSCBdnrJtvvtZjEPFiWyECOZhNt/qcRfEEf7rgJvuJi1Hb
7L13x2l+rWeV0wnZWNE3YX7fgYAddOxXXm4zNomdWRNcTOC+K+tm4jdtkHTM
MBDmELgIlxd9iGzAgcTWBcsnBPWqmVaWNR3o5/wdV36cQWCTm8zjjR1gO1+1
tab1dg4em/wan4/0ue7YXbSeqI2BtQtT5Vjm5cjv40MQKSy2k1+yHN8piRWx
3Qg+TkYLLXpyMbvOdtdKQQbPajYo5TpmoygsryKX4uO7LT0+mfEUBZJ33/Js
6fflgtDP8r8gMJFR3mdDkHXSt/kGrx1EcbdP2yiNz8aODVgfwPXN8f4aNH7v
hq+PrQQH9TN5qWW0PuUYqcbvfboxpRdblpbPQNRBP9Tzey7Yh0NO+pxloPVp
0Itd2wYXCaMjrhsZ9Cemcp0NW3BV6JbHYgZBxnFR+Z+WGiExuC7p3kuClhUK
q4wUOej68LxCrongghG/v9jrZmxpnNBv/pNghuX6uSmmFpFTrAfsaILklxah
Hrc5SMxcpTVF8ZD82G6fz90YreJ/PHOSQcaen7UEfihHxfi3xrl+BFJPuN7b
jYvwuuhMZK0rQad5q1B8aDfG/3Sfs6F6G4g4+vz6/D6OLu3bmUbrrXUVX36z
g4Pw2JRXv1cQ+HkbfhzxfIvDbTtOPHGh+vOaZtzXcvH7pvywEGUGxk5s3bJV
dUhzP+RHoggCD7rWs33bYCkYsVZ5NYMb0t521wtb0RbR+k2FEAPZNeeLi2pK
wPJTeddB8RhZX4j7sbESjc9zFXQ8CbT/WLXH7CwbgY4517qDCPZr3VJjtdbB
Qttu/ksEgQ9v+qCHTT2iWiMkkx8SGAi7FlTNBGG109wLC4q/JzGo7BuDVvRG
1TwrYwgUCnle7ll12Joe6NVwn+Bc0OKBTpU3OJdQZ8F1JKib3Z85+7QHIj2c
fUE2DHiWDm8mthaiciEh6gjFV9ruJscXGYHEm3IVHjR/cnb/n47bmhGhK3mo
t5LAM0CvdJNoO6I6pmXGab2lr3WTwuJrEPFAhveARWAqme6rXMfBC10B2RHK
p0agpl5mbw0ezVawLH4jyIeeSCqnGPvDY5WuORMMrBCZ2qLei1vr/3bvcGNQ
WW9RZjvXgCGzki9hj+n58kfnYyzbwXuZfPJENcGhIEWPS+o9MF6wrw6YYZDk
ZjcVdz4YU8FaY5YUb012p7fm7h4EDN8pWW/AQJhvTmt0WSVOBWaYZ9yk/Z49
qKCakwNBE7ZX2HmCsLjKPJuQciyvTPr+1A2qz/HF9Qr7C9DOb2xoT/UfsvrL
UXy8C+v6p4daqf8on72WO7Q2E7K2X7hWdN6cnHw8t1vVI+GIlvA6irdI+pa8
OH8tpodeioU/IJC2rf7jlGoTXPtZ3fy/E0yoO2TkrE+BqGSvk68dwdigv3/X
ZDWunHr7w1wYgaaSB0kPKIO60iad4esEwlLHR/XHa6G+JeyzF+23/jUyUsse
dqK68/T4ETsGfH6y4wFd9WhuOBoumEkgezSiX7ynGBrRp2c//Uz5cLGv9UUD
Kn4JNV35X/+wF0htZSxe1UtbdlO+hNvGrMKTyiD/92kJM/p/WEcM30lOLWSX
+5iZPCK4PjTgJf2sBxKRkvstHjFINYw/cNG+E0H91Zd5pxkU53mlpS60Yiyi
fMfptQyGtF/ISk20IOlObMT6bgKWUtkt1eFUzCSdPWhI603geQenR1O/9P7i
tEyM8tkvRrjqjRDQGH+SS/vHYHr7tNivPZDV1I+6XMhgj/q9EMM3naiwfpPV
tpfqXSnAL1tXB7NdvENNqQSiV4x3TLxvg6zgkvo89bOPKq/493o0YLW688ud
dH6OvX/27lERB9pJ4toNdD4C+E9cO/C+HhP/dH2xoXyWzvnnB+uwMBYS8vgX
yod26MMPnr4cjCiS1SUfCFYqxJmG/K8ZH4vDXw0WEtg95Us6s7sdkQMXx7tF
GCQwustupP0Fue7ByEiqL2v/VnM27mOg871+DM0Xldh8ZFIiA0p7Uop87AnE
9277WUCxBqLI8a+k5+dHL455bH0Kha+DmiaUH6P8UrGSlkrwhhR2/+RNkLT5
n7ZxgWTkDcs4l1I/72Jvqxp0bEa8Tn6bZhVBRMz4dZ3UNtjUzovaTxIU+N1b
+SqzGayRgyfkc6mf9ZvktF+4Bpl9pz7qUDwPhkRLzHRyMV91Vj70It2/Giuk
j6tlY1HT+5HG+f/8nt2QV82FSclVtQ/iDMQllqrHLbkojtEqT9JkYLFkLXMp
rAptIc8Os+g8KX/n6mOk9BYaAtu/BtD95T08y2+7oRHCkhyN4/EEhub2y+8c
5SBQVYYXwyY4mJgrbjTNgWCpal94OvXXdF2x7T+1407ejbKLcgxMV2RU6u/m
oFEtpdC3lsZdLsd4B/fB+atly2GDAegIu4Z/+2Mz1KVVBLzfUr98pbMw6lqM
8jDRGGEPypfEhQfrVTqhlyJ6wYHux4PPZZWzljpxOXWhzIT6sbN1X/hGdGFa
yE8qwZLBbNzktlSrMhxzNIiQo37M2mx6hRFLwzz3oovDOYI2ke+G97S2wm+j
ULFuP0HfP2aKImLtyLm3tl1amoHGt5yWDS7JIAFBn6epPqzfqjskq9yxxaBH
QpvyLTDy7m2mFBsacf8Wz9+m9wOVHdaRG1pw5XSFVVo7gSqKR8TfV6BBPl0n
kupdFbpabbG1HWs2Z+yJpvOkUTesySM5+Ci4mT/Gifq96fZ1SYI9iOmsUokK
ZfB/aijEXA==
        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lG0bxlFIRZIS8UZZImtUWjjppaSyV1QKISRkJ0SkTb1EiiTJVkqy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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs4lGkYxlFOm1QmsshqUiHEppPTrYNDJUoqixSbUzYRqSbEtiapLHIo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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk4lekbtlQTg7KksnWoZEZTIpX1zpKlbBllN8jSkGXISNkKoykaIYmS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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4lFkcHqG0q0hbqWWjR6U2l1AtqlcSttQqG1qbkVtEFLKJkWtJRNHF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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VH0bpohkq1CWkBR5ZWmx9KrblmhBVCqKJKGUiqJXRdIiopIsZc/S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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs4lOkfxp1S5DCzOWxSkegk1BJbdLdFhOTUOkSRhFqxQuzYqFTbSiSh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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4ldkDx2UpGYQW2oT6FZEKSQ2+lihKg7LdoUVZJtQgZNqEpCiyRI1B
ualkubZiiixX3Kxd1+Xa7/u+lK2MMJSZ5v39cZ7znOecP87zOZ/v96i6n7P3
EBUREblHj//P69oSZ/cb9WBa75t5mtQAyjPWsyX5vXB1WPvLrY1DiPRMFJgx
BSh65xMq70RgU0bA5WfzPHCZvG4Ts0G09KVqWshzETlkdWRqgsAFcwUL+aUl
SOS6JKscoSB5OvbCRp2HuCThdjibQcG55gFZfv4lkow+pmdFUAizyusOBgea
vl2bb+hTqJJZ6PkUEoe4a7yS8uMU5hJ+7F8nywNTN+pwogEJhTNjGWUXuzEl
7iUy9HoQOvNJd0abuCBSdnUoPSLATFQmK/a3QnJTTHWNBInpkEWaw9vZIHo0
SpXGSUzNi0vFm3bh8sJnu8AeIbzzK4Vd3PfYZSP1TWBJQLqXqX2n6T00n2as
GjlDwrQnvCwpqw1zqcw493YCZbfzvYNruHDMr6U4fwuxkX/pi4IrB4wX7eMR
dRRY6gbfMlK5GNN/tHsdj4BIbIDs0LgvygoG6zuOUfjwbNzVrr0UeaXZCUvo
tbHUE13nPY3gDXlOpJqSODqDC8e+cnGL/MPxch4JiWopd1NXLsI1HHq7Ziks
l4W0+XgHiG0/sdumKNgXUAyHQAFidXEsbYjAi8Css6SgBs0fCmZEH1BQjzMI
GyhrxkCDdJ5sJ4mKnrOdtek8HLbacdSphMCo/8/iPowOaG73C31SRCCyVmk4
s7EKa74UtPqWkhApc+JxFi5ijfIJhiX9HvtuOQRb3mjAWHqAao4bicUHJiUz
DvZh8H19koTEIFhp5g3GfU04e+Vvl0ctBBY/Mf9teRwfb0uPfBXG0TyuHNoZ
nP0Gbbwj2/kiFA4IsjyMi3PhOs2MSNagINFm0uq9rQ6WnYsGW89SmBhWZmq8
6sbY3eZiG2chVH6fsHy2tgWSrKL5qWgKl3Q5lrPTnfBdu63Z7a8BxIt6/llm
V4K5r+V3JGmfDFUOr9s63wP9N07MlV39iP5Ll9hVxMKGqPG8lZYUNGpD7fPO
cGm/3B9eaKHAv6+fslJPAF+btGnpLwMQ3Xfai3+U9n+mcsD1/gAy7bg5eTlv
kSE6zMunSLCbFHr85jh4GtWcl7ybRK9+52aeZCc07QSEPElAa5FJ7tfnbNQw
Fv4pW0VhUE5EdfFOPjr0Ds1O7ad9j4xMy9CsgpYmr99sKQXvpBHLgL2vcHqf
6fCNDRRyR1hTC4rvkC9n1JLjQ+LX3nvbo190wrAvPcWqVIjYewHS/kEt0Dkh
uOfrTuLyFcbs3RtsaHl5+2/JoTA9bO3OMu1Fqe/rYNklQkz+vKP0Wn01Zs78
0XOXQaJbfeFX6cYaGJiHHFOuIqEXHPAvuboYJ2+KtlmZUTi/c3g+63/vcMCa
/dPJayRYsml+KHuGNhOzClHa34WXjMIn5iw4rY45s8yFguPH7aZjhXzkxjhn
6ND+p+U9rikMbIdqmOKJXoLAKl1huV1xK2ZY2bYOdB+0+d966vUxGVFXzzoZ
OlCQY1n0RyW8Q2ShzDZXOxInnhf2GTZXo7z7wP0Rf5qXQ1TZXjTCoDdl2awi
icjxvx63M3m4b6RTKVkshG1m4mfFRZUIr6LmiRESTa+jPJyi+3Hlk8bqH9yH
IBr3qqwltg2hL+qbT9H7hpu3HZIqfotHMQRj10cC66ig0KGwWtyUXW8psYNE
lYFsk6fUK3wqfSm6rIbEwloLiS7Relgs/P7MZoRA2OmT36/VshE31B00RdLn
01uTnbzK8eHXX8KHDtH9pc/LSogsxvdKBz0Xmpf3nHyl64M3eGsTllvtReeX
Zx8REVME8ZnBEFV3CmVTn9nihR2QhML1GG0hovg/WreqdeFP3zU+jqZCPPg3
oGj8j3ZY7p9r/x5B4JhYQI9faR2I6M7BEwsk6lJWpGSEvoegS8P5C5uEieJw
ctJAPdycPPxX3iERvyA6ebsiH1sDg46P0vnS066Om9pdi8ebC47Ii9L55jCj
R9y60cYyUiLW94Pl8v1Z0A8tKPuWr+YnIHBPuPn45+kWsA20yQfhJNKhZbzb
tAPlt1m2j04RGOQZl675kgpryd65VfT7TsusYMos5eEaY7lSvjoB9qfNS5r9
2lGVukbyCM37dFD4nwWjObgz6fjKERRCyva39fB6wXJiF1SokvhcqdzPqmtG
GHuIo2VB5ydaXFlQ6Y9TgonfWHQfRSpabtnp0guTbW1211bT88X7zboHiqDV
lvnP4vMUuFLmo0URDWhOrM8N06FAmXE5M+eawF9ItNhE96G+qqr+pGInanc2
L9HYMgC596mZEMvDo5MbLllaUdg73T8xmsmHY/bWsGyFAVjbWhc3BHFB/azp
nTQmxAv/6oOR2h24uHdDo5sMgZvC1eo/eQnQRrV4Zg4SYHFWTPaHFCKStFTR
8aTwZf269EAJOh+chG4xFQIl4Rl6AePVqNgTqqxWRCLi79IIvo0ASjabDmpO
kLiuZDTlq9IH0XGPrFqPAXTP7fe8uZqH073RcsvXEjBUq0j5msyB1qV/D5Re
JRFtyFlM/FADbZNO+6p0EouOFnxyKGwCUbXd0UeOgphYKSOwuwNmWsZZk/EE
5PaE2aqnJUB9iL9760n6P7ZUTlTqbMQ5w6iwD8E033o9sZnkJiRdvWzq/JX2
fTBBTi01G9kX3c4X0nwlt4j53M1jY621RkxsHIkw+ZtLd2k9hFz87Z7WUxQu
LOxL1O+qxgqZZSufq1HYsVBfd53xEPMn7L8RNhR4I5oVjsY8uDNSWg6/ISB+
y9BYMrIR/cca/P3GCDhzHeXEvtVjx+PRuOxIup8cuHr8+GZo99seH2XR9xnp
i99tWA3HO3Qj8EkMflrlffDlE8yeq2RWmlP4+Ph7v30lBzk8o11R3SQqO8+5
bazmIL3JsK6kmOYdVrInpIsHXauzPK/nQkhv8mUyrtZDz9Fj5ZQCBVs1F1FX
rzr8JuayzMiXxGilikxJBR8qa2LrNI2EyDwp4jKX14B9JQ1Pl14nkR9stUV3
tB2eub4+r/UJ/AcQBtIT
        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk0ldsbx2UqbotK1FWhTKWy3EJSfCUlSkoq6ReuOYQuMjS4oSKlrjIU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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8lI8fl5YyW5IolVRGqEiUN0JLMkpGVKQkRVIaRKSUkb1bSIhCssle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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81dkb1nSVNVxGY8IkS5KSRjNDy0NRpGJkadMgNUS6vzINuoWytEcq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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk01ekfx3WT/GL8LA2FUanIWBKSpfHWOonKpG4RkWyDKUILksiSVGNI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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lukb1SQRM7+sbWRJpckgkRKOESkjfWMZS3YKY8lSilGJsu8VokQu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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHk0VWsfJpG6mZoomUKmDKGS4kFClKSSREkoEpJLyZSSoW6p0CAliRQy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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81dkbpgxS2TKI6lKSUF0xMZYekyYlGYT0oRHRMIkWsjdGlmqQnyZX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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVWk8lVkYV8RkyT6DmEGSQsOQpMb/KrKWQlkqI26hmpqGlJmWq4RJUkOU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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4lOkbZqUkHWxbjbJlKanthy05bLhDBzmnVjlLDpHwS8raREXZnHNI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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k8VG0flkpCJUWSkFRUnhKVtUt2pSxRyiQhqSQVpZ6IQraQpagsCcm+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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs41NkfliS7i1CIIqlVSULRUvt7ZSNFcquI7eK27v3I5lKSSi6/3GKj
zO7atImUkYrcb2PcGoMZlwZl5sxEW0whcqnfd/84z3nOc57n83nPed/38673
OOPoLSkhIXGTWv/usxfOaZ6xKcMz+zX+2ocIopzk/cVPuHDM6jEr3CWEkPfm
SnoeDxwLdz32+GtINLkUxLOskRir+srwJIGf6zJ68T8VOGXzae/lSQFe616f
vzl0B/4sN93BUwQGJp410uI6NNdbD643JSi8a3/XhD+Ab0wGV2bpU/dLq6be
2jOhlJi86n6aABH7/G9/Mq1GTouOTlMRwYWoXF+xqB2Hsyev5O0g2F940ejI
Lh40RX9Jfwrjo/zphlKaKwvs6OrOZ/kEEsfV4+yPXkMGzWJm+2mCdzs+tP1B
50KmrHihr0cIemWnedn/KmC+2yEmsZjgjkbRxcjPRejtdWYG7CawnqDT5c+x
Yf/ZQtP0FoVHHDX2Nm0AxrEt0x4/ELRZn8z+vmMAlhWzdgxVggmdE5kh8Wwo
/5IbGx4kQFz5HmulHDYahg6oJ7YLkKK1Tm1ONIhd820Bx2cJVEK31Rbu7sU+
r4kyLSmC42MOIZvpQ9hsmlXoWyOA3lxLWGdPATrGeQ3OJwh0m3e3TlkxwG7g
mR10IpgtuJ78X+UmpFqW50rZEsg8uGAoGT2MNkvGp3VTIzD0S9JQbOBgecN0
+Z4mAa5HvG8br62DSkbxtxcZAsxeuq2g0J6H1W5t2nf3EWh1v5GmnU6DuqDq
7brjBK93jiqax3cj3zJgx/RVPhreXHtmPf8MZQNcuQgXqn+kGy3DrxHaXjbV
+tJCuBxPqxB5c2Bc3u9b9AuBr+3Em1f0RmRreK2LLSXoV8roO1BLh2T+F566
JcGMUfDmjc0t8JKjt81mC0AP1onKohVD//aN6ZQggiemUmOxz7lYPKyv2Dsi
hJpQcWregAHnSI05m48CPDCVr3ha1YvqsA/MTX+P4GPf2g8+xlzEx9t2QZYg
5HRLiUtFL6Jmfvp2MoEP65vtXkNNJfC4WKib+9O/eoi77X6GgdsFC8p5Rwlc
NmazosJbsbRqJMssTgDbuen3fiu6Eb640Bki4OOSWoT+ggQNEUFxPH1K78E5
SeRX5yE0PTAZJ4bDUDD7M1GZ1gAlJ37CMJegTsBy/Wnb33BWM324n+JLb3mb
xZcb7TC+f3p0jwHBJsbtiNqdXIxvkqnMI9T/mBE1Es6G1Dvl1ymUvnyC6uzf
JrNx6pOP35FjAoi/TOgs5dLh8Z05k/MrgWMFWRu5uR152+R9k44QFKVYZjMT
u2HlLCp85kpgtdVU2mLhPuqcKmu5lJ87fR2y5sf7sbo+0j3mO4I133cdKR7t
hO29w4dUc/jIjC/68feyFvxcoek06CTE6PjRx4GvGmGkkz4fsZ/A5GDOPwOJ
XFyasMw3eUzxb1bS3UzVS1b7eVG8XAC2qmzURzYbnzXPWSpN8/Fflqt2q3oN
6Fkhro8o/2/N1Pbs3dyPl9J1SeGPR3BThnE6wK8Emjr2UiwK76nFr+lTuZ2Q
P6jzSky9x95uMt6Q0wlR/dBSuxKCo+emrrp38vAo1jayeZHyk1V7zaQCF/9J
Lo6o0RNgsmouvzmwG4EKdhEKzpTeve3ds3tawGLq3317T4Am6wHvM569iLjg
833zDB/38vtL1hr0YmpSqjSmUgiZh1HFuUGZaDJjynpS/LKlGFlr5J7DtKM9
1JaaHymta700VF5i4VYsr3GPCL2DP26/rsuB/BIr/cs0ARIKVRQv//EUJgEP
ixfdCMoNJxrFj+nICRoTn7QhCH3u0Zba2oNu3e7oFkcCelhQSr5XHqJSb2Tf
8SL4GjTlreXXA/O30fJMNz70aEuKcgQ9qKRdOLTimBAa4jOtgQoD6H7T/mKV
FR8tqjGMyBMMyK30aNeoJpDbn9v/wZ+FPx8ZNdUfFaC/poVroF+Bjmtlkg5a
BAnpC1Yu9HpcOTm/OmSB0m/3y1TdQKreQb/S9L1CqAt9UutWDKJ75uNf542H
YdB4Nk/+NQeFqQtZCkpCbKyhb/Q17MQJtXNykxTempyjG6TLSiEzouAtiiPI
NQuX1jHqxybO2lCrDgJFJQdFzfschJVV2kdZC3DVzX/XLYqfzG/PZ3jG8vH4
G+/ok5/7YdXACn6xgeBp9m8Jks1sFKgFGe28LkSYVKzssrkSBKWfXzAJI5A9
bGikfrYLtJnPacEpFL+/WVYGpvTB7UTjA9VfBFC/ZmiqvqUPCsXjc+duEWQq
z+idiewBf9/rltxZITqq84+9sO3B+xcbbFfJEFwUu2oXMOrR8HGwwdiKwA6/
Rn+160OQU5mlfQ0f3dVqtee/NEOr6Am72UwAF53UAKu9bEj3rpZvsiO4Wt5n
wQ/ox+7C7UfmDo3g3oEEn4IiNmj5yzoklwrwvO5iSrL6M4gUNIfMt1F5lMVz
YL/kgJt0wOvFMB9i67JilR3VeHh3sorXSpC2SqnFTqYUJw/s3ZJ6luCyrFaB
EYMHUUDwWdaxYeyrGVYV/DAA7xUtPzrn8+HilXm5q7sCBzj6atmSBIFihlbv
kmZcVb06HVpD8S1a3W4SxETbgP57cyUCSeEWuiKFf3raPmMFNY+rFrU0o20G
8MMr/xt2riLUfafcN+jIRZj2+oRQphBaNLshzmQJ7q9cPpaYRPk3ztKMNtEF
0dwhW1nK3wYjGX4717HxSe2fLYpbqPlVkZGkqMmk8s6tM8KXwuOg/urJ32zE
xS/odlH50n9v+9ekd3SYxVbf3UCdaWncQeOnfdBfLLR4x+Kj6TJTO/RlLTRL
rFevoeqZ90mzPD2u4L39knkOlX/sz8wXjolszNw33+8qQeWVNqtguKsPMZEd
Z0eXiXDt+dCNdfyXsNk5Nu13jPJfsMriaH075GlbI9PdBbhROK6y15ULYY14
ldUjPm5u9armzfSAnvx1gGkkAu3UeseYax04fUE+8Hd3qt/Y0uQ5m060RoYc
iqPw1N0pDlmp2AyHrN3P5ySFKP8jbziv9CEYDXp9wz4EC+GX1ozKtcMuhrGt
34San16eNJPpOlDa6FhF+eP/dIfWtA==
        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41dkfxyWTRKIZy1hCyBqiZCa8LY2aCEnSFdmpTJaGHyoJg5QWGSQk
tNglZMhykbFc4dqu/d77/dpbhpqipN93/jjPeZ5znnPOZ3m/X0fB3d/Oi5eH
hyeFGv/Nh7aJy6by9SCyZSHhWCMXG/Z4JqQrMOEhJbmw5TABs3rRG19/ZkC8
gncu9AKBNKUex+u0YUS8XUkSjmOjrTB5tHuRCZXhn/hPB3IRafxawSujAz3G
GfOG10iclA4vLc5vxCvONSUHaRI6dx0tr8UU4UPAOnLTcRIvaJJm80IF0Oyw
HejyJZEemJA8YTOISkF6ZfxdAlqCW9O821+ifG7PQGs7gdm3mw02PW0Ggz8u
mWNHgMlT0T9yjoXEwuuiSRkcmFh+d+zqo2L0qdYoufiREIn5zqr57w4E7eLd
0i9Hwn9Bb+6x5RDEGH71ihIELmw0b44/2YrxUvXKw4kEFHbkHvgs2Y9xa9rx
HXFcMDrEvOmzNbC3n/rx0zkSZX1NjV4pSWjl32r+xykSlz7FSw4F10Ph2ylZ
hSckDMKVnWdrXoLH2Tz5iz0ByRTPPSuMF4iu/Gt/1FESkspOFwOu9mHOsDHO
g82GSJvlm5vSFQjMuS/tI0ki+WbV6vJbOmKCix/xJpLI+vakXdx9EoLkorvY
DxMw4dWWli2JRkPio7ZvLiSyw00bSb9ipC+Gna0zIhGp1uoklHwdme8adK+4
UftJm8Zyh/LwdI6Xd8iLBE+cz/ScYBsu7pSgubkRcHRQDnabZiHUalGiwIgD
bwd5KV8tJk6c2v5sdQOBxnmWj5h9FUzqFRWfHyPx/VcZFf6QQcSZft6rLcxB
z5qapZtzISxemtquOpJ4/Vj3UxfRhYB/za1/20idd1KOEcJN8A8neTJdSRiv
F5dgZVaj1CdMQvM8iSf9jKqSk6G42C0ZokjV0/DM8Nqb0EYs/8m53ClO4hY7
NSh5agwxxyPZ1lLj+FA8xZoabQPL6Nk8Xx6BFvcgR43dNZjttht0MSFhf6b+
UPQvdeiOzi1l7SBRVJA77SLKAkfjeUC+BAcFz7e3NtUPgX8hiP5Sjw2esuil
wBEnLBU63JGl3ucZTXa5ODyI+Mhrq5uVuGg1eRKUJzSBRyJesvekx8CYLFy5
ol+N8r2fZGvVSdgE2HbwzLBgFP9ripEHARMD52btsMdYS0u9feJ3EtXJQlnj
9xtAGIyEM/8hoNrn69cb2o3zLbSbpUcI/Hm2SzL4wyBEx2lflzZT+choGC2t
Z+HD0ybtYBMONmpbZ/6lVgOXH8wkQgYJ3GoYeDQk2YUSXQNRfz4CEf/cDZ3J
pvohfKBVoZaDosRN2xrWj0FzVo7u/IaNjNMSUYVulB91CdV9RVwIR2T+b//t
PiyH5ypaBZFY3iFXbnqjCDkHpdN9jUn8fvSMoV5ELyqfbTITJjiQ+lhn48rL
hNxbrnnqJBdPwq3aiPxYCCp6SW11J7H1XaN0T8AwYgtYKjVqXBTVuoZ06QzC
XT1B9HkYxYfSdxxlo1L82VtwOPMAiTMXJmtv0kZQN/f9Nh0hDtqckvNlgzow
pPc02iebqt8fU2YFzrloUkrQ3WFNYnZDYGy3VjlGRstqd1DxyXfMmuhVdoOm
2yrj10OAPT5QeM46H0W567al2ZC436006lYygIysbwICUgRYnBr3yHvtSLg2
0vwwiwt5qwuNr9bXYknx6T3H30ioehdsF0krRvXyfboHpd9qTT8xi/QBJH+d
uTUrRCC2unsgvJpF6dIk0s+Mjd6cmKfW21vg7r9lp/ZFEq5n0/d0jHciSyOl
QO8hgZou42iZ3F7IF3aFs38k4btR6HVl39/Q+qfKSb6WQOQGV1dXnloE0XwL
KvlJBLxg3Yk4kImj5r+MZp8kIbO5t/gQ9wWink3ctrSk/Nz/87kvKRWQLbGg
yRwk0Spz/hzfyBDyRAKnBWLZmKkxi9TzpPirvzd4lrrPkYpOwK0MWUtqwxZ6
JCJUnx1oDu9Bxj7ZqvwaErJWtox0nUqUaJ/62GBB8Wg4JCwuvxYu09kf+Sge
99zhUZ9b6AOnM96fbjeFGKtvWnSBZhho6D6Q+M+PUTe06o/lYeXSLtV+ql58
C1FHblq1o+hdw/vaTALugaY603tZUFQKfPiGl8TOsHVGV89PoOhVvNfoUQJ2
Zrd7A3eNQrLN/FZwNxt+OpwMz4xXsJbXYciWcpGU3dziJcvCfGr2x6z9BPJ+
W0xYqO7GhlNb1KTvc9HGPeIR1T0MpYXPR07EszFmVyKYxezEz2/lvxRT/mNb
afbLHWSBplD764jXJJiriUF3bMYRf/r3s+HbpsATLaJ0t3MSa++UO7xGJmDr
nvvlsVQWlGkaii0UH52yA+gNw6PQXtw+Ekz1n5GiYypi3oXcBn/FqSYCKVFL
5Abvbiwoat3h2U3CL7a0XEm+D56Xd+8XnuYiNLHMkSeYCXUL7yvS7Vxoejy+
nnuhBcNiXJNRRer/EMwMZZ9pg8MBfeUeARL9ge/qK75/iIj3VWkhFK/nh1aT
J1b7wG1Mb773KxeqDgtsfvs6tDWoNonFUXwVX14y/cxEfI+Ef+gKFwa36oyD
vmvAa3sV/4ExAutExspdh3ph3llNjIqSSJPNeCwQw4Tx134F/VwuXOeD1tyD
72LfQ7ewZSrf3TdesfcIDUHikYiuzwwbfL3yhWuvm1BhMWhZ6UMgtY6deEn7
JZ6r01cW95FYvXDdrNx/EoYPbH5KcqH6eMKs81NLOQ510GLqQki4T8kxs/+l
1pvr6reXcVDtffxoTjwTpcL5W7XXuNjolKzFe2gQvuvXF9IqKD5Fy38+NdOO
gRWFz8+7uGgR/iPVgTGIqpox25AcNt6r0KxU6C3YNR0awaD0KQLvuhU7OvQn
00RPapDQOnf79MxlFvrLjC0GFNnw4f4wwFDpwYmt986/3kjxfyc99uB4M94f
TVjM0iUxY7PzPq8nxfE8dc1G1gRkbQ21//LvQRXzgcgkQWA6i8Hoi+rFp7Xx
Ox6BlP5mcnKupfXi8KX934ZOcBFrejdSX46OTAfWZZ9XBF6Il2qM5PbhkP4W
Z8ODBB5IXbX3VutBzuJ5FaOXBP4PGfu3Jg==
        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8VWkcxm1RNGnamMxMClNRDYmU8pShqxJCBtm3CpksWZJSUogsSbYp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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lO8bxW2RimgRUUmJSpKipDqRpZKiBZUt2ohCkSJk+VoiKkKEspcQ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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81WkbxvESReq1DSZLIzslNYrisjYc1ShekaUFLfZRQg01oSPLy4hI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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs8lOkbxq3atkWRcqgIlbJiE0ohl1Aop6yMlbCZjGSL1DisUwihk2Ip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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs8VWkXx49LUpShkhCRS42omUKTaX4kopJbGjWF3C+RkC5SJpIX9bpV
xlSjpIjUuCZqOA7jyO0cnON21OjZlZDjMikV7/P+sT/7sz9r77XXWr/v81ta
nkedfCRZLNZVev3/XjgTnajN5+PyxED/3GuCR3ovMnsXdsLfXW81a5YgRccx
VJ7NxWaNOjaTQnB3dVOi/ZN29Nhq9GWzCRpjrsg3qFdC96CCWP0IgaZvyIWA
911YuS3HoHWCIPQPs5Iaxx7cUNze4ribwdIdgcfWxzXCYPf6RRcvE/BNchZv
tqiHW3r+PONYgmc234QWfezCQ4ug/CWODLK2XvDZKO7FhpA0LdXzDJJ+Hnvt
iTaYK4fyXXMJWEUVoz5jnej+Khu48wOBKMLZvGCwE1kG8ma/DxHUhK1ZUB1d
Aw9PufaCUNrf246KRkEZxCbWG719CK4Pba4MX96OA70dovu3CVbJTFuzxc1o
jtbl+N+n8cpT18R6lfAs2WfwbzDBpnbXE5UzPWD7ttXLpzFQ5wQ5FqVwMSPY
+Mbud4LE2K/LSq17MVh2JnLsMIPTBb+FfPkkhI7zucx9pgwUJrO3SND+8vxW
uHgYMFDysvdSeUDrfWo1f542A4d5Pqmin0rx0lKydL8fwZqX/IyA8ho41pco
VEQSVAeojA6FtsCt58Su1CsEPw5YHlHnNEEz3tIoPYPgxmD6f75J5CGqpUrF
5CWB+hOpO6oranF1wXCLZgSBw9R04IuoPOzNO2s+fJjm/0wMz4UL0GS+YYwM
E1jFYjzPSYjHEtPWO3wZsKRW9nP/24yhtnVWbQUE399/OnfUshsuDqOlGrIM
vL7Z3/F9fDsW/ZIauLeUgAQOpm/N7ALrRcu2QT0G1emms0ELn8PrqtqZg3S+
t8r2F7Cv1SBP+XEToXq4Ph2vPpPQgQ05f6gXzxBErPtTx9hBhJBWUcEiAYOw
uZn+hredkDFy8uDNUR6tl/dIPRAgyzzaJGeE6s+zUjtZXAEd42BZLzqvj/e2
G1RVi1Bzp2X84rLXaF/1KKXWVIC88hRDbVUGMSe6oeYWjn4ivG3iTiDtazTS
WNaB6/HCp3JfCPZ6ac6Yu3HwVVs5dS3l8WMaKyeJ8nqhY7Iz5yZBZtmDLsWz
PJyRT3u5KY9A9uRU7e3mUiTz04JFvpQ3ywNTWbf+wu7RtOwq2l9om3dnCOHi
41vbKA3KR+HyWV37gAYErwjTeHWJwD8t5ZHx0Qq8kZ5POgOovs7mWVqLu2Bz
6+G24ncErZl+u3PDOtFrV2L5QYbBXtXastpmLmqishvC7tD6PkdValsL8V7+
jWHcBgauLcvdlXy5yAiTllKhPMhq6VXWyjzFwHHPWuMggoPx/emCST5Unink
F/URnLZZfT1KYgCX9aViRHUMCi3swuxFfUjtcHi13pNB6dt+lfk6QmQEvUhW
cmJwvlaPNR5bB95Oa5Yf7a9a/q44fOIOrCs9xQMeBBt2XGN9Ti5B2C/zl16i
50uwtEKOudaCzcWvBxWp/lsqLRTMjrMhu/jY6uNRtL7yXcxMoRCRvKzHXAUG
X74LmXuvz0FgINvG+yxBQrJmMft8I4KaXS9GUv+JeXAuwbIuFSktL2XjqH4f
3DU3pa7qwD7hZIj3PwTJ+TomP7rUwWFEfGAkhvIxs9/bwK4RWlFl5zYnEKTl
7LFlK/OhoW1nVfs39a/2Wx8k5zXCdbJbNzOavl8pvORYdB0p+mSLDO3ngFZk
641ODjb+8NX4cBxBlsNhfTmPDrgmK74O5hGkRzR4LncUIqL4XYWkB4MgwfSQ
xDAHiuwA0dLzlId/J8lkXzISFJ3FfrReFaXJxCfv+PDaeTRcWYJBJpHyOFRf
jsg5ubc2lN/tDaJ7NzbxIF39ie37mEDp/ucfRl/WoUJ+2PT5r/T/Ok7vb410
Iu1hboDDKMEdhf57yduF0JBeMje4koHp4v5Xfi082NlYh3UICI4o2u4apeeV
k/tMW7SMgZvkosGfTrUjPG/0/mnKr3kLJ5AtLoZaTr5UItUrdC71rlRGH959
O1F9y5n6Uew/+sfet+Lbs9320tU0HvhH1karQqgFW7vAk9bjbWsjodOCRpni
+9aVBLt5NUU+MVwIYnoKf6b+rsR9lL7/QhUa84rMfqV8y2cot1qcq0D3jj8D
a/3pedsxHTb8pgTBEmUJ6vT5cEBXc8JsO5JSmof8CYFvmWxYTs7feOQULr34
GuW99+upMckc3LaYza6i+rBkHbpHfOJwc8XMoT10voXLBllHqrphxVdNmFFn
0JtkqDc624kFhien71VRPcwyp3sO3UOS/PAKPep/0sp3P+sOZKN9p2L7Tpov
UObp7OXDHAx4P/xSfYFAv3vtO5/HXOxY8qc45zeC8/MFR9hdNRiPUeFePUFg
Y/rdnh/P3sO68fopO5qv3Cpq0vZCLySqndedOsTg4MpkiycRXNyM4WYk0HwL
G6P9u8BHuraJsEtI4FFlma4bXo7WXq85fzp/2YSB5yPNf+GGoZuZ7nHqD7H/
FB7LbkCBTO5MGuU34/ShiUk3HmZN4muHXhAU6Lf1ROr3YY2cWgSxYpA/9snU
aB4H+qwwtSnKH8drtspWS4RR9pXzWnQf1eVbRLoEN+DSAnezJzTeuPDg4k/2
PPDE5mZGjQTZdYIf7j6phINRpwOb7ru7my/FDYw1YP3VeRMGtP/Hek46D/za
ERfg7KvVSnCyWsjfc60Lhe/O9G+lvOk9S1xp5tCNqV3yq41dGDybvdgf6y7C
tghNuVfxDO6I5ha6P+DidBLX1CSVQCtazms4kg/t0fhY9TaCPdW8tU1n2/H2
St8a+w66b6xLCpcdzEVF6gexNp3vyamI5b6hf6Fpy2+iF+EEcVuMfVV947Gv
tCDZgepf5OaRVLqEhxCpVs7vOQR9UXI/jQ+yoaU4oOR8js7j4cTaEN9a5Jpf
na2g33uUc+pU7epg1bbMMJz6kczX4HoJWT62bJdWHC2k82l6L+k20gMP8fOt
6dQPLZbkb3S5JICeKOl4zRIGekbxiWf6hSidWV+/4QgDQfzN4b/NazDHpO5R
p/v2f1rAy9o=
        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lf//xjWkgTSMkKyMRJKQ5FIfqfCRlVFkR1pCouzVEiofIyoVMkNC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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41tkbxpkwL2mSskS/7BpZQ8LQrU1aZBlJQ40hKiPKluwiS6hkSWgs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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81HkcxnXIUShCaGVarF27ZZObnnItSjlzZKWW1ESppG1tmrGJ6HCH
xVgkIZsjuVbOHLmZMaNxzPx+rkgtlWpj97d/fF/fP7+fz/N9nvdDO37WyW+1
iIhIMnX+v4fd8rYJ5zjQGAift+SSSGOWxGw2aUPMX1s/PUkn4eQckMCN6MGs
nvUpJxsSmVzagfCcXtyZWXb/4+IEjtvdDIyffIYzTRHaxFMCmS7S7QcnOOAZ
6UnrsAS4FWCg+b6sD0+1F6P5YiRI05xyZiof6Yu0z9eVxuAQfbTySk4nAmWf
mL7JIjB+9WNVlF83lkT1r48qErj9Mdz8WEUzEkMfrJ27RYD2qe9C50ke9J74
nPgtbhzeSVFKGjJsKJbv+K31nBDRP6Y5lYUMQoau5rGpSYCb1UFejuZDMDwW
llD++xiCntjWGE4/w3x8ovStiwQcOPWCuoE8tHamXbL3JSH7Ut5B/UsuDOqC
6tZ6k2B56U5Ni7YiMJ9dsJJGonP0Q324YhXIlHKzsmgSIrETJadfVKCiS2HC
3IxEynI+/bh4C+iZlTpvZgic1LgmXs5rgnL0s6rJGyQCPGKf/6E7jL1Lqsfn
ZUcxLcGWv7SvAiGOWjERupQ+AU45eT80wMjybr/fXhI6kcq256wKcH5+Wa3X
nYRvh6V98ZVWOCeE76guJeEz3XYiXGoYL9QlM0/dECBfNHUscH09fBbmTPk7
SYi/KstiYBj0/KkuTTVKDxly/6vv2HCT3B3nnEDA/b5ZX27/ACTbPt9g8IXY
onPAw2TPY3Qo+nk7HSFhU3fsa8XJIUQN+LhU/jqO9ItbS1wzOnDGoWflt78J
CE28+V+N8tAY6+Hfso3EtLKb/evTtWj916JXhEdgz/GgufzuZsR3dSavMaL0
aXqRdF+uDPmqn970qpJ4Kz7frOs/iAD7VVzbFiHoEQx6dgYfv3ved176NILZ
X2/KzETz8KfWwvLeOAF8NHXNipMzwfh3umI/NV9RE+OsjW8jpE1y1Qq+IWHf
Vex5nduJitPMXfKeJGpTi4Om93FhVHOkYTZXANNq/wL0NeP9ytRQ4gqBoDmB
ZNLZQYSwba4x/xSi/q58ntoWFlSti63a7UjYWuh53F5sRbMwN11ugQCn0jaC
pA9hfqm+98ENAgxPusJ3MglIqHBenDtMzSNZ6BeozMaFJpZBopgQw8Xm6TZE
J+5kv4KvAoFvje5l76f89NA+fF1CFAFZr7rb5kcG8C7/WkJeCInoHHqu+m4+
mH3GzIz7JJRq9J3GAobByF3UTZ4nIG64L6WuswPbHxnV3F0ksIHhl6KszUGK
vOg75UABDGtCv1p5/xhb21P/lvlMQDPkrZTS+Vq8FpE4x4ojEavU3KlyNRvl
xx7+MvQDiQPtbi4T19g4VGexHYPj0OdpmK15Xo1Gz0hGdBIJY9tPRPvuF/Bf
TknpdyNRkJw1MqPFwRLRyGd9J8R4ESP8w8gDLKy93JtG8QFnJ2oNU1/gZdHF
o2NdQuzuF65Y+Q/gIfv2J7vfCWzu0f7+ILsFf92KoFXaEdAJZvYd0OGhdFth
iOIOApUcVZW0GxxcIoOSIrWEyHdweLKt9jloZljQViORGrBLWsGTg8M6XJeP
0UI4Hhr/KX6KB62ts4qX+0cxt0F5Ypd3K9yumX92TKP0tpTNi0vgYpfUZd16
6j/UrG1+rGHFwzdbPeoGladYNbvWDJEmWAQPxwSGEQhjFrk2BzZjf3xKjo8l
CUZ2Zon7vmv4li+9KuEo5aeMFhGWXzk2mH55FdYkPsTd7greOISF4INrprOE
yGKKjiUZNuBkYwf3Jp/A4OADLZdILkJNThx4FzsOkeq0Gn3PboyrPddyO0Ng
owxHZn3mIExjtNO81ITYI2fQZLFnAKbkke3rdYUUnxQPhVgNgBcgb00LFYIb
+nwQ8oNYOHHscLKlEEWyKk6pzc1wZa/20tIhUc+vbW2KT0XHiKvUQQcSzm31
FrFL/bCU2r/qcCkBy5K6rsdXB0HnnPb53kCAn2WtSlUODqMwlC6nzxpBTryk
uoDkYHeowlNJgsqD1VeuTL2fIW33D/MDtX+IxNcacYG9UNZv4WXQCNjYr7d3
cslCdEti1vZzFI/Sdxq5aqRj8dzO0EMeFA+GJDr064ZhnLvSXac/hiijCw1X
7J5CoUBj/EEXgej69g2VgiEUqLLeXnIQIux8qnWW2TCOcFY3ae2egO+GL0ru
KvVB6voP3kf7CPAN7uT6G/VBJeHh59A1BEwOJ597VMiF7B8VvJCPAiS1R190
YvZBH2KTykEkXOoGwti8bky9m54zrRPi7K/mYi+p9+hWCmX3eEKqN7KGgy2q
0ObF7NX8iYTK05BT9aEcdE2679rEovwSGfaKQRvCEj0yRsJlHONyOpWbO1mo
zGj7opnyz0baziXtLW0QGt+9Uq9FYO2FjqqeNDaCaou7/Z0pnnK1vpxLrETN
ifr3RoYkVr2TKfKZ6cDtuevGWesnENVaGryW3YjZIvUYBYpX6ltbJ+Wq2Uh/
li5R1SNAgMj+zeIOzUjezNDrMSIQW9K5TuVMFvg7mAwmpS/D/U2wuuMQuts6
IzalCZC1x+xoW/cgDE22qSXVjkPclLGySrQLeVyZ8qeuBKYGrbMS28pgwH/W
w6J4xYnP9dbf0g9N6eydonuFaE7UYv1YysZxsZ9OzxeOIdnz3pIXbwhfvF/1
douyAHtv8jY/ptUgP6n9gOgcgQDbh69fJ7VgJaWlX5zSz9NXadp4ZhhZ0ltz
/88Lg/+LY6bmM8jmXZ38QOWr3G1NV2BHP0666epz7wmx8YzHpdnINqzRG1HY
ZUz1TUTi9U1FdaBF3ZH9awuJZGev7ICCFti+Dfvm/756VHT5H2PJVrgX3lVX
zSUgxZ49by7BQ85yW77bSQL1HBtNdheVj+n6qWUqj2pXd9JmHsXi26X78snH
SJwZGk7vixvExlMvP4qOCiB6k2aj85kNkQJrmdL7BKrN01enag7C2EY2xvHf
cTBTDOVY64awrkRVzJE+AUOLPYV/j/agoUF7pLNBiL1iOgHyBxuQ/tFLRaaR
wIfQ+N7x0n6oxx2qWhQh8B+zQ7fQ
        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs0VWkflkvJpUS5lCL320yohol6YkrC5JKEQUUNoSIpIWSEjISpRIbI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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4Vf8fF5IkpLIqSUIqScs39EJLVlJmGdkV3yizqVJJdhp8hYwiihCy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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk0lGscxyd7C7c9IeFKq5tKZKlvomghpJJkKZRtULduJpVKclGi7m0x
2RKhiAoVGmOpO3ZjzFhizPsMt0gpipLue/94z3Pec973/J7z+32+n+fRPhjk
6C3DYDD+pp//11Gm35DJy7sIrZ6qcOwAgZfi0cBxxyJERKZabNhG0LHoSNEN
Rivqpwu/VbZKMCpNM3YViWDAEjrXxFG4rrTLQoxiKMw2DnA6TvDk86qxVggQ
l/tj8ZNOCT62vp85ufY+BmZfiOlzJZi2q/L+1s4sHL2/KsHahYDrYLTPJU8A
kdnd7Mj8HnSqOMC/rxOV+k7x5lZi9H+Ijn17mg+mY8ebqbspvFBtdNGRrUHJ
lqfWpYYUDN3aXGTDhLi9tqRmxZoehP+5L9ZNNQdJwX5FKTYE6Utc1+w3zceO
L4flQuwI5KgD9gqiOrieKt+U/pAg5Xsz/7GAh62Jgwt13lOY/nt8bsabq1B/
brruhBfB1dZ359m8x7hw+pe6ltMEfmduPK7YI4Jc0OLohBcUiptbVXPMH6H8
12fyuScJGLHibtnbmah+pu/R5E8w/vBx7m6vVrAzX/y0pvd/pP61qoN1EUYO
x3AECQTJlqGNu59wQDIrbMymEHxxUPsUWCgAe2/dsZ2B9PcMI0WvrELcZLms
kbMmiB6IHOhpFEFngvIO4UoxWnj9C1MzH6ZW1Xsy3QiOLNP+xaK9Dkq1C0Mu
0fPMNZGID/gLkKWaV2J+WIpIs3T28xguPNxHynKrKIQxdTsD/miG9ildsaI+
haN320JWDteA6W/H7xNQSNxetaTrUDtOtPdcua8rholgUsZXo1r4KIQJFo9S
UIo6uNeyvhKpsVM2nh+nIC7Vn1XeU4KyNL+J6d4EHi1PA+6li5DWgc/evgRR
Xa+WM9VS4CZz01nTg8BKosVVOPsKBknXxtRqCJx9zvl9LBAi7K6/36J0gmrb
7TyVn5XYXrO/8dEQhc6drzO35LbgXV9WvvwJCj5aCv/c+6MRLINKs95JUky/
PTMrRScHS82iXUN20fUfZI/dHIkHK7Un3JGu15c4teb+kBCzK5br51pK4NkW
djrjkwBmt356y4VIsIdURJcbt6CYbT6L4UnXk9cK0SjMhcrlr86ZdD9rfJWs
p24TgjMip/p2cw8YcSpj2QppOFTzVKPwIIHesb15URl8pL5ihanlEdjErZPe
tGvCWY66YecPuj+Gb20fRQjgqGjHXM6QYl3GUNBA/hvMdamq3rK1GzY/52gt
9XoED7MapdwAuh9GCYGTo1rQHMwrWJ0qQXHuZd39dD9Piz+8I1el6OT0FjJ5
9cjZaOFzSYXmL9ooKUnuFNx5KXrr6f3y1w99ne8pRKh97MzKhB5ME7oKj7QJ
cb27oGFHKAWNpKpzkdcqwY9i/m5fRdD5m3dWv8xrsPYdOqWhKAXLxf1hO5uP
tpWfvfLKCUplq7837H+DKVQKa9/8bqzzjg86q96MiYczql5kSLBD71WjbGIp
DDJntB6i8xZxq0NHL0SEb75GaW6KEhwuFYd/1W2GjD7jU1c57ZMrpq7e3+qw
4UPTPNY5AoOTJufCmsqRdjEuouMy/W5ZXzpo3oT6BWqR2e4E397nn0uPEyC7
a1CPNUcKtu1GM/ffeVAQTUQOfqNADH1O9kbXgR1wZNupYQrhDQpbXvpegG5H
h1wHPX/fa80Z2y3aoEwtu5ZVRoFzw7s9XJaLUXmtiNArtA9SfovzXZKA2GK7
hj9pX3Wy52ZPud0GHS2d8//SeSkQu5t5725CoEGeMa+EQPESi8l9wEf554xt
ghcSRE7qomQrmjDpfXRH9GQKWqorXqfaFMHW6XTFrQ0EIs6Qb7J5FlSePlgk
oXlZxy9Xj+gvgWiFdk5GJoHmy8yL/CYBzh+nDvUHScCQW+WUMBaBgya9Q+2e
BJtE/sNOvVwclWEF+fsRBGeTlM3PG1AWGDWpLp/CcNOFxOClFfhx1urxmz0E
Wu/Opp/XrYOyOTd15haCT9NqUeRdBWn1Np/c5wSq8SHz7pWWgUc5hRqHELi5
sI9dceRAu391gJj+v5Jv9M50sAtzVwnaY5i9uGdSeW1ZUgtefN/ADjSVwrXG
QGG+WIj5zpW9NjR/s88u12VdqEag0o9PzrT/GjT1lhipvoGv+1y2SXQXrI7L
msfktWLtd8NVXTTPZzSHLZ5v7sD6HCYr36IXj0Jzks3zazHPPb1kRiEF7rs7
Nm7Jr7F7hnN6zlsKVy37JnYzuFjg5xn1Tyed7+n5LsFzClC0dtJOlx0EtaPK
s9IWVkD7XuKZkRsE2zQz9I6OtoJ7J22lA8177MLGqg8Jr+GqkO9YsUwKj9Bj
9ZedKtA4cj0uhZ5PhKdJ5InLPFx3GYldI6XAULphKivjjN64FUu30Pw1qx8w
OeJcjlCbnTaCOTQfO4POWM7iQO6R8qWGzXTefZhVdfEFGFzde2NNIIG9l2F/
+VI+1u4/tri5nIJkIjTGpqkGBr/GU5a0z25WX4xUr2+Fmsr4X4fVelHbWH8v
u5MDVeVAvzZnAgfhSOGTA09RMWflyP/+N/TquqkWLEKw+5nCWUYEw4WL9Icm
82HsdbuldCN9vi3gBxw+Xof0wZfyvAaCMPzdt2uekM5z9iYSIAFnZrLnivoW
nJTHhi9VEnB32J+wJregpyIlHNqXU94uL/iY1AjRh38ns0HhM9vK7ZluA554
KxTdnydBV8nLuc9s2+DqrHd9XIPAXfXr7fHWRrhOU4uxlqHPwyLrYvNVjdAa
6BkvF1HQNXkq7/GQh2tTUwXvKwgElZI9E5va4JAcz1cY7kFj2cEFXqcaYNcv
vZC2n4DTbqum9bEM+8aOsu2iCdYObMZ4WhF+jp93nzlAYQN/tv00+n5xq6Xl
t+51UgTLaWq/8hciqazYXINDoNEuCurOqsWZ91uDWmi+i5eJB55EFUPnsW+w
Jz3fk9uViY6Ai25rx+STNJ+9ewqqHyp1Qp05sffO+m4MGC1stc1qBvf5Bx8r
Me1TRtaaWu9z+OvvxK3GtD8Yq+eNfVVvgqRtYXrvcQlKlvKVrcP5YIXD4hWd
l428n7EXf/WByH4i1Irm5T/4FMWX
        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lekbxiWZIUlCWeYMJR1pmmpU0/nRRZYsLUIpimRNRpIUn5JMiyjZ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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lekbPiFpUSeMJFRSZEyiTcitRqXzU1nSKIokKdlahU6WSEQaSzqW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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8Ve8fFymbBiEKLVoou/K2UlRaEg0pDckKUX0VIUrDKBISUhnZsilc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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVns41FkfV2JFRViNVFI2olDkVcpHusiljTKjGkXWWrmOipA3uiwl90i9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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81Wkbxk/RaI4lSqUy2dIylJGlTS5zUEpyLKOxn9BrwojKklSWSTVM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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8ldkfx29jKWmxVZIWM0zSNBTVHdunGZSRJIz1Rzdc2UImRjItJqZk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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k0VV8bRqRMFYlUkgalkqQo8iiin0REZC4UZQxNhAaSUIQkpZAQUpnK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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVns8lNkflqSSJMktxarc2oqoddl6VC4lKdqkoYhFSZHLLpaIUrG22ViK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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4lekfxjUx/DARQxhLtkjWCEnnVmmIklBGm+xJlqmxpUnFIOcoarJU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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lukXRlLZUlJKsmXJFBHSTNyWiBqmpJgiIrJ8xRhJElqUraQkmsbY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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VO//xq0lVKKQdj6pJCQk4ZakBYWQFqKESEq2SpKIooVoQZJ8syaR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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lekbxn0aaz9aZlS2QqKobJHS5JIoE6GStXLsZLILUWMblSVH9goj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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81GsbxsdWHUkhJyoiTqc6r4NsleWiaErJ0ikpTbbirY4kW1RHXooQ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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4ltkb/sKkmBpNWQY1mGqIMfo1ophuI2FMssSICjVZpkKEClnCIEq2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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VN8fVtmpaBFfkgohiZKQvJSKlD2pZEuFyhaypFRSiIhSKtlDiyhL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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81ekbvbZGIpGG7JKZIjslUx1JaWyRlFAIV6HMGL8RSipUN01mLFOJ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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns4lVkbxjdJKEYqFbumCVEoSRHlzqGDJlFEKJXDMCVntSPHUWKcohw3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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lWkYxm011FFMKdek6BqJyohR0cRdkRAaW5SlrEnUJSdCGZFk1CGi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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k0lG8bRiq0U0IyQpYWaSHZLkpRSRtJhLJWiuxLfimKUsjShmiTtEll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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx1GMZJv0a+o30mKJpjBJMeGDq7GNkahUZAsNFSOkooSkVEjJ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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk81dkfxi+qMZiuyjKNtWtncJWaRD2KFjRNUdYShaSshZSGkqVF1lEa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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk4l1kbx0mL0spMISFpRslQtqamvr1SUm9NE0oSoSwhFRJR1myFV4oQ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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3lUTP8bx6cURSWESrtKtoQKRW9fpbJEQiIiKgkVrUIppCit2qWVSki7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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs4lHkfxiVtbXYdCgk5bsWojUptOtxDpOMrsm+SxDCRHHIoppPD2nSg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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk81Wkbxq2VHAajUpG2QaWslVd0SaV4hZlBx0yWotDIWMqWKLTYKoRw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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8VekfvkwmaaSFfhGRMBVCSfUz03Onacotk6UFyb5VKJRlRJk7UqZs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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3kgVPsbxlXKUolQUtaIulGpROiR1K1IlGS7luIqKSFRIpUlUslSrqUk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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx6Ui/ZiRuU2y9IsUJqSaipIPcyMqS0VlyRIaZKsQhZT1RpYS
Gin7TAuaSZYxjUv25V4317WkcL/njqWyZEIq/b6/P87rvM4fz/Oc13Pez+dz
VE75H/EQFxMTS6fX//dDB18fZWhysFXKwFo+kSBwUX3eVdCFuoBfPAbPUDCK
n3HK0stGxFurqfunCMoyuriT2Z2ILb8paXeAYOhGcbbGnU64H0hWfeUgws5I
xeTP0x3YtuixzzaYgtgj97HWf6MQP5NpZuBCYFCTyxzOaYOSguLqYiU6fomG
/L3eXxAy++i1giPB6P4vHYLD5bj+JWnMRZ6gQJ3tvVeyBxMxcgV/WQ2Dzfxd
wjqpFEq1IfcSVAgGvPw+aS7pQMaYzuDXQQKjuhW3JIrKISiZHGT5EIjdrnVm
bs6F9Khz2shBgmalzRPPBlrwd9rJNd++oOuHh4wtM8uCvkWl1CY3AucdvuNP
WXwMJa5IktwsRFNzntoovwMWUZdGe/woWO+p0HXu52J8S6KgP5yuv9TmsPHG
bsy/874rReefV3Zap2DXBCutiTPfGRF0at3qC/zMwYZwP8O/dhMYXv9zg+0n
AfTtj8/aPCbYwlTenxPUgPesBWtzCYITxk9CcwJ5GHMs/yhjQ6A3bzYWEfY3
VE3GssrPEEQ+mFkXxMhEhO+fC66nCXRTXJbbRxdBZy/nYa4XfTbarrJQ8Aif
h9xt80wJpmYXSoOe5+EYnyH32INgsWK4N+tZPxQMf7VzX06QOuV5qza7AWqi
Lk3bKxTmv7MWf8TtR1enjI7kPgrRFzz18/ReYt5Rgy3FH8TQG9W7Z3m1SNLN
97OzJygXmOvcYL5E0zHGiw+bCNiFtx6zOq7D4Oy06XVn+ixYaWVTXYYCjboz
2d4EB2Ty9HxiulDlHaAePEMhIKZf+UpyKW4Y7UdUEEFcdfqPa7f0Ij1vVVKy
iRAnZdulT8w14349V0J5iMKU+j8RXptiwdjDECTQ+XNKqEumeXGwsXnotIu+
j5NM8ZkPG3oQksJM3bKBQqS3g/X78Tu4/IH6KYDm65sqs8s7nHmQKX/b+wPN
C7H4JjjWiwOtmNYTVcYE+6791Es95cHG7SL7/Tuaf6I528nPQFm2res4HR+w
PLjhxrliGEqE3py2JZCtFz/ys4APuX6JAuNBCozwh6pfWp4jsuJ5eCc9T7Eu
49+mpPMwkyMZuHmlEEMuqd0KS5/gZHLwrqEIAp/Yvg376wfwScMy5Vnia0SL
Kn9f1Bdg2+GxmMD3QoiJrh50S42GjVV8CUXX9/HOb3os241Wr7C158IoZPr5
P9heycdqfxWts9EEvtqFXdsnXkG6qjxrl2AYam6/q3p58bDMIcfNPZmgPSZs
xZ6pZnj+6N3LMBBBd7ose9KiAnlSTjJqxQQhIQ7KguZaPLDpNt60leZx519B
mkubEDjYaPzmFQWhfY26xcYunFaqy9iqSqD0ueTNk4QG1P+xrLE4leBOunrU
aGU3NGp0xJ+yhVgTbhAiXVGPcdlJXaf/EJhubvH8YUMXXFaKeajNUthdUdtW
XtgDJc+AqUwdEXZ/tUzgtLTDrEf6+/8wKfzokheVusgGw1X7XmodgfQFS7eF
c41oNLmdYd1Ex0+mqmqFdsPA5jrL4huC/IChxU0L9fAa2TQ3bkcQrOzTpavW
h0ExqfWloyKcijf2SimsQ9kq9sVV2rQe9Ribmki8gseKC0GKiSNoaxjoOaXB
wxKJ/o6OYwTbJsziXq8eQK7yUW23oWGsH54z46eVIo2Tw/Gn52/KkOtTGfQM
1ufjxxdpfqbEM0V+Bi+QacSBoTnNk5vp5Jc5Hn77L8M3pozCKKtdjnMyH6pz
LuNPaX4F7BsGjXpNYEVM7V/XRSHePWJ6PqEJ6fdPKM2vEyGTu3FR5flTGGo7
SSrT7y/tZMjJ5whwhRdqpnee4GrfXeE+i04sj7+oeMqNwr5Vh1RsR7gI/fmm
2GYBhWNXpyXf9/DQevbaUpcVtB5/nE1QOO2FvYE+W0edaD1XveuU2yGA1VQv
v7SYwvHRpQ1h+b0IbIjcUqM1jPpE9Z6tfg2IjhGOqN0gcOk7LiqML4D8iUN7
pM8S/BsyN1SY2o7+3ooFg3QRomNrXLl6dfhpidRRl1yCkzv7zKPaupAx+K/Q
QZbWs8SyMi/VUjzRKQ1No/XTcG23vqndc3AOFMpoTtL+E2tbkGncidb2i5lH
j1FgmypcrE+5CTn27tWlnnQ/dYpzHV80QLjzNNN4mwhmbt8Xmdn/AcXVK2uk
jhBE9V81jyvphOpN36WatP41e0wwbtUWIfJlXYK9NYHI8fxa80oBdp0+fNnh
Ps2v88CSynuNeGDA6mHTvK+vmBm3EE/BBLkwcsiVoMl+zlxwj4ewi1IP88oJ
Sobn9JnJdZCVvBz253GCBDNLxzaWAPLMDhdVWSHYwR+M3taxUZ31eLFsnPaj
moCWV7JF8Ei9OqdC+6VRnqgu4v4VxNUVHxTR/U80HK6W9m2D2H33HRqnRNgX
InktuZoLYqleoqckREnHgeisFS8w67d9/T/PCDxYfCnLHg6+curfhXGFMDIx
8idqjWhZ5VBjV0WwkN9Y9ZJPz5P6cfJFkeC7T1+9Zx27YLTxlzUe5yj4Mj8f
1N7SiHc7WouuDVBQCFR4Hd3ajbi0j5eiOQRva1YK5E340CX1eePbhJDt5daG
U79C8FZou5f2D78jE1kqEh0o5iubuDNFmEqKVV6b8wpT9o7enB0i/Fxzjh83
wofNGtl3vF0UJv95OnEurQ3XP1Ulnqf9+rfDv7Ieuv8BZmiz/7MrBEXb95je
pOu5B1d+5L4Vor3ljpyNXR8mptvNl2UNofelYpPluufo7GPZrmYSzFo9OBjw
sRs7G2bq7Hm0f18La3Q9VIOJl4WcIdpfAsJC3CO/8jHwwZi3p4ygOmPAY17h
Ne4Ny1GXdwzBmuFpmKT0CGk7Gfb+DgQvpLSjJSMaYdTfTS7R/nOxflKVwxVA
Lp2V58US4nR++bfV9H+o+3iCfuhtAg0lL4bPmyaEeAeEMwopyB9w29omxUVE
slzjYIwIPuIxjj7v2uB5+2OVphbB/wA9gL86
        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns4lOkbx0eknxKrZVOkpoMGhRSbki/KZLVKyJlIpGWZNkqFRESpVESI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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs8VGkYVtlINbl0p6VSCimSW/JMQ1LJlhWK1UQi1aQV2Q3N1LRdlrJl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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k8lGsfJtVRVJJsqeioJJVkS+pSSYiUCnWENjqhJIQWJHEQEiVRyJYi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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlns4VOsfxadEJacQIirddCJ3RaGlklN0SqiQ4gjlUBLhoCJJRYxLfkju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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns41GkbVlsU1W6bRW19kcMqtpZSkrqVdiSnRbUSVlIrh8TnHJFQyaFo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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs8lVkUlYmK0CAVmpAKIzMiw5SW52SkGHM9kpCSZ26KEgmhpJC6Sk93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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3lYDe8bxonSJi0qSyiUhEpoE3clSSlJiSRRkaSFRPuCZEuSQn1Ji9Im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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlns4lOkbx4cQItr6SaJyKJLNioqir7WtQwfH6KhEOsiZxUSS4pqVM2lE
JVKi+lHOZRuHNmzGaGaQw+B935lQtpAN29a++8dzPddzPYf7uu77+/3cj7Z3
kKuvNIPByKHHf3Osw3AdK5QP0fkgmccEgeTGTagR8iAcvmlR30yi1LRIomXZ
jQ112b5bmQQSw42u+qZ1YVeb26/GdSQYe9OHb8b3Y/prkXNrOAmd8tx4XUcO
2AXbbmWrUQgvMxzznOWhb3v9I4U5EuZ7UsJvn6/AfZNbkZPhFBhxbX/prTDE
4WE1P5NjFD4u0fim6nQVjSrnMh54Ujig4N0SltmNwJ9G3WUYEhCPhpYcf/sG
tUXpOpPRFPq8l6vEyw5iZywr/B1zCIcU/vpjOkGAD6TqdhkrCqcb2Guvx7fA
SrtfwDah45m6q7/wfg4zw5vs33+mkOmQzIozacZiG8lhWW8KBR3XWmxL21FZ
t12ny5tEjNTZlEcEFzY99f1ZTiRYewhLqdpiSDq93TIOUIhZ3x6dvb0JOU3h
xJ6tFIbjygJ+1OVDqd/ZJXQlBalZ4rzldQ6ITaf0M+l4ofN3ty7x4INara01
cUGMHi7DvWBKiKYmY22VMwSUVD3mI2I6sLf3pytPJkj4+Cy4cXD9IBLzZtpu
WZFg88003Ty7oW92+21qqRip3XGbuXoDuDYzc+y3pSNwzne69nKoBb3fM8Oa
WRSCNtkrVr9ohuq4ffW4GwWvIjUln3sZmKyxqPf0olCSfS6rTbEE7t4Sx5P0
2vrz4bk9H04jaGT+Tzu6Hjzti2cURTnwrgoNGztD4fn7bo/Xwd0IdYeFF0Ug
Sy7KuJUpQMdmm0d39xAIV/PnFo81YWdEZXFDAQWbVJXntzNrwDi2TI4wpJBd
v1Y1i/kSV0X36wp1KWzTTfFKkPCxr4Ovdi5WDPmorW+KpmuQcuP02ImzFJQV
0gI8TQRIVINSWysBVoW0RLmYB/HcwLnxURLtdY+Zk+wubAq8Kd7mSaLcIrSa
fzsDGoE/6M8fpsCxvvwi91UneuXLHQRXSPQG9tX8c+0JlMJe5hucoHBib16Q
8m4OyrUGoks1KbSEVkTPJDbg0ialg88tKATXDzswrHm4l5R31W+YxMGFXgOj
7iLwPiQdyb41AqEo3vGfYgEmBshV8VMkBG21xvV3+sC9z1TWqhgB55dTdZ4t
F3B5Vj+34SiFmtktHMsLApTm31g0QeuL98Wm7EpRIx4u3jk5FUxh/U3+7wUh
AqT/4L/y/UkKCR25GQeW9+B0UqFuaRr9XszSiHSrUoynXJhj76UgVHUWTnO6
sGS3mtxaCxK/NUmNc2e7kSEy9PlqQMHgfZDPUzMeNL/lODrQfm5PZJYbWHDw
+PGS5O+SKRyR4ibqavJgw+flWRhR0Dy68KyKJQ/MEOkQkboY1is+W1dl5OKS
Xepbi9MUQtZeWp0/+xrJAYZrDxsT2H+8aoh5TIiPkSaWMdUErNUfHyi9n4qc
V/pOrrSf0pu3BOmvrcHKUTnzZpoHs0dMs1JnelCUXFDtTuujNmDwsEShCxHv
DG5ocCjcuaS9YEtIJ3R/LDbDdjqfnk7CnRebYcXv1PCj/dyrJWNfc+E1Lg6+
4CbkEsjXD5IuDOahfMBVdt8chU/jddFZ/i3w3Lcl1jqKAosbN6H5vhI5OodM
NhhTKE33yyddeiF8s1En2l8MdbvAa11JHRhQ1744RPujbZeC/Yl+HsI2mLuc
CyMhbx48pGDaj6b+EQ+He8Nola5YHBnZjESv6KdzVbSev59yOLe6CQmXH3a7
yYkRs6p5YzNbCLvReY2GHLq+4yeXvk7jYpfREdduLol0KY+eNc+6YLl62bjc
gBhlUStOfh4VYJHpyoCNT0h4pW6iLlc2oTpEoWF/Pc2jCE6Fsn8WdhTsKL9H
+9O80f4ta1svFI+TOmceU5AnJS1+rD8g+1TfwPk8CeuM9qh/Ym9B9+/9JYXH
6fyXKIemM4VYp7ZlfoOmBPaZPuaLMvnQsbNaXBclwXy3ZGp9YyfG2s4sSe0h
cf5/1fdqqwRgF2fBs52EJEeoauvYC3m7zElNEQFe7AOfOasqfGZ1ejifoiCQ
6L4s4HVC5V3dzI2nFNR9yVnTB48wHmv092Y6/88efBzJ/aUGXqeeyZTSa8Zd
mScB7YGwlXsnvETzndeQ2PS9agfMB9WcbijT+6/eHcl12YlQkbGfKc0f1dmf
N8xHFaG37WfHRlcK3OuFD9NIHqTW7Up22UyBalnK/MocQNgXI8aV/f/5qU/R
sKcD+XLKsv60Pw4pMEbLLPrQbS210UqPgLri3/2KH3qQKaXqo1tJIXnHN5HJ
iBAJ7TuyBj4RUBVOk7aphfjzflurkTuFNRo2iUFkO0yFlUpuC8UISZPRk7/L
R4feozwVagSjV+R1B21eIGZEyzqN9stNtm/ur1N8GNfnX9umREBQsDB4o80z
LMsWfqqneVTgObAvRaoCKxoZt1/sonA54P2d3AcNuF4flevvQ+HB7y+/1iX8
ge/Gbc8yI2m97v62emsV3Y8bSmZ16PPZc0N8+b0DCF28snb/mBgsYaLs+TIu
FtqYT8Y0kXjJifRV8hFielI0wbkyggWhJT6/VXFRH3N3VbIWiRJWdGnLskpM
2CqdLQuk4C86VLtjTx/YF7zdPJzp/vtWO6k/uweuLRYBSXtpXhZ5vBm804Dh
L6olsjSfLmZNnFTqboN2z7HCaVUSrT+pq4nE1XhqyCLgSGGdpPqdm34HwlOl
df2TSOildkTqlFRhNCPbYIhN88jt1FG9nX1oNZ/forichC07d0PkGA+EkUuE
dSJdj4clq/M4PATY3Vdk+dH5Sfu8bYbRiyM6JhGBhSQuf1wm2N3TCOeHvwrU
6H4eN53n5CXdCWm7sOLqoyQ4ls7tpt+6EL7O5dUtkRgDjh5twZUCWPiZHYx7
LYb3qn1JyrH9WHbnkyPjG4HvWj2qFg8/RI1mXbUvrS/H5v9zFfu6YG+1oKXn
A83L4SnnRfT/4dVftcJCGQpG0fFcoU0v1qS4EMGdBGqHzlR6DvOhvFxbQ/sp
AfaXBXlbpVtwYoGtqxl9/1/dx7os
        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk41dkfRjcVKluijKVFJq2URslLm1Jkm6RQyDIl1dXYB2NU0gyRiV+W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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVms4lVkbppG4apoUSiSlKUkGSWnoptTgKx0IY4hkoxw2KpWMTyIyziEh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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VPsbx2VLUihlSXaRCFkqLZ8SoshS1oSEJJeSSgu3LJUSKqKobKmk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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs4lOkbxx1ap02bUi2SqSZJJ5cstuIrOa3QOFTIryQ2pNZSRlGNoqO1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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs41GkbdvhEK6m2dWiJTg4RQ6lVttsxFaNZVGwqlLTZZQqpsGnWKaUs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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekbPkgkqqMsadIoql+YqcbWolu2IhWSUmMrsmslihwpRVlDhelK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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk8VO8fxSmKylKJQpaSKEUokpwWCqWUSJG9skSIUBGKKFkqIipKSEJI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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81dkbln3XNC2mUSQhlNapRI8ihEoxjS1ZyoQGFUYhLUYSEqUrS7ay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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41OsbxqeTLb8iSYt0rqFOyRayJdzT5pyUpcjSIiFZIg3ScRqkhJIk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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlndUVNcaxccgCEgMQQhFfdhQsADR5GkQ2BgER4lG8ixEiNKUFpQWukqI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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VO0bHkpRQpItS19JtoREhFuoT5LwaZOyJEVZU6lUiiQlS0pJUrIk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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk4lekfxlFTZJ1CRnRkSVJCDSV1V5YylpAGcWKMGpW1EOnXESrbtJCt
g0g1RLKvyTKHdLKc48hOznlfcmULTcqU5v398V7P9fzzPM973/f3c2/y8LM/
JSIkJJRMff9f7Ytr6VL6OXi2z7tAzZlEgnpHn0hsF6QV3nq9lR/DiaPDx5bP
9yKrwPtGkj0BvfNxGl9ke8GuYmnHbRKg8N5zXbEwLlKe+l9i3SZQYKYemsbg
wGlW7vDKKBIhvL0/6RpyUaT1Xmyj2Rj6Tofec/3YhmnPYbm1q0nkCoWz/7Ec
wvatyjKKFQSMJ54oZ+Y3gbVZnW9vT8Lh6SurOo1aeK61M7gnRcLJubQ6kM9D
XMxpMrFSANVPr0fa93dBITiHITAmcSTIUGs3nwVrIYUZMQsSL9JLb+osDsDW
c+ok8xUBGc+lw2lN2Wicnbqr60Eifb1k0sv8frD04kJFBeP4y6Xu3sfP3UiY
ExOz/UuAfRf8pEffcPCSps1dVy9Aq2a1pUwdBzpfny0dmydAxqmrx6a9wYCq
fuB8KYHoKpe98dq5yO5cZWBtQ0LR6G/PHar9aA32Kq8zFmDXluAMbW8Wyhj0
YQ1NEgc28phnNStRaG4WKneEhG1QwLLUhh6Mi7c92lEgQJb5n/LD6jWICvjn
105bEpeO2Fl+UuoGN6bYMNaKD5fdtMFbRV34s8lB7ZvkGLZtbbAe3N0EL4ts
p8xIEipXRhnmsTkQfv3QP/AUCaE7sZ1zLonYsKD9cfo3Sk/7sOaY3bEw1W60
DaP0cDc4XmNkyEP83vQ8CUrv3AyNuvVDjfgUflGv8RMB03NERnMbC6I0+wbd
ehK6pu+FdHsi8CTm3HQVncSQ/kyJ/6tWKKok+r3NJJFqesyKKcPFqoPh/f1U
Ht7tNxUIDtbCNP3Wte+KJLRaaVH30gbQPnM/eOGCAEKaITdKrnhjRd6p6atu
1Htz/r1rpu6Jlt42/vJJEhODP0xPiXWgY+6otUrMGFwTzqu/Ch2BI3jNaRqj
SLNw/F2Y3YpocYMTs1sI2IRs+VZS0Qvj9hvrNy0SuOwW+H2P4d+Q1/GYvxVN
QnThgrCucQdkLR8qjQ6T+HbZq/3JEx562fPlqu8I7DS5/ePwRjbE5u6yJI0I
9NELHdltPSisUGi08BVAlu7gaR3LhqpvXpKmKgnOv37TyUEVYBRumzlP6Ru4
9rYSs5+DP1S19q0TI7FneI233rtuVFnU0U3q+FBYvNjXoM6F/xebpefjVB6K
84VqaXVIljylbHCd2tMtQnZdeYGdq8+5XTMnUZags3D2ZBNafFqLW/8h0Pr6
6sKaygbUV6gHiEqPwZdzMlR7oRslY0oTDCaBXDVPNbXDXfhYfq7CqIOAw+c8
6QMnGiA6qRb7RYvErkk335zaHngdryOYhwjc+3x8N6+iCzSTCM9Qau8pFzAQ
09yMXFr/nY5Uyo9K58nR6jAYc/qaPCg/subpTu5VRbAq0rs+GU9iyy3zvR0t
7bBRnrCrraDy4/ci1+1/OVjj32/yK8WXMi0PQfGdl1A+KpOqVEugMK4wTOI6
D7JGf9U8uk8gav2H0YwzXLDd2+ySn5EgXz7aZpbdi1VZ7ZfrAvlY3PxrWsd+
aj7PiNO2GhAIzr46FKLPASst1i+LSyCQPpYRLTGIXY8PnzIQGcOm61dWLk1U
oUTN0jLGmkR0ek/2H9n1mKJneZQHk0g+JnPbZTsHJTnDiKf0zUos2H92qhM7
nzFEThuQOBPsqCfU1oWbIQkm58oESA5cMTpxioMHN+X5JU4kRkNoi86/NSF2
1la035tEW3SA2V7pLszubPz9kwoB95FvxcclGiGc3REtm0yiRDVEr0LwChwL
qbxj1P37Gd/Z30252LxwhJn0kJo/br6/mWQZPlx8UtnpR4IlvE5+OLQF7str
t1ZQfka69LisONMHpUnZibZaAaIveLw9mVSEQj5H/aspCYHavLAok4PVWyJe
S1PnNYiq5YtbliPC55c3Sfso/3Yt98Zc6YDPeaGhldsovq7ztXUMHcR1poiU
9wgBo0YdVxqDjcuT7HS+NAkvFyly4cdm2NCsmL/kk1gyfxHpbMdBgkLVGuZz
Kp9+qZl2AU8Rfneyb2cIibkqq+IayT7U3NhTvfYMH93rc4YnmdXQabs54QAS
EimJjhr8FnB+7jbS6aH4lGC+LloxEkkHalx47lRfPPtyNSm+BH6SLXMuVP53
h8+VhrNzwBJKlW13JKG0Oq9P1KALh1yfbqxjkbDR2J/MZHExEpQrHPyaRFGC
H2sPrQRenmt/nj5K8Uh7+4T3Pi6cMme5bo8E2MoO+LynpgT3bcJ8b14kMS/Z
UR7xrgvBtDLv+9oEUu4bee2VrsSlev6h98dInPB+6jtxqBWmatUrDS8SaAiM
uKWSG4Dl5K9S76n8FzaIZMnpvkH0PodDciwC3fc95zakvsSmxqUCCSrf3Yw4
a2M6D+dKtbbdofj/cGjLiLxKF/RTHlZO1lJ5WQzymMkvQZTytY2G1HlR36uP
15W2guGbWRWrPgaPBydG/DUHcfH5o1nXFBK+kiUWTm968OGm8MKMJoEQqUTR
TRHtWLmhSMQ+kPLj8nJQamQGpOs7J/+keCzTEqCaqF+LpeAdnPEIEgXBDgNT
zhyMXgmeqZ4lcEAu/SdllCH18W9H/cJINDmr2bgoNiLWx3PgRwaBnLchU7mR
bLw4mJdyNonqt6D68uB4FnJ/WIxJpvr6ef4DqyMyPIw/Vz3wQz/V39zIz00X
BqGRePWuSjaJ6+3X3gbuGAG/wFCsc2wE7lOfjTfvfAwdnrRrP8XHhHWuubdO
U/wxGlLb+JD6n9IbOSYtPKwikqPHaig9FqUWvio1IJN+MH7zAYof76JqFcNr
4LNKItNlFzWvmaUMceVuOB0VSbr7RQCV2c568RW5uEzzIenUPIbofGhqvNQF
GVK+xdZbAIfJ9oWMn5sh6mPCeLdE4lCKwoR+Ui+ERYyPTL4XYE+aQ4DaBh4M
VsbbKR8k8KBAy0I//g1WJI9rD4hT+qps7TIVqgJdcLppXIXyTzNQs2NbIx65
PT6pQ/Wnt4iWtPFAF2xkthsww0n8Bwh4pwo=
        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk41WkbxxVFaLKcohqkGVLqoIak5UuT8lIke+RV9l2qkZKRpcU+jYli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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkbR4tK6TCJVF+ojEykmknWn0qYpu0zKhlT2Y1RouwxiXRIlmpI
CA1lTR1L59ByQogTxznInuV5tU06JrJmvuf7473e67ne57rf+3f/llvd0cva
RUZKSiqRPv9/940uPzI2Woc3CSwxL5zg/J2l8lIpf2ILzy+y+DiB3nGlWlZU
DmIO1l1gOxDUZSmdNR1uw77HKqRblwF/4Yfz7DQRqrZ7p895R+ApsUjRrmpG
yG2laceHBI/mXLbvUOfjemzXdPIZAv7GruQyUSnMjqwNDHYlODg5ePupshC3
VLnRPzwisGALtbmybfAwfeG4fhmDY41FeyaPtUBxfM88sQoD407NMW8eB7oa
c7UnXAisPav8JeY9uH91Q07xj/R7vNyf/+gIkRVko3wvm/Z/Q3/FNW4zakw1
G43LCaLNlf11H4oR/yzggd4EgTBL49Dp0DLMfDyqqE37YfcxzmXTXJib7SLq
HgSRQxaOT74+g6/BVangYILTy/7qC7/bgLaJvESnPIIbTSnWPUHVeCv6mHEp
gEBr+L3Gwp5KvE+TX/I8kGC7VfJQ3gkBtDfcmghOJIhZ8Dp/u0snmvqn784e
YxA/vGP4SM8DXJC58s0LZzoflvyP3vJVeGubeFnlD4L27ZLAo+DA54yFOIDi
va3nI21VLoTxTT3p9kqC6bi8bDlxK9JtKt71/UtQc8jIIPluPew2OsmuiSZQ
u3egfW9OOho2n+vbc4JANX3hy3MTQuy3cf07TEwQMOgezg6uwAyvJrvpFEGf
RH5/ztpnkLluef2lD0FOQHfhR1Y2dCVS8x0p/z+9LVpQvKwDn7vMf88KYDCV
uyj7qX87tnpo5LpGM2gPy+ld096K2VDTq+HyDPRKM8MrZ55gJk1+oJbWG03g
FKTGV2Kj9Y3PXaEELWttzr1Tq4EgRhThFkGQqqaQuH2yEskrl47v8yNIVFiV
XL+oHbLV+tObHKkebo0p1joUoTJA3dnNkcA7LCi3KfUVBKx94XmaDC7usQhb
vV2MLIfukkxpBgkJ0za1+fWwVnBRu5lAYLj0BsdCRYSUul8EK6k+rb52LNzl
KMboz9ENj5qoHv61VfF1yceYp9DTi9YPGE900ZxfiQ71ZIUwymf/4c36B+oa
EMloFZBkgiRnjvHqlh58mHwZpUOoH2Impz9otoC7h/OfmcUMrKYPyAWiBuWZ
0fWIJFiWd90kL1kAd52hT+ICindMLmg2uQlLYy65mz8lmDjjPV+jmfpld93c
3WcJWDql69brirGxJmLJ8VUMhN1uKQWtpSgVHs4KciMQWBr4mft3YF5e4Zkn
yQzuDSocmTovQpj9fMkU5TfDLtOeHcYHm99q7Uj9d1rZz0mu+hG4h4XH//2d
wFdnJ/N17Qt0t5ltNrpO/XKwuJa3IAdSeiEVBZRv9iJGabSsCeHfJv2dQedz
ozw2ymp5N3oaRFuejjBYENQr8XktQjWbI2vXQvVb0/tuHbLRS46mD1O9hQq1
VpyaaoWhXerbzYqUjxFY2RaVQEZReEhM/RbxcFPp5GglIv0XF6ZQ/whzHLO1
qvjQ8hWp8ij+jADJoTRWCQ7tdu+xpfqf6G3TCL0kRFPr6PrFlD+WbbGHK1+M
zV4Zcf31BAkmvKVl7mLYnDKxVHpCMFP/2M7+4XOoPvB0q4mlfGbHrZs3VI3R
W0VHt1E/75mnlMjXeoWCZR2p6/czcOzjmk3HtoO7dfRGxyUGCyfd//PmdBWy
Mvj7V1H+zdLSe/5hc9CjG9hlRP2av9Ut2qlNjKCYFU4Bnwg8dv60M4iXiQ0/
l6b6UfyL/U/UHhA9g2mJ9HsfiueHfnv7JYt64chuOphSy+B7xV80yqJpPqRq
xXrTPHnEqg+s2sTHwEhbpjK9f9/zi+zotgLk1ebWdFI97tO1FBg2CVHSr9sb
y6H1Fxcv2BbSCNP00WsbHhD4CfPSjj0X4ht9BRNpet79aY2DzHQn7vRILb2b
xCDR45/mWIMkxApNxptpvp+fzx5RTwjD+6+fBs3p+VZlUf/RBg7Uf6tuLKL4
ep/MhhpeaoAky3jgZCrNg7IL7BNXyyEzu+Nq8kk6zyQ3/UhC82sk+v04vX9f
OvNveZNupEeppxg5MChISLMwnHqJszkRuyppPxsPGE/v/iKC5fXhi5Iugu+V
NQt4WmLkF877nEDzKyO8+vc+wwT8pZRx4iLtp2fsvqZbSR1Unaa8d1B97h2/
a3D46yvE6W3+WdOL5mf6cE+WTioeN0k+zdL7PmqrNo4NifCF83rTe1qf5ROx
rsSag4nKddcKaX99A/HK+849gNl36T3LqZ70Qr4E38nNgpRr/gYNqveh7ECX
+nsvMbGl+Nc1FQS2Mb1VC3c24Y722NVKmt9G0WMJs56tWDJv4OGkKgOzBdJS
JjaN+FVxwm/wOc238wlZ7N1dOHl5JfepkIHKYmcP675W2IVUMGFzGahN8j7M
qeDCtMJMEEb3i1m60VC5ajvItUbFLLoPzrn2r/6vXQVYjjr7lH6j/X70HmDf
5SI2St/1R3q/7DZXwJA6lPvxt03ReRi037dLz+1FyohLs0RvCM5bBO9U2O1Y
kVkbWKjAYLmJjg2UuPA9Nbx8tTvNnytSw8HxIqhoxOpw6gj+iJr2WM96hTXj
2Q68Awy4VxQYgX8lLL/cMT1+jvq/RrnpYLUYg8+/HY97Q/fbnMsTvpGPwVey
v7/Ni+ZPXPzjsC4xyvL3536m+9+8eWXErtxGDDbPuKWW0P3zOUjuXUkVjGJZ
TsY077X2ajdsGOEj5lRJSKEv1ZPiAz4vvwahV5L2Jl0mkKrWVjbacRbViimm
+pTP1yeDDGRjWxCaaPv4ZieB/VvNcLX6TtzbtLLfYweDt7khm5wV6rFOzdX9
YTz9/1wnuRPdPAi+2ynppnivxPGcM1WE6BbqN8rQvLil2lng4N6LrYYi5Yv9
DLysBlgNoS2QGmK92UbruxubFS8R8JHBubJcn/qv4K8CXkPjc9wsrzlZd4nq
W9ZuTWZvLSzKLV/Moflx9sJt218mm/HVocrNK4fq0yYqwnTLC3je+VK49ibB
/wBEM9nP
        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k8VG0bRkVJokIkIhUK4U2UusiSNiSUCElSypYXb2mTlEgIyZ41u7Il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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81dkblmYSKeugIUuJhiSyFNVTNBGKIYwQWRvJWCo1hESWaRGylSzJ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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4VesfxZHKUIZug0qFcilDFLqilqgbkmOIyJg5kX5Rt3BNGUquqVE3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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4lOkblihFEWUlHchKoYNhd7bonrXOpOSwQ0ItOcXKSkiaCh1+tm0U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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VW0bxVWGE0KDUoYiKopKhSjLEKmQlzJFIUVKiCTKUBGSVFIpkpAx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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk4lekbxy0troYokixFUSRJY2uoLynZCuGQLINqNIQoQ5ZSkiRDEUIK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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk8lOsbxodyUkmUZAnlqESl7WQpLmmjJISibJWlCIcSFTlISLKTpiSS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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekbpu1wWi3jZ2LKVsnYp91ym0o/lYzdpCyVbRCnsiQGZUkn2ZLM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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8Vf8fxyVFg9BUKkUXTd8WSb1klKwWGnYohLYohIpCkaRshYaQVRmV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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk4lWkbt0xl7OVrU1ORDELZmkr5SSRCJ1NZSrTw2ZfIaKoJafkKWUoL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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk81NsbxyckkuWmRdeSrcUlW0Td6iOKst24ZSwtSHFHshQmUnNLJUsk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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk81dkfxmUZkiUackW2MWqmDJF9ejJlEm3CFFpEaCxDoZpIypItS4kW
qZhWMoioIVwuLnGvncuV5XxLll8LrUN+Z/44r+8fn9f5nnM+n/fzPFoegTu9
REVERDLo+u+bJSWhI7WhC2PSv6i+aCCYuRNQzT/Ax3hL7jarUoJy2fBT08Fs
NIaznIuOE8yZTyyszu9E8bFchXPiDL5JSZSNm2DjTPHrwx3HCDTlk90OtpXC
rJp9+8khgtkTi74Jd+vGJcVMVTExBmoTvNtOLn0olMh1K5VnAFNrI2ZvD2ye
Xzl92oeBitX8/0x4f8FKVGHg5wMEA2JfItKm+9CUkGlxyJ6BRVeFn0nfAP46
MVMZKmRgZVr7SBjfjNp38i0XLhHEjS57ZXisEWWhf0YaniVodKvqEattgva7
G2IXzxPsFoxomVm3wcGgoNJ3hGBF4s9v/2zOQtKJNxri7gQxC1TFpQ/zoRmm
Kp3NIbjbcchzaC8bZV6jfMdIgnp1TmT1+TaMnVA+PN5LID5XE3PLvQei2rfs
FA0YTIrNsmw1+NCJFqlh3yDYkeIppSzCwdhHqZ2PIwiG3gqas1SvQ07Z1cSD
nnfJWsk73paHI3NC9eF0Ar7kunMVCTfwbNx43oTWvW1CZB8s6EbIsOj8UlMG
Q54hrEuihRB+0OHwPAk4GbpkVQkfygfs0yyrCfx/ddj49DUHo3IRW7qSCER1
+T381F7ourm9CpRhIKPvn/IqoAoLtFZW/nuEwNDzmFr5vhbsXLy6Uv8eQeTK
8h+PXn2Ckpu6T10DCVYpZacbMN2w9cwWSFgxcMrq9Pz9aBe+mN4Rr6Lzc5hm
SRZpF4NlVmFs5EUA2WU7vg61wGOrblxMJoGIRva2pM5+rE2c5nxuYyCSOuv0
XOY8cqwddM/uJ9ifarnsuoQAyTMvHMqiGWxx6DB6MFWGFaF6+8p9CCpOhkvp
fO5Frd9ILteMwUvjSzmD+5qQZJfYqZ1D8Grgvv76qX7wK/wTlIMYKEaNStXZ
d2D3WkmruioCu4vZdbUvexF5PVtu8y4Ge164Y1y1Dt4O48kBlI9ne9f17Yrt
w5MHTZocGzq/8J94E7b9sBRXvzoezIAvzLf2Ln+GuKXzg7w7BIvfpQT1JubA
1TUn/B86n/TclDBBbgtcJUof9pRQvmJZRdyQeowktknYUt7GzKvD4gbq4esS
yveh/AyWF43Ju/WAzfn60pHOk338/k17my5oC4u7JacIzH3HAw84ChAR9JOJ
tBODoDnh/D9KZbDdGqew05tAbbK9PS2Wj05zHw8fHoFxsePdHCMe5Nye/hbz
hOCgTHjHmQIumlrvhsUkU747amsNllQjI2op3zuY4Pjg9uDPUV3ovxySdWEl
g6PWZ9+P9TTAdCppmBtP0N6uEcBltaHaQ4LnLCTQvxnbXBjWjo1rU+KzBgk+
fbe1ROREK/Q31nj/Svtx+dDHHycHm7Ek+JTTpvsEKi693Zo76qDZKGMkG0Yg
N+d8WVxQA6FfvvQhylO12Ic/avX5EPmfjJBdTJA6GCaMv8jHcNZLMUEurXfF
zE5O3IHri/e89R6U/5QkiUzrTthMP5WbnyQokVCPPtLYC6P6Aq7CLwxK7E4J
so4IMPOTIVMbwKDtvblbgEY+KlTMXznS/SIFeQE19wqR4/Rhj9lBynOBko+e
Ug22lg2lBlG/qnmsc0FlXzv6Oq6tl2cIOjV9vzUx6MTr1b1FFgsZ9CQrcnfP
1+MP+W2dZmcInO5ODMrWN8Le0qrQ9CKBQc/2BbsUunHnmnCJwnIGnyY2zmz6
OxN1Hn1xlZRv/5ui+WOLynFIW8r4GuVZW+XklzdsNrZ8OiZeGELw9T53X6N2
Hfylw/kxJwlOXVNza63oQKpDmWLvO9rvvGGf9NF2DK/YKf/2G3ofqfhXb9Sa
0CoXcbb4KkFKqGXF5zoeolZP/7L0McF3P9s5Bv7ehgw58WsbugleaJcE8V7y
YaHZcPPBAOWXda8gWLoSccuVI/wCqF/O7CtRCSxHlJ7/Q/gSLC+7bzEV0IPm
T+GpGQepHgP9Xh7PfYZp9ZkdYpTnmctDTuNtDXix4s9PZecIep9fMejd0wfR
w37e8dSfV4d6BjWt7YfJR8dHrpRvxdglfabLu8CKv2fE41OefD6bfO/Xj5RH
9LUMg3cPC46m6fKxnXukqLmV+uPH0R9Knaowsn+NmFoQ5ft+8RPrhRw87Grc
UEn7M9k4O1wqaMUnP/0wp1s0XxY7QN+Zh8QcLWEi9dtqaoh7j1+Hy0jDuC3V
Z+FH9TK2bDPKIzWRRv21OjJhZo1+G3IMfbUTaqg+bkRZWGZ24J5XqnLhAgbr
y0+lqd7ORtDZ84NKdP/IkNYBvZWNGLAMt+RRPf21KGiRwhEOElzdH/Ho+6Xl
nUfU7bvgbL9wgNB8C6r8+8cZ6h9JtbtnfjNmkJGsYUwucDC53PzcdXp+7Hb/
ZjOXVqREP9D+4SbB98qpy05Gt8PmzUG9s1yCPUVr9si10P8FRWxzWkXzNb5S
yrmnG0MPHdes7SCQecR6unbVE+g0DM3K0vmt0IzS3Dz9CEW2p9I5NG9XeBkl
OBa2of6MS37KZ8qTVicrz/YZTnuJz/XmERjtVjGWrO1FYKPH6XR1miftDp2Z
h6vxLLzVyj2UQC9VzY3kCWg+azJVeQwiL0mWnt7UgoEp3buvqb+N1xw23Lim
Cxk2Ed/FbGfgP7t58ffJbHCuaLTOUz3FRtvs4sq0Q8d69N1WNtWf8tchL8l8
rFSMLWdonrt3b3r7h107JKLJKq3X1C8tVUJuBAihuHg0TD2JwSinKPlfWg9V
UKoJpPXIqgNuDnneuJJkfX4N1dNFzwq9+opubJirsk3eyoBjtU6K18kDt+Hg
orwigvXBz2vW73yIuqAluzd4/+dXN+wDewqxv1KZtYnq/4eAws0cQTOyf7Vp
9qX9cDIv0eK+4SBZNuPfvCiqj5rYjY/TuuCyMmZL4nuCjnUqdqHdlbil8eH5
LOUxvTtXDOJcfHt1acv7CwSqFh/r3Yc70H974l7iW4J+wy+mWiw+pCKm2jMp
z/8HejC+Xg==
        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k8VG8bHipKiSwlCi1EVErZuSRRKipkL0SiQpukKCqRJSQtIrKE7FuS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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81dkbx5FKg6KSiupKmoTIlGzNx75HaDFCGFtSrmpiREOWhGyJipaZ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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns8lOkXd0tsYkItklTKpZJCIT9f0sq2RLpR7iFaSW1FSipLZbcaspQi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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4ldkfv5ORIjFSSg0SKsrWNtOUT9Y2JLRRZGtBl0nTRpaUFu5kiSQk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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3kglGsbxlGEEm3anCzhVKg46qhwRUiSkJAjFbKUZI+yNyGHoqJIomzJ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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs41VkXRtG4VCRyv026CFPIPS+KUELFEDpyS4ZS6TSMXFJIiulCUW7R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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lekbxpUsUTQnpEKWlF/JFv0IXSqFEJmMUpSSKSm02mYsI1mLLFFG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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lWkbJooRpglF2lGyE4qarjI+Ko0RvkiSCaEs0YKiDoMaGk2hQXYl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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Ve37xVGGaJBCIkmmUCllKFlIQuVFQqa8ml+RoQyNkkohMs8ZC1Ey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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkfxi9aiVQIMWHys4zRJGSrx5KlRVkShVBjmUFRlLVuxc0W6idC
hDSVJbJL2bJ20bVdXLLc7xcxloaUNOn3/f1xXuevc55zPs/7+Zwje/aClSsv
jUZLpMb/50GtC/N3BlgQUcv1WBtCwGLHE1tR1XbwMs6tSpmTWOVEZ7IsOXDP
0rCq+kTihOvRkDxDFlbeKLSW85D4texoZ/W9Tvi4OE142JKQSWHNis7Rscbm
4y0hJxKfLC9YIagHtd5DOtbmBGyUXXUZTl3Y5PF77clULp6qJPne2l+LjM28
Plv+IEH7MaxXur8MU0V/G6xeJjFqEawXIFoMj6lU74oQEvUm33Xm6GyUyGS8
nrUm4Fz/if9DNBOqTCPeGbNxHGYpCzDkKlGQ8OR+L6UvvsXQzn2uEWmVngGS
ESTY/nfvzXm0QVLO3JmZwMUNnRFP6cYK6KXnLEfqkHA4fiz05lQd3t+fhK40
ibY2jQ9XVOqxcCd4JdKIBP8ht2DHXDY2Km3bIqo7jivzXsnKqxwI9Z27ZjlB
oM00mHe9YCcu3NyzdiF8HGbxWQrSLjWouqnab11C4ups92DSgwHEaGu+UD9K
IKX4yNTTYjYgIWt89h0XK0kzguon2IgRWzOfaTEOxZTgR7+GtSH0mjhj3zQB
lu03/XyB18h5mT8QkkbCrqro9KJXBxz4tNMCoij/4g431zDbYVOupMcTQMIj
ZPvkxqdMTN8YmruZTOLFRB29QYiFxO0W7pcHudiQFl4n7jKA81y65b5rXNA5
cuWF+/MR33a9/RKDqp/WCE3xwCDG/vn1YZgEgQ2yXbf5V0vBcAkONbIm0SyS
eNFFsh8Rny17O6y4OJbOot8K78KDsonGRjkSPo5bH6jX1uHP7M9usqIkLIKr
R1t8mKjVskwO7icgwryVXRPSC78dE6mBeSSm1Dz/NeLrw98+0ga/5I4hrD9z
nfm6ZrhnVghELRAI6F64X/hzKc4s0BaPXyGR8c81IQNGK5zemcnPiZAwG9A+
kGJbgqsP56YjKR5ruTWz32n5+Pq36curFyg+TQROG3eyMfdh5Mj8HMXb7mMx
mosRYL9RfBNM8dJ9+49/tSq7cKdbajVhF4GheUW+22Qv+oQUmPqtXKxLf7xs
KNqLJx57fnnfMYauNtHzHQM9aBj1cOEx5EK+JHto9ssgoqpa2oaeDSPm8a5G
3cVS7DEv8XI1JFFY1thVH9CAWcX857UUj7QX/sEliXQojdp3aJ0h8eqxz/aB
8Xa03XugZqtFQrgl55XDVCeUt37LfNpKYDhwV4JoUyue71U9VwICFX5s32Oa
VdB82q1upU7V15WlXWXZDr3ivBBvDoHCDFU+Wk0tFqUCD3EOkHhj9eCIePQA
jIwD53UGuBS/W7d94WFB6aOSZdY1AnMHbLpyH7ExzT/D6HhGIpaxHJzWzcRb
n2//dVYn8LTHpq12XSsYYYT3q0oSeokm3gE/lyGd2TBr4UUiJMH11pusbvRH
mc5IUH7rGQ0V7/TvRJT66zaVwHH8qRi9qehDE3QrZKaTlgiUSS0LJPB1I3xs
aOP29wSUFyRY+xWL0PLx5KnzVB657PFkdXk2bDfNJ9mf5KLyRp5CfAEH9z89
yysUGcH1zRzPgk0cFP3gEbN7ROXhhsnsX2bZ6BoaV7BxJOGyZojvcVE/ojWd
sryDxnHZP+dz3P5eyB46NRvZTeV/05DGIU4PKiNmY0xOU3n/VOTg1N+EqJJ3
nkQo5dfnRbMvjo/hrWDMuOZN5ae8cF9UXglK1gQpSe8j8deSo2JcTT0qfrk4
pVxD1f8nDftVlGLc/vmqVBCJk1UeHWca+tDkGv21heJbv83R9Zt3OmTI29JR
50gcje2Jp3NLEOK9XjDiKAl7Sf6xHkkWlqp7kv1UCLQMrf32ZfE51PpPX6ow
IbGre4vAefTiaN33K19ZJCouuscZVJRAcnnDpIcyidOX3Xn89/ZgjY+bXx3F
W3+uyMuFrc/xmemwW0yfxO9NgaY/wpsgms3DeO1Jwrhy+JkGk42zD/NV7k5z
cT+n3MLCuRweVl6b3Kj7CoqcKZwIb4SQ+1WntHECrW+NyYfig6jfcPZHgsoo
PoapjlX6PcPKsEyQvQ0JE/0Nkn9t5MBZ+G1J1UsS6rs1bewC2ZS+vPrwGBfL
WxhdNTvqoK+U2LbLehyjbP605IxcuPU+136pQOK3OP0xYfVWWISejXF9QkDR
4MRLt984qGe3jMStjIB2Uy3N4G4GePV373WxIxHQc8dli0A3WtzeS304zsWn
SzxZDkvNCL5bLOp/j4Tf78aPSssKIT9pXPWVytfBfL6wXWN90Ge/Y5ZLcPFv
ccJ5QTUWqksr8+pjCQgUrBz2zeiEVnsDb6EwAZW9je3fA+sxnyrfLkzxHlYo
tciV7YUXt9RATJ6qf5tKqJhzK/7zWqwnt4DKc4PkUkVqKAIMbWIKKD21eBFT
9mA3Aix1ct9RPCZkD1ocCuwEPd0+lC+fyu/ByjnP5lLYL15MSaD8kCH5NUKC
MkG7Sw7IUOt9xaaDTW1fgbONLqhNre9fkj0+fL0ICtJ1+4ao++ftuNfA2tqL
Oblze+e8CNC+Oir9pBuPBc0CpQg3EvG0lRMF2lkYyXY0TaH6m8HoC9vJ6B5E
jp/b02E5htPWBhvtJR5DytlxPuA4iTVS2zfPHOmFlS/tD+vt1P5vbWvjCyi/
njAFU/8hkF5/Xckrsg90Hd2LLW5cOBsdrB5sKIDk4S/Sby9S/jXLcw7GVkAu
rzq7nNLTLz3VlOV7G9FmEYz1FO9a4ev1d26uAKf5TC+vLwmdjT/5dd3rw7zd
+nw3MQJynU77S3ma8C35T+ncQgIzmeJey7+1IzZdokiCek9mVPN/nBUuQthr
IXodpXeM744/w64PsUGSccbiE3CYFK1896EahqPtg7W6JFJy+tWF8rpwd+Hh
2px46v/it2Ry80A1Lm2bpIepULxaVtdtXupCZsOAVqLEBMrMu/RcIwch6qVh
Qd9D9f+DC2e837yA6jrhK32qJOi3Cncaf01FkpB5WLwziaXGtetn1DqQkLRH
oiCaOm/90oNYIQ5Ojez/rEb16/8BtZW9AQ==
        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lWkbxw+KFiWTJZospdKmkyIN44dEjMaSsUQcsiQpqThTKnQyhMLE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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lWkfRq4sg/GhZSLVlykGQ41E6tzVWIYMvowS4lCW7DWVbeJki7Sc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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk4VW0XxjUJlUwJSWQoSqk3vKFupDSgTCUJlSKZCYmcSlIKiQiJKEJU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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk8lOsfFS0q15WQSqTiahMuUrkd2ZJUCgnXWrQjERNFSkSrJC3WdJNr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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk41ekbxkUaMzHKnmRUaKEIU5Z0k5KhMWWko0JZKjFkzaBFZOzTlMRF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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4VukbtswYM0yLqEkUkamJpjIkqVsTaUKEjKJCKoxChKxRJpkaVCNb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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k4VV0bFpKKkihUkkKEUETULVFCikpSCUkikhIaJPMrCkkiJaTMQ+aQ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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs4lOkbxyekJGVyaLZQTm0HP5SWGHxlSUSkctiwdFibqBRLpPDLMUVl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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk8lfkepgZl2pPtWiKa5JAt0UyeJDJiSLbKmi1LSpkyzC1iSnbpxghj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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4lOkblu1AIjlkUmSkJTlWRNm9E6uNVZbYtlRS0sq5muTUOCZpszax
K5pKopwNY4ucjUHGYRwGbbTfN5T4dVCpRb93//iu73qv93nf9zncz30/TM8A
Zy9pKSmp6+T777+MeVlLPWoQHt8sfa8ZQ8Netq6TXlsKnzNWaue8KLDdF9HR
EhYu609NWxyh4CQZKeQLOnEt4OrsOiGF/U9DJk71tYCro/6NaTyFymW67x62
FMLIoc02+xgFRoGhr3laNW5FVdXxgijM+r5YKjdWApXz9Qb6xylo1X1W0B1I
B3erMLib3B9r67boN00+5nYeU+JdJfspbgWTN0QQbTSti22iwJH1Fulkp+H2
3e1zHcTedsNyDc58F5rkRMppPAqdd+KXbDfMxXyGecq9oxRcdDsOyivz4O5z
KyfiJIXUb6cM0gVCfG132sW7mcKB4nj7Lzb98BAqBYRL03ht7ZbMzBnCQIh1
UEA8jRjHvNGzUv34nf/x55TjNFKSvdX3j5VhcMzEnk/y07lj3HV+Sy2qd1t5
9PlR0LbyiU7OFcIrX2HdWDWFYIOcfocvHdj6Vsd7y0MK9m/6c0+0ijB180LH
xCwFf+3Yea+ERnha/2LMjKLwpe/iFnOGGKvk3zQaHqbRMcFWtFNvwriiqc33
JB/tvNf6TOM+tOT62cXq0zDYdbZ4/Ew/er9e4hK2nca1x66FEc+eghovdc2P
o5Ek8XMN83+KpLMxzGA5CdiMJAuV7kG8dKn8+xqbxukaGwMDdRE2dlzoTVhO
Y/xJeek/iU+g5JNe+KiAwo1RybNp934oGPk7z2wi92s83BL+ex8mNNrGWYY0
2PtPS+r3CaAp67BIM4zgITd/n6yaGI320p9GL5L9A+WLUNCE3j09n5MvUQh0
/G1jdVktpvIrfCdDKYQ7czZEBgmR7Cd2XltBYT65WequshiVExsnYog/u6vv
yqve6YNt/sywQIOGwqqKoR+ED1B8M9jmiicFKb25iYS1ZqhqNz1rQvCg9zaI
Nv2hDF1JXgcvnyD4dflF+dI/j/HuvM6QdyAFk90yA9KUCAfuZ4ZVfkXjxxVr
yp0/9qFAaZhXbkbDKdFhk5lbI1hqLHn1CAoeyl1WFmWZaDgyFLHEgwIzy6t+
8JYYBQZdTff/oLHMfPueuoxe+Ov2GrDeUVCMVJS5hGsYdSyaSCP+SC+80X5o
1zDYezx6dPxomBjs3nf+2T0MBxpsUCX+s//02K9W9BBqQ3XmuqcovI1Mdblu
2AOLvVYp99+T+JyGLOXj8qHjYrLjv3hrnaSXuXOyMVNS39BL/Fk9a8lTWDUA
D4egtb/Z0oh76b0tqk+EO3+vEci+pFDM8T16rLgcBjwB84w3hSiNOebmo31Q
5a9m7SXx7vRzU2gQDuDAyNzzjHOkXrNfHT79vwewkRiH/Ujek1nPiR2xrEDp
xTmOmOQzMGChVHx2P9pXenusnqNwUjtAlXVOAI5n4bBMAsnXtyGb5twr4aQr
Lyj1JfuclRk5V8sQnmW/J52c7zi0bf9HdT6Syjsl+dEU0jckx3+R78T4Wa3l
+oRPOK+qzO5O9SFC+Yne99/SaDxzy6/AqBwviu2KROT875+GQg6v7YeeleLH
WoK/pTMTu2pKxGDPh3G7Imkk+3cUscw6sPKiyoeaNOLPl4Ovnm+uQQ5D53IJ
qX9CKvTCv6mDp7ptQR3BX9nQj4HZnsNghKeNmebTSLiZp9L16DEirezvOhK+
0mUMufcoiDDTGWz/WoVG4NN9cmuu8iGVtB5NcRReu1cbtR7qwT3tf7tkpQge
gqz02yRCdBcy160g/NJpvcD9lc8wBBqu0aqxNKb9U8+PWAxjZulHc51rNDJH
uet/JfhLsTlaVC5LY0tCyci71kZUMr64tMcSvjDXNTDZ2o+cpVl/nHShsUZu
i0+ETyearzct4HMIP54QW6xP70Zkz9/1iaMUuFV7L7rsqIN9KMUQEz76aOaW
EnynAdw7YWpRpD+3sWRq0m8PQ0178sMxMcFj/a9Xtze2gjLTNq7OpJDM3FV7
qaYB8s7NWWORFCi9wnS3xnZIjt1ePH+D4FU/p9khKwx+WT3PrQi+3dsaZo03
1cDtyV0Xt9MUTrzTCvbQ74R6xYJlyYT/pL1hw6oSQEEu1ijgJoWD2gel/2pt
w6Fhnc9O94g+DDPMVAta8SiQ0bWYxPOn7jbJG49uqCfsqJ7sIv1aP2JX8FMv
bu10+JD3HcFnacOuIsUEhCEi8SfyvpaAV69Uk4yBSEU7FllP7z0xaJZzA7lH
51XWkP6orDNeusSOA+fYO0J9sjbZasfSY8fAaE5Zdzexr10mrLkc9Qg2idJc
rj/BY550kXCUC1zRS9cneAtd8rJ3+YAIXhvWRbw1orFik2HwkrZGiBKjZUKT
SD4ysjZayhzEqjKmkel//pjxd2/UFSMhg/HChtTL9vmkZnVWLmQeFF/nEj1i
Ry+Kv1qXikzGS38esS/bJh3ytJqP4lfz36kR/u8M4PXUFPDgm1+3Ou8XCvGz
LGl2KB+DNn0CLumX+6rnai12tCDfUn0ynOiBJJ6rMxHXBetWGWFjI9HDlpLi
7zb3Q/BvleWUDo032ss/NwpEGHPjlMutpOHs9LjgvE435hfPf21N+GXNrhWH
Y+aGoLAzYo/9SRoyWfpzqaYDUD3uJlCdJnxkL3Xk02MBjq7iCRuzyPuDk0wt
fjdci/NKaVKffIb1tZpPQ/iqOfRZTguNs8Ib01qOXPyrpOzpT/SdbZ7p4lVR
ix+Op8+phlBYOErPGobmgrf30/wbko8Li2JWrewfwAsx33Ga6N3D3uGZxCN9
0D5Vzn6vQGOh+NiGJ8sHMJXmf0VhHw2VX7vH/jxVDf16Y8efSD+H7wzRNv+j
BN//Vbl6lMwbD7Kd5cYe9EMSdECjwZXolY7Ww7hmgvfM47fqbxJ+v+y24vCj
diSxF2zWzCbzSELsgpsyzaj4WdChdYXCuLu84ZvZNvxjlLc3LpfCh5YnYk1X
AbojznTEkvkmofv2+3KlZtj9vKB9JIbozYmMPYneFajMSH0vIfzqW9U6psXr
w/0Piy2j1Wj8H8cJrF0=
        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHc8Vf8bR7RImqRCZIRKJYXyliRkJQrJKElLpRQlK30bRsgqIxnJFpGZ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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk4lWkfx5m8Jk0LY+ZIxxZZkoxBi8n0janGHs2JGjSSLGlTR7xCtsQo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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lGsfxseRUnmVnLKlxVYRL9WJhCtrUoRkaXGQao6SObYoHUtlS5FG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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lekbxqkUmZqpQcoWg5hKmowtupwapcQgskx2ypIYSYhCSmKiRQph
QpM1mpM1WykHx3I4R9ZIz8tM9bOlaZL4PfPH+3k/7+d5n/u5n+v+3tet6OZv
5blESEjoJn3+e29SDX88frsJZ7badSQkE3wzbnDtT0ETZKvGIyrPE8xqLSjn
1nDgULLbdiqWIClLvaKymIveUqw9wSb462rNRZ3FOrwfaH+6PoDgxg7tberl
rRgN6/wklEgwPPq4+FALG0vmYx8JjhFwVulnDGiwkaAhmp1Iv0tSwsfibEpx
/7fF6tWeBC3mJs+fH+Hh2E1jnx2TBKGSAaLy/l1oEkt02NROMKJcVHJwaTvE
hS1SEstpfml+c7/tH4CYwME/LJhBvWWegcSNZLx8NT/00JnAY5vqjNuKbrRU
lgX4VRPk8+84zba9RKJovepqnzFoLknVjehuBmfFYGrIbYKLHpwqtnIr+hSb
xlUyCHSdzi6UcttQ5pncfCCTQMhy74M3S6+jOHdpXxKNL9vn/7Tf8gW434k0
tJgwyPc6a+OzpgSe4fq+cx4EEgH9b15c7sf623r7nO7S/F41fpj4PR7hXkrJ
HnR/r8prTshYK9gZ0t6dtwis67yvFrj24O77pR7+5gy+P1Vn7xLRhS/ndCJ+
aqN6TS/E61yuwZ7UQTOWL4FJQlLql3tsfNTX2sVQ/USFd8pt0OLjtBp7I0uF
QXht+pZ7oTx0icSy7KoI7FeZbrmwph/BgsHfhnwYjPCfhDQqFmHl7MwuDXd6
vy03QzQ147F5x12BE83vko38/l/rH0NbSSo10o/GXy43uXiyGmPqzstj6fln
f4758FZWgF3l2ZcOijH418Q4cifTi2uzczEaRgyEdo0Oe0UEQcGNW69D47FN
fjBea96ILIPp6KEwgnpD2xyWQT2Wzs8cOhtIYBGwVuzl2zuQFZcRUXYh0Ltw
vTgvaBA9n5UKVzoykE2Uj4pPfoYh15jl//FpN78gc9m0AVxWgqHWKQISWHLD
gZWNIFUl9nu6P56z3V1V4xGMgjqyjSlvFneiNcVGcjH6o7OuuytBpNWB2yMc
HkQnwvnR3QRZ/oIthZFZSH20PX8/3S/9wTyvJKATngp1hdaFBBWcyRfOob1I
8HkeIW7HIOCNZLPalXbohz6JLK8gCC/+svxccBt4Q6F1vHsEOVK3lknFs/G3
6zX9WHo++5hsiUh5A0RuGOt8T/Xs/5/MRp2hXuzj6pWd2sPAoKPEUmqiBdW7
/LXG4wk2aNeJaJoIoOLbFuGtz8DpXYD3hW+asSmaH/Uv7a/Ptml/JKlwEaQ0
5pSeQ+AyGaSw7lYVao+7T096EWQUs2x/WtaIsGnVe9KRBKyjFz68VmjAtf1n
ggOCCJbonZF1SW6GY2LMlSiqp7732cVMIx6WOjukbeHReP8ssxE86IOO4F1e
zAkGFsm++GxdBP3JGGUxyktn75EZufMF8J3mqOu5EWjOi/DFffPgFjd/tIvq
m7B7kJvX3wqvGjOzNJqf0b2untP+MVj9EH0H/+Nf68tWlfdlkPi5b8SB8ptQ
63czdEUrXC2FJjlpBD9dGgutf1IPK123XR8pHyYTJ4OlxZ9AKvV3FfUzBH/2
VI1zJJrhzFrj+OkKwcFslzXW/XzM5QRPsUQZ7Dssd/KZNBfzhg/IA9rfC0fu
D/7t141vPpqVf/xIYCDtFaUt0YU1grI6mde0vhrLuO6sRvDyVRsHLlA/DD0X
wIoshs6fYu3K9L7zwx2bPphmwFL9yA1VyofWxJX11aOduBilt1qB8pEldEti
ZUAzaj2/7gm8TvCV3ahaQu4zKJk9tXwTTWAVt8QzdroTawU7jksJaD8XrJ5U
EPsDE9Zx3klUL6GdFolRUfFQndKodaH6LLuXGr4qsxlXe5mbltmUX/tfIg6p
/QH7gcI0Ufq/8aXIMt/TDWjPsp4KPU3rdflAYGcLD4LAsEX1Jsq37UMvi5Dn
INfmVUcuEvyrNdU6nN0ATuhB7++CaX87zyTH9QxA40HpTleGwS1h55aHEx0Y
4gWmrS8g2K0ycWPfXDfko4SSN7wlOLKwZnO7bAOSDYvaiyg/WelVpwZfPIbh
L2nXU08QqNVVDX61uxyXPSK0pH0InIbul0Yf7sWBDWNmgdoMatOvXczT6oHn
cNic8gEGHjy+W9IYH0n6d9ZpTtD83A0HZ+O50B6o1fHJp/pcCTlarv4M/gc7
Vq4OJ2jP/3Zg+hIbyvK1eayjdP3b0+kSWfdhZGc2c4Ty91gyX15FRoDRw2p1
auIMLqt9ZWjOL8VrSY0BcerHytLXDW6bVmLd+ed7+N4EscL8kqH5PuSUBr2q
8WfwTk7bcMN+HurbuCfX9tL4Rl2vr1r9jqqTm6/40XoXbrZvFDi1IOyYQqbX
HQLucSvFrtw2ZOhuOjTxkPpVpMc77/WDsJxuFV5oYbBZbNa5QJELvZEauXQ6
f+z+clS4Y9+KBP6KYwlJBOZFXrs/q3Tj3adfvdsHqZ5eNsU+CqUwGNSRGaf5
hpyV0bGq5CHdtC3ln1cEEz9YFijs6sFUxdexrEMMvJremLMlq3Cu+LSBO/UT
oX2/RkUeHIDJ8rgVK7wZrCqT3vhjVR9abjQ29bozUJLzz904/ALJpuzQ5FHq
58+5UcE6PCw50ThsVUfndX/m1rCUamSppDnmUX/X0mKnfpppRqSJda9RCu2P
inSX/m33cTSux+oL5W/KIWXux4rb8Jd8ynlNeZ19+0JvW1snDHUlp7c/ovMv
c5txpaAH+dFXA7fO0362Me2IvlkOZdsZ1mPqT4eHJv1sGocg2ya1t6iGwZC8
ifmiKR/8cNGKmjeU50aDHMfgHrgrhlvsnaX6r4vYWenagpR2+5jz9wm6cuOf
sBx52O6TedGGSyBeJuyhy2mDIk4uri2hfpun5/MouwxBp6pfqtJ6v2Uv7BB7
yEUx966PJfW7d7kKPmdyc2CRscH2O3of6YUGl53CzzDh1CpXROfTcYmZ9HVJ
3ej3LvcOXM6gzDR5L2eCh0GRPbXVHQQp0xd0ShV4KJy09mXXUr0KMnM9Ijlg
98dg4SrB/wHXP7ud
        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk4FY8XxilRKmklyZoWES3KUr1SCSEtyJqkklKWlHxtZZdQypotS6Ts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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81ekex211NeLKZG1GmRg0rq3FEfrYs5TByFLWkekMRhiJUMZYQhF1
Y4SQtSiyhCRbnHQsx07oOL/focWWZBjh/u4fz+v541m+2+f9fR65n8/bevHx
8PDcpsb/Z3/NWa64bh6+8+rtFHUmoe9Roxae1oGEnwPOCM4R6P3k2315KRMT
NpWVVa4k/Evk9mt2xcORb9H2IbVf6eCHMbeFCixGj9w56EXiBn+VednNIhTy
p6pvnibRNKRs9tX7bKieCNeRcCOh/oy9TzKkF1/FT3sXUeeds1s/f4wZxbqX
dBo3m1qPiy4WC2hBbbbmWaXbJCJP+l4pP9YApfE5/ZZTJEajlgoW6wbB/Dju
p1U0hbzceGWt5gmMCGes7bXhoincbbfi9kF4XxPh3PuWC4G85NgXH9pgt+Nx
rO0XAvUpcW6JB0YR1Woe/2ctiY0H+duLwzqg0qN0e6WVgK/RpulB7QFYMUtf
T2pzsfhCoMWT0w8eodoCworEsk6Hki6HhcmuR2dNgyj/bVwvqiaxcKJqwPph
EBf0AOEXyjeacdVkbP4LFW/+YXqlktNrHLiXaatFZ8O6s096mn8IhzOPdYX1
TUNX3OP1seox5Optxm8T5YIZb+ykozKE1KVaA5c/SURVfSvRbzGE3W+Xc7Zl
cLGr1L982u4ptAIfqheoknDqiN6rvDGJlujkpacnp2BtGGlSLcXEMXORlkAH
EtVL4yNNzEE4JeVN3uqZQlW10x1Xo2H4FK5/shUksZTDsC+9PYEcvgOyZ5Up
/xcuhhdP9SGisSdUpZ6D/HcRvK4izzG8v9G34wmBvTkKTUahTch3lmSGMwks
MgzuThnXIEhKlp5M1S/tSNdoSfcAclhvM4sECbBpJ5JvgIWLfEMRd5kcXJNZ
rNTr7wPtkFfw5m/TcO/ZlJzVKIXLTL6rxzkSIYp8CUl+E9ig9y17OBEItbU2
DwzpwYN/YmPUMyl7Uv+c3Pn5MQ7Y8KaPa5NobAePo1wfKoQdmFJzJMJVtLLs
Lr2CcAA76JkDF2z7K55FA33YEow8PqdGQjXYpH/1SDtcE42TWisJZN7OXj5T
PwBmqrpwVvcUHFRzXYfk+tGunBvWfIGDl0So1EdDFjYzlfUuBJB466x2rSe5
G9uv2PYrlxF4fHh+vY3BwjSzU3xsikSvlJZbjHI3TCMs2/3yKF7cLVc/TvTi
p6i0Q3mGJFZDec99SmzCdlOPzxvCXEQ+e74ctvAXtnfcNNlDxT+pEpcu7jUI
P+8o2a02Sj9NA6+kb3TCjM7nn0PxYB8SSbtQcR8t/7516dLvJBSWNr3zm1rw
2PmYSdZbAi1fdJNqPOrxvuDlsM/XlL+iCXsSY2qxT0XjR580EtlvFPf4Kdbh
vMd+8eTdJA794+LNNGXhWlzCuE8wdZ9wlmRuWT9oIeUXvBgEfiNp4bvi26Aa
9/VJvZsEeLRtTtBXy/DGyj81i7LfYJEacd+kAaYJu7ZCVwkUR9DvcWdyka4/
tNzmTkLiSNLqy6Oj+CZGhnf4NBs8k/fvxGwl4rPoJSd/io9aXqG1uq0KZChY
8D8PJTGilmGZVTGMSP6AhWgZLnisnhXn/jcKCeY7Ord5kBClZR0xtCzHox/I
NQF7EheeDg/+4dqNXVpuL9doVL4d/bKcGgtguGA0unmGis+rNaVSYAzhqo6b
+IEL/Yt8RQbqcYhtHmesu5DIzKAlzzAZ+GF/EMuTOt99yj545UE/srnfz4mv
UfVsi/lV3uM50vIfcvg0qP541fmqGzcXH47WRRyh+MovvaE42/gKEhKTUXar
XLTHyV+vnh3EafbNRQtpAqzqz42xBizk9Q6mCM0SkJK0CT/V3YDpEtYnmVhK
r6FO349p9CJ5Vd6j/DWJYql1bYkNBgYXJL2vl5C4eub53xvOLESdTWKofk8i
lH5qnTUzBsfcyPZUvSlE/j1yXe/HF9gd0pQwTKP6nenoSUH2MHLCzc9sfCRR
/ofXddp/etGtK9R4f4BEdMdYrt9KM3YlaZm1/k1A9pPQN7Mh/RgJfnV56gOB
s9pFN4O7RlBGr1CZMSKgMresXnOhBzK/dWs/ekeAVvNLXrjZU0hlfJPx0YxE
qbzCotP4S/iqPJrJX+dg0cmTp6anFSruhe9ShElwnW9/qB1tAUSclB13Unqk
/9zH9m6E/muO33lKj9c2frHK9XuNhKBXoi6abCzGaFZ5+Zahff+LoUAnElOx
891rAn3I65TZHTtNwPTB6r7Zpk6IVW6EVdcRsE8IVnQpGICr5nxnqjGl15LE
ISP+bkznNtvTKB4W5VxpapP5kBGTtbt1icpHGT1Fel8Vqv7l3MFrQ70vniVv
F2/dR7TGgxR5SxJ5xn+FPJRvBTsyxsR6nkBkgie7xyQMLR6V6QOUXnhWz+/U
6evHL71i6apUP8hRiTGmpd2FmY8b8zHlb5KO0KkrkyPQIypdHcNICHIf8/9H
PA/kTau4ampd3tmo8lzLODR1G8SCRaYxkBSbUMBow/vfn8oaHKf0azq/PG7Z
DMOuXx3EWCROnF5R8DNmwL5eQ3LyHsVLlLR7slQvjifrP1UAF108x89xiA6s
uJtPl2YQVH61a8bjxnB5x1cOmS+4qDUpbbDQHMahudidR79wQBy01JnT6EMw
nfeOewkB2wD/gpFtFZjW8ogxoXgprfR0l1svRGqHooCFCYm+82rjpvvGELST
z6yB4sMsRvfTldNFyPxVNsr8LMVrLyecR7wWtoXeIeK+VP8e2RMnaVCB+Oav
D77xJGHn0/phRW0AgYeXtb+b40A0S87A0LoDIy2RzqL3STgK5RzwN61CaY1Y
17OrJBa1jvr8nt6No1VF54uuEhCst/2O16YB2wMvJydS+b9xKcRiVmUCdpL1
M4HHOMhR0Gji10sBQ7Nc0IOyV6v1xpWxMoRTTwScL+sTYDTUtb0p78Sk0do2
pb1U/XYMWVjvLUS62sLoPBVvoY5E8jS7Asz3c0eWqP/KZPCd+uInDJwT2bLd
rUnCvOHQetL1UQgcMJemDbNRt3HLReTbCbx/GbJXVHMK+7beaTvcZaLoHH3H
6STqP2D1l/yEJxPOP8WG+T4h8T/2lcIf
        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk4lVkcxy91M1nKlsYakuTSNGUZom+loZAtjMpEYUIzUsOEbC2UhqEa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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk81esWxhUhc9EW1T2KDxqQTkodetJEh9M1ddBtkFmZoiIVleFIMhV1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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk8VP0Xx6WUSIos7UoKiUSW9PhQSoQWSqVGi+x5RAptlDWFkhKJ9CCS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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81NkfxqXkkth+SJuyksbayn1TVE9NiiiJJbZJhSKEhC3tYkkKSUVL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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lWkfxnWylClhUg0mJ9GiZVQcZUxXUikTqbTZ0mQrSklNyKm8aBnJ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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lWkbPkWlxZIpSaVTyrQM05R8Pg1XGmRpIqmsdU6NmAihRYuQSGVL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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k8VA8blQpFkihKotCqBiX7kRKhCBVSSUJRpFIpkjZEUqiQJfSnVJIk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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81dkbvgxJkxbbNMhQqEEIpeLnoaFkaZFKQogsE8lgMKUrRDVjvYlp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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs0ldkfxlUqmhRGrl3ckmZokAqVx5RSqOQSIbnFKIoSuXVxSwphUoOK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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lVkft5VXKZKyRKSoMDMRE730pdRkRggjRWUfZUka1EiWEoVw6UaW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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k0lG0fFpEtqdCiRbK1I0mSS6K88laUiAiVLaVQaEFZUikSQlnKkgov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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8ldkfxyXhF2lKSfZBKVpkiSn5SAZTsrQMGaGohIxIxK2IJMmWNWtT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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk41Wkfxk/KMmXUlJESpSRNJktqkLqlEaXDiLI0lTXqVSlea4nKkiVR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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4Vekfl5Q9oiaVpMYakxKyNR+hLLllGiNrRAxNiy0pE1KGcittV8pW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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3lUTW0bxps0aERvpqQoUlRoMOS9QhFCSKVImjSpKET1lqQSpVAyJ0rz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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVns81FkfVuRTmzTaaFulqaTS+5ZsBrvqcWmjWNlSLosiobuX3CLEtGoT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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81Pkfx8X+VBOtUluOzREqR8lYm6iXjeyQHBlHmsparGRldZCQnKVD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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk41dkftsRUJBWFVJLMnaxRlNLbKGqIZBtMliRKQpQ7REpXhCyN5VqS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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4le8bR4omlVAho6yWEZXoI/FtfpHRQCkJla3MQqnsUpQtyUpIVkT2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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41dkbJ9ljbmZoIaIsSUYlTcIna9GkrGmZLJUr7ZaSQQgtP0qyJMuo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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk8lWkbFskySE1ZmlGWqCwx1dAXumw1GHEsLZM6DkVEODNUStYyVIPK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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk81ekXx5WS8gtJ1CS00IyUXTL4mGoklaWMZFKWGCNrRItCIgnRYokR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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwdmHk4VI/bxtFGqZBS2lQqWcqaJblJi0qSFEm2FKl8pUSFJDuhUBIK2YoW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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk4ldkfR2UnZQmjhrrZklREWT6SSMVYipJisrSomKxRihZFzC0NMZFK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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns4lGkbn0Qnaq0tX9RGErYt6YpI+JGS0zis84acKRraxKgUtbQJiygp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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lVkYF0ZKqwqpxtZiVKQiCj9RhjJ1QzNM0iUakWsNqbhDWsiUBhlF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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lH0fxaVET5FKIkuRlJKleiLk2CqVkFIKJcmWLBWpJKHwKElpkaQs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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lWkfxg9pIjIqUclW1qSQqbHUpaJMoeyKCkNkSTVSHaNshzDZk6hI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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk41WkbxxFlmYiMsfRKI6QpSfbSt8JkwlDTYIxkRMTYUr2hsWUiNBlL
i0ILDr0I2bIle0445+DYDs75/X6kLNEiZPL+5o/neq7nup7ree7v/Xzu7/1s
cQ845ikiJCR0gx7/znr/dfL8mizG0HL+jPoZCmU+28drYjvRmjo2/DiDhKjW
j2vfqI5Ac/7rp836AsRss3eWutiLsv99Fr7EIRBoMOMK6XpkMEvuuBlTEM2Z
6LQwLUd+dEgbby+Fd4GJow2nmpDFfc0ebaRQXKNDrnvdDVWPfPXmMQJCG483
5Y70QU3kut/uaj42CA7YpUzU4KtezqT8CxKXLBy8BRocfFk8UZk3TUDxxkNP
l9whXHGIKJwI5ENtJfnMpPxjeNyxs153hEJV6CcPX14exhjMF7FHKbjtXvOE
GmrH4mJkZWgVCc9lWZm7OS3YI2phebmOQnvSyIXBl80gUtMMt9P7S50Z5zUf
tkDcvbMyR4dCLfe+5JWpBhxIDDiu/IDEvqZD/mEuLAh87az2fiTxbvD9hKUE
E/IVlYMhkSTkj15rmknqQqyt2ZejLSS23dR5bh1dD9PsPQ+uyVA4UpoRLDHI
hQ7DlXirxcd7AyXRfIVByInd/H7nRRLTToqRI8dG4B59RjTEfQztU1vm2yb7
UdgSgPA2AqxdWYVvG2+jePUrKbVfKQSoLN0SpuOp3fVOPZmOd4OSSFEUqwtO
1hsda6wIkPpbWemtHIyqGKwmdFCIlLVoKtxxG1VPHQWXnSnoLugc//KmFV2V
yUVtPAJxx1xTpobYuOJyM9FYgoDVn3+Irbyqwdwce0DDkMK2ULW5hi+dINaL
n9+nSmKreSPznmg5bG6ZyEgeoBBue+k1V6QXse5eEwGhBIRtWAs6dRxMTIsn
qdoQcFK1Nx6VvI3Zx/cnpX0onJ3euvr0vxxwslz2mUUTUPGa9n58uBe8Z/fG
zBMJCDJNwqpYXBzOGalXOCmA26E+Sz7FQFHqpuhLfhRs6jlWKulVULTmnQym
1+61GQdbczgwVZqJuhhKginyZsJ1uRfxjep/zBkQyP1xdbX/Bw5m7e8WjC8S
mHOntTt24kX+vMQHBwKRcmWnYy0iYeFm2CF2kkJgzQ7BA3sODizvq/q1gsCn
4hz76phGxP3ptUvmMs2Xg7GqvFMB7L77Tb56PwW5YDl1bdkWPFrS3SEtSsHk
gYjv4EEWRI87a/u8IsDvutNhsK4Op2aOGq+5SUFHSFj8iHo/ro/vTvJTI3GP
x8qLk2EiXCpY4UQeifiD+Qm/OQ8hqsT0iq81HydUr93J72mCQ/FY3mQYCVbM
C0cRfS7+IHfVuSXysZywtPxDWwW80ryfintRsHpH5E+ufwihqvFPVjQvK2Vr
0iQS+vANN703lsWH7hOt4J7qXsxuVts9SZ+fuW1Lo//OJhTknn+pHkciu924
gEhpAM/Ip/s1rdfQZbWMbTyIxaOHt47bjMHY/c91rM3VkHbDaKkenQ8tM/+z
+9hYOLunQdmZANdCQmNmZBj3xDMuh4vw4fy5Ny2Xft+PqNS/zyTg1v4fQfie
BDTedpY6Ted70LjOnDBiY2fzkum5WBJbbNGVzOjG9qWOoJRQCh/EzlE948/x
cza79fQAia6HJTrH1NuwnRG833uZRFU5I8pPsxN6B4bs7jQSmI1ZWqNQxIEW
y1Ac8wIYO/B2dv3QjqbBI+YxbwloGu7Kko5ow2pQuopyFQXN6yqvst4XQs3P
KPSDO81nYNl3n8RqMCtvKTGnSoHlH1fkNcJCAT9pY74u7XfCbsy2ZjbKTkmb
/zREYDL+uvX00gv4u2fq+7jTfjA1YSxz8wXESvo15OwoLAxY8CzSuXDkadX0
uArwu+BqWvjzbuxjhuqL1pPQiiCCbAt6oaB9tuHQJgIbZtdorGj0QJnJrP5e
l4SZzbSfeOcQHEuuxfBdxlGl7Jx2eFst5P+p3fysmgQZHbg3KGcYNYIQzWER
Aokmey/GDzzH1IahtTEWFO2bvJBHv3ajyGDNcjyLhJDv7yzNLw2Il70/L/eY
ROr7Zyf8KSYCSitcNjqR8DYZWjH4ZQBv58WGb14QIE7y1OV3b3KwX+Vkv74H
hU15dtpDdL2ZC09+Vn4pgI3Fq/HtoR1wWrXdNO9IQmV05pDUkWG06BaEu92i
+ZiVlYlW4GDvvPOjiHgBolWC3HTCOCiu2Mk0GRKglZQ/+zOnDz+uWyxbX0Pg
kWns6Lm+Dmjfi8vKFaH9PX7aij9Wi4ytDoW3xkmcsUyckkiuR1zQas6/vG/f
zyrJOj0Iaz3FU7J6fLBGVzVdFRmQNHiWN0L3h4EZ/1veCgOY2xx5m1jmw6Co
REp4fTemLK2o87Rfs+aaBzNFW/Dx71H7D34kXvp4+LKZffiF6MkrVCNwYTHY
J/pkDwbCYo0iXUmcZKzfoyx2FR1WLa4hNL96LQyvn+aqodha7SWdRMEhp1Fi
QLUS9f7/XG+j/TN0tD5Dbm4Qn2cm49lbKPxuIL9oktyPKAV/eyVTAgc/515p
u9ICajzqpSetJ7VZNVmpoBu1bGddJTMSLuek6zzlO+D5dJkfFELff9xWklpl
44FH9YzZUxJ3zWOVrAo7Ed3saZswQPfXbrugjD35iEpcZ6VP18+G72/IRGzk
4ZPBNkOHbAEUV8TvVjzrwpOUydv2Xwiosd/XuZQlo8DZIKyJ1uP9rfXVE1LP
sVU5Iq+DrkeGbfp4ggIP8aez2cLX+Ei99FqZs7YT3fm209/8TaEvXFvm6ld9
iDM6//chmjfvjwEemVQvyruyxYYPkOA5LBny+rqx0M9us7QiMTAQ4hgpVYFM
zb5ZaTq+03clr5V/y0WaCKV4UVaAgoDy386VsbBQ9UDX9jDNo/tfOY+D2SjP
Y621HSawtDdpdi6FCcdSk+L4Ofq/QmkXM6baUBoharZQSfOd0pCTbseGUYGe
dLomgTwN+RXdM13wLcNfMRIkkjyudweS7RgOG3M3pv8HxVzue7lDXOzgNZSe
+IcPj5jmzGyrPjDOs9cayZKQ9vm4/PBDM6KPZgnqUykUSv7Mu2HdBxvuhWcV
lgJ0MIRX+F0slBxW/e6vJyT+D6VkyqU=
        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4VekXPpUMJ1GSJqMyRbkkozIl6lUjMUWRrirKtdxLblGSW6KEhNwi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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c4lf8fxpFRklUJJaOoREmhvuKOJF+VlVBfmmQklFXJCMkKWQlJUiRl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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVns4VWkfValcIiE0JpcioppS+iK1kJKKitzJ5aMpE4VEUoPJZVQouUWR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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs4ldkbPbnUiAk1jhAdGpcudBqX1GBVSkKK1GkkZBRObl3QNCrTFZVo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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk41fkb1WIyRTEibUKypsXWTExHNUrIiGpUv0oIqSktCkm3IlsjhBRl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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k0lO8bxhFtFG3KUrRZKiIlJJdKSNZSJBH5SqQkSpGUkiWyFkqJ7GSX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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx2+SNMky4deobKUSbpKUrY9IKEqrVIYWStOkXxOjn90gNUO6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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs41NkfnrVKG7XKtWJL7U40UYrKJa/kkqgkG7qxyNpY9CuZctsuKAqp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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4VekblS5IxUT1U4QyimZQ0U+JpWhSSSIqESMSijNShEo3B4MZl6jo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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8lN0bxilvaZMkqWRL2mRpI6nLnurNEiolhEq9WYooES2ECJEolShb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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81HkXxz2upbIjcqlIKiSLtpQsfWgVSRuJTWHlLhQ1idVjU2rto31S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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk8lWkbPhVROUYxkt2xfKQaTbYiF9qMpU/IZJSdtOEzvoqhpAalhEIp
SyJlPVpGDrInuznH4djPOe+L0xilGInS935/PL/nd//xPPd9X9d135eGT7CT
/0oajZZGnf/fPK0He6bsWuCuLt4+vYPEsJX4nHFbK8SkVyUuPyQQLJ16eH5j
F+xLNpjYHidx3SSBnnn0DfRmVz68NylE0kzTOvb9GqRYjCmRxQREXaGmXtnV
SNyaoaZsRULSITxSebgLBnMxi0NPheCdfdIaG9oGj51j5az3BOzrn65t7OxF
xjZWFSNGABFnf9DvB/ogypDOXLYTonBisOBBJwcabsobpI4KwV+9/s4BqRwo
s8wK//Ym4VgtNu9Ay8fgYb2IOz9T9cksfItlslGsuJAszxdgoUP84PXodvwa
7f5fmXQCTa7DtefFmqF+ctz6qjMJU49wVtTZIaQsdmR5lo/h9l9cj+q0Xnzy
OlFiaU1As4Axs1PYiy/nbkQVHx1HX7XMJu/hXhS67lfKsxci0Cf02e1MDtTk
PwvjlQn0z0ywGt8NodpLsn+oWYiestJJi9f1WO+XJTcSQKKUKMvJLhjEOSNL
+cBIAvTSIN3G8j7IzYpMhZoE/u4JKLPL7EfdhLBV+74QojBjjxveHTD6d+l3
0nok+Kd9rQZUkvFWMlvu0zESmxquHCt27oHm+vYP3HdU3F6j3326ERY/jqdL
8gjkSNTpRfQ/Qik7nKVL4SMd/qhou/WfeGWieeQ7YwI2FkrrFjTyEWJ4mcf0
ofAY/89XxSIWnt2O3TuaTCIqOs/1XToX6in7Jm33jcM6yKrVoKUTNQExPvFM
Ahllnz5GZ3OwJHFQk7lLCEkNkU2ECRvdK+6EfO4g8deGf47WF/VhwKvGSjAt
BMNoMelkIRefJ3fOmiYIcU1gpFOXw4WfIHTFTLIAvaFmSxzxXJyPe8Z/6Eai
rr+okPGiBOYqH0ZUTEkwFjwrpG36EShZ9/fJxwJsnDyhN/OgDf73zSVqhwk8
T7Uu5SuxgbkPfp6VVH3jUj4F0m/wQ3lJvj0Vh2R5/aXQ1YcL+5rajnApfvS/
jg+UDMCxYjjTLVUAWs3bke0J97Hq+BUB15OE5aH0eZiz8WencEGHRSCGnKqN
4/bDTvGLmOoJ6n22o2fM1kFUmcWuXZQYg0IetD+EDKH7SP7Xg9Z8zCyNil7j
MbRWLDDplF6Z+XztlrddcF0hvkGG0o9M7P7GCtt+mAdnMuceE+gI3atAj27B
3qAsWb4r1f9hC/t181chnyim2u1OIiB0Y6rSmwcwdOAsXqT4HIto5uZV9uD2
8Can9H0kTvk3nJHzbkWTNtelj5o/WsnL88e3eaFNyyPciOrnYL6MXajYIEwt
6C+uHefD5fTDonlhG87UBDZW0AmsdtDSMNceQruNwP3yHhKvJjQT1e9yEO8k
u2y8i0T+8M2Pqm95uCD++LrJCwJC5y8sFeUeGGzT13zMFGJl1DcxDXo7FMWm
3nwYJRD9g4XW5uAwkAqOZuMeJDry8ho0s1vx5kPkL5GrCEjOJtP3SNTDqSLX
44oCCTkZmoRqMw/tFYbGK54IwJZd6OY4jWBniyhSpMGH4aqRqzS3Xtxfqy27
43shcuQGeXX3BjH1e4NtfRkBy7MXdjc/GMDT90vL24wECOxg6rEVuIgsrzTT
mBMgLXsgc1ilG1ceSdgaryTwbirhgJYbDz/ssjImBgRwmTeNG0IrXlbxbkzL
EljTvsYnIp2HgKmoDNNwAsxcfYZ8dhMiqtpoMfMEnPy1LjbcZmNRaetn4V0B
hL1xnQ8n++B3j08/4cKHfdC7a6fuN+Hu5dhbP9ZSeNxjlE2a/wbVtCoXW4qP
s7pBBspRvTgg714hIyfELz7lZPhULyZO5O51uslHTuum0ZNJBYi9luas6Esi
D01bgvv7cEumgG7K5OPxOcvZ8VtM7IHjrw22JLR0tEeK/FrBKH94yUWWxHPV
/TadEhxouXFMIvQISGXtVmCefI25lJsZUdsJVCWlJJ17xcW3RV+pjD1CWPP8
h09v7sCnR0+ftopR+UJiNMN21KDLiOZcwaDm4ZmH+PKBAXioGX5H/0iA45JV
Qr7n4GV+wCfbAgFijMyv1bYNQnmVisIhpzGEHQlKuBBegczNm1ZqgkQS/dXP
7G42Gj/6OLB+FaBrLbniVj2Vv+Lu2JI0AZdgkY0+tU9G1BTl7Ck9PPXbsBhz
mot3OmdMlioFqCsMVjlx4y50dr50OE/pydRXyv7oUg2eFYguaSuSmDBj/bE9
rBOJfof28FaRCDk2/L1aSgc8OREVy4UkvhScMtfb0AxGPG/3gzoCrgUT4dPH
ueAFT4+dOUTgXEKGw6h/HaLsJWRUo0mcT2ve/i9uD3T8rQJjLUh0GtctVyT1
IVG+4HL3WgI+hs3KT7SeY/TqNjfnUxTebZlbF/W5UPl9xH/6uACSjKxa35Q6
hC+8ybSLJRHmrvZbiy8HMUcs89JFAtypXZdN2vXB2jl3+rfDJLy3fBQxzPsR
ff7m0rIdpf8nIcvpx5pxa8ZKszmOxJYLYj+tCXsBxZmpoVJzEup9NdvvzbLg
3dOTFEj5cwxt7m7k4SbMqosGleYIOM4Vp1zAC6hPZ+o5UXrTXcPIKX/bA9eh
TddbBEIohO3z6TccgRwpqypZM4Kmt+NmvLheSMpeVC7mCvA8e/lGZXM3zkbp
XnbsJtCQ5Hl1dQQbFlKs8tQuAezlJ1PV7OvRHlOs8ZlG+ZNsbqbC7jLErubJ
0YxIVP7UYD66rReBqSe3rvmF2mdF4e8jbnViKsSiupjyx/gnufIBDvXQlK8s
3WJJIl6/xUk1rRY8eadyJXESk670mcwjPYj2O7S3dZHqx3f9RkZZIaISlUM3
U/vPYPTUjKUlG+8v5eldNyMga1yyI3mqD1++Xto1RPG398tC8gLl/1Wf2Qmj
cgSKD868nvmeiy1hGqMX/xHAa6XO9Fnne2CaHbDJp/zZYHbtQn5oBwzsjQRx
1LzqerSS8RLUfwluvM2HhPCq/mpyWDcd2ksdNZqUPxF//HM9R58DSdGO2Y9f
qflK6LD1LmtH8Uv3vIw/hfgfUm68ZQ==
        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns41VkbPYO+oWFKNySFzEwoRCOTzBIzZlCmTE36RO5FFEOSpNuIKFI0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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8lO3/xSWl4pFSUkkIxbfFEhVyhLR5bEnxiAipJJQ1ClkjZY0WSZGy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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41Gkbx6USrUOsNGqTSg6bJq8kHfhqtI5JDkVyikWRrEOlSMoWYkO6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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs8lOkbxqcDpibksJvNIWo7aAm7lB/VNRSinHMKNTmVHIYmlCjRiUiJ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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4lVkfVYlMSBQiZaYp3YgMRWXJCI/5KBUp5JprqZGKSJQaZuQePiSF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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lf0bxxUhCZV6RAolVORRRkkfq6IQJSmKkFURT6FCaFmJIgqFlEJW
RPbIXucY51gZ59znoCEyUtbv/v3lr9vrfK/rM96XpI3riYvLOTg4zi/j4Pj/
X9rcaZaATCsavcUz0rTYCNY7MGjlWIwDK4Ty5y4QGHEy3xxZSUFPuPuvaQYT
wQksmdm0FgSMW51hTrFh/C53tVxnGw4FbEndZDSMrKg7MbNT7/BWyFHtLPm9
RNlw13wsHeO6SqMX5BlQfFHj8cCXgotsBRv9HWz80tAqdpCtwufOs/uVFAgk
B41Z5mV3YBvtzITHuhEs2v5uc/pNQ5jsGrVSUwbU/IczNZ06sLRQpZ/oPoKC
76ut6A3dEAmb89mv34PVEeKv4vhoON9jNpPvQWDxQ9nx4jNtyLek/rlxgIFZ
uZSB7Wp0VE7b6/7wZUBkvQp3I4V8r7DREu96FmD6wznxEAV5IofGHomyYRMb
7HlwoBNSq+j9DfODsNOl6qhJl4PBmJjm0SZw0ir5Y6FRJ9z+yIRMB7DgMfTm
k8IoHecNVC4H7h7GWx8Rw/ANuZC1zSmfpjJhasS1rmxvPmZFzyh/8yQgUngg
yMKMir3PZ5XCn7Px2TXix5ekFjj/NXPZ+57AXukbi7ZK7Wi58JWX4wQLQuEG
DhTzVDx1Lp1vPE3AUn3JI5+7HYl3iT1vCAYIKYU1xn/LYc9507g2iIB1/fKn
m7c0wyLUOc3gOwOrpt8lXDbth6fe/f0RgXW4p6d/pS6EDsKXcebxvSFc3b6Q
YnowFS37Jq24cghcO+i6dLa+CvxrdjZ8+Umg/MxP68WYGHSvOHPM5jKBef/l
8u4OdbhQsqukIZqF3RMFR5s0cmH+oeHP7xICmj1tYgfOl+DoL4kJxkkCtVwu
GpfWUrG1/+VV1U3DcJS5cj7oQRXcN2W2smMJDJbzMYOXOrDLzfrKtyMEwlYa
Hk+Jp0JCrLDlXCkBRe/+RNOMYnz3VeEceE2g6adzkOxgE7Jv8Xo8ySTnObQ7
5KxmAwROO8wSlQxwLHZHvvP7hO13M8U9WQTO/LPE1gipgcKvDXAWZIGSmXCr
rDQPHGsr86LsCVAoB3YsLRVjrK8izayYifCrbX837ynHfKPspioeFtKdZXK6
s1vB23ZnTOY/JhRvrFQw4m5EroNeustaAn5HVY/6TWfBJ+dHVMkAE+VMfavq
5xno0qEHpjgQGBfU/LEyyws2y/YJLJ0nwFGsaPj++SdcvL4k8K2dwNAA/YFD
PQ07NjOdPO4NgDvVfW/SDzqqDqXVFB5k4dzXsUG+qCKEU05W+9cSsJhf4JPr
a4J5WPTvWFIfM/5aHtFjNWBRop++0CPnpcUr1dP+AsJuWWOENfm+QJ0fTxxy
sShjr5R5idRXvyV/0alMzPLPhj05QOrlsfaA26NYmE92eLiS/lFOK+26zaBD
iUdGIi96GKVbJJsHX3RB6tVWarHpMHqOJT9Yd5UG1QD1+VKxIeRek120mWkG
Tbkgs3aKBbV1BXtcr1Tg3sdumvs2ApP5nTHf8pux/lZ49tFeFrx5wx7++VMG
5dkbCviHBfuqju3aIW3Yv0E8Tp1vGOMfWM2F3xNhLO/WqGJOAF+kTor6UPBk
Q06AvzoTH0fFlZM0+hA2GJNkfuQL4u/mhu70bQJlMmDNNjM2TE0j7aIciyCx
VUJhGY2Jhg6Zr/lreuDONR8YOcaGygvB7aJeraijf1jFlmPCQClyP9FJwZL0
xOifdQQc/wZtzGvKQ/GdhqksfQJqhu6F0dwf8WSkXub5V3Kf4ed2iRo3IMA6
pOgfHjJfZHeKT5VQoWvwVHarORMW9cuyX7xtgd18ceU94RGMUz9zf+YqRcXX
088O3WJCUE8t0eRgN1p+fzzr9oTAmx1yx4YDKDB7rxm2h9yXgePdhed2VISp
TzTKF7IRKcjhNyvSjrHTrLa9pB8lyyfMR/RbcTNM8fqfuCFkVSu47XTLQciF
I1qpJgRo8fePD73sRvtu+rLTd0bw4n7W+uV0OrbNNXkFy45iQopvjZ5YKe7L
pin1kvl7/23NLUk5OlJfVt47SmUhQYsnhj6XhuASmQ3zhgS2vTptGHS8HC78
15pu8bPg9X5Swrc/B2ZvtZTfLDDR1EUT8cquh0r3xoA4bSZiP4QdvPS0D8lS
irwRG4fg+Esr+e/7ElTWi5juLmAhUtlvK89QHszpy8dy4pgYv/dcIOxFC3b0
t0tmVhCY3b32Z9yjEmhI2HG6mhL4PjOyn6nWirg+zXVFGQRKhC5eXZ1fj52a
7AiVF4PYNZCYoxFMQQF0Vz28wsZer61tNdbNMB3bFJxKfp8QUGBze6oQX/e+
epjhRMCustbJNrYLzjvUhb2bGLDXmo3m1M6GduxO5XeiZP6NWsv5XuiEWFBj
zZgpG3XKzpKzGo0o2nWhWp3cX7mlRGttRA60z6/auOIcARneUEphcA3CjgZm
OaQw0PvvbtXvVnR4nOfasiVvCL8nu1TG5nvgdzlE5+1TBsqddt5WC78DITVF
th/5vcTObCfD3kr8LqcLu/1ggSPvUWk9LRKbVq6ILrMkwL7v8/aUewPGPONf
epP5IuzlKrDicQMCLz0Z6klhovKkXYBVeieoKSKhp+4PoOceJ3PVyy7wO2QY
z18bguapB1I10mQ/PTxmMGdP9pXjT3E5Sg4M6t0rXMh9PvVT1pGf70BLrEbF
Ba4R5FCE+woD6Wi1DHyaHTSIAsOA+iPUathkTK7W0GdBNi3/9+SDVixnrrPJ
mWZCV1ekaseHctjwfbw5XU2gYFoxfbi/GG+zb+yM2Ez2gUGtnpRtApKUvJoe
qpH5w2k7nH+rCmYs483yHOQ+XJJ/3IrtwBT/rqvyuQRuup+IMwrtgMGXY2K7
/xtC4MTRF4LaRVAc7ov3TibQId0UdkWagj7qjVhJaRaKmpIijTM+4920yb2W
jQQeMp7GXf7VjoRDkd9z/2Fgc5pJZIpCGwQ5OZ/5r2eCY/qWbOmnJsi/LNdZ
4UXq/XvjrfGIevhZZkcVuZF+dJS1/qpch5GEBsmUPMb/35URMJ6HN5dqeU49
IpC1qbkxPKwIt0eMhk8/JlB6XKf4BqsCKedV5nVJPjDY1tiwK5sCl5HH9A2V
bJTbPlp8uuozmoT23ool+/C3kRKn1/VmvEg71YvaIXz7qPBm0roTURytGxQ2
DaH460OKz00qAoo2TujvY0Hu7YsH+7b2oFir5telgRFkPMw/8DGUhn+ppjmn
ekchu1zKOKi1Anct7uZOuhMQ5qlwLNxExY7kEZuGLQTSO1YeZg9SEPb7QeML
c1J/qZ3OwQsU8HmYcocJMTCl3SK57P1n9LVLfY3QYiKhM5qdqfoRXica9xiS
fgnM2OvnepfkFzdNn4RyMi8n5MMlcml4UxKXE/6d1GtrzYwAtQhCjldT+HaQ
fc47PxK0vwFCR+I+M++R/TJQlLo/7hEOWNZ+fUrm+fnQx6t9pzqx+mUor6cu
AwVm5o82rMxFZGWoj9xOsr/WDAWskqRgvdenuutk33Zeow1ZC9ahWEh2RmeS
7NvLvT5CroXYz1gx8+AmgUvO8vy2URQ4ZW+ZDuxj4+wXadGjUaSeNblSeIRZ
yP00+trqXANa2ovbR5XJ/VZwWwTtq4f/1DXGvyksTMQO8Tv5dQMGGTaikww4
PiyetOCtg9/4m3DhPpJ/+tRd1q3uhI1iPF8O6ZdAYW+lqmsleLjnsIjHv6R/
L29+H5IfhfPdmaeryX5/neZivLyrH0Yqpz6KkvMLL7q0ttm9Gn94ltlx6zNB
jIyKB4Zmwb0kd8VHIQJ1Dq4rxduK0BlbwJA4wILBmyWTVacoaLs9TqNeI/uo
Zv3a2921kPDf/crLmQ3PRC3TvqUK8P58kitK9sfoDas4R782HBRNP9B3axjW
jmLnCle2wvd07PjvmiF82XtBTFSyFkWS69K2RRDY2XfHGF0U7PcZP8IXQvKD
/M8jI/GtMPjcfL0jaRCDe742is22QDDBrf19KANvn6hdZuxqg1qzcf0HsUHE
yD1dtDmYjSYx4h7I3++ofNP/ZkwnnC4+OFOUSuDX9RTbc2s60CV81smaZxBC
SbqL1XNFsHQ2SbNVJMDLKX/F6kYjDiqv37jn2TACq3Nd1/PUo+6h94w4ya9Z
1HKlLnsqBu0437StI3li7k+vlXQtVtQMpVc9ZkJtcvvNxOoGDCjciVYzY+HO
29FL1kc/Q21V0LJWEybi61w3Ol2jQrKvoorgZ2Ib9byApRIF0fofAobSGeiZ
OWUntZyGzdZn+E71MpD0X0mt9TYKFOlVS9/Je+ewjy6Xh2wduAd+17UVkf7I
syjbYV2LuxesY0x0mZhbOFZ84mc7Vsuc25Ju1I/wL1cbdBdzMD/1jVedzHNN
iczntEIapqWPuOf9y4D5op8rj2UzNkjEXPi1gok9366zO2+1YZdG/F2pAjYS
xtJ3FxS/hNfBE8X5t0m99UTpf4iOQkFns8iJ/+eRhZJ/VkkbpNxH3co4WTCz
aM//1tiIVDmPARuSR6yjKIJu5ztwdcY6XDqanF8fL62J/hpdvOFRqgdJfpHl
DznwoRT9nQvDLt4EXL5ZGe6KoEHOvkrNO4MNs6FG87G6NtDe3whY7czAePN9
dfOOBETG5039sSHgdTmEIyutF5mKxjEiD7uxprpOetD2MyQn+i3OHiX/X9Jv
5fvBDXDdXia6ch+ByKBSwz2uNUjoV5i/o8xEqrRyjph7Nwqkg59p1w9CU7tt
derVOkgrxbw6R/Ko5ffL0Q4i/WAkDR9ONmmDF/vLmQEa6VdvFQvFfiYkSwQX
BIS6wZTw2xglyUaTWd3W4xwUfL+49fjzxyzoBd5+3birEuPXzMO2urDg0/jB
WrmJBoNVXIyU6lFovzrt7by9G7u497lYXiT7O0N4yTfkGaLKss8ccCb9MKUd
NnW4GRL9ib39HkOQODmzmFBSANvElTUSk0wcqAjZ8aeiD0LNWi6KYTToXdeo
dqNlobg34sYs6T87idrpEx+aUVKj+2+JIQN+MfWd6fG2UOMxuSpsRebvyUr9
7bxFCNzz+bT/XgJ3TW6kqi2Uw/LYs8xid1LP2a8E9igkw6791y8ayW/PTT0d
1O1pcK6S+TFN+v9j4nv3H6U05AhEl086DIHj1yVToXvdKL8gXx/hwUKyAt1F
cK4Ls8K1trk63fA6xug/t7EVhrtPTgl+I/t2dOlP8UQr9h9aTy0LHoZm9jTH
Z9GPSBmc+HsymMCW4QiX60JdKK/hr9a8Nopx/q8ynIGN+N5br7R7lIVilV/7
nsklYu1NXYakMblvnWtCd0apMDrqkjMqxgZHLa/N9BFrsJ/e3GpHvvfg5rpv
5dxUbNN5zNMTyYDumqs7pkTjYdp7aXOQC6kP1zm51QkNmBGTDD9UxcbbWfUS
s8VPqAtfENUmeX39evba9jYq7KuDiPWjQ5i9ONd2nk4BvaSZf5PcEPYubH+f
bU/B+VyZe7zkPdisQ7l3I6EH3/WKhrk5R6ByPHXbvHgFtHeo6X/RYSGjxWPm
ZTEF3SzTNyvcyPtNyVzRTK8D7d70tQtnSV7Uj93/SrAVApM18s0xDHirrlJq
nW7CwBYLzhkKAyJVxhllFrlIlxXP9lQloOelqC0TVwrVYhuRsAICb2c0eNwv
V0GJskV6xpSJ+fvxqkeOleCNoN8/LWQ+Kjh2P3cuaEfX03SeP/Ekf/1o4juW
9gGfmidvFf1iYu2Q+cu786/x6uZAyYPrBNoPKsdv5CtFcMSouUkUE9YCbjdU
v5ajaWQxzVCeQIONpPaG9BLMxP624uFiYb5p7Yp5uQ6oiL9efTuUBbbPObGt
XzrQcO19r58NC5pDDqr6sd04+23ItJbUu4TKQfsr5xrhfS29iT+d5KFvx37M
d9lgmRvz5ANyf5TDapOxq9/BvaBjTX4SgRH/Ozxd0XXIihE3WuZF5rvOf9Et
gvV4l6Lm99KViUiPikveR7qAU8erCm2GIVBVOaUk0kxyeHbD1CMW7iYHpQz0
tOPxubISOSYTStaUGl77ejzPO5Bou5sFIbqhR/tSF9p+nR2cI++nSzIOGQLx
A7C4WaHBB9Kvnw2tgrIo2F6QmN0sw4BHRA/n4T1tCELO4+c3R1AVzvqQ9t8A
ohIkpbtI/tF8psKjwKDioJUdo2wzG4IFOny6ye3gMv/70j50GLXSDKd1qp0Q
pIjXW5H+kJXu6vJ0LEH2YRM+I5JPCs0THFPuUHHiiZYnJZsAv16m0VnfWkx5
6Ux81GRiplBtSjKmFbP1TXvPjTGgZiIBca06mP9zxtcjlLxfJNw65rprYOwv
/TaV5FNFFe/0qtfJqD6+1taXzPPw380qzOdFMO70va5B8uDmiGHParRB1Omq
LVcEA8Kt40tyg6W4ct26liJJ7u/S8gscKpVwmr+7XcSZiWHR/n/pXO3oKOaj
H/JlYZNfWsVDShJ+0P9W3SH5Q/vETyPKiXY4j++O3/ONAQOTDWY++W1gUjs2
/TUi4L2rPM/nQT2efHFw+DFJ5smuFL4TqumQ3yUllEzqoyt8nfIJsXdQUH9Z
dYPss67KENfv0oWIkJ+Zqowi9R90Skb9fS8sxptDpUj96XqnjMfJUsEXLcId
FT9M3i8Cd3QUsxG2MlsrfD+BpJ/b/qsLoqDHKcLEs4yF0L1XjdULaNhwXeFa
3RS5zzfi+19foSNJOT1iyb8fnlzyXe9s6yGRIvtlIZuNkVSP7Z45tQiUKe5m
FTExu9AmamdYDat/Uv84dBBI9ToWfE/+MwZnKntfhTMR/rppwiexCbnL7RpG
Zsj5lcip+t8tgF7GQ8JHiQDX3Fh4j2gDjqVOZ9MZDAzdd2vpv1kLDjm9y2sm
GMi67Csguvk11FaGjH0i58VwnJ1fOE3yROZje9omNvy45QdM7Lxxf7i5cR05
n/LNzWENfRWwfN98dlGWhXGbVXus7mTAwKZztoW8531Pmhdm/6VDeYz7cm8N
yVfjZSa+qnQ4isVVVjEZ8PKpzxmQL0LHX48tbuR92Wd9SNeBKx+eIxGjI5vI
e1T79tJ2lKN0TvThUXUyb5wM0o38qDDU7QjuIu8vOxsX5aeW7eD7+b5BI2UQ
/wOGeid1
        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlns8lOkbxoe0TkuOKYki2pWi0abD5JrVoBxaOR/bYWWw2ayUVkklRCy7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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs4lOkbnmIL1aYtrZIkVErlVD8V3U6L2iZyig5DJHLIoSi1CWnZRLJY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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8llkbNkKWShMT6ctHw1AYS8lk6VJTtmRsUzLIWgpZohJJCU3ZQpHI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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwdmHc8Vv//xmVmVlbKzKiUUEm0roSWCFFoWCWprJQRFZERZVX4lBCVEhGS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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs41GkbRio+OiqsKFskSsmWSNtNckxboSS0JSRy1nFpK5MtZNEi1FSi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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns4lVkbxn1IKgyF0ZCcNU41JUnlFiaFZCvFDimUUEaZGTNTQoRyLBWJ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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx4lCCSOkqJEZWysx1a/iU6FSVIpRI9mNrciWBilJC2YwsoVp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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k4VY/XlaR+UiRJSoYoSmkwJVqmSlKJlJQhY0pRxjKLQpIozYMxhCQR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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81Wkbxk/yTou8kWQtyyA1o5QlEVcZRcaQIhRNCQmTZqKxzbFHRSn7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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs8lOkbxqeSEOVQoUUpRYkiQ6S5Jlq0WaesVYmIXzmsU8ihNNvJFpUs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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns4ldkXx1VDaijXRvNjMHMooWmGSoWvoShScptRoeQ2iFMUIppEIUVy
GTQoUYqkQjTRceQSp5PjuOYS+5Vy11QyLr89f7zP++znffZae33X+n72q+ri
Z+22WEREJJk+/72vbk3lxEo3gW1hkxV7g6A8pKHtgSwHNm9uZZZEEvQYcBN/
MerBmNj57EOVDBQ6Yk45JDxC0I8qeqs9CM5xFyT35jZArStUQiGfYFXBauXr
PkXoQ12ywhEC9j9vd2qa34aU3Dp1OReC4tItNo/bhDAKL0zrX8vAKSMpq8bk
Ob5bJhRsTiD4qqv+b0ntemS34EDIXwThNYNKK3cJ8bOHeMtlFQbpK0PqmaFm
+CQN2p2spfF9+gP+Un4K9j4ZG/ZxAq6/xlB5lgCsPDUP6RECtyTbCnf5Dszq
8DoGLRik6pinzgXz8I/EgHdoDkFzSX+92oVmpJl8uvkPn0BEqXtaxDkSYTuN
uyydCXRlU6o63V4i92rt7rhygviYwf/JPasHEz2lMpdMcJHHGXff2Yq1qlo/
X17KgKWVor2l4iWe606mcYoJJiRrAv4sz4LMHf7ms4cICpcPKT2ZKIbelI+C
jhtd99mwPx7gwpm3PurxWQJTOXttYa4Qe8UCRacNGHz1xquIZd8AFtFUi08k
YF2pk8kO7oJ7jd3M8HEGr69YJXyOa4W49nlRZoYgYMPURmOGg232i4PHTxGE
edpkK8e3wvfXktSlagwk3qbljbi1YbN04OlZdwYN38tsNLjZguXP5prHljFQ
4ey7q9HKQ5Bz36GbRQSeN+95J2i3IqAv7MR2SwZGtVvFZF3LULvr3xnh7wSG
jb9m7YzuQszgaVMDKwa2ro2F5R316FhnqxucQrB+kdmZiNYXKJ8y+jclg0Cx
a+fYrMI1qm9NwwLVd/rBgN63JhXY3LD8s8VRgsHs04zLu1dUJ97u7haCU921
9/aocKCYMnQi05egP1ROSsBqw4q+UrteIdXDdPyIZ2EdKiUEl45dJEj/oJg3
1NmFxuO1043+DKTY88LgFwUoM5Q88hedx6HQC9oW90sQOi960ITO726eeuuZ
67XwtS6vtKbznlp5+I/fjB+iPux7u3b6fUh3uNOr4Cm4Ob6f9vvRfspWDy6R
uY7ipsM74mk/Za7LLNuSwodeyIjk8xoCldqIZQM+Hdiu06O6RIdBj7NT4daz
tWBvsNgcQvVQKh6zvmjNh9WGY4XDZbR+y2DxV7MtkLj804dMBQYV4UoyvUpC
3DDJv37yOwZWgz9rleg/hM/aOwVu7gRlea+1rSJzsSkgqunAYeo/k6H0OoV6
yFvumVi4REBm3ZfILH4F8wT7/01UE7Rn8NQzDfiQtEvwr64iKNquKyrml48/
3musMKV+TE4Nc81zaAFbbVbu3GIG+dpRpfypV7AxXVnT+IXqsy+37HfNbvhm
flaKe8egJYJ9o4ktgHKOV8jefoI65bgDPp1NeGZ91UtI/Vqn2Bv1Tp6Pe0j5
ZpjmU9ml0fNRthwND7WrdL0IzjzKzRteHI6egloXI9r/tTdd50fMK6A7a/3S
w4cgKKBusmx/LULzbwXsov4qOhpyewfhwUxMnnue1pelF189lZ+HabsPc3to
/YeWBk5P2bwCS/m9+OdcgtdJKmqOazj4Tbu5iUPnRW//lxKpGSH4/JZf3LYz
mGYfUG06loZQvwdzvTS/5hZNhVB1Drbb9zZmBtD4dkpVjWseYUpjfF807X/5
aE2UaQgfZ387G5lI43NZuuZz7+qw7jjPWz6VwGrhZCfbvxByGvrfelI9J9rC
e9j25XCYahMh3vQ8J5q91g+VwjcyfeUNGm9v4gOJXvnXmFkgYWYPGbxbM6PT
dqcBYYuWiFok0fmer7D33d2K1Lix2V6G4MK1JxdVJTvQvMLISsWQQUDsosc2
j1/hYE3cD8H1BD713upeTl0Yl2Ot6/+TQeMDwejKUS5m7p4VGIQT5CYGM4Zr
hRBqDaxsIAQf7KNHKj+3w/7Lbdl+G8or5+I3kasFuGvgalT0lkBqlXaMfzUH
3EWlt/aeoTz8UbEwsrkRklzLbT6XCe5Fz/hs+ViFvoFPDolUL1sLq8necD50
dfzMxUtpP2MKBiMK2pBxzeXu3y4M9Hzi3I8cbsfdT76peykfskaXzZoe+ANf
aR18bkL1PzO0aCQn7yQaJr5x2kLXQWIn37A+l8LMLLqpl/LFc8yG/9i4GrE5
yprSYZQPWUfT86aaETPflSLaRvXmRdT5H0pEVWek4xW6P6qx6naUmRBPm4M3
nZ8nyD5+5BRj0oDXa7c5aqXTfIxHzfPQbHRs2ig4Tf0r9dHhmdyyBviOFojn
ZBIsvTMokp7ZCoeftk4myTAI0thoX9opxHXvY0dPzRJwTky3T8u0IfnNvZok
yvugw+sP2u6rRn/thFUm5e22j4+mXBbzUZkg+nSIzn+Qfs+X5VwerllP3tga
T/PfP7TIJ1CAo0XSxU5U7yfWmxf611Rj/F/9CMtgyh/Pko7V0s8QVWmwEEzX
nuEHNZu1+cjwfQMbDsH7F449pq4duPSkuNxWkYF8qrwfZxP174hU7rUpglaj
4W/0mztw4W2FRjrVP+27q1X6qnzMBwY+aHxI77MISX7JxAsYsrYFltL71nuJ
7NcvdzfhjvqIsgetf8i5aXKhshPR0mIFo2kM7AXy8WWJdP+5mdOOTwkEQYWB
kwH1aL1sXn2Q8lwuLm91+UItvnW3EArOE0hY7pI2Te6GDZelzz7HoCBo4O8M
iddYfsLqUxiXgdat90etVQTYYWYkk0/ryRIGPjZd8hTmRsb3m6n//UQ+SrWJ
NyKDF16XTXni+kOytf8qAaYi1cJtuwnMeseZ4K9b0WKVc1hjP4PdO/YtpG2s
Qqsq6ydbfwJxJ4duR2UucvuWth+h87+jqD3Ww40PxU0hw78KCNZZR+k3jfPx
Q/j7Da6F1J+ejyZiYwXYZLjq4sR9AiguN35i9QTTt0sM91DeV5jleP3Ja4K6
1MBN02z6v+DSEH+ph49847GKFU0EG12vnLwxyofS12mKof/xzukdK2YuH1ni
s22OlAf/B6+p04s=
        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3lYjN8bxlPKtz190x5FKCUhFF/utNCGSpuEVFooylZpkYQiWoSUdiTa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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81XkXRpiKKZWtSfYkFUXJlkfCS5/GHkU1yBJ1qRmhdGXL2EmiRC+l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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns8lGkbxyml3ZDaWLsqp0iW0K7ToJ9CvGpRaYxz7Cg6rN6yKCmnpNK2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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVln08lWcYx7GSVVpeFsVKW+UlRqi8jB9SSea1zKKoiKFREeqQRFQqlIrW
DjJ0VoYsJukg5AgHh+Pkde1+cJiX2oq87t4fz+f53J/nfp77un7X9/pdz/oj
Qc4+UhISErfo9f+93XKH6/HcNvTEW847STNQ42aw+3WEePl9767yFQy8/pi/
enNvISqy68fyvQnivNulqvd1ovpY5JHQeQKJxCqNzgARpu0t+D5XGKy8px1v
ycqG7KN37g6HCcybXdz8w0X4IlRiXmkPA4sdjJPV2gx4mey8t9GLwIKnrvma
HQyti72Dhp4Ed8aeWXNrGqFkHDYZwyaY/7nleoadAMf6co+I+wnGPnPuNl3R
Ci2BdGhwFUHCBbUjkl6NWF50Obb+AcHyl+2HtioL0KXaIrtfnkF0ddSstwkf
2lWBJwZLCD336F86h0rhUd81meRPMBTV+beZAh+6AY/Wtz8mSMRiifcbBbhG
zFLmaX4Tu9R7T862Y5nP91zOZgacc84L9ioCdBjxZ+5RvdZ6BC+6vkqEkcnm
8b7DDGpfuCa+XBCgP/vzxAT6/IF6FNtEJIBnlhGq3xDsyrziq95Yhfxtvlus
zhGwUuUyVA7y8X7NKV5JEUH4nRCXPcgCV/KQ7BWqT6yOSpgxW4CdH7m94nGC
bjfbDXX/NMK2jZmTraT5xL42K5lJx3zuPt/FdL9irrfPqdlu5OslKF+eZJC1
aJYTlMAHOyZtixSHQE/qhzk5qUwUuzzu8aD79Zwya3fVVKH0mwPRGacJgsMj
nr/VbcGSYH1uBY9AMKp9Q/pYPSZi7MQFyQTZhRftNwUI8EPZ6CLLJZSXqgNa
u0z/QM9Z+c3JAQT7nu8pWRpSCQ/ZuMjgU/T7luZv67QLwU7MHK+h/LB6fKyM
hIWIS6ljq/nS+j36JwNRNfDqyykUxxFwxWYGJW2dUJ4er4r4loG3aeammqBG
kKWlird/IyC/KolkywRIaJpTklFiwJ8xW8d6KEL1knX5a+8ysLv+8Ezkmzq0
LjwaLY8mcHwQFNobcQmOPJ2nByhfke9eePk2daDzEz9fORsGi8u2ainWdCOV
dzPxt0gGevebxa4qzVDkCS130nq4Bf3iXx3LhkTBUTkXqherr+TxakM+8rYO
hr+hvEQbFPu4+RYjI1vOLNeH1mNA5uxU8lM8uJBknhJI9dT8rMWt7zacu6cr
y+j5UleX5+lJClH9YT+rRIfBKyXVnd9Z8SDQFU3JZFDebp2VGcrkYZvZu/D3
ifT94WsK8YFVuJO2oHgglOCw8ohe/lkB5LXXa55RZlDM9HNVbvFhm7DjdWYt
wcN7+q0L5Y14PPJ3QArVq/SHkD/cyqvg2L/WyTOS8r71z1QfmV/Q/E3xNkna
n8HbZlYtS2Mjb6hPKY7mF+XX9Nvq3G5I8LgWulRP7u25W7PHvbFdtmW1Po3f
YmS33ca6K2iKDK/3pGvH5CcVny5KAynzamqma703qjzWx1pwxvBFZCzBK1em
w+afbixeadI2Rb8nw3kVJG9Yjy/Np1tmrxLYscp3HnWvQ77O1PJf4wkyDm6R
rc1ohmZF+e7vnhEkXbLJ/+pyBdJaT+cUnCQoHtcySv5chNn05kArQwZT5uyC
sc968VA/5YSDwwCOjcRklgs7oC3SjfkwRzDlEu7obNcFTQUr+8ybDBxFXY6q
udkYVjgxM0DzVdPpcpf1+x1/bvLkRlMe1VhfXuZJliIwfmRNrR+NZ1VYysaw
dqT9aRf5yV8EBtLGbDl+PZK2/Z02epfuvxogGXe+EIcP5exzoXznGZzdEMNp
w7IlWqm9nQSrJSyEUW6dCNW7tC7mJAMNhf6GNqdGfD285nxhKoGhXdtwpLgF
EpafztnUUD30HR3ng4W4dlK96cUUgXfe+cR/XZpwMy2hruQOQRVzQfrspAhx
nlZnrPKonkpfl+mZ8jCQLtGwmfYnd9/mb68XtaPz1P37Egu0vmkvlEo7hJA3
kD/2yoFBhK722ongXojvXgzxHGSwQRD4nUxiNeSxaUXYeYKKjRwT8Ycy3B8P
3HuC+qO1TvdurmsTth4vHEpMIegP5pYeKrqBoaEnJ37+nwfHvueBF4sgmjn3
SSPlP1r1aMaPpQ14eZG07v2VrnVCA17sKYCZ0auk3VSfWMNHZRU5fIQulzbx
f0qgOrW7Z6zsKe2P+FcRxym/8ds1vrLqxHT2+a+GlzIokM5VcRB3Yfkip7fy
YbRfdJY+ro0oAMvQqvLiUZpv98LnFfY5sLcPMJWjPM+W9OYbn66B/PhMjsIF
Ag2LD3YCzWL6/uCzEhpf1MiPrAeurfBw93tiTv10eptvz4b6esT8WxHfdpvA
fnRsRbB5My7fVNkcSPtnVSUv/Z0VHxqqHNGVJwQ20isVb6zKw9xfUvvL6XnW
xY3FA0F8WH8wtq7nEtSUpga4ZzVg7/TEueu5BEa9vtcWDwrBb7s/fFuL+qU9
M8QqyoK1e3TDT5Q/7lhHrff3HXg2uWnNoCODTt0+1+PcNuw5YGxQSueFtUuh
+rB6K87tNw7RGSAYz3up+FOqAKMmE60HKY/7BMrHns93okL5nf6YE53X1mdc
Br+Nhv/HEy6WtD6qNqkpfca1GLocaztB+7HKplLTNL0LiizT6OkjDMpOrdmu
4CqAv9jWZ+U7mq+8mWOSkI8PIVvcOOmU58IOE+ed9LmtOHejiPpvaJRJMGmF
0tf6PVmjdF4vndD/ub8JbatueKwsJfi4mOyd7GlAqetqdyaN/h+MWTsvJPtD
IzE+xIDGU5c15iv5vhqZEdv9NMPoPNM7rOqu1wS7uZWsF/S8AZ/nKUeMXyOq
0KFXyYj6f3JuXgyd9+4aFga7+LQfoyZ26KIJ27tzn/GpvhazIWZF4+1Y8kSu
bz3lpf/h8f71gyKkbC65mX6AwfRYYwNPhg9Ohd/JomLqv7HbI2oInSfs1oS3
j6hfNchWtsQXQK3m7ulIymeSUcp6nYQo2MqebzCn8VY9fth3Y6kAnEbN9IPU
TxKFI0LFFi4cLomXLaLzzX2Gs/dcbQmC+L/n2FD/+KnutEfbSSF81Gp+adFn
8B8uNssj
        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4Fesft2UtRJakTQotlCUhPkKKhCQhpJJECm1uy0VZyy2icqXsSyXJ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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVns8lVkbPaKTpLtc+solk+TWZRoUzTrlFErijFSuucsUUWiMiEoYkpIi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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlWs4VekbxpGMSpKkRpIzTZlBmbZUtxCmJDkNsiNyztDBIERyaGiXMsip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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lWkbLsJE0yIpNCUkjOpopGLMJcnIV8qWaBFiUrYsM5aPVEKLr0i2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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VO8Xx5ElkqyFVkQkQlkSfYiokFYpvnZJJBUpUSoJKaRoISWJkqzZ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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81Vkfx5UlJJFwR4sWk6RRIVw0H4ZKuWnRMiGhLDUVRUaPG1kaNJaK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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns81NkfxifNJlbKpS2RZElFZRHa8PjZaVxWudTaoVyqpWxitS6lRFEr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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8VVkcl1RCQw1FJGVpUkM1pGnKNyohDUpS00xSqChk16ZUIjMkZZsM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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHlYTO8bxkekkCRFCy2IkISEpLuihHYh2VKJikqS0irRhva0KSrxbdMi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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81dkfxm0NhivUSIk0tqtmlFIhPJU1S4ykLHET6WedJJTENCX91FhC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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lekbxsmSZmwzFbJEC4oQSinjsqQxKOUnhGQXSUTaiKQMMxXZWuxr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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs8ldkax9XkkkNhqChynalESrQ1mp9OTaWppoSKsHPJVsQuRXK/5Dq6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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3cglf8fxSkRCRGJaMlI37JChaNSSrJSShpWKZGREF8jZJSdyP4WSZQ9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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk01dsfNT1KheKZUoZ6pnQJS/GjnfIkQr2ISCSSpyIPCb1KwyPPD3V5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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk4lekbx0UJMVkqSrIkFUZGyVJ8LYkmGZrG2CKiOUrily1bo4xs2YqR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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekb1lgm67QoEiozVJYsMwzRuSV+RDUlEaNx7GPITgtRp0ERNYmp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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VO8bxpFsKUuSUCHao0VS0Y1QqZCyJWm1hRBZErIlqZQ1LShRkpTI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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41NsflihXdP2KQhSFRElFJHnRggopV7kpKkRXRdxItuS2Kku2uHVl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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk8lWkbRmkamUNCpZjCHByyZPlsuWRIY6IoJWQLnyFLhQpTSKXNEsl6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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns0Vdkfvz8TU24ZJKSbaJRHxjAoCh81kvGKQpKZMNVkyiMqTBRKI48e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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8lP/fxUWKFkXWomzZkkopSh1ZolKWSmVLIeSfhNBUUlkqREWLKHtF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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk4lWkfx08SGipb2sgSkTC20YZvvA0Nb42EJBklOqLIkkMISSo1la2G
xtbqJUJI4nQc+5Hj2I4ly3nu0zQxltGkqSbzvH8813M9131fv/v6/b7f7+e5
NY8GOftKMBiMDPr5/ztBYPcNy6IdaqJL76JkCZwy3qeKpJqQZD409ZH+lmTc
Nq5gCsGJEwY1FVC46xr5NOAKG+d2PVJaFUMQvDP1R72QGjjX+E29SiWQi139
e05jIzZdW/8o+jiBndm9I2pHhiAjH3f7QYQIjAD9J3J+bPCXBSb9ZUFgPLnV
IlrYgGETc9sXjgQzixkWc99W4MAlu0dPlQh0byYrfDMqgPboXKfJBTHuZ4ax
pdi9CFnw9l1Hr3vFXtohuyBAdYPDol6KQvXvGwp5Jo34ZH7Dl2KIMeG3i21d
XoGNxalfZX4guDaSmz53TohPWtN1HzIJthYYPXjAycGX+rLyWk+Cs0VHZNyj
+JB4v2lPdZMIrHFmkEVOM9jH/vtV14UgX3O975Kf66FsORefr0gQNpiveDJG
iJe7J78dhhjEoFtNO0OI58TP1vbrGMZcDI6/i+GD98jxwBzd76+mFin/o89n
ni9skaDGkZY5obJyTTP0yh+naz0l6E/xKmQZCVFSt1lg9n4cLzY4blNwHoLX
gopznN8YJjONshny/YhP7QuPaBIjJbnrw/eD7ZAtj5R+2E3AbLMciOodxujL
5EG3syIo1VQVix17ENHu314QSaEi2eXl8MEXeOPhOUrR8zAP9XrmrStEiqRf
wuYL49DzIo/Zsa0ofOUjX6VMwVMtbW1YSAOsfl8ZuF1A12dFbZ1W6EKW9wmt
1v9Q+MEjunvMjo1rkTq52xYRBPZl+GxuFED2uLfN4EqCFos7GcvH+1BXFTbz
zJaCR8y2ahxohe/bkaBhMwrGgzvSZgZzUbE8LUvnEEFaj8hk61QXYj3lDaTt
xeDkHtXvfzaEEfU8z5MVBHquiV8vsHjI/lMjWNmTgttAnFlr+wBaA9b4+O4b
R20iqdyWJcBhx8aYLavEiFPq3m9jfgGBHNU+ucMEpW/bNOKCiuDZ07yz9yiB
KtWwm23EAS9pOGBXE8H5arM3RpVdSNP5a9rmogi+wyF3TnkNIuV+mjNzpQil
2Y4OCRp87LynrjLxXgRj61k8ju+Ago15kvV2Av/lHJHlyX583G1XO72b9jtZ
Ydii2oYOeW6wvRuF6/sGuH31FcjIj5y/eJr2u0fLddm8OvBGbmo67yXwkYzM
mpHtg2fkpNuZ8yLomhlm6Re14ua6OXmOmALDnSHbL2jB2pKl7Uxjgu2rp4rr
v+vCZNXn+2r+BGvLFw85pQmgXneOdWSSzrNJc4xT9iOwmBsUzwYQPOQt1vZQ
akGR6b0c9SMEhvVavF5uM7ju5kl5tD4HR163Mjy4CFtc1nh2jD4vbkL3DesK
wjS5XDGdj9IRVSulyhfobPBSqDUleKMh98+2W3yc1i0YGXIQI08nc7blzivE
XitrcBqlkFxuN72P+wqqfxremz9JwOabqM2euoeyv7XW3PKj/bLTROuroAnH
NF6+UKf1VZnc8ff0pmZk+BgkHLhPIdg7xs/lPg9J3jrXmmm/amz55f0lw+fw
tNs7epCud/eu5oL+fAeOLvIeNEoRQ1Xxw+F06WHMiu1nI/VpfbL2t5tHsSEn
8cJEICRgLYncOr6fCxY5nLniDO2n3waYmp1VaJm7uqPajUA+tCHBMu8hll4/
tzfRmsBoi7L/8uBuGHwz5ZI+QyFl8YzGU9keCHmfF/IKCQ6N6/hdHXoJ73DD
K+8/U8gaPMC7w+XC5am/wzV63jKCHcVRG/rRzY9gLqP96Bt+e1+JgAOprhPr
S0Mo1MzaGgaFt0HxXsTMzAqC6gpOk6dCHb5IO0Q0niDQej1Z3PJECHu9hsAw
phiMctt4n/FY6PQdVZGg/TxW6X7xKD1/scrHJX2/iXGs55DqCuuXkHAgVzdl
0fk+7T/bupwP6SOmy/ZE0/xZO32bVyFAZlKv9HefCE7prvlnPnUEzaerP21v
GsMyd5MHdzu6IRE7Lu+dLsL89FrWkr0tqE3wfT5hQ8/PNKdne2E8+L+aKBd7
EbjwL+ulLq6Gv/q04r5zBI+bouqYbR2Q/MF6oUyXQphU0DErmUbUiz5QnV5i
SH0NMo3/tQE16ody9tO8yMy62NNhKcT6iJiM0OoxGMdEdLdtKcaKXJ1+NZq3
yrWNpQYSHHS4rin9Xo4gfFzS/WZ2OWSqdn2ZMiGwbV6drixqButSvx1fhYAE
hxtGCXuw9EKJc0AfhS+imhfchkZUPP/JMDGCgkbj07vJtQUIPclqfEv7qVQq
m1uzToj4SovHitIiPOSW3RrVZiNR8XvKhebxqctToSuP98P+wNlL934UoSNX
zWa+oBc6buFjuTkU3lbl7/5uggsPj+BKGZrvcV1rIzTDstA0UZTs6EH7aXNG
m4/5E6RaUUUjNN96OZ2Jod92oOlRwp0kmn8M14rawCu90JY/1GqfLAJf7ufP
uiGlsGalU+zrBLW1N3gmzBacebesTMpIjOwTf9iEKbDxh+DK5JddBCGrRTGm
2XyUOrg66fpRkOO+1X3IHURjQ/22zv0iOG9xvVFrLQAWrPIjhglMSqxTatcN
4ydnfTuZDSOI7iy+MdTBw0ZjpsUvAgql3b3uuyRKYTxA3VKl9f6Y2a+60akH
ZziVaQbzdL+SHevYHv3QX5XHWHAVo2Tr6pgcly6IZM7r8LfT/cgvkTfUu4hV
km6PNWheaFuuW7bqNQ9KrU0KlmH0fUGpv3nAswZRy9+JJJwJbtWXWBUktcJ4
KifgjIjOd+FrSm9LP2atBrUv+lBgOu356Xx0Lt727MlYSt8nxsqDAnWu56Nl
UcP9nw8SZAxGP+Lbc8DsCk/m0TyUZ/kqnxJfh8Sn6mfZ9P55YpSkp0//71WK
Iq8sjEO8R6Lr9V+vsCPx88CdWAraLTp/fNzdjcsVAR+ThBR2Os7VF3zlQaOf
Xe4UTef9iK3MqxNCXPb9UP533zgse9yrN27sRaD7E468LQEj7VbdBx0uru7p
C+1RJfDMYhCvnD6U3SwzC6H1+hddM7SD
        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4lWkfx2VM9ZLIUi4kjWTJlEYk5CtpKFlKGTRRREK2StIkpCYilIQo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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4lGkbp1S0Q2zWYduK6OAsyqpVv5IkpySUGjnEkJzZVEbNVois7PKJ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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8VW0Xxs0VCpEQQsYSQinSJWQoZSpJMquUQipUnigilSTJlKeMiYiI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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVns41eka3SMmOWhrkBokTCRTSkUOLRq3KDXZ2y3HSG45hSTjFqaGqWFm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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns0lekXVjIphAnTj2ai0JURh2SqBxOTUEqk0Kgkl8atQShk5FIxOlLI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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekbRhJZKtOmImOpmKgsZWbUrYVp0ahGWftZSpTsZafjZMZS0VCW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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VP8XpiRRqCRpISKUpRJaeKWSIltSJBRDEZIiEqKEfEuKRGRXIZTs
61izj23sy8wdYymVIi3yu7+/7nOf+9z7OfecdztbL7oYU5ZwcHBYcnJw/P/6
itf0/bs/NDAYoU6JtuPgodwetN85BAnwBcjzDaOeVp1/g/8diDMKmc0nCdia
UHspP0pQ4HV92fZEAvEqD6m5EW9w4otf5z99AkmRVmZ3otuw2c2FvbWYBZEO
Tg7xgHYw3zVVbi4fA2vUR+Hbjm50HloREnyaDT/BPW6T+yjY+dtj7SNLAsSD
vyZ5Y81oMLg/cm8tC4J/PwvX/OyC/3+KvgfusXDz+IqYNY7tiJToiRCoZiLI
VmlErL8Ox76J7g8OHkXY68STN7bmwk615JK9MQEJwbKyu8ntMMmXrzdfP4rz
gjJFV360g08Fli0HJ7EyxfYNz80uKOT5J1JmWbC+6pCfv4EOf6G4ZZ/sGfCT
VdXsbCnB/kRPisEHJnrk0hV2mhZCOLwuXL6MCcmbsp76X+qxEKklQexh4YjW
0aRzSl14KOzx5FovAzyV0TfVeTMwE7Nue993JgriWl2S5GloeSz3X8Io2b92
p7nRsC6MFxZm8X+egFAfnXjrQ8OU92hsQiATPFNrS9x6+yHfxTU4u5ENZ8q3
d5zfOiAgPjwZZs5GEb1cPcemC8QR3ZQO7Qlo/utqrpF7DnNdlfFKbQJt5/rT
uzK74a9n+vOB8xhm2L6Bctq9aLolH6zvNYrQhB81IWotKLDBkT/Lx9BexxPx
eH8fcpNvuDBdJ3Aw73RCoAYVXKZXwxv/MPHpX1uAVFseRMLr7wyuY2Fk2tOO
Ld4O6ZBG0RHdMYQFl91Z9TYRIaZRAhK6BEampMIntnVh1XO7oakANix+PoW9
eiM0OVxkcs4S0PytmHQsNRN9C8+XN9gQGFexXmWq8hGf4yOfYgcT/jcWBz48
a0OgFX/cSwcST9I8CrnNdfCWaO6yOc/AEoKTf7VXE3hbBX3c0gnwB4pMmMp2
gMed0qe9hIWw9ASjF1Y1SLXXnqXdY6JibiO34NNsOI1f7OlxIxC199jCvkcf
8TOnysDIjnx/KCIobGkbnAIO0+kfmZg7cu+L+G0aNL0GD+lFj4AI1W7RXdcL
ftesk4+m6diZZn75WXM70h766R1THYMSLeed/7lWuFf2sbdxjSFO02ONiSoN
2tGeQ19mWNinWrNLxZwGo6BrapZSo5B44vd+73QX/rwe0JNcTsBvotDIPykQ
hHVJ0iWyH5qTS/wHFB5DX0o+8zyFwLTI2ic29k3453OeEOobQdCA1GEv9wFI
MlbacwexMX85KbebrKfvWdncHh42VhIfS+m6zShoDSw5cpwJjUf9Sa4O3Yih
5frryxPQ8syw6/GtxYtEzrQCN7LfFs31BcVVuDKfTEwbshAV2t57v6wN+pmZ
Ts4PCIhkSfg1bq2BZ+YfgQ2+BHKdzQac3rfBZuv8ulI+BvbHJkze5e3Hvmf3
s1cZsWDox6/35ygN1UGsIzyKLOS2HxB9d74CaladdzmHWXjPZdQVF5kOMeHQ
EH01AjZbupIeRVRjpZO3MC2TwM6ai73Lajvwl3vth8ePCHQyfw05HsrAgMcc
b9EeAof2ZCeaL6PBd+pKFZ/BMCpO264pH20At/HQm5c9BEbjOMVySPzFllc+
6zvDxsCIX4b7sjKkjuLiKU8CayLqjc1EurHU9qjEqgoGOg+rmW6Ro2PJCUv9
3KAxvJi/VJqV3IbRptb14z+Z4Pq6sKJDPwICE2vDP54jsPWkW3FPFh039+u2
LiazMJ6VvLjhSSeEdF8+FBpngMtp1EW/pRsXOaLHBEMnEJakIHaaNxqCi9TN
1iQ/Q/rnvw4k5uAol/aDvuskX4o8CvsFKiCt1SrEf5HA42Rh5ecatZBpEdBw
zGdgZ6zS9yuxHVjJ+BGRZcBGlDfj+YxWFZyVfYqukvgPsD15bBejAu0tm9yU
5ki9eY76urlyHKGesn8RQepB9DrJfpensFjUmnvoQOCVdmCa1aYeBDEWTuwx
HYOcwK/diTJ0/C48nHSqdgT7lHa9jzGg4XC/hx77FInPlOnjMmdLseJ91OI1
Ek+bxkvWapc0osgondfPjomwXl6GVFY7/OuMmsYUR/A37++AgVgvNGo5K/aP
ssFZOq/4fHcTNolG7NDvY+AVtVKT06oTQ+mXXmUoMKDB8hh9k0uDnoE+NX+E
hcmzGt+Y29qRv1fi0/bcMWTYepSlKlcj6FLRnSWmLCQUOIvmLrRAp3h4fe4W
BrqEujdO7+qH3wzz9IqScfw9/6n09qNq2Az/6ZrRJvX9zHgGz1wcYtsOruo1
J1Ac0viJc0s3Ru5frWqQmsRAg9Gt+z/KYbvBVuUxlUDoUaOZ6C8V+L38YFmi
FxNlcjufXfzQi/XXhradsSdQHzC6StalFK7M2gRJBhP/nPm4pfg7IL78kpvC
AoFP26d2z6fHYU1+YPz3ywT0dlNOxBo1Yvmq3MTSUBb8ZGrXG7z8iJnynZX/
RTIwebrEQcerE4eet6x3J/XgWnqVnrlmM8Zac10bt7OxLVzn1xPpTpibTSbk
rWEgvtpCumBfKirFv9q8dSfgE1jHWfuzGe3jqjOpQQT+/mze0cmdAhOjZSeL
yfu30py9Yq506LyQp551HYPFaJFVutRrcB0vqD1B6mGLnZE/taQdn5w2HRvb
yUJe68urEmc64bc4d4+zhtRb9RzZPNdBbNcq9KjmnIZhQk+zT1UTtOpPDSWS
/qA3tCpHt4kOE//++t+OE4jimVQMLaAjvC52T4nPIFIbJM8XePWhbP07eq/T
FPwiL2yo5ruDr+O7mVa2BN7sz/63LYUGH+9Zl8x1DKgbVT+UedGNhjyrglkp
Ngrkv6023FqGktK9OTqcLDgYlZenXW5Dfc0q2eQGAjezxHV1vjXgKu9CYzWJ
H1EN61v40YSmmkrKeC0TbgL/llhRe2DxNkpM9gOZL3JXlj8croL3krVL/lgT
sHN7MXtNvRuiOT89r5uPQ7/R4WXTo3roXQ9ZgD4THOc0bxTlGiH4tYvdOitS
j4KHU2U52iDh+jIpO3cU9M+8B50TuyA46Dn5sJQB3ZaoFQGcw4iuN1x613sS
H1M1A6449cINco4UxSHMS7AMqOa5OLh3OGgymEDJBoPQy9vrwEiYCdzaxoQS
T2JAp1gLWqS2r3lXT55vahES3+eCA1zfXZ6SeenuKTe2Q2U7Di0rtqWGjEDH
Z9/9fn4a2j0jzi27Q0D5y9W2dutKzCdfOt+zm8wbanMSFqS/Cu/SdekrJsBV
+DbwwJ568M9G7Cw9TX7/kafZBDsOiVGeWmecCPyJXOK5fP4jHvGH3xYeHINt
XSDradVHXJlWVtf2IWCoWMcXQ83Hp5xb7xu6yPntuFZk+I+Ob9FF9kobxuF3
XSyzTbAWVxodFPclMvFtlyinwrEufM6VrlNonUB1bhH1YHAt+H4xoiQDCVg/
vS6VENMFy6zXDbYr2TDt1R4dpw7iiUfK5VnREVyKbV/qEPYU4jLN93TJ/xds
try/P6ILcuaeDlWkPzh33NEcoLRCqdL1XJAzgQFiJrj2IB2sT311knpjyM1P
408TzkSFqv0rFVL/xQz+TQ6+aUDB39MPfs4z4fLe+fPH4+3g3a+jlqg/imOf
f/QvXirFmmcqji65BLpS/XsM5bqg+ezrLh+TcQQt/hj1pfciJeuF1+TjEYRx
BFrrb8vGTntR4i55vkiOk+utlTn44fXzgogGgevq1+ar8um4ovZkZ6oTE9m/
hHZfVn+H7Bjm1i/bST0xuCD0lSgDU2JpT2MOAY40YaNjEU6IP//XKo/EW/YS
PxPD4TbwLvfUGm5hIO3bul8P+frwbtpPY+VjAnWrf5fyHuxBuZhkUdOmKTya
dj95zesZVHw5vsuR73MInwxhqwaj0pKqmmdB4uOW2p6Bi2Qe23TpcngmOV9u
rZ9BDY0Q47KQD/VlQvmGY+SamCaIu20MVNnFgNp7bYdYkUqUFHhsNCTxJDLi
P9yFfmw6IPBDpoINTe4ttx1TXJHqdHGi+TxZby3X49XbWiG64UDb6VQmBjbe
qfxNrUO5/PDulT0snDg6fWI4tA5aMwc1+dksBFU0+/svKUZIKC1dMZOJu5x7
I/Z01kDcc75pgXMMHLpJe6x0OuEQ9SAuh2Dg6YMnKXJH85D52SmHsobApfrW
baVW9dCJPmWn10FARe0/UQ+LLNA9f+of1iNQ8WxqgpPUQ5WM3Ab5IyR/hy2F
vWcHEH3nt7vqJjao0YyhB/epkPk1/ulEBVl/qeWr6KEP6BDTjjn0H4E84xC+
jI2vYDlbu0PgAPlc1WZux79mWLtoRRgwmbAVW5XoTKvFzK6TYyGVpP5fsbX7
M18PB9XwX98WmLBLtr1qUtWN/Vd/TZYcZWD8+JKJZfda8YhatazoHcnPAWWd
FWaD2H2uReZh9Di+tswuqukXwfkH5aK4ORPuWlP0/Bfk/pCQwsswY6Egvife
k96K+OBN0XKSDMTNi2k4VtGQwrC54qg7ihDzUNmbV3vhbu/7e108geoM2RSN
inZsop+Jcto5hiC2r5nufBeaQn/bWJ6exIiXm4Ysuxg8f04KTCQwwZ0mGPB1
YxfyxE/8/eFA7mtpQxsue4fB9jZjzJrMo95f5SYVSrPAiBu2fXGUgGjMRsHT
6xqg/OqmfJ8rAQf3UnX+D+2oDqsrOO7Bgkw4JZbyqwYsh+KP0mMM3KW1b8yj
tuOn5+JXigiBr1zc1zdol0KT/muL6QwTUXNmLOdjvYhL1Dub6TyBnhKvfa4x
H+AufKvF1p/ke/rT2+5z6ZDeyKOiQ96Hnal2tuHMRaXdn29ligS0pxrf92u2
IdWyXGDEigWdVLaLbGI8wmOOjaiQ+sZx/iW/9e+X0Lys/uoMmccixyevuUQO
YOaDr1lvwCfsi+hxKzTrxrt7J+0zz5HzvejTLducjXA96y/H/Qg89fmxI0++
FVvG1WUUnRmovuz+tDWeBm6nU5/HXrLxvdw+uN+/B9aKB43rl5H9ch/Z0r+v
FxH7RbOmSH991ZkRsv1cOWINys0E35D4rNucetQoEy9Xn9M6uJkA98IOhf12
NFDVLmRzU1kIHiiINfEfgNAGu8v76QRoXuzHxhL9CPPupnJc+AzlX19eCx7u
w+TI+gvGAmQ9OS56D0ppSAx4JSW8dhRyhpuVNDzawQh694a4Tfp1YhOhNNKI
jC3XW8V+MrAmmqJ0qigfua587BByHvWs4iL1uQpE5BOtBjcJuPJ/HkvwacOH
s49mAxyZEH8zZ9Jy3xvCdp+PJZP+afjlVtY/j25UyBl/ti5hwvrBuERMUD46
+ygxNFKf3+hd/CS6vwuBDwTuPqxg4sbKK4pcAfWQHp8NYHiQ89vsbTl9JQx8
PgcqpkwI2L7QCqN+J/cZqwMnt5F6fVbJQdaxswrfqtffTlYg/YnRmsDqp0NN
creIxqVRjPdKHmyldON4cWYajdRzuxeSWndPdSM5JMGan+SXTaNTq9gRMp/z
vrl9guSz6Oj3WQdZKgbYD5cnt5B+KJZV4GxFxSZqi4LiNAucrbuuVO+uwklN
HQfR3Ux04o7SVrN+6O/4mO8tTeJxh+vXKaIaxtVrzYtWkXk2aZfGiGQbKFo5
TMNZBp6oeQ3lL+uAO59SVEUVE8m/PI+puRRD+cqq7e9Dybyl9HFv7IZOSEge
Xb2cl9Q35YwdKo3eKDsiZbeb9Dd/6b4Tfu/bIdGaUfyPm43J3cHL6w83IlHf
ZeRUDRNX90apRC59Bp9y+6TnjgQsBRUcZGI+Itmnrrj3DROz50bClm3qQrRB
h9XyH5MwpghsUvYewIuBfRzbYsh5W5pWDT6vRWTVs42iawlQtrZ/+WJfDX+v
GyIlluS+k/VcSWXxIwqSIsvjZMk8LLD0loVxFXSvig66GRBwfJLWvOhfiLLf
F4O6Opjw8w1fHTaSB2GLeIt7pN+It95YZhbfhoJvh8OkDpH7qbhZx4Zbbejv
uGWp4M+CkC/PDXpOI5QLd7Y8NxnD4fU39La+f4uMmc8+GSR/xZ4a8Kk3V+K3
f6bxDTbZjzMBJhm/+1HPEbKdx4r0p45+J6nWRvhcuHw2WZwF7T2L3FY1PVjS
pqLy05TMx2e0VT9NZEHpfjYXN8knmWzHs/ZfusGV7z4R3cyAjQWldPdkCT5w
vb95Oo6sd9pwOvNtE/prhH18uBjgyLj+PS/5Ohxe5UVlkv9juFVWbijtNcx/
zRzW8CZgwOAKFeHoxnA/0afXNAnNu0WXvD1ScJ0aqBpPzqM40/rivX00HBw4
Xb6U3O+M49I6tqzqgfs1wcWNW9iw6Ds+6U/mqTjh42cEUsh8YBRYkS3fhs2H
X17kI/UqZKGUVpreiy+vn75MI/OykvqgiIxaM1ZaKJr1kXzSkTQ6IRbfA6Hz
Jg216kxMhQw+FM6vhXSanJ+pDMmXfU7hSaWFMCw7Y6IcSeBqBrfhLts3uHbH
orLfi8RL/aqlXxS70eRizXtIeRSauG/KnfUULaPnRGXI/cZ/3YJ6+tohDKbM
F2otnUBTLYVPKK0LwzGPb1Q9Z0KHf8CzcqgY1n78M3xJBOIY8eyjx2n4fKu7
BOR5Bs3UVluOdugVKcv20plYnczh5CtZD6+11YYtp0n9NRx+4WGSjThzQdEj
0gTYVXW39uvQ4VPwrPzZexauNglGPB9Lh5vvfdX/bhOItt+1hjdsCGdrtJY+
esWCyT7p7W+9ayAToTMbT+p3hVhh7M6xTlCO963r1R/HO+41DTwNNJz1GFx0
cxiDjI80xbiwC5ENa2yuF05Cr9Z6l5BgFeTDl+Ma6WfKKeeaqlJ7IBVyO7Yk
jeRjqcYhYsocnAM2devJ+f+d9JmtfNeHzTdGLrSLj6I2QfVws0kyCKFGphSZ
B0ocD9WELXQiXpqywOIexcgp2V5x/VpwOxvfyAhh4Oq9wrMfRDPwuHjrlq1k
Pr87rqQa4dkBw5QiNREynyTLztIdqS1gG7zW/nqTAZVblLTb5D77QW3pZvqL
CShS+iYoQW3wFvQ9cVOX9MdSl/WciwXo+Zt6P2GE1NfYgpEnv1rQHSjklW3B
wv8AUU8PlA==
        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVns4lGkbn/EJodJ+SCWfZFui2JQO2F8rbQexIaM2ySKUQwyWtKJILEWt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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs81GkbxlMqMVEOpehIhLbYFDsxl+TdWsfWSpZ9y1qnVFaicogIYZ0r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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lmkf5Z0aSzSmfBGSCembjFxeW006lmQ3MjKqyfJSZO1DoZBQyU5i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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k4VV0bljcyFRpUSiEqQ5IpKm7J3EBSKZJokGSqzCENKpGQKAmZhygy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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8Vekfx22hsaYhYyjTKNIqW6Q+CmmVpWwzKkZZEzF+EbKkRKGxhDCJ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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lekbxk/2aGJUfpImycGESJNMGZdihIyQOdmbQk4qRIlGWYahQ2Ub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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4ldsbPY0UdUlR3J+Q2zxwy9RgqUyVikualFmHaEDCyXjdQiSSo+hG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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk4VO0fxmUpSVpJkiQJr6wlpbqFhFa9smQrbZJsUZZkl6SorJUSQiok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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41ekbxhGZJiZxoWxtmpAp2WO41ZC10KikkiJUkiUNpoVCG2kiS4gG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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk8lfkXx40YstVPixgjIqIsTQoTPo0ka8meSsithBgjUTchRck0hixl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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8VWkfR9qzV4hQKCXRtNgaXxXVpJQZ1VQTJVtRpLJGlCVCIkuMIVne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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k8VG8bRopWoiT0t6dIJKSFSyVLhPaoLCnKVkqWaCEtpCJLioSiUUJI
ypqdpDHGNtaZOTOGSpYWu/e8n86Hc87vuZ/7vu5rkT91/sAZAT4+Pjt+Pr7/
PzXr+D0k7L+i5F5qhvJmDvRG4x1+T+ZAVDuPKuRBwH1ipCX0Xh2q8/yS3IVY
iPZ7khPArQbfyIyltRcLkgFqwlctS6Dgox23vpYNzfc/awWYZXit0rKYTWFD
a3PzndT0KhioxyjuvMCBKb8oxUGsAt6z46YJBmxQ3jaZ7Qx4h/qZkyuHzxBo
jHx9xUCrBWFxWTYP+AbgF/JW/smaSsSmrZm7YMJG/a7y5hRVKuqFVTWX9PRC
7tVSqJTkIqG8I8PNkMCqSI234bodkDk6t0NkfT9uCFGO8B2shN98M9NH/WwU
Lz0xlWSRDe3LeZ/GtxBIstkhviD3Ce6eidtm7kogm1n81LE1BcZDcQkPbQjk
QEf0fVMz6KsNjC+5c2DI1NE6fq8IRrMvzYKcCQjJFwkYqjVD0CNDMu8mG3PB
OTcC9etREW+hEXmFg3W3FdQcGU0oqXZ5M3mOi9FCHk0trAFKrq53wx73oeGv
zKr7DnTUc/pUduUwsbpfYIOLei4yjH5GH/Uj0Bf2mRns2gy5WefQZAUW2hdv
qRia6YH3dLag2QgPAS67F9i8oeHRmOOYsicPxzo/JL9blo+tUnpz33UIDPJr
aB7fQgdLwuzE0GEm9LTFvgyuaEawbgpFWIkLPutjicJtDXge+izOKoyN/7Je
zzNvbkNBU7mucyULa6KCBQ/GNoMllxhRXMpFv9ylQiKBgbSYymXJC5j4K77M
3upBG3LnhvxtnhEomNFeInkrG54e/7A9gaxfQGXIMq0Bhfqt/7RFuYhV1P+0
cGc6hD/aDMuaE6DKZz6yKK1DiIaqk5k9G56BHsYa22hYu37il4d1H3ZQxo0K
s8vh4B/2RXg5CyFbLx6ul2uAx1DxO4ltTIQeP3RAi9sB0WNRC7fm9UPfxbNB
/1Ib/llbPynU6MPBRxKXNYqqcWp//1S2PAevTqV88yyg45XcpeHSICYsbhne
Kr1RhIFUncaBVAI7li1eK2VQiyRazOocXw5CHD6dEdpQCoGBeppBPBujU4rF
j66m42W58ER7NIFxBcuVEd250A9bGyH0goBD9P6nYvM+o6DgwKh6NQFrNXXF
d355cPYK1swdYGPFP/P4igVUlLV3l4Xf4+LslsPGnT4tiHA/1180w0Gruc1o
USwDto2Rw199+nBkgfzltbubETU3fVfxMRePJo715O/sQMJ3i0e/L3JQlbzv
KAobIf59IKDuLgvU1NNhvp7VSI+3z/hTTKBMb57ihdh7+LTt6uC5AwRcqjYH
2+nRsXHM4M/4FxZ0z3hF3OypRsNPEaXkHA4i9rtqXOrNhfHMnc706wRMRP1p
Bbxa7PYJWVvdyIZRMF0PS+oRZbPvoPsDNnZUmZ3Mr2/D79WLzzp3MaDnsCmv
Sawck7MZTz/VELDw9rB8xqCDIrHrgdj5PgQmagpflWnGzeylFOoVNirNq4dt
6+hYK2ysPJXPxcbUpC9eHTScvrZkeagRB9sWeEYejGjCodJbi16KMdG8Kbe2
baIJ5XXKK4IC2KCr7J//Nq8Mw6PCYdtNCdieuSw3erkGVPquhW8CWMheLfW7
nU6BC59RaRi5z7w4foUo6TbstpZtqCxmI0/nxre19Da8klyQ7X61H3o+4adn
m+kQnHdQftS0HzM/BCfaI2iwvmMbfT2uD61v67oU9tBwUfX3x8JJLrIH/CkS
l5Kh581y6/ElsMHqZWDWwRLccBeUkVMiEBi7YfPdkQ5keiUuSfTgwfAWT/f1
rWrkZySYrCXnvXkP/X3uRhrSfA8nd9K5mJ4N9tPQL8BtC3cObzMBJS8/cVZ4
BTbnB+9K2ckBPWb++qHeGhwyirr6LISNkBwvAaeCLqjOb7/At2sQddZ3lDbm
tmDFTjHHRevYoHYMVERbNuJA7XHDnWxy30X2XKjZnYoDlkcSNh4lIPZQ1YRP
gYbuzvM8+XwOnq7a48Kn24RoKWVHB+N+eFOG2afXl2NW+sy1+M8k/93raWi+
VI9IYZ6/hzkX7tlUeZHYalit2eMWeZCDgj1b1zmv78KmjmLZY++5GLq5TKjw
Ow3RE3n5+veZ0Bnhny/d/A0z0UhzaWLh4qIt8g3tdLh1730V08yF6eh69+1J
OTi3OlJMLJbE76XnhbPpT/B4q82bE4fI/arcM18tsAw3OFMH96tyQFWSC37W
/RKFeTfufN5HoLXQ6oGPXi3ONndJtgSy0biT3lnTzoCd18qHhvIszDrYLX5k
3gaHld+sLcx50Pxq+fDfoQY4F/GJ/z5CgM83JT/SKR2TGS9aRsjz+Npvb/p1
Shk6/mbjGvYEKn0Keeeb8qHq/aiApUDWoy+y90ZkE7QFA1yMfhE4Ie0hyj/S
gsFD8qGbGjnI+hjbxHxKxU2KdMiOF2zoLU6P6q/PQ4tX+Y+jJF+UVVISLnh+
QfDmDKO0eWwMV1aqBr6jwM71fqQlWU9stHOu/Q8aKmgLUVTTB+pUac61HXXQ
sDp3qfkkC4xD6UfuKlbBJS3LftqNwJI09sV+zVrQqzRDo26T9Zus9lW5l4pt
4wLZsVsJDP/wcY5wpkDJo5mjQ+q7sUSj1lQPHUL6eiWSNgN4dLFsZGIhFStW
tKlHryQgun2JwPJOBvgGjZe+pHHh/d43Q0GzDWJSXUPNz1koGr/lKKxF4lf1
wmOVJALRTZ/TGBWk3t1aPO9VEIk3zfpvq4vtMNqb2z1pR0CmWnZCuaUOz/8e
rfAl2DDsOC/b/+Yy+BrkNkSQ/S2792TB67422M7pxxZ6MCG8w1TfamcDQoOT
FdZLcJG3bMLIJvMzKp8Qkdkkfhzu2ooX1Cej0eTJ9Q/k/ss4RbbbxJbDquko
/9k9HHh0La1e1E7FJkO7edIRHKSdflJdltuEI4VnS9kqpH95mGWWaNaG6A1r
gkvaOVgRrBts9qILraqxgVYKnVij1mP9js2Ar6igetAvNm5vN81JnG7F+Wtl
zWnXyfN3hYWYSN5Ghve3ukCy/iUbpSqcDNogEKxvkM7PgIVym4tWVRaJSxXF
XnWyn0/3FSb9eoOxsUKrSrLeHbz1n1gjBeCeXnNH/DuBdmsRwTX5NARXqWyV
FeLCkP/cV6fwLjQEzZZ+p/OgnenQcDGzERkf3D3Sv3DBq1Y9qsnIxfzupbud
SL72UzwZN4OvyNC4eTRHmfy/LvJ01aV08Kb4fv0m61O9naoYrVuB+OSXvjWH
Cfy0/zVWfogB7ev72m2bSL3KGJivIZIM0657bfzk90qBptqVUR2ofJH0ymgb
6T96x59ajTdA0vTP8008DjauLBAf+kaHZI5b934HFvgK4Mxn4o78AuH68+T/
+WND2plOdBgHJ2SLppD41h0eSzzRgc2Hi36mPurDsYtZndVppYC6XcD782yI
bjaRzc2rQLOMhl5SMQvDi8KMIy/XQ/KMyrrlWWxYV3NVHijnQKCv3jmkiOz3
tvqPfxbVYodUtk/lSQKfZD86CDbSkKcsz+faSPqFb+qVl4uaILRx3slVAgTC
A1X7yu5XY2U1u/uDAgd7VK6LMqPaQOyevznoYj8Ex88d+n2iCStQU12sz4bO
6SnbVTdrsLvKoH2ZFMnP64J1B+fRsW6l0kFN0t/sqY359+9xGzyXjd2OSubi
xEzhlsM6dFju8B29F9yPydiW675vqDirqPrN8jmBCYO7tct3M7Bk3FXruTkL
hiY8OyfhF6D/XM0w2Ebe5+eXaRGDemRuvNovn0ry10e6hI4EDZRltq4J5H1O
bz/zbhO7CorXR85dNSL1zPfB2FatOijQIlYFnCH7K275aeDjW2RQpT+qhRMQ
vt2Ys/dqBbZI2yZF3SdguNRpbM/YRUxF27UEkPPJO3XA5DW7FA1PhD2nxdlo
z04sdGW0QeXMXUln8R4od2usytZ8BXXLvgiqMnke7+j+EcXPcIhJ8o8n9f2K
toAF1fQ9Em2lA8STyfe0W4Etb+rRcFmwKNmIi3hue2/jpg58OifMeubDRvwm
8XTsbEdK/nSGD3meqWrJrZ+Ps5E3mdJ52Z/kozCXhyMHaEhvmIxQtmZD1tFU
f/Z7MxbsM50z3kvWP7Li3M+v7bhyi//xYcN+OBSveip1jIazazoG1C514/Wq
E0uyXjbhvqL3Vu5bAl0iX3Omy9oxTl2j0EfywX+ysn150z14G3zOV+gvF+Hr
Dj9We14Gxok12+tFCXTGDvFH8NXC9vNOdX/Sv61Ye7W0OKYTFj/S1gZd5SL9
+nFuhicdS/epieT0cSCV/OD2bEo7Jqs0OOpXuOAMnXMyFWRAbjhmy8LVPLiY
e0Z9qi9BnsywGXGBjYEot5ubjrfjSOr3vW6rOFht9Mlq0boOTFmnnCm7OYiQ
REaGnhDJG11uUem63TC8Hh5tsaQaws/lJPkGCNzw2jVp8pOKP0E5Oa+jWPDz
ejh5ZeA9KDNRJhEkvqhSIi9s73ZA5EJc6QtRFpQljnmYWlMROn/PH2MpDvhu
6L0TKZ00KDbjPNQk5x/+n3qyVHUWeAfevlLcQYCYv370dUgrlCyvqT/p42FT
4c2I9jg6lFtyDA+rEpBj6CW/WBiLkgvxSaKXCGiq/PDaczwBUrSAs+OkXlE2
HLnUNJiDxXZ2x5KzSfzNqorUfG3BM/Hl/vqRXFjvL/7ZN5qFH88Om24j510j
V3CHYtoEpmHNvKsqXMRtuejuqlmOpMdlpze+Ic8LMhFOWJaCmTGvG3MkX1lP
VWqemqlDj8tsE9ucDdbtHV/sMnrg/nT0JbulB3L9WmWTafnwLvjEaqGR9zFP
DzJY2Yx3r1Ifb9nAQkLIqOlusXb8fvF7KsONDQv3jWa3XzWhJkBpQXAhgXX0
l6KtakkQDmK2hgeT+p710t7Cvgi+Ti1/8oMIvOz+dueGRQMilALDNUg88jIn
mGriLQhlvpuNI/3fj96iR53FNNjMmN3S/NAN7fixhoSlVVAuerT6qQ2JP1UL
OdcN76Edo8RyYJF8nSkV/nu4Dn0HwqeXh3EwzvT+GPq0Hsy/AYsjqtkIlk+n
SO6iQlvK5fUVMv9OB8JVupeG/5YW2pv96IP5X179dnsqpOyD4hjlTPgdyEyg
oxi7ijvpJVQ2ts7ctJsh98PHx7Fepp7Un28hGtv/poKIfls/SM5fRbd01czB
DBQJlHguukP6Z+e1Uj1hTbirUX7KWIMLmWfe+4tEKlB04fvio38J/Nubf0Vn
ay1Kh1w9W8o4oGRIjJgpk377jp3rUXI+ugpr3hzez0D71p2xrJs90N69WKRn
uA0Zidt0/lWxUTDPNYVD8qUWdfTldDQP5XuFk0LN6ZAbT8hWSGMhwupXwabI
dixhax/viGehVlLML8GjGPl7Xb2+PSD7LZ2k8/XvVwxnXFm2t7APfk8NGK8c
U/BsBX/0J5KfTrTaTz6b7UBcaU38VQYPEfo/8lY9aIWPVm/aDMkPpl87PaMv
VmLw8iNhGdJvvRl5WFToRkH5Zzd1MVI/le6vMAzpK4PwZqG2Dx8IPKK86p3z
+AoRq9Ff6SRflGip8zF3t8DtVKDgEUk2JGhHPf+S+WXDCxUbPoKLu09frpac
3wHV8XD9yn8E9t5Ru3hfIgW/sx5eKbpAIMwqRtfWiAq5GCXXHO8+KJqzWTqP
W2B90bT9xjTZ77aFuRODLThOMZ/vuZyHMv+aSRcyr0sq256MOMvGbFBPppXT
Z2Royq8/RfqzcdpWKY37ddjUkNJrKMvGtSSPNf6D3cjMo192HCL9ydvNu+WV
a1FrH+Xc7c1ClFiy+cG6DrD8H5aqT3FRdOUkxfV7KwRfESr/dpF6HSB769ZE
OaZjvetWkn7teGLLcs6BErTy6+qK6xG4W+ZdsehnGZ6sfPtlfRzpH0wcdbOq
v2DnZzNWoRoHRtlN9Fb9VrB46XUvfhJwVXDdN8ZhQH6uITQ9hgdRnfuLmTEN
CFgbniL0no1FHR+4/OqtkBRYoSJwlYDTom3zi8XI+TIFX1fbcvBbJHOf9Jou
RBSd7g963A+q0PWoruoWfFGJs7uVzIRrp8jj4Okm/Md9skP1IZkHH4hbDDs2
Y0mc0lDWzn60C3n7mLo9AyPgtPdtsv8pshqH+oc6Eb/TLdIrjQm+j89Eh8qC
ENHqTTU7ReD+p7LjPd+aMVZj68Ej+x106Zv1u+gOKPAlRq68T+oF1TKEUVkF
zTuVEdo5LIgKzRMR9KNA40tj3yi5Tzf6vXRLZ0rgIXh4+8h3Uk+l1a44/klH
5Pt752skCFxQWLOuzz8f97tFUvVqCRgQWWe+yNDhKLWI2e/PBsX9Y+J4bxUa
Ijx2nQjnwOr+k+6bn5uRz5N2ZuznYu/ufU2muh3wPJc2J+XHxuCpxu7LpXUo
s8t1+EDmL+snQuu/HKzA52DpHR8aOIhTLgt03vIGqTLrXzm7E7ht8t8hx8Wk
P/XT0990jQvVZ7NP/+S14NCfxpNlw73oE9+QW2EbDXkZb34mmZfXbaOu9b3z
Cesu7E+SjmBjMjTi4vnEcghUnzncPUzmIVXJN+9dvuDuHyZdRouNG1sSjAZC
W/F9EYOpNNUHKUqv+7vTZH5m+sk8D+EieeK3k4FKC7hF5X+v2PeDwrxfm1tZ
DNn2QK1eDVLfjUQOVB1pR/3J9dr3KK1IDS3vUeQ0Q+vK5lTR5QPInqv3yB6K
x/7Fwou22JJ+yeZE3+baKkTXBptJHGKhTOyBpXFWGiR3C8kmbCDg/teOPohW
8OoNJlytBmCtY+jV2JGPLkeBauPjBCTv5He/dKjGYgfKuWWk34jpevuvyDET
NtqGq0De/+4cXfH22AdMLKXJry5kw6HVT+FNcCTGNY0kR0/8P7/NLak5mYsT
bgKZLZYkf6wuFCsxyIaLD6Xthyu5n7r8Tj0qXyHOoP3xn0/q76hH+HYTG+gm
GkSPkvtlOCj88Yd7DBiLmEdiSfzRRNzP05ISEBSj15luQea1gTq7Fb2pOH/T
wvfNeQItg889dDypWE6fWqcmSs53uGKloxbJJyFNKW7zmDi2ykwrr6oN8b3X
vmXGd+N/JtT+jg==
        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81dkbxy0tarSZSTF+0oyQijRJ+uFDGVosl2wZSxlutlAMohGhLI0t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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs8lOkbxiW7iCQ0pFml2EypUDJUrqiYnIqUQ1qnRqKPdFDRwVS7sULK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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4lGkbV1oUq9E6RVm1KtvJMau0/WwOlVSUnGuQdehDvrKZxm5o02VV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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k8lG0XpqJSCqkkRWRrkQpJuChbqUgKhextRJKlJNkqSZYWSpIkZKdk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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs01Vkfxg+hYlBuU25hXI5YJZWRNA9K46W8iKIhUiTVITJpUokkl1Ah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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk41ekbxs9EJpUspcTJMmXfI1M0vxuZQiQ72c4YhiyFVEQlKZGlXR1N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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekbPpTGHl0mS2SZQqWYUlTq1qqFxq9pI2UJ0UK2GMooEiKSPak0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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VG8bxu1FylIkbUqkEhItli6VLGkVpcVOJEoqqZCUKVGEbMmWbD/J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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk81dkfxvVDpZH8JO7NWJqyZAxGi608NSGTspRukq7KvmQJZU8yQ1Iq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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns8VOkfx62Eipp6WZcoly6bGmKTyuKji01SqNC6hErRSsomEevShbXu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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lfkex4/INdFQGZqKNpdJsqQaxHyoSMM9GdMioewyFcKZaCE3kcgy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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3cgVQ0bR3rTJJWRlFHeiJKIJD+VMlIRskd2spJKimwio0JLIiorWUVG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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41Vsbla5Kuq4MxVcfB6UydTSQ0Lq6kjRIZShjZkVKknR0JVNIGcul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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk81Okfl1BshEIiV6ImlQ5XS2/kSpTYcqyWIkabzNboUqGlVFasW2R+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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkfNlKZmEKNfFI0pWUMxUcLcjeVMmUby9j6KmuSOeo4mYoKQ+RL
KipbOLaEbCFbOUmEcBwc5yCk5zUYW4MpRfM93x/v9V7vdb3P77qf+3cv6118
rNwlJSQk7tLn/2/LY62iCo16kIrCOsebBPauYeoGqXyc/LO3Vy6FICRtp7oi
pwr/OeBTcIZFsG0gbO2zOAHcYnU3Xxkn0GoP+Hxfux1Xg9/oyrwjOGwsNPUM
aoDyXWd163sEr/RPJLdLNEHixlzrfTrvxOij+rMeMTCVud6ZfpxgT1KOiat2
DbRYUkZTZwkCyveueJoohGWyV7DzMgapyVZc9p0n0J0fqIv0IJhzs4ji+D/B
8/F8SaOTdD7+GHEefY7n7qtjLp4nUDrC+upajRgeXtFkfAOD5bfSIyZRg7n3
427bfQjGyh1Ff9n2olgis8bImoF00cLLC9ElCFhsEM5zJ6j9M4BZ3dUGczkn
sWYdQXGz9GnLhHYMR+iHaU0QrPlx5SmL8WawHMLsnhUTBJrlrilvTsPtazON
/BME3zvvUrfT6sAvuY+k4qYpnzebOEsulUKD7zaWf4ogJr/kO4FdG9gJoub0
KAKpyr2JukMtuGGUr34xgaBS4OoZmiLAQGjcW6cWAt+kp0+Yey3g2U0/vFJE
MDN58IeUcCH27J4NT/6DoLTAUjEvvhatSyMSHa8QRF5wyJuor8WyuDxWYgBB
mWqYS4CkCKLI/SvnwICf0Hx5dXY+ZjjWS/muBDwzPmdy8iH+5SMbf9CFQNpz
NKf3eAu61dMu8TLp/Kx+4eVFtRiKnmqTpvw+eLnhxy3oh6HXSGFPM4MWleZA
/bZOGIZmdHgvELx+VS/I9OlEkNPs4vGPBD88VToiP9yD8C8dQw5iBh6L+oIs
hbW4GFq2MYXitYw70rLlSwa0+AYbDZ0pHqtjCaQ2CPGisFhjqo+QbVNFv+m2
IqbZd5VLDkES736OtHYXftp+lbtCj4Gb1budpqc7oHDr3h21eQKJP5eEdgqs
Me8l076dng/+NJa+X0oAl1wjcU4/wUc52b6baXXoVmqb86D8D0TkprJOs1Ha
R77bQf8f3BvFHnzDh+Rjd/byfLqvSIdz6nHd6FDdYVfxO4O1nzQj8r7tAc9G
WfErHwaDiz5Ma6eKYKLRl1e5kUH6mJ/njz2vcd6qZFT1IZ3fOW21ZPlrHHM4
2/U5liAv2jzPeEiA7r5Mbc0xAiurlcMiJzGSfSuz/e0YFNVrzhtxmxCuv956
2QOq50uHrhdMieAo6mstc2FArG86px1vxpDMg9N8ii9zg4XaDZtOmFpsqAhV
ZbDKWXh4wOIl9iWz364NpvoVLJruWqjHFzkllh79Dsop2Sl9tBaH9eayv1D+
pSo+c6siX2Fd6axU0m2CLK6Gyrv1TzGwylgQzab8u7p21p9shey2KP3TTQTe
Rsp6e80EsOCL/d2SCVjnapwkVdvQb/NA8tBT+n8Ce8y//DUEHM/jR+OpHqe8
K/Z5tCMreLy7mN7323WVf724J8av4ryfm45SPara/MR704D5WBPpzSEELiqT
+bpLy6HY7j4Q5U0w5C1pvzywF4u6p56GlzGoF578esaPB2Gqf1L9OYLRc5Uq
mpJ8vM/oKdxXQWB4fmT8Lws+iqIaegXUn+f1ho9PVqXh2s/9VbXUnxtj/CZd
FfjYZJXVPkv3U2D2t1tEVjdMfFOPup1i8O7TnKWyXDd4Pe4mNy4xGNt/ZuuJ
iUbM6Lx4yU6i+j6nHHT0bSd0xmz11bQYFBh9yi6UFYJ1oFZuUJNB9ejAVdsZ
EQwiXsze4DBo9J2oCuKKMDMxf/DAQQZDSr9/k+AhgCB6jckkIRhuCC+PW5eC
v2/qMFspPrt942PLvMQwKJLPCjnBwHtos9hxUzlqf1a88MKL3m+9n+3Gaw2Q
C4vbIaL+zFfUXOFk/xprU3YoNqYT7D3rYGywNAIZnP6R/1A92z/aw+VOd8He
fqb6FZ1nvzlbIthWjOy0Pa0jWxkoEYUAFVEtlLM/LFu4QP3zWPLf8jr34D57
QKaYno/s3m3O3OjGnNNvchqxDHZt/dzVe5nmVd0Sz2zqn0CBjsnnxvsIkMiZ
WkPxl17SGU4+xMfu1tvVtyge7pBvgC63AUvX/VZ96w6BiVmKyaM1j+H/vu+X
OZo/ZW+XaPS0PYQ9v0DhG5o/4bMOeWcquqBwW/LrbRYMhn2tJFsC2jD0z/P+
9hHKz0ezObWFGizXqjBbTPdvmhOl2OHVhKw/5gcf0f2MyR5TZiW0gGUrXyb5
gt5Hm2uvP9oNJanBwtwE6p9mHcXanY0oyfc6zL5OkPaGk/CdYR045me5nRG0
vy4maD3bKoK3+7YYDdoPt2r/zmwN7UbN55KHjo8YZFss1vZ2FKKKp3dXVYlB
Fvv7b4r6H0NuTLajkfYTXy/kWyYtHfbyulE9lI/A7ZuGDLSb8ClT3+kX6j+T
jzY9X+TaoHSQpR9XSOCpN2E8+Lga6/ScPs7S/ivdonKoTVGMtZvZxi9sGJQl
XxAnHulF6fhqbkcwAxsOp10zwAdaGVNsXbqfMgfeSsMdPOyYEJl+dYbgenfJ
ruCGOsTP/RPjepn287SXl/KwEK+Tfipj9lK/7VqzIP2lHau6XB7k0/4wzzKW
9ytsgotYtyCa8hernSuv9L4J+xbuPmmgfVQ8/nb1FZYQpv5OChfUGTxbmXZe
f7QLods4QZVU7zLWOQ/eB4lRdboj/EsaA7Xo3eZ5Mg1Q9NMfHfCn+c5Vy3j5
TIiQoyZ1slRvItWv55gDT3Ax+Z8tUbQPi1ZvObVscQ/MpM+56t5hoKvW7x16
W4B1fL5GPM2T2LrqMx4fXsJ+S4pPCM2ry2/6rn241AMfvxm11j4G11+Fpu7k
1qHkzlDwY5qvPHD3uMbkY79mZVgl1Vdg4/1fDd95QuFX6Wkdylf8ck1zpT1t
SEzojWTEFN8pfuhtxR4UOx+wNaxg8H2K9q3xTW2wu5y+S6+GoMYho+lTeRtU
rqazzKppHkfdX6FnVQN+4j4jdiA9b6iyQgu5EPLGeSNUv//luIUMd3fio8eg
urEUg/8BOWrYpg==
        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VP8XximhshQJkSiVCmlXqQeR8k1KJPuSkCVClpJEtkrJUgolJCkh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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk4ldsbPY3kRsoJuVxjhGtW5GIZSoYk0kXKVCpEqBBFoek2ITJFwtVN
ppR5nsl8HJmn833qVJJUIuL3/f7Yz372s9+93/2uvd61xF3OWrmuptFoD6nx
/3k+pdJeerwed1ZaT6zzIUDjQ4gTdy5YURlH//AjIRb7G6P1n3jkjN0ruHaU
xOhGb7t3zb04bVZiv3sziWHexvwWiX6IJkwGvqwaRzl/WoZzQxuCOy8XcVYS
UJ5tDay4lYS6zNL24GMkIn7t/fmp7V8YcF6UfnqCxJQHY6pEuxp/V1stB0qQ
0M7VuaH2kwmNEwrEOWUS8ZGiMeGhFYj7s6B9oYJA3Ffp/mMHqnGJ1zdqkHpf
dfJ9m1o6A8L5b0UL7Agk6IiudEUMwtIyJ6Be4S2296ic77OqQVyCu0XDKhI9
8fSSvIIyKIiJDSSrk3hYMHGxdf9T0G3LCBtvqh4PqbY14l1IFPhzyqOOANso
iGmsWYDXhdLGp3aQKPY3U7j0qB9bvWL1dKl4wQza207bYfAoHxJhT5DIdPjr
s5vrEKL09YZeJo6iVtVk5q5tH3J8FZpVOEnQ1pp4lxbWQq/JdGZ1IIkZs97Z
f543QzZ98YD/qkk00GmfTyg0YY45apS2RMBpq6e3g2MC0uujxx2Ok+CqbrHZ
JN6PfLlYjrsWBKY1BtpP5/Tgq7DogFMMCb3BHSUOBY+wPBeoEG5P4o8toZ37
OobwKfvg+NaQSbQ2n1yntNQNRYbSywe7WTgtLPOLmOuFT7pOmZIriXuK/Pb6
3QwIKSXLxgpMYuNUtJxtTT0OPevoF/uDBK9XXK2BXiGKP99cVD9HYi1NjkuG
uxP0+Q72yScUPlV4d7fiNZqUoqQTmkn83iNkxGdaD/8lJyvddSRe3ZJaNLMc
wL6AszbNKiykLGX16wtVYcP0i68nKTyuh92YTwtkgl30dTmIyifMCj6uHDIE
i1v13UesJjEQP7T2SGkvFLS3veecnkAh38Hye1q1GA2ukl+lQGL9Xl/J1OlB
vBSPVeY4OIY91vkPDRcaoH9evks8irrfLUy6ahcD4utdOzKEWWDPXXColC4C
EW0TJfSaxIfPi0FlT3qQI1oeaRhKYo/AnV03ZBrBNZXPHM4nYSTUV9gix4BL
mvEXN1USj1o2DWoF1eDNiP4+IQ6Kv4vFbtPKDMz5pzb4+RLg/bG5y7SxDDoZ
JsRfFF/beB5PXCpqQvGgs/6dCQK53S9kx+wG4O5xYbjFeQK0Xw8k/fKjcMbK
X34T9d9nxtQabvL0You9746bkSzwprqJ/NjfCPfIn9KJFL7aj177bj75H76P
NNpFWZOoUHDRquZuhabx3G+OhgSEO2Y+S1Y2YX55cp0ePwmX028vx9xvAcNA
woB1mMTfasLfQsvq8F1XiuOuLMVH7l65CPVc0KQjPFOp/qSvIkfjrQfw7HLY
wwsfJxCtb9gm+5SJA8KKHrZBVHxzgmRdwQAKkvQ3i/GSKDfKCk5p78Q++oTJ
0e0kwm+1aEU61yP2S65U+U4SO3gKpqNPt8G2XViPq5rAzTgDjq9/5WPCv/CD
IMWnK+8Fi+rVinHRm85OOEW9b/hiXqh6D9ZsO+QRO8KCZGQ93U+zC+lpD5jm
6wk4rPAoJZ4egKbD93//KyKhGi6/GBY7hMVv3/3P+0xiIqXSoTCnCfTzu9WS
VgjsHxdhtev0QN1F6vy/TCrf7fFN3/3u4vClbIlMZ0qf3r/Q2u7eg8Kzifqd
u6n61mQsZAnmYqXgbGQgtf82eqPFwR9D2M6lqVebQ+CbDiNUzaMXHOs7zfb/
SSCrI9vTaEsNhI98IsQdqfM8XOv3NuRBfXW/Bc2LRH5335Fky2YsX32eyU/p
WcCdy04KW3NgnR0tNONB8S+5at+tnkGw42T5j8wSyGEmSWY7taNN5WlPIkGA
S3WNm0NFNRLXjslrmJAonR0Jn3PtxWzmjZFkmUkUaevx8VcOIkrVZRd/zjg4
p06YHUsrh8y6mKQRA0ofus4sS29ug8w/Uhbyn6j/sP4g4H/9JfqE5o9FUPjr
OdHofGHRGDYINPJ3ofhl2xSvPtOF64mB42O8k2Bb6aQ0sZnIfzyor+VJYP5L
UJVMRB0KA8V2lFF62ibgJWfKpvTkY39N2isWZsyX0z0U02D0+Gyfpx2JY63b
2DEtPajS+6RMN2ThGa9r7pH9TMx6feSv+zGB+p2pguOahRjeYBRnk0zCYXt9
SPXxdsSM5LpaUni557hLcAzlIQqOaQ6UPzx/0F9itq4ZJttyPC6tJUH6daUf
HiqDQyDrggm1Hny/hj4z0Qvza8VaIRtZmNq6q7MrtAN575QPMih828ziN8oE
NOLXw+AKMy0SbE9JE5lndfhpfuXRCxaJnxmmXHVR3WCPD98nrhAY3pYmsFaZ
wnfcp+/MM8p/7P4zPXfvCQJuWu2UOEnxqWVhU7zrKyy9HLJRoOrdYXDKLrik
A9+MRK++KqP8YoOMu7FpDXxVHUQqfKn4pA+qGr/u4TMn3SKM6vfVcuZKZiFN
yDLkbNlwlUB4zbvSjNh6cB2XsyVZBKqKhk9mt/XC+HpeItfoBKIyde2YC63g
EeslVpkR6NJirmhXtSK88cODi08o/dGV8dtjU478xQjnH8Uk5m9PrgR1D0Dk
95u9PgwWDqR4M/ssu8EcLY2/nTWJJT/H2IXDPVANNt3suHoSmbTVPwtvdKFr
TffYYAgLUoqCum8EGzHqHG4isI2E95esb7vMK+B5TqFEgvLvHB+R9ADaEK5o
ODIst79FVEDCPrWtVD9w850oUaH8L2Suwz4/FXkRztNb3Egc1db0XGDWIPq5
fa2MIaX3nIJ89m8KkXbF28hFg0S6lkXTb+ID2N3RfkohngRjz2xQJzcTl70V
l+4nkLAWGDVXvNSCKJVjiXU6JGxdktcHJnXhIWGQt+rCJKqzK/Tdb3cjoPxu
0+1FAoMxHC949bqRrefFYaxCIIXDXiT1Tg8UfUqZl19PgL2F/vijawG4iZpl
mxDqPi9GpfW5PPi6751LlaP0bUzA93tCC8I0Yg5Gp5Bw+nFNlmtnE5wz5XWv
6lJ6eSj2gKFiC96QMqGzWpP4H24Tsxc=
        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk4VfkfxzGFjEJuuGVN0UJiVCZ+vU0lITLIT5JsZR8q+3KTmVJZQkY1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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8ldkb10JKSSZjnUiFTGVJTanp21hSKUkaLX6F7m1UGltJETeMNMoV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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VI/3loQ2EWmTpaylDZVKvdqkEIoUwoeypIVQWZIs0UKSIqGS7Mq+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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41NsbV6Gb3EgLkaUokgp1pZIP2iSUba5Euoq0ocjNaFEJIUshhUKy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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4lekbxynJXsQoUbZRtMiuwhcpmUzFzEi2pESW4SeVokZCJ0ukmkZJ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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4VekXVko0EinpSqX50WSSMCblTRoplw6DJJUSSRlq5LjLIAYJYXIJ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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VI0bxSetlpAKFZUSJWvkVakjyVJeS6RIIq2irJGIlCQllZBUSFEk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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81PkfxxXVEiUdRqstkbVNi027qVUvyWod9etiO1wRyVmOlHVOGleE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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs4lOkbtghJOYQUOYaylXGW0k2hw9JhqJzXKSNJq2yr3XLoaAulItU4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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8Vfkbx41kfiGVsVVGUrYsyWiU5MO0yzqV+EUkyTJqcBlESI3QwpSy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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VP0bxgctlIq0L7ZSkrzK+kbdKhUSQipE2SL1RiXakKxFqciaPVRC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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lekbxo9GZZgsZadBQpYMUlTqohOyjGiQqZREMUqWMSGVKYVEtNgK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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs41FkYxyexW7sUFSEklya3pMVWbN9BuZQ2KSW5VS6RikQUpZJQwobc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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns4Vdkfxk+liDIkpX6UGkp0IZdxa95UiImkGCEOudUclzAq01ANxZDL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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3kglGsbxhGKJFsiWyglS45KiC7kSKJEluy0SRSlhRCRSElIIkRyVCJO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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lekbxqVJ2YaEUIOErC22sdVlyxINaUGEbENCDFIzhFHRlGgmSray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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81GsbxrXzWk8rU0lRpEKlSLgsdXRQ4W3hKFmG9yRpIkvSCYcOSatQ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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lWkbPqMyQ4oihJAkIyR9WrRcMibztUxFTaZtrJEtS5xOprRQmCHF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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VG0bxyWJED0kUU8qS4uylUL5SbIUhVR2JUUhkopSIbImSngqylaK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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk41Wkbxy0NmkRmWmbEZAuFNjSU+hodb40UWcfaIYoUMkjJKJQlxSBk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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81dkfxnWT22DMjQgtlmIMNyE1GHlkKssgFc1kS5StUFK2Bi22RlNN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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8ldkbv5hp5YesKUvLDMlMNI1pkr6aKJUKU300UhGSELJPTGghEpIl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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VO8fxaXFVhIqZakoUpJKSHSElq+INkmyJVuRJSktVFKJEi0oS4kk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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41dkfxynZ0iJbhn4Yki1NygxFb5VuxhSRZFBJdoUJlZrKWErmWkIT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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns81GkbxhVaFVLYrSWlty0d1mEdkp1col5EpaJ1bqYt6bCVIltRJBqH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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4ldkflwapDBLppkJpkTBMqUk+FYmUGCYJyTomoiYhiSwxirrST0WW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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHc4lf8bNiqUilBmJfGzUlZUdEslKhoykiKFhkpSSGRntZRISSSbZMvM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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81VkfliZpGlvDULaWISRkCSmPLUnIuHbC2CpERQpNQxmi3izJFka2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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk8lVkDvmGkopHK+EqLcfmIYrhE5T5otWRUJutoEmMtsmSJEioJWcIo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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk81VkflkHEi4wmRZEtyyivvGnjESpTRlKKxk4ThmxZymRJltcIUVkS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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHk8VF8fRshPVEobKtqTLSFtHpSizZIWFZEliVRKkyRLWQsVUUqipJA9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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81Vkf1mCYxEhIGFKWmBYpCuVBMYWGUChxVa+MKZq00ExSZCtLKbRY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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk4lVsbxhGiU6aIEEJInBKJkjtzKYpCIvNQfUdppDLzkYNCpjpUIlNs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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8lWkbx7UNRaihlxZLCwZRyCDjJ2WpV8uIKW8NJXuaSIiIJEvWImNI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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2kglGsbJi2kok0l2aKkcmSrLF0SpY5IWdJGkmRLJ0XlSBRZI2tZE5Il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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8Vukbxl9C00oh1UQmQ4Ux1VCJXGQtihQpeyGTkX0ptNgiJRoVBjGa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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lekbxsuYkagwpBgcNenIlpRSwyVLmSylqTQSEcJEp6iU7VimJNSg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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns4VWkbxiXUUNrTVLaajyI1GecwTRO3mqIwjVNSGUKkyKlIQkrJISLn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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lG0bxlWUpChK5UtICKGyRTllqUSbhBbylp0UJZJsKRRZkiSJQrYi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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk41dkfxzEtRn6KsZYsJSRTSmOJeqtxxaQRLbZUlqxFdTOGNKGyFmUb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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVms8lGkftqwoOWRLUmnS1maoJWIrdYVWlBxCUZTD1HZEkdepaepNW7ui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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns8lOkXn4qiSEVFJGyh39qwP5XS9kXWttIil0QKKdpNdNsVlpQ2k1LE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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VO8bxodUshRJCZUklS+lRIq6kUhKStmSZG+TZEuIUlFSiZQla0hl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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk4lekbxynKqMlkVKIRMmGiJJIW36hhilQGQ5Y4JDTZkrKEJmXPTAmV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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk41WkbtiR0TTEzCGksI2vbJKJp3EiUCp/UZAktJMQhjC2MHKUwkSVb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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lXkbxr1nTMlLSaVG2ZpGKtlqJEOX9CIpISJSkihbTmIqQkIMIi3j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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHkgVH8bxSdJC1kKLYhQIZWlqMixJaVIVCp7ZOkXkTUlWpCEIlRIJZQW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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81dkbVpYkRGVIRpYWKSbbpKRHURm5QgjFGFtCKJqRqSxjmGlUKBKy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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4lWsXxk1JJ6ck0rBzhCKhsp0S6lZRppShZCjDh6hERMYM6Sjz0HDS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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk41VkYx1XUlEhZUsMQjaYZoqRum2+pSUpFRAuVXYVKskYkS0yJbJWJ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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VH0fxtHeo5KQLKVFSXgsLRTdPEkpeyUVhShUspOEUKmUSFnSokSS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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81dkfxqWMUrZGl6FJNWok0UKaqIdLZcgu/WSJirIbUcYaFWlUV1Ky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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4lXkbxlChKfuSJYZQWoSR5dNtRFGdBmGQXTRoIkXGIDLRIktkZBtL
U9GhkuogOcTg2I5955zzvpXBR2RrMb73++N3/a7nj+e+rud+7ue+Vb2D7HwF
+Pj4Mqj3/z9H+4cCg/RhqFtb7aQpcOB02NpEnjaAK5F2UW5zHKhck0+urXiO
qi7TZSk1EjMM5ofIeTaa7Zy1LFUJJDK6i7UC2nGY73XdSWMCTilRk46LT7AW
+L7BR4PE4+trmrv4mrBU6HrXiEZC37nS845mM5qzuk8K6JD4Dy3VUiakB8b7
owXCCQ54QyEifkUsCM6rv1ndTWLTUOZWo/QO3PFOiv49lsCiSia9g14L5f7E
RsYsATMxaQ+dtD9RFrG0cdCBRG6Gj37ZqwZUB9FXFj6S8Oz8c9WvkA5B+13v
3siRCLvXfOC44gA2i0w3/qTGhef+O6U7IgZgusXgm1R5Ht4dyWpoa2eD08re
LnOfwL3ba7GiNl0IlFm6v67HQ/bEQpS9Yg/idreVPhMi8YdM0+I/xQMIYd0p
fqHPQ9/w4YD8wRGM6kckSFQQYHEPNfz31QAuredocCl8Zp5PtMSecOgEpYXq
eZKQvn13smawD6VjQ6Ea7TzwDY4eb17oQsEEzaPQnAu5b6yXHGT7wBURsGvk
cGG2WBeWYJECQ4fE/fvdKH4cvC50XmhANNvgjo08Cc3KTfNXb4wg65D+7FgC
F8zgK1HLYTmw9zo2/Z03iWTWkb3S9FH4XPwN9/4h8dpDWFPQtAcdhpKXGyII
5G9PEBOYTYNrJ2vhFIXPvLfy9ohzEXL2aRjrUP2ZW4xGosu6cGI9vdhsJw9H
a3tc40d74DmZfqnoAAnfyeaArIhhPBj2LLUaJ5HeUVwi5VkFp/Vt7u7UvGqL
n8Td+Aeg0aZ/giNIoICdKRYU2Avz89b0rS48pNT4N9HKOyGx6XtdH2qehyra
UQFx3SgTmW6NLeGBHTjlrz3+Ejuz01SLfyDRu2r2VMu7HUnBLSm+0zzYRFXZ
up1sQMluyYv5HwgoMbztpzLZUEfbR+ftJPzQUCS+tQWyDxpnn1F6fJgZuxJ6
vgt75+h8Z75wIfKvjyYteRSNOu8cab9yEeJA3xER/wpVJQFCX11JXO9YOnC5
tAf8VZGW2SIkzDsZy70e46g6/3Vq4i2JyTCDwyO111HTrVXR40HCipvp7VLK
RL2C1y1FfhJzQXMV6mm9ePWh1tnlIg/5n55le2/PhklljKkopd8Pg2VCt5v6
YHA62uanBxwE71gsz3zEws3S8UkZYQJay457JZh9sNSWXqp4xcFFpXBR31sD
ONgmepu/mIv0XYIZwYJMiHvKCowdJJHY/tfM0IsBLEf7HQxW50LFcO2W4YZU
6CSe2zTkRYLM/9e7Tb8D9sZJHafmCewOydnjPdWCbf/ZH5NHUPdV8VWNbpqA
12/ipCLcSWj1roq9P9oNHdH3FslXudCQmlEedOhBQ2x0jbA/F3yHc39aYkSj
u2n4rBa17xhtSKY0FeFvR4eAnRTf748pdHYk90PsVfTHgAIeGCL8IgaynVg1
kpkOXSDwIjV9e9jaCErC//iF3DeKW+UVq3BqxM/01KP3qf5J0qvxqu0A/PzX
3D58GUewcrZIoy4LOhsOXFLRIyHInlTSVKrD6d+r2eKvSRz6zvTMgkkbvCPC
AoucKf5O7Pwq2cHCydhLG+Io/xATFXif19MMWktgbaEECb7c4IOWQ5UwPqzE
WvyehIvKlaOzGW24fDE4cBkkOG5Rgz6Ph6GRfWku1YPA8tRInK1VP244M/Za
B3FAF5MJWVJshozJ5gi93QTOjrv5r2gN42Pc9/nKQwSKZEOWHjU1gpV7rfAh
5W/0a4eMY+rZiPHvqvwSwoPcb3QJYbEaJKbcsPzlBImp9X9+UzjTjWZ7/UT7
TAJRutHTj237kTMsLUuroPxEVH7yYUYcHAXYwg6U3jy97BXrbg4j6diKxHW7
cYS3pIRf1BnG7FNbISnKX+WGjeyOsBsxExb8aILatxxHbquL5yDofpKVCTc5
8G5Y2RA0PwDBijHXxXoedAR0Ih2yepHItjinR+WB8tTyrg0l/Th3dtfa0kku
1ELd9VhOvWh4MxFOSyUh1uT+tUbqEV4+dj9WQPkFs+Km8ojFIEQLCEYeOQ6D
LU0xzaoDGIy/ZeD4IxdJJeJld+KHYRh/xqPAi4PCT9pv735bhUVa3ru/KbzN
22kkY6ENN9ZGVX4OoPJl41vN8QAmnhcz1hVGCHR1MC1iZurRWyHaVGdOwkHs
buZnSzaMjLrkp2opfu8FJwrr1cG2mn+zvwnFT+shVgo3BVon/5bTcyahtHfG
N9mvFWUKI9ZN4SSOKq3f131Wh28Yp1XlKH20FiRxi1L6cXTdX3BzEJV3T6oe
pHWyMXHqjcO2Fh5Wp0trprRfY5IlcGtjOwHHBbPGI/Zs6Ia+MSxZ5sFM8nMX
Gf875S+5wt7Ufph28wlm37Kwx15m0vAIgZnv+K5ZiLFQLasi429A6W8lI3NO
2w/iY1a6a9S9cbJ6FFnkr/jR3ffKOaq+e6b9xlPKb6cmlBeFnAjknZVcFtVp
RMe++hNP1giULam1npLrR6O3v2vLVh40prk3nER6sS98N82WQWA20mgMsz1Q
l65fMK2h8iXpdPkOzafoXZh630rdq75QaIjC5R6w650+e/fz0P9X5ayYyXOc
Vj82YxVIYjVy1Rj6zWBeS+d7SOV/pkD8hbM1Zfg33qhF34aE8eXxQbGBXuQ/
2cLMPM/Dl+MzNqMxg+D8KXRfZSMBZnWKImtzDG6fTi/7RPHBduu4rV+Th5Xu
Qo08R2rezwzXOfG7oC+rtvlT9aiBdPHLGSaMqke1N1H3sjjbk2qw1AX1Pcur
HbY8SCHxLKnYCo1ypzCjdAJ85ySizJpd4CLXXiZP4e+ff5ST5sJGX6r5i+gx
Aqsbxf+KV2egPCY3lN+XRGTaH29Hvu2HuYpbr+xzLmJUX25bPD6EDN5VWRNf
LnSNX4bZXOgFX6j61+tjXFxTtUmWM2TDSq28z5rKY6kfqn28LIYgcmIsK3Zs
Auq5DPMrUUNgp5BWgjQO/geYzLV3
        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs8lGkfxofo7SB5EdJRZG2Rdrd1KFyxqYRZJCVlHJpaVMzqRJJ2LYVQ
qA3JyJktIabIITVOUzNmHCPRe49FbSQ5rNJ798fzeT7353nu+3e6ru+t5eXv
xJZlMBjX6PP1nVr6Ic7MUAzHjrGtCW8I0pdExMgtS8H3Qy2z71gEZf6dU3uC
H+OUzqnkdecIKr/s3/SU24WQORNRRzdJofluwtf6gQDz8rYdXnSL4H+X3Q4m
hwvx65rjefdyCHKTbAafhtXBXctHOZHuXz2dMk9VJMbphEvW3z4hUAvfX6X7
dwsulzNrOPcJUhufut4Ja8RAp2e/OI5gTJftEbOnDQ98Tph6EIIerR8m9A0e
Ib7oYUM9h2BwxZ3k8Usd+NTMfRY9V4r0zLLRyLp2dFwyCXVmSuEh+DhXcbAA
09ese9y8CMJCd0efulOAsQ2T91routGnniFJFmFdQM7zkFKCbcmeyho7JVB/
ozDMeUnwztjl2C9qXAT9qxsZ7kFgYcT87BLbAnn5fS9taD4Bk+Wib8LawPTM
+2CnJ8Uc/hCj+mAriuaWG24fICiM+FbZ2KkHIdq9gaphUpj8Fnk7eEoM46rs
g/LjBJu5G7WrX3TDw+5HTZViKRzOZZ81lDxEjPqw6ho/An2H+Osem2ugcPe9
zavjBFj3KOJqIh/7/APbFoUTNNj5jRCOAEyDiiZuLkG8rLN50pscWPXqHQzy
JJj3XUR+/9Va1DnZyasHE8zespadtmnBxSoTjmkRQUyQhiC4hY8gWyVDy0sE
/IqMrM2lIhQvGd1p0ULwtHVmoq+xB8Wj8T+c7JSCUX754G2nxzg85Swje5LO
6/28l2XjfPRVn1FddZNAbL/DRG2gB3XLbIfWD0iRYHnU69B4J5iWO6qaraQw
G6tmhv7VBKu3s+mjXAJVHSN2/9sOrHbeYbGL6ind/Zrj4WWZEL5Q+WOG9ntl
irfnr+XlkDEP8i84QtD33Wj2aqtbWGsX6WtEvxfdvDpZ8/E2Pl1QD++n608H
Cj7fiI1Cnuufvm5Uv0lp+5wzZiTwmu3daLtAihP5KgsdxrrAnbxmrxQgRd8a
ZvFrKy58F5xN5dD9djkh6U1qz5Cv310SUUD1atzRKAp+jgchBrGNZVQ/WWXy
lhWVsGBmda07RjA1Untc36kaRkJWmhPVY1Sx+ib/MRG6mPYnmM8Imvlnnnf4
vMKq3PhjIpUBhOVw5XU/i9EyUC53pZHARDyze3F1PTRYkivLqN4zkmIadtZU
YWfgPU02nfcg01/Zwa8HNXuMVlzMp/2/rW19IjUeZh1syVlaX92Citash2K4
Kwced+kj2HWcV5D+SojaUI7t3/UE44gSZO7PhGN+estFWh9/Z4RDZ6oE4evb
+dUT1F8Fcn/X1/LANaxcPp/2N/fjrGqsTAO4h+IVhYkEpRs8L/j9IYZS7mpl
5X4Cj5kZFz/3WiQIjWUWUj2NX96aHuLNh55PZHx4DMGfvwftKzR9hkp9+zOf
IwmW/9bgUqDUjfdJ20b7eFJY/Wbu2llVgp/nqxj7HSaQHXKKr3vQgr7e1nD/
15QvQ+8t7n3pgkgtZq56tBQx9xJyxhNfQefItbal9gOQDeNY7uV14drUZvVS
Gyni/dg+Hz358Mq9MO0dQqAh7Cbc8Kd4cfRcx5zzBEpnYjN7uzKhpnP4lRn1
w7sDtuJQjRfYoHimTIlF9Vjv5cjoEkA9OeAYu5DO33S6YUNLB1b5CmysTGh8
GVbOYk4dfo/UHTGl53nYeD/3neThrCLODFJ/GporphvzO5HyvW3GWjcpdu1o
OiRNEqH2rpeWqIT68bGr9n/0H2NWbW1GxwkCZSR6nV8lwqnqNdFDlZQf8+Uc
43jtCGVrWaRvkSLRQp6/RSYf379r8umh+Q4xhj/3xzdj4irrjSfl6wHFsPPL
FduxPvbIffZ8KWTjgll1mp0obyqYcjGj+ujcWKbE/wkuNr6RG6k+gq9m++52
rcFRh3+kK2l8EtZ1iUy0gtM96NhD+aP34bre+6JHYHxiP5jwJQgpY6tvPv0C
hXUGq50SpBBs4+7l6dQgzz7AwTyAYIfGTO60czvunLv/h2CjFFtZzdrh7y9B
RaXXyJ3G42mKreeWPEHS/Ycr74USJEa9VeCpluBApEk6g00wUKIwy2moQ7Rm
SZbrWYIXpWbt+vIitMSdtFlM+bXp4dthb7ViFP7lyrek/2tI/onLSnkAu/V2
O7yoPivvGgTIKgnxeuFzbijlzekML4+0GzWoCV16VNWf6lGFnZdTJMaCNAvW
L9UEw9vPrjQt6MCp2J+LAil/KlXSXrroC1DD27hIkk/z/Ssl5taACGMmXZlm
QsozI769raQEAuE3+YY0XoOqmLMkm4eHSgnTXOr3lWmmI86zEpxqmkrslBJs
LSnULXd8DH6HjPlS6od1OfKR3nqNyPni+S75MuVFUNFw/pHn6LbXPyKhfG1N
u/Hj/iW1ULgsCF9G+7luJuKurGsrWI02PlGUF9GvW7bUfeyBvLh8RcAHqj+B
YnbUoVbIpz0RD62l8/31ZFfSHAfMClWKv8735kTk4pX+bYhndcvXrpIibWue
sUso9Wt3IH+glfK/V4/BEz0Bo+e7+W8uEIh8P2i7fWpD9vzUobsyUowf+69O
tFw9frlxfnwogSCzsG67qTAdt9103O0pL0b3Ri8VfigB26BjuRb165iCT9RN
UxHmNi/VjXlE+fulNNi0oh3TQdHOMj9KUb7o4ta9uSJUVd5esqSZoOaKRLHN
PQKx9UoVjjRfxi6edaPGLWgqlPS70vN9g6Ll1pt3Qml2gxZHTgq3nqLIaKcm
LLhqFbWU6v0Wy/q6z09tqFF9NGj+lt4XtWPxAg0B2hJeLpuTQeuLHd31zcJe
qE3G/MtPpvf99OSIlQwfWfw9NiO031Vu23ma4W04dtHmvl0XQTHHoFPNmPI2
TN2ZcYVA4WlT27i1CMtPl+Q4Uf3N2705kDklAjM6taxSRLCgxy19BUMCzcSR
lCP/0PyLKqaGes2RxIwL+dp/YhmewdIuhkX3wevD3gRtjn7b14w0oGhyi/kg
5fn/AXjdwWg=
        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lOsfxpEWQh1Hi0LKmiPZU5xulYpCKpW0WKIkS0lZKkmlooRUyF6n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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81OseHpQkhRaHOESSrRI3yRw93ajTImeEspPllKXDiFIkjdKnuKWI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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4lekbPgltKlNClCyRLIMotN0YNbRIOWXJHsYoQpslDWkOc6UkhsTI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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekbPsikZWaUUSFrMpbGT2k11V1+MjOYIjFk7diS0qHMZAbJSJHq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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHkglPsXxnFbJEVlKUu2SEWhunVtT6mQJZIlFcm1h0oSKgmXElJJkmQr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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx5EyiFBpWux+JUuyTKmMj+xRWSJCZVRCSIlkSpQtxTXKEqoZ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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4lXkbpqGMpZKobyJNRlR2H9OCW5FlLEmFRjjDSSGKscyQLFMhGUVZ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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8VekbJ5oWpJ/Kkq1oFCVZRrtv0RQmuklly3JTyV50LUmIuklZE6KE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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8Vf8fx5USFVkpW7KahKT5QjLSsJL6KpIUIUlIQqVIVplNKzvZKiHZ
yrjGva4Z9557r9USUqjf+f11HvdxHvdz7+c9Xq/na539JfNzi7m4uE4v4uL6
/1OuIXPm4FgPHCk3vm1fPgE50ZN/DXdUIK7zimzteSaWlG7/xi9MR+rP+V0R
ERx4cjmLXghrB6ffuSuqkAn6XL+4VHkD5pue+4iDiX1/lkXH3OtBgLBxxpq2
AZRF+ZWG7aViZY7SeZ9sAp+lOsrYv1tR9fa+vm0ogZWVCT2VXZ8gbTZBff1y
GIOfU8Xux3XBhX/YWOnsCC4czPo44FaJpL64lAMWLFhPTTNZUumQ4eofyPMk
QJPT11S/3IFioZTrd7VYmBCdlVwd24iYk++C5H+Q518fqHHJKAAzxPBB0i4C
HTo9e98y3mJ5YrXb3xECTnmy5y6s6Ubyx59BFWIsXLCOa1WRyoIz1YQ4YEnA
+kzd2TyXN2BQbR1ctQkslCtMavB3Iag4S+2hNQuGMb6uEdMUhOzeb5H1hAUu
028ZrcQhsHfsdlxqS6D869olPkfqIOF9qmV5FBMJEuWRybpv4fG+iFIwxsSa
ENHmW1odaF//e5UVD4EhJ/fViuodKH22w8urkYXvGs6/7N+/g0WpQI6ZAPn/
p9c0GJ3uxmiPsCpTloDyjBrRxemBjdmxJT29o/Dct25aTYqK0qgEp8+SDEj5
/pzU18zCyvMaRyriCGw1oy83zO1Gftrf8PXLGfC0XLBxOV2Hepm3mxcPMsA8
MyowY9GCoK3m0Z7qHDBVRNWfc7VBJprWqq7LQpBcvo37vTa85IuyMFEhwDaO
a9iWlI9zJZtPbjlGIKnr3VC8zmvMe4gtivYnYBqZkjlgm4M0nX0/TA6R9RQ9
wiWxUIGVNT4vWmgEAjrs7G33t0Or2ZCyRZGBUT+jJXMCPdidu6ZEyJgBc7ci
mQ93KHgRPlDwuoeFITXJp0EKLyH4X2hk4ysCh3qUnoVtpcDd0/255jUWTG1M
H6xu7ED86zcH3XIIyKjVIc+0E9Ne/DvqM5goz7l0eOTkJ0ggsOTcATa2Oyxs
lhR7i7toPqsjQcDH3ok1tikJtQvhp87aEFim/DD0VjwV1Icrss1EWJiPq1eu
76tD592Wyup6Ajy/+zj7u8qhkCD5xTOYvL/gMUaYzAdMVWs3MG8x4aDWZted
1oiOuDWb3g8yYZqyLdBVrAPZsYvptJVslLv7lVxZ/QlqdQ+2/bNlwmj0lqjl
jtd4xNsuddiAwFHbo2EDknRYnjpyTKiZg6Fnp4JUS9uh0uCbsUAMIfNzx46Q
I2+haY1+4QwCKWlOfEXc7fCf2RJ0i8qGZpH4LLOyAYLbnvVfbWJi/w3J6hCz
NnjtK3HztuAgbrQoYFtRE36MuyR4e7Fgt/pi8JaIdpT5pymtTmHBN83ALvY2
DQ57ZaUTyH18kXvB4/TGXjgEeMo4trDRwH/jsplmN5btnzp/9h8TzfW8gots
W2EZY5K2opuFtU3C4zUqtZiQvHyVrUVgvNDq8bJ2KrTMUtTGMhnQHH26y3yq
FRu6chqoG0YQ4uKxtfRqG3TD4+S/3h6CVepOz6eX+zF4aCGr98oIuM4sTAU6
dsNShdkWLcnBc9P1dlJ7aah/WcZJWTGMXZURjKjOanx7/K3B/xYLluXL01d9
rUetePMOqbtMcKmrXEu9dB5qlxWHzO0IKBWYRFvxtuOl4Gzmfw/ZSArSqxIX
eQUGN6u+7yo5vwicSNNLRWGLh3fERQJvnK4qP/7djKmdDVF36xiQ8zHisU7u
hl+h6mvZYQ7s/qy4GNz9BEsW5/dmkN/3pwYI7JWkIUbYw+j7ejYM5ajTA+9K
EJfzlO/nBBNb703898uMijgNtmRlKAf6jerBr/LbYVyh7zYiNgT6rSJZJdlO
WMWIaJVxM2HnJ/pv/7p6HNu+doNeIYGpDkGRuyY06AasO/qZMQSVwOXtf4e6
YNm5P/XVHAN08zyPntcZiG69MFRH6lHuxwDXVJNKKJstnjlxjoCKS0DQsr8U
uCrmXxKXYOHQW6P1b7+3Y8okcoLvBBuH/cMXX+XthP9nrsk3+SwIR35tfLKj
F3/3y51409GPUNl0Rha7D3vGz6QtM6MhW8LEkNeWCjnrmWVffgxD0/O36P6P
VdCv+83voc6CT132Xse9mcj0Ppgo5EegibXNW/kBDaF/UvXUIwYhHXNnzMqv
Bw6X/HoT1QncSo59Yr+mC6/UT7eei2OAZ3Rr2fXRTnyPcqUOtQ3BN+rC0f+c
u3FgeDiv7gADJ5cEJ7P2tcCAs9xNSIuNzayMDbMFjaCZpst3HGFiVoaL8kSm
G6pMye2O8kyU5vnHiEZ0oKXd6rZ5JIGI10PFky00qBcuUTQ6x4TwRvXkxsBU
BN2nXt3pQmAkmCHxwOA1/oYKeE91MSFeF7iTb18VCuZeBkqQ9W2+Vc4RoKdD
wCU3OJHUu92ZUs9CMyjkvvP91JZngLc+LnelfBkIVl5hjjeBWplZ+eKyAbiu
XXHP8MEAokTcTnGrpsKm5ZlpuBmBKsV1BWeYXdC62mnNfsSG9Slt3m8rGhEx
we1+1JSJiw/9vmpsacf+i9x+x6OZuNtkqx7aOgjnas361nUEHktSeAs1upG7
03/Qe5BAJlN3lmfxPUiFHL1IIf3NqHbP9NPZd3j63K57CT+pz4+uh1wS64GO
4RwtqWwUs0ImE7HjJbjGczGouZSJuB9F/x0z6oOLdCYfxntwpGGn1KGFZGwN
vFsic4b0r335vIH2TXg9tXVfD1ggjpxVOyjeAetPYjLWvxjwSw32md1SjYQk
C7fWPhZc7p8qX1NTgMbT7lGUAQKlznfii89TkBY5YyrSxEbbU67jKUItiJLI
TX30mQF9pUZ0bmvF8fPjlwXekn57U6JVprQCDULSQ7e3k/swEJ+8Wuo9dDwG
N6dOELghv0Hr4qJ2FIppjVjasBF4+TQX3w0KVqz58fjxLQZGGnQs6yOKsD68
VtHiLIHR5Vnxpy2oyM9aLWjUOIykLWONkzHVeGY/GW7jQMB97qdv1IYCHPsy
aiJA1lfOcTaEh12O3qcyEUmTBPzUvx1sLOqC6fR8ZeEmUu9tblit0PoA+rcF
5XAPFvn7M4IRrUV4+F1pjeB1At8TNwk7iNLhz7U886bjCMLm6qYNZ2vgXxuo
4OVLwIpn04d9dAqGpNI2gvSX0o+6FiXudFxdmXSGf2EEVRb34g3L7uO+krSx
oiMBjWu6rpIBvVALeb/yle4QTBNFvyg43ENY75TxYfJ+in0lV76rUPCWfaw8
kpwXz34PVT9aPZZHEqPXRBgkp33vFXTsxS9pP9nbSgTqlZjRfy7Uoww54ilX
SP/3zVXO6W+Bz6ODQZIFTBB0lRx/jyJ80pp6yxVFzj/l9YLtykL8VKUEONgT
eOE2ZsWRyEYEKy8iifycsuoR/3RtLUpXrAl2WiBwwfdBsv62bsSLCDsOupD+
vHBIMyzgA8I+77aPsCJQeFVEe+2Jaoh4R/4e7WdC5TFX8EPqe7TeO3zLlOQ/
Fcuwd3tOtKEneoGx9B0B7WxlOR+lZiTLHXwYHE7ej0/aRaO3AvNKHrOPyf3U
+++PlTJXO7rs5u8wz7DweMvvY0OFfeD8Uhs8mknybnnNHZdPdeg+25U/F82A
Wdmi+UTldryWeJL8yIGJQXHusV967Vh2nHpSu5zsH6/N3izHdlQ7bf95PYcD
7Ryd6oPmTbgmnWX8QJLsN22ph6TRfTT+eOxoTfqNmz5TNnEFFRkjSvV6Z0h9
riIm7lI7oGkQMKLuyIHLN9a/B+N1sGjmL19ay8DL5dwXFM/Q8FfZ6tCv/GF0
dMQ77ThfD8Wy5Esnj7PQPD/csbSiDVFCpverNVjIFBicsf+aBBUe7oOj/+fX
LWpBN0VzMFXFVJw5Qc7rnksRV23rce2+64YXNkww5sRouc9o4Bo0oh17MQSu
F9sXT9f2YMTJ9dRK9REY3RHeVmHxDicZIm8S+5jQIX6G3pgi9TX71TH7WCYi
k2kKSjYfwaNgNH6HnE/NDNNVtoF01Agr2+4l+6PtOlzj2vkRzE+DGywqSJ7l
yRri6GXhbvntzU7GBAKtuZMbo3pR5aueUc41hhmBSO3Vzz8h9u4hQnYFE3+3
vOC7toMKX4EK/ekhFti2Yn/X5dFgODH62WuYja6tm90XWbShvFFeNWMDE40v
TDRC1xbBbeeTlyGzTKRnu6Tnm1BQOxHPf1OPgL4c/fjnLy0Iq9BY6nyDwLmQ
+YPfTneC55ryYGo9B9ZcLiJJq7qgo6ArfuscB6Veygc2/qDicu6ec6tThjDS
ysdmmwygXlzC/rAbG4seue8+7tuBakrAoMCjYYx0no36sagUboGu1hV1BF4q
y/3ZJ9mM+5MG0eMGLKgIXnqo8KQEYexkMzMTAlyRj0KXdt7DseF79EUkb2pr
8zUPb+oAo3aXlZQeCzzZLzZJu9ERc+5RvviqIVRFqY+lpIXDN7dd+OFpAgk3
haQbvPpxu2mGa6yV5JGUyi9Hv0Th7E/z7+Okvy+1WP1ip1MdYtvzOj8tsKDz
Wf78kZVRyIqsfB51kuSZ+GTd/SRvzztLjueS9VU8HmH1HFS4PDnAX3GKA4qj
5Ujg42KYNUsuoZD6MrJCQuXCaBmsXv6YDCHzBMFVs0worRYW3rphY++YuL8v
+uca824kelX3691kQyx6kbPxUAd+RPa7Vs4wIZXetTtiSQ3SQiNylU1IPvYK
qNVTqMVWsW6ue9dI/dAX2rNOfwCrxC8Vj4T1o9eJdqb2IMlnzzK7GrcR+OvK
52CU2IGdzimJTpUs0J2t2Un7OjHOGNJb9JKDmOp7BdZ3ulH83drTd+sI3BVD
BlgF9aBr8w9EaZL7uEePW97TGhvvzRV3kPWjSUTwlp/rxJSwJ/FKmIlDihsD
NJeRfiG1dt9SRzLP5maZG2t24qPBfrcEdwbCXiU4b82ho0tpbfh5FdJPHqk9
N5prBo+QV/78Q7I+El6DNWWNcDVZ4tS8noXfgTE/51/2wT7Q18fehoOqwKCi
Y9Rm2NATYu3z2SguWTwjsaEaPPQ8wdhWJvz8goc9g+vgvMTxVOsOAnU77D6c
IvNeun1/gksvB+W7Fz54faHAqOinQ5A2C2EaEuq+n7vRuvOhxqIVpD8tnpb1
uVYKUxPGAaWPJD+ML1AnpErh/2mT8ckrZL8TgqxyrtPRQYu/HE3m2ZfNUeu8
HZrxJFM1pozMR2MLsa/cazuhW2ycmBk/jCnnpn8iNu8RFVze30v6labQ5UkG
ow705fmNrgMMqMlWTKv6leJo/cSCAplPKeutjJjH03FhzHhdAjnfguFnKM2y
GZBInmPYk/21taz0tdvfh/yqjBsi0cOYVbEqSDejw8TfDGd2jULi2C/Lnqul
kDP94dQrRaBVS7n7gjINnl/GlNtUGQi0MOxtuH4HopNWGpFk/05H3P0uca6b
7N8Bj+JfZD3bNdMXU9oRlNfkeYXMZw94ornzWJ14kVwzPwICc6vfWS6b60Tj
LvnK0WUE4mpPSYj9joMEzcjm9nFSnxU7VVz/1ON7ZKSFMMnb1jrqibbSNPiX
J1Z7RDDxRsY6NTC2G4OFXWlPXRk44EpXONPciXRziYuGX4ZhXfL1z6RkFqw2
+3rN7CHPfxKRsK0kD7sGC80Dc8k8+kCdR0a2C8056tNlsky85KngbqygwdJg
YeN1DgtqX+tW+XP3gMewKih+/TgSD1/YGztKw24ma/WqnBHoTNxaWvM+DHNT
v0LoJG/d+v7pSiRtAAINrjuz6wdg6kM77y6WDmsRloVrIAEP7qh/kTF9aFD4
mt3UNYyCP9d8eZyoCHmQoNedwsYUdb/5YAgNJwcTPub4DkOteA9PRv1NCJ6Y
FHQh/erNM0p7i08DTi5sr37lzYbZtUvCV6z6wNKtkThD7leS9OiVTaIt+Me7
9tmcOxP6kux9Co1diLnvbnb/CcmXn0Vy64dbsOdu/DdHkuf4W9aKNf+lonj0
V/Hk82EUj+3dHTNBRc7+zTE0ChMfdwdscSivwkdzq+J00s/kI3HDXe89RDfn
NvCTPOJgx7oVb1MPW2fBU3vesDFPY3UORfXDeJj/m2QjB6YCwyOcK20YUesw
SHhCvhcvPLqSqIH39oLgZB0mOcctBtXD2TD/ZOWQTfK3hINxpalXNz7p3D1b
6DICywTjAPq+Vvz9cHAuspKJfEWZ4/k7ymHxS1OeIPPKrFR//q8PdOybXSLy
p30YcrNfqaU9mZBLuDaa4EHqecPw7rluFzjJTHcYkLxhFnLESP5fO/rf7HCN
jCL7G/tBtVC+AnK3N3B7HmQhZuxbUN1cNVga3Z45VJJv6/hTmQXJyH8Wb7TW
lcDJzEDpVbQ+KJk61/P842BQWoF/2qUfMk8ybx9wH4docfQ3J6M22PdFCijo
szCfpiV2brgOoZknf68PJfnkq/AJg4EOCF+x29Tjy4ZJ7wPdRfataBRW/SUe
zEGCt+ZUnEEHXhGNRW2qbJTfi6B9ffARp9fskUtV5qDP+91hh3CSB96O2jZE
0RDWqRX/QbsNl151sV+QeUblsaz/urwKPOiM9JviZ0H3I+3b4Ps6XNzwOUC1
keSP+YsU6sEiaD6eGV1G1rvxpWKGiH8DVLWa5lyXsvD0y+X3TzZScGO2oLoh
bhgnqmLduAdpEDq6McAwmOQziyoxXqUPsDRSsNOwI/fFVD3ae3c+/N15Rw/f
IXk4+NzT2JUUbC01es+9MIQW6ez+576dkKD/9DtcT+6rhn6EAblPyw/xNthp
MWAguxDq6U2DQE0bT4YkA5vXu7iEkvk9bDKb3/RCL3Q2qxXkCr2HT1D+3scS
BJRUHaUiIym4dKRK7lEeAxK55dKiVv2IP+2yt1uNBdPSgpKApm78E+WYBXGP
4MXcYi6lvmYMyt6bvJ7IgnEZlS8ivR3OvaOzku5s+Eh5TL7WbUXKOrEbu7JI
PwoQvbbWYQD+/FmjO36ReTlyy/mbfnToJF7ftLLqM7jkpxqvtD5CunK4xCkn
gsxdJeGXtJvwQvnP98k+Al2vJbMXcT5hxJRP0kmAjVd8Dr+deTugfkObK4U+
jP8BI9kHng==
        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81dkbx2kRSUrCoJEl2RKlUuGjUmiUFhKukHXSQjUSooWUkDuqsSUZ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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk81VkfRqpRdywVorypSNEihFI9mEyRkIiiLFnKeEuUkEoivBrMlKQM
CTWh2816ce1bomzXteve+zuWQgppEvX+5o/zOZ/z1/c5z/dZ1rqes3YXExER
uUuff2+9ryHXh4y6EOBYNRniScHwzKEq37AEcMGvyzQlIEyp0iW5rTAbDg34
5ZgQFpZyzUM3XqPNRcs5q52AH2MS92PuPn4UpziEnSB4mWTnZfyNi+m3zXYT
MUI4X2lLFl/IQtYkOzPSkcAnvHy0ICoLs+Wt2YddCFr3yv4qFc2F/bH6hf5P
CBp+z7kxns6D9AmFeHV/Ib5zUxMpFTYyqw7HZoYSvHUKUClZ+xIzgfUm4s4E
Ckfz3TfVNsKDSfH7WRTKfC+5mkbWQMwlQnvTewr8fBd7p8YO2C/jyfi95WMl
Ws9eHWqG/7trnIm/hPCwyjdw+NqBLXMSD5boC3HycNaR5Zlc6HMfiW56ReP/
ditc04uF7TPJ0kpGBGy1R9fvjFeDlCq68Wi+jM3b35mdqEVLk+IANhKcln5a
ZOJdhKkQtVWeDgRdr03yPnM4uLwzXF77Kv1eKp4+v6sHKlE9NtE6NH8CfVZH
YwbOeHdLGVkTbLTwu6ty8jlyTTd0RPsRPOuammGd5UGDE7TCSpRAxzJ6o2db
HSpvNQW6BlPoOnr9paw8B5Myqotk9hCEydv3KZnk4VC7XZqiD0Gwyqew/PBq
uI5M7W2YoFDTzJie4VfgQtOLmDllgkjjuuBe0oyRqRzRsFoKuZxFxkQ5G8zN
igofwglCGl1UqksfIFNlpehrGwJn79u5T3cV4uWypQsiFQkChK+4u9vf4MPF
jZ0RND4SMakrn9SN9jRB4Nx1PgJi49vGdraB+A8ySrcK8e3pgdqfuM0wYHx2
2CI5CMO/brc9uFCB/WvmU346R+HeY+Xruvpl2MJL7e/QI/hnv+5Z8Yw+/L25
K0LiOB/GwSJXxtVbIal1zYLzVohIbRt9qcuFYDFVtm+RJbjDaM01yejGvpjZ
H1GvB8CwZEhsnmvHiBsV/SOdwEIxUGRsdzvKuozRvJ3Ge++3UX1eBzTtNNQP
HhaApXnms3hPL9LrJHnM22/Buu+V2mKbj+L6+LrlO2k+rDMWB67MgsHy1fua
vAk+Zt7Y3pLNg9l6hVhxJyFmXM9d8cuuBMuM07YniECsrXXstGofrFunPcey
CbSiVu1Iiu2Hlly6dj+hoKyuPe/UkAa2nOXRWFeC0QTF4HTLN/DdfFP1QByB
hKKiu75zB07FFhm10/+ttve1e/6tHYpSG6cXR1NYsdKjbTq3Gv43mZnvL1Lw
ybARX7ytFC+tv/HTEgiyy+dGPlj14N44W/ydlRBDuY/DTecHoBwomzH6XADz
/EwBw6oWkWY3TRP6KYzg44K/jzejNKN4g0O4EIw/z53TlCrHgW0BcTo0vrLB
7zXPfDtR07evviBXiGsKinsH1/WiJXaBeKcGvY97QbqLn1WhZzBHb2oVhYe2
cREvNtVDU/FgyXlHCh9rO1fL2j7G2MAjt8t2BEltF4cb8rl4x/iU+AdjEPr6
89asvE4EcXjlStJ8sFe9kfCN48DNMHy49xuFMOUKlVMjzXC9K5uocFmIquDc
UoF1K8alWsqfLKagZCkDy8FOpFc9rxJOCOHPdLZUcq9DzPEO4+6n9L6nav7Q
XVsJOZUHzqHbCDx1B3hN8lVwNak5kadK63nRm7wtegWIZael2K4jSNm1wOjP
qHrMfomaPyc6iI1Ju3XCaP88kg4Mcpyi4P2H+nX3SR6uftp5dOVVAZz44uxq
9OH7juR53xMDYO4tWbN0QSe0b4tkPE4UIiRDvidXuhqRVovU7xXSfh5vLeqM
Lkd+0qodc7Re4l+kDA+L8uDT52OZZk6hImt3T0VjLY5IR15wc6HnNajNDm3q
xeUPhV4rmgcw5mHwLkGpGXnjZuqbvCms3P69cGF3A0IVAj0ZBwi9d6Yxf3cx
NA+PHs9eS+t1m4X/v/5pOhDs1bWOglb6yzMfp3lYUjA6a1QmAPGWr/XJqcCl
1Tcl7RIphMgUHVSNbQLX7uxIySmC71+fRWSf6cNvAYutmIx++A3XhclEt8P0
f8rc/BICw6XdN0Y0vaH+80VmuBNBzrZHcta8KlzQUTO6IUbnEX9KUPIrF15S
gWU39SkEffG4799ci8G07A3rtWj+59Xc7NVyEfJXv8RmOm9WVD5u0dOrxBa9
7uVr6XyMw6XH2gvLEWT3Qyyxg8KdNDtTs3QODt0/aaaxn2Aup/BuoC4POztt
r+W84uO4UviLzXt5mLPma36Q5aMr+aerme/ZOL9Nf2ZsH8HngYnQmIwWbA2Z
ZP55SoizcmUGfNda/FpkvufIMoIplliIQlANkuJTLayz6PnDaa530hvxsHt5
Z4MTre/On9mJ1i/AuzWUoudJUNGmw9rv/Bo1TVlDt54J8eWL+X8KF8QjO8nP
aZruv/eNTn4qCh3gJDMmopLpfuqn0hKvlsHRw7DoNN0HWtQI2/UQF1EO9TlJ
hgJopmytcxTvxQa3EsbBrQJgh1+1UkEjRpK/2MbJDqJvdPZj6ckuxCyaEik4
xseyqITygYUtmH+a+kVthxAt+XZT9ytfoXDrkoBJe1ofIzkX1PfmoUNVY3Ct
GoHj7clXgiO0HoY6bQMHBQjtt/X8pJoBC7mLP99wJ2B1aOosaUjHyX1ibqMG
9P/veltz1vFQILujxG09ja/swfI59t9Q8S5nTIDgpvmbrg1RVdjvbrn+K62f
VKVHrdShFlQe3X/m/O90X1dY2d2O5GLZlazjFqcF+Eey5aJNYTHuZRfk5lAU
2McMWEy/AvDNIyJjNAjMlELPh4u0479nWxUzIoV4LzSJH1FoRdtnVoS1khA+
v/kFhUn24MKgV41KEJ1rT2aC40sSUGGTEFVF8y2e5eC72r8Fky5hjWt2CbHO
w9Dtq+NrDM/o2vzCpvuc6RBgNVKBUaNrLyS5FIpZjIfdve2Y0uCs71sohOGu
xM6u+DwclR19a0br07DC3LhYuxZLqkdfxX2ncPqwmsyTDQ+xpmb3gz10nrFn
PU0v0f5LFZW4Rmoo/B8ir8l4
        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs0lVkfx10S0xSRVzrMUMqSlCmXCvm6hV6ppgy6yZRcDyMhKZckFSX3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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lG0bxqe00GZJKJI2L16EVHrDqUUbFVpI9kpIpGxRslUqlaRCKiTZ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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41Wkbx7WOSJRlGiFU70hZamQf38ZIzKAminRCkhOKQyY7x1ZZ0ojO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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs0VfkbxlVqVOiYyTUUZboMZQyFUY9xqxzhIAyikkJyqVwyKpeSxiVF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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwdlXk81dkbx43R6s4kUk1UlkgqSzLRND5RQ1OaonVK9iVmXCqSpVy7hIiQ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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2kglG8bxRVK9iRJkkpKsqSUbEdSSYWkQhJSSSrZlZBSFFooJFqtSQg1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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlWk81ekbxk+WaJtJ1iQRiRGpEcZ2yZDItMkWskQioYiISUkiS6TJIGMZ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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk41fkblbSoCNGQVGpSllQqjXFzJNcSypRKyFLUVUKWiMoSWozSYg2T
ooQwF5HIHiPLva79Fr5LDTI3pEkZ+n1/f3yez/M+z/vHe95zzntUj3sdcBMX
ExOLZ97//7t8DaEMtx1H/lHQ1b9OY6h0jKVwRgC1pFFT5cskdLJFDwy35WBf
zMv9t/xplGpob5+/sx+Xpq+FK/D6EErKhRCtlZDZbSh35AcF8W+NkleXvoNB
2bBk/7/vsPFpvKNoQoBrS5omNGcIDIUdtM6Iq0ZsgHPV5GIaoUdS/xr1EUDv
dmFvYjqJrJEWDs+tGdlmJ0fU20k43FLNnG7k4+fiUysP1RHgnqpZnMbugdw8
U9H3LwRqSncF/PhSjNwH0yGl+jR8FC+PJ4p3o/tq86OzASS05liX91U1Y5uk
wTPzShLSJ5NPpgZ2YeFxyfS3KwiELvrR86vIC6Wm6z9rOdE4VqKqGDDbjfBd
Y3nENIlQiUt2tyVvor1/WvyrPQ29e6sjlfzeQus4/F4nEihzOxQ6LP0O4lbl
54O+DyLqwKjE/v1dUJeRFgXdI2ERFzXPM6EFyeckXLxMaTQujvHfyumF9e5c
X/uLFPoscgNTvnegK/WbvDSHgPfnxkYPsyLcSVE3V3Rn+Oj4O3PF3nJ4OqcO
HfWjIR+qyo0droesQf1rnTcUQkNqVixbKcS8gZrotDIKgQ4l1zYk9CLEySrK
wZRAyqfuPTpWQuSY6hRHBQ7ArPZ0Qwe7BFOya8v/DaLxQlni1zq7bnRd29PU
0kjg3hVJ7vCyHkzYs88q65P4LHR4o7+pE8qzCgfbZGnoPjvrdWJHJ7Kaiq4Q
BwlojW/j9Zi34nHhmNjuYgprFijO7R3OxDe9ifW+FjRGw/IPFyQVwTJQtyHa
g4ZzjHD4mFoTppQ8JO7foBCrXVJkU9UAlavGU1bSNOiEOfxxNT4KqmNOpHaT
yOBwCvN1hBiyXr8zXXoAVcan+ZEmYXBsKOv/yvA1Zu3r1z7VAI65xPL6SQrj
th/j2OadGIoYDHSIo1EbNXI+ZBujV49bI2nnKBToZpr/rVuC0/td10hxaMRq
1fAXrOUBEjveu61l5m/1cZPMq4Nrzh8xssmMnrfd6JZR6kCPu1JQ2CSBpljN
jH1TPOQn28wdqaXQI9qQ32GUDcNX1v5qx2h4Rxnmej2qglH2UvF5iRTU5mdb
qVv245OewX+X6gZwT7syOiinA4/zEmr+ziEQt9LUQuJ9B1a9+4v9jz0BVozX
687NfUjSaKqoYHw2dUXWpG97NUK1h2aaeinwQ2oTP0q0o0qj/c6SnSS81y47
FlEcC9GW1x6DLjQyBPq6N70FGKixcreToMBifdzFsWyGmqs3ZP+gYOm5xWSX
fTW21Do7aXhSKKrWjrhhWoupoCQFl68UOAiyaXvaBPH6+JP2JRQeXOyvS83s
QmbQrNUsRcBonZKdWwcfbTdGFpx6TUGLVS/IznqMqszyQ19P0uBwMq5KWT7H
yyh1lUfKTH3UYrPcYDvYqz/w/q0mUO4akVWwnIdjAVusLqaRWHVi14dCZp9P
9IWjjr4kNkaZdfXYVKJNOXx8730KJxJjgiNX8lEqt+56vB4NsQ+jnqdnOFjq
OWQgdKRh4vreoNCvDH677z/PC6bRZ/vEriGwBwUqwQXj9gyfniXPD8w8QnDq
Hr9Jhp/TPslxA+58FHUufJhSRqLxkOKcx3vaYHxd58wiUwoBwmjewC4BGi85
v68XESjQUtxGnC1HFsvJ4egUhSqThVLnrR+CODxkvcaOBk8lhV3TXgOPXJ1K
pxYKd9xLxyvEGb3arnb1eUBgbOJ997fwWrD9E/rqGymMjP1kPbKvGOGxR0JC
DGls1N7RX2nAxZr0h5nZpxh8GauSDT8y+vvATtH4ncLyrobFj1/2IEf9eQlr
J4HopDZfTkIfyn6pUlg2SyJQKHHBPISPa/FmsYXeJP6Zt5Pg6lZDmfNEq1uJ
hvVFo5sDWenIKDobkORG4/y13HX37QRIjPi9ObqCRIHb0MzR6TfY8tPMhfz5
FGwvRKY90eSh+9mevwqOkzAbbPnk5vYKPSXGFWsZ//7imzSs5NuCMy/TMgpH
STizvD02V2ThbbxtmL41jcGxCCNJzi00BnKzBc40dHgdv8tr8jFRY+7wkMkT
Z4sL+t91shAodcBdzYGZrzVS2pvDhY9qic9cIxrsF47x3mvegcoeP7xlkNlP
6yX9BcVvMDEZ+EPRhgI35vBWkVI3ktRFNyUfEjiwymnU0ekNnA9pKxUfpOC4
5NNxySU10BTyyS6CQoZ38v7rUk1wmZk8zycpBufYGpd9L9Gvn+5aHk3jw7zl
ev6iHmjdc5/fK8Xg/2Jxd9VAHWL9pot/Zvpth4zDwpUKkWe5aTh0NY2p+ams
dWGFYPXbRXRvpREuZ7DUeaQTfulcTxMNJh+3yrYX9NeASy5o/MjozVAQ4rnC
kgsBP3GzHYvGduqk/ihdjSmbTeGpORSmTrF+SyiqxHR8S4aMPI2qvcE5IuI1
FC58XlQ3RcI6yugy4dmKG3tUulyPUTA81Kp9NKAE0wUmipGJNG6/TH2ad7EZ
5zZR2/MqaSiqPHwap8BHCiV2x/YIo7fJmy7iuULMzHENWXqbyZvZ0OVRLzpx
Jkz4amQDAXbufJu7tR2Qz/H7cpjxj2Lr1YZl12sRNLfnboUxU//i/zn4ai9c
ZzvcNrsMwibSK8YkqRO/ilYG7FhIYUnuhk9zRM0IU54bz/1BQnLWard/Ti8q
tc75lmfTsOPhjuqGd2Av/ibRJD0ImWDWpezeJqzvjPThMfdxNP+3ek3ldkiY
LTEW5TB+nOa4bGLwFsvdls8WY+7zwZJHB64IMbXjbahPWT+MNSs8/Ld2IV2S
cgs3ZfK5sVjzy6kSxu9/5r7YSyPlP8f8Mz8JcNFZR6pLn4C2wEulxaEdQTfu
6RhJkxDY7tT7vkGI2fTo2zrWFBxUEy5PC6rw8UfT5VEm3+qGxhrUz7XDPJ61
/rguiTQltnKAci8OqyeNn11OYNBtkewfz/qw8E9SO02LwAOPeo+wrdUolnfP
1W1j8kJx1cEWmV58zxW41PgM4n9vsLyl
        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs4VWkbxvVFyhiUGJ8ODp00JKdPatNdhFLJFCUkbXIIkRShUDRNY5BT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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VG0fli1KaA/tJUv2JUJu5JVKEpEWFSFahFSKt9BCKaRkSVmikLco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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlWs41Vkbxnc5RtlSQomZVEMYBqFJ3ZQ0qRyKHOe1y6EcKhQSphwmoiQ2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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVWs4lWkbpXJIplQITWMrojIxIQ2yEJJDGrPJsajdRBmHwSb5JCMZpEjI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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk81WkflWwV0mJaVMg0ZYpKwqvGoUyvqegmWpSIyhpDkfG2TKiMVJgs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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8Vf8fFhpKQ2V9W0ZRspVU8qBlFYlSVIhSViQzkSYVUoqMKCsZF2WP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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVWk4lVsbpiJFCI1HEhGiHAkJt1Q+QySaODYZtowZjtRXGgiR6ISQobap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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk01ekfx2+2JktjGRnXZG2RpE0i8m5TRBqUEMpWDRGVZYxtpCIxOUKL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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lekbx6kYGdXQaVFCIUm/ytqk9DVSiGyjISmhpLFWtjAle0VjLGUy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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VG0bx7UJbVosqSilFNmlpH6SEpXssoSUJyRSeVCSrSxJhZDoUalU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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41Wkbx5EhJSGFUklpDC1EE6KvvKVSvNomHUsKEYpElCVCIpmJEqKy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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lWkfxlVMNDTRkN5k6cVUFCYJ4ZIsJ9mTZQgplESkiBbClCxFaZSJ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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8VekbV/lNQpNBlmrKqCwx8ZNMKX2bqLRRRAZZo2tfkigVpphEZLnW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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHk8VG0bFiIR6tUmWXorFKWyRLhsJVHhJSKUyFqWKKRIJQqlqEiiLGXL
XrJkX5Oxj33MnBkqlCVZou98f53f/TvnPM+Z57qv5R4JWzdje3Y2NjbrFWxs
/7/qDHnfcz/QgnybutGISAL1S9rpcXubYSCQG/xaj4D4zuRMF90q0A5pLEc/
YkKG1+S6O7MNI7PVu7PcaXioZGjtGpUJ5xWi9pFPCZzl71BKzqBimta813Eb
C4XrW3UPu3fBo0am+3D6MASNpou8ucowekj6v+xHBBL+DoRtU04E99pF7V92
BKxt3g+882uDjyytR2oVA+f2ntdWftKNvyOzJQIdBEyYQqJZ52pRP+pw13aJ
Ds78td15TZ+gnX29cM9qAmd6q2hTq3tQ7rHjPCWHDpkZUc4F/Vpk8FlmZC0w
MRAv9G5R9QuGu6z91epHEEboa+w5HYwoY7uKdnMC+es2P9PLqoJdb3C4wlYC
yp8dTL0Uu8A1t6Lao4KBI/py78LS27DqCq+Ukywd2fv1hK46t2PLyb0Lpado
KJurUxQ7RIWVicGHFDUWHgv6qSoMFIPPeduhCnJ9x/StCwfvx6HDU16feplA
n0eX7or75H5ytSap2wnonfugyLhbh973TdBjMHHWsnuScvsRYvy+tC+5kHiE
8F/Nls6F3+rD29p5CRyUNS/8ZVuKI06vB9KdCCzfeGuUcb4KZTEvnriR9Z/N
mtZc5i0ofaC9x/sCHeUKsSU21Fb8w8Oh8biAAbbR/lxWeRb4akeGP54hwM/I
uaxxoxR9zy2PzbYyEHTi0JNhcv1VxyYaPMbJ788VbLRIKoNHwB6eOk4C65AS
FEvpB3UF99vt+5l4Myx9a0yjCCnO2xvj4xl44hZ1QySdAkWF0wX3Uph49N10
W7ZEPy7leD2V72SCc57rFvvTTtB++qaeoLHAZhY4JXnXBylD/k+izhFgE31a
zxIzgeBk9I85awLl3HXxc38/ottLc5eoA4ETxpSKSo5+qJ+TeB8ZTMN8Rtrg
S5lunBDjO8CvQGDFCGOjC08j7pZMrNK3YyLmpf0Nd6NeuB/fV5734CsEt++f
rBfMhchS2IwBuV4wa6OX/XITfpnM6LzeRkBJd+7Fkmw74nsTCK4EOiZC/jGO
kmuGyA7l2/kTdAhVzb6xLeuDXpFJ5MGAYThKEsrGda0IGlfQit46ivpbdu8C
OGrx4XzqJupOBo6ePq8sv5yDS9zDAttVSb50/2fmPFmDW5eZxpVCTLxM+r7b
42orLhi2nAw9RPKDx8p78dNrbOezrFIgz0O8/yvdILMHly6OXp0K6UO5uF/g
PekGtC3qB+7VZSHhsMH5IL4iuI4JLarsJUD5ssomUZSC5d3xWlbWDLSEf9OR
vERF4/2rHsd4aYgwMhA8sbYRq12GgxvcCMgdt1pzfEcnPl4KkBj/wcKP472T
yxN5CDR8U+RgSoDm872Y789tBO5J8JQ7T+BosJWOWcxjnNBOSfo/Xr3WMRxS
M+1QWTd6N1OYxHPOxUVaxwLGp/n5ztiQeI5lm55sPIHXFV4+qmTtaGckKWyZ
j82bpR8sO5P756xaGW9TADHk36vUJvVImeO+zIleJDkpibM8mHB25qCwCXag
pEIw29VyBK64zjmxphvl5zPnxYKYOBg/M5fp1AZObm71B7UMPHMLu/ZeqwHu
4dzP272Y2PSjT+aKOgWjS90tVZx0OI6xGqJnamHeODrqPEPWwya57OlUsKt2
6XuKk3pQIHSA2VVF9t3h+BVzBPpblL9rRFJgHeCam1HEgsjKEp+tLdUoDx3f
aH2KgcaIndmD5Hoply20znYy8DkpmSO6qBIXQvlvPn5JIOkCU1JiTyEqipNq
Zt8yYC3NrjMq1AVR84s2TrpMZMe7arfovkNQ164o3s0EOPm7ema21OFNp/g5
UwsmOgw39vBFNmDQUsSo4TULR2NnnO5to2CRb0xgRIvAQ+7AqNOjVbCPFUz0
7mJALzbrjn1JF+plVbgtXjAgZWoyL9tTiuzB9Nk48velxLYu8Rr3onHFjiAB
KrnfnPGZRvc6iK66MhBxkImad2vKCkN6YZMyePlA7jB0p6tEn2d3w3WyfLew
LgGvtb66fE7NCLaXCtlO9j/NXVjzqCCpH9XXErTeEGjUtguw8+pGpJyG4rrV
37BdIHqntEI3dPhNRhqv0OA0yZVy3bsDCdJjAWNsTFyIHfdo9GyG8LqlxMT/
CDxZE3c4M6gDm9xetJtVEfB5PPu8fakWAg8StFVLSDz/meSoCqfASHvGMfwK
Azp8LR8/FlFwKr/I/H0ZE/LrB790ZrfjbxH1d+sKOuSVrQI22HRATVagNC+f
BampXX0Bd9rgl9O/8uZDOnLKxTfwVzSDCFXYvnKSiZWeT91+TPRgav3w4F8G
CxprnW94T2YiLI+r59ElArfT2FHF3Qyh2XfhL2KZUFG8zMUvUQF1SUvhrFuk
nj4MVxvfXofnC0guEWciIrIqxuolBa/NJt8sUplY3W5j3/ejFny6VWF3ThKQ
cpUxU6woROrafZdVSL4pCihLGp2iYLN24osJYzrYn+eW9bn3gNG97ZbhqTEY
yhRs5P6QgKdf+/WdzQgsRVPeb4xpxPvLhUsc24ZRK/WntMa5G001LYYzKSQf
v31z2a34BGJWmtZnyeftDddn3h8l9cb81N1kiWGcEVXMNuT5jMCe/xL641gw
EdHh5tEfwAXFl27y/YNgazhYM7s/HgvNqi+ueBEoKcyTXXuzE0cMI88ImzHR
pSu6w9u7BymO8Q1rPxDgiifq7C72Itqwe9bHnAHx7OaOQq1uOIYUbvl3gY43
XfqhMjUNMCgel2sOZyA/1UXqcVEV0rdwUh+vYcKdM7C/X7IHCcqJ8/0xwyiZ
fsVd7NuCE4EpXzeT+Br4jM3z729CY1q6ybNqBvbUefc8MOhAXsXeZqYF6Rcf
owWUVU/j5CLfDkFSb/qZNkYN4U24llH8p+kAASrxmys1qRuncuJPs8KY8C+e
OlES3I0fL4VrwvNGIOojCcuH2WgwTbTvCyZgLn1w/UIRFUF64r8+r/uOpA27
qzZklkJEiP3GHxoDJzjWmHrWdSBtKOrzx3t0zPhVlh54mgvxmDPdGqEEMrU3
Juhd6oa54Q6JksMjOGqspnHgbSP8ct8L9Yqz0Jv53yHpKgpOlBtc11VgguUt
dmmI5M8Flylui3/HIGtXILTvWSvMrR+63VdgwH+JdwuKymFt/tLFkcw/u9T8
FqIXi8Dv9JMtuoBAlIRk8BHKZwwqV9zZ0ExDeUj1kpLKFxxWluqy+02D+Mxj
1zVCpbA/f/o3q4nU50xqpJZ6OT7unFfJW09g7kKxidwyFSHj9QO6rYPg/HFo
+kNQK4zuraoMD2Xij4+l5uOLJP/rBe5FLBPQOWezhXYjB/dTOKcf5pP1F3+a
3JcGFMj1sB0vpSM5JmixYGYQoXnqmZZNg7iWunW7md0XKO8eNJngZOGRwu0m
rZ5WrEw2fivfSuI3Qj/+aX8G+uKKswf0SX3qct/1+nYuZtU2rkxNJWA4nb4v
6HYxSm6oaSUNMFDN1MjepEJF1ZEJyZDTXRBuPV4imPcZK0Y3TSa+YmBKQnX+
QnAPckrXRBU5D8IuDvNoakPtmRrIrhtBf7Gvb1BAAc4d0cy5s5ZAa3Nwb4JJ
K9J5ZgRj1ehIcnuZ/GzsKSI2XDLfZ0/AdJ8D16asFlhMGz16sERgIXj0CNfD
NnwcO1j+2ZaFOFO+Ye/QDgguxJpfbSDzw9+2Oy9vFWKzmGVG7L8EnvkJTk/q
fsbRjtCDs/Z0JLBdO1rskoJ3/HSv3WTeO/h+/fEYkk+5UoH+Nc7foMgx4C0e
VIafduafK9nJ/FPG8HWz7kMS7T6nxN0+hFh8EmrVzEftMSuHWDI/+Ph0bK0v
bEQs34bmaGuS/6Ytvk6ivnBY55i5ROYp84zgVfblrfjO/VSy+jUTY5LR12Qs
O3CBO7tU+zINN1x2TP626IbKY4dnZX4E1iuntQnYFyLWdrth9CYyb686v0XJ
tw71vF6Ct54zMXqu8gh7zCvQbBULt5N5N2yWfYfhLBXpe1beDNCkgqKuVufA
04F1FkYGS59YCAk0XTeaUodADX+HKkny+bA70rcMSX+Vt762WpmAZn34SO12
Mn/HXTzYLUeDTPflNRc/duPcvtbLPaTeZ3d1eu3n+IhigmZ8BgQ+n1EVsDjZ
g6h/e/+e+TEMarqphfxCBxIrZd1k5kfg32ZeeSe9A3+GfjQbjw1CpvLHvMrP
ZJTsyP99pISAAO9DT+JoJ5w3e7Y/8BpCtaDGp3DtOtzverj+iSYDneklx250
lqJ2V+Q1viIGSuxTF09q9+JKaL60oRoTH26zVh6ndkGVyFH7aPsN2c/DrLOb
WkDn+ZEeSuI5yvz61UqvEepWUi7WYOCDgoiCMl87ZC7dWnjVTAdF2ra6QagK
nrmbMF5P4mOwa7deRTnSjnZp1Q7Q8Yw66kXhyMbgNgE2/T0kXyvc4o/vLYCO
7u34FtI/3H89vT7rGwXVhGFaH7kfxUw3QYbnAxo1JYdA3tcxX2/pkUiFwIbN
Mr5XvkHDVi0zbFcw1FZe7RmzJfv3P5vfex5+QcQOX1PeIQLVxYaLn0tbMfh1
9qODK4GbZkMemeubIZhH8fcNo8MionP5rlI1HKVl7jl4M1FMefX4zaVmSO5a
k85Nzmfuwk5Gm3my4DgycaV/B4GILiVDelkhko+8GX11jcR71VTZ1wkq1GXY
xItIfTKJvambXEPFaa77T+7fY+EhV4jw1pJqnKLcr3s7QGATm4+GaEQbDNW1
tWb8mAis281z3PUNFI7Iig2T/cJnso+WMF4H6cnntp3ppB9vm54Wu1aBXOrb
jKFDDIydTBKf5m2HFc8h91Z+Ggxpt9Zs9XgJuV+Dvz6Qfs7+7ECvb1EP9DbU
ODbwMvGk3MFQhL0EbaX1hU5K5Hn8Kbsu+6AZ7Ilp53aFM1GiEbvm7YUmJIrt
bOCMYyIhfdW6O94xiOWMvaJ4gYBgn3TQhcwCfHy0gzX+noBCya48SztS/4Z0
IxtsvuGDbHVDZ0072gq2uSp1DMF9Uv6wpXYaXvUFTnVIE+AYpeipmndiXeX9
tN5zTAiunYyWlX8HV+/mrRqkf39g1EqKtJUgRWc+r8yXrD30VSm7U6E9F641
ReZ/Q5/wKbzOQklDo3jjVVJPHvC6h5bno2OQMdVyg8DOLD+x8zkU0p+KvteR
eZ0arxUu3NyPcl0/Pr55OjQUPav0HWvxMnHAxpOcV9jY268fm+jDPQ15vTRy
Xue7NW53xKwPF3hb1K81MGF79Hv+QE4HqZ9yx+Pc6EiUWpHyyqYN8SlywtSb
LLzhS2COu1EheoVLe8y3H4Xn1nzTqGnDLLe/2TvGEHbd+CM6zxWF3pVyqpfJ
76VtuMnmwpmO5fmf+xezyP3Nmjmrbz/AM0GKSg/Zr7Y2Vmf+5tdAniDkNvrR
wZb9bqm0vxlpeSLF0/xMfNOxrYA8BfY/BNqN1EcQEJfq73mtG8Mi5ktnfjHg
Pi6s7DJejgSvY24PHAkEsl+vHq7qAFuP8Qnnx6PQKDd/X9MyiNTdVdeZ1gMg
LD9H15D8diR+stI+0CEzXv3XhswfzGm29xFjpJ9W/Hdt6GsZBl2+JQRPM1A+
IBkSF/wZx2vEPy1eZUE8teP3zsAcCHFdX2KrIPOHSY3QqV+fEFz718KB1HNV
DhXuMjIPGhTl9j/SY0JDK8Zgl/tNVAfEKM2Q8xVrxI2h7tgFIbvGuuBZJtiO
2IiNq/lB7FNicit5P+TIlxs89HuI0uTYt/IsgSCPnaI2eq8xu+Lpy8lnZD8U
W9k+kqRCamWvRGsBifN1ikh7TCteiOgocJrSEH9uiMZT2IGOgHGDodUj4Dv1
JCL3dw3KJ656BeiR8wOzq7daqwlnhd7FfPp/nry7NaCEpw2vNX+fzv7JxA+v
rUrP1rWjuSFOVPE3iZfEjc1dNxwhw1x1cj+Zv+ac0jcaj1CgNB2Xz7eVCam8
6OKSiAoEsdLCKP1MhPSvyjhxoA1a34sEb5J5QS6D17TEoQ8uYvpLvHcI2Hnb
ijgkDaLRvf+O6tde0FruRkXRPqG3a6Qrj8xDb8boh/5J6ECOSslegYURrE7z
v2xQ1Id8jlNr8pvJefFgzPrS5Q5wV1ltLtk3DH3BmxxzVf1ga6JwWLAxcNxm
IOaCbg1UGgzHzEj/OlZvJSG9rxW0sQGFkrCvEEyu3qb0MgvFcg4ctTcJuBQ9
TbIxakNGytEVf////9B3lqYu+f4GtS6iy4nAyZuygqJf20G/nXY1htSn3mS5
3wuL9fD02WCXLMSAxgOdkmG2LHwq/NrtqkfOh2+OtUao1sDdZJ+r1B4m5CLP
rgiNTYBW1sS6YjKv9seOrvsSmgeWjd++B3cJ+Eu1RLw6V4e0SP/d7w+Q826M
8NnuN40QdpdgDpH+lOjn+d15qhm97aWTnmPDYBsNjlpQeggDjuW8JBKPvrmG
cl+jHjz028Ga/zaCuOre1JaQbvQF50T7PaMjrChR6pZ5OTS+/jVmXiH7dZbz
ecPqL5g6dO33u0dk/3EwevkkqsCK1miJTGJCZ0gw8ppRBVQSGgqPknr0k9vn
30v0XBxye24jzUNAZjKD89TnRhTs4tE6Hz6CDz7cIy9+R0L9FkE9TerlTO/3
Y6ZP+xH3bW4o2oUBGkfl7SnrAnisNVK++5qAioqltX9aA+zmt3xzPMvA0bPE
9b+aBch777TkOcvAggIvJc2/E7uCOZVCZ0ZhTtX5eiarGrT2N06LXgwQKc/M
M+TbMKnPvzP8FgOVgacln99rhaOm1p1nT0ZQc4y+bL+dgn9Hl31y1VkI9Jpw
fl9Qiy9pexOevqVjLsgng4/SDvUtk2tfeAwjSfQvpTevHsc8m/qXRRnYuXJP
UpVFHSIuRktfDGAgtd5/kXtzG771Cz08IDQKrees9cVdHRhs6BHR5WXg7PO9
TdqjSXBcPLuJx43A0MbxylP0blQufbhaSZ4/1fXmEv+DOlg8lv+S9YIF4cxQ
yQj+LmQ/UVqlmcyA4aChRFFpM1I862XvbRgl/dGsXSq+Ff985+H0PDiK/wFU
dwXv
        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk41ekXRxhbaBNGkWgkRLY0+GizZAk1kmxZkqiUopCshbKELBUJFVJI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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk81HkfnyIsLVYSqu1wdMmdcr6VDgqJVSLMKJsr16bIljNnRdGmknLX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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk4ld0axrcGKRWdBjRQpnSi5OijgVsynooGKg2mkFB2ho2UlOFLioqE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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VG8bJipLWUtERWVNQiXi55ZshQhJpaIkbSgRWSJLiEiFJJU2y1iS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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81Okfn6wOFfEj2daQIkJSJKm8E7WOyJXuWFFK6ypExEpytFR2NYiV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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lekbxpUWU0YhhTFlisb8KmSZpOEiKmSroY4tS6ppmLFEKUokCZUw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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8ldkfFkYkSZTq0tStMTUoGUskj0r0QcsvpEIaSSptQ6iMENpJlqTB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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3cglW0flkL0GglRiCIzO2lwSSorSUiUvF4ZRRpCSkaRFKmMiLSMVELK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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81Vkfx2+7CnkKyaArTbaENFkqn9QkKkuRJEIJZekWxvBMJEu2MfYk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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk81PkfniIpR0o3RRpXohDbhn10bGJdoRIlKUQ5GxaVpRRli5RNKNHk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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lVkfR5K2UZEaU2lhFEVlsr99GyJtaCFpYWRudqKQneS+omIIqddk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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lHsbxy2VJS1KUklKZUlZTjv5KrK02MIplV0JlUPJTlLoqEQhWcqR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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81OkXx/GTVCplo3Kp3FuWakvS8rEuEbFWg0JGlJlFJJRKUoskSVKu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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4lWkfPpVKGBnZSslMm++YUKRRcpMKkyxNE206GXtJxWCydELKkqij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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns8VFkAxyfVJo+NzZa1sii2VhNborx+GmrLJtJmSy/aKYkkDS15hCST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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8Vf/XxVW+lShDhSSSzIoiya9aKkVIQikVUqRIA5VIJGXMUEIisySi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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81ekbFSkhIcqoRpFG/EKDaDGHFCWy1JQKyZJlCJOMSMnPVpEaMU0i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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lWkfxokWS5YwZJlUiiilIWrKxdiGxkwhL0ZZEy/JTDLGJEspJSFr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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs8VekextUxh0qZ3CIMMpQoiW7Eo8YMTZpKRSEhOSQp7QyiXHYmJySl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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VP8XxkmLFtmlrFmKSLKF4pFUCEmKEmmnkGSrkEp9VchSiiRbESpb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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81GsbxiWhg7ZDibJUEr0HJ7RQXSEZaRFKjkKdI0JMC0papZA6tmzJ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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs01WkXPsq9lFRyG5L0IQxFRHlichlKGCK6nEEliYqYspLo4h5Gkwmd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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwdlnk8lWkfxg2aiqyjHEoKNaaaNzUV2S7RomE0SVGZksYyyUSy5czEkO2V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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VH0fxkcr2hRZyq602iql0C0UIdlTKBL1VLYeopQsKWVJeipJhago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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs4lNkfH1SqbZVcsi4RbTb35FJYn0wbUW1CLYtsmEpIWUVShBiXlEu0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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4lWkbJ0UL8kUZGUkb0yrKpEy/w2gZIVlq4owolaRCKdt3rFlKZWRk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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lmkXVvjGpKZFxRTFpLK88fqaUrarlBJpmiwhxhYaCSkiCklGtjRk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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8Vv0fxoUGCmUkqaRCpVRKS11FyuMRyioyHiFKKKWBcpdkJSoSCRmJ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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVWk8lWkfPpStYjAq2xRCmhaKCpXrKJUtYooWo4O8YxuhkWXkbQYtEkYd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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs8lGkUnoSEJNlVWZdcKmQrZCProVBrNymSS+6UsKUL5VLaSigJISuJ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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lWkbtp5pLKeQTA2TyvZN9ZWlheSSpaFo1KhkhJAiSyQJqYwiW4qU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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8le8bx09pkaaUJCNCNqUpHxUNohAhWSnzK0WRZEVJGZWEJGRlRCjZ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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41dkbt9XkJiRky1LGEvnNSKU0PtJQYycMCr+0TIttJJMREUmUPUlI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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk4lVsbxgl9xVHJcMhMg3AaTAl1C5kjQxSiooxp0El1QlHIkRNCJMc5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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4VWsbxpHpRIM0ExWlVDgqc+7iEEVJSmWe6csYJdJR30nlkDgZOmkQ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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VH0bxj2UyhZCJKUoiiQqQl1aCEkIIYRUkqXV0yIJyRbSQkSixRIx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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41WkbFg2iJFu2hCZLskQ0tm7fULJkClOibNmZSCtfTKJSUjRCQiUj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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lfkexylRFCoZW2TKklHTpqYJH0kMpWRLcm0t3NFim8mWRENMdkkk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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lVkDNsO0cLNl7CZJZW2yJIM8pZRJjMrUYEiKIRHDSMrSF0KyZU2k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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2kgVG8fFRXtCCFJ4h+lLG0qHGSrLFmSLYlERIlkL5FSiuxaJKIsIVsl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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41lkfxiXRmLxTRL3qbWxJtkalVHIbS2GkCKk3EoVmLGXJ1mDsxBCy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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns01Okfx6dcklzayD1JHZeSaKVIvYktW6pZKnJXspS0LllFTLbaFW0u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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns4Vdkfxo1UTCV+jAqpZIxMF6mmQvOqMDGEiEiR+7iEEn4ohxq5k+qk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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4lQ0bpyiklJAXZSSVbNUr66clIatCGSEhRVaKtCShEpKIhKx6JSF7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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk41XkbxknEJDUSCjEibdSrQjHuOtkqSkgpkYycIZMcIcboSJS9srXw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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk41dkfxy1lSWnaMFRSsiVNVIPwblCJFNk1GXNJhlESJtRYRlGWskey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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk81VkfllBTaYw1E2FqEBqSJgmPxpooIxOVLL12QumNQlnKTiYikWTJ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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8Ve/bxU1JlJQhSRISZSqSipakDCGRJkL9VP4pIkRUoqKSqWRIJQkV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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81tkbNVoohNSQSUgZSxmjkinjJEIqRMSQ5Q3ZskyTSlFRkhiVkl32
ZSKMsmb3IvsupLf3e1+RvQwS9fv+/rif+8/9nHuec87zPNIMD2MHbi4urgj6
/P/md4jY9wejDbIy1IArRaAmLG9WqN+DI/63p6RlRpDy/m+NdxtrYR2o5bop
i2C7bo1Z9vpecAcWKe9Rp8AclVfkCmuD/mCVlEgRhTs+Voa67m/xc4WIvOsK
C6v9Lq/99hcTAexbn9gZBHJynwKDnYowf9DWqsmGwH56YlvejS6oidXcL8gn
WMxjXmTs6oCWQ6pt1AKBkq2Zx2uZZixHpm9vsyBof+AePN+ZiombP4tscCMo
kD590f8RE+UN5HZ6FgWpkM3qW3zzEeFZ9H1QlyCjIbT7aVIXauMcziWsJZiw
aRsLUC1EUKBP02UGgSnDOpvXoxF3E+5uTLlFwShswWTa6SKiD6UpNNP87odz
Gq9vuwOVnA+Hd9sRcEmKJkja50LgUG7f9mu0XnU2PGqChdjyRWup5QDBcVnx
YWmhVhxPZQz2riEwK4hR2fJjKr6Vi372pf9LeWUh5svzBsGO87vjtdiYOyRQ
YtzRj5rIRCXtjxR49fUzlw0qEd/pYVRsRcDq5Tf1TSiFoFdBqcs0gZ82xdcb
Uoti5zz+8FACoeCzXZef3ccRxc78aRqfN21NvUNzFx74DX8R8ieordXpds9u
xQiz2yJrP8Gu0cdCdeGt0J9Mdu77StBacNk006UbPNaCXZ6faDzH1ZJOxX1w
C6lp3OI0AithRuiB7w2wPPhbUvASwfITzcrCXVUYbxJ2s6fxZuYeL3gF5KDc
n/t6xBm63hNaAbL8iYg0vNHaQvvFsOiZnw1oR/WBPRJRXyjYVvnJi7eVQM+0
T+pXI4LkrohS57he3PqnMEf+PIHUkg2n7UQPnG6XKn78j0LzyvRXrZRuaH/Y
YWxnR0F5ucAsv7IIcunnf776C8GhtRrjrwxawVx2/KH5Dl1v/mLz/LVCMJh1
7xjWBM114ts4D4ag8T6AeuZNwF9i49Ku1g6+nhsm4u8IdHTWzbVv7oezis3f
/7myoaA5Np4RNoTqnKQ7Ets/IELDUiH0bB4yd8X92u9IULxu2kcyph9/3VwV
UZ/Ixg1rMZ7Tt1pwuDqSvcaS1vdE4XC4YQPm5GpyuzdzoL2BFZfi0Qx/O64e
hSMU1MYCct+5lSEk5tKEszuBkZ3K9lGXN/iWdPzFBT6CIfaJZupUFjYcjRbm
GNB6PFabkgysRaJCdpWXGEFMZlpWe3krMlfv36NvQCFTV3VixbwSxm+yZnJm
aL1+1N2k69OJoJnYPXnlbKzX9On7KNSPW09XzqzsptB6LHZp/9xbuC0+/amx
h0Dse2+UoW8rih5dFkg5SedbbVE+Ua4fxsc78hQG2GizrdC4lViLqbW/h+T0
0PjX7oW93dmA1iups7XKNF99RYmRrgqoUmPcAxwK18y8BAWihyAocuX6kjQL
Uufl7PRUapFjL+i5ypAg1871xRDViY5wd5OVn+j6jiY6TaUPwWZjeualWTbi
B3Z2q37oQMNUdsm3NRyMrs8fafLNg/3cU58CJ7q/FiUfrg/vRKyar96DBgJb
H/JM53wvvvlFl7Fs2dAefJxre78J92M8o5OECUjTlR8cVkpglS9dPGlL5+Oq
Is+p2noMiu6JSqojsOLKHM0qy8PU6neGaXR+jSbL7R/NtKBcTWd5VQcF1s1V
V0qnupGdk2UeeoWNl3EmHb/bDCJvSKDHNJlCloCRgERZDTbKlO5KiqVQeeBh
slbIY1T2hogk0vmfqFcRtcvow1RJ0WmxOApPFZSLdGz6sSlcS7lcdAR9b03u
GEw/h3C1Kr85rafUOSkzwxO0/7PM+H89aD80jxmvM4tGu6PwOhGaP8lJLW7o
a8Gk1iWZgSUOcvTC2EyPDjzK/HSYkcVGVXe8mvqxF/jId/1BtzSB3hjHwlK1
B2XFM0OR9H8Gxskf/43owfVu8fklXZrP2b0ONvuiYOga9KPgOYJ+JTXN5IZB
PD7rNN/eNoI5kzjm2vJ+KBs1PvB+yQFn9Yxp6d4+jGvImgTFUFhhSMhOxw5i
5kKOD5/jezgpnZtR0azHjoIyVgGd5+NxB19f+dQJqUk9eZkONpSdgt6MJHdg
b+nWwfAECrlOOeyv452IZDAcdS1GoGdt36Z3vw6rnfOPXmUS7EuVWCOwUoHD
dixPdU2CJMME/aXcfhw5dH4h/SwbPgyT4v7pXujppTlc1+Zg/UJR0ZGTXdh3
4Htp+iBBjjN3mmZnD5QjLcjbYjbEV77vy6zsxXGhAz7ywQSb6sPuJp5sg9Pu
8ybqFIU/r7lvqXkxAP/Xmbsdt7LgFDggI1fRic+Tjvd2biMoGp5OeXgpFrHp
qsxZcwLz98rPJhJSYHxhZKGT9of3h2FnnqRKdK0aX06i+WoPF8ypZJXCe4N7
0go9r8rKNThnu19iMLrl373iBB91n/+VHtQJF6FmW5FmCjsiU/ivmrXAyi6V
a9GUwFu/P0OdXQ7rVw5HzZXofKjHz1zblYGX+vE+DnReuXYbq0aIZoHpzGpa
Rb9nWb+xYz/NwazX8rZGmo9Xm3MJh7sD3jVbR90uUigQdXMREWjGfEjBSck+
CmYKfsItS1UwstohduZPet895NUc8x0Gb2Xh1renOQjqUDz33L8BJyIkDv+m
QfC3ZuWOyOx2SHzeOhFCz2PWgJ83970KXNCWPmhOz6v9DmdGksYHsMHvGE+d
Dwv9UQ2Ll5hRIBWWWwLpfeZ5dSFWSSILp/iqngTT+Y6w32NUW9aH12YXZO8N
cjChXSB3+8kgDJJCn9s9J6gsCxVVLq6GDd+XwCBngrD31ms+17+Bwezddade
0fvEaFLRcDIVrZb/rGj/QTB/7hVrdroG36VYmyxnKYwuWcdEetfh5UNr3idj
FEr0qDrt7mrEGg0b5C1RUGrc7HzGqwZSv/4W4vqVglUpiWb+U41enzltudt0
f3ves+rV6YG4S1rksYb3eHTVsyWim8bvm7P77EXPj4OnfpH7oxP6sQsDQzs5
yKi4w5Q99RJs5chYJ3o//g+skdCx
        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns8lOkfHXbb2qVyjy6oFKHcitalk1RWbBfRijCuu2UrRLSR3FatxKKY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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lVkYxxFpZaKalAmjUhG3VKPIL1OKUhNuUcoo2ZeyRZZCsmeukm2y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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4lf0bp9TbHshIpERC8hbR0AcpI2VlJSsjKbJSQkmRRGVUFCLrVETI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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs41VkbNRW5hZRy6QujiVLGyEHCikEm11SjDFK5flQ0I5ehGJcQpSgS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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41Wkbx8XblCwhkaXSlKIkhUL0RRmyNZahGTJkiyJKE2oQyZIIJUZJ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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk81dkbx29lJkl7MTUtaqQQSmpaJh/8pM1wa0gZZCxjSbaICVkqDArV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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lf0fxumREe1SSZRIqWRFZVySItIiFYqGkaysh0hmFDKSlZCMlhFC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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81VkbR6hIKEODUTeyjYzJkpAv2mw1qCZNluxaBlmiSEqytFqSoYwa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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk81Vkfx02W7hRZCq0TpUi25tGG8bFVKpXsyVzakK1LWSpT0qBk7GtG
g26TiSyhkLJzi7juvbiWcu/v96uoPBRakHl+zx/ndf44r9f38znnvL+fc9SP
n7E7tUBCQiKdHv+fTURc/75QHjaGYQslR+FZ1ptljDQOgn6IluJuoyBhLffg
9rV+LCkwU9/jJgJjjf1+hg4fplI+XvnRBHZcMF2QOxuBnfeu20YwKRjlXL/x
/NVtqKjKbbl6lIKBfKuenEoTXCyXemz0oHDOpHLCZXs3Ns3/tE+gQcA74dwe
LeVmiPaZ6Sy9QoEzxokvMGgFT2LHOyUlCqwSnR1bFYWwGT97v65IBIknbwRf
N7WBf8MzdsPPJCT2yieF1J7Fmbo/t4TS9afsvM53MbowULHELKWQgEyVlgqn
ogc9I8E7Ao0JWI2bbs/9ykHH9j8Uj/iSMJjRiHzPSIVSl+Wy3a4U5qZZUg5B
jQhR7pMMVaOQftJCM9CwHyIVy9lbpRS+aH8Ym7bhI4Oq3FxL13fi3VPJuvgM
nu2HSqdGCeSax550D+Hhh8FtixrYBDQ8ZHwODQsxdSNHOfSFCAanTmz97N2G
obm2ifkPJCa8I+ZvX6/AtzQTVvZaCr1TfVFekkNo3AampzKJBccO9q05MIBI
lc1tYmUxNlmdtXbR4WLNX0Nlz05ScClpjzd17AX7ZoRkcpYINVUlnrfq+Kjr
X3d3/CAJdsj6kXadPjC/6+tO+IvRoR6aFW8hxK8aF1tkPUXw+DcAm9PZINbG
Ji12onDA91lv4iQfShn3d/NLSFDS0tMOl9rBVWIO7JclwW3oJBMiS+B5+oZy
9VkKze4rvxkbNOKq1Iy5iRWF3cFdpzS31uB8rPqru/sphHS+k5eW6gYzijMa
VkygKNuqpzJViDK5laHONgS4y8MbL+eUw/Dij7/dpPlr9Yz12tvdh6t2er/G
OooQPLVkSXLUcyjH1khJ80goNDu7S5S0I5Jyqu5tIeGxfDyIce4OMkVp3Wm0
f7PTTE+Z2Wrkhf1nyapACjc7frpWPjaIgYyw95a03uMDxx8nG/NxfMLmSDNJ
QXN3bWbmAiFMfxnZHEvz9G0kxT9mlxD77t2VnXxA4FVN7/Ki7kH8zlzot9pt
GK7rpDixJ57jyGsMdKbT/CgcZsyU3IWouIcdZkAh7lns0E7zcuS/Xrq0+zIF
DwPXrI8beLh51cokLICEjv0WrZMbO6D1VPuQ4BjN+1PHEyGhvXhofUlf25JA
TIbE9oX/9GC+qKXWVZ9EhJX8Fp1/eKhO/KY/lUuACDyIbQsFsF77Ut9JVYz6
vqXJBQXtqNp24/LiAhJmlGDF4EUBaucq9V7ME0gnR9xJTj2CkiYO75ehUGRW
GPfRpxfCxLRJxWQRHtYIyV7/QUwOVGq7y4vAMWevdqxORw2HaI+i/d3cqveD
lCUfy1XOKRRQBN75afbaNQsQtCrON05IgK2d/nnqHg9a80cN3LxJ8AL68X0n
F+Z6+7MPBlPYsTBvWJLmb/qxa2Zd/zCqis4V2+R3IGV85XxTO4EI1r+6dTFJ
8Ht+XvGdO4Xlquk23fICBO6pSJDTpWBzLPzhaCYXAZ9KtRcFEhC9Cs4zmuXj
zV9Xeky+iPFk2kta3ZqLpxPmDQm0fmKqQpDpqSZkaRqnqNhS+HO1pP3DuAa8
c2cOvGWT+Hz0YnZAoRBJ0bgst1CE7A8VO3J5QxBRelZxZgTUOivvt04eA5cz
bqxL+2FPXklT45WBs3Fl6JwlhdzKEB/nKi7eKt1VVVtPQhjA/mgqXwkF/znE
0Pw7fX6Qz3rRAc28h7qcRBIdf5TKP9F4ib1HqNVuaoPg2LEW271twuOumV9M
60kI3ob/HaVK8w6fRNtBMRi//TrqPVCPB8yEjOkCCrJub9U56zuRqtTgO2RM
QTdeoblxDxerrP1MNjiS+I9fGUM5tB3yXTbfT1+i0PjbhV/O7mnFmdSBvER6
Pe71PgetxhaYPrsfeTqTRN2KGn9Nuh/0ImoknmYPw4O7VtbKp5jO+zSNFG8K
XglXNb30X6Lgq1uQ3RMxIpzt3TIVy2Dn7ili+VJQOzmbqjrdh81ORVcalAhM
DEgb7WVVwS0jfJAVTZ93reO6SZ167OoJS122kwLBVetjuLZBK1h+eg+HxLUF
3sx/h5oRIK0QUu5AofZn4e48SQGqyliemq9JuBwfspZ404DfbaNdXG6RqLeJ
LBzOK4bRU8UPd+j3JPTTcUNniosVa05Y+I8RSJ1MubOi9iEkNEce+ZhQ0OBt
Ds+J52Ld2rEv5VFikNvC/nG/OYR5M5t0B+9hHHxOSrKt+lDKnK4NrBADBzQy
OotbkeqdUHhmI4UwuTV/5F0XItWg/9IBFgWtzhfPy28MIrT9qEMXra+hsXrV
GYteRH7bVZKjS+ArI7h13QI+mJl/Xsum+VS6V6+ZzO9G/BZDjup+ApExSY4m
e1sgfs/ap2VDYfXZRFGyIs3vW2bZuD3Nh+4ay06LFlitN5I7HEyi+Xu00hid
7ycPx73q06cQmdn+N+tBD+akfZ2dmkhcrN/UKlokwI9GO8Up1RSsjm16sKGq
EbZuHjHNj+n7HlmedTC/AZ4nlGRAkchkpZZ6KHTi25fz5hqzJAZfjn4UKPbg
0cyobRKd52oVW4MOjXZjxlzE6Eml8/ivZYsnskpxYV+MQw79np+Sik86/V2I
gnnhAdMOWp9PODPrBJhX+Zrid47COkUlDj+hFZEvc/9eSvv18C3OlzVKxXWC
PZdI94+HqmBs2EsAKvi9Rc6ACBaBH3J3tfGwKMUsmRwgYUvwTeUMG+HUff+T
pAKFYxd8pjRM+zFMNqnfeTGMTN85413/HULHx1vl2StFeMpO3D44y0PSpOFC
WZrnQu28e7VH2uCza8peXElhJMhbZiqxByuiPkzZ/0RAR+ZOrId8P7paJ6yy
Sgn8rLhTvSKWC0O1/kduMwR8kkbE0i1D0MqvXhzRLUK4zlpF0adGUBnu9ml5
JHya7G+FR/QiWqr6qt1XMUQy6YUoeATl9NvKH+n9Leu01lnk2oiA7a9Nden/
Spof47317/3olnzjaLSIxP8Az96u+w==
        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lWkbPl86kmVSEqEo31SjKEujQlfS6JgWS6LFRJYc+mT5+tFIjZQs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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk4VO0fxklFklTqVSmytSmSslW3JC32JbSQfWtBIUWWqLwtlGSJVJIs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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81VkYxsVMpJuYaVFRsiuRUiTTo1IjmghTEipLGQklVKgsg0p9MlEN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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk41dkfx1FRaNMyKiMik9JkptSthreLZJCliSGVvSlzRTU/ZV9qUEzJ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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVWk8lWkfliJOZWqQJYnSiYoiRU1vVztJXhlRGFuIimSyhEqJscbEUShj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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VO8fxSU7lRAlW6IoW1JK6SAtdkm2VIoiSyW02FNKJW2SIqmkQrZk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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk41GsfxoeT5SBapKKy1cEb5eCUjLpJorQIZWkQGkcopo6otBwOLUp0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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41dkfxy0zo5QsLZYSNYqydM1QxtJbUmMpZOwRkZ1IQsuIFvk1hVEZ
pBGTpSwpRrJkKdu99uW6LnWX7zcZSyHmWqL5/v44z/njPOc557w+r/fnbPMM
sfUWERISSqHG/2eRPAHbf0s/bK09gzr9SRjH+Wica30OQ98BH2I3ia4xfS3n
pg7MWjrdizQnMKxrfzSwshoF1qOpg8dJhIuseWLe2wj/9sQINVkCvWp2dSVq
rVjjLmKfChJyzAvuhqP1YJopJ3Hvk2CfUfbbvL0f+oOqWhO9JAqrKyRrp1l4
W77wfiWbi+FTQ7MGYiw8/lbSy8KJiw6dW0/OkUP4OL58cedHDsZS+ZoP0weg
f4AnXbmRC1Pa0tz43lb4XJjYxbxIIKo48WNYdw2C/jChJciTEIqPbgoJ1MWb
1r+7tNyp9ynd/ag63wZjsvr3N6F8jKX3GcpY9SJMSHHDQAwBY8W5P1ySf8eM
d3mHvQsJAY+lunB/AN0SLu0cGQKseE7aJxYbYyyTyr1lXGwZu1f11LALBZv2
utzVJpCbP9jiVtqJrI2b22Y7CThs+PnStdEhpA7Ez4nHcvEd11p19EwTyEPC
xA0mAWVhhryhUjKWHRJeFniQkBbqzxD6qRumS1eKS34kIHX4wIBwajP8PMau
ccIIxDAO1Qzv80PFn2JHT1PvcX3w++uTa/vxcM5GW3k1D67TPcdz9wxiRsFY
9tw9HqKWVzWVaDFgdl5qS58agRI0GrDSOyE/Ej9n0EEgfF/L4/JYNsaH2oU7
Zrjobee2VTvXwdY/M8MxloRZFmvY6+oQpOhLZj/v5cBC7K3IeX4XVglN5X8x
JCFuF8vz9+3H8/HLoS/G+bhQ+mPSuQfPsCB6P3wqlARtw5205pWHiNgULfqz
I1UPK3PuYHU1nOIFgipvyq8zypKSlwcQp0iU5poSiLcUOTT46yC2V8odk7Pl
4VTt4pLvShfFe+DW2fs8bE3YGnt7qg2XOBvJe+EEMmI8t2lk12E+2LtDX4sE
V6zrutXeFgQ1hz79uofAyw3RJsaHmiC+TsnZxoqEMt1WdrKwCqGtLef7ZwgI
uQTD4WsvgswD/jUa4aGDkemi8iwbYwSbVAkhISk0Gsi73Ysv23XKnufzoDby
SDkriwWF206BQd48TDT6dX4b14Qxp+8rXotRfiVd7pKisbCF05ZctZ8H9cea
n2qUGmCj3hRy3IDEyNKn27J5DcisWjuRSvFdFbkr4q0GHXpb3S+67SRgUSwR
9c8SE1/7V73+15SLm5VWBr++H4LHLzOsuL84cBDU6fKD+sE0va/1jy4P0XZH
dq1PZGFR7FRvmB8XHrRru46s5MBl8HXGiDMJm5EyDy/VInw3lx33cA8Jqa93
y2LkHiG36AdNUPXzyLHWa3/WhuIII6PLtgRGG04NMDOakbbuHfNZDnWfk5Zr
5Lr7MSttqB7jy0daplarrEQpEm6k1V2l+kVXct6Lz8fbcPVcl0qzPYGInFE7
5NHR1h3698wWAq5TBVJZIXXILQhf+1aTBKuS3mNX1oP8G8wPgngeKhRZBZ+L
OtFRPKZ7cQeVP5/IzeVfrkBHJ89o+wkSKg2WDxifW2C0WtWhuIlE4D9cVmHU
MF6d95JQfkki2jPHZWMDC9PB3ePBrZTvrybH5L9rhOKtrOdZLwgkrVdZtCzt
QQCReYB5ho/nT78pGovqwTaiqezoERImv0gxzy51ghB2fLRzM4lUd+taz9l6
zM04q76l8uW3whgUXs3A8O4RC7dtBCJXa2rFvO/FDpOlsgc0Powjxx//JJkC
fU8Lo1qK90ToQTO37E54Fon5xR7mo+e2+RVv60Yc8Tn2+AWNRKV4zfpzzDcI
cndjKFQT+GbBYu1N1WYM8zROTFD8WvrUNzXmV8BpxVUpRJlEVEaOq9ClPOhV
2jdbUf2BW5EiKrTmDjzfM12u2JF443r/8KuaerA6mYVK1PklegL9YMsuaH1K
avPlUPxtJl+t2cOCaIgWk7GJi1srJ50ld7ARda1EMGnEgylx0iLyCx2pvxkK
olcTWCcbLK8yzITsDqG7GQwefHIuJi/798Gwo+zGj7U8rHOey7oyw8KJDjOZ
Fmlqv9YdHz/tDqhNtsWnKRM4bGWgp6jFRCohE2PA4SPKPEjC1b8NtNPcz9VU
/zylc7oreTeVTw5f8Po6gcXq9XNBfj1QDRMtZDvzQe+PjxAt6kbA6sRJ1xoC
anIv9/+rwsCbWFpQWieJyHdHDnLMeuBVe5PTak35WahQ8dN8Bywz+X75FK8/
r8udtqC14EmNhlhQGeVTUqC2nB4bPbPlvez9XBiPTtuombRBkjYv+OhAoGuN
jEbKgf9Bw2W5aQdVbx23239vO/MG+8RUqyRCCBgmfsj5VqUeqelmSZZ/EbjL
mdXRHB7C8VpGVetNEjG6uhnS/CKo5kka0k2o/DPvVdsqJ+KE9vr3j9xINAnO
jgg0n+HY2Zw7CdR6wtG43OrmfgiP+8tdY/GQt3DdtEidBZt7D2I7eglolET4
xJ+gw/i0Z8BZFwJ2Sr7LF74ZxA+OT5Ts2W+hIa7avq+7Hk5R33f98pKAXq3J
V4FJN8rTTKQ1kwkccnBZjqK1IsHFyWur1Hv0pCpOvOP14azEkKiBLh8qNbHs
eZFuLNBX3eF38xFqudthOPcpFOXodqfNSRjQg6X9Tg1B/1W+aFwogSvBfgpK
bd3QmsrKny7nw41Qdx2vp2Od94Tr1CYSFfFhLNtjDbgjfumgsA+Jh8SniOxb
1ZDn7iz+/gcS89O27iPHXsKXId6Z9ZHivegTU+Zeh6tga4sxKJ6/bY8WLPYj
3apm3aZ3PNBo58tXNNKRd/DIhwTK96nO/Y4BcS2I8brhoHCDwPQZEyOPJy0I
90g0HxwkoSYlLyKLUvA4DdOplP9qBiqBKq4XsLbLbHCc4i8e+NqxIY6FFJm0
wlJ7LroV3JQc29uRsnMpnLWBxKiMuNn8TTZGPuzazPbgISa9aPFhejl2hnlU
tRqRCNJuyO7nPMdCgewBV+o/U5tpZVUHlIE/mdK3zZUE85oTK6CzD+wUTW7w
CT6+HKqXLfBpxF909abMqwT+A6E9xYI=
        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs0lekal9smhWYkKoWo5HShNJrkp9IUORgmkUQiEhU5llTjOqFSMqLk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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lf8bxmW1rUTJDEXJykjR1RQiktDSkFHZo1SKr4iMhpKUSlbTKKOM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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk8lGsbnnaKZEgpJSJSspQS1aUPHcophpNdNJEUWq1fURxCISJL2VJ2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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs81Gkbxkdaimz0InKsHErW6SVt4aImh6IsRS1ZNY7JqYRSEkqUEpoV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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk81dkbxy83GjTSJu1ESWkUTVT0yShpaBnlhrEvkSQ/kzWJtKksxUhK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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2cgVY0bp4QiUaneSkOyU+ovJH6RGRWykxVpqJAGSRKlQogykhJZ2bIy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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVns81NkbZlq3JLdySawkRG1KWf3E41JSuSxdXFaSdEGytElyrQxlk0pC
Kosat0QYExHG3YTMMJMQ8/3OpGRru0hK7ff3x/mcz/mc8znve97neZ/nLPMP
dT9Ik5CQyKDG/+f45HUKUV0NKCEr32+YJZD2OYDBp92Ha3p5q2Mwid8T2KJB
8yHMbMgJ6dknxJ749yqyFgOYSRpOzXxNokSxtp9hxEXXZWazVRABp11LtTzm
d8Gr4Uy+SQ8BH/NJR2WXEZQ2vFynKi+Ci2SrDHs5H3bp66cm3F5ia0q0nLrv
E6y2od0No+JnJh4vCvEYQtW0lz1XgoDSTMtsqlwVAqZ2OBfakAhQNFLjXW+H
9M5uM9ZuEnbvJEeti3g4fvIjS5cpAifzWVzGrnYszBte3MgmwXK5cHv7fDYa
9K5K2iSQeHcyq33Qoht2NM09MaEkIjdvHOu93Q2/uqhZr3skBMpN183L+9D1
j/3KJcMkfHoS24NzmjCpn5ikk0vimlb0vL27H+Ndm3LR4DoS0X5sITHLg2T7
8odPSglMvCk9ln2Ni02t2sK2P4TIDaQffZ7Rg7uF15ekbiZhzd44Oew6ANMa
X1uV2nEUpqq1KuY+BuPkm2eM2yQu7I/8fiilEefeX3c+4kytS7KSl8l3o2vZ
9w3iyyLoXtaUiR3MwOyCziv395PwO9U39pCRhwtZsr0uu0iYysiWBJr0YcHL
y/nxQ1Q9dwQsM3Gpx7OgjM9rA0gYO+n/z/+3AdhV1DzNdiThT5fmSBU/RanU
ncV6xiJcW1jl3H6ZhVoH/1VhfiSasr4oHq5iI4jVmuE1QsBq65SeqVkV5irV
Cn+NI8HRKkqJQBf+mPvB184iMfyJ4eIh4sJ6J2MqpVsICa7liPqOx/haNs2P
iyJRfvusPDMsE4UR37+E7SNRS89P1VcYgG7gtN6lZqp+d4xCDxg/gvRIerp6
GIkJ/1stq4QcSCh1gZNPYiz5jL5hST1eXd1rrH+Dem9F+oeO1vswaM6hG1wk
cW/qX9u5bVxI/Mgc3atAoF+4LiWoiYdk3aU1rCEh/jrbmHzaqQ1Ozmw170AS
LTYv7O48G0b9b28venaTIIPPL5J/1QjDSZUbttdJrPJ++LRMRQAdsWzD0T9I
OH5ybJMPrcbEGhODzyZUfofWO7I7BODfC7RSbCfgl3r4hlFsG858EjzXPEZi
feFPtsy6XhQUZLUmvaXyXaplpZv3HFvKrO1ntMQwvJC0ujisD+EtdR5p34TQ
jeGGrBvi4J1fWWvjCFXPKyq/ZLC4yPkilmZeo/A+7ckqUu2H2r6khPXLKT4W
+ZQN7enCzt11Qa1fCTRedf/S0U7dz3T4HDM7hn7XmS3Ce3xs9qHzPuiLwfTZ
cCuogQ+XxQXuRnoEWDojQ0tcSmFg73zz5A4SBqRh+61AHuDTHenrRPGXqUMP
tG0FTVLxOZ9DIsKt4py+z1NERap//BBBotnA7VJzKQ8C+ckX/xQL8eeGmhrF
/b2guXSJ7D2FiOtr9Ly2cxhJoYHfProKUSvb7PUooB8FQVPrjh0VImicS+uV
a4Zj3ohlgjr1PpOklHMNWeh4n2HYQvH7a7W3Ba+TjwizxdIufgTGTGRaO5Mz
oeVX4eFA4bdRaJEt84aH6qY6Kxsqf0378HqN4FL0K1yYv2gL1d/Fy3Y/ODuA
HfOZHU/oIozZb3lamjgEMi7S42gbgRz35YeiM+rQdo42V/2KgHmQiMVyrEbU
24MbY5ZSeMX3OG8bF8D6TuWa7hNicOTfzmfeKoCbbaDGNko/Mg3ORZlXs9DL
NbaIGqfied0PXHFpCL+aNprJvCEQufrgP4LVXCxZsDXbIZLAcdlT9JmrPKhH
O1hfvCrEjsTlck3azzDiWhAtcYREtUV7hXiYi83b5QYZCiSmf9aXN6APwFhw
QmNMlQTP2WheQUsvijIN/6w7TWLJnsOmN7b2oTamap6qOYHXRvTvIcwRRMYZ
/yTOFeL9hJt0jBIP0fT1br9GCqF3cvYUMz8L4umY+jIfEj/p2UXV2Qyi70TT
8pU0ApzwS7KWU40I5UuZVaeS0LUQbcnwTcLqeJlLBIWH0QEpOw4nF0ahW/3v
upOQy6lqfljGQYxUw2tVBoFyfZkEJbM0OBquZNhS592uxFVLKvHxWSt2y9oQ
IXxDuf8eutKGgNHSBxco/RjNfXCTsb8JeYLexDs1BKoYTprl2S1gJjvFLtIg
8aeqXW1EQAsSPonHF1H9+UjsqbmiZxDTjoTZA0kRLB4+8VuR0gnP7IPHdRkk
HoSxVa20ODhPC1/D1CIRPxH1IEUvCoJ2myEVSm/20ALmu554gWXhP75ofXuB
9NTyA9/6BWBqsNTV4gloTEYQN7p4CC1yOJFG9dtH+dq7Mtw0vFtbY6/oTen9
4l5L46OloO1b/MPSnETaS55ifWMnNvG+5s+cp/h710Dnr7RSlNV478ui4s0E
bO/s8RjE45N7q+Y2iLFqYo1UfFceyjK4U+aUXk+sSFd+za7F++KO36csqfvo
n6zq2RVIqDiob+tB+VfbQgd/CT42ds6cMfUSYvN9q37eu34s4drGBlD67Fnh
X9A+wgX5WHF0m8045J9rO9YtYKN426bhEEofbmoqcSvvDqN4V136QfEo9Jls
zbPug1D524NzOJ3EmeOMTK9TzfhSU3O+34Hi19KEaScBF1qhK+nKPBGlcw5z
IlEbOFemT9Mpv1ia9VYnX4cPXWav6qZgArnSNF8162r8aNFOGd9O7Q9MGlc2
t6KACJ/T2iiC57DVCsKyGbrKg4eKckika8caEwkd+EVXOSP3FKVvsdkfcwOb
4S45PS/Mn/LnaN9rC1+E4/Lpvl2RviQcXNJGuZ8FoHX97T3dQfnZq+BgOaN2
GMvwF+lT9TuyPVnwOqEXxFjCRUPqv1Bppx0oaSZAaifr3pu8MeiumTd0078E
4tcOXLUQEqVD/DGlf/shP+JzSeFnAhJHvgVtvuEN14rukDUUXhoKpxJLVlXB
LdmwXHcrxd/esjFGcB8qPizapJxB+dOuyqs7nz6HaNWAuazCC6yX8twbVsLB
xUKTcA87Ekp35LdX9XXC9GefY9seEfgPubu0YQ==
        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41dkfx2+o24gWk1KDLJVlmgmRmHgzk3UqS0byy64myogouzuISaRF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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lWkbVlPjlCRlmRotlomRkbSZlAsj2YZIXyKSkIpkUnYJCWEkaw4O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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k8VG0bVtFGkSRKpUJaZN42W7mkksheWUJIklLqRVG28hZSSQoRRYuK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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81PkfxxHlzFkoGyrnjtCq1Na+KGG3IuXOFkKiMlEiyRGZJCGxHUon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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns8lOkbxlFRW6kUsUjaVoeRHHJI1sVSIacsEol1WNVatKRkd6lIVNY6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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk81ekXvpkSbZaIaUVlSXGRaiQPWvj4kZCikCxDJkWpRCLrCJHBtFCK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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2kgVA0XxylKUSlLJUVFScqaNvpnKZGiHknITipL1oQ2ochOUXkiyRYi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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk4VfkfxymPbcygQdRkTIMxyNK0mGjeKpRUSOqWGXv1oC6RbIVKWcqS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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk81Pkfx2crraMUUSNqHeVqW52OqFdp0zWErCKVI/1mWzasxlXIulIS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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lekbPsSYmqOMiUxMWcsMZUnSoFsLZRiZBoWRLWUsIUumBWGUbKfI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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k4VG8fRkhlS9ImJEoiUslWd1pU/zZJQpJ2ImSrUJZISZKtkiSRJUT2
NcvQ2IcZ+zozZ8aaVESS3vN+Oh/O9VznOb97/a276GB0hY+Hh8eSl4fn/895
PbU2VlIVoik7uKedCHR88zNc0tKN6SzTZ39/sRF67sBPv9xsSC2zD8xXJPDQ
aLtWinciHDWkj5zQIED7FvRkU0og4g8nfDh4lkCRWDP1o3sXpHZ7ZB2JYYHg
r6y/MUuDz4rCM/9ECWRImkfL5eej/qOM78geAiGLVZ7WjbVDPuLAorW/CVjZ
7n6Vo1aCdWU2A+wOAp6Xx369ca/G3BlNVRPyfmVVX61oV9vAyngU1uXJhUX4
dHhYLw2Cy1zdCzZzsSH89vmWHBoCLCu0tZs40DuqcN+3pxapvNOlfeR99/Ks
iyREWvDfzUht+vIhWB16vHeNYSOeqPzgu+XJgtVXfybBX4Pg5j/3KILk/79S
CLZay4Abncc6QJq8j5DIrsM5reA/tOjU8x1cWPs8jf4zkQmeUGcfrhIBa7Uv
/LMFn/Fe3s75NS8BJdWdY1vFKzB3MkvyWh+B7aybezPTOnFOoK7H35+FhYuG
n7bVtSH04Fw6sY5ARUSXeZA5Hb8FmZ8mZNlQ6nrmxSuUC/6tV8tKXAjEZsf5
trzswG51pfo/1lxMyA+E7GmnI7o2s8A5iJyP6IYMh3MfcVty9lWZFIGlvqN9
M1cbMFcd2DNNYyOvqvzu6uw4uB3bQDF4SCBaeiN/0JI67MtQy9sYz0Q4T6Lx
KoUmcGuqapLyCOjwTa5fvZWOVSH9C4R02aDVdufo9bYjOuuAU4ImE3uiaQqF
ubVo+6qqs+YXgb5NzYGG78pxQH1TmuBRAuJWX1dE7UuAfHRlUegpAjIxEYE/
JlvRq2Ou2nZ9GEL5TU3tAzXQuuQXJnuDi6BLgaFaIX1Y32DweLN8D2gloZu5
nn043v4nOE+HieLtBZZD5l+gr7x+wdg3Aipv1IKa3jXilM22sgYQmFSxdRW3
rMIGHZd9/a0EWHZqKvM2dFxoWGLpcmQQiY2P+PpzGTBeIBn2c5aLnuruEz/q
itClZGuyUI6A5FyOx4vFdAzd1178y4UFytvzF7239SIyV8Mlvpfkk1Kt7bHR
Zly9o/WnIpINlqJh+snZHgjnmM2L8QxDPS+5RIfaitSlTTsSbrFA9alc5CrT
gfi39qfcuCMoznO87yhCRbb3owbrMAKUeJkv11md6DPOyzfbxkFszkWKw+cW
BBrmGalnsvGzw+2B29Y2mL5xDkoVG4aFlNPBRdGdsLe1tXAc4yK+KI4beJyC
ahW/R3HHCMgpT4hJbo7Cbc8O4qsNAe6HzzttrlSgdkdysJIKG0In7UV5Ftah
y7531nAlB46pR+z3lVdALqRfpOIWBxlWZc+dDzTgP2q+aaQHASH58VzvvgZo
9FDCFc8w4f1S18VEmAa7nZIGn6IGsTxFd3U+ux0mb/QPPlUn8EtES4dXj4Yg
p7LmTSTePBI1qneu22D/2LWQrHME3A/0Vlb/pkPsiteCaGYPhAREZuuJcnTR
QyQEP7GRUfJ43cLNbzHF8uCnk34yHlWmcUaVgXynLMbsFAem3USML18RGB+Z
Y2YhBNJVJl0dOyuhplpQp07yQejbsFkdUYuSgHwf/VoOJhIEFr+4VQvDoLVu
skvZqJfN/vvqbg94hYeDWy4OwHYvo1sjkoouftHeqyos6EUdV2q/EI8U3V3J
/JqkX73qYn7OTYJczNSFZD+SH8bx4REGNGhEqhjoK7NB/Te+pqWoEfu46XIX
qVw42Guw3QZbscgD3nmMQVDYv7tCrn0Ar/8nVekAAvGBiqsUUwqQ6bZ2149u
Ns48+FD5r7sGJmu8jnidYsOA4XKtcpwKrVBdygYLDuS6xM79i27AjqDmXQfV
WJjXTNh6yJ4C873WMtZLSbwWnG1dkpCKYq9h5ksHAhMRjObjB2oR5P/fGYoa
G5OjQ76rl1GQcOrLyZh2NgQlNwmNiKTC1EPn9wSJx3Ss+iubrZ0IuXO+8ahN
N+wGvg975fTArfeU7Y2wLvBFhT48qd+OBTpPaOZuXHjbrxz/eMALNHbNHf4L
BHzmLRxFNDpxlI8rJpU5BFu766OdT3tgoPzthPLhYXTzlvoImLbBo6Wqe0UM
E7R9l242v/0MUUuFGwE2HLA81HwPKDVCRnWh8mpzko85huueb3sPf9lEE5/d
BPSCDk62BNNRX1UUoR5NznvymmaIfiYksxIO53aycajkQPOOtBQIjlCHUu8R
+HKBkpPS1IXlCpWv17GYyL/JFBZckIOA2eJNp/cRsDj4gL2Z2oInwit3sZ6z
ST7ZWF141wzW7uGDDF82rAaNggNbM/HFTaJ45i2B/QYpIv9ONGH2W0d1Jul/
9apeog7NRbgQeOSAXikbYQO1p9a/YmB5zSfXhduZKKzuvD71sh3/2er3PWMw
4b6TpfLtdSvKUi9snSwZhNV+2bE6cTrqdE1ED/IPIp/78lj48xqUWm/eIH6D
jbIoaqi3Shlu9yx4l7SKQEphfkznHSocZTveHtrHwrhCvBbjZRgomsZ2HaS+
/BWJ9ABqLZwSdlSHSbDxAjvvLAvvQIQDzWAd6VeGv09vuO/vjci4x7wzJN48
RL3m/qd2ePeytjLZkoCqnORVtgIdXWWB5gWyg6BuHJpXXklDyZ9upoz8AAxz
ww9GyRQgx7qkm5VI4uEwcP5gRBWSljvahsyz8fSsSmVKcyUoDDlGVT4Lh4if
cbSVzXC0Gn45GseE5L8bN+bn6ajiGEt/5yH1z5V5oP+zGbMS3eXT4ixkzJwb
E3lGRYhG8GuL+xwMRegvTFCjg5J2bK+mBXl+3emCJrUG2DwtFLjNYkH9jc4i
S8dgzCfARP88AWM7l44rIS2Ipd1T1EkdRKPXs7czf+gg/qSqy8yw8CDasFbW
iA6L9w4NsRaD4OHrnipXj8OsefPIVUcC0ukDArVeNFhH3RfxN+HA7io726Gh
Gk7D7yjGawn47ZUKqy2sRuTTwbWM8yQ/n6TZNwQ2Q4vFjY4yZEPuYNSnkNB0
PDvhs7rBmewHTzYnfa7ohsKFz0sUn7VDorHGOa26D8KLXE9rm4/gsgCspyPL
cf7wzR4Rkt9XphTHm5RbkH349D2BKDYYu9Y8/rWvCBKjG+/nk/iY7jjcJKrb
i+1W8m9WTAzidp5vR+XvCkx8vFpRs4bA7FKl4ayPLXhpdulviRcBuyVvXFkr
mjETp/jIkPRvbtyMNVOnBFJSWjnGGzighR7PUbDoxsSFuBvP14yg0MOTVeTW
jCJx3UBpMi/K7y+Kcj0Wj9GjMt95yPM0On9wz7Ec2ITTxT9dJiBYdMwzlHxv
qC+xPt+f9Ju8oyGSz0shck/K/IcpgdoRu8ENKlmo1uuQ30/O4/cLY4dJGg0G
9fvad2eTfSrix82K673YIu3cekBrBDMKIhFfgprwV3me182DDT5ZalnJNRpu
h5j/DPYcxITBuRmxZ+/he+dU1SDp9wxxgbA5VRq251+6+2WCi7bOggtmldlY
/yk55tdzAsIvgr3dbTqwbGRA/J5QD47G2PpVuhdCI96weO8i0s9t70+bX29D
7WaNx8LrBxEjdHrJeCkdsxZbjTlXOVgpHpw5pdaEu+9i24uiWdDN279n29dK
/H6g/WCNIxvePKcU4mjB2HNOuOUcOS+eE13p+alkXlwJ671E6rWrvFHRR6kV
i10XrTtzl42QD1krTOSomCrN+DLqx8X5upR/2vFt2Ej0ygbacFHm/UKvatUt
lKYzAypIPi8LUp5Kz+pGn8BFmnQaB0oxg/xn2F/Al+zipB7MRrVPYpyPDgVy
+l1jFJKvsVJrsrtPP0KuS2aSkRV5H7PSbWPCefAOy/Rg+hI48bvU9Pc3OhYd
lNCZUmUjP/khdbF1AQrfW1dRPNkw1KmYWpHYhU1blhfUdhJYyWfH8tMvRIuX
udGFHLJP/Pg++fdzG65kf1aOsx2CzPbZnJDPdJivXduzJo2NqOM66t+3UBCj
Kynq9oSAm5O+XCAfHbEF31wMyT4wwaB7ySUm457s8RNNVwlUQ+/+ZC0DswKH
s/kUORC9Q2Gt3t8K/Sjtu2eVB7GtrPsupaAVW0ZnthVmsaGzmGnIfEL6yceK
FC6JT93JdzMJYEDzaIR2q+kQZqaXj3zrKIKFUXuBezKBF51LT5Q8L0aHi0Ab
k0XOX5CaPKf+AdInQ2N2qJHziY0calN6gNailGcBFgTC/vgtenfnE+QFg/7u
KyKgvN1eb58SHZOhvG+bJvshHu3QyJHOR+3Gq8NBEgTWHqJdck2ph/Lc0gyZ
ajb8jm06U8QuRpTVD/u+YgIzQnK0INp7XD7sf6ua1IsWTVj2Yk492B67jV+K
E8h9EJivPM1AcvPoo/69LPA8vDSMNgvEZxTVbiLxN12ppmkRnY24X8E0ObLv
G04VH6upy4NLYkuqijaBBZwQhdFrrVhq9qBOc3UvPKY1QvZYtoD1oN/MI2AQ
qoJBnZ5/OnHFs1Q4Zrwf75dZxJzZ2o7a8qGxQ1uGoHF4Vcm1H104uuVYt/sh
Ni5tez9FW5uNXZVd/PnT5LzDH/KNVLdind2hxj+v2LCb3CBW+rcMojtLPkae
JPUjus1yOqgIV9ZOtj8m/9faWcyoSqoKFkxF85/HOGjTyDm9y4OOX5qyfoNU
JuJbrv1Wqa5D+ppDZxyXkPoa67OXmizBCA8jq5fUq9wdhpcYP+lnx5VXRnoT
aKNK7xR9SkdvypHN+XMszKifXlgyVAAxreCNvlMkPw/9uvbxXxai7o/vUpYn
MDSfaXb3WRWKGzSXXRYj9wHdvGbP/Eb4GQ14mZP7q5y+lcXtte14/WNq/05d
FgZUz9bt+9IA68/ubxaMknkUoLPsg1cLHtg2v9YQZkNTOak8qbkY6Q1R/L0S
HJhzyw38F7dg9+stp95yuNjOq5w771mA3yIWrrPhbDj5UT9VnW9DvtnHhMEW
Jiyi9zTb1pWBdmuV+dhuDqJffPqeLtKDc2c/y4WPMLG7cGGXz/ZWGH/wvyG/
mey3azd9+7ixGP3Kr6Z+vmbjtGiLpe+aalhIe30IPU1gNzvSZP5aPOaX9S/l
NyHgvNXXwWhJBTYpXxFYH0fgUI5ns0YC2Rf076WJjrEwl8jd2y/XgP2RC/ry
htlIeu/67jGlBDfWTSckGBDYIyCnXHH/M24piOaWCBDIT8pw8vjahvrlx/+Y
63FwttLX+vnObtjvkBo6290PSubZc9d4GViZUOV6ae8gYm+dWH3ZKhFHv+Ye
OKtLfj/y8ZclMm1wKH+dYe3FBo+bAU3fPgkPfX7e2HeTwKtbsXb978thd3vs
xZoUAsv1NDYkF3SAN6jwWa0hF+MfTJNKQ6tAWS6mv0KAA63X6U9i2xtAXRBP
l3hM9oO0CYvmLDqKf9+U3viBhfTUOKYFTytULnYSee6DECo4PL2pPAtWPwe2
h5J8uJisyJOxpRPybXeumpJ+9+Kdds71J1UwqO1cn/qOgOXHCwJzwQysurF1
j3omEz8899sHZXRAQm1cfan8IAS12wRc95SRuZEWTCX9VvpSh7rhaB3cuwYK
HUi/flH4tyRrVw8CbvuwTXnYiHT9Jy13ugs89r8CrMm8HtkQe6PdnIHWWs+S
/hA24ncID0nYv8EY75yl1CUS7+Va1+0M6ZCQ9NTsax9EB+c4zzuvKlSuYVQK
bGNBeMRqv7NqBk7Grrx1o4DMA9ttlBXjNDD+XcvfWMPEzGwDT/ClarTevaL6
7w0BB3VJ0SwSb8qgw+avZF/RemYrZLi5EXoaQpKji8nzvz0y/4m3QdLo+KNb
gQScdmUN5ye1wiLc9FbWUzb23LEdZp9qAsU16Z7NGyaG9Ptr/5ukYOFQhMHC
YAIu381Ltfx6UJpw/MKHbFJ/ilqerxVaUbrU5Aj3JxfiAWFdJza3486BW+f1
RHvgnqN78uulFMT5rMyzJPel1Q/npeflK7GCOhfYqkNAM7Kw6GPEF2Sf2H7G
XJqDsp1bH1sHx2L+/SjXxIiAgkR69NXOGrhLLzPRdWZhz9OvBeZlOTj60OTz
UmMC98r87Bw39qBY2OiKciEXcswXRc5bGFBMyx6o+sOC9JxsbZ5pC2rqu/qy
yH2W8Wd400Opduy1epbvJDAIvwU1bU69tUgmHjY6P+JAXOGJv28ABXrsrxbD
4uR+8V3b+p0puc/Ezq00iOpF0y6++QNWeThZN+r8nbxvsZTx/kTjDigGCHGF
nvZBvKqu7v71LLy82bQ2kew/KqemmVr+NEjWnGkPJvUhdD3+Sa1TP27uN0Pf
yVY8DJt3n7mehw2Z1e27Sf32bNqYYi6QhiDLwks5YQTKVo5pGT+vR8/fkVNm
1qReO4dC3DtLMN7DcDV7QPrv63Ou8p1F8LVeV//1Gnl+if9z+dd0HJdYb2vT
yYE3zeDIe/NEiKVOH/lC4idjt9glQKUTdeeUJtYN9yO4/y5N26wcypqihQkk
f24uStBNupyKtx8MzATMyLx22ZzRsoSB/y7e1vZuZUJC3k7HldQLRUVCKayQ
je3r3yjfi2iBbppgnn4yB/FdX35ZnWpHamZn9aehIThbTvWMmtPxgBrLaahn
kXvy6fqFTVRkeITTKnaTefLt6GXr6+VoDMiOOOTKQVXEoo9CvQwU8Bq9ncvk
okj4QX5RaCteCkoZGOUOQq6O11o/oAbj6UVbsmQ5GPhe5EVt84fKvrYiLtl3
Mpr2OtGEKQheXdxJrSH7ruCht2MF5cgEpUtziOR3oHsBzyAdcpM/Gr5HcwGX
tXoRHj1I0D5z+ymZh0edSuhpW2kYEmkIuapI8nXnKt7EPzSMj8i+LCtjY6l2
vkhieg0sfP/9cLrDRqyI4IW0o/HgNm8IfO9KICJt//EdqmR+cL5TDpP7wf5X
xb2URjqCFud9+h7BBMN+o5BlQhd2KhpTFXLJPNuhrnT8Yjk8GesTWWcIOGr8
suWpaECuz1iEM7lfpT9P3x1xog0DORNc+wCyvwk9Tu+R6YKT0+J3fEJkfzHP
MEuJiwGfW0WHJNlf3iiEG1DVyxE4OG9fWs5Ghm+A9mxiK2LfeIRxyX33f7V3
H5U=
        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81VkYxm8oKklNU8pVlrIkjZSGyKNGRZmrmlJhbKkoS0mWJDL2EI1Q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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk4lekbJqJsiRCVtWUSOq4UJW4mhJAUbaOyNNkqMxRajLVB6TeDZF8S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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXlYjekbTtPQzAg/GhOpTiJZCmkh6S5r09CmfZMWklRDizYl2lSMUSkt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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k8VA0bRZJEIcRbIluIqFSUnJRKwpslyVbJ/maJbFEmKkuSJVIoJZWt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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lWkbx+1DvEIabWPfU2mqScivsaaOBlNIoRBGmyxDykihTZPRRiJL
dnktoeGQLUuW4XCOwzmcczzPwZRBTYSk93n/eD738/nc9+e6rvv6fX/XreF9
3vmUmIiIyEPq+/96RbHAuZkbCXoDa33KCRJu6wOd5iMbQU+V0Hc4RUKBp/a8
diQf072smpO+1P4mD58+i3S4Ha9pMXAk4Xu+Onv5Ziu0b8ckuR4XQuSxqPHH
30thka3U98aBhOS1toWwpjYUz2X7lDMI9K8J+8z6ngnDpzpB1upjWPSmLdL1
OXCLs7mpYzeGK+7eMSNeQxhuU2G+/UIgoffCb67MPkwqeUrKUfUc+ez2H4Ev
B4eU7ujmtvKgkP96wFO1GsdTrX246SRaRYeFbRId8LYizDyqCYhsnS3sLs+G
xCO9h54hJM7ps8v7aFwsWu0fru4VIqGnvuDqTAN+TR7UvXeTxLSn/aR5CQuO
gtxQbR8SvXSe9NRoNxh9uGbfSsJQoow211aE1KDXP+cEk9CveMnTGxxGdO76
xIK2cYg8Oeuy6OOC5cGGb/d5keiy4NAyLAeRcuwg9UPC20b+qFRsF+pvLicN
zROoquYX1naNYuru3Kt4SS6u1yXGtXsNQlQqWv+QKYFZWsa+iqpMhMaH8SQ8
SCzX3HcKH+9FRNaiMPQ76n7KocoHXXzQmVyXk0bly+te+9f7wja0xnuz9EAi
yLY9T4V9D8QJq8NlniSyHScld/zDhdQbH1/NGgGCpH2ddk9lI6IwYDb2HAlp
F7t2jmI99nzHXVVB5QsMKI+M0RhGCGO/PfFCgCcmkfa38lmgras2lzYkYLQn
Tq+D3QUpnQWasSqJYj0NB/O2Xti0RqlbUf1b8Psw2mHJRu5KqopV/DhCX+yv
f3GjG4dmXqyOdRBiuePgu4scFl40626plSdw/43xVppMKyZyjhydLCURoVHw
Y/nhRgTfnFFNovg8Zxsk3nyJAQNVNbG7EkLQUpaerSy8xhpG4Ul3dxIieueO
msUX4YnDaE1YLMWrTYDYeF4ZWFZ6X6JsqHqUG2W/H2jB6g2JvzpGkig9fUHx
QvYbdM5PKBmNkWD7OdI9TDlo+BKlSbcn4bh+192UiofIDq+zcKX691oifI/W
Ygv0pU/KveMTWPXrnSpR0V7YDmuqJwUSSG9NLJVJG4JuSsJSyT8kEm8kLTR9
zcO/AboPRqh4E7/kukYfHgL3iZfaqXo+nllpyn3e2YKq5C7lFao+fnVmTDsj
AOviH2w8Sukp4jghODbwG5rWMB8rUXpI9x/seOjDQYK/5voZPxImn/ZLtx99
iSz6z0tO50k82Rk3m0BjIVqoUWgROg6TyDZ+pVwdnLS8CgUBVPwf+t+RZiU4
HLUt3c+YBGM6338ugIGon40WzUwImEr9lqGXw8Sr80Nbih4JMWD5ziGD04ik
hFXb+RQfIs8uOZqV1cM0YIfAqJNEKEPr1NfAYYRuXlrJ2iaAsp3YF04zCz23
zlZWCAgMPJxSuzdJx0SZ7WjINsovd6a0JVo7sXosatKOmgeOs+Wuu8UKUJUu
/VzRhdKryDvB9FAbVorjd6Vcou7b9ajse5c/YXGQGRtxiMQNPbvTTYalkLjs
llFO9XPZw0Rm0xkGzL/dbMR4O4Z1g0my7fV0jNxxc2ZnU35TdhGIOvUhmBi1
s/QT4snW4AqjTBYGgrh17bEElq89V5D7wEa6KpkyOkrgakzthj3GzXCciL4n
+p6A+aiNVwyHCd6KwpSL9xjE4t2if+GPosbnaNY/KSO4ZTXY5Fg+iDVZl8O3
yIzBqHZTSxxS4Lg2nf8XxWN8gPoWGWsGlnOl5GuiKL6Ktf5+tLYFStb+HmoL
BNwpVd8qsbGZFvCHuBuBCw0uKTxPBj6yfM3NzAkE3HD/7KTLwgeLvU931pCY
xVtF23cVkI/incnJJfFnc/WnNK1h7JtWfO8VwYckPzD/iKAH2lf3VkwnE5j7
VHCk36Qduv6xKSFMiteivxbtD7AhX07oP4cA/OCIjRGeseBG0151UXx7npFd
fKo1hNTVP9T42QrQYvbjbcPOHvT1z5AKSyTy6+T25D2thPJugXovpce50IJV
nlWDWLgU3nnXhoB2aIfcfMsoQotXnBODhWgtN9jcON8Hdp3Yge80qH3hQLZd
QA/qnbY3Bp4SIiM85e+XUSOIC1540Dc8hv3bwrmZVVzA0r1K6zYf+WtUNAzK
mqCt2ad+soiaB3XFd9y2duL9q+h/nTcQsJ7dqD2S2AB6E//6iesU35ctCkVp
WWgIFt909SDFm0/EHpfhWhifdd8kf4wE/VGFeKJUL7hRoqzxVwT2ib9LOxN8
FYerVegy1Hz5w35w294lJoJ8hxq3D5H4eNr/p1TpRjCWzAaT3xJI/JrsoPbj
ED4qHOaePSKAeYOPw9QlJuxknft3ZhJQ/yZwgGmTDRP+7ZItVD6326dCVBRq
YOm0VTQxkIRU6R/W/g/ZeMPUmROn+slmW6t+K8GE5nt/v5QpARRCDAoaLjaj
vWyVWuZxin/JiACxsjIMql6vk6d4SrOs0lG26EUyTyeuRI7yf5pheuRPvZDx
TJ2O3SRE/mf67vztHAwMudfs3CZEruvwspawF6lbM4qbBZRfYy/nP5CLw/ld
2fiG0jtIfvOHA9Q82tWz74V0mBAnZLlyHiOvsUNsh2wMFZ+u7rxfua4Srqfz
l/z3Uv7LC/ukcL8c9c2RG/aakMgV8mLHMpjo7rinkqNC4MqM+r5j5kwEyyXN
P44n0F60oya8pwdeIj+oeIYQMN5wN9aWycEd3pRa+Llx0PQyHn/6ykVbwXxV
LvUeyj6e9A46X4fUIr/rOTRqfv7kP+N6pAke37SW61H1Wnq3zafpceD938fT
eVYEhuMCm+dKuzHOq6wKMyVxxdqTX2F8BSWea59lUufZ7oYv74V3QrHHVFZn
ixBnsn4PEllh4Mxb0fgLVSR4JRtrVxuMwKCGMDuryUco8+KxWeNebJd8dfya
OAGF1OBbdeGVSLJ0i+UdINE4EdnVv44D64Tu1/U2PDiStX0JxZWQYHT43Kf8
cMLgYswN1n3YloT7t1A8/Q8yE7d5
        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns4lOkbHjqQQw7ppMkKoZRDibal25ZQUtLJKSKhAyFFq50Qaqm2iJCK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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lWkbPlOjRWWylRMRsmSJdiWuFpMoUjGRSLJVpEUoCkVRQlkrCsUg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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3cg1e8fxRWJklRGkVlGm4zQOMgqlCKpyOxbaZCUkUqShGS1kJmyt5It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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk8ldkbv0qyZcvIEsWoSGIkyfY1iDJqLCnLLWsqQo29ITf1kygpW4rS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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns81NkfxmkliUiybuWSW3Z2N5Rtkx5Jyi4Ssi2lSSXZ6bKhNC+kXyqK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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4ldkX1mVm6GcodYZQLjFjdFPSKOrVjRJFqaQRHSSVSK6VQVLUISpE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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VO0fxifZSZQoeVHJUsqSeiW6JUW0oF5LL1FZi4pKKRJRKVlKIilF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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lWkfxsnSW6lMb5QaWxlLK5IkdVnKNkSyVfZUlmzFUCJlK8n+njFi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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns41GkbnpBazVohk1TrkByzorUSboRqY7NhnOWwnZV8H5JSEjkTmwg5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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8Vekfdo1pKEkZKSS0b2JCfpaeq/yQNspIElJJJUKWFMO9KUUqGqQ0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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VP8bhlWyhyxZUrZ2a1R8C492KUQRJSKkbCkprbaiLKGisqQVbdaQ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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk0lVsfx89V5kOKupVZ45VcQ8XV0detK+NNplI411zEcjQSCQ2mMhSi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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlmk81ekbxrXJiFKULUJSpMhEIi6EMbZDw1gyhUkmEUm2bB0VadE/Ii0o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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4lOkbRkSbalYTsiOVsqHDsp1QbpWSjT3oZGOdKscabBsqiZCUlUOY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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3cglf0bxikkRTIioaIiSsOs6JKoNJARCXmzehuiIRWlSVaK8KJSJDTI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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8Vfkbxy8ho5IrS2EaS0rS2Ic2H7RYRpNdNbKXSGoKU0woNAqNdtmy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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk41Wkbx71lkDmFhkx2KhpDRNL+VYYSqUzqqGPsOiFJlhZkeE22kWQZ
6uW0aGwhZKuRLNnlHMc+cs7v96ukpDS2g8zv/eO5nuu57ut+nvv63vf9uR9N
13N2HsvExMRS6fX/nXXFc62othght9T9vX0o3B/3krO704bFNWdWcm1JsFy2
Vqs3N2B0/Q+avCkSYl/uDcuJhyOsVOa6uyMFgYW7/GwrB7t0zheb7qdQkhis
+6qnHzOz4uTQagKyGns9s2ZK0drBqxo1o9CO+T6jkSfYx/B5kLeBQvLrG9U5
b9oQLakV4sIn8WnmKk97XSIquw+FnXeiEG1jf2SbWxQ+POPJ5tLvxXvJfx+X
XguTkxo2q/8mEe1VxW9e0QEWg221tZEASzgZydcagGPzf/aM/iZEu9F66bM9
PbAOHDpZvoXArnwfczLyDgoN1dXXuFNgPEqybLrejdR+Kx0zaSGc1Y5XNjv2
IFuUEv3NUwJsuQjOj8/K0afQGVuxhdZnmcd6bQYfBQdvnnxaQGCbZ9nw7GAv
Nj5XvJ0tEqKQ731Nc7ITTp3WpqG0nrqJf/y8/20/VCKlT19dRev3mntFczQL
JQa5ezaeoVAbncnijBTCK9X4nFMwhUSmSuOWLi6cDbuTZOaFGHXwaJVo4CA1
U1elik0hSOjiPW9SDGZQ8SpJcwrM3Yuhz07m4qbMjvFrQRRkTXMDD/2vAg0W
yfEdTApizQVGe2+cRXLhO78btJ4M3tXOv6S6oPCF3XeshYSSgp/E1EIX2LWZ
Lvn36HwF2Kv4dtWirchqn3wA7f/N659eFB6C62bZYm3aXzDlm+FfUI/f606w
rtiR8H8vI00ocHHr5NXdgqMkildstx1IeQlXBcfkKAEBKfnLrg4DxZid+LxH
FErBfzyMHfOFhxwPntuuQAIcSbnDy60fYcheIsDsGIUAPw3VyIUy2EWNfeCb
UGDv9Mq0vNuG1Pvbxu4tkHgfahshmOUhX01peDuLgO6Uw6nrLc/x90MNPeEh
CtsHD+ypyWoGJ9s76UM0rceSSuuv47VY0E/ll5WTqFQNjM8UH8DR6Lqmv74K
Ifag+sd0t2pk/kHNqUySCA9LTRA/2gLbdyXO60JJCPapDX24UwbZwHe6D70p
6G3SdRmeq0P/L7McOx0KDv53mT/xedCL9Zhxl6CwacTG569T5XAft/5HwYHC
vuH10663KzEUUytz5gqF7+K4IdO1XKzrXek6Qd8XrbslXnGiDq4vDotWi0j0
e1Ro7Ts8guH2E+/ueQxBYiKWLWPUi7zrIY+3MwmM6sx/+Mm1GCrLuwdMj9L5
lxTNaQtb0MsxrbzMIcFU1fLa3PoEkxEduxfpfLEuRIaeFgxiuVi1JTeMQEJI
tKBsYxeMTeL9THZQqOP5dofl90LDgMVmdQgRuEJjRs9/GF3HnDfNSwnQnqnv
eFO/CQ9jHQ+OqFLQODjnxjD6E3P/vDLwO01h2iNiOSHTiRj1tluzp0kkiuUZ
xpjfQ41fpkywHQXOgaoQt8YO+GyJSYthkahe9sCEaGjAb/Wu01ONJGK1w3if
s3nI7NkYYUvS+XB+Lrst5xRS5y5t30vHr283EVxsmQR5jQFTZbr/OXKD7Ru+
+KPq67GeKNoupiHmJWIp4v6f006G9NnSS11y5A4XGS4zDZ4kAQbb7piyRAWS
JF3WFKlRCFfOOD3twMNSwafPr9tJbDzQ8XR4JxfTfGXNK7cIZNwtnTSrLsXH
+pQoko6/TKSk8DlkADss6k+YfydA7BarBKezXdijPcVvCKN5VZTeRFoWIfy3
cKsxGwqGyXEaMgmdYKRnpN3kEtg0rrd5jSIP13qMIkv6CRhKRS7EzD5CtJDZ
zd5OYVta5S35kk60pSStU7ImEK6pd37EogsVbNsJ30ISaxzezuQtlaI8wkpn
iK5vpmqvVWVwPX4xONcRokfBnfU3SjoeIvjr3YEICwrPNlR8jPi+BZSoZWc+
zTcmv9Mp4WI7Pk+Nese0kvhnbW5euMcg2i2MXy16v0JsyvLJbwu7kebj4ujv
RqA/uFpHUaUKWu5ucX4MCvkv+etKvusGNzZtPKucgu9tUcDc4DP8uaR8X+Ma
hZ/tDS+Zaw7gZfaFjio9AVLWrHoxRfMlTV/6gdE1En0R9t1W6/jY9WOrzbcG
BA55Po1hyvaicqhBcEGS5mdLkdxXcR5q1tqlTg6RWDZv8CXd5SWaffYnGbuR
mM1x3MridUHipvgeK2MCV9bam81H9MPza4pz0u8kmtNYl6J0SnD7XqhtOa0H
v7e38cDFPnx0LIrzXSGAew71Qt60DEzCxHRwHz1/PrFKkw2eQuLocyfFJFp/
mWMpiY/uYs5RR9qf7kdFQ2V+gG8XvC6E2v0wSMLQ3dvvsUM/RPuLfKzEaR6P
q7zZVVCCOueRIBlXmt/SNpe1StOR/K26ejpdn5qL1u4Jb7twQleh0Sacgt9i
Q8GNlf3QFY+PlDkkBGfzxVXNl3nQYVedSWQIUVv2SS2L/QTOWtRq3gSJ+8Nl
Aw6SjSg7tcOnlZ43n2QM2/OZPKgWx9o9MRNiwbqyObu7Df994dT4wp7mVZWF
9Lz9EAKrDouhhubvS/cgufNNyNixiuT/QeIhJaiZseiD5vx61a/7SZRNe31j
/LgS+xWD4gwlKTgGpsxFFeRAibFzYCXN38CqO5d9dblIFXkk7c0j0ZtuJrmU
3QqpmwN7VzXRvKppfX3k7GNoSCxtu6tCYbPkkY6gDj60xcc2M9KFkH6fZb/7
5x7M9RtL6F8ncDxPt25Gsxtdri/f8lKEYDfNKEGhDacUz3Nkj5OQbVUTbVXm
0nNirnzDIoGywuZdNSN83A9Inrl+nkDFuFtbpGUtlELfq1A7KVAF9QYpWZ2g
bpOyOoq0/Ymh3DnXQYzt/Lik70nzI2+i/rM7PZ/PduVKtQtwINXQvfhEHYyk
n/ol0/8NRpZuCXM3F+wc4zi3ZgLdQ59+GGQM4ALxsd5rjATj4AG7DOsBtIqU
FyL1hQiXsrq1UfkRlD0OX0w4QsHrzcwbpzE+HkfaR10yJWBmLtuzknoMH434
48Jf6X7jmKuJm/dh0D/tjUMugX8BmKSzQA==
        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lWkblmJkssQkI5WKqSRL9TXV0NUoKkJjfJISypZdmVIMIusnqZDG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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VO0bxpUWeZW1hSQl8RZF2ZJcekkqsrRQyRJZIioqSaWSPRSpRNFG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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81VkYxm81SRMliats0RQVGYkW5klZWmQfJYrI2CWyZFK2GtMyRPYs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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4ltkbRhSJScnSGGWPTGOym1/dFIZqZCdRsqRkiRgMKflqypgsCRlU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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkbV0OolESlbGVtUUoNk+XnI1IpKoUce8JBmDRUhoNMlijmqzGN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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c81fsfx4UkaZBEVEIqIyqVhJdKGSEtK6NBaFhJMoqyc0tGJIpCUley
y8gKHfs4h2PVGd9zzAopXVG/7++v8895fM77fMbz9XxtOOtxzJmfj4/PYQEf
3/8/f2lvplEUWpB3wChNo5iA3wvd2g1nGTCP3yE/2c0Fo1o/W4LdDom9/v02
PTxU3zZkB3gl462Hd80yfQLDwzFHCMNMjM8MurofJpCQmKvgx6hGRNYPQVoY
AWZLrPTrZQmIEuvcKXiaQKhU/u2Y0G7ofI9/qjDDxtIQX87noxSkp31rKesl
oHp/9/eM3Y1QzP78gC+EB9dynfoA13YwZakn/+Mw8dGlcLf3OBU6P2zLKK0c
BA48bnpFzl//O0aRXsaB8Pif5w1nsnD+SlJL/z4C4j/CW8UeM/B23VHmA30W
ot72HxAq6YTxzbGk5BYejIzy7gQGNMLCU0jl6V8CyTnOTmc8myD4VEDT7iSB
iTI30aCcHKzuUSvZGU0grmduxbaLXei26atP+8iCKV/tcwmBNzj9ZMeiK3sI
6NcqfzzXHoe7p+dZ7tYE8v+bzfP9/AJ2OTYzVDsCLtUb/PL/a8fTkGe3/VvZ
mPbbpFXtwMCXxoiYgGdcBPsoXXcb6AMmHep8PnJgcFH5xF+TPGzuSZpL9SRw
/scLndqWXtgu9Bha6crEL9UhPVZMO/7sXFyT94cDant+G3rpcGh2zqWbsmDd
ozMS/rwb+26qZEo+4SLaYrhybGsXfMbNH3z9yMQ773CE8n1GWOkbz6sBQ0jZ
6Hzqu/1bEOUhFNoYgfmA9T2XfHtxyfGY2bGKYfRvqNngeL4T3wL8C7p4bGic
dLE3kXqHjNUL9O7HEvC5VBRXqENFd8naxsy7POjP+Nhl+9HgtIp23fQYAalY
vS23fDLgL0T5cMaFgJbFhczq5e2QlbgvZerEQdukxWkZ6V4Y/hbtvfnwMx70
SgrJ3enEjbFgn6OKPFB/mGy9pNqFoxs3Kiu1DsM2tarz9F8abmTXm1BfE2hM
nLR8f7wFy2bv3r8QzkaObuTBdns6ZIQdOqI/D4DycvyWxcB77L3/+smvhwQ+
W9VM+c/3IaZu6lVtBgdx1zu1dPnpGBP+6T88yIPmRbNE/pC3SFAbuqfNR8BV
LmyVy3cKRNVXFMZdI/B13DDew6QHm1Xq+HQ/E5i2H3Lfq9aKtswzu+MT2eja
Uc8/3fQJDXeeZJxp5iH2v64fympVaPIxUxiqZkPAxljLxacLaQ6joaNLyfv8
iCd++30dljqqnMi/yIV1ysLjKcx/EWPUtSUgjoAdf/RV+q6PEFxl3N6YyMK0
7nkzoqkJ5qKli0tTWNDIGaT1y2dAKnNhWPAd8v15pPuLi+ZjdYHe1YEUcn5P
MdENXv1oCDOVd2kbRfopSzlK8kes2757f0cu+f0vTnx7lj9DDtNjH98uAi1X
RU8edC3AgcOGf0QPEdisWtfzanMhxMWCGMJ3CRRo2YdpTvRibp+goMfKfvBF
q7j81HmISY2UwuN+BE6fiNQN1AmFQVVJGOsMAdGVjeOq/YP4Nd322TyyByLp
ZjlF9m2ISKYsPbVmCH7OUQIx8RUwcrh9JfohBwsX2uqtd6vFbzGROfEsLvTt
uV67WnKRs6eS9/wfAvxa0hfMM99DPChQiBbKAd+JK3EHpDtgJ3Hl/IZlQ1Bi
MTZsUxzAUuPFr9tukffcJdm9IJqCKSW/PJNJNhofq3/0bqbhbOZ7ecopFjRj
xu5IfPoIwnB6v+dFAtk7vG0Sv/ZA0F9ZejWDA6OzVN1s5yaUydoKJHUS4F20
uXxfpwO/uFkG4fcIdPf7ej9JoMKoZ5N3+34COUe0l3/zbUX6WFYG04WDcZmr
51+I0VFzSP6AhRobw1Y/OaGab6H+pMuh9RyB9IThJungf8Fa//bIg+sE5FJj
DywVe4OU+FOUsTYCHdvLln95XoNjO9drCJE8qTYKGlO7/BDuRarURnLe1EWf
mRe3ViLhvb7winUEAi95dabYVaM3vNhhjQ05T3bRsyZmL2YsKs+bKTMxMWdm
/Dq5EdJrxudnP3AxHIBEi+bXOHuXvtZ0O4GdZ47Ga26iQWwm09vJmYUnEwnf
SiM/wGiwU1dSnYt/m947yek3gDrhWTLlxQNfHf/eHwIf4J9V173AmgPX7/1K
+y0akGAg9nShNheSXr5qdH0a1pn7F5xMYUKLcY0RLtKBrPytqRo/CejNzu0N
EepFRMvDx2X5w+ArXLvzZWg09H5FbI4n57dpV6obXtyLhgx5CY9ZDnouep0b
tWLA3fNuo2sbFxeyr0q8uNmLQJHsJwOGHIjnBGiOFDNg6yYdOKLNAWWvs3WN
NAPOlI/BAfdHkK7T/ZjLaoXwn76QzYpsSI1pWKam9WOcmGoX2kiupxbZaefc
Ap3S0pvrLxPgu8PfvHcsCIkS5wPrbcnzuqhQ8M2qALd3ebJGbxCQtXu1KaG4
AlrMqy6W8wTeCf5pERXowtlfb29fieUhR8mHVrs+H6PHQn44kO9L5HKo2uw0
A7Vfulf1PWSDT+/FO/V7rihK8zjLciAg5GIXL/ChBwtpGSuNWVwkTW5UeFJX
D2aEWkyPMoFIY4fD9vX1yG6vWzHHz8PpQvdry7dlwKe4iul6goBGtwi/XHwC
+EKr6v4eJ2D+RnPf8gV9SJBboV15rwtNZbaPOR8K4MC1PdmVSUApqtPyjXkf
8u6z19QnjSPWNiMsiZ4L88tdjD2nyPcrU7TEqLwKBx6Uvk25x0H9um0Pb6Q0
YYfovg7uEIFMad55sxNdGB+Kmnf2GULg7aNZkr2DkHOdkz+cMwTrSSHlwbAG
sGjLo1nVQ/BETDmnsByGjSoV0lQO9DmXxjsjU+C0WKHFw5DACnZ9T+yTepye
40av7+NgNGYBM9eqEotK8yy9nnMgGNptdV+rD552/+haGDJhsLdh+YxME8Q7
JB1dvLkQ9qZSCwXqceGapW8pnYPha0KZx/PLoL2aLZZRR+DggS+ZBYN92Bnz
UPbHVS5u5NepC2lSMTe+DZ4bONDJ22mme7EOa7g5dXEiBOoj7O7Y2PTiBFsq
iK+Bg9Nlk7MnhHugdcQ6+Fv/MH6vs7JXje2D21DwQIkZG4rNUjbRJH9CPVrr
oqI+g5GQ/uPlXCs+ZQqYCE9yofV9rsAgagCJqrQY7ZFRdIevkxf0qkNZsIp5
Hekj3ItHnyn/0wflLw62ZY1sWAdaB4qbV6KNwtVZTebp7rsbJy7OV4Jn45J0
4y+ZHw/eXZ+ZomHX0gtNgieGMaxouN2sPh3aExHth5zJ/YwWHZzeQEf8Hb6S
6GQm+Fy1Fjk7lsAved2mjFwONE1SO1tEXoD1c8k4K4FA2xYd10P7qFDQNyRq
slmQSwuRU4irwcqIb5Lv9AhYOJ6z6tleBso7haWzWgTGb6w1p35oQ0m28/TC
Dg6ajA4uauFRkOu+UyKRzB9R5hrnrj9FkFITuHvIisAyAZcN3dNt+MkW3VGn
y4HKrb8in7zpuEPvIO5Ns+AzPWvZ+a4EJkVdegtCSV+YyvpW6tOOr5fnHxX+
x0FRe+y7ezo0GFJeaGtf40DWeYQSLNiN8zr9Wsx4JtxoOo8MVtKQNTj4jfuc
DX+fwTTbvD6kGCYEBi5nw241V3FNZR0KJqSc2tfw8PNF9sK/vp9Rter98Z83
hqE3Jlp4dksPrjSJRMacGoJ+DDPMoyYd75gP/wgcJbC/M+fRK6c+qMc+kYmd
+kTmG7NmyrAUkBITsif9ccm3p2HjJnRMBx+Zt6gn9+dZkNWx2zS86t3rosLh
wiGOonpkbTdmw4PlRHQ46M00E7hn3AnnBG65lBEBwccWD2bL6fD94du0/y0H
Pn/bGUe+98GY8t3DeJj8vzN/Tq5qbIb7YMm5TkWSTwE1VMvgaETLxjj5OxGI
vR4+6WjahX+zvVQ+kbxI/yck5THzJeq/+DpSYgickXmWE3Y2CXEnKy3izhIo
2yYxK9lTDnm/KysvkOvJKeuYjmVUYeqhVFBEAAGGvJ1h3+MSHA6QlXpF5k9u
zuyn6Np6hG8uHVzQy0GrtmSx8sFqKE26yPqnEQiWSa37oBYG88T/svhInplO
UjUd7nXDb0dW2pt6DsyNZyfXpjGwx3K1+qqQIYSK8bxSeYUI6dkz0UrOU2HQ
KpB7oRsLxfhrbG6xoP9LeC5gRxV23Wc2TkxzsF8mkdvM34x3diE3/qSwEUkv
XRVhTIO8LJ+xG8kPqVnXC0vt83G3Y1+OOukfLQ4rPW2k+jD95pXVtOcw2Osi
+qmvu5AStephpCQX7vbOfP+2dMPu1ONnrS/HELsh7pV2WBMmvihm/3OSi3Fv
U8ppeiPo78Mz7NK5qDgj5DxhT4Ot74lC0XQ2snYo7Ui73otDelGq3DtjSDC1
HJH070Zis0WJxG4OVEtOb36zvhXjq7+ZfCHPczq8I7w4ohnT7l8SOmw5iNql
UjTV9waHLRdXM66Q9+XV3uq3B1ugoei29R9Lsl9s43/ZI9KKHh3rt2qdPFR0
B91aN9iKginZGmmSx5Pnmj7xK9AQuV53Y9oiNhqoGo13wzth7r1qGa+DDUZq
ygGNoxU4NFh6JI7kR37VnPLFjQM4l73geMoODpgVXrv1D9ZDtnrti2WvuFjD
muQmm1ARtPr7prtlTAxPZu5+2nEfJ5SlKxLJPKn+lTQ/rNkK/+D6TbFkXvok
GdJzqHVoEmteMhlCINwsfpeoRjeMiqXCYmJ4CGybNi9+XYWOM+stFsmQPlmw
bMG1ADre6xPOt3XY0Lc4u1XJ8DZKmsI5T8h8NTl7OE/5Tw+krtRrxdjw0LzP
e/5SWA9M2x8sUkgh+et8KKlNeBDRNyqztHwH4Vvgpv3gQTlqLcSf+9VxkJMr
Y3P/YBWKlmUdtFUn/ahscvlr9mvwNjh2PvYgMLNYzH0x6mBv4vNWTo6LrXSX
2G2udNCelQmMn2SB/7X0MQ8TBngrbWedxcdxJj6rTH2MAf2n+8XadxL4NeX4
3e1qKVJVzFsqyPPauubS1qzDNKhK1AX/8hjCEqurEWwdOi4Yq/i/IfvobjH1
LC8GFb9fNYct3cLCJm7bmVJGC05XsmT0h7kwmR2LOni9E0MayS8L1rLRdEjw
jdjRt2jLTSn9o8mFQMaAaZh+Dypkrq0YKRuBRaDM/GjqM5yaOOj5l/x9O7jt
v7OrD5FrbhydFBqBzxGHF+7vKIgd6wtb4cSFn2tq+XX+Fmy/O7JTrnwIFvvb
prtWtmA26mnK8FYOJtoS1b/+akKVyqbOUVMC2pu6n6zd1omJ/JpXyx8MweWn
789xhzqsuEyXbCgl+f+ul6j0pUM80bdoX94wOmJ80+eXtEP+3DpZY+4QqveK
6gatiINAQtrpdrIPH2uwdDVY247Y5RJBRXNs5AkdWfxoGR0tFYtE7B05mNvE
3DYXXY/qw5QpHzEe1tw79/dlXj8qxT57FoiT9/Xj2iF1J9LX+vJ77vNxETlT
qJ2cmQsR60q3Hzf+74/Lec8W0VD0+9TJ3WS+VhSt6DAtHECyZnm6RCYT6eqL
1joq5OHB7KRkB7lf29uUeXGXOhAeJKVpdYDMq5r9IemFnfBWTQ7mVXJQdrH4
i3VAGxJCrYOWm3MxvWVB1uK9dHjb+l/7KUf665XWvZ30Bgg3R62sEuBg488t
73R+09Gml3IkiTUM709R0VnFFLJjb/NkbeLAeFCp1KCQDjOHrZtcU3goSKtU
60qioEPNIc3kBRuxL9Jl915uhSz4rmdHcOHqpfWvVmk9DGf0hJvI92ta5PqV
UVOLYJsm3QX8pD8W+9XeHcuGNF+ySogruT/u3ocHZYpx+3BkasE2si80Kh+1
W0JFpeFz0ZnUYYjyty149iQdore+O/9H8lBZsVJJIaEXix2Dnea/jsJo8a7g
jG8DkOKsbrtG8jnfJKc87upLLKhxZkSR+TFhYGOUO/ABgUeMdrqNkXyQLxTm
PaKjbqVIlPgPsj8vKu4YMCF79i29bBaF9LOTfuf5V7QjO1OWnSw/jKq1nkWP
lR+Bl8q8GUbyp13Iti9MsQ5fp/ckLUsiULJCcI36436YMiOZ8SZMbI9blyBx
ow2HtGSeTmAIBh8ZYX4utUhZcsHNspeNrbsG5wYmBxHK2/glpWwQ1RvfqzlH
XkM69Ud1kCOZd81v7KPW9OBr3mrNVSQP2cld3seXDMJN9/neuHOkf7lJHbB+
3Yuqp6dgGM/B3daTF+r5GWiRjk8+NTSEClFlhT+lFMSs9384IsFF9KLZE0fk
aDh3XvL7zsBRrNh3YkJJvQo7vowO1jII/DW31L092QwBHa9ZqxtcfEr/siyq
uhOKf5tUZfII+A2sdx7Qb8bPSP2w+Y08aJqLJCrV92B4WpIYJ/nralf+PWau
CL+aD0z3jxOwLrDG/Aka6eXiT6u4PLDrjzfyh/VB2mXtROu/o1gmPlgmeL8H
5qkLTnmRfaLKKey3fTEdOaGXfWXec1Gy2CZZitaNaXZQgOxnNkYmt1eKplFh
L1fgd/QZgbMD17o21gyALpv9dHSCjcWL2po1DChIF+COFw2xQauoGRET+oCq
WxudjpD98OxvR0ezjI8oCuxqUVDlkt76wPRQNA3df+eHs9cOQ6N2oH+isBYj
yqq+S1fzsCvvsZepEQ13rN5UDqzjYbO1WsXHmWI0+P5ZOXWV9BNL3YSDwqWQ
Y8blLyf9v0RVSIEqWI7Nu6PbhkifrL36KjJSsgsWqeGds24crLi0p/2GehZa
qLnFfsYk7+SLPw2aPMeZYM9QjwgCTp/a3Ye3dEEoXc8gl8qEsIHMt5Plb6Ao
EpLBt5WAZX/3GXpuGfiv7fitfphAU92It/zPj7jlwO9ywIlc392/yyH4PR4a
gMUsJv3h1vepS3K9MCxWKl+dMAg+xg+ihny/WptD+EetyD4hywsZdS+Dahvx
bcshso8F/9KQ3dmC/+w7jp0+NgSR1Te3a5W3ImW32fvv73mI5W/wXnn7ORr2
5a9yJfvkr+QNbvbjNYgJidQtJn1Sf4Fi4/NX9bhrf5pQ6+cgdtll26KbVMxM
tRWt92VD+NCg/8yhZlwoUBnfSfLkD23zI/PsHmgeDblu+piFTOdl5eeXUMDc
9Gy28tAQ/gedyRI2
        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8VPsfxicJtwW3uKks5ZYlXbqFVPTYrjWlZInIpXUoW4tsqSSh+REh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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4lVkDt5QtwhTGOlIkS9aK0M9SlqL6zIQsZewaWyGyxCjKkiTja7OG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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs8lXccxzG0qCSSooW1htpcUq1lfcgmZMhIzXCSynSUcimKUnIJJdFh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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2kgVA0XlijKTio7Za2IUoo8XhFJWlAqW0SWkkRUSEV2JRWplFASGqNU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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8lWkbx6UMWVJNtsk2LfY4k0lK48e06ShbipGlolKR7PXmpYZGllfq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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk41OsbxlWiRYU6KpGOkS0VR6ks3ZLsR5aQhEKWFlosOaEp0yGFjoSk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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwdVnk41dkftrRKmzEUk1R3JEWRJNIrUVqUlt8kjAohVwiF7C2kLplI0Shl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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8Vf8fRrLKiiQVoqSS6Gs0PaRIKCupKClSCWVVZBRtQiFbQoi69mjY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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx5FRSSXZShmllG2YSoziYwkpkZKtSAgNgwaln2KiaaRCpCHZ
JqJJ9jCy7671ulxc673fQyqGUqKU33f+OK/zx3md5/U8z3mf9znbnH1OnBfg
4+N7QI//5vIA1YAYfSYi3YO1Ig6OY9+fMpt+H+iF1K6bFWL1XDgV9jKC7J9i
6oK4XpMLgaAMX8iJGAZU5m9uu7+XwO/00xr5gC6EHVbOZzMpLJR0F5etYWFt
VoSk/7pxFKmXNpp4MWD+Nm3p/hiFLr7RN1NPGai9VHJNz5QgdfNm59DZB1iO
FniZdIrgcKTLifnSQZwcWoxAG8GQ+VKO06s2uH2/nBMwR+FOQVybl84TJNs3
htqcJ8hOcYxrku+E9vqdcvNHKPAFKrXWpDujpkguAGcJ7uxyWTQ3r4fbldDY
hQmCAke/llztYZzeJ1sxLcbDpFFuyIvWXghNdVS0P6Pw6NHw0q2ldtifO7LT
roDCl21ZdS6VTfD/2912lzDB2IKajad4F4wfLZf/KkIQenk67ZtkLXT3Sd0I
XkuwX6SEb/tFNh4dnrY75joO6U0a3I2aHVg1rafKsB5HV/smnaALbByWU5Om
yiis89pQF72nBt+l5EeZ5hDkP8uQ2riqHmZ5EUZpdgSiYx+Ozmrn4+K90swS
J4LZDGvGxew+zHSkthcv8CCYUF34bKkTWywbLwtMURjiD7MRAAvZNjpS3hoE
2zsj8tS7GHAVXlmnxqGg7fFBiPzCQu1jd2FfNR5m3Urfu/DlwOe8WLmvK91/
vwFHLrsCW00FNFafJlhQ0bXykavAi2LW1yUPgvWmvstzeQxgTUDy+wkenNYK
z9h4lqKyqXNNjD6BkxslM68RjRGWXeZVmpcUylZjJrMZTM62HbcVCeJqYqPD
pPvg07Of6dBE4VuW182P0sXYPlFEPXYn+C0kT8r+fhbenWGcC6XjHRTZ+9Ku
vBWuyirs5f10PV8S7I4ncKB0QUrAypsL/29PujeIN8LDaUMGU5/CbFiCkWZM
FlQyf363w5pgz+NLm9RSq2B5V1f0wVY6fvoTZ6+WAWgbfg2LP03zEn1N7KBq
N3YfKrMuHSL4K8LCULG3G45KMocGoniQE5v4NiRbi7barNl1yRR85UJ/OO7Y
imZz3WTLBgL974PmZGU4yC4cKIyy5oIv7vFsvl4IIkWZ5fcdCQ41cXVNzAex
JJoxfEKCh7+N5tlBrG4M+BoYuUcRpC/Xfebys/DwReya8OsUZFuylJkeA/h0
/uYbCZqvgmMTQ04m1cjNGhAyMiTQmpVY4ZDMRK/ULwVXWwi2fNHXr77Xil8u
jgg7NVMomwk0OTfZBPt3q711bhCsCmhUpE5Ugt36LYadSJ/n4CJ3LKUCf88L
GJReptdLHrZT7CpwDCwtnYsI1k7d3rpSfRBmNWvuqorT/GurTu2b6MPIqbnG
U4ZcuG79143H7ENT+tWjRQ9pnle80pcWqsJSknDcuc8UXF0ExNVtB2HaNyqb
nTeOggtNUT0fRrBxu5acoQ5BYql9GetTP9w8VJxl/HkoOsqeztbpwaRL64ZB
+QmI2m7MIuGJCM9vrIw7R6C+W37s3dd08PZ8TfW1IagvlHgeqVKLmdDIppf/
5b94bGKRU4wDv7F+eEzzIT2qeHYzXyts82++LWcQPD7wmZPzvx5Q6ktXk6wp
FOS6a2YG9uCM6+Rx1+s8LNUO9oXV9+DZoTKfqw4Umrv9PBaCq+EvomFzWp6O
/yXPr0WtCd2caYnGBAJdT4Hc9yINYHRxruemE0xWyA48/6cMlWdsFBf0CMRW
M8O/N2KB2ZhrK5nGw/6e3L3DOl3wtki69SKMh/igHgdebS7mRD90P6Hz9b86
X7jedgizT+UmAicpFPN1ZJx824wHXq0V215RiFMQDCqQLEW8/P8GbGg/epZ1
uS3s6oee0o5bK5W5uGdr8ntnHhOL79/wXPNp353xbbJe9wS8JW97IS+6H4u6
oVV99fjpIP/rBTrfsZFNV3aya2D4rGjvFR5db7KBc3pVNox/fP1I4FeC8Ob0
xc4VxZAOVM08RfvmvpFmQ9JlJuzE2arLw+OIbPUU+NTYh7tW/kZHqrgQEVKy
NxYexmWJrybXfCfQllf+c8VPnWBwdE4e3EkhcPyb6OodjTDdmB8c2kvXa3Z4
ZkVgHUbN5S1EAghU4lmrXqU1wKD9tvGxOQKF/igtb70q/HZHaNJshoLSqJu2
7HwfKM3QYTnaFwqvhM+UVLbgUM5xsqOSgod1ucYx0T7wFq0tM0bG8eNMyMd2
0R7sD7OI+rOZiyVKid/HpBVqamcvGb+lUG/Rf0kyuRHJwfGbxfYQCFs7/Oh8
rwbZ1w0suR0Urjyy5QQrMGguvzP/l66ftVL3W6JfNU5o3lpxcpmCnCdjh0x4
Bl6Up2Qb0vd7JORh0uqcfhjUL/aP0fuVtZMt0i72Qz841feoJu2bD9HyHPtw
mI21znqfISDt9xRcivpxScJidtsmgh474wbBDjZC9cKPutC81rfWfxeYW4LP
4bsW49Rp358bFmTdSkXkhsgrgbSf4zUPuqxI6UZehVsOvyWFPL2n/uZXKpEQ
EjCslkPzrfbr1sb8Bmjx3Rb0MqP9kHCjXzawBbaqt3KqKwhcpz9YkOd9+MFk
VDCV3q+u+K43+w0Lb6s3t1lLUNjCGOnWOFuHa0z+T58taD85x21JzmrA0d2J
rwXp84tO2nX9jUQFHvLa5uyOEPBR9t7x2TfwUczM9KQz/X5Mnn+twGajpjdx
ZMZsHAf+jNzeFTqKqb+OFMomTUBmQvn385JMzLN2Ov1sQeGP67WWYa4cvHUc
iTV4OQoPhVi5xI5ecBL8rYIYFMI/qutZZZejO9pkjbAVwUM/B8mP7nW4H3tN
yHCBglpqfv4puz4oZrd+cQvjIot7IMDdoRxLM9XOWjEEtQqKktwgFvKNI2TW
bybwssj04deqgey1QxMvJAn6XVayav+oQ7OGlW/iHfo/sjf2+bJXGg7PjjyI
of2jtWprYWx7B/jFa7+a1VKovuEZYm1Qgu23mbKSSgTON+4GyK1iYk73D6fj
/xDoiVYquzg8gBt798cU2lf/B+TTw1A=
        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk81PkbH5aStnVUdJAjOlA/lVRW3otcoYOpiIiMVc7IsZRjaStJl9q2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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkbPzP5pLEbMmTJklD2aUZSv/Kl7UMIUZFsUUeEaOyh0CYl+WQp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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8lWsXxqmTJFQi6pSxlAoNjgyHy0ylQgpRhohCKY4UChEimQrRoEEq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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk4ldkfl6GkBZWlKGZ+FIZRMeOS6YPIboiRaKxZUmPvZuxqpsVWkbok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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk8lekbxo1RCdPY2iyDoYVKxpSGcB1MyBKlorJNyFqdUMNIKiohSdbS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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lukbpWQpSraRllGpSQwlSvJzGhqprIWJ6ovQEMVnihpCJVmyZi9L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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VPsfx0VXuYlSlkjWUqKNK1u9EWGSKGkhlShaCEVJXVmKIkKFK1c3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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlWk8lWsXxlVS6SRDRFIypsEQRaJLRYhkqPOWpJJE5mifDBlCSYPK1iGb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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81O0axlWUpZAk4Y3ozRJ6kxZLrpK1RRhrIaRI0liSSiVyqCjJSB2J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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkb10R2UcOoiNTM+ChLCo3qhzYzpFTSyBRCilGIIpcOZYuyJMkS
Z1KJRDFt1uNYOnY6OLac8ryijUEqW9/TH+/1Xvf1bPd9/5Z7hfOJPa4/iIiI
JNHv+591fgEXMo+Qea5PVfcowUkFeaecki7ww87+nGXPQMQpwGP8XwE6Lmv8
lbyAQUVgkmu1ah3SDWtU3NkE3JyJnMXu1Vg09bNA6jyBxhyz6vB5AWLmpTa+
VWfgeNrR8uOuPIj873HGoDNBw2jAaMGxFsjMcBR9awiapYajDTRaIT8be3B+
JcHVh/oezDsBtn46rpwcyOAbf1Fg01AHDhbNKq1XYKBzRyeo530LCneF7dG9
Q5D4gT3avK0DFq+ViwvnMdi94nnviTdcVE7vCFsaRKCsNci221KI27EGXX5u
BEq/Gj5o0uODax9qPDFMUHAsaCzxrzoYioeG7s8gcJSsAFukHkGV8RZieQTV
z6Iqdr6sxSGxrRJXowhEVFIC5fa2Yu23PuukToLRZIOa1Xu4mNzVx+H40/4N
hm5kmVeifYf0gjBvAqGn0havkYsotKorcTpMIGg8lrck4DkeKU6+zI8jeKzg
tVl+SSlMDbuF5V4Exi7Nlr4GXIjKSf9ud4ZAbqHHyMiHCizpbpVdR+8/t1p2
Ws6oEwOuUx+MjRgkJjUKmdJm+I/nCJsfELBGz/udHMpA8CH7ol8cCUSDK5Nn
drZgX/2kivI9uh4Qge1hPGRxLo9PsGj8c0WdNCsUJ7+KLtxB81s9PjZb68rD
cWu2uHMqQVG8UM5OvxnObkUGmvcJXMyEai+fFuNq2HvvkL8JLPUvqf8mrMfH
cJeMNUUEDzdOmiWMtiDeqldlMotA8/L+vNNPa5Gmu9+4IIwgKUNmvsvHXqRW
37tpXcQgTmNH2Y/qAqgErOxcT+tx9yyyPD2Wib7IyKHzNH/hPU6twalyCEvX
FKjTfk4mpQh0HuZBw2RcK5HyqcXtz4X95vlIKJZcYu1CoOajPN+BVwyJu2eO
6ZwgCAy11TV41gP5S6wLE3cYLGiaPpqr0I02loXKnnMMHEyzvVptqmCuHCC1
KYBAwm7ezDapLghuWXh/9Kf8LymTU38ahN/UVFs30f788cuzH8OSWjGq7mH2
nPJHxG6DqaVaPOSnRWZD6Lr6l6U2pdOn8W+upt5vNE4Uc/qyNrUW919bn2qm
/Ak1/MzL9eyApPqyWvzE4Gms4lXR630IiG2+/pXH4NrOMuE3JS7mvhgs4gUT
LN29NvHN3+2QfXRhWVwbgWezuFXehk7w/9Mpe/2NoC5+6gprkA/3kCdfpvsI
LocMsNbxu/DZOvBdtwmDJ55ZdxOrm/BPz491/EKCmdTjEjkN9bgx9NY2k8am
3PBD7dM+WDV6NNiQ5pusctYnSqoPuw1yN3DzKT4kbkm8VQvcIufG2eW03t3h
XwKSQiAhoSC7ne5XlkvZt+6PuzCqW33jkxPF/+YPvvduduGHZUe3KLkx8FGw
0jtrUIMXOSJ/Pab1sLZFpSr/cguaPQIHR7q/3ODiyYbsaiyFXuHvlI9RbOOs
RaJ12KE6ct+D6lHmdZyY7UALPP0OWHJvEBy4m5abpsXDRXnPndOUnxbDN9ZH
zxWj5Wv1jD/Fu8ooyuZuUQ0is/9oeP+d333ObdOHvKBa3eO4juYrlLBuiBTn
o3fXJZbdGEHMjBsnWqYPR6JusmfPMPB2a0kpO96FpB0hdg9cGbwXr2vPGypD
xjGH4bf0/ozx8uwrvnwckpA54CDB4Pmt4TJoF8DZfCY67ggB34HbaDLRA/7c
drOSegZBrjqSyRndYPfPV0vbykAwckDNwCUHFRar9KUpf6vYYktyx9qQrG0S
vXqCIGGbxannft0Yso+QalnJgCWvoH1Z2h/BXrrhxt/z3+i0yEeyCnr56ZtN
z1K9no98tLGuFQre/orDLyge6UZKGHuJsi1RJx5R/BK5FhJfVzYg4W70lFoK
gYr11tLJP7tRsszp3zCKj5T1grBIhTYEbzZ3/qeXoCTXYWmsLQfGMS/SP/kQ
1Hj5TfH38iDIapbKTCCwYq94197cg5HdNtqXEhgIX+3p7DVugHZ9fu6vVO/P
e8T93NIewrE3+0GFK9V728NY3c4OTNmcqjM3Y2DaYh4+wi6H+2G2CYf6XXx/
58dbnC48fqHzp0QE1duBpvvRp3yhGeN95DsfVRps9yv6PcEr8zb7Euo3rZW3
9ZdrFKJEw4yJpPdPBfJzgvY0gslMvf3mJkFFii+LFV6H0W88wZsrBOaJ+Dig
3wa/ob5u9SoC+UW+rzqOl2Iu8FW9H33/demnGy7pfBjsClynuJDB+soANXWp
ZuSn2Bo33CbI/sZz76d+PxamL5+QTvWTV7s8bKgPwinvKkZ6EB4rLD6vSe1E
96y6YpU1g5LEw6vKNDlwENtnyvOj82Ch0hmF2VwIjfa1lVC84ywaV4y/eQGB
z634gRnqDx569Wt/rcbtzwMNlyhflx/M+6mgqwWicW+LnxTTfspqaQvucPAk
4l26A8VD2Sh4WbteEUSPzlam0Pojlyu6X4h8gNEqrfh/qP9VqNllHFx8CUq8
2oYj3+fNhcVeC9qeQcu6mzNM6x1NK/Agm4rQxJM1iaHnNUNO92u+eIZ995OU
5Typv4tdu+6hXomLbrr9n6jf3mNPSJavrMVX+cx5XyII5is4vfkkaIVy4IOV
z6gfzZi5ZltEtyLBqXtyfTXV26QWrLy4OBd+tks2kODwtN6VtLx6nNKN321z
jfpDx9n8c/oChCx3vFKzhkGOoaa1zoYOlFaK9zC0HyeTcsL7/yuDumBevB/V
22Zmo7Z9fTu2boigo4igPzNJurmlCfYR+1fJUHxc+sILro/VY7Bk6bbtlN9W
ZlmSmTZ1GMra5f+J8lH+aKMvV4SHrar2nJgkOu+3dPQFqXSC88Et1WqS+lna
rHVpRiDs1LJqTWi/9Lwd+abeudCK3zv7meJVsCLYTGT0KSJjplP2Uv6lbbJd
q+nRAe+2GpfsJoKhr2b82IELmJOZfG9Jzw8eO3g67nE3GharikXfYPB/X2TI
Jw==
        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VG8bnpAUSSL0QyVJkTbtcouUFpIkIVkKSaEoJCRbGyoJRZKy75Ls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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVmk81WkYvVkiYSyVFkkqIZRGZUqOGQ130IyQJRHGHoaGMlFIFDKFkkyy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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk4lekbtpU0MpYaWxsaMRHZj8pdQiqjg2xnJkJFStYOadVmSZSJyJST
VCpZj8iWNTsHx7HLOd+XiCZRzZmfyu/rj/d6r/d63ut63vt57vt+XjXvQMdD
YiIiIinU+rGr8u0Kdpu1wWBXnzv5L4FEm5jGHe/Y4Mg9XRxoR6JSIUkU6Tyc
yNH8O7GAQMrU7wpe+2qQPe81Vy9C4q3jGe8qUR5usz77WxnzwXKQ23ZAIRNK
l4fCXu4k0a9lZHHtUAXsV7aXOPuRUD/06mmgTCUcOx/sEU8ikf7RYWhX1jAy
1Wc9Q8T4yEiNyX9jOgrB8Zeh6Rtfoz+GrfnT3XIIXb/EbiAIyA9rPvSy70V1
suol8SEBJMxVE/m8XjRcKnlFMxNAP5cnUT/ThJQAk49GiiQiuE20vd3N4Iw2
x7R5Ezi/OvFDwbgfPpG3RvU8SVT8d/fDs5Ym2I6tnwv2F2AsoarHbP4ZhrKd
k8NcSOwTG449L+TAa/hKqU0NibRav8Pce50w+Lon/+wrEmyJrzkJt9uwjzZ7
aXMxAfHIh3ttTwzCz2aJr1wKgdQV1kk9UQXY+usAEWtNwjdm6eo7j3mwPj/7
uWgtCa1UgwXvzb2QZmh1MU/xcVrZLNZOsRtViW4iR+IF0GwPZYkENuLXwHmm
XAyBCGYFq1G2BvWn2CnxYiQuFS72Feq/QItLX7w7ncSnSh/tYZsyzL4W/6/p
IImvu725pWvKwBw3DiHDqHrk04XkpiYwGzf/eX09AU7E/qWvfUqwsV/3soIG
iXLmfRlxKR7oq7abffd5g7KAydsaBwYgFiDtcsZSANLvlNtpox6qr08vkmMC
mNgc3VDvNALNOGaF5PpRmK2KfdHzlo294q3DtutIfNtwI3S/fTeeC+ddA/RI
uFslXfWn8stsTje+H0xgCY1nt1SjEv+4nDPNNSehYx0UyDBog9u38bqFlVR8
08ufXbO6kRG4yP7hIgKxjv2Jc4V9iDyRyva5SMCtyNo9L4qNVfLblxsfI+Gf
94CZ3d4Fq2+GdT85EWhvTlBhrB/AFdVTYWbvCJD1/o9VLLqweOcaD88AAnSr
g5qeVm24ddRykc8CgSAWLaPQvBQK9qMmA14kDpSFhOtkZsDurWzOCR8Sbd8d
FkQlW2F1poJbTvG7EfX8KP0+aJ71ODbwkICQFtRx8tZzyMsKac5aJM6bF0kx
5K5jxjyO+bc7Cbr4xiDHbd2YVvW4ar2PxHTk7jdm1HmcmeUSsp7EYRt8C2H1
QSZ7h8zPywnoVa9oWhgqQ4+2x4V2QwqfpnTp7Toe4NjjJ8fiY1tT7bp0u0ao
hRbcvNBGYMLvfHK0NAcW959uK1gQ4JWyU60/rx+ya7tcN1Pvs3/zWO7cynYE
qpYxfcIJVB9O+aPvAhuML8LGxcYkJkRJd7nIW0BvhCWb0ofkx9Egv7w+2Dts
53Q7UP1gLtWtiyrB4H2bq4so/pbSau5VanORGK3DaZkhMPa/tlnaaBYGHb7n
KFB8tDVcfDN1cQO0ZD/Kz+mSGBPbsnDj/kPYnx2esHal6hGtY7opIhNL7tV+
FR6i8sf7Bl6OLYGJw5qLYb+RUAvSjRiOb0ZxdMSNRxZUvq25EdHxbLh88N/n
QOHNCW/y04wdxMhdxYyyXWNYq87lNGztRsrJ/ifFznxczU4NYi4bRELt6lae
Bh/5k8xqVkEfSgP4DV9zx8CaqQ7ZodeD24rKWklbBOD43Gi4VpKFqtK9R4/t
IbFB+OhUbiYXt8Pi2GoiBJJomjT2s26wJE7OjWcJkP3C8MqWGS46vJ0SOii+
0iX0xMw7H0LFOTztTCCJ3GobX59aHvL0hW4blQXI9zJK9DIuBN1/QLhzKwkR
09NhIS+6oHT3o6/MaQEYy8Yrmh93wXPTHm5HhgAHZwZ/JUq4yGsoX247xcdE
69Xite+bkBvqVOjbKIDska1W0aFZCGsTzTvvS0L2zkeD0PBH+CnHa363N4mZ
S65HEv96goTAp/hgSUJ3lRSNocxFkAmRbmhFYpNcnYqOfhVOF5xUTXYiMahv
81brTC+Y/fTquhFKj47ahbHWlSj+/Fw0geJ/UPf1dsXwe7BKD8l8SvE59ZTC
1FQXBx5Tly+HWxMIjLWQ64vLhza9JmXHZSoeGh08oFUJLaXWLA7Vv+tBaTzm
u27kHCwxWTIiQEt9tGkkh4eXfuorIqMFWOf+QmPyGA9ctfTS43+M4Vlanm6Z
2yj2Z2h07qP0Jm80sCU+PB9Nn+0UNSi8M/mSP2f/+wjtJ+X3t/zw81sWd/JG
eqDOC5jWWiPAtpaj75VLMjFtQA9eTd233P7IMLS4Bp/juNMW1DwZ6zV43/L9
CSwZSyVv7iIh3RY++mGqHx1zGV9oGgRK9ygarhwqgviUPqvmB//cjh6HZDtY
kdrCiy8I3GQo7VzqPYJs8RPeEUve4E5yltU/L3sw+Yz3pFaV6t9cqrNgvA3D
9PQjC2wB4vkzCbah/WDkt2jp3KT0lLLtSttcMTQ4J4uzJyg/i5nYKe05CJ0j
w75p7WMQYbbHPPjrAfzHjZu9KPylteu26D9owZrJ7damspQ/eJj2+KztRtbu
uGTHT3yYNAUPzZ5tgnaa7iMnNQIiN689G9etxnj+H3oqtQQOLtPf/9f7Ivy7
nOtUvZ2qx+fJ5yKaI8i0/kSs4g7BzLhTS8q+CPTV46LqOpRe55U6ypTYCJJh
TC7/hcSfe9KTAop4aLq1I8A6ng8JjbNph+qa4dvjsYKQIrBOjVbYNV2PBxN5
nvQtBBx16F+E3lxsjbdc0iBP1TuEVfiuNAeh/3Ndy6X+A9cSE+0yr3VD9rWE
d/OoAL8V9M/2qAzAJaX1QGKVABHORSWbGI9RrnzuuoktiV+WEeXPJSl/i2cd
nowl8Cn4xDej6V6I9a+44Pq3AL/XnyNsO3ohqf78e0DlGJRurPNq5mWCmWpa
TFJ6qL4jpXmcUQKvT1FSpvrUPP9z8PvUPAd6MV0lfrXUPD0WzLEOa4WTdGfc
D38TqU30IBf5IHrRXsYqil+ByzS7orQ6EHdD5WLyAqWP5VH6RseqYHW4rcEr
mPIzuxVJqWqdKP86Zh5UIcD/Ad4Bqtc=
        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs4ldkXx91HSkm5TQhFNUmFSsJXZSQZuaT7oOMkSiKSTEWjIt04IbdB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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lf0fxlVGg5JNVoUkJMmIXGRLWiIVpUQ86pGGIqWyKmQ0pEFkz+y9
9x4Hx7HPuc+xGorGk+R3//66/7hfr+/r/n7u67o+72vzuX+PXljJxsZmv4KN
7f9PSbOj+Qaa3Wip5j3Ne5MJ2j9y885n8jEzrbPtbhcDHr/lf5i59MLwyWUF
m1ACsUn1I7MW7ejYsWa5UJUJkad3q5o9+7Cw/aFQ7jwTboqh2lFRFDSmPyiq
zB2E5BfhS2yrGsC9PX0PbzgDM9QEyZ+93ViTEhA/3U4gIDDN8bthHcTzA3/E
jTCh+FWHv5TSgc+MqwIFaixYjIcpf97Rj/Oq57+fCJvA0S6aSYwoBW/N3kpL
5DGhZ5B0hxUZiGe3Gt1VzxIw/GHvd0alETF7rKvVPxP4Exi6/8PTPsSF6Zbf
0BtFrJB6cG37C0iuCLhQZE8gj8f9UX5AHXquVomNzxF4QD939llqPeIYKQK5
+xiYKtrhp5vZDkPptbRmd/J+dm0hwvuzUdJ1iffLDgIquf37yn++gxRfUbOx
B4FDzLkcy1O1ICTVDvzzisDCJsd7Zns78bLn55/b5H34o0uabIUHoSYTGV66
ZxJdLpEavFzdoGWyemfMGVhI/nblzHIDplKXV5udI+ArsTKR834Yyk9sPFF2
gsBxrRsvg870QNG5P8P06wTeiyx/lXHPxxVPlqLBUwJxjp0nNd9TkWxc1tz9
mYn1cSc3M3724pvAO+7i9HF08S7Ti56UoGYVdbXtXQKml078vLeuEp+3uJ43
FiJQFed6r/P3U/SYbDz71ZpAzY+0o4XPKdCVFso51TKOjNPdQdqudaAHx0nU
8hBIzTtR4V5UClOZjoNEPYHxmz1BJaVt6BcsXnfbgIW6Zrbggj/9eBkUJ58s
MYvZV4pJunMtYJ+b0DxK6s0wHo8vN7SDXrww0Zs1ge+OqUXSfRRQ1bZnvT42
hrVDVpQbe2hIpiyxXQQL9CKt776+VPyl6e5ZLpjEqm+T5qUNI/CxK+/sCx+A
6gkbdpYjBTXLDjXqiePw3Vpom1PRBPcbZlf8PJkwP0mVENJpxZXAL6EvVBjQ
Uxm0MJx/joceY/aq5HwdF7ROmFMKkeeyewWnFoFtCVGcprodWBm1qF0tQYfv
96Ht5pZ9GGfd3HhblY5rP5RxKjcGVR+33l1hRODtrNEnk85+9J58tORqSmDL
/NRs/t5ylBXfyTcvIKDYIpvZt4aKZYfwhUO3aPCS9XgYaNuLqpQNTdfKJ8A2
UpDyxr8D9JF7w9n7GSgMD3D+zqTgc4vpPNdfJvLclTolvGkYKzNw+jk3ip92
Zb2pmV3wCtA99dmYCa/SbU75FQNY5X1x5zYXOlIjtI9Xf+7HXEFxX7c/E1bu
3ROqjiNwv7uyvlmNAd8PnqkczA5cvrSBUnWcgZ/UcY+fFhTEJex295ohMPLJ
5kLHSB90jfkN3csZ+JjnUnaA9JNWsBhPjh0Lhc13eH46F2Pd4KmZVmcGdOIP
XXBib8fMtdrlW2kEdls35+yUqED6h0LhCEUGNBe1NQT6qAjVe6eq1MvAYdF+
q8cJuej4JqQlpkPgnxX8N+w1OhDtP7zIs4uA3GZ/cVm+YRgW2vTsHxhElPSG
5zb6Vei/Mb9tcjPpL/5OtdXaA5A0U/vLuXYE3KdqHA1201D3ruXVxUAmYgm7
5athpRi45hm6v5OBhKMJoV6VHQjkmrZI7yNw1u2o25hoIgK4iMc+EQT+Fpgt
5vJ34WuOQtDwLQJCYfZCW7QoiJAjBiV+M6GTzXNaK7wYSgsvVnHUEpiZYzsl
s6IL2TRH5YsXmdj7IyL8jE0P+p8aTrXFshB8T0ZUeFsjmnwTNw2lEohKe30v
fZwCcY5M91LBScRWaeTmpsfjz7WZ3qULBPyEtt2xaM2DveOVfq4RBooqUqyF
5Aeg80bVeAJTuFlo7WBnSYNKTMJlxfPked3i4u+P1+PImfEzkseYCPsp+Hva
sBnfBevXGB1iQFojSMqyvAjsr/2cNt0hYK9e2v1cqQePJQ2lb9QRIC5kRjYV
58KJ+vNkCZlfZ8Zc52lyPTjy3vL9s8BxpE9fW1y/sgP7M2xe7LVn4vdN4SS3
vwXYHvohrdCNQOdehwCH1zUoOvBgNGU/E+n3Qu/z1DTj2oin8eUuOlYL3zIr
k+pFFofKUGwjgdeKtf+Wsij48Xt3QPqBCYjIOk8n2RWgKeIEjd2RQAv9adPq
Vc0wWZIXS+agQ6fo6OQqtRZcel+lsizGQMzx3+xKp/sQfSxyeyHnJJ59blDu
PduMoF6Rt9JsTHiGG5Z3k/moMC40YFXFwMUpTvYpn3aoG5ZpRIMJAytbg/oq
CiR8t/U7fJoAf4JE7+/XFNwRKtvd+XUKbJbDgYmiFSjJljqeeZzMRy113WL/
OHBu/uIS4ENAT2BHUw1POqo16vuLr5H5zFzmNGSEQsG5+lHhGQL57emfzJva
oHlAMDae9FObiVFQzw4a4hT8n3o6k/qpsM0qUu9AUZSNaLEEEwnc1HdM/koE
oo9lrUuAruvw8WoRBTLNh8z85JkQc2F0eKtUQ+Z4m12kNhPNFpsEkweGQPmr
ZMQXwsSNZcGjZk49GPs1rSDFJL83Nl5u7fIA/Fyueo+psBDyjqGrHDgIDlqw
6pq1E6iSMtZRr3wJl38DTRQdCMwdlHIKGsoCN4dpcpYBgQ9DMorXZ7qgqp8X
oNQ/CT0fU24/jWK0JVf38q0iwK3/SV8kggJPnbVPG4cZiG3rWOR9NgCRrFJe
74Pk+a/YuKQqB/H9St3fmB/jyKrfFXQ6vw8tQX5ixtfJfEuo2HxwMQg+At7P
Be0IhImE293fVQrjO4uDSUZMnK5NzprMqUZqjlyy6F4miuKvW0kblENPqcKW
y5KAUzZX15arVYjJ2fN4azmBC/HdZna8dehq3lUhukyHY6/Z8sVnxXDVUMlW
PsLE3PZnRvKdnTgnJR+ndZSOKnG/6TKJlxjWf+J1nPy/l65nt16b6cHyLqaK
6TAd0WMq8gYe/QiveHPPu20EpTfi17sMdqPqGHf46fEp+ObtfyrP14fNBxm/
YrxZUEmmLIw50dC4zXwh7S2BTDWLGJ9/B5AlmNI6Hk/6kUfrHXVdF05vl/ku
3MJAcmNgZKtVF3rvsH6JvGHB9NFvxbjmIljI7bpiWU3q6WF620mOCuxxHmpX
f0f6+2iQ3Jh1IeRK1Z29ahkg/tt1vWtDO3Ls5qdUpxl49ajK7lpZDTo+qePY
DSaakhOefD80gB0KVifrHxB4HvKt/NRaCvI4I7wPmNFR1Kgt84qzEq7bmP1Z
owxwFt6KTiuqxgmHL67+hwloegpf+Szahm7N4G3a+XR4mGb84yVcA3WGPl/G
AKn/+rXxQ7uawNp6Sywsn4HpoMQG1R/1UKvpNMgmeUHxwY8JatQg1smpFYma
jcO8d2vxTscuRLdVlv4nSPJBaeyZyg1UGGccNs1KGIO8rYt93vQTBKW6rfMl
96948RX3hYMU5LP9ulLeNg7je9/937k1QdXeKI3+hAEq40wIfUULnvP98Noe
QmAqkn1fhVIfCg4nzj9in4GIX3PxAb0WeLh6vbgcxQRbadDenDpPsD4XbjtE
+pMtVGXsVcd58FpuOd1P8h8n36zD89V9yDk+nL2YQuqF/fKO4eB2TH04wnef
wkSOZCBTgtyHUQUatOjuMeTVHsqy4qlBusjBrSZRBOQNcxTsK6owLJiR7lPG
gGG6QkpSZyNuUkN5RO+y0LSYb21GGYTBY8slQY0JLJjk9RIjNPzTUa4xz5xA
aGT5a33FOvDeTRbYpU1H4Wa3hqWhIehpJpufFyb96cSZd7enFWH3JeTZSb67
E6p2WCOwGdfDuUdNQN5HkTdGcMoG1oNXrUXI+8V+OXzg6ocE/HO5o4r/FDmf
U236i82NcH9rvdmb5PWqNsslnGrAfU/99RXLDNy8EH2817cUObUrDgmZEfgV
x2+raVUGfX79R422BA5PfxXp03uHvHvlzYfJvG+/fDv3zo4eiLhIyU73TkI3
tlTi/IVaPM82mmw0JufxVt7o9ZFafFOWz62jknquVA7nz32ApIlh7mjye9je
+b+ov34Ru1MVVT6R83f0jD6daj2G5zMb/lFmn4D0Pb69ip/CMOxsto4g9RC3
3TBlQr0FXmORfiM5DDh+OXZbWLcbhI7zaIQDA17pckjP6IavB7PGXonMDymF
c43jdfCbjvpUNEjuP93UtOSMVNT4Wpm8I3miLjIl8Q9XFzj0d+RqkTyiemSG
ypc1iFWy7zuvFtChuUfxRs1CB97NhiydIP35sszEeairC4T3Ua15YTouTdWH
XNjQj9LLe6en3Fko+pPbZryChufrqF7ULDqUR2xFdSZrMf3y20rvj2Q+Nhw6
Y+Kehfcs8/1KMgQUKj9f17bMQplmo2Xqd5KnNnyf4TrfgLi7ch41rkzIUUV/
O337gPTRUvF+DQJeMR+HlsZr4PKF5l5dRsBYJnIq600nZKsdlXbZMMG7gUp8
MczD3wb/4eufGJjV/3o4U3YAYbSS/f4DTHxPyX3J7TMEC/OHIZw8DIhX7HlT
vjIbXJyUcMpDsi8JuioeAQWh+1ZvbldmYOXoVg/HaSqKdChl46GkfyxmRySf
DkApKXL1wkYWpNkOz3IwavG2NdzeSozUh4rn+UfRfqCtORj4i8xz9lMyV8dt
myDpuaIqMp/sEzmdIvfkE9GQQU85tpPUw/Tx/6x90hEtlBpQ4U/q22EVx/VX
bTiW/NXx2n8EXN0L7vFtGoa4GHeFuxqBE34+n0I9CuAyvFVVdpGBLq/ij1q3
+qDn1MZpZEWHXamWpEMjFS+3ZLvV3yHzfei+yavDdbgmXLo5/zHZ//wFbtwK
6kaSqNhDoxfjWOldMXNEox8zaUKS+1IIeDx8cqxKiIKGFY9NJB5MYqDpxfVQ
u0HYlmzXNpofQ9zoNqUTnjQYijRvCWqlQTpmZ8vk9S7c3FJQXtg2CYtReu4f
dhrY87aeSWQwkUnUU7cZj8DthRa7zqopiPMVNVIftqBCgePH3OwEVtf5Go28
bkVA2UZBTWUmyY0Ly/ORPVh69UfuHcnrVTviZZL21GBK12m7B5nPvk2Oo7Gx
JE/ggW+BBAu/9ut9DV41gje6YpNpEdNoC/m61SeYio1Kk9wnq5jovbvmQQOG
MXX1ogDt4TTcc8q7mkdrceKDyKpeUwbcDrWcu/KnA6niETrpD1j4qLJW9+Ni
O7b0hUT7tLFwdiTK3+3rKxgvcd0SNyHw1HnxyrEFGq7apX147T2FqC8Rzcmp
ZQjNN1CSuUfOd5OrW8bHFqiqaur/WEPHKGtzXMMIFePFSaFKT2YxlfUguESE
ggBVtQdMdSbJCQ673X62Yk5Nfk3sNB33dd8fU0rqQcGeyFtSRQzMeSYV2EhX
QMlC76o3i4mYjqp6s8Eu6K3kX6UVQEfi+sCufsc+pIZ/CqlNYqKLLHwm0SX4
4+T+qH4fySerw7qjaAPQyOURTVgxjZPsGhsP7h6AhH+wDIuNgMC2G2PdAhRs
vZY3V+9OB2fe3yHzoBqs+5SsMdTFQA31jFjUESqseRysg5l0ZPx4vMfsVi9W
r7PZvHEXE9s/DKmVKA1j4zLD6PapaUTlC80KVmRA2cQ/M5HsC3VWMgFHT/bg
PP/dh5y3yX5U1L62meyrna0f3jLqxhHBt+goYtJN7ilZTyduBrbwqoaaGLTh
udXedYmVBCS0HPnzFXswYzrq/OEyma+aeT3iMVX4li5xsvgiAwXN9esWSJ6n
vc1MOr6eQMDsys0cZ3vwtjttlEH2aen1hYz66Dw0tUtxJoeR/qks0mBtrMPB
MzLZAvvJfPZe4nLSH8Ty7n4Leus0/LgU5hR7WmC14qeHfg0T0RuvaqpdGcay
MFfrf9JTuJgxGW4TWYY7guGn8zoINLpG5P/yoCCkMP+8PjcBac+CZ+krK2FP
/ZOYTfY9xdGzwrLZPRjPmHDYsZmJMvc4+crCCjS9PsyeEMnA60cKf6XfNIKd
I8CZ8YYBe7bbf9ZF9sHrdgz/Ti4GTE8m+Q/Xx2LOoNspzJXMj70flJVmK5Gp
VWjrfZbcH/t8uZYz3uFwaIV9gg0Bt0A23k21zSi5nvC+35CA5F+zg+nBTfh5
3/OgIcnfhxdlgxZME3Fk8T1riyq5b2zlvulReyD2+1XnjvxJjGsJBDQdy0Rt
8etPr8i+f+HJkteGPY1Yar78O4fsxx/dDr36adWCx7ejfJaDybyT/XJz3rEA
5q0rNPm9yTzbkGNRvaYOnRtW+vhwkO+/GF3Ts05B+HMtgWVtAl/2cT7asUDB
Sgk53s5pAlwBu+Lf0/swYMduFUHua5FH7cqV45WgNoWcP0rOxyor88pu0SHk
FB5w0XJkwZ0/e1ornIInfiX1c+Q86v/V/Mjxioq9x2eulwzS4Rs2tGtqoAQZ
p2suEK0Egl4MZuTOUvE+pdBp385RdP+WC5BL6cI5nSAPs5BJOMpudwtYaITD
5NXH5hsI9GXa2HEUdYNV9bIjhW8KvPOSkbP1NXB/xOs3nETyRHyZlH01Fevs
dqY8VWAg3nK4o+g2Df8ltYpEk3xL9ZSlVJ3MQ7RXvcAleQJNPP1hpzlzwT1X
IzZCziN94PWblqU2ZGtefzsSw4BlSG6RVwENB3wqbe+9JPvfyOVmP4supGj5
x4Tq0JFq4rn3i2c8BCLu3tAl+5BI9VSYwoZGRHWJL5UeYaCjyFbqYXst/qzv
V+8k9VDzd6LXXGsArv+qaec0T6AnmLgiRur7h5YdteQIC0Fpa4oTPrWBbbfN
BS2SP6MeTT/+vb8DhjSoKugwodmxt+1WfTlSF0fmuyfIPP53U76N/SBe6zx2
iPtMx02rl2ney/2Q/e+bvNx2BvQiXeIO3I2D+qzMOqmT5P9nP2qfXfoWnLqX
q3wukX163NScQywL0W9pCVLZBBqoolYa5YOYObVjn4/nKM7OiGu9EW+F5M7n
lp0MOs7u15Z8UxyEvQ1ng7+R51naMTzrX7RALFBufxrfJNi04xai72tg/NKx
s5qkXqjKFoIOpgOg9PO0zvaT+yA1a9CtvQ5zCzGb3P3I/flSN+pJYjfOMVaY
S8gz8D/Pmhbg
        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lOsbxh1K2uRkyhJlz0mp5FQcXJVCGyWRaLF1RIpSlpOSyDaWkC1l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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk8lfkXNiFp0k+MSGpIIyF7SYznWgqFIiSKW5YxUcpIKDFMjF0qjH3C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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8llkfxlFhGKQREhIlTU9aJEujS5SlkbGMFpKlNEymlEi9tpFRGUS2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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3cglP8fN0oaorKpkPYwUkbqJdGQQsqXokRDkoQKmdkNK0mKbIrsmZHt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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41Wkfxo+l0IKRFDNZqlOKtMzIkrpVyNaJGea1ZVeWFkOzpDkSMoqM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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4ltkblopQCBNJZcuIlGWyxdxiLIUi+/YpRSoVrRSRJZSUpY/Gmoxq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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk81dkbxw2lKSUtlmjQlML0a1BRUh8hpcaShAxZSiFCZVpJwtyQFktK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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VH0bxoUULVRCllBEhUgkpUvSQjxR1hZJCNEibaIHeSRpkSxJRAgJ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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81VkbV/ZlprwmY8kSwkiolKX4kq2EiWhEkZB9aUGlQqWNhJGylKVL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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk01WsXRq57kluIuKVDkSu6ppApjylKkojMV33cVMZUhlREoZRoVp+I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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lWkfxk2nUNOUnRlLRpsOWWcSxVVGBkVNb6PJRLaUsmdNSEJ0krIU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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VP/bRoqkQkgqS5ulSCUp6rYlImQpvkmSItkSpVAqSiVZS5Lop82W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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs01Okfx61kpxCLXKJyi5KEttqK3rYo0ZYiIZVULpVGyqZJqeRWloiS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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk4lWkbPxktZJQYMfaomZEpElNSPwrJviVSwsnoKz5apJAlWSqjkrEU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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVn04lNkbVpSSpJQka8dXIrFKrdpy02/7oFYRv0pKiIRFlKKUlgqRj4Sl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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lO8XxiflW9EiJbTYIlGpJEV0C5W1QkVlF0kpSZtdIUpCm2wpCZF9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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs4lOkbx8ckKUQpwtJINQqFVML6OqRVpBObnLIqtqKVopYQteWQwiiV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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4lVsbxknpkMiYHIpIKkV8hoTbQUSKMuSQ0CFJRUSmBslwRNKATmgw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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekbNtGk0DpSUkapVGihaaFulK1SlmPX0MmeZKpBSAgnKiKhkhRJ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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VH0bxvGUqEiUhGyVKFG0KOoiW4u0PEIUKm0Usj2UUGk1IipLQiVa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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41dkfxy2FhhmSbSIMKiNJpaYMve1kkIQWS0Q/iklDUlPJXohsEWNC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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4lekbx20xk6WNCMXRlLVJljDUt5oII7QhIlmTFkRJRMjMRKESMjmU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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4ltkblmw1mkxmDKNsYxpbKpSt3BRDxC+hqQl9pDIiTDLJ/jUqoZQl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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k0VW0bxjXLW2QIrzmEpEiSIpfKUEppQqgkDWYyVeZC6kWRZEgpswoh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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx6VCQ6NQU5JEdJNUpiyl+RBZsoSyDFHRYr1SdmXfkmgllBoq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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs8lOkbxuVMIp1YpWQr61ArlA7ay6kDYamUbHJIG21t6bQOySEkh0JO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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8lVkYx2+ytCGRSGOmrqJGiKlE9RNtM9MgpHCbabGnLKOSrTSJlCkl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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHk4VG0bHyr1pkWFJK1UikSIIj9JkhAtSPYthSShelUSsiUhqYQW+541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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk41dkfxy3l1i9ijFCpwWAshSwNJt7NUIlGjcrSoiQyxpIZS0oGWcqU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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk0ldsfxpGkQSGipEgkVzcpU9MjSkgyZM48pEEdGkkZGohSVJyULoVf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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4ldkfvyMyFU1UUlFIWZvQKCl9bEm0GFGSLSOEqNGUO5aoX5YyBiGV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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2kgVG0bRokKSURSyNLyKnshddmSpFfKa22RCG1EsqRNoUWWLBVCoaSy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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41dkfx42iZhQKkxBTSSUZaZmK8VYSERVJ5CYUKrJVpPTYI8SMtVAY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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs41Nkfx4l2hWS1S+XRShaVkFVJ5a3Idcjaco0QueYS/WiFYiMxwkpC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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns8VPkbx4WVJZd0G5dalZRLG9GmyEdsG0KtVJRQqaZy10VJLrkUipKS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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3dcjf8bxpNEStKkNJSMtMyoL5cShZAiaVMotKiEJhmpNFApNIQSDSpp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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk41dkfxy8TUSrpR5RQGq5InqKk8iaRrLOUZSyJspStGN1Kkl9ZMslM
xMxQ3GRJhuxDtqxZ7725yc79njuotCkky3znj/Oc5zzPWT6fz3m93+dsdg/4
4ZQog8G4Q7f/+uHS5R3tWnXQHU3KmVQkGCmI8fUQ1MNK9P6uqnMUZoUhlg7j
fChM+dvM/U3gaydbOeVWj/vh67601VLojhO5WBzBBffX80bTlhTi/aQ4cu6D
eNs4J5siSnA3XyPkWtTf2HAjZetfhgTOdmsEG2qLoM1YlFZTJ6gdL/RT+ud3
jLi1HMu0J0gd37cycEsn+mIDiw8rERxabEy6dnMY76Kz9Rwlx5Ayf7U3r7Ed
J0zL9Se2CCE9rDIZRFoxEBbmyXtL4DDS8FlO8SkKa/+3It+UYLxVOmhlLhu5
K50ZVccJ0jrMjrGpJGSo6vLn7Ojzv1JslcBSPCk5b1tlTrCZZ5a95xkH906y
GeHuFKJDFESsu/sRr1uSq5w+AkWZrV5av3OxXMP9+fouAQLDXP3FkpvBy96y
br8KQXcMKflzLRfhXiXlAgWCO6/VcnsGWnFww6fmQi8CFqvI1rq4HyKUjnFZ
7D9gfJXWHnSqB+PRWbUnOwg2FGtEnfvIRZHaq7QLa4Uoeh+n/vojD4YtMqa+
BylYbks0uGY3iOrshsfx6gKEv/+ZmRmQjq+ln007bAlOVi8ZKk+VIySD121B
5xeUs6vzVMlDpDj4HWHrExS83m5t8ks7dlb1Koq0ETCmlDcd3caG9BqHCAk6
vvgbFpl/327FbK21b3oOhfEpMbHPpjnQ2Wp0tdSX4MXz1BLjP6vhElEYsFeC
rifhmVmEtcFINXx1TQxBeBKDbWfcBfPL0219W/+rfxzrwa0mbNeP6vFyJNAy
pzS6Xj1GxUhQkocBwXztpvnTOR2wVx1yEbtFgTn4zQkjjTbctmI3D1IENn53
Lsn0vcRcQboyGGMoMArTPjFZjRV9Bs4H/QgaZjdl5r9rwNifB7Y976bz4z9I
XGtagwqJ1wc1tWie6wOom9rFcFhYybRnEmjLdo8lsvpRHG4V6PrxHxheUVf3
eVoPQ1mZ6xLzFMr5uaVPJDvh52BbpkIoJA98ef7sdh20+3a0NuVT+PZom6iT
Tj8W1BV365tSsHHWEVN3e4qQpdFV4mq0PvpcZvrn+1Bv6zO/8geCdspves/y
DrTlZbekqQqR3XcyckVbD5iLR6Jzrgsh33TJ11PYgvPiSkYzQ3T9imV9ElNi
wPKSVYh2oXmoCtlbpD8MB5e0BbaAHnveTCuf58HI8eh23qQAI22xPmWHMtDQ
IDXa9yOB/MEF+4GsLqhyGetPywjxvj/SxOxzIa6reyjG0fqLvqAgL7KlG7Gh
Ftp7vYXwdtXb+fl+Ntp1OL9qmhGEEmmdK5YVSHO4GHFjC82H8spvpi80IqEo
NvW9P4HmGwlDg4AByHBqwiN3D2PklHWT01geAh2vjfXQ95GGd0xTkwEc598J
kMmj78fh193xjXx0SZVNSw0LYSSabWm4n4vI9Qdq3E/QvDVYu2/nlcLBYMUK
Ls3Hy5z6h8KEZlQc5V3R0ibwkPSQFb7lQa4h9pxJGgV5lvzcvbg22IV0rkp4
SCFUr/djzqsmyNgXubX/QeAtVsIWDR3ArPdLqUvBFNykSiU/TA7i0fqzcy9s
KKj0V58LimtH8TqJn4ppv5E/0trhLF6K8uDP2T2WBHVz60zV4/thxnywZuie
AKvZebNjNY3Y35y/KaeEQsTjjsFZDQ56VPR++S6foOanmY027Bf4tGFJ5O4x
CiNdDIed7CQct07P9XSm9Z5XG8jJ4uHNYbunua0CsF6lCFjxDZjJL1uU66Pz
cZ+4PvCuAuzOkKKYJTo+85TS13aJGPeWnXCk1y9r4MvE7XoG8YIXFQ50/f1V
U3ZphLYjfs/B//clUzD666IOLl9H1/T01C2al+/uGQePcR7ApNK39QcWgeuD
ZauCD3NgUDPZe2kVQWSdluaicTdysu4ML54WwvmL3U7eEBf+KWe+Gd1Nz7+a
8shbMhe3lrqjtlsQXMvgey/TbMFahcoPkWEETEJFPexth7jk/Sm7c7Q/p7LC
l5a3QiBZZX3oA4V3W1n2E9taMcH9w0rUhQLH+Mfy7188w4L8gIJ6NwVpqWPK
U2UV2M2NYVTS/p8wWOPlVN2M4KpDp5ceEWTxb3eYeA5BTO0466i/AAVyE5ca
fn+GQseQzVnxBA+YIvv22RQghORaRNN+1L2sV3dKqxPGqYn+ud4Upjr2GQ3v
fIbbS2Hi/hUUfpo7+RR+/dAiaU+kJUcxxUxMFhtqgtmRuQYnaYLyifoYcUEJ
3GJmqvmuBNwYlvLGqSb492atzfKg95/Ltn++uRuXz3ZufE/H276gbnXGpBEG
by7LVUUQWDnGTSx7xUGTtNHYqR4K3x0WjCus5kHfXeL7AFcKjM54+SjHDtpH
uO/daX/ecYUdkOHRiw9zjZWrP42AmV5QZLKHD7HeuHY9c1ofYevCgnsiwPYo
PaLjRhAxO0oF2dZhwSr2jW4yzevmMzvuSfVhb0HN2L4wIXboZqYPb+TjZ1WJ
ZdJlBIWeTLsVPjxoj559+1WaAlezaS7SvQ6yTmdO+m0kML/V+DF6uAUVyebd
akUEYZr7M5tnODAtDJ3pmabws0qmYgyHDzmV5FxWGYXaPN3BLy6DqEx9ufYX
RQq+8wXLH5V1YL0ed+jaMAXn1ONBFZY9SEvqel6xT4iMBKVJ8UAOHrUV9Ow5
TfPfU5+gx+HhsWvA1xA+wW9/nZWPuNCHYLEDpkq1Avi81Qy13PQSNRL2PjLU
KFw1LTx5STW42KbU5RZKYG3JsL0SPYShXSrNBWsGcOix5bpxyR7UFmYwOBoU
bkh/jBiJGMTdtJuFn8uHkHJXotZoWwtUPU1WMxto3pJkJaM/VaL8vnvoAO3P
IzbJfTcis6EpO/s2/RStF1W5KaZkGw6scdDh0rwsztf91qrfCO0DjYZXFygY
KiVo1J58idVizj8W3KLf228dd5Sfz4PTbKXX6yj6v5GfuHtyvBjHlIdV/d3p
9+228/eUXBMS5EPG5unz/gUCFb/e
        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4lWkYxiVJltJmJIMkRZSMhHTuaJkIISJqsrWolLJkmbJUx05ka+Kk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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lVkcxnUpyh6qUZZKpVGDkjHUPPZUym5sI0SkUGqaGlkqEZEURqIs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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VO8fxSUKydoiIdS3hGxJSM4klSRESkRKRKmEpEiRbBFKJSSVohKy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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlns81NkfxqWSSohKhV0tISKlNCk9dnOr6KdMQmiNEl0kWSkqWhERhZL6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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk8lHsbxh1NHFJUzoRUZOkYLWPPSS5bUXRSlkS2VEKy5BUpSymcKMWR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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lXkbZkYkXyohLTiO0nwx6Ms2VLeiZWqSmiKVyDaULSOpaLW3kA51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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k81P3Xxid+2UopSgslEQrJFqLLraIktzZaUImoJFpQN0WWihKSkIQk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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81dkbx1VSFCKpUJEsrZM9pI9KTbQIUSGMDKYULUgLojCyZokQlcwk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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lekbxkUqUTGWyKRFDZkszZBILmPPmGwtKJKxNkYY2iwpDQaDhImR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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lekfxjmFikkTI0qWKNpmlKY0+N1kTWoiqaRGshyNZJtQlhIqSfYW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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VG8bViHZUkr8kiRKWdOCkltSSSURlZCk7IlCISmlQomIsqdFtmTJ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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lWkfxm3RiLGHhjdlbEljLVQuRaQsNZbkVJRIeaUZEqZUY0loOmGk
yET2CadIkm3s+3JwOCd0nOc5RobIWCrS+7x/3J/7c3/u53Pfz339vtfv2nIm
8EcfIQEBgRRq/H82jG7eb8Bl4XJ5bpS5FA8Cymm31411oVXDfUHsOgnGaWHb
PPtGvNo3OjnJJUHv1c2z7u+G5kOPxQ55Es8NPOgn4kYg/lDuVGsIH/G7mkU+
n+qCvdG7Db3GBHKDWOykkTok6kVnXcog4SfTqWcgXYtndg6VJakkku393aQi
2GjcUXGgXGoCsZN1sgITDNB43IHckySkQ+QzZE8zwVhsdjKeIxEYckKpJYGF
c7FaQl+7xnH2SegRscFOXBTWv2TPJzAslNl7yK0GSQZBM/rWJFafJORpjnJw
cl/rhhOZ4/iYlK1aKVUFcb+OLD61L3M3er2DZBsmw03nJJsIuMRtSVsNYGFJ
eik9/CMPnDEDhde5ObjUY7u1yp2EpUbg7oTMGJiuGDu9OkUiRvqVOK2VCb/l
i5H8owTmeM7Ca8YleKoVVuPhTaIxVMTG0K8HEf5PDEZvkgj55vHdRCkmXA55
PurT5kEpXTszf6Yddb7TD5+9JWCp+h2Hk12I3E3f2dwJJdHp8mGi/hkbl/11
4p05BBpnPzkH641gVPNpCYPS79nUwNYkPxYSF5I74sd4qBPkyOllVoElW9Am
+p4A3W+XnMTRNqRM62V3xZC4YfU1LGKajU3flqubRxO4IG/pPjs4jG+0t9OM
gngQmf5wXT57BOaR5fq9uSS8FCPzK4oaoao9ncX+QODWwfA/tXtZSFUwTvg+
ZxwW0zFPrQoG8clUYH/ENj4EyLPE/uBXsLggVR3qQaJuiLdUfORXMBzL922n
6jnXMRLPVm/Bu+fvTu26T6I31SFUtO4FZFaCDaoovR5OP3p+LLcKZUl24zcp
vY8wovYfpKdjrF7qDqjzLJVCzt2NH8AzRdMYy1+p9xQZaEX11kLAem0gitIr
2+Nojbk3G0HRssfitUiovXXZ5uddAO3vfNSKr5H4qG8Q6aHXAmZDIymuyIfh
D18+6FsO4dB7byVHQx6GjYqs7M1LsdFQfHmvM4n3HB+fwfXD+GrueetWDYnY
pjZCcEczVtWVv6zvJlHZn7MQ8a4HwTrfLh5UJLDdot742kAHInsKyZAwEuXz
BYX3wjuQ3VPh5ZBPwpkh9tb7QTfuR3PN7koQcNbuCR8TZuFSHFu8Q5OH9Mvc
xQT/LqyYCdLGUgkUFn+wVOJ3wdr1+u9O2pR/HlVe3HO8D3EaLf20MwQeDvly
BxPbIb/Q4XXKiuJLtVVZy2kYIv6kq+LcOCY/h+cn721GJ8l3KhknEWyyLBsZ
2oPWfI0nj3YT0CzI2znMHYXzsf22n9N5YOjQFJLcMuDQxrn/23ES/31VvW5u
shFOqZ6VThS/7L1aGo+DWyBfL2y6RvGw5+Si+9VzDWCcVQ74TxWJwyJmHWW/
t0FO3ySi0JVA4miY5t6rDVBj0hBL/Z9+S1quwz/DKLlXzY8wnICXe4bN3OlO
xJfJ2NJnKP59N36pCkiB4/4o2hmq3ua7T+WcbmQhOH5Bh/QgEPrSPXhkaQC/
ucxWW10h0VpgZPlyey7I8U4XPapeyfVWO1ZE++DL1DVxUCZxsKVA8tLjLrwQ
Ccd2kuL5i2Sy/pFEdAsX6oPiTeDzyR+4Rm7YWlvUc9ST4ul1ljy9Lx8/0dP5
6uepdV3NgL00B7GjZWvNdnyslE3dpq0Ogc5VWgqMHofE+L2qy7QO9N79s/b8
Gao+BcLUgoH02jF1rj91nyev6XIxG+0vZXSbKP811mU721o0oHxI9eepQBLr
M+8IZVq2wKfTcVeuBB/D3b6jYxn18Mg/fMZIiQ+1WeujHo1PMDm1kLmT8kM4
y+G3xBf9WMfQWvGvJKF0X93nsc4b2FyMf3ay/y201/nI7XnRifmRAR3XNhIW
izt1vZY4KB108z+SzIdp1dWrOW61GDoUarf6gOJZLUBI1bkK8600OW8pyj9p
SyZJLDbKQkwl/3CdgPA9l0N9Cd2ocLV5JLRCoGa2LW5KpgL1O+W3VJtR70vo
nvg+thK+oWmKPfEkdhc/PZtgNwK+xc3rtIIxdDb9XVKn+QbutaGp4RkERIRE
N2j4NMFqNOje/X8ICOjusFGx/QXWT0vFr3mRSLD/eUrIm4EYhS+722xIcENm
S8+aPIXE9toD5wJIaL8XDMl+1Yhtm+ctGlYJpAYGj53IK4fCVfo3VpdJlOnr
K9zc2g6VNonigM1U/ynNqbyfkYmpUMGZwQMkbq+Uv7Qd6EK9nphZ1AgPls1Z
Gg0L5Riji7i92UnikNzausLKPtBTRG8Y6pGoOGfz2eZCM46X3nJquEtCM0rB
vffBIDIOy1WJB1P9fuRiadjmPhAbnT+xRwgcN2kr/aTEhCg3rGmO4q8xR+HK
56B+LERdl7Y5ykfLbZU7c4KDeOBR6jyziY+USGdOew0T1c7SuyR+pPxnWO2y
3FMMM+X2fdtiqXx9qzkTuq0PTfbLG6crKL9Nq3faqTDBcWzuDtpLoF1R47XK
tl5cmedIPFwj4aJ0TKxjsA/nq6JfZlH+m8yt0nDoLUTe36z1e45R+zdI858G
ijC1ecRLldJ7IHd6/qfFQdjTDrs+EOCDIaT516ZPQ0gI2zjEm6X0EzuyV2em
AVM68YvTlH7WHJWTjZsHcZ6TIHNmgcRSKiH5fSYTcpoSRc+v8HHw2gUZs1wG
2mUF1xLcqO/txJQ9vbowNdZmLLhM4EY/O802ORnfCq+qmVL5uUJj9VpvHIXK
ggI/xmAc2hIzb35J6UbzbocVvRdUf17/hya4TFz6wxPuWQTkpq3fMKg8z56J
mx1o4qLuna/978tM3Pj3B+93dCov92xw3JQ/jLToj34/UnzdcBVTjo/Lw4IW
Q1eM8k8svShJPacerp/srJhUflSENjseeMSCV4nRJFuMwJpf9PMk7W6EyCb9
dXWChx2dKa99vwwj3EFM9PhNAi8KdAMPtvVg07yk69dUKm///dPW5DYbav/4
emhuHkfKPp9MfUYzWOaetTsCCPwPaWm6LQ==
        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk4lekbRlLKMiGX5WQQCRlGtkrdhoNja4RSkgwtKoOhskSpJEaLzMiS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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk0VfsfrV4rFZ4oUREeKRXuI1Hx20oZFiVRytAgiZ6pXhF6kZBeNBlC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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4lf/7V4iKkqIiQgNFZgPlpaIyKqtCVtKOyKiPlRX6KPkoI1mRGRJl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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk8lWkbPg4tI30hnyyRSk2K+SrLlOgyZN9zUkqSLCNZkqS+fElkKZMW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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk4lGsfRum0oJIthjYiOaKyHdU952uT/VAqtCGFHJJIC7K0yFYkHdGU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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs4ldkXx09Il6GSUOaXmsoMXSTlMmr6qjCHRkhMI2OkQyMaalAuY9wa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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VH0bxke0oZAoFZESwpMU8vBcQiUJRZZCJSQUqUSptFrSRknIHpKQ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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk41lkbNm0oyRBJUzHK+MJM2ZLKLUtDg0yKdySkLIkSlZgmEiIqSray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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs4lOkblnJoR21OJRQlFhttZSVbbsksyfmQVidGZEOUyCU5TAezndNG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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVmk8lVkYR4kWQooWEw1RkaHlltTflEER0tiaFnJVQpIl60QkQ8nQSumO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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VG8bxomoqJR9/akQSkhFpS6hUqFIe0SSQtFiSRKFEFKRrKmQbFnK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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlWk81ekbxo+TLamxZpkwNURZImUSucrIKJQ0DUKKREgKJUsh+hOVJiHZ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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk01ekfx62hjFHRlFIqaSM0kdL0tnUqP6HcqZtJighZs99RZCsi+snS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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8VekfxzHJJCpZujVaUNJm1MhPDX0kZIgkeRHapGxZJiI/e5ZIuIpu
iRRDylgqlyL7lsJ1udwwZXkOSkyLSqHm6Y/zOq/zOuc55/t8vu/P53uUjnla
OomJiIik0OPH2b/sWMUxLg9xFa/csh8QVMV5TBY8ugCDWw3iLocJ+o0EV5zW
/wOvO0/XO7kyEGGC7lx2qUOp5DquUxSBcXSWqIdpOc737hYL9CB4YGbvv1so
BNspZOldOQY61c72GyPrYHx+8hQ7ksDGO/KGiUslxrJMtpT/SRBOvGMnJjqh
l6m1MUeZQf5RDyZGrAUFx1nLp8oI/Fs+d20NvYwl8+PaObSe27LK61+q10EL
uzM5cQS3lkL68FgPLGOGCztVGURs2hxpzBfAQ9fQy2AOg+0P9yr1iTzHlkDF
HEk2g74Vf5ydHeNhUVK3/9cCAtZ20W29UvU4qHcw4Ed9EVbH3y1zqgJnsXfH
zgCCwuaYaAOLNlQO6stp5hP0yXOTl7zoRfRbUtnuyUDj01qiXVKJFz4XL63x
JrhzezxYWpqHbF3d/8VXE5SHeUoHqTdg80m7srCLBMOl1jFPQzuxw2Zof+IC
BkdMzM9KPniIQ2xxayV3uj9H14shtTV4abfPLJXqY5ObDqPPz2D1jsUdSiXQ
c7f2CepLgIL+PCu3H/1ZI3NLe0kVtux7S1T96PWru5yhG4XoTC0PdDpOcCKj
0DNmazUW7zxh8Ks/gWaPxEqTMT6WP1sk98ckfX7p44ZO52p4uRWm1dP1SfoF
ro7zeuAR7PJRNYnBwTwxO6uTfFj65PxqPUiQ4VmUudWlE6di8wZiCgmaPf4K
1kjj4da9DYO+nQT2HZ9eOpVVIWD4W8Io5aFltVLCB3YFgqTZqRmnCdTkW/xN
5haDG9sT73SSYLuur5RJeD5e7TN6v8uRYGFWQPGSpm5IpYh2v6O8TTcHfHu+
gA9J6ZtXtrQSaChNXHj/ogvN6VdUYun3mmTfGHL7GiGQlX3nl0bwufXuW1nb
XlzVyHv3ZZiBAufnCL3MR4hYesjS+hStf62mZ70uB6Lum45WUf1U0jZojlj1
oOW6seL6rQzi/j5iE/ChB2P2J8NWNjMQ7jBoC1CvBpuTZ2hCeVjlcEv2tU8J
qsQt3G+4ETj4LXZPDxCiWb7bMOMgg/4yc4O5ErkYejrwuPcowbOS97bl+zvw
Z9upelM+QdBN94p3NXxInbg/pNhC+b/wydbPvAtyOf82b9BhUMMLU6yVLIHM
3bZoX2cCP1OTThlLAe40Sc4Lns8g3H6IHPLuggGrxKjfggGYddNZ1D9vy3Z+
W9ZDIBKqXvPxSAHmtopekaR6FrLn3KkZ64Ll6PTLmGnqb+1HCebySVDuv1YR
TfevOXhG+8rtasib2zno0v4byeWbaLdcRfrLA5w+et8pjZtj0doOnYlQtfBG
6hdB2efKj89hcZgbdsWMgZpC3msVdhVSsp1iQzwJ5PbNsd3qyYcbv+23pr8I
3pgFamklPobuApaSnQ/lv33yeYJyOw5V50p1PyGYmjrk+ZN4Dew/7LTuOksw
uEpZ1T6sDonBIzflztH+Tkf8VtjUiGyV+nuv2QQKAaYxM0w93Oe1GRhQngPz
N544kdSG028OnizhEoRqxxTtUoxGf5iulyWtX1LRnAn8LsDiIlcJa6pXqdtC
Vn7OE0SIclKNEgh4pieLAyUycebV/x35R2h/r+ms4UeWYsWMdYoU9WOdxUim
RnYnVGQ6L6nNY/BKse/34F01ENqsXtPjS/NCXzehSKQavh6aeeJnCLiZg/3l
Bjy8uD5eea6GYEVWMy97fjeI/P0DGcyPvByrXvK4BKkDbMMllP/+wDGRi0XJ
6BlyaCql9a5ziMwY9+ChPCFs2KuYYIfzOqc+rWeIZ19jJ10nSJdOelgr7Ia1
2L5Zf1rPFH9BSHZoH9hTj3QPXmSQaKtWgOh2nHkTNbuliOC1j7PY0VohGi5d
PbDQn0HQ0ponlxs6IOWhPKA9QtCwgPV0ekSA5k0hg99pfi5KK/7ucq8GT2r7
7h8NovqsmN6ZJlIEgzUTEgzliZUsUXV+lIufbuRpuVM+gzU7KtvutmO0fJ5y
fhvlzzVXveFxKZyVBr7nU/2Em/asSj7UDUmN8UuuxgzmCnu5LqZCREkW2Q7R
+ZCgzVVZ9qELHvvP6r01YnAgQNrY0KgVGqdVIxxyCJ78Fny9Q7IZfg7RgoXx
1E+pum/u9bfDvC1nhy3N121TuqEPa3ux2zrq69cwBlZqwWc+POGDM5ql0EDz
wGXdtQpX1V5oF2Xd0TdkYP03I5Ix24A9/NkTRnR+bbx8v3Ugsh6DcrMm8YH0
/eZejim1PBSbKLbFNRBcHg78Ep7bgS06YjIJ/xBw1nKMS29mw26mwLqK+rvc
0/fDzN5m6H3p3uodSzBUozte8ukpXoiv4utfozzO7FZTTU5GfGKy6V+0vxak
XvH9YCWM3FOzxCk/GuVSy0l/ASoHHEOlqb7nf0kLnzwmAEtNacp2JeXV0Xl/
oHQ71reYDv37nMBZwqtYufYxEt/MLeig82G1QL7RalsHzinmWU18Jfgkwpvl
xvyD79nxttxzNM/KH9kZ3uRjcvfflz2+0PzTWfay9fQNtBz5OdGM8i5yPajB
eX4HZlb1HE8VUP+5Zqx0ln6OPbvkFjvoMXhgHJc0pt4D7+RfXBtDaP7ULWh5
5lOJCZOoG9rU77zhwQt7FUrgGpQxG0j7vT1EOu+omwD7xYNcx+m8WMOaYTW+
b0fsM6eWPh6BNs9MpqmsGXO+325aSHkWbl4612fyIRpFrbTu0fU2K56OZmt3
wLVT+19NUQaSzotGdk02QbaH8KajqX4qtmbD/RUQhGQdO0LnyaKolGAZKSFG
vjWfqfCl+5XKT5dMqUVdPqv/V5rX53M/fjp3tQIbXS/ofKPzSCS9r+Dctlxk
nV9lsvoYwe+LlztEH25FWJT6wj/pPLuwejB1/KMQrAnSt9eGgXHv4NoC9RaY
WVZ6q2TR/5vwMO/rm1sxqK+jIFtLcHzRqfV+o6149DZ1gxL1q6hZJCv4kgAc
F8Up7kYG/wHOUsPi
        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VO8bxkepJG2SUlIkUSokJNxJi9Q3FFmStJItpAhJkiRri1Ck7JRQ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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkbxw1lMmVpRkg1hGTJUA0Z5CMtthpzkSVL9lFR8sOvSK8KISZr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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVWk4lWkDlmVQQqnQIkoRKSRJk9tI9krIaKI40aIGTVJJqFDq1BgUooiS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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lekbx89UlrIkhXapjDMx0igjla+UJdPMVYaEZD0lIstIMSYNv0K0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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8Vf8fx6VCUqloSFJUZDSEUnrJKElIoiFJFA0JWfW1Z0mKkJBZIpIy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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk4lVkctlylsSRRKpUtSe4kGUvUq6QFoUUqauxki8oSStZMY40MEyOF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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs8lWkXPWWiwjflUswQKsmlUBkyxiLllsott9xCTWIQOSoqJiFMBoVQ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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk4Vukfxt9EpMbaKFmGphUZLWha3GqSTGRpGQ2pyFLJFj/0miyNnaSx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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VH8bxpU2lBQV2pCiTUhF4UZESIulkkokKglFKmVJthCSrRJZf0gT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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVmk8lWkflnpTxiClhKTGHmUrKrpMTJZBSoulKFGSUBHjLccYS0ykMqmx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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs4lGkfRohSmf2QDYlVKhN9RFPZblFJtZSGSGE7LPGVSUjjlEjKoZNT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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lekbxknKRI3UyCBFY0mMlpGaymWnMmWd0akpYznZ0mYdzTCpplRE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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3lYTP0bxltElCSRXmkRERUtr1C5K0miRQvZKyWStKC0F/FSkhYKJW3S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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlns81NkfxodySZLEppTUyj3lstpl61FZt4iipIvsGNJlk1xCoabIliTJ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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk8lekfRSgzIlpoSlrsU8lWSE6hCd2QvUT2QgaVSaFVKCoKTaSiQqhf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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4ldkfv5XIVqFFaijThEncbKU0H9OoafWzJKZBsmVQuAiRuUmLGPta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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k0VA8bJrKWVEiUpFRaJCFJnpSEhFIIoUJCKilrslUqIrRYQphCEkr2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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8lWkfxlEiO9NYUkLbUMlkS+TSkSU1lgkl2Rq7VlH0GiQaLUrWprzI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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns4lGsXxp2y07Z9lUJFCqFMmLZj2t2knUPIIW1bhCJNxFCSSEcVqW2r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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lXkbNrJECG2mUWGYS4XskeVusZR82SZlWlDZ6mSZFsqEZBRZChkj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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VO/7xylbKomSssVHZa8UofKW4msthBQVEhWVKDtFilAUFVJZIoXK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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81dkbxykJYwlNSZFSoSLzi5tIH0wjRcjYJiVLFArJGoWYSGWkwpRk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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk8lWkYtTYYyYwlFWVU4tbcLA2yHSRJu2LKFpcwZVIkhIxSZuwxDFKW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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8lWkbx0+2zitjSTUjMqKR1BQqGaZ+mDJeNRWJUSqvoWSnLIWT0SIx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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k4VP8bxiUkIUnZEi20ixKSuiWlEkoqZMtSlErZlx9CSQkJyU5IthCS
yJKdGMzYQmPmzBjSpiRK/uf/6lznxbnO9/s89/O572edzXUje24uLi7LRVxc
/39qaRlM+ng5o/NJRcM2KwJXFxq0B/p7EJUbkDVzioH2zrPuM/soUHCniNzS
ZINe/sIhfawWaqVL/OxpBOL37e2Xo1Kg3lzbKxzCQF1dZQHzeAemDuwS4F/H
xBaWgKye9wCoknSLAzMccM3JGzUMXoJm6D+3WksCYpaaU8K/a7G69LV4uwoL
mdxdv5+l0nBNP1Asf34c1vpjYa0TWcgLafB5pEGgPiRXRPfKIK6sejknuG0M
d50DFM/GDyK4l7cjyYOO3zc25vz99B56KW20USkWdGqkf/LefIfa3E/JVxQI
0FfW7v4824Ujf/+dVvRjoPLsEXVl6gcMadq0r+8k32t2pzxj9sGlqF08cP0Y
OKWhZ6OiG1EuddIoKZaFmo7MsKDiSNQdcUveQJ5f9N/zcpPP5P2utJaGjX5C
6sWE48u7S7FT3KYjJ49A/+6UZkKsBh/FjWoM9FmQ84vYb/q+FmdPCZ6KecbE
6lyJGTe3AXRIH9thsolAV26fTcLyIdhEC5c5CBLQ+GgbdTuUiruMzMNsXyZ6
JC64PxalYXMVZ3r7CgI2ISI7+nc0gaVleUeIQt4vn6tUXCQN9Awl0WtmBEQ+
HhhNH01FL+9/5Q9tCCi56qdYXPmA4SnjM+WjdNhNOD05YpqFQrEN83XbCGgr
vS5Jq+lH3rNbE4bnmYjME7fyyCyA1lbjM8xhAibtEmnuklWI1eVfatjHhJT9
A98A6xr4ib/T7XJlwiD9Wj9HuwNVua2zLRc5qJnR2Rov1ICt3huUuD+yINIa
03jBNwsJD+bdDxqQ57HbJM3cnAoPvjiDH+cJREZ7Zgbo9KM4+6eyXgQDJfuH
DJwqe5DR/9WA5yAL7LJHOvJx78C9SNFfaz/ZD/9/1/XNMtCVzRZ6Y0iAGihx
7OnmWgzOFXj8F0sgQoEi+Du9C33FHvoavBwYX69wKwnrwuBaifzXP1jo0bO5
KLevFdpiZTE051EEuzQ83BffCFXXFeGnfdng/1npbf0iA62JMS1rAwn8dRKI
UsjqQluo2oe6QvI8yt3CFwR6wF7LkXyROopvsZe+r1MqQL3pKckhLwJO7vla
ipUduNTy4gJ4R9HqKe4RSOnCoo6zYjsvj8FYtdF816JarA9f7rgimomhwAcJ
tr8LYbCKr/ZAMQEdWPWJtbyFrFr7ws0aJnotiTY5yRYs8IReDJtmYmC7baf9
NwqOy0bvSAplQM5xx/6xrRVYHBWl1JdN1tOwXSpv7BF+eAoErCPry6nfOXQ0
JQf2ErEp53YScOgttzxUWQRHB06q+giBK0aihe2FfRDV0VRQTh3AvR0Secul
a+AhW38iMIIJH7GkVpM5GixemwfdZDKh7jvIJ7KnDuWulcfWLyUQPKJz+/5Y
Fzlv8U+Ygwws1pZ69dGlHBqevP3BRwlsVA3il66kwk+EIfSAwUAF7Ub1+GQV
Tob+COtxJLBH8kRfj1o3HlOVjrAbxkBvOvxK82w+hCMUQhy1ye/ro+/MpNQh
1LNsxUwIgTOs+ent3jSYnaG1puuxMfcrsuzXz24UFGtQLM1ZePotRy5+oRMt
+tkSO0hehfHtCnuqUASNxUub//iQ/AnfIqfpWYE14WFZ8nvIeekwETknUYF/
Oy7QL+QzUD3On6ipNQzK6eVBJyZYWF9oqXN9Uz1ma+jjfFYMRP6xN4pdXgzD
jMs61coEPP/88t70g+SHj2Nc3VImjFS5j7ewaeiwd7n5PXsUIjRF/dKRp+jc
WHv1CVmPn/V3NR/MtuBv8RaF4lEmJAgei4V1LWCI8QzKkd/HDlOCXj3Ih/zo
veir/5joto00T0ypRHD9rMXgDhbeyw8qbrZqhtNQOL+pHAGJpPjgfsNXYIn8
zHFKIJBqqhqszJeHy30nUvz9CZyIl9BLC++HpapA2oLoBAKzo+L236DA36vS
epXpGDwv6DJuvehGxLnhjm8WLFw+anHuWFcnmN5W9QlrWciQGtz59mEVUtIL
5Ab9mdDKHjwWJlyCsOwiNenLBNb8HJh12TsAJemve8pIfp2SX8sSKhnBdLIK
y1GUDa6DAWrSI84oVOrn3mBNIGEyjXnrLRWJBdwxmaUsiNnY707YUQsbzobz
khtZIPjfGHX86UF+pIjGUhk6gi8ZWiumtaIg+DNraQEdCmdqdzmyuyCb6pX4
7QmBqcov0s+2f4DQpXZn5a/k/WWtH/8ZL4f5Te3Xy18R4NJJ/0qVN8Df7UZ5
x0i/Kz7TNhlC8sru0K/2Kc9RnGwU9V58thw5y+wkLUyYmDqxyK/vxzC02nU5
lREcZHQsL9U5Uo/dm37O8tsxoPOuzXzhPAUv16aNcYxGkdO8VzaX9C+mmL3w
5Tgm9m2x30pT74XJbpeSzl4Wtu/YpP1ZgQZLd78MIR4Ofh1VYQcr0qDfut9O
nHzXvnFDWGVZBzRmtW1XSREQ3HT14pr2NkQHy1s9XmBAy8n1xQvbVhyonR3W
FmOhPOkmPWppNbg2+wZdnSEgXG7WP36FgvURGzMcdJmYmzt17ZZbEVY3GG8q
IueHay37t2a1DzIouh67SP/ifcMXmZXQByF1SbkPBQxwuYfmOttHgL1LUF7g
EoHCtOxD3kc70cSfd6vzOxNyX0Qq/zQ+wW+ev1YuDgQoQwPpD4XzkHiy6G30
SZLna1wC9GQ/QOK16Mj1MRZWV+WfbRwbBHebuf3VwE+g0x/90kp6DpbS6g2q
qgTubjYMr/lVjvnX5k0uaqR+u3NSl/iXQUDdZ1l8GskjTSUY2zWB70I5rEj+
SCA363JREYJco6dfBRGYa/O92JffCc77W5/XkfNOqbQNvCD0Csk93F+PLWKh
917udMIsBTe9PP/pzbDwbRG3mdtsBQ5WUuflSL+7E+PaPLaVgs3W2Rs7VRho
vue8iZ1LhexV9SRhGTZ8Za73VjZ1wNyc93GuL+nnNWguTytCrC93gTnJj2Rh
F1eTOz1YO/Pw3tWyUWSnjAccWF0Gk7GkoINCBAyGX61T/9sHCVr18OrNbDjw
y1QYbGrGNXrCHuYxFuaL9rW6KfVAyZ3nM58SCyn7JX6HabRAMypF6TCZR4Zk
M4p1Wd2QilxibNcxCpmTNm1nrHtxR7HlmD85b0p3nSbEtNtgLO1W8JbsT+UW
h4U47x4ECrMnXf3pkJN5d8V/OgjG3lyrdpgT0DKovqFbdgsnu0LZVFOSB4m/
4wT86yG2ZWjlsnImFEKerZkxo8CZr9/SVZSB9dLOEkm1vdB4c8f0iOg4Sso1
WhfzdSLsQITD/R1sDAXPDK2JbcU+R66F0VsE9o5L7PQVGMROSzcRWd5J5P2x
WnNjzSDuf/IfydRiQDNB9RrP0VIEZJrumfvEhPHurfYJpm0wUUltU97LRviz
gPBU0v9Lo4uDR9aPQNsjXKbDtBXyGzUrXtDJ/DQhYVh0IQ1cqdTtKcZk//ME
QxiyFHj8jLi3SmwUgytEWOfLhlFXv1I9o4mN3cOSth7jNNSGaSh6reCA/j2+
e2/oM0w3SaTQST9f2eN7+qxGF3jiubmVyfmtEUlx+M87FHtbMrTyyPzUcy1j
6OVDGjy1aMNvyXwlZtdqJvWVhhnd+kiLOTZOysTxleTVYVfkPa6TZD4ismMm
NtpRUXato6wrmQ5frzrf4RdUGJe+7DrbMIKA2+X9zLgICCzJnMq/QkBBkPZg
zZ5eWPpWJF28xkQtZfYDX2UbgvWKDkoqsEhd6ppPbm9GdUV3gTjZr4D6V7+e
i5mDPutr9H9+FSpoOeutzsbnI4LfuT3IPLqlNM0htBv1au6PN2eMgrPvojXN
rQHJex5cdkxiYmvygqz0dwoqFoQ/uAyxsXn66nXnipc4UZF5usqWvN/GkJJt
eTS47bowaXd5BAuHCRUDwQwwvv7triZ5kFrTXOX5pgjqxpaWcy8JMD/uK3Ff
9hrWMV57OJ0EXhx1qhSMeImhFgfrT9UEmgknq/862/BXOaB05BmZV6WfZtjl
DSKXnjQR6MhE3nSAgeTDt5jdbTgp08yAA0UnlupeD5HhS9L5p9hwjrY75irX
gkLvJUXCa0i9933/0WA9gKMTlIJfyzhAuwtfYnUfwkorTs19HEM3l0uTO4eG
nPMykqnBI9g+4XJ1661+BOSln6Z6jCGgtPyq49JuDA2I29p/GoXG2AcdvrwW
7PpWEaFaOgou7TUHW8LeYrVTtbBqKIElolkan51qkB593OhVBRMOpS6PqE9b
wfNFzaV6A6lf8wNlxmn9CIld5/negvR/M83/1mZ0Q+5vj8PzKAaMBUa8PZ3e
w95z/6RAOgMUXw5PFl8BdglPZkioE6gplmkZv9oPabOWr4e20mE0xlkucb8F
yfJP5/4/H1pDNTuGUjPRpl5+/sBjgsx/WxIuP2iFk+BM0zLyPBJFykMyh1rg
k1u895IKgSChN8U6ed1wKB8eGSD5aCRkZZrs0YTL27Z1ZbmxcDK5Xc3Eh4Lk
w2eeNSWywB+jPh1+vR365S98LPQYqKHPPHy+ugBXpu9s3FdG8qKrnZHm0QyN
klClEQUyX1aqSsU/f4Oceum8JaSfFqJu8KhvAn7UCNc6upB8lPbPv7O9Gu0l
pyhTL5ngsg7Y1rShGrQ9E9kGRQTuT63dvPzvANRMeRWSZT7ArXt9jOlxCgak
Wg9qK4+h5evD4AXfj5ANXqYnN8KAWn7wYj+pHjjIDe+ebSTz0JWgRwrdndh/
PPfHOzU2TNZE95blUiAeEuL73zgB89nP2paePbChKtfvF2Ch1KXA82gPBQ1h
9Pcmd+lgZ19ka/2mwszYuK7sLDlPUarJfT4V0PrTLudN7leTvHczXjY1wKBQ
5JLVKhYKz51vaVDox/S2vwWFmnQkRXlJDQ82QGP+mumDJia+BHzpHBIm98mn
i/ZOZY4hUe8Ar7dMN6zqjsTE25H86PGcmBWloMavtecymT9tHqbFZh+jQbYs
OHtfFh2C+q0uF9Op8Dbh5uGv4MCzdP5xi+EbcN+uuB7aROCIZUVk/mA3tHok
Z9YIjoIvKFD9p9F7CN4VLNnDy0J2/ZJTSS8peGtge3Vej4mbpUuY+3yaoBIz
1bvInY0zIlZ+liFUlMpsMeft4UCuZqdh7a9kaE3Qb2uReqV88aM+30xDzLcr
fi9Pk/VP1HU/Gk6F5a3nDQwyD3Pb/Xim9HsQTuJeRMDYGKJyZCxFqilYG9pw
JLGFiUW1kdlGMwOQojMpEuJsLImd8ngrPgRP56Qq7ahJ7F/5XZJfsxodgxZt
q7YTKLFduelTUC1+TcZPRguykPr0ilKnSC1K/j3xaxsg/WfTtPbqtVTQG346
yhhxYGO79VScaANchS7sLtrCIudTLmC4zAfOdCuLlST/jgb9+8XzqwMmSy+o
+PkysPGVjquqax0WXzv0uvwtmefTjAMzk7qgU3PY6ZTLOATnXl9qmxgAO0bq
+A2TMfzub2i3t+nAHbsWNfMbDLAzRCYE+ChQ6khOPX2VrLfOSX8zTwoeJWwd
DXpH/v+9YkJMbxfUla8vnyDzd7GNAS1DvgEKs70BDzLZqP0pUNfMQ0M499eS
Q+T8an5lXeUKacdcwYbeHC4mLm1v7FjH/gB+XkZx8yQdOgX3VVn+VJTzm8/p
fSf14/HeecqrE3uDLIylt5P16fTl3FuSCNeSoDdUcr89e2bgS71cP/580G2K
N/sEdW1jnS7Tcmh6qPzNlSf5nbhff9StDveCllkYzTMRJ64V53ZqEOc+Rn6R
OED61WWhtfp5ZL8Of1BroZH3teEKcPk7hDm5VVORZF5x1c8Lev6zFsfypNM3
BpP7p1AKY9W3JjzLqVMZlGNC2Yd7yQHSD0tzQLHJZYKf83vXaeU3MLRV8XK+
QIAnml1H29SGIyGJ70YqGQhR+eGwldOA4K9+3I8OsRBXV2vWnpUOyrUU5Ql9
sj+ml4JvPH+Lx93Vf6MzCay3ms/ZU9CMy/rMf0tLCNzeUPBA/mA/7n2Us8wn
+SN21Oi156pOeHsJ9oiVjGLkeqJo13EasohhWhKpp436CU2da5sg7O3kSNNn
kudYZK2R04eIHy1/PgeNgzq3ej51Xxce7ptz7STr4Wwo1zzC/RyciIAhF3If
azWqyLtzpALEWMyNhCUENN2Pfzga3g66WZXlygUyX/IOWzTavsJ8unpmFZl3
nGULI75aVuMtrw7Hfze5Xw9ePzHi2I6xqjAO3zs6GMJa1bLR1SAMKTdiyXxL
AqXt9YsB3H403617mgEVdGUpTzejbt0qmTRxJpLCzlFdA7rQb3Lm11cv0p99
ylZLKjbhrmn3Tq0VLLiFxejuDmyCQZlQSp8cC4FWx5Z9Ls/CiwBrxXAnAr9b
DlU95muE7jnN5vZWAgzLJmv9+F5E6vSHtzxg4V+E39L04UE84rmWGt/LgJHk
H+tTwr1odn24Yft6FupHstU36/Zhut3zY+ZrJrJcM1YVvOmCnqUw+zC53/5u
sN/Qz+mC1O0a18VTBE7PdS23MezBB5NvLxNJ/tY/7HZccbMRvos1cdiaieHj
FY3yNU0IP3fieD2pr6kTrl+dA7ox/mNaRZd7DGLJ758abGuGCeH1MSSV3Ke/
nVpyiec9Av8clvpO6ktJ8EZHo1kR4i+eq4r9j+S1sMrSOblb6JVyrhQn82yj
Q1zczD0qVLN1m768GYP7yexk1dZslP85F3bDlcwrF6X7nd/ew/bZPc3FpD6d
ZsKiJ2Xb8aI7t2DjTQZcv3yJUFSth9lUzvUtN5lQvxj1LzC9BQ1RjVEPrVmI
PLj/veqiLhx/8nStRM4YnMM9dOctX+DtGzkf45vk/l6+2lL9Zx8cTrf2V63u
RZxWkHSMdw2I+6GrPmWQ+9lu25O2y3qhzVncp8Cm44joiqBaBgUSHi4HhNew
IJgURFuxvxXPpxgeJ8n6993TdHtJ68DUzoZaLXkGci+KOOs96YaK+6I4RTL/
Foomi4eHxqF7pHefF6m/XZvLjanZDXhwUfxeciwT2dNaPuf4BiF35rRPiScd
/wPtMgeZ
        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk4Vfkfx4nRtbT+ZJTsmWooioYib1tGUtm37NKvLialJi3WtEjDRBou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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk4lekbxyUj0+Yw2RpLVGNLiH5zrF+hMpXKkaKYymVky5aQGUJGlCQt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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8VWkYVpGrRtnrRoulJtuMTMsN9UhUJC1ESbKNdCOyRabImqVJSIut
jFskihkGLXNdcbnZ10vXMjpHwjQUKlLzzR/nd37v+c55v/d9nud9vqPq4n3o
5/liYmKp5Pr/Lip4xPESE+C8MNNt6AYF/0WbPQ458zA2eOW6qTcFcc/SuNyG
Ovw60SCaTKPAijI8oZ1XCgXVrvhVHhSaHUtiki93QoZRyVG0phG8yfCYKbMT
CInztTlG4/zn2/tmSl5h3KFbweUOjYTk3avuqTaBzV4x1032U+8/qr0vIBvs
v7Ql7ztRyFMOUPsy3YrYXF+VTzMUCl9xa/lm7Vg///uJf2gKTlmfio+41uDm
LsOQZRcoCOdpPevjV6JgtTT3qz+FdayWitGVPXAcbb1704nGzOxQ+e3IDojb
nJLduI6GljZTT59Vg3fh8Wvt4ynYDPGOt1zvQkbIbwOKHyk0wmgwQ9AClfn5
46PVFBgVSzK/i+JBczI+qiSAAveX3QWTjEswNhQ933mCxGyWetTDDKhuCH4+
ReLf7R7rbD7RBY3uJBl/ExoGMWGu9+L7MCkVuTC3iMaDsojEzRwRfrx2++Mv
eTSWrHH39eD0YGOemZATQ/A5Kt9iZlKLYznboy7GUYjUjV56ems11Auq3jpE
kv3uPToXNpQNJ0wOCgheHU4vjayO8uHeVO0RR/opm1SanHeOj8HCsOW8MAoj
GdYHq2xEyDu/L1j1No1Wy+36qUYd8Js+oCVuTuJ6dQOWcwuiTncm6ddRsAs+
o5Y/J0K01YkOZi0NRqanomN6CVbsUWLlE75VEvYr7Jxphq+U96w0h4KG2fzn
diYtkNP77WrcE1Lfet+RDaVNSGCYMxSKKDy1Y43Yrm4A26y4Xr6MQhgz6ZLL
RQE8t0VGuN+hEHdtQNZ8vRDxjSWHz4TS0Kuqc72hXAUthQil5QRv7wXrXJ/e
eQnLuA/FWxMojLmUebfI85AjmxuxjKwbSwf1ri1ohEZqm8r3WYQvj4K7jfaN
iDu5J7uf9FOfn8L0SeICAtsPrWcpGKVXLd94sRNZKf0Pi96Tfk75m765wce4
7ed/a65QqK6d1lo8rw2Ji7S2OnZTGDILPcKueIU3Co+546M0tIvkxtb01MH/
/scnVy5TuLzIITsx+QnGdENcl3pSeLbhyoc6bz6SYxJzkghfCTqLNbp2ccG8
v8Lhkw/ZP3wsY29yOYYsDYQZ5H2LInfGP7deQO3dkxsqoQTP8IHKMqVWmGU+
DFv4loJXwuDedt0qqIr6Nq26RCHoQ6Tg47MaHOCLfH1JfhYk6wvsepDW+NU+
3ZvGHd+RJim/FAydLVdKI3o0jj7pKdmXhVjb+zkBRC/CJK/3kQYNkFr7rdf/
KQU9Rs77BuEj5MjdNdb9mYLb2WUuex+3g+/jxw7/l8L2hu7Dl7cJEeRap19t
QPSs/GFsS0cXgo9yxjTW0jj3IMuDmd2CE/HvL/T/Rfwi2lKzRrcNq9XjNXU+
E75FF1veyTUidSNDTVBIQcbEOvggpwnU8fy2OaIPn592j6rKFiPJQ58nSfYX
+/JF72iBMx596/xzA6nfYuGAfrmUCD7BhjuWptHIbX5qPpzMI8/rd/b5kXyX
QobH5xdhf7bg179dKSzIdBLP6+qAj3Gk5zSThunpEJn9jjz87m+xbpT4w8Ch
3YrX95VjwtTcMO8UiS9p+7x6nQb79O33FhJ8PKxu9R5xL8dD1uKERrJuIhFx
T4nfgdwJuf0T3yjwVoVlWk82w7DTY8+fzynszbf1UmjiIcH41tKbJP+eM1dn
n3k/hxpTPuAC8U8xdurItb7foJEem/gvyT9gp9bA+KEKsYfsvGR8CX+lV0YM
PnJRnP5xVzLRZ1KtdX23TTuK58+EpxM8ty+u0F0w0Q2DkUWh0xk0Tt5dIpBR
7MYPES8C/zlEg7vU5e8rt0rR2v754cqTFKyEB68VBXRggRXjxVUehakpvYpC
zXqs/yte3PIehXcc+cGyxmaYThU7LiDz2H5cZ5ML/QLKsrEbS4i+REaMadfC
WqQtgdyqJDLPW11PV7WnotbM5tpTwke1vnq3KcWHgjRrlfNVCjpRkuGrD7Zg
XNTSJpFDweEU7O+78iAcC1wkfZ7w68vs7VzIgYnUzhXznCl8V9a/RfXnBsLb
UcZPxP8HLNvMl1ncRaTaTGMYwedOtIT9FroHiRHO5sv8aCRmVMSr93Mx+NJf
d98ZCuG/1v8eI90F/x6T19lvKAROTedG+BUj17Ey24zoR+ZgaKYwmPivl4Vr
2WEaMhLDeybuVsKm4GakA9HLGrdpJXHZdLizbF/Nkn4aWRvKf4yphrLETYmt
ZJ5TbhQnHFv3GJ/f2dh7u1HIDVo5xO5tQ6jMpDlDhcYfew1r5sarcUpFdlqT
4LUo39ZNcqAdsc9iZ5umKeywbGb+4ShExzBLr5tN/NOZPz3S/gS8cncdBqlf
OJopv6uuHha7stacukny358qrT8ZjLE9Z3wNSD1Bpq+HQw4HoNW5wIBF4uUp
Iq4nwZNl9E6HE0i+7xmOzz9bAaXAecx0wvfjNrG5vi3teBzB4wxI0DCJ/FHh
QlAnNut7alWvpOERo/nd4jM1uPxEs31pBAVlHzu/tyUtuOUX3MZ9TYEKvar/
wJqPpBHW4Czh+2LY8a/nlOoR7ivv/vU2hQO13eallkLEmX4ImdlOQ3KhwEr6
WgckRrLDjVpJveXHdT/3NCO57UShYgkFhVmpps3j3bAZLXz+xYuGmOdwYmit
A7b0xpj+P8+XdzJCnKxL8enY3Ntqcp6IeSvSrSoP8Ojv9dGRLmTe1jPresc7
kfjAcjx5Jw3ekKKWttMrPPiBTjhAzqPAbXaxgqxWmF/n7KisJf8f/FCNpm15
SEr7I4VH9DVgMtgjp1cLN+8dnZtSiZ7lVbPOsoUwdrc0e03mhe1VymOK9+D6
Q2UdKWca+moz47MCLjaunrkQSPShnlK6b8qwHwVHXlrpug1hUKXST/ATF2YT
Lt9A/Nthlh/0xu0Rwi8qRhcRvxGdW+Nbdf1PHKq/EG3BJufNrf4QrbmnWK6J
lxGE7/8ASLizFw==
        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8VW0XxlGEJI+IkJISpUGGqLikTMmQoYQkRZJHSKIkDUoZUhSKSGXo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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41Vkfl9GQFhQyYUK2bkiSJPrwtoxl7MQtWxMyKkuklEp6NaMQFSoq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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns41dka3kqREo6SRIakSWlcyyW9NChJ4zIjUy4pzaiY4riGULlNCEmF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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4lekXlctkpJMxjahBVPSbkFFyb2nIrQZJU8TQQYwTcolTjEujQk2O
GkpUxyXFz7VIxBAlt+E4B8c9o+8T5d4kSWbe/vie79nPu593r7XX3utVYQY4
eImKiIikkO/zf9hCzGHZLR09/67OmnejsNFe2m89VYmGbMVWTX8KPqe5/whl
mxG527wl5RqFQz0qnBmLFxC5amJ0Y9soGK+km2J0+jBNT2WY7KIRt64JxhvK
4fD/fLdX3hREb//4/bl0Id7b1YvLB9PI6M5lpWgN4ezJBaHndRost8Cj12z6
8TTjU1BMEI3Nk0nSjqcHUar9/EJTBY0+W8uKlqa7mNTfIsk/RmGrmOfydbsK
zBlNvO4l+BaahPtC9hUj5KhhYaonhc6QA4r3OQ0w1+N7+sRTGM7Tu2/3Awc/
u3THnCL81ORGvpIv6kWnoKV93IJGt+X3E6wBAdzGnrZFi9GQceUM/JXciBF9
qSqkULBq8Z9umOqFtqmn4pg7DY7Bvkenhkoxs6Z4tyPhdyuBVTrwtBfrr4xc
VrKjsVT3W86KI+W4K2Nyc/NxCnHKQbkTHqVYdTAp3YLk40G7+PQgD6JeDwLk
71OQsXILtZhl49+YN5uMCD6RoGtD9n0VuGzVoDL5C4UjrN8Mm/Uf43CfrNuQ
H4XCIxWFcbYd2GSYEltcTOHkw5ngnOResE+8NjO3p/FPxY2ewIe94N9W4H46
RsP0hmy4/80C2IpPeH9gUlirlW0+8KwRlyL1XDUuUNBfen5GrroEI2pePnqk
f7yc4YzDRY0IaVQpESSR+o0xmnaLPZBwojm7z9CwFzt66HZ0JXStjHRyWRSO
n1PYl8btw/6l/ewhWxpaV87qTC+1wjSJtRBL+EXnmK0pzM6GxjaneK47BUHx
0xZL/zZsZTXaiGdSMLB23Df58BGawtU9OL5ET9e/NmWPtUFGkmMW9ZzClLa/
9nrTOnAj9Yf2nqFgOsd5ZLQzH2OtaV7ahI8h095py5kGqNlaf5cVQaGSaUM9
ftKIyxKMeg8OydcULIZe4uPGhoAaMwGF9SW8vuoXFZDtzJ9nE/y+DhKxXRXd
iN02ftVzL43L13/t9b5UhrjJwGOviX6bTV4mPX5SjhOVRezLRA+RzddGTws9
kSYo265D9HKQ0qthM3kY8F8RsW6U1Hvv+kDM4hkkm5X85U9TWDJuK55T7sCF
dq2QY6kUZtbbyudmdmGF6tbClFU0jjRv1bWNagU/zTcpgpxrv9R522FchDMG
ymxrDwp/JAd4y/jUQuXQFwyFYApc/t0SWrkcT5x+fV3pQ8GdF56mtvIxJkLy
ao6T+VgI44gKPjRhgKG0pz+DzJ9RW2n7YiN+f2xSsvMPcq5074tm0UHYqNZ9
kr5PQ8Q0y285LgPO/QFlV4g+8hERyfEj+bByt/aOI/39sSb2lOUdPuKtZFVv
9VNYfrmtLl23A65hb6REHxC+LjNFsguVYNcFb3tH6tf3jww4W/HBXFiUud9B
oTaCvnNy4hY+Vqx4YEnuH3OxHnPzTIN06fKet6R/a/uFm9v6W3CNsTJw9T0K
bCtuw+zhOnRd9NVpCqBQJxMcJaJRD2ZRWOcUm8LEzQ8HaxV4qFj79YngZ6Re
qHWRilMHenViTDPqKXA666Yyz97F1dWHahKJX3hGPKdm5dqAu6ZzJ4h/DVud
rYq36sULrZKDP0TRGLZhXuVEFcDZ0rPyc7/fOaxUtdXpwnc37LVeS9CIFlF1
VtuRiXKbRwaXCP7hr6OZjrZZ6E7KUusk8WblzjznOz14asnycgyhIbfC3sdu
dzsU97/r/9RI9nuxRkwqOQNxVm9Ta0j+xg7NVcySLCgdW3dxgsQcCwORwO9a
8W27xOCOXKKvsWZ3z1fFGHE9ubiT4OGWJlT5mSRgQ0/HJXfSr07jgju71buw
5ZRpbVQVBduYuSM7DAWYDl+0/nuagn9rtdgPlh2Y2vNlsk8ThYRdfqwNb9tx
6tUE81kWwZvpH57pWIugWx6r1oVRkNRzUTfNKwc3kcu7TPbP2LBKbFrnOULV
y84ZXqTw59fbq6cNhNgrMe7n60Bj/98HewyFPXAY2Zh4PJrGo/iV76zmGzA6
/kLxTAzBI+G9/BNTiFAtOe0r6jS0g1LUrrRn4XikDruW8DU1/f662WACdlbP
KH7mY/q/MuVWFwFOHE2LNH9F4ZuhwHXzjAcQ4W01CiN+NHxT38jyrBBso70x
B81oNMatYSkm9GHpn8SPg140PKt6AtYkNIOxYHPqOfETmfFzrVUmQiTY3v5y
yZVG/sDat1LE7xfUowQtgTQkU3NmE+faMTu3py7rdwrj3IKAwjI++D3Fv+0Q
p2Hzl2aW8ctu6PqqaUhupOG+KV8xL7UXCTPCMG1jGr3vNI6FFvRBpspcti2A
BteVHz4x0YE7lVsOpH3eh8UDryzin0B66Ze5dNLfE9xhibrzQqywUDgSNknh
jfYLjQyvduxXZHxcrqSg+/Hhz4MJHcj+ueAau51C865FvazUesirFBU7n6NQ
Lpq2MSKZB+FovkcSmafYLzc4l8t2QKqSEaRO/Ebf94CHXMIzlLnPxeWeJ/vB
y9r+ZpQHR5autDmPgnhE8gWxPKL31eAdD4nfNQqL8g7L5KPvo3pnEtlv3mFh
Z2lBL1Y3lQ3Ju5H3gsdK81TNgdP71S0OZH9q3fb6ponXwUV3NHYt8dfMyqWV
zD/70CeIVlh7nAbDcTbUqbYWxksWiZnEH6OnF1UnprqR63Ja4sVuGsXVDn+P
GeVip0SD4g1ynwwjPepXl1bciorpLiF+l8/PFUQq1eOeHcNIgfilxpZyZrhB
P06b7AiPTCDvadB7KX7AfajPJx5+R+YhXVwl9cK3jahLLJqdJ36WnerGFbL6
MfFsZJ3HTzRc9rpVb2d3QeVO20/jRM9mflChH6k/pizvPEDqyyvbaDL66tEt
ZyZxPorgMR4/5LPcjrOf5L4xyiHxHwo/zl/ogvfCLzE7lWjs6mo4n5/fiyW+
pGB7Eo3ag/dsl6t5kOWL90QRPUU8WGK1j0NxsUp9Vp/Mczcjhe/2oQMOqlaT
21sp/AeGAblF
        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3cgVf8fxkWyJW1RRIMUSsh6KolCKFSkZGU2VFIhERUiu5CWMhIqe6+Q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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk4lekbPoVSZJemZUgYJCJLJjO3nVQGySGRGpXSZsaSNiQToiyHNjvV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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk8lekbxiUjiiSiMTWUpUiWrJnDpUgahBgUg8iSTmkdS4pKUk2iKaNC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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lWkfxk1JkhxMpULJlikjIkxjulRMTYtSSaQsqRxZjmmSrVJhCjNl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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VW8XxW9l+kmIRgqJiggpIVmRqUKGBiQklUipJFOSKA2kSSWZSaaQ
ecp4jXHdm3m+91yEEEpKes/71/nnnM9znr3XXvu7NtlfNju7lEKh2CyhUP7/
9Hja3yNr8wm3914vCf3ORMTU/APKsxyc8HxWbW1MwM3GY1N3Zy02ZPX7c+cM
YobqaWZ/uh3Chu4vbVsGEaE6HhXfRsfZfsUl/iZsBHyoU7FIb4FhS/Pm+aVD
8Mv7JynUcgexm6j2GWcJrLO8s8smOhdLmuJuJ8QQ0OBc9PlHz8b8nicVVF0C
Xc7zFOJAC+TmLA80HmPidfSNxKmCepyryo0S+DUIjdixvRMSxeAz3vg2dZHA
WrfHtvZunVCJ3b5ronUAPIoFetPUBpQugYO39SDMylOqTXu/YGqGGligx8Ip
9RJ+v9EWXHbynjS2JiBhuae65OpbGHa0jgudJJAv76pf9r4VYh7j/YcthiHR
XMb5r5gBjjRpreoWNgxCHkm0OnwAkf73Rfx5AgEr6xmq83kYFfxU+9yNgMoJ
KmWCiwFN00oZ7htsGA4+Tt6/lYq404U3ZpYTaDx/ZvnGzjJov3rlG/CXhXUf
Nrbsu9uBas6nW0U6h/DLm+2SksUAwXWM4tLCAl33oXvg72z4oz2rRoaA3I1c
2j6uclxdqeawrYOAIOPgdu8OGkRCdJz6/IbgIarfFateB9mKNL7jJ5g4Qn2w
LLs6GUyFkHRPLQLVPMV9w3+aMF4bKX3RkACxLva15HAbFtpPVUQ0fwXlh9lK
LX139OS6yXDbEni6uMbhWEMLvihHzhYdIvtp4nq96Yo7ynK2JeqfImBX4xoy
ui4GisTYQPwRsh5KPVOXn7TD/EGv5bL7LLjZ/jw4ZJyFrF8Fj84EElgaWBye
4VIH3Uze9VdqWQiQ7OyRGigHB2fzgpY4ASVjz5Hgt+3osJ+1G2N3IqKpxnDF
7RZEn0v0uHaQBYmLCkWieXUgXEUyRNayMLJi407piTocH3gUbvJmCJE7uF8x
fBig+jQcWV7Ri0XZHJFPSe0QvKfcv96MDVpX2ITyUBr8XHdcCFEnELbwUtPg
OB02+qr6H8DGZs8usUvX2/HTZ8/FjevZELx/jGW5WICOnU98DvESSNMMvxQz
WAY2f8KXYT4Crl5HOpV9oqFTX2hkf4JA+mC37OoXX7D14sUTr+VYCH26zM5q
Dx3c48dw8x2BJLXv1i58dGyekZDy3kKel1Rnr0yUYrbWXjFUgw2NP/0JJ/wy
UTObbxX1kQDlhd/l9eGNyFtX4N3jSKDwgu+LC50MiC1Q/IXNmeATuZhxf1UV
fu3Ye0Beh0Bohn5f1XgunpaZrkmIJeAQVhvlG5uKbTmjk877CURr18by+b6E
4sSWq2Wk/jPS3wpcj02HAC39k/VpAobmUXrmJZmofxZXbZRA6utz7c5rQTlI
3KldkChPwMXDPG83vROeh61EyzVHUXb4xipnjWZILpdZpnqLjQz3o2Y9x3Pg
KTmQ4mZGoHnlwcJi+RZIeB38I1THRuAZ26ELBUXY6KL2S8aLQFVOqGe+ZhuC
Vowq1n3rR7b3utb1nXWgDFEbnrwn0PH20PZzyyrhIPeoLNKBwP77KcXl5yJw
dFWebIg/gVUl9TbzVS3I/t11QfswExfdzA8H72jD97s/Eud0RzBoeC5RwbAL
Ps9X1ResHcS2S8q5me00nGqdWZoWTJ5/4kSUT2s+3knHaG8k50nR2Yk2XtAG
j6BSvuPW/fjryZJyutuC+k3tond9hyAaNfi4WpyBQlc1AdW8AdDWfNMbe5GM
MN2omBDSLz04OAZu3i5FfJ5Yr04PWU+GaG/Blh5YxVXP3WhmInfPYlsnow3C
R2wSbL1H0RS8tLtybwtufVuSuDZmGHbLlll4RjyFi82hW6uPEhg4c8cpVZgB
NZ3LfZ/J+u8X/8h1VecNuMo4NGSOEeC5Kf74YqE/ZO1DrH3sST2OftEpD06G
oFJtjb8dOW+WyilndjRCezFV6R6DjQ7p+7YTtaS+J9pO/lhLIFbO9MDkhi5w
qLF3eUcOoyri+Lvq+CaY3txlnRrDgmJrbHy4UyoumqkmUU3J+azJv6O1oRdu
ygq0rJQh0AYlms4HZ0NKXHqdzj8Whs8Y/jC72YJVGdXzOs5suK06OnJanoFn
+YwS5RdDkAs9mSDr8Qn3X3c9SA1jYcPVS3kmKnUYcg8r9H7EBv+Ii0RYaS8U
eSkTm3xJvd1ItjHaUgm+if0c0Xxs7HL0VDFSaISelvjpPbZsqBVmjlJUOvFB
gzr7R7ULFN4Z18DcZ2iMkL3mfIbs58xzCZHbDTCOXAhIUGIh8uufKN3qL6iY
DqgIEmXBi+oRFhhTjjVaow9/9DDxapT5VS+hEr+7eB7u12ah9vfvxaduZaAc
4ho/JMLC1IH8FYPfknEriOOYsyXZj/i7S498cIeQQNfhBRuyX/6PHRtMa1CY
p1p0LJpA8t3Z8T0GZTj3Mm3JtV4WKAev6ai5t2Hx09WS5ZWDpH8InL51PRkD
LrsXUyUJKF8WXGMo1Q5K7xeHsW1jkFfT6U/92oWtt7aHqGSMYoRqsut3azMi
HtUJ7EsioG1nnrxzvg3PKi15z1szwebN4vZ+34bqm2Nz+jtYcJIScp9IpeG/
QeoZhUA29o9ukeCh7oFzdxKXIunvazLfC3zSSMPe9fLFpzQJiFw6Wf9ucweS
Tg9wPiruh9B24/M/V1ARxDDw9/Jk4WL8gKtCdRH6573nPt4h92VmrMml6Trw
jDOLqI4svFxoYNg4NuNBvefGm9ksOMuPGdwqaYTDa4OIjwwmtqdkDXpsroCP
7dpzvC9YyF3KleVvXwU5Lae9DjvJfeJwlUkcSQdXAFyNLEg+sBCLm++ugO1p
9QfDZiysNFeSlZZshb7lkZq86SGoyt9ysTpfAxOu4MLPvkwI7G122L+vBRs5
Vzm/FGbjeKO3qKNSCyJW8HOpBrLgEUdvPLG6BkG7+E+MThPQ5FVesE4qwMCN
z/zKTgTCJTb0JplWoyeyX3jJSxYULAa5lDw7YU7zOTs5yoJxchSFU6gS0Vd5
dys6s/BIdUvejHk1Lhj9dV7RTvprh9ZrV71WCHlxHxK51Q2XZvkoJ6d2PI/b
Mnu0ik3qSLG+d+YKLMIL/Z+Q9bebXil85WAr1Me6qgL/svFLR8vn8doshMcs
C9Ai97PO3KUr70RzIZmp+DHjIwsJ+91MhOqooCTRe3bRSP35rLJvbWXAUGz9
l95oFmj2k+XZMVnIqA0yaiDrmXUj69+fyx2QSwnXfpzIhImr6MTp202w+W/J
g3YqC+dkA6VseBm4y3NAiqQOCOrq+awl0sA13sQzlcTCzy0sYYW+dvDX3BJb
dpMNX6OkOB+nLthHFmuPdQ9BWXdNueZ2BuxOlJfKkHzRVcu+sSajCyWFxjFy
mp2Ybg8ci6LQ8KVsrUr+WRaSjIYfcoGO+NIvuck2TKS6br5mrloHpwKVTWa3
WRjY+lpxSrwMaifkjNRInvy6PvKAQAkDZ2nfWEvJetmcOp/7va4VSrl3rAX/
kfobSX7cb9wE18Z3x5cuGcLbN9kHtgp9QfwdtcMR1BEENaivcNQsJH36qdZ9
8vuMuJVBn4WbseCZ0xk8w0LZu7GvvR2hEBuQz60g92uHkcazjT6tqN3ANaQb
NYyWqLNqPcHFsD4jTw3LIFBbqOSqKtCIKYaXq6cn2a9sHo8Mki92ftpWqHtn
CPtHUnrm5/KxbYmupGQCC1IeLtK7m7uRviPiHJHehwXO33+Cr3WBr/CK136+
QegJahnaZdYhq1lE2yefCaf+PQpbbjLQkFjh2+g4Aurl9HeW++ohrhLW+2QN
6bcL6mcN6dGQGpj1XGtF8oCQhJ7153Ksv6gaeZqTTe4DsTYX1zJIGYw2X8kn
YKKWKpMrEwvtoYH4OZJvUzceDv+aTAXTlH2kQ44N91U2Sgz+crTPmPG6kPWZ
dZz8mna+EAlajnYaIuT9WryL7a62gu0uf69piAkHKzZlD5UO5gXjjDO3mPhp
XyM7vq8bPQPdDkJBbMSkd5+Zc+5G5eSI6Wbzdhh8PuVXJEfD7EeaQN8kE7Rl
228cKPoM6TuTGrn9BEK0jKevP2tD/3bz66d2MNH2TVLl6xYauiYPjkgxWRj/
nCO5p4eOlSYvLF2MhpF1ycgroIaGRt6JB+q9bJRG7fngNkhHiY5M2741JH88
Kdmn/rcU0criTltCSD2r2721ci7Foqjk89aHbNQWh1ftYlNRL/RWuDCPhQjR
frdX3GR+eSD6/ePAEO59CDeJr69CgKuiHEcI6df7+kVTU5MRNLrJ9hXJ3wkl
VzLcXMowa2qnI1xA7pMiY/FzS1qwji4yIHaQgNDVoh2z5gwIbWWVBo8MQ8fq
/hsN3Srwtj4skyP1ZRN7WirEuA1jx/bUrecaRvQH/s0b5yugH7Dj/uIC6U/M
Q61vVsYjkG90OmgvyRN8QUPjI/Xg539+9Ls8G1I+8/bquRUoFTc62/WEwIhT
n7ng189krlBcJX2Ujcj1XSJ6XdU4Ue68/L4bmT9+n6icMe3E8fHU+8L7WZD8
z+KH1mQ5xr2kvw18IPCg6rpuQB8dknnKPSXuLGSJnKRzzzfD2LdH7iIPE4rT
+QcDm+mI0PjloSExiCmVNSbMzI8YONh6RvEQWU/9hsQHGdkQ5BGMn1Ai8OpN
JTWFJxHyG2g/YsIJSEkL02emSR7/+a9o808CvxaLHIf39sJX/GFHD5lvbv9m
1Z5+0oDdm+KXN9xh4m6RmOAqw2aMvvcNMVMYAkU2NTvD6wDCoovVt5L6NEv4
t9hh1YYltqGFvu/J/Gn+WMnKsQ0b+s86e10ZJvvNpdL2pBxynYYKGQ0kH/ln
+m2YycfxyA3iA6EEIiadlEqVaLBICz2zxYn8f/VLQb6hudg1l/LEppXAsJKv
/d9TrfC54PNfsSEbzxs33V+fl4mJ+QWJ2U0EHmUTvl2ns8B45vPBXpjUl9OZ
V7k3avDjX9nx7zQWhD446uYnVkGnokaJco7AeBCHb/PcZ0ilf/P6OdsPDzVj
e8+jn1Hjuvbyyu8syO3evNRfsx0W7yzvfdcZRaJwkyefJemXdfyUbg4mVG+m
vbBrT0Hu0SODd8wJGAR6dwcKl+PGo5f0dxwscCvGzV4pp6HUIqqJx4qFsNW8
V9MmGEhmf3KRMWbh+TsNxswlGlaZxMYSJF+MHl2mus2+A4o3K/vMx9mwERQ9
XPxfJYpVl3ArTLKR9KHZovZtCeJP6Xz7K0bqNewP/yizEpZbb72JG2fB0cNF
0MCkHK5NsasO/seGReKbKXH1HES0aywcJ/PdlrHzarIC6RBpDsm7QOb52gnN
S/IDdDytM7eXe8CGtKQnxzL3RmSbv9Pdm0CeP/kszq6nFZcDblqQZg5VWwVl
opCK2cST2trHyHl2OmtkMhePMoc4PT2SZ7kf2gYHO3zB96mu4BpuJvz0crTD
4zPwjT1VYUnuH36Z+3qHx8rh4/V+NiOSDfquRp6zgt0Y85oTe3iaCakOcQGr
gHrcynAstJlmIuKjVWr0zgyUKScrLhwm0PnQaEwysBW5GuVpc9xkPreQLzBt
yIFH1NMmQXLef8fq9h79UQGLaCHrBRp5/2//ZN769OLpchdbkRdtCKz+1+cs
8gXSOeob9Nf1o0XG3nc5sw+UOEWT0APfIGMwsefu4XpMmhVGDi4h4BfEz/eN
EgCdFQ8p7aQ/FwZm/yxgMxB1tKn4YuwwvMp3Viz99wVBCluTH3mzIUnL17oX
0oBF4QXuTkE2HBsub64V7Qb9VLuKyVM2Vu22a93AQUd442DPkuwhnErdxhtY
SUfWt1BX3ktDiL/54k/cXjo0Jd1rPxIsVD2K0fqtQ0fgdUcthX0s8PuvSPDQ
agAynx8bI/eHwUUF7oKALHBSY0IMuAlsXLPmkRz5fpoC68/kchZid52yl+Jq
g5veXLDM+UG4ma5O4aB9wNWTHIcMyPn3+vaE00eQhupyKbELjiR/OFCztmu0
objvltCeFUyM/N27fE93CVJmKm997CT94SX3jfiTXeivKv8o+f0rSlOKvWW/
tOK/h7r0jNUs+HK9TjR9WwHj/quGwmSefjk0nTzr1QVp3+Jd0m0jyJ/73bQ9
vBgaJ7MzrpL5csSKCOsUbUXd9kTOz/qknvfxUDSkWrAs331FJ8l3xkV534Os
G0GXaDqnbcrE797jtrrSXXj6WESzuHoU49xZmd1pDRCdF3wWT/pdyKHvYmaf
c8BQjRrX+cHC4wF6euSOLwj3LWiQLh7Gwrk7lj4/4jC8KBiz/zp5/gYH5rFP
7ehI4S+KCBqCJEV2w9q4TNz9U6hhn0nyn672euecBvR4a6+bV2WD97krQ8mx
CxpTPm3BAkMIjT4/etYkGiZ+BvcNjpP+Qxh8GND/hMUuc6F6kv/vLvUkHgt0
gl9l3bafAiQP6k13WB7owOmXKl+X1/VDTllf8vbqcsw/2S30Q5xAaC/NO3Rb
Osq2L3peCCPge92EI2EzA37Dflp7NVjQXp3Imfy3GWECC5yXrdgIGsqJ4kgq
h1+vrQVdlvzeTFA5TCUOzy1/KReRedDHoyLl2kQN9rutfh2/mY28esmEu5er
cffkUW35LSycmk7aMf8wH+pd9T3jb0n+enllc191K3JeRTyQGeuA85XdUhe2
1iLRUv76lY9MFNE+5nLtaMaP4qB1l0g+pC9arqAweqExH6jHqdwJ/7V6aa9u
tqPhj8UJxwAmKBLZ+nrH28G9aJG+iZwfGssjVfVCHPQ5HfyNL5HzNa5oT23P
R9i5rQ5P/Akc1H0/ak0nebBd8oFCNBual/XyClMYMF3uObU1YhB2S9t28lh0
4tLcTlNOUo+P7klwlHRSsfS/RIcG0k+N+dJXeJfQsV5zd9bZnUPIcNP+fW88
A+43XvqruRGgvvH925fcjZe8Yq+4xIcQ4P5srsu1Gfff8tH6yHw0lXFVx3B/
Dy7cVTw6n9UHv7lrdYPH/JBN+FQR5H6jXDAtnqe/wtECo8tWOqQf7FtTdSyy
DV2am4/kPxmG3duR3MPnX6L0U95UFpk3/TIUAh+2toI5HZkk8GIQ66b+7NpH
LyLz+NjJnUUE/ge3xvca
        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8ltkbxm0VZRtGSkiWMtKUGUQmlyjZs0QqlYSSYhRGKiRLGhoJIdmy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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4lekbPjioCGPSNKiYQkhEIS23mEEYRD9Zs8SEENNUkrKXyhpiFJWI
qAjZO/atLMepcDiHc3zfqFSIUmTy++aP93qv94/3ep7nfu5F0fOErbcgjUa7
Tp3/bk6ie7bWDBvhVrJycbf4WCscZevGuwEfF+l5HCURZPwXPbyoG3fdO2Qy
Gwm0ltX7Pf3UD0PZ49X/PCSw7WzG7zmlLRiIMz6JCyRoent/KR0pwrbvwuFj
viRySuMuPDjDhPyn2eqRHwgc6ndfEo1sh9uPciePZhCgmYk6ZWVn4VDWp6rP
biS+tnZsy6lqwb31QhbZgwTSlJqku6l6kj2G3C9vxtExOXD2d6VamM6dKkrx
IhHBD/U/9z4GHW3Mv6+7kniTfZ89ZsuAe7Ovu0kqie74/Met/UOYejXFjczm
wdhCJ0V3CwtxdNt9Y98IVGwKN3gdVo4NIhZ7DPdT/yOvnHHQ6YUPR3hB8R2B
zKTNXI2ROvhUXtYMO0Bia8dH44gz7Vhxr6RYpJmAT7VLCv1QFeSiz0a/nCdQ
0t/qNPSZheF1ds2SyXxIRVyK/mVLIY7OyRU2HyLBsHQy0NJmwf/mmJj7ynHY
HPj1WOxcLkIEy7e72JIosP9xIuEgE4Zaiytd6SQqSF1bVXoFtBPUVIztSBRd
8pj6fX8jBjqDzfl+JFo1ArNriSfIXV02mbiexJCUpFqfPgOMlvM6wQYkZH1K
l2dlmHB4yDEQ4hHQP+luOsOsxHWXB79a6pDQ+jbopnH2Hr7avbuwx4yEkJbo
dEBKHRL9xnq9L5Eo7LqaYOHRgN6PdYG7d5NITi/IKjNgwUaskB3XMg4DLRW6
dV4siro7psUp/Oe/TEVVbeKC/+tSqtMtLrY/lWD8u9iN0mNuhfdWkRh18zDO
7mmG2Y5zRY7UPLlRc5P7op8hVkOh8C2N6j9Den3OdAuCzPi0pbsEDuis+845
x4RZZEPflCKBwIK1a/gLLCizBYPvfeWjsTFR/G5SLqJ0ehSsPan+aDwH208t
EF9tnHFygUBIruULOZt27EqvM72sQOG5vlvC9igTFh7B72ryxsGj5YT4tZSg
/bI2Z9aJxLqPR2489a1ByLxqM2sliV3XPHmFcyz8qdue2vyYhN92httXxjPc
dShg0HcTCBI1FqGXVUGdme0+YUOix2RlsuMpFvTOeBodUydhUqtWxjgziDHv
Ny25GXzQvW5smj3WhEWpuLrKGQKGL631l9OaIZ+SmuOrTyLMelmF/WMbxiL3
C3heJeHCiKlSUnwFnei/cgr3j2Nm5L3X+XPX0co9nV9wmMSIkaPq/WIu/BiX
5lz9+FAhr1QTzo2YV+uS0Z0jEOb/c4dRZBPU0thTByk8hq3kb0/LjUFhwnPP
Zz0+gu7ynSKau2D4ULF5axKB+oH+902iaRA77O2i5EKCx95Wlvv6OgxM9F8E
OJJY88/XLu1KNhw2JPW/E+aBlmffxVibjvANOdE0Cj8XqSrl764chMrZCIya
jyJEysRqy9sOND+mybwiCSRHSEYKcFjYapSl2bOFDx5zZ2ee8UvMRoX9PRkz
jlLjunL3gC5E2bHOaYZS/pATrWIfF4QsTSefa0dIXPBtHYRDG2T+mEkrKSNh
5GXEm3cZgbqJn74hjY83EcuK8h4vkNvN0Q79b792gbdusKtw4dUHGT89EvG5
R8v9+56jQcLSoPHUOG4P7r2guuc+Ahrt7zCNSXC0Msq3jtxDsH9cyskgiv8B
kp4BMs/w5o82b98UAlf6A8SCaM3Ql3kv9A/lDwtxIl9vxg8hM+tQdnwDpa/j
qMyj/Mc/zQOSP1P+1CVc3OTuC6ewNWseUP3vO7B5cdmMiwXJCWfLah4kpCS6
Z12fw/mDlVKMEQnpqYpne78Nw7NLTOV1zCgGQgQvOT58hHxf54wYil+lnRrW
nIPlmEy5qiNO4R2n98QnVHIEbZYX1woKcdB5duf5lESKL5O7S6ap/d4or1Fo
oPA2SExwNP9IzeNRke5ZPoycAyaqvDwCnccuLpS8G8F8vYC45jwPzDc2wRdN
3ZF+Im9amfLjI8Er/FvmipE4NrHP3p7E2K3ev7mGQzjRSFqEq/MxuazvnebO
xHcjcG4ZktgRf3eD/Z0WRIrP/rD8moBgE51XKsXFkGQm969TPNAf2Qhbs9go
0os4UiHKw0y58LaAwAcoUo9wkKf0a1hn/XhVdSkU9rxNPf4bxTehmI0/2TMR
/n1hyZHSw+1JzbB/LWugfO1glvJmEubH7zu/KiiCW2qng443iYAAWbMz7kN4
1kdzndjIx8y5K/VH1jVgq2bgqEkCiZ9XtbjovGRAtFjpfbUwCTexfa5SW7vQ
uKqSDKD8vfGKVe3pTjZsRwXoOU1j2BUvMNW7iYky7s1R0V0E1MYH5+/sZsLm
h9ham9FxDIGVSL/6ArOVCfld0gRcLk+v6vupFd6SMcmDnwkok1JJmTUD2JK1
PskqnY/MbgXu5agabGYlrhGg9t161mNlcgYTA+xuU/SPw0VP1WZHVxNMBoty
JQ6SWNrpHNqj8hwx0peeypoTuP1EUV2u7xYy2n3sUhxIONzOH0r+1g5sX71Y
T+XRl/jh95tc+zF104y7O4EPrfxBQuyXFgS2BzAq2AQ4sgkWGktciNvGhaqP
DiPigdD/WncmQoPmudnemYTCnZjt2rZMWD5d+YFtTEBE/9HoW8E2dF9dHOmm
6i3uaJtN+sIEfd2KkIM148iMnEkv3f8EDZkCGVwqbzrrWty+qObi8/lKZQkq
D7wHF5K3m77C8zVMiedtlN4M0g6XyFH52iQrerqWAEv/hL1A9EvEbm4ovMgl
cC22wKZP6SXE7byMC2hUPh5VWfY7XAzeC3NxdSsSM+4r1knnPIfulT11urmU
37TI7+Wm9eOtlISuYTwJ+b7+fKF6Fpi2QQJ3RAjE/mG+5FDPhX7qikcTFH4z
zLQM7U+jsPyy8XZx7zCSYyZCfWqfgIZy3kYKb7XJCpFkpxGE+rr0Sn0cR2OE
V+SkwGlEETvbTCg9fNi25LV27wusJvvCm0oJKPwmTu/sSceWhilOPTUvTfaa
qblDHP4cZrSKUu//A/EQskU=
        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs81NkfxmdH0U4uuyjR1S01UULSzZNWU7upaHRhSxEqKipdrEuy0qiI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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8lG8bxZGkkpKlkqRItjapZDtEsqdFVEKytwmpkDKVIkLZQhSyhlGS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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8VfkfxlVEESZCqEhkuIwlk5bxqAYR0bUloyxlqcZS1nZrUgnZUnKn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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk4lekfxvGToWVooTIlTYliEI2QutE0Q9lmrCkxEiWNFH4VkzoJCTGy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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs8lVkbPQjxUUppapSUJEoi97Tciowaim9qktukC+UampoKuSRU0qdD
biMio3Evcr8ccj84x33MMbPfSMSUUlG+PX+8v/17f8+z936etZ61tqKr12E3
YRaLFU+/f9eaEp+kgG1cmK4Ln81vJmiw2cQ95N4O53N5q+fSCWoCXG2tOFz4
i239xaORQJBl+zbpWDN4TMh2/9sEMZd9mf0xfEwsVDu0ajGQH8uT4LzqRmHF
TnXBPzT/69eUhzl96Bk51cu3YnCjYvGZw/lahBTJPje+QMBrMWoJ6qyDhGrF
mNUvBCo53k0rLz+D0p6SDfKnCS68O7IrzLERXMGK4fOhBJLNVk6f1HphvXj5
URiLgSkTzP2gVgy78OtlC6cIZhSt/RLD05BybULovDNB34+WUZt2N6NrVGKh
MpygaFrJ1D55GObs8GHNTAZJfxe2Tf7wFAKpBnXrswTpGlsSpja0gfWlwreM
TfsfU906YXEPLPm7x2OcCLL+emXk/L4HPjsqNX1lGXQ0+XvqJvbCtPw69Jcx
cK8zKVtuwIGNgrtG8E2Co3H5H3bpl+HMHtOuWHp+7huRkx597QjK9bcdLaV4
/xgb5pPXAbLn82FuLkGATrmD2KYeOOpHBjRx6f2T0mvn42Ih9n1b9r/3b1RP
HQhvSIfqWv2xMNrfJs0NLzLKGxAgsz/h+TUCtph9tVVGA0Zef0odiCBIE3m8
X6okDpdsKgaT6P4avusNQWIDdD1WXyXBBEE5O7pCc7Ih+KNyW7kLgfeFbVfP
PB3EJlmliSIXBtG5SnfurymG5n2JFUFuBPEmkaHr/+Jjo+47TsY7guypxbk2
VgcMV90p5T8n+KbghCDLoQwLN7bI/+lO8GUo6uyn+kGkewzmi8cwOBl+LVYs
uhi/LnvJk6T8ku8u6xz+pxWN0ePhKRQvuZXiWm4JvdBQUSkdFWXg4Nr6cESq
C7yraWrreTT/g2jwyGgTDofXqCnGENh1sf2z1vTCeJvM4aIjNF8xcuFbmSFs
XP1787gpg6VG42HLDXkgEy09cxMEL21svW/db8TWjcuXZ4YQ6Gt8fdan147B
+nXlvxVT/H7leK9V7keLZOTsjBcD65Bkb79zT3Hx7d+XVp0hsJx6cGDwXCk8
Ld2DTDwIlD8cK2kCH+b1q4I5lK/w00ozSzbzISsZVL9UhIHM8soGwd4XWCYx
9unPBAJ100COr2EN1rwbFFzyoXibb2Z/nh1Eu9CEmo8BA7Je6nfNWS42iUhl
854S2Bje/PaMXBcWJhe+0Ukk2OzF9viZW48gtl+4ShDBWeU5g+7XfGwnVsL2
GrTfg2YnK0LLMNfewtKm9c50HtlbJNuN2YdBounVdP74Ve88ujshm3HTLrWE
YGnVjN3Q/n4o7g4W95RicMgxute3vQe+h0L1tITpPKfaFo409eD11Kpcvxk6
L/Ky5mZ+fYgJbX22Q5XBm75QtpkcD99zq3p3rKL1LzNdefRJDz6oNPikThO8
GBxMLmPXorB6bfGYF8FeHRchbbF+BHoGxUhsp/qr03VRPDSEUxxp+zZbBoKS
Sfcnu+JxJcKtOYfOaxDbrePQ4ygEj0w2uNH/3FOOx6qa25E8ILEzoYog+uui
+r2+YOxTE5kwp/E9pjYrXS/ysPdE3M86/2HAsq6875oZgLvpR5v1aDwzvveJ
b3kPFKfZmyN6CVJVVor0l3Ag66XVX36V6kt15KRhUys0u5QWxu8T3Pz48Xfi
z4Xcy9fpByoofwNKLgGP+bB+teaEggyDfu3dFoNSxfDMuFQ+T/1n9/rE5fZG
NXgRU7sy2I+goikydP9kNzydIoZIB8Flo/LGq2o9OK+t/rZgiODeLxFSydKZ
2LfodFqc6q/gntmz6e5+WOl5bHyqycByj2PCGv4wQk8EFB0tYqBw2jfh9r4G
XPS0avG5Ts9XrP+cV1eHR+vfXw38mfL9yFGI3TCCJ1N3d493Msj3+q7ulkkr
RKvt1UPSCBo/ZsQfNOGh+LbfDyVLGRi3f0ldl3Ydxsl73x6g+OiU+yoO9/Hh
Vr+v+yn17zaer5eJXx34dSM24QGUD+b4H456BZA3DLs4/hNBrLyQkWQRF7pp
f2uLNBFMXje7kzZO8Y850D3xhcDIIi1L1qELb92mBu5Qf0t6qeXUaNiPP6T1
u7+n+tq+MfaAnDsHS4TmYqWpP7OvRN29XlqKpsBKgy3UP96lp7hkmySBda40
Qpr6XdMOjeOBIV1IyU5+f7yf9rNVfCC0Oh6WF62Sq2j93ldiTYT0edCwHXM5
+Cd9fzaPXT7bxoZjl3FgN41XvY8ICHJtgf4pS7edyQT5o4FGSSvKsTnJV1vp
PM1/mO2ZLFEGq5uPmk3OUX8pvxe37vYABAa7ohQdGDh/tpgalerAfw2Ns/Vr
aDxPukO4sAR9OdVzhpT/NtOTz5M6+SC6XeUdGxh4y8zvb51pQo2LqEUO9Tdu
NNcrV7gTdgrCiYZ0v/Mb+9CI7CK4xDnXLaH7s/zlvzYWc+DYrflm+xUC+U+1
25SHqnBMZYXFlC/1g0OTqRuUqpETd8K8kNaXfzqt1MOBA7szMzvn6PsoI1a3
5tGTxxjwcupd4kr1MdoYO3avHS8XbZ1PpNB5OSi3PXmoBj3Cbemv/AnOaKX8
z33kGQpu6aiyKN7cY+npi59T0KjhMg+Kt3XmJ820/Fqo6JH0AXp/5PCWo8bT
bXCVXFKlTv3M5jcJtRsPWnF/9ssK5ziC1R/zA24cq8Dn/jvf1FA8dd0U5m4f
6MPh0sLGa6eo3ksPGoia1SE+70LpczpPLP9Lqk46ifjxRWtPI+Vn6RtlTtyL
YiyJVnqsTt+HWw9Cjrab9SOOFZFvIc3gpZ5Bgd1PfUgRdI18+IHBObeHPgXp
fdDjvq0ctmMQlN9WmyleizwPNWdJ2p9+88BgGI+P+mHtBFuqp9gjYQ7zKcnw
Fo+OWE/7s9yrrKJf0YqAaXPlDOqvrDTv7JO1g1hx3EmOr81Ab61gt1JnJbp1
lylneRIsnPYbiBJtxKxC8az0HQKF5sj5qIc8zE13mzPzBGbKdrsktfjYkhlv
UUsI/g94r8bZ
        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lG0bxidaiPpQihY7IUlRaHGqUOQtpJRkKYSsIVtJKKIsJcneniUh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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs4lHkfxtVah0JCqk2WyLZaYmsd2uUebTlFJLJyyGlFXGUdSgjVrkQr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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs4VPkfx0lJDNpqkdtSQjfVFol4C8lSRMhtN5F2VWSrrbBb1rplZYmi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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lXkfxo+aspQY0shWo2yNka3tpXOHslUyTUQhGlvRgmG0CWkYGinR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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8FW8bxkVJi/JLKJUoSVIUIalLhUpIKoQsWSIKZSslSSFUttImKUuS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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81dkbtiVZRxRNiUxZsmYJbU/ZRmmZkS5jj5KJkjKWUIRqUvZCliRb
UWmUbBkhbqJcrn277vfci6ikJio+/b6/P87n/HXec57nfZ7nPes8/e2OCgkI
CNyg1/93ZlU6eVbVDcfPBdt0RfmQif3gevZMN+IUNk7d3zoGDUlT3mqNAdxk
19hmd3LxT+7TUwVqLLxzeGBVZEPQF84JMFErQW30QoO9B0HpnCNVbd0MiwPe
68IkKUi2Rps0GrKQmG/n4DdF4QDXazYuhAWzd60Fpb9yYS9Z9fVTWDcqrdjp
ndrjUM1J8FiV2ILWc+fL9llQ2GabGt9j0Y761tn+peEE9r/tLf862oym47G2
7lcJws1wLSpuBEcV9+cPDY7g7Wxz4bMnLXC5cKOFMiAY2TijvoHZjupAldvl
FyksTGpn3Bxog6A4x1g4gmD6eGTEldE8TCUkTZYcpetlWNynMjvRKsbRejVB
EP8lmhF5jwkl5cYeVgoFAdWvMSm3iyDvYOsdcIgg0IA1fcuOhSOe80ImEgQF
L6ITP8a1YSjpY+0XE4IazWI9LaN2hPb0ucR+o1BqsFCXZl2Pt1rfvf7yIeBY
yR7YrNcMFYUw9cJQgkjBwIQfa7IwwFUNeOpFYP5py/D1mQrMqCsrbFcmUNmp
q1vY3QbqzxsSmht52LTO796y0nK0naEKlu2k8fLtOYLiffgcedm2/HcKHisS
wuS3PsKS29cVPHQIxuz0fnAUOrFs8cpwRw2F+Ughm94OJmaWvH0qFUPweAX1
OFG3BRrku1HRcYJuQZxy0xzAUf3YGbWwUVzelfxd2KMdK9v2lhTvI9jQsSqv
tLAXF9jrdcuyCBLnm9vlvjMx5KmmphpLoT5aITONVQqhRDHL2GME9e/f7JQL
aETX0dDh0JUEuSZ275Zuz4TkRe2CQU8CgyRj62HXfoisY3ySq+Vi724fweym
F2DGnBhYNONB1NIwOsarDXt3lm2nOriITDN0vXTuGrhLL24ZcSOoLfEWyP+t
A52LolzZCBp/ZKSp0opqnOtgf3XVJYjeF3nf9x0baXydZVvcKTSJhK72ahqE
eLvHWCyLg5DQi7J1Mu3YHxz1emEPQVtGTILMH00o+qxtZV1IIXdOtDzx3xp0
zz78xySAxiO19vtgWTJGOrrik2j918owy69GNWLzbn65K91v33PSFTk+Q7hX
re8WITsC/cak//btYqLtkNuglgUPnJBIeafpfChuVtqfepDg7Ei+vFpGFwzU
5XSUu7g4eWG2QXVNJ8hK6WSv8/T9h8pSNo70IXWNfaBIJEEe9z/jjxq94H9L
Vj0hzYPAknlXc+cM3DyoFnDPmeCnfMvwfc4FWM8wcmim32fgzJ+4adUPe+/R
FHtZHizjAhoPLr6Gxkn3lTGJBBP+D48/WvkMLi2iEu5/EOz1D7Uc1HqCZfz4
5vs0Xrt+802Rjk3owJ9ZJvF0v9PVxSuNu9FLhItUgihwJhlD0eFsLLQo8hRS
eZC9rZRUo8LEpLq5oAPtj7J/6kxzY/6FTZZVrpcdQfXZTM8x/ecQ/6Da8kaI
4PIx1pS24ys0zaVw5MVoP+qlTm3Qfo1vv6oYiVhR0M7VuXXrwBAElnFaKipH
UfzL0BHGhhaky88r2rEpxIouHpHgDIBFmBW7Z8YQeNJ4R8RMNXjGH7++VKf9
vOlTVfObQYRUXe24ZErQMqd/1exhPywWdj+Tah2DhMWGOzbFbPxtNTXG9x3D
9A4poYSoJjg1aE7PGRLkWzNWiZk34G32cHZENH0+x2E2x78fcWIHDs3PcVC6
TlKuXI+FIIFxrxi6/y4RjLhaqgwVL07NaG4hWMd4L2bAfQXrzx38O4MEa7qr
BF+XdGHqfZ9qgCUPZao94/2W7Rgof5sXG0Lzu3Qq1Y37AquveI037SdgGi3x
2Cicj8+mRsEyNH+mgnXdMn83QNXfaURhK0HlKHv28C02rHtZ+qnXKQykPc+w
lX6B2p/V2iIoCu2NzjklC11glKo2PCUU/s4aee0T1YsYxmKlQy4XAofXZ07+
NYTwR7dPtFfwUaliOeMpW41KKeb97XQ+7Vziza458QD8oTa5Oy60XqT1MoJI
EUbUpJzzbOn3Pj8jsNW3AsLXUuZ/9yZIjXJUNspuw+lXL6P2LxBIei+GiNU1
4dGkic4QrSdOe9mE8sGHMF0/ZiRkQeC2i6u3VWMIX0OS1/5J5/+pOjNpefd+
JDhv/6U9jAPmnQ/xV2sb4L+8IiMhmECmaHnKy9FevBN13vXEicK0+buQaoMG
ONr3mnemE5DlclL/PmnFYcPlOSr6BAIZP7RX1yXjj82MPVl0XojZvrR/r3QX
9zJfBP9K8zsxNtvlH/QMIntG/DJo/Z86kTistLkK93m+mqdkCOpMapKWy3Uj
2yZP7/A2AvFLPR6XiphYvyolEGsIPPSU7bq8e+B0PURkNV2/Ut+u23dJG7yr
W5/Ob+VBnLo6Km3bB42gVv+TNXw0GH9o21LbheRsvBTfwYVGmkJf06MANMmN
J512p+dTZYdFz44BWDd+Ezah9WoX9pxfoj2Ip9fM4lecpfNr/JiEe0I17MoV
dBczaP4r/Obb7dpxxGzwVfACBX7dF4sjF1n4Ehcst16QQuqzVeo7Gf34So2q
SYxTqGU86HE/3QeftUVBEloE6SUO9SWbWnFEw/NxtxsFzyDrKUWl59CRKjnx
mUHzpRQ/JL3qCbYVxiiYKNL8/GLp4rQpD7NOHj/fcSVQ7BGf6PJ7DCFWVkJq
AsFCT/N+qbutuMJezJ98Ref9mR8VvAdvYDpdfPe0L4HD8OmUtmw2HqkLGVwf
5ULhraFnh9drSL8J+U9LhkJfRZihAtUJ/h65NTb0f8Jju4xR8U9sdOpPXAly
46HWZSHQJ5MFZpxM/WXan5EzRbO/DZZg00uu31QaPc+4HEmpvEYIG4Ufy02n
EJmbUx0hUorVRerzSn4EjqMrSufvtqAq20p4zoeC5YcRoey1TeAqz2bb0H6p
P2PZHVx4B9d+FD82pPOT81BOPCzvFuqq9wj103hTH2TxOg1G4Mk6f54hTCFI
5wZbQ7MLNgF/2W35QeF/qEq5zw==
        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns4lVkbxgk1OzVE0ZitJKecRk5JuEvqk8NEDokyMojoIMLXJyGTplHK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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8ldkfx2+2JMskcimNVDRKi6SSfIwkjcbWaiYSLRKplLSpCGnIFS4q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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmGk4lP8bxS2VUqTQpiyplIiElHIkSUJCiyWVpZBUSkmRyJJs2WVJKUsh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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk4lWkbl2RphCLSRJLkRJwUYcrPKFFRkoykj4REskSylCXJJyEHqSgJ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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk4lekfxm3TNM0hSwuhDinKxLEUabn9yhAZ26WsP4xBkSV1BknGNqdI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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lWkU1m3FEDGKibKNNJGEIvWoqdDCVMpUQpKKEGOPmBhqkrF3G7Jl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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VO8fxadCUqKVJEtJCS0SkjpIWggtsiSEbMnXGpKyVFS2iqhU9gpl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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs8VFscxScKPTxLD0mTUkpcJVJNLRVClEJKmG6EuL3ETVKJXlQSCYWU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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41ekbxhExWVIo2yRblKksWVLciMmeoihTYVJCKEKIRpoUbQijBU0L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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns8VPkbpmLstqXtilapVitdtCWpxcOG0IVc2t0fiRqxYSoVuVSyiawl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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmGk8lH0fxSVuSUWyV0hR4kaS0h3HllJIWUOESGmxtSFEi5KyJ5EtsiXZ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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41VkcxhUmg2nkYbRoUJIoS2Sk5bW10CXr7RYh0YhSKWFUTI+lqUQY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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lWkfxg9lEN4Y5oNJTaRokgzTjCznQt4oWl5LJSH7W4RQKNTYRQ1Z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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lWkbPiktNChMKhktxjIxMU2T9UKS+kIlhEZSdmFSaYzGviRyrGmG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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8Ve8fv2WUUkkKpaQoCclIIW80jMpOSGbJaKgoKpFEyUpIg5Akqm/I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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lWkbx5HCSJ0aU16VImnG2AepiZ91piGFsi/ZJrLXSBQp2RpM1rIv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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk81dkbRipSNzHpUoosZakkaRQe3ExqKI1lkKJsiZBsTSqTtRprJaWx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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4VVkclTLpIldUZqY8e5FCZihmWiKvkopeSoooI67IGAmjlDA9iCkV
Fbre7/e7O0i4l1xd7xLZR5QZGlITmdnzx/nOd7797f3ba/3WWr+j6uxl6you
JiZ2iz7/vzndVnHzrnRCj+dpr2DGoG3HO8GDoHRczj8hqeNMEMZ53/8ivRuf
WvL3KnMYdEs5Cb/U1WP1ntHFUr8SkIDG48INLajK4qRrFRJ8yvt7TupBMeYt
fJOr6UawrWA8r2FHD1iyG6TuBzAI8elcMO1/AyNLpcM8jhGUrbjzwbK9CDI/
PrRPdiVgV/yqOVj9EMuX8e7qHidoUOZwJkPawTutWrK3lYDnPHPH5kgXbF3L
mlKNGWweaVZz9n2C4UjDFvfLBB4XOLJ6m17CPXq5SWI1g7HKXVUWbR04sVD3
hrsWA8067zij/b3oe6Tq76HGQEP78bzNBs04OekvnpFB4CZ5dunA9VY8ftfi
1ZxN4D/9puDjjlqYaBndFf5CUPt2bDxx7Suk/ttg8lHA4G8z7y9XSzoxkvlT
rPF3DGqs1YxdC3MhcBo743OCYCJ4QOlyWhLiK7eqh1E8cZWfs/Xs2iHdsOd1
8xTBQ89sHA+5h2n5mNsSdD2pT7v0Er8JzcMDIVdjCeoXR8wde9eBDFfHjNkP
BKv6nRRONKRCSVxnlbMTQazBBc9k8TbYDPRzq54R/Ljn7YR7RBf2XgmX8qT4
wkuXKBQpilC0v+3LghoCFVlhZ7BlIW56LhbjU747i8+RmfgObNotGZq4hsGw
0R5eggMfAYf/SpDhEswG6w3azuOjf048zzGdoIgVmiLPakd8zOlRBQHB4k2W
w/1KbWCpGMacKiJ41Ns/FBFRi/Dll6IFFwmG05xTLLTqIRPVUlPtR/d3lw37
uRVDSU7tq6e0/oCP7vZGqyrkuKa82u1JkOWkb1e7pQhdQW0CsVME3eF+kvnv
u6FfOT9Z/TwD0SmugG3QAmktHQtN2i92X5C17a4C+GyTK/N0IQipcBWZaAkh
4P/2r+kfBBft6ncn+tdBumduMSuEnjfbNC4MrkD6URarkeqT7SFI4f3ehxC9
b7UnnjPQ54YEK3NEeLl/xkFDnkFU31btA5npiFQbTFtD/dC8ZN9Ltdc88OT2
5X/0IogqnTyqkZ4Ltmh9nTrtN5ste/9rZRF4uHAs4h2BmJFuuGZ0JU5NnUy0
8iAQBAmeYJQLk8j0XYO03/5LDdx7H/NhLR8VOUrxRE3FrraKrUGUclKyCj1/
3M/Gba67Hr099gNpPgTbS0y7/X2qEZe52cH/LME6Q/OhI2MijCWc2c+WZbCu
yuTC0bRiWNVZjtq5E0gFDkb++WchAuevnHChfIu9fpwtoVKLQ8bTcVnnqH+v
rTFTN6tDwNAdx9nzBCNO7T9nBdWBreI7vpSut1ldiSy3f4ofzjexmoIIRE76
Axof2uFzx2tRdAHBVZvvtrOUhGCbDshWUr5HlA1920zrYJ2rl+gYTP2rWBFd
srcbCcnn7k96MXC41Ho0a7QDtg66HCc5BtJhiXs3JtxC/dz37sU0DzxMI9Wm
ZZuRwrbQLEyi9z2u/Xn/sUxMHjvo6UX5b2vfJbw3VgQXg+ay6xSPysPLd9Xk
byGkTsa8nO7n/RB38qrqdVQdMg/i0O+8IQeWSwcfaes/O9neI2gM/MnO0LAR
2XYLbshRfymuv2mgVNGAg3rm+qUUv7NxWXj0YCc+DU3lq2+k/nHg5zdEtEHL
jGORGE/zSu/zXFJUI2pX/zvSGUZwuinm5ASvGIoHxA4RqldLHt/9um07bj4x
G0rqJYj3XPJly7YW+DS8l5Si/ogqOue91qQFRRXO0stSqV6VttTsW9cEbY0h
scP0PuwlrxVHqH7usubiTKjfq8Z0Qt2+awWrV1Luz1ICow1d2mh7Cu5LU8/E
awTGDxqjxotj0F1bmhBL8bI+DA6u3NuOs5LdyUbDBKGJz5Y7Xn2B0uf3S7tv
Ujw5tmN+RULMHknINRqi/fu7KevEzgdQjO3rXUf1eDSgQFyrpwspIsUrfF0G
1qW7+ryZamxe6zLIUD061k9Gb/fLwEWZkYsqtB8hsYX5g+sf4oXrvjXb6P5a
CX3tgGu9yAyrNnFWpnm/kG+Z8TwFZ3cXMf/n1egv7MLijSI80uFvCewnWJZH
HsVs68H1mcaH3NV0vjz1mb1iVAa/Ks3Eb6g/43Y+Ep3ybIbcZwuH15T/zgVx
B5728fGiRuKGJtXHKvMJSKSUoyxeUqqA+suYu1R5oVwaPHy/upFL6ylont4a
FJsH81a7YT/qT8vfBiROT1eg7ZV8Ri6HgDv3j7O8ejtWaHFqeiYIzG7ZvvMI
68OlO9558v5Ur4PPVrxfJkTRSOv35U20XpZGcMdAE4avr0l6cofylTPdE+bW
B/34NX81RjFweZZyYGBdKXRz7pvvPEn5qXrVN+DWDMc5gYFUJK3fZCNjH9aI
R7FfTzpFEQQIFMq51p3Q8GSzz9C8bjbdZV8bT+fxRnt1HxUGd12KjLb80wvL
zM8fZJQYjBinOgeo/oHnqTkTBdT/HZW/u2QO9mC+poFYogGDWb3gIJMTTZDp
+zah+ibBgRUR9VPLn0NJFNmePklonyZZ+i86kGvjdr6T5tuI7Tlbhxt9UFGT
+92K+vOWS03MHkkhDkt+c8mpmSCzZoYbKGgA12nIsoPe/23XKm8ZXyH6G3ou
hjMETl079q8qbcL8UYVrt6MpPwvuntZ/WYeViw02aYQSBIYq+k1kN0Ln9szu
eVSv6mzxQAe/dmxc+yHHjc4jnZXfjC7KycItu/Ub7lE9dX5r4SlxsANKb64u
s/6RAWeIN+j7phupXz8QTtkx2GqTLJ8jakP7pZHwoVoCl1a7j4Hlz2G/6OcU
Z6qnMzvs/YhhMVK2Z7ofon5cNBrQMq76EuOricbBYgY89TAvq5EWGE57fNVF
/1deJ+8cfRshQqREtmxJC0HwuHf2sxQhJM6W9JaX0fl9s+z9Pmk+am5zf5Cn
/d6qWoJPbzuww/fQzCjN27lalaEglRe4OFof2lPGYIHGsY1hF55hqZTZ1KYK
gv8AI9zC9w==
        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k8VH0blpTCU8haFCopikqlUpckiRZUqFQqJEkihTxZKjyyJVtR2UKI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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk8lWkbNipR9s8oLShNgwopjTaX0ihL1pI0IVIU0SLLSFJKtiRkX84Y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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81dkfxm+qq6aF0AymGkrKDDGkNOKhGEuT3CwpFVkqka3GWEYhU0pZ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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8lWkfxk8SJVqkRpIUvai8llFD0kVRR7ImTTQjJPTqkDhEC6a3RaF0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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3kglO/bxUdFKUJZStbSZsmWUsmhCCWhkihEhFKiRb4thPIrVLI1SZJS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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81Okfl1BDk7PIbuXomEqSa7f0641NRTbkWDmKRVRsk18S2WJXsinZ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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs4lFkDpxLRjYRVKtESckklm/zSSCrrnsuSNHLJKi1ScomStC612qS+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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4ldkfv8oSxqASMag0bTeSvWn00aL6JbfSJoykwhSTJCIlaxRJlsQU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        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VG8bHlIpUglJRJZCloRs5ZaEUpKtsYSiopCflCXKlqWkqLSQUlFU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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlns4lOkfxlWUqBxWJ0SEkOTUroruIUkHSiJWSRmt7SDaSLFIjtWuQymJ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        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4lWkbR5nRTpmyFZmTDLKUGIkfkiSETplG2YqyjEiWb76SkJQ1Gbuo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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
    GraphicsBox[{
      {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8ldkbpx9Z0nJFZipLUWkzlaZk+1omUjK3KQwjjMlSsoUWqYyIREgx
0SKEwdW1RLj2rWzdrmvPWDpvmGIkJdp+pz/ez/t5P+c5z3nO812ed5WT1y/O
80REROLp8+0dsMhxwJklROjZGjHNaQJh+UN9C48OHI7e+6vdawIli/gETWsh
Nj34by76FQHvVPa9Aw7Z2KqvosZ3InjpZR7z/VwVFlVqCyT9CdghgZz5+x6h
16L+1dKjBN7V3V+jH+bAblfV82M0XrLNb+GwoBsmpTn90qsYFEZxuMvmCcE1
wSm5pQyEAT/1mHvQbwX3GDNpBgZcUb8aKy54C4c1H/xB8HjsyFuf0SIc5jLa
7W4E8RtKdrnM1oIdd+Hc8FkC3d2ahcOhTTj//qLJ8WiCydFTRr9F1UMistJ/
4UUCNwudsOapHqT2LrL8GM3ATXU6s0RDCA2ZDwY5rQR1J2YKSjldEB4MCtYy
ZBBYpb2nob4RUolf6077EuQGmU1sbS2DclKG1DlPgnCPNRnBg00Iv6R42uE+
vZ+VfFH43zwEPkemlQfBpzUf/FzftKNSEDEjVk6Q6N6yPcJZgIZl6zbsrSTg
JkOxjtWLG/yrXZop9L513Dnbsk4EdCsaXBdnIFa6IPLalm4kXSx3S2EzCFco
+nDySyFCIlP2GdD7j3EGfDo3tmDyzsTQWArN51yirjBWjyOGB+pSQgiqV7Hj
+axOBHtO7cxWZjBoWSQTfecuRl413TniSKAWGltSFFyOwVOakj94EyRoe57M
kuVCumLnyrZveC22sD3/qzfCTf0itzsQBOmweaUjGXjtc+h59e/0vD8s5Ma5
hUhScQq3dyYYlPTS0LzTgAyTpCmbMBpfphq/7dYZSHpyN+nQ/VqTMwf2a3Rg
54J7sZz5DHzsTojbGfbAcoWht9xBBo5TE6piucnQl1NMOUrrC4k059tbt+L1
5C0L1Qq6n3vmr/bGGijdtXKUOU/PU3lxVX7zbSSyj05vp/GDR0fqKiqF+JAp
8O98TPHcl/BJ8cVjtNXOl5tNpHy40y+zSfIG1NWOBGXRelxL1htWnxBC26Ul
e4UMg5DZzwclnKsQvNp95DLtBzeuw3L/Jx5KUwcfbqN48qtcTUrWdyF5UDb9
yjKKl9GYgc7dfoi7ninecphBclLttibXTpztDSIO3zMQMd/sGZd2E+mSvmIv
6Xle18CSsi5HG6uep0L5IxKoG3NOyxkC11z2NroeftD4c2x9AUhjtmYc7Wf7
L8qCYym9OMXZ5GC6kQFXt3N8XDQRa9vXahEaXzS3/u3J8/mIr9Wyrqfxm9Rd
DNfotyHWV6u44BGBY9pFyeXfdYOf61PmYsyA3aHucX91OvhbeZWrKH4i/bZ5
owWRaEpdf9+F5pvyKWj8vp+Pgguc0gTKz/R/p/TD7dvhNzQZ3Un9gdv+8NpO
uydo1shOWR1FoPHXaEB9rQDqn8TSTP4jyAk8/nvklRbk6e/QM6Z8TPuY35fl
wAcnrmLwPo8g3z9N7lF9GUQv/lF814fmq/6YbXmjA3y3NpVnqxnEX/kPG35/
jJ3auhoiVwmOP9UrtWCVo3ezzro4L4I8q9svsjye473O//oOLnmJ+QZf/Z7M
CrAy8DZLuplAOj3K5rIuHw9sWZWv6bfaHhjYH26GfdWL+OOpBCbc2c9spXbc
aohQeNdLkCw+cOhnphEKZxrXmiVQfE//lrExqgVbzq+KUL5JsKRDrb7Rtwka
rnNn9l8nOL3ETCvEoRjDnHiJg8dofR/PPlLo6kLh3xaTR2wZjIYTfYvUCtjs
OvDuLeXLuHZv46k/n2FdhPFDkSIC9RGvLK7cI8gOvHG84E6gHxkTOeD9DLHL
y4aQQ/12wBI29XyQryeKWc8ILi3QsllzvR811abf7c1naD9DvT2uXUPY8w13
L1O83A7bpdTNy0ezbXrOZ+qPbsd5gkLRHiTK5mY3GDD4ktEf+/5eF/jDfbYT
5gya2F6BD+d3oMraJ2fBDMEOG0yZP+GjWMLZNVNIsHffK8OuFx20FNNCX1EG
CjV7avWO8WG0fqnrv1UEgRITY5zHXbAOuyaWtouBt8OhWquZPIiVjXPGKP8m
Emf686q7cbpV3b6HRfURsyBrPKAJTqYd0RK3qH+Huqut9m3Byp5WNUE+nTc+
W9/16gkgWRWn2kr9kUxHNx7+8Tl6Do2wew/Qfhb5mu02asEP0cqCoHQCf35P
92PzTgRmNvYayTPUT/Yq2p5NQ3NSc9sXqv8YESmvhvE0eGsnTIPyW205y1Df
V4iVoUoM6x+CD29dChcllGJ2pYeu4XEC29RW/6WJ+fC4kXrfhtbv3eYba8Mu
wQ4tuREpqs8v8N3+a3w+WBo8cUu6vlJGfP9rn05UrPeLUKX+PK1pNP0TX4gT
W2Rnfak+Rt0Q8E/4U3imzzM+TfUzW21qmhvVCVPL4AdHqd+pibw5PyTTh2XL
h0qzYuh8aR1aqMTugUVpTA1nM4Pr8l4dS6SeIfzJ1OKhNqrP7oyqm/d64LJn
9+V9Jgzyh/+s7VssBG93sB33PcHavRd+TFPl4/3nzXpZnVTvT/YUncjnoGZX
6qQT5YNShkzYuHo/Duh6zG6+zSBoRPLoVr0mLH1pdjUqluCWeK+ttHIlKhQT
zZ5Sv2OP2cyTm+1BUcNveSLfMUjwnYgbk6vDobIw40fnqD9J/Py1+hIPMjs+
EFOqXxOhu81nDQHUxo2V5Iep//JcQjJjEuBe3Lyn9Jvfc5PlXV/1IWqFv+xU
OfVDFueBda4n7k3Wen6bJ24b5K73XSqGiZ/KvG/+ZWEQICqyogZujD3DPUlQ
ZedUnjP1J57ObfnbhMYbhYqWGCU1YVNcvOjGCAKVl+0fCz5mQP1cmZQonVeD
ytH3ryRXwGVCyDOl89pAR+FmQ0I+9AZi9NpofpHB0fKiZkvkSkqNbaH5fpmZ
O+SU14GIK4F2BhTP7pO5abHDQrT8LJ/wZjHl7wzXuG7oCqw4q8uO0PgBmVSt
G1O1yJwN8/cIJtB+t056uWwf6hUXXvW6yUBnQYvKhRj6f2Ps63jZjcH/AR46
vtI=
        "]]}, 
      {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2kglG8bxf2RFEUikoRokUIJpToouzKVtSypCCmKQkWWFhVKEYpShFSI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        "]]}, 
      {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk4lWkYxoWkhjKWomQpKqWmkrms3ZYcZVRSRJRIqBA5SoxINLZIJJMs
WZJQdkKyZz0OzsFRlnO+74RiWpgs02i++eO93j+e633e53qe33Pfyk6XLc8L
CggIJFLn/zu8qkT1iEUNGm1+qLNukJgPGaGNpjbihuSBPVUXSZikBU7ppfRh
na0oW/IDAd84b2/TUjb8V2xYPbOTh/kOq0d+0wGIdM+Z23qWhE1G9eeBo1kQ
0daUT3QjcSFmTVqQTzsk+l7foXcQ0GmQNnkv+Q7mcooShSp82NlcdV/40Yjo
o0oKwkkEiiP5x6I+dEH/88Vrhg4E5ot+eNmS3ehPaRNarkIi+MuYpGZYGugW
F5bCXUk8ertpWfl4DMwvD908c5rEoI3fdWsXNnIdDT/KuHEhoxBV76cyCi2y
pcveexTh4/eX0/5lorSuIDFbnA/h3twqRdV+cMvYZjF7+KDrNnjOZ3ZDutBJ
h3OXRN0ha1PDfX7wyr7HrnYgEZ+p/G/e/kEY97tvImVJnG+U+Tn9Zj9uSk/J
+E8QaPrQpM7xZuFHs12BN5fE2qTe8+GW/Ui+YnonIYUPyydnAyp0WMicqF5Y
HU1AWH+thI5DPbZX/Swb94TEiPq9oamhQQyrnsh63kHiXdlxHXPBLrSWsTMO
5RDY7SqubSqZizMt3sfqXEg8PdLePiXXj94TPraXwwkkfeO3WJ9hYGpXvVd0
PBXXCVxY2lIFR+2KNs84Ei7Ne92UMwZw74qq7HUZLs4KNoreHKrCel/PKdKX
hL34WETcIAMjRX/1/n2MhGxs16q361qQeosI+7OahITblnzJ9ekIfv3pYfk5
EjXau7K9Ekux8baL1+tfSIhEnK58PtoNjqV+FOMHgVk1PRUppS7sqNZYJ67L
R9ABs28L7myExxmZqs3zQC58Gqk92ACzVo9p/iyJznx90fVTfYgO1pvtUuej
xtSy1saXhSSLOCYRwAczoFS8+goTV8tynG96kJioOl5D12pD+QV9x8hUEndn
9uj/NF6DsUZ/JaMeAhORj+4emyxFFXH4SivFS6bm/FyEIgNJm5M0laYJONP0
Q6wS30DdapvT2XwSAl/97O6HluP9YIb0Kz8SaTPFbzwec9Cp139mbokHYyNd
kadr62C+GNybsJ3icWPMdrZWDdZaMcoJKxIPjhs7/ZDnwCgvJd5VjoBFaNFt
9+lm3DjHWKhSJ/Hc2ZLRkNyFi4V3uvzf8nAxXd3qriMHqWHPP5VQPJla1LE8
NveAlMv8zaaAR/XP81viSQ6O1C8Lf7Gc+o8zPGuh0AWazA7Tv4spPukrWLlO
1RAqNPtHzJREQ3lB0XLxFkRxfcJctvPhED/u8ZdjD+iVg1mFB6n969z27EES
B4Y/7fNy5Yxh90ERa64+A5Khvx1jFxCIUZVj//q6B8rfOQ6XYqh5F66qivzY
jOUzdL59HwEVG+EyrQYWNLbO1rKvEShNUlxQ7y3Couu3p4VmJMSkhrfZ6veg
OsJkMY6qb/a9mRBvoQcT8zYh21oJSLSZSYU8qofz7bp/jO6QOFurYr52rAe1
Gdc2faL4T4qalZNv7oW+Qd/4Bqr/BsJf4v+wzMZUbsTkSksS1hUVk3l2PQjv
4A6VPCLw2Upr5lRbLyLFifbKdhJB64p/1n/DglWRZbTxAwJOyxIymuYGccCA
O+nJIKEyK7otO3EIq8K4X6KE+Dh4QfBx/4kSfJ4UOa5nTc3fe2eX4ccYKOle
3ydM8f1QqF/TvqAFJUHpoqpUPglVzcvNdgwENCRvtvUlILBtKbwtpQkfaI0B
U+MUj+EMJbr1K6ROyKpOU3ooYBJvr6EZBumcrAPG/+uj8+ZLYmJvQIv6aa9L
ABWXromMEg5DggOLwaD0qypx5YEOtUHsenq663UGgXTTvIVd5Z2oajh5a3UF
AfO6eKVPiSyEyNfY//uFBzcriS+7uXlgehfkSlL59znRnv65tRnK4TTjOYqH
u7RUtqJvFu6ti/3lpCOJRdr0q4GRUrQIROrQ7CmeLhwYd78aiqaeBJ80St9a
z5y6V+3TixsK9yc9hgl4uRp9HZYrhNSQ4gs1qt690oU8k1EWDMeNr5hn86G+
xo2nEchGsoHpQBL1PmP4JW+73jt8ZxrRjvDGYKCgn9cq1QODHB/fO69IGK3c
GG2W2Y+mLKNywxs8pN9/ZKDtVgfpc49LJzxJhORbRgVL94I5x0q69Y7q72CJ
tuF+P6SZnGkoofKbZwUHuu1hQkLyQcgLAwJZ5IzCzjQm8nl6K5zLCCxqmU5E
zrAhK96+VLOWD7W9Ul5qTBZeFEl+35/AQ+xtI6bq7mZUilUM0DZQfmH0vH0H
vwnPvpq6HT9E+Z+QlX+JTTceu/q4HV1N4vaOfTvPJ49AbictWZnqf9/6upav
UR1IGLaxOHyLwNKNScfulx24PjWvW0rxfqIp4jd5RiWEL9c83HCNhOfKWYmX
KwegWHdLIHklFb+wmK3ZXYGN7ZdCeNS8mz1nXtatyIHhX4otp06RkOHbpxyn
D+LxN8IsrIuLHRp/vAxkspHKHsqm7eaB4+I/4bKVg5n9sqGHOVzoliyZPOAM
YbTVKeuwJIn9glliBpc54GuknIyleA6xV0+wfTqIW7LydoojY9giP3Mq6M98
XBUR1rOJovhW2eTdOV0L/x5lP9uPlN+u9zd3s3qG/aceiq2i/OVVfkLavBUb
Rdqy3NuUvm3KbXsmMF2Cyrmv6flU/XkyWbbndg6g8muv5ct2LrZ4vW23p9cj
Z2zIKuB3AkyXxzxR6TYUKufNij2j/Ehmn90K9WZUCGuKxVL7/Sa29/QWx7fQ
OVrir/luDHThUp/e1+0QrLevctzIh2jams998m9g8/1FX85zEvQnPtHqyk2Y
rblbc57a3y1OFd8iRjhgx1+yeSH5HiKLkefrKzsx+UtwnJoXgV+brmv83slC
aGBI3DJK/93+yEwsK+qGA12xWNiQ0iv32AdC80NwliQOVTBHESjlYUSe64XC
Fci9X8WHBq+w+IlxHw6uL9KKCuZhUKhTN6e1EPT3q9cEOZMw+3shKLy2H9kf
1Plygzww9YuPJgn2oL00bJNTKIH/AFmYvjw=
        "]]}, 
      {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk4lekfxmUpCZGuwrQQskUY2Sq3LBOlsv2ytdpJg0mNtbGUpkKSQbZj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        "]]}},
     AspectRatio->1,
     Axes->True,
     AxesLabel->{
       FormBox["\"mesh\"", TraditionalForm], 
       FormBox["\"value\"", TraditionalForm]},
     AxesOrigin->{0, 0.5},
     PlotRange->{{0, 0.5}, {0.4, 0.9}}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.5457560206793766`*^9, 3.5457560252754326`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns4ldkXx08lIVMnU0YoKpVSQqRc+lYkTRlyq/h1QUlKZNSELhIhQ7mm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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3lcjO/bHaQS2hRFCG3oixZK6EQhfmiKQipJSdYkVIoQJUnapE1RSbvS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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk41WkfxpGkUoQiDGHIqCylQum2vCQkoxjbeywxbbJWskyUZRwjKkK2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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs4lFsDxYkiSRKpdAq5pOKckiHSwlFRKCSS3KKSSLqJyiWho5DcRcol
VD6iIYQQM7k0GBrXZuZ9UzF00yGk835/7Gc/+5+991p7rd9Wcj9t4zlPSEgo
iRr/n8WbUhbMG6pDuFWhWNAIAdHMIZXV4lkwP5T3SduXxKzP6kJWcifELNdP
nfrKx+PTmqmhZa+h4kIPiZwicCrYU/mFZgcmE9PU16YSEGg/c3zZOwCrlXkG
yhlcSPgEhXno1iJH8+Pc4FYSrmPN5+aeHYNLq+EXDRcSfgGhO1eEZCNH/7hS
4B4S+0V/ZHK21cCBmNFmfCDgS9O1zwrtx/CrqsucKh6u6lQwdRM6EW0Sc7Tt
CR+rrCPjLW9x0CgVYe60mYeTBrse8qV7sFlX6/foBj4iLQtUmOkDsMjLlayc
5SPO0HP28iUm+G8ulE4N8zG9K8jF2osNaZniB48GeUgQdpiR0ehGh/y+qh8y
BKrpxBrvBA44p3zzoj7wILXBI+/boR6YrLTvD7LgI6I37bNEKgsqX9b4eJsS
kJ43l0V01cPXf9ZJ3oaE0ZK0FdccLiJrjXiBgTOJCIvJ5tStdcgaFZ5cfJXE
GhkmIbajHLN7/Qvtt5HA7wuqLcL98Lx4EfAhodw18qzE8S1qVf7JdlHloy+8
hB74uwN5t9TXsd0JPMjkhKTKtuGDqI6rhQ6Bv4okqtXMK9Dn3RKxcY5aWxyf
yExph0jvbf3t9whEfTk/r0W5Fc/5dw8zVPhIEsiISVpxEHnf6Um5AwnJRimL
ydEGhP/sPDpcQYBx6kZeaHQH9JoiB1dEE1CUe6DnqckCYdw7lXiFD1dhwSWu
ZSeu/mbuCJDiw2xAYx3PtQValRW3DhiQyPK72vrsZCUslxwYmnUjEcAZyQgS
tGOwtXdTvzmBJyFidDlKr1r+2iVaNSQyxyu4STZ9mGql787YzwPtTyPatAML
1X5bbF2sKH+5Y1t8JpsgPrDs9dLN1P4Xd9psnHgI9h/qun/bkjjnk5EVac1C
z+v8vSk9fOyPaeo9P5sPjbIqQfExEhtWHCs7uIuF8ZhvU/k5PJi/13ugsLYb
UePm3QohJHTeb1pXLjQEWYlF58YXcpGyt5CMknyFuc6OGb88AuYL7v0kmC2Y
0lIs7Mim/OCmredknoT77cxKGyrPrCUMmeGtT3AjoHdwE6W/JlRwKvF1Fe52
KDVnnqbyffpgDlc8ATfVrEMbHUk4cO3kQuJSMZNufHjoOIlt5Q005/schH17
8Xk0iYCHaFaFpFIbbnwWzi3+xYd+q0m+TV0/Ph01S5XTIjC0IZHnGNEEedv0
gV5XAjatM+Ph+kwsKPWWSKT6M89tyFuCUQ/WWOqiZWokKjhjxZFeHfB9KuAq
jfMhZF1kPKLVD6G2gp03FN/Bb+OhZZ8qH6Fwfl7JJgsSdHfDNqUNLHgTCpUx
OVSeNcZ1okXS0RhztWyBK4l8bU5m9LJu1C9V+FewnA+3bzSOx7dOmG4WCv3x
njrPxOdS896XiOcn+ApMSRzcsr3524ouXMuWPlL2lIcodl+Yt3kt6L2eanL7
Sbi51mfLuLDBlur35BbyEH9F9Ee/YTl2ps/U6e0j4XPZMDV4PQf6YxJ76uII
JIXFh70w6sC9RtoSXaovNU2lzoFlfbiZbKlXKspF1sNmz6m+MuQwHrQbzCMx
snwZQa/thn19Fl11PRcnzs8Qd4WLsYrluj3iMolWWpD79r2t4I61706+zEdW
eI8sQXsD/arj3/MpfScu2XuVaVfCXawxYbkhiTPFQmfMdryFOuNspEcNAZbE
TbGC2RzUj5K526i8SU5YfLlj1Ymk6Jom9h4e/NcsdDH8wIJOSbLzIQMCGY8v
T/yd3ACGHfNNWC7VD5XBI7G5HUhKmfgzrIoPtUt/OcUuZ0LxNz1O5CEBI9H8
wOJqOlaRxTqcsySGNa96CiZ6sGdwOOXcWz7OLeo5r2PVAJlHygd3U3mSDi2Q
NxxsgEtt6lLPHqr/0flSDPsuuH3OaRm3ISguy2Z8WM7ArWnPUUYdgawdwjOT
atXQVIpabNJEYDWLKW3mysI1o8POCmw+QuacSbnss+is5Lv6Uzxb8Igps3BR
H/7p+xInJM2Hnq1HiWpkOYrSJCWNvKl+qr84ZfF3H6wIEdcfv4bAYoTfbLIr
gEVyIPcXSCQ1ufG6VgygZmnKAe8KLtxjhU/mzvbDa7grUMP4HRSzqnNvzC/D
lmn/oC3qJAIDTEiOSCsyb20TjqP8n9RW36z6mInePwRFv7+TYBSWnc4Zovhs
xDwXHcQDo87WpP95E8xLPDhClQS8vpouMtZiQ8AtvX+Xx0PI/JIX+QdiIWGv
ovuHEwmhbKEq2rrdMBLxVTal+tw94nplM7sPE3LbXt6+QOJL+vM9KbGVkP+q
FxyykMQvi/5A33aKfxxrJYfzBNa7+4WX7i+BbPbZyLNh1H+3lPBnV72C5ZOu
pMgIAn3aRjenV3fB/s9LPj8pXnK3K/3qMynCnmQ7j6pDJD6qln4/SnYiiOlO
09hNYCCg/ezkow7UKRToi8TyUdaQqjwt1oe1P78+rQt+h8b57df/PdEGtryO
2EZdEgLG/8SOyLCx1HzlkVgtHpLtGr7vu9+DEIlVpbcp/ftsOwuTEgfg/vXV
R703BGKaZc3SOWzQV1q2HX7Nhb/gyPdfNDaUAn6qH9vFg173juDU0VYUt+y2
c2RR941WFvf51ArrYNPESGOKf361Q1aDPVh8R8NSvYwL0+j37NuzjTgaHVat
7UXgo4JquNaZGuwatX2cK0q9n06LwSDtJeoKrFdvjScx4GZ/70hGN3jX04No
h/mw9Dtj1ubUiQqxjWMx8yk/ja0/x2vT0f7JMZWbQqJ0wbDWGLsJU+VzoZ6U
X64F6Q+6F8fDaZPUVDjFowyBs622Fwfafk/b7mnywE3oSFsuU4znW45ffGhG
ImTabUA7rgbXejzuzCwjEXOnyCjD8hkcFN146yhen7DvIPfaVSLgulTwdSMS
ihFltCJWLOiyadE+R0m0V2xq8jr+FmkbxZ8LW/EwYK1Tv3akHeMS9x2jJKj+
aNZqRPcUQt6v1PMK9R7/AcOqvsM=
       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8VekfxigJk1STCSE1aVGiTZYHFfPTRLZoHZKbZCKGlMSPRmRJkrGT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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lO8Xxoe0oCRfkVYpsiVJScndIjsJRRKyZaskayQthJAUaVGyp6Ky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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk0VWsfxw0ZlqgUuYk0XBo0CEkD36KBt7jIeM1d85LiquReySyUkilU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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81dkfxm+ZQVGjCUUhRgtpaLSMwkMhFTNC0Yx9iOwiyShbI3EpRBlL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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lekfxs8UKqlmZEQl2pXIvueuFDFMhJIilTKJyQhHaH4IZS1FklMj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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4lG8bFZKkooRKRYmK7FFURyql0KIoWxJZyhYtPyShskSKZE+2Etki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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx7WMKSRJkWUsXSqTupZRqvFpbKm0ISGVjMZaISM/EqayZCxD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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns8lNkfx2ejtov4bbkVlUaRW9qoZOVjiyK5S8JG5JJ7LkW6KCqVsjWy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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekbPpmUbJEpmZzJHJMSkxkhNXQbTdonlaKfpWVSiBip7GRyypKU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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lP/7xanIVkop2aKkiEpKKnVK3zZJkrIm2fORvZJIWVJSqCgSki0U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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk4ldkfN0k10jJliiwpNRTZoih8KNnG2ggT6UYkJgxpNMyUPQYZu1KR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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41ekbxk8iW4pIKUtUKJQZxt7cpBmmoWLKyJaKElmyhWJOSUWJZixZ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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkbP2FMRMkc6zed0UQjmfAVFfLzifIZjGJUxpY9ZmQZ8dlSWoSI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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8Ve8fJ8pIGaWpUmlYRSWy3loSKiEpM5GRjJBU4iuhXaIUlRHJJiRl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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8VWkcxlVDEmW5SiSkRknTtY4JPbZRNDXWUlTGUqZpyBJthKHNlqVs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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk81Wkbxg8vLUYykWSLkFPekJSldEmTrWzNSfYtDFKZqZlKWZskpuyS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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4ldkbPSQRFU1jUE1uuUQhSlGtboQolcrEEHKZMCRdFFFySf0qJd1U
mogiIXJ0OC6h03FwznE7biWzP1MqUYmS/HZ/fM9+vmc/7/vttd611rc1vYK3
+kizWKwU+vxcV9/IOGIWlYPWyQZrZLwJrq/c0rVwlQRnGjKUvhgwsO8/HV8Q
Vw/X8zVL398jqHgysUrJshpahttzXaII8tKTXWs/sMGtLrYYDyA4GRCSYKPJ
wa5dlwN99hL0mPJu3N/khZs9GwWmHgSDhqMh5789wIopUlJiLwLvwUW/+f0u
xNrLySIrNkHiyjyDtX81I9kp8HcXeQbPo3sFi02eoyt66r8nEwhu5r3OUfPO
haSipGQ7Pa9SRtqRTxViPLRWqOh4TdDr5Mne4CrBJqmWFx7ODITFl/gBQ0Xw
V9wZKf0XQWx+UN8zuQ6I+zn8vfcYlE7fujJmey0cBlQvaR2leC6Mz6stakK0
9eDR228Jxl1Hv1olteOAwwp1aDNI4fQpxiiJYZNr0DPQQzBzKlcYHNQBI4ci
y/qDDPR2O+4P7xWB73e83K2MIFoxtG4b9yjO+v7VvYLiZ3X6K3QvzUJBmkJ9
oidBgfKvGhUr2zB/ZIf7RhkGyVP7q/zUa5C4q2zv2miCvkea02Z1NyPcuHPa
+TcEyxKs8120n4E95ZSWdSQB29Szxcm/EDK+sqmjewg6Sp6O/7BqgsuISdKn
r/R7F49MulNYgRI7pW09+wnkbgR0zi4uR5gV8RT9TSCjsP5mwLsW5Gy4eFw4
m0GOnc3wn2weZk27durzcQIXpRJFQ7UidHUYK5pR/uT7+T3Xg7ho/urXG07r
05pzhr4PNqOqW8CzHiZI0Oh9/89oEmzZzZHHf+K9ZuhnFluGdXkvBrnBBKfX
WNd5VnVhh8eOdUrBDBI3L1K9/K0FPQEWujJiAj0Z2Z233KsgvS7fe9lhgruc
gE8aoc2w13F8Y/ELg5OVDmZLourRNZTaZf+QwB69ITmjzZhz4kNroxoD1QED
fs6+TLj4yf94Tvl16Tqg17uyEDZ3esef+BHoz7nEaPW1Yr7SxnMyrwhsdYfV
DnF4KBIoly9JJjgr01Btp9QGjV98NvAHCF7kR+wcNmxCXn7K7FcU34IyObfq
TSKs5iak19fT/vMUQheuqMbjUPP+Uaof1mPdOOUBL3zbrT30U+8sfm2j3pbT
KBjRu+NB3/+RmpMzb3kz7BZovDaj/T8bHyi+392CkaDTG2OtGEhfv9eWGdOC
DbVTYj8uYmArWbpqR2IeBpx8+Vl0vqVNlTP6Itm4XlNWUuhPUBun7Cqe0Qan
VKFBow6D4MKs2AljCQrUFfc2rGHAknpsZxEiwBTbpnipTAKh7K351/Zk4tSw
9HYe5Sc6qLRaVSwG1/RvTR8FBvVu26aYfm3C77L4ZtlHMOrN0x/bWQBBIK7G
+xCEu9tOMrnVBtvR4GA5L+qvyLGccat74M79JZBF/Rz+76KGbA0JlnzcpvMx
lAHPvSpQfj8XCzaXv9kZRPPBtCTQ2EMCg2F32cU0XwYN/7jofLsegW1fMuRp
vuic6SwL8S5Cmn3oA3dfgoYkRY1qdTGM9+d7FpQSuFd6T2578AySgod2lyII
zLvPpMjaPEPlGcdjUbEEvvoV0faCFsiS82q/6jL471Wg1MRsIVhymS32WVTv
T2zq/OxFSE05OLX/JcEsY7kpYSXtMLqpwMmm+hdeiNN/o1qMV3++0OmkenkX
bnw0cqACzT+qjHQPUr5eRmeLOxthubrO5Xs6wRcfG83+0Hacnx7rqW/OIPU/
i8w9h0W4uDG90v4DQaheZsHeOZVI0p+4e+EIQVfdMXspV9rvmKyQE0YQv+97
9FXHSrwabj1wPZzmZXGnSpdRDUq1+CqOFB9PKYEfElWKmBdnG9tpvpI2H14I
3U/3SI9QpPszxy1Oa8eL4e/8XrRFRBDBjtk2JG6Fib6UpI7y25MbdueudTqc
Tn42zd5NcCgje9DzhgTmw3UV4vUMKt66H9KbJcH6bVsTp7sxkMyuCYvXe4KB
zXb67gE//d/SIu/cDqX3y/0zPBi8tWkIVddrwjSTgP/FtRKEbFfRPjvxAPMH
NnKcaR6vJvGxK+zYeHxhiaMm5a+UMRMFfxTgm+D2nZ2pFJ/FYYV7IxJUrFn8
4+ouBvrWn4xUmHpoK+ZtUcun+gxwtz44lYvvWwxdi0Jova7cuQyfGphkjTjP
O0vrd2svrg3LQU79oeWpVG8qpw55jag0w3zycnEanefgjsR9g+fzYSK4WMml
fll91Lr4Zu4ZODmnpwdR/xm0Vb1MUe+G4uFUzYLpfahIVtznai2Ar8FZ28i7
1E/c1Y95uiKUjrc551I9pmS9jeLdL8Pa8TBRDtWvrWGZUXBHGa4Vb97Boef7
Zh7xPlhLhERvC++rHHr+f8bs+MJyPPEQblm6j6D/VskeLksMXYunPmw6n5vG
Q58PpbVBre9t6qYxgteOTyNU44UQTrP84FVO87tJOi3knAS97AlT9+UMJk3a
vyuxpBkOg56XW2k+OnOidj8IrUTg/ZoPDTQfucUpnedYzzFzyNg89hLBx0aH
pWHBEhyeaqMWwmLgEMYZ9p71GGa3zOe407xQiUh9aLxKjE0ha0sVeAQnhu8O
irS78MolvUzhTwYJF96NrVXuQHSMw/w/NBmYrPnva8K757hxWbokjPYfzLri
n7zuEdjK8Den/gwrXZbDf1SH9qy4IN51An/+FzfJtVrMXNnXMZhI/ahzrN1q
/VPIub2L4lC9Cr/H6Hm/eYTITQu1O2m9r67HSwR3Y+zlxLwO2T48ne56e0Fc
B46fMJzbR/OFLYpNeshphItF5oLp1P+tF+613o7m4qSlpc0Xym+eeMzNXSkb
12TmPr1D9WBy5De/xZebsEvir7me4ivI3jz/ZW4L1JWNzQ01GPgXbih3JkW4
orX/12n0f7bMz+HfGfLN0Fk3b7LWDHofuMraul2+FlcuWiZ5naD3HZ+56aLF
D/BO/Ez7x8/+3eHmFXufwyNRVWBL8aUbJ3/UNSrCrM/K1fJU78ce1kkWhlRD
cJK3p5DO5/8e9Ljo
       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lO8XxpGEsvSNFkWyR1S2RLolZCtKGxEVUtmKLKkQIQqJSKukQvYl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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs8lOkbxq2kDDpIDkvY2YqKDSGVuiQsoaUkUQY5TBSSDsqWNoXa1sgx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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4lWkYxoUkRaTQZGkjYcRMGkpzY46YoYSSVISjhKFkmqbsZZk6lhpU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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8VekflhRqInWjqekXFSohU8NMY+aRmCyFETM1LdeSiWQbEU2iKCVK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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VV8bJZKxUBmiTBmSKSUqWSVFIhVliAyh0kRUlCGVEipJpqTIPEVR
Ml7zzMXNPN5zLhLlp1nKd76/7vOcu88+7373WutdS8bp4hGXJWxsbCfY2dj+
/xuuN3d/2L4K5mGnX4gdJfDDOuQEJN5h0mPXx85bBCTn3mmlyLShyHnFhZtN
BAT5Um4fr21HspUaUyN2DNJ1YROM4Zso39nmXXWchN2FQYuTUT2Y41ipPBdL
gPt3WeKF+CaELNSyrVjNRFHG73EnpXokdbVmBDFJPFROuqKQU41DDlmv64uY
4NwbeP2/Mx/gbyNb4hnGgtre5oKsRQasA8t2b6gjcUjphyRTswnFaS9u1rwk
MSh49smiQCt0h5s8+KRZ8Ko7YSYRnYzWzS7jZdok9tkulxMZ6QLt6eer/NEs
6LpJVYxLNmP/7fwRwyUkNDaKv7q35BX0HW/zixuT2FJgT7DF9GK91fFrh6j3
Dep9Z5+sb4XcX6/rqzVYcH+5vzfwTDpUDNzoA69JXE0oOLO7qRLGb6IbI/pI
TPbUWYwFN+Een8qzPVNMDCavd7zdUgQRn0521ywCHwVdwhYCuiC53LToSvMY
xrM37RY9XgiDjDW1sdT3G2KvWr+48g7dsg7vlKJJqB5IfFzbUAPnR8us5b8S
sNFJj27Jf4E8rRAajxcJMQ+/DZGb82B7V/1vZDqJGGmv7Iu/0sHNNvzIiPpf
uv6iUIBML+x8LN+G+jPx6qvlWT1vBrZvttosVMZCg4Kgq7BJG2YlvVt3cE6g
lLTaUDpchTtSz2cFf7BQXKhqrkW2QfhUT/zc2glc49qkf5SnHwWNVfuWvpxA
+P38+FOf81Bv/TshJ44EPdyNtKW9QWRgWtyPKBKmezRyfxWNoPkkK35IYxq6
XlK0Zd6JCBl5nzFiTa3fp21Z0d4FTeXkCO2KCXAefzObt7UURmF3JHl3keCV
evz8omUHqi5sWLx6jMA6o9XoJboQv0drC0/JJNj2v9nPlXwIh5ca7tpnT/Uj
L0X18pNy3P22xalRjcQu5y+MtKwazNPoRyPVSRxZv4LF5jOA7W/CTuoHD0GM
vbJiwKUSO2TqcpVvUOs3HVT7rfkIDX84LxqdITF7UURAPr4C2THuGROuJCZ8
u6NtXnzAJo1D/1iMfrAV9IY46b3C7IDfHm7q/eVDMaPP4zpw7IDQJuHDBHat
UKtlmTeCXrKdMB0kEJP63WdcqRSd7DEZbTIUnkiNTMf9dSgIsQiv/MYEx33N
MJtrlTDzNzZ4f5KFWf9rU6KB7XgUoR98VfYjOIf6tTKF6OgVZ/htfECATU+W
P029HVMXb7qdOEvi9G3Rnz/Vm9HytfDN+zsEpP0eSYTnpOCb1MbGi1tJLGxd
Ip9L0rC/sZf/mhfFT5fE7iCjBqjz6lunmpJ4JjSbeb6LAc/NNwergybhHnBv
7wOXFjg8MUxUtyCQ580VazTUAk+1xvLlJQSSjreYy4XVw8Q0i13Eh8A3OzHX
RxffYlVuh+aRbAqPX5MKd6RXY+Xux518p0iMTkrEmBi/x02zHLaNZVR927jq
b1H8kDjvt3blHwKchltkE8/mYU1hekqGC8WnvNzX9ugGb2FcX3YVC3WDxhOu
0oO4letYd8l8BtwykcONvDXI9x1QbKH42KQ+P3TAeAjeMnntoV+HEDP7X4xx
bzvcL41uiS6g6uFKqEs80ocmed6SG7NMRImdOlimQUNh6oDeAFVfy6soh9IF
Or6dkt02rTMJ3VXOyiuvd+Nh8+ykggwJ/S1B89pFVfC22Fp0TISF6t+6yzrO
DKJVh3tv/RsCEr8+BhQZDyDFfmWbji6J6KI7+l+l3mKUJ5nvJo26H/3ogyXW
dHCOGbErvpiAd3jrsbt5xSj512acRelrw3Inx0DDN0h96ye+04LSH1O7V74C
NeA38teV2U0i+4SmZQJ/N0pWf1O4fJiF6a+dz5Uru8Fvejoj6w8T5S7HAhgi
PWjkkpC9+psFp34e20NEDUQyrXKVA1mIP8j/O1OgGQlXvtAj/5CwSZRo7Fdp
hdZf/oVrlP7kyUZECqv3o8k6ysZlchjHLlu4DdL6cHDfukbRpSxwm8sWftWh
IVV9xtKYh+IH01V93XYalobntrg9JbAv+eheQe5O/Gu3/NPAYOKPI9cT3scf
0MEwdUjaS+Ff8rpBgk0ljj6yK84Fpe8y38/aCPYh1NHrBsf9Sdyon3h9jC8N
J7StJGKOkmAbPWjsPBuJbZMfSpZT+Py1XF3zskYVagI+trSuIuE8/7IggBzA
r3/dhmQO1a8Ph7PtZNqR6su3rOA5gSUba56FsXXDq7PguOZLFuaKKv4MXOuC
Gu3HkeqRMTgLGjb7KZVj04muNvHPBHpX8G3RNemAd7cpj9U+FpRuqqxeLdYE
ByMhYQ9nFh40fB22YWOgXXJ78iZhJm4MudjqTQVCL1xL0YOaf7SulBD7Ahru
KMuvy0yg9I3o+rUjsRspsbrpSy0mYKJeV253rhb9u4fPNuYTOMHY5f2xaADG
5Uu8b42xUPrjRZzOuQGwiUQNCNhNYXRzvouPRAtoiuvNYu9T+H1i7xiYmYVu
pe/S7uYk1q2Ld432os73+7pJ6cAYQnjatLMbazHOMxGh5sZCEtiYWmqdaI1Z
xy79loVj0j8ef3HvwaowQ3nCYwyCnI4SNk6DeLyhOHYwaArx8xacL3614NJW
zbsBdqOoYT7hOd3ahGPRa54vsSfA4HM13ahfD+v5rkwBPRJK/MYyvke6EFnY
6WDzi9rPXVzkWkgrpO1k15a7kYj8wO6iPdCBtSv/STy7xIS0r4gh0ygFyen5
FpVHSHwLlFHZI5UIpWoBqYc2JISNKhLPBjCQ9mPBqWIbC4LWdw71zr3Giu8H
bJdHkHAgVfUzTLrg1jsT/06LieS1Q1Ih6fWIzDLo/DlKYvwrd0fKwx6ovZwq
0xSZgLaMmCfvvyEIjB5JkWudgNLh9NdDrz6gpiK6TC5wHA/UhSdjbBqwSWDR
8nI5ifJqLeGPh1/j3MmrPJwU39Y88z8UdbAD71uuP1cfZsH55OJgQEoPlF1i
0v0LR1H+9PZD96hejH509PlSMQ5eev3NhvMf0Gb0TkV1fhSjZKir++VuyKr+
DnvQSenXfOUyFccGiGsHGNc8Y+KQvd6x5JAGRKmeDEqSJRAcxKP/1rUJTD3+
+rhYCs87tY5ek6AhrcRQM3MFieSUSBX/1d2gDWks51YdRVwWq954Jx31TO6s
Rh8WpIOnJM1KH4Mzuy1/LzUPC/IcSoQfMlCZK2Vn6jSCGw669GNd1zF+mLtB
6AQJnWnlxLd/C+F7f0HMuoLic+r0RbO/zbgmq37vlvEYdG48kJ64SfmZr3S+
dzlMfDyeZD6p0o9LGZpRRAKF/y1bzWe0YhG7y+TsbksSvSpRi3XfG8GvXlz2
bgeF55yOLRuflyO32bhJbx+JGzm5p83n74CxN1fS5ySl725iJWbcJdhMtNvP
XSHg0OismCRO+QGdxWbZ1lHcYKXpiYWVoUjcj+fuHQpPFs9binmSoMT9c8OI
HwnHw0GNk1VtUHKPcNURHoeaRuLrynjqfvj/1Ekvm8JkR/LAmz8FKMfwnnYl
qj4+zk+mqjnI49w2L76JhGLrqcqTdxlwKLTkv5I7Bsk//zLXGNWgJEP68mFK
f0azS9q2evdgTfUHXuaXCdzoXVe2YrYdB1P+Xvq9dRzKK4NoOfzDcFp162rm
h0lYrSTMYsOCMPtWYH7KloTJyfVKsYwacHIgiTucRMjTozpcLh9A92++bJXF
RPrtlyf8j+QjmEPRe8aTWm84MXPePBx7rprFCVB+w+iKavCKCzRULsRHL1sk
oLA6YddAVR2uJJXd456n9J5bcv0Zn0H8epbXPbfIQoJ5nrSPeB90eSNEr6oS
CFC8YWI2/gG8Z2mmmXMTCHIdzXDr7IL7eo+GCwcn0CsXHKzu8QGrd+Y+jGwh
IHbPcnIg+D2GT5Vsi6L4vWWN/hfBW3Ss+scnOhBK+RX3s0G2K57CxPzxvLId
CcFAeQmuT/Xo947lIu6PQ7fnDx9R2wlJRcmM44GUn3v9wdaMg46pvMpn7DQW
llcKba9R6ARbW5y0Z90ExtfcdjIT7cfbLaeWsn5OoIUMf8wlTYNaM56PMih/
k35fb3HmEF7GVpyWofDccHB6SXNaM/JCXqTf6pgAt5d8S15FNzTzDElxBcq/
+vz0fmfSibZbbGlXOCj/8iO8wu8ulT+iO919Kb9RYHV7/yd+GjgNflb9p0BA
ls7nYy/XjSV0ec+q75R+hYs9KJWmI6Xih77b8zH0eozfSc94h+yfZXGcq0n0
tG7oE07vRaEJZ8f00Bhcvw45KB9g4KnbXoKreBRWt8V78zLewKZXq1vgGolz
bj2arvVv0Z8z4CFL+T+2eVpESeQ5zNEyeUYo/t1968bju78LV3JF7Cp5p5C3
L1HOZYGGX7QYk6UbWHBtqOIKTKDjYd9eIxvKvzJHS107VHvQ5Lm5xvoCCzPO
1970DXSjTGA8rd52HGI2eRXCicUQ2uEfWXKOhaLYcmVHuXT8lWr1S6T8H+eP
yxJXSysR3qZylP8KicX/Pg8IBlZjjfaBj+1U3mE7IfL5cJstrihwjc5R9f3w
FfJ6rdmC7owYncUMKi+ondPPYnWhcaMJ/f49Ai7iB+qU9nbg0JPRWemN1HnF
m/XvX2jDi5TsPfpRY0gyv7J6zbIulE3aJO5gMiE4+VvBO78NobXLc77KE0id
a3V+FNcExv7yd9VSJCSLhLdYSNBhs7lT9u4Xql+rXxsVelzDOQtSJ9OBxH9F
Yw1KLn3IbCpcGnyTBYfRExrbVAdQsuj+w1mHgJ7X60VyaTP4PbTvGuRR58n0
mdqkkYCC78nyXhcp/2AXJrH2dz7OBSmSCutI9HeuPOMU1wmT0PWl3KIE0jVt
SzP9mjAzGpTO/43A6pacJcVHKX2gWbt2VzPx/vTRrfRl3QhfqS3ydwMBr/Nr
dD1XFsKtJJO5x5e6z1LzgbLkLsRpaS9UmFH5OPAsvXpZA+zuf2ZI7RxDkb9n
WqFWFbbL9Sfqfieg8eaAkFlOK9QauJ/lU/N8yfiF3O/1DOgvpKr9YxtHemuR
xSazLoTGVKRKjhD4PGwo/eXZMIaDde8HRPVBLvaUZaFcF5pGTI8YLR+HQQu7
ta89he87+YY+VP1G6sLjy/jew9fPO/bTGIFzobWC6r6NyDx95tMLEQJSbh+3
VXtQ38Ofv2I+Q3jwsLX46ksGXBcUd3DojyDY3qBimJGPxKNSjxSofHPmCCvG
mMoLi3Zh40sofHbLfxNJPtkCbmtDW80REjUqNxJfb62EyhMzV2lKf8Sr1+++
KtCHZKfvHSqSFF8fWGaejmmEa78Dh8YaEm4ODp+nbYaQfzBELKaWhZ2n/ztC
1HbBKDrNzvwFgdvM5pcp7bVI3OCXf5OT8s+uFRH8Ck0gJ1UfWryi/OT2p/F6
7XdxvXyr9iSVJ2t+q4xvZyvH7Qbf/d71VP7d+OSfiGI3CgxUCuQ3slCwIufL
0oBWeO64ImPXQ+nXT80ZfY4IPFqnVzhN5Q270AyVaGUGAn0FsjmkCMSLPrme
+qkTC8t+7NlMMkGXzVKUOJ0JUWGhzyYUP4LbNTQ+2UZjnR55fpjCZ7rMgzXk
PTrY1QVdQ/ezsDhkFbrjVC8MOV4p+fycRO8yXu50xVK4mXbFJbKTmDb1Jfb2
9cDOSvSpwWFq3qs2Se4YKkKQo0CqApWfXp8nKn2GusAmMxTxSJqFO7L5Dfts
GVg6p7CvWWwUDQ5D3ny32nG90iOkL5oFI+E+eznVZrilr5DXpvKZTVCkbsXr
LtyTT+I4KjsKNrrAwHvxGpSunUv2oPJAb49/7aVLBeg69EaRe57AqBapGHs2
CbsOc5yfo/R/u2bWR2GPTuyv7ft8LJkFneo479TmNmgIDdVF1Y/BIWoxT2Zb
EYx77/y9N03N1/mfCu3+BbgzPeW7hZ+EhWmAsWf7AAIHPAsyhz6ioH+x7kta
Idae4Hw1N0Pgn/EZA5rfANp+e9n3dpHoS8o+9PkIxS/nRMH0rSys53h1zjGx
Ewe3nRv1ovpVGiDeU321Gxt35YeLdxI4lvf9UlxdN5o+Vdp+yydxaGn5g85r
b/FyJolzaiXlxw+wL9n2JxzV/rmbdlL+PF3vzPSUdjf+jXisekD5oWT3F6zO
xAGQvUqD8/WjlC823SyqwcAneeMFHTYC9NI50T1G+TAiDKYdU6h5/KKjTFMv
F6VKntmvzlH4Mdvsuvx5GuZdJrTyT5Pw/HszVm8TNX9ETp1eq8gCw+vy49Mr
a6iclnx/UJvKO0Z1ad2zHxDnmcVfqzwJTdeY4jGrXipnXcz47DeJTOU+TyGf
FrRqCr0XNSSgczdds+lrI9a0JERU2RG4bjY7Mu/Uj/VfDr8XrJ7AYOVisEFD
CwJOxjWqz1D367ypz2ZHA45WLqvLSCPB76vtasdB+buFdVb5bQS+fF77jm7e
g8xVwQafA8ewdThE+2YZA+yJ4TX51yegcJntH++xZrTtkeqN/86E1cynCO+E
WlT55WpfcKL4JLJr9ptdOyJz8aNakIXIsKaIB387oRn2x1chgNrPa/+6Zfod
cP8nHN/3kYTYktbrejNNuBsVtzYwiIXJEp9q0+xCBN4zPUfIUft9KWWcIhMh
uFN1XJ3ikwOdKzCiuAM+h54+qaP0mGHZYCLW1I1a8pT64LMJnCxuHVmR0Iq9
Y/dTU6j+39jhzlPPXYXKHZVZ27RITFlW+rKP9qGLfXgVd/xHaOSd9H33uwL+
YfEdXj8JRLBCQ5an1COO13wHLZZFPc95I8tTiYbqvRuni1lYlU/bILKhF1uU
uSzpeuPobTyZNqxEh9fC8OXmRhJh4yceFWUMYsOdiKitbmNgazmc6ux7Cm5h
p70HKH+ybyNH/vHQJjiJL33gIspEw9WquOmZZjw8mzm3+s04vskxiuNT68Fx
PVSQez0Jd9vdux9Q+r8z02nsiDs1Pyvt9r/KGMLaXbk64sdHUG43Ui9HZyBj
Xnqak8rXR94xSyaT+9Gw0lnAk5tEqKulxMVPQ/i8/HvajD2Vz6teDaoKNsN4
QmfXMC+B/wEdoevj
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81dkbtkZDzEhMiWgbpNxMi6V6JFmiZMhISsMVMcnaolHEkCypbpab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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41Wkbx5FCKadRGJJjSSXbmIaxflMIkxkhjKwnSy69JDpEiWSLjiVJ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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lXkbxk8zRGVJcxRtw5ul7CGvqcw1jBQlKqTo0CFJRLKUyVJJkoSK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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3cg1P//R4UiTWSUVSKVCAn1UCnJyGohoyHtqKyQkQoVJfFBtpCRvbL3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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx1UzKhUi+5pkKaJImManhSaRLCVJFCqDQjOVGiSMkBlMaTEY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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41Wkbx8/I3osUImQZgyxFUxOpvmgTUyFTKiLVUCEaJilEIxqhRSRb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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs8lGkfxieHpUha29u0sp2jIsnYFda1qsVKGxvCymFeyjGxnSiSQ4UU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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VH0bxseSJZJQRCs9tFmytXm6JKESQhKyFEKWCiWVKNRTERJZEokk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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41ekbxmkkRVHnNCWmpLGUUakYS7lNYZTIlpYpilPSYufSLpMlCXNC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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs81OkbZWVtTal1KYVI5VZki5aUw5SElZq1LrlWbCTXDBXrUqEkqcTY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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwdlns4Vekex3eNnEIN06TIuOyaRicpDQ3JfEPCQ3FMDTluI5SSUm6VW9oJ
I2JQ4zYuIZHSLoVdtrt2233b2JTiXRUphmpEcd7OH+tZz3re531+6/1+P9/v
Whrux+w8F7JYrFR6fbnPDGbpd4+IkbRX2UnRmcH0i/lb82/vIaLq4pGoQwRS
C2adClX7YRCssvjjI7rOq3RPmqrEyazQbjVvApGD0cgF5wF8zA/3sXvJgFe1
dMOH4U7cnz55a6MUg3Y3qwM+4e3w8n24LrmYYHOR5+xLmTuo//TPSTcvAsc0
w6JNyr0YC4j2SX5NEFHb55dtEQFhi6aLiSuBn/nm9zOpXdDR09j2QIHB4ozC
7Rtyudg5Y35Bhe5nh/nnlzs2IZdxUq6IIXB4FxJ7k92Mjb8fzTGPI3iYk7z8
oEMNFmoM+diFE7DufqsTsrsD5fq6WoGVBO6TLKf06HYsmkyfCL5N57cGXEo1
ToG6ctj+O3T+4jQl419sJFibP7tp0JUBS3FMruiMC7Y5uBzUoetyxf/K/FGn
D9evD2vUqTHotffs97NpQvcxdVnLVILvRgrqc9i1eCD4zWNnIIF5YOJSYigB
/1WYYoYeA/8TuZ1X9FsgF35XsOkvgixr07irVTy85Y1ndvsQbL94ZE7s+AQy
+qdHU39mwC75aCSsFMNs50EZ840MjltbvqheXoLSkQIJ6wBBvVb9UYPzNVB7
/nqJF5235fk2B+FoBzLcHtt491D9455sMfIUoFL8LrowhUBTMLPk0jD1MyBR
4+vDBMQj7o1R3AACKndxXJ4zUHyyJshMtQ4l8aMZhiEENsVhQT4ydSB/W+SK
fAk4MYP+O/+pQd3U+oVRpwh+HZf391jYCrWe6bXXqN9uns16WTdyUHBzWL3Y
jSApRzpY4WsRGg/2ac3UEagX31MS9SQhe4e+aRTV08x8d/e43AAe6G8WSd1j
MHHpSKBhYDYsHBuebqf7Weu4+awBMSLevP/NgZ6n5ZXsuQ9enag19ngoGiA4
MZz2yHa8CydF8etiRATHZxeuXr6vGoeuLluaF0D3H6/XY3xqkGRsOysfSmDL
l4xu9W/CeGZaQhf1i1VsqxvUUA7Jh+tPVlD+Wd5sosMRQmF9Yokf9SdY0yOn
fWsNdtrtCfMPInCKfHqXbOODzdt0q5HqIVM2ppjJ7oVd9zWjI0oMBEYBtQMy
ndBnkkO30/Nq3ZYr7NjEQ55YtqrjOMEq60vTCRAg6ETPpRLK52SozLpXnHaQ
28Krk2UExuwx0y1CAU77GibnUL8izjp7JhxyR1Iyv/ULf9YOIRWx/QOIFGjN
TV5iMPXOOKG+sxO9t3rFa4UEueoCV58ztbjd5jzedJIgNd/S31iqHdoyyvPL
CqjftlmTYxdbENXYfr0uk6A5mG9V9FUDYucV3ujFEvifklaJ7GxEVKS5XdlZ
qoepq6pvTiS+K/OZNaPzWWUuimOp4cir/mS0gz5r/d2ko5EmwoIzje6nWghC
rq1PtA7hozwy9CCf8nirY99a77GryP3WVlflN4KMUWOvQfMepLmeHkxh0/xs
YPaP77oPL/eK1UpU/4ndKFLYWALR74GcrynfPFbA39q9Hbj5+eYKW+qvY4BM
O8e0B7kDfk+HDRnsUPSwDLPjgiMlf265J8HhpHQzvfx2qIEbd7aCoHeMmdIY
rMN9nxPxSpRX6wPPWv+0eQzJjIWLZh7Ne7ydgeuOLuRNcCXllC9eE/uHwuMC
iIciVU2oHnJLSg4pWeXBYkQrM4vy2C6IsxzVK4GK9oPCWHfKW/Om0df3bmOf
ber8Qw+CEmnLU4Ib7fgg292iTf3UfzatmfOuASEmzirsKJqPkZbtGTrlOLpP
Do++8KYaVZC3IQ0pybFHmC/9MyQwLvCqhtjI/H0p7dt35TI/7PpeDEmVlNkv
cgycqh04Q4/74B3h3Oe0lwH3vobQabwDdo7LDOSvEWSXzzUcf3Ebzuc77hhQ
PfZGusUKYutxb8jBqvkMze8nM8V51U6s7FmTWvOM4PSB1HL98W5MpKgWfTVH
MCNxaPnlfC0m++wVM2l+3iau0NZ8KcFi/r97HB0YvF2SVdpnz0e3LpvrTP19
+6lYpyinGwdO55lcnCaIjjDrDDKrAHvrC3mG9kvy8+mL3396hInTXG5bJAE/
lSWal/wJ5fjZ2I+uX/p/uHNZ8w2YxOh8w6V6av6ga+McXwNeQMdLaZqXHf3P
FfosBdD+zmb7P9F0ntOClMsJ3bi/yoKzchX93hz2+xhzuRkvm9K5aucI7Bdx
vNIzJfjAl1Yf4DHQJKOPtaMaUFu2tfonqj9fPfvClmdtGEhJ7Zq4Svtxd25f
nH8fZP90TB49zKDxeUrbnHovFIJlhyJ3Mnh1zUM2aX8ZriqpWa6h/gZHBf1Y
uLION4s1ehrp+/ByP5wKJCLwJhJmY6YIwgI0VswsboBVa/QeG/o+Lv8tNV44
1YK5DBNfS8rb0F+feXuuiOAfaRZSTPuh102n9rF9Fbpa64rjaZ/sZxin+TYx
SqUyGssXUb6tl4XFCFtR6s7R0rxDIF+xa0qtnfbLNyOkcJ7A4u4qqc2V/ShI
np0uTWEQV8LpXVnThnPS99Y8LCR4tvrEH7equHAI3SL6nfKWW5vTE36qFdn2
i5bO03xEGJZC+MYf44rs9J+oHwZ1nLZm1hPs8+rXmuyk8wftlYfeX4dV/tLJ
ZdSf2ittRY1bxOCYXEv4g+qfsfl772fZEjhvu3llvTuDOfNtQ3t1u1BzIeKG
1xCBZ9pY44W6foyt6Jj2vc/gWFqYqfP6LqQVeDWMSDOI+NXNdXNpNPg/h7fY
0fmt1Uv3xl0QQdfQ/pDNS+q/rXDqc8MVdOjEpAvp+kyCtLphei/e3qjgyBnQ
/5PcRz45D4Q4UhYvO0L7Ush9X2R+sQduNnWfd6kycJsJbVjcW4v3M7uj0mh/
t5sdG7N62oDU3F1FYsqjvK/GXPjlu/A4LzmZeJBAJ/GR7/IFXfDuLN3jxSf4
1u7pG8WSajhdfvf0rB/BwM/O3q8VajDEO2yqQvMRofEfeytLd9hObfh/P/8P
KwrXZA==
       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k0VP8bx22VrcUuiVBEQkUovEVpL6mQhIpCylLWdqRUhK8kSUJCytJi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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs8VPkbx6eySutSpNiMy27bWjLZlMXSh6JcSgqR2066KWkXUaQlqVRC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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns4ldkbJVSTInIrFKUYJArjNpZynakotyQ0zsQoEg3dFDIjJwkhl0gy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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8Vekfx/nVWCLKXqloMOqqrsjUUJ8oJgwZezMqSwklKVS0aKxFRVFI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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3cgle0bPoo0KNRX9KUolBESUqpLJELKKNqiz0yRlJXISihERiWprJCZ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41dkfxyUVmiQko5iuilJmCDfF/N4qGVvTWEYmhUxJClmKpEhlC1kK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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs4lVkbxrdESChla5CRKHTQIFKXG8mIlBxSkpEkqhFNySmRHCJGUYQk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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lWkbN+1SkaRkIkb1USRENfhRJ9SYxjRUM9nKUupYs2dL0glZMh0y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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3lYTe3bhuv1o0iJBkUqzYQIJcWVkNCEKDQpKklSGYqSJuVNoyFNKjTJ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk4lXkfxu3RgjkjLaNNGTKKGmSbbiJLYaRCKLKHlBLGy2QruxYuIyEk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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk41Vkfv0KUJSWRStYaLZQtTfhYSllDM2OJIVmKurb2URRetDB6K5eM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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk81PkflqRDlkibxraS7eIntFlH9SjtlpxdsrGRo1wxKqWWFHJEUtGo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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3cglf0bxkWppIkivaEk2aMyUpe8vUJFVkNWsiIZSdKShCKjiBBSSUj2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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnlYjekfxjspkaaEksRgSJqhaRGGcSsqSqRS0jKlhBapaRNxtGgRkiSl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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk81Okfn2RTUmG1FuWolKtdWkIjb6KiVVLa3IayzlBUzlb9bEQnSUKO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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk81ekX5jaKoUVGdWdiRGWkLGUvHqlkJEpCo2ZKliiXMEWllIgryTJR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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VO8bxilFkpREFAlFZSmRpO4UklCREL6IKCSioiQ7ZSlCJUrSYivJ
vmQIY9/Hvs3MmbG2KBWRfuf311xznes6532f537u+/NInrtsdH4JBwfHf5wc
HP//FX283yS9IAf7eErOf7IkMPKG7VwamAERpY/Sav8RqAv1uVLs0wizTSXB
lw8QSNbO9/0s8A4jbii4ZUKA8JbbNm7Qjr9HD6fz7WFBTmhatHFLOdT2vVPl
fs9EarzXgy8pdZB2j0zgzSQge773Ei42wMvuk82hfUw8+nuoU06xCBd6fAee
XiBg86Yxw0a/F7Iqf00OvZ3Au6NVNT0+3VDN4ZAdCmDi+3u9qhNqfXCQySWK
uJnYfE18s3NOJT6aGcfrFBHQSf5t4hfXAf7lI4khG0bgNFyw8VN5Iby82g0P
CRK4lGZ30L2jEFPVZ1Y0+pDnN3ltOyPdDd7CAGP78DFwJK8/WHZMCwFhUnm6
1gSieKwolb+aYfnyXdm570wYGrjpzbf34tHv+67DsqPYLedw4Eh7F/gT2ruO
8zGxMCOqafOIisogjUpDWSbkd/hyb6jpRP6agxJ89cNQ2qQi45ZfB/dau7NH
9xK4EL3ElntdD+6qy5yq6CVQ9eApV1hlA3JTpFwdzVmYmpSk12S0Y4+HxdKV
YyPQHfobxxDogsYTSfnXN9nQ516i6ChMnj+6gffck3Gsv+nZMZbagQnGjuhm
jWFI38s7X+BNgdPT8rrvx1lYXs5/y49WCcqf1nNcb5h4K7xX3PRFKyKa/Qf7
xZjwKku9WSaTg6sX1O9e30Zg46XpJ7XjzXhYXqOiVMVACz3x3/Ohdjhff2aS
9ZMFLgede/QfVJhdK4kvG2FBQb7gz0BaGxZmp5u47hHw0kpXU7lZhMg9HnG5
EgT+Bcxc+erQA6MDqeoHEsdQOO2x++WyUlz1SzopEM5E8OmTsx/CB8DZvOXN
+1wC+bn5f5aXfkKyUNypdkMmvuXXbbmm9A66maqLbBqBxFd8c/9V1CPlS/op
6UICluFnDX5faEOfcM3KE2/YUMhhpwralyJ9beYV8VQC1crGtuvf9kEsc8cT
aTMGEo2kRPTZdXBdqTMT94SFkSDhRx/l0xBqt89O3Yrsz/jM2sXYdsScFI8u
N2Ij2V+LpzcoDozwv5cTHAnwygxt4fpUhR19T9z4wlnY2uRlP59ExTxdxzT7
J4FXTqeJ4X80aDVU3Mk0oONpeJu36Vwb7ucezG+mMuGXGNulkF2MzRG0gKBk
Ag5DV+ZtXwwgqm+tkN1PNjhknrkNTjnCxntGZiWpx1Kj/HWrb3bCRCidlp3J
gk2aTm8+IxWZWj3bfpPz6nLv8J6rRTT88d1CPy1GR2N+nVjPBhqMXENV2iqZ
OGR3/LbumTQsTjW97TQkoFgVvkpnnor6bovdH8yYcMz458+078SSGAE79QIW
7J3C7N7+bEbr3ogX2doEuC349ESYAzAtfDj0tI4NEZcVncb5n3Bzz6Mi4Tkm
jHo0Eq/otkE/vaJ1rRsbn/YXDjFf0RA1zt/1SHAUluarTjodTUc7X9RcN/m+
b0wPKXW9fPhx3j5/kpyvC+rRyw1+DmDG50akzq9JTKUmdFlof0Ls+aBbnseZ
uB+29t2xJZ/gE7Dn+e9J0g90kwMjUyrgnzdxcYDs14ePTZfzzvfiw4olm5l8
ZP3Ehi97zTjgJNl4KlmfnWFm0cwtPbAvmNUuecLAeNbHJ9Ki7ZDikdW66clG
56mgnX8KajF732WtchEDfqpn2yTOeuPRpF1BGvl+ffUymYdm2ThzVTjxlw2B
TO/u61mpVMxk0wZu/SX7cen5ZIz1WbQbBdqeIPuVXDBp6O/8ASOWuWmxcgQ2
n7l/NXi8Gkm2y5rvlDJQSHflFC4sQePXg8sOnCSwVX63QaMCFa6Hha5N/mJC
YJuVYcqbcmyq9I61ukvgUK/EQcX+LBycvbh9gNRf1+4qGxXDaoTPrFKU5mIh
/XC12l+ZblSn+MVVDxHguNg6vXi3AVXRxw+N5xMok1OLsKzqAM2Ay9fGmoUr
Oz0abEY7cOtsBf70j2FF/arOYIVs/AwQ2re6moDAloEQNYlCuMiqPpebIfsb
/EOBa08F7lnrmecGE6C0PHgqcPsJzHmcs0rJ8wyotOrMFRfjWvHAUuYcgVTu
hapLGc3wCdUJCeInoCuuenNXZC/yLUrFT6wh6zOoMMrVkwvpHr5lAxvJfOAx
rJUb7IZhyhWTHnECNXlKen866nAkr8fAQoiFhWbZwAKFLpxjDxO6ayZxY6NF
yZB8FRYWe1+UNBJo1AhL0fxVh7gDzlOqxUxQzJSL5KhRcNFyb4kh+6GkvU/r
QlkKeAIMeEzPETD6EychR6/BEpWwu/qJTNj4Ra3M2v4KhT/2mpmSeXhSWUCr
dr4VhYK/kgS4yXzSM/2eZpoMT39b27VGBN6v/eXUfa0ToRTD8zzBdGQ1aMq5
rhsEclXj5brZGOHflUTv6MI+h7ytomQ+2ueskb37sAXF8eqrdssxMJb4xl0v
thuTQrqExCE2Xn+y4/b4S4N4Bg9N5tQojna9Lkg7PIC7c+sDHcg8e1BHFY4L
6kP5XcuVQwajUF8abUoT7UK+qfKl2wcYoPyTfaVxNQqDx7ZyFJF6pY/pDD3e
04GpgeURjP5BNPLoS1Nrq1EuVc5x8jATVQu+Dkl6VMR/+HlJcQULfsZjZaFE
LrwF6P9Uo8h61VNjjBhUTP23fvtGcn5m6RfzFya74WPmPSggOATK9P3h6esZ
+N53NrSfrCdf09EdxTcbYHPLI1yzhI0Zz+pEP2oTfM//eBflw0TAnPa2juyP
2CHaHXPTlYD6rkzrfpdO3Pny8+VeMm+U8p3z1u97DSGt5KNLIwhYW/q/9gnt
Qu5RtyipCSZWR+DTCvFuxHTmiOUbj2OWnWhCD+xEpfL3JJnCQShpmZ7ifVgG
3l0rHtQrkfOquiUvcqQTu7pqLbYI0tGa4PD4xokqqP1uZT0j54nyNi7GtK0D
FBmBqI+5DJxTNdBYp9MFkym3yyFFdEz0IKfraDeSXp7bsrdhCD7UyohKjUo8
X7zzu8Wcjc2cxU5Ecxsssok1jpUMHPpRFLUsKgp3volS/O0IBGmeEh/eWYW3
6XwOFhdZYMzkZ+REUqCqpNgpEkTgdKMI7/k1Pdj+XFX2XjILfF47FJVdauAW
dfxN8BomRCoTmnWHM5HQYBw3KklALX4XpYO3GYKFsUqbBNmonesO5NlRiT8P
GONqagQSWsL4XyS0IuEulB2k6NB9+kPqMxcFHOWS896DBLK5D/ww93gLn8qR
5LXrCHDpPd4/RGTjbErJsqFV5PMmxetx5hUwjVCZ2Ejy27fH+okvKTUIK6bd
WE5jIEyne/AkqwKKM+3TgVdZ8Im5Gz5l2YTb1qylOjFMNG+IeFzgPoD6/BZv
F5IP9mSGu0TWULDzs6rChmQmkpdS+fbrtYEnsimhm07y246ZywOcjUiIt1vm
tZvMW8dYTRWjQojL5W5mkPXL/Xm/xnlFFepWRtfqZJO8GLo012t5BSSkZTdv
4GPBUtE2ynBVDyZk9/34+28E0he3N+lubMTU0fBu1kY27J9F8zQ09EB08J51
hgULEnLeMoeyaKBKxybM2Y5CzE1A8WdJCxKTjE49cCfnWT6Gfm24B35nhjMe
2LLhN/hIXZ/pjWWWl33USb//7ambpLWuC6Wv0qRzvjDwbfmGqDKPHAxqcwYP
i5F+BlG+TZuawSjYUnmAzL8w50uNJ5Jr0ESPFZTyIv0x9ojUrf6P2H3NWF2+
kAW3Fae1h4Q60NBp6G8rOYKeVWPjTUKF4FISNyy6TmB3z0GFiZpClLG9RRJ0
CHg+bphfuNaHiJvW+4V0x7BxT4dhc1ML/izt5q26wYCnh1d29u0ylEbZSnqQ
vLvurKXcwMUq9DUMmV7VZ6L1n4ryT2safN958Gl3MHBUMCNK9WsfqvbzJ927
1gGFDTnrWpf2Y+ubkrqHjmz0sDc08/k8h8vPjQ0RpL6Slb9blacGY2Im5Yop
2R+1XLnQUqQgxsTQdcGcgPN8A+3wzm5QZq4//9JL8k1e4lxafDHUf3/8qhVC
5m9KUYXSsmaklvwuP3uRibUvJU3/1GeDiPhyL/gSgSNXv63OH36LFD4+waOe
BKTVlUYc6O3g+qKqk9tGR03mrMr8Owo6W6x7OCyYePMt4LnG6AvY7w1kOJPf
n1I+8Jot1gePTbVp/WQexdxe4Gsqb8LkHvmFNWzy/nET+hTJCmi9PbH31BIW
Du6jOl73a8f76L9PfV3H0L72RNBUehF+ut25/+I3eT/VwvodB5sRdfqfjvll
0s+UBbaczm6E/ec/6p2PWeg4+og7hTzflM5K/vy3TAT6rDgjGtKHkQ88yf3v
hnHjiUSm8g0KGIvPrvQnkXxpHx+ps+0+wo4fUV7mQKDw296/XN+zSS47cCdG
g4Bb7PyF6XX14JNcOmVL8n+2WcawhVMH0nsEL3zbxAa1+PMynme92HrjQfTT
cXL+n30Lmw2gouvld3vrFhaUuE5fbs5KQVdCzwttezJ/dR33dK4uBN/nilTd
4+T37qX/699LQekZfuNxAwJ9P2QVVi624+KVTUPa/mzohdhyHHQphZn3pKTQ
MAHv3hdWihzDyCwzlwt8Pwkzkb6ghwVUNHZ5btgiSOax1Cv+Kc1s2Kxzd2pq
I1C550gB7WUFzqjJrI+YJuCTU6E/sKIDGcLnDt2xG0Gp60KZ4MZOuKqfSDGw
IvVRovta7GI7+FKO8UYzCfjxuwbuySqD8At/YUth0l8inZPLXxcgXcj4wskM
kl9ywrt8WyswMun/6vQrBgSWOGwtet4HXBAu0vBtRdU/uZwlTXXgO+i/cSSU
Bc+4plnupCaIqR24EM8ieUiy2OB21Bt4rluzU/Q8ydvrJ60kFoug1R7CGu0h
+UT65JJB9R4o17cXso8xoHHgUscrkjdE1h9awm4fR7a/2c3okJfYbf+rck0A
eV/hdSJ7bSqgmvem7A7ph3OcqQcLuloReTwmVP4B6VfuedVvz3QgwvOMVvtt
Bl4+Mdpj/7oSshL8exNLWPj1n7iK5O1K5BiLyZ0g+e9QYVKQ4PhjODVnmE+T
+r3WSktdpd8N/XunXeVJPnm0XOozlZWPfKbLGZMK8j4Crye0+WgQ5e73WVzK
As+smXqfWwFqw09U11QSaL6zc3PP63o8cslakdLFAD2kfLa+tw/mujvVeR3o
mESv0ClnGuo0H9uHKo7jM+96K0cuGvyublJP5iT9SSIuMMq/E8sviu1COxO8
lsZmka8awS+888y/G6Sfa/K0xblRUbfVQeCqKhNiAR9dxc52wPnzwqMTwWP4
8GdUpjG2E76lmXRecn5EvocyapdXQpmqpmJ7jtRr79NFDrUWvNPkDOLnZIJH
u/m0qlcJuox/73OnkftKavJGt9EY5B6jOL79v784pR1eX0uB4TeZ+Wpynj+J
cntujO5G/K/YstwLIyR/FufoOtEQk/LycSZzmOT37ct60sswoZLX+jKTAFts
E8/+wnZU3NsUyh4eA6Xv97MdGllIucbdfjmenL8fOsPrq7NhtnjIzleGwImQ
3ue91f04fVjlRempETAkOOfntXsRZxry/rbjGAas/GhRjZVY7mVz5x+5zwwE
qj0TX1eF/A2BLYukH+cEqIbkUDvh2cbaPt04AnORUOFWiSbcrB13ebaCjcZT
m6WW8Tag0VHI2tmN7OcBsWmb/Psw270605r018adHmX2Iz0QFI7rdX1DPtc2
HVJg5ILrjON0L+mvakUnzf8cbkQtNUMo0ocFinreQnFiPVTPCrIlSL9Z0HKX
zN1fDsWkb3rHfxBoXazRibfoxD77ooWpADrSfoh7NmvRoDsvs2/5XnJf7J4a
5Sonea8obdt/SWT9XdO7BeRrEfWs0ulICqm/K573v1qTed/zPo59lY78qrGa
7MwBRNfM5cqzesHlvsv5xJVXkE0fCOI8QuCKXtxOpe0f0Jw6IG1B8sZo0Tv3
DzEdOD0enFpiSYfmLsfF4N56BJ+RLzb6SOrX6kKJ+483MJOmFVNtSX7K9mx1
/lqLWs6NFR2c5D4XaiGyge2L8CqF8FAyj+s/ruLf/q4WrLZjs+mxBMIEh/7V
7s/GkHHwI6Vr5H65aHKnz5iCxkQt4eXT5D5VW06bX6ShlJXWGUfyh2/M51LT
znrMxF9x9A0i9z3PDfr7Lano6Y9f7UH6ZQi/ZpC+ZBsmHBVusU2ZIDSDz+tl
U6G+bVbzFoMN0ZLh43b6TQiTOlYTP0b6cWXELnUfGp7X5vIvu9+Pt6wBr4lI
Gs5civm64e8oZl6WjSwfqsGI8xKM5DFRT+3M232WgjTtb6LyX5hQij1WmCaT
Cm+HTa5pJgTu1x28qvu5Ep4NJr2vSH4SYcX/x2dQgAUZL4uzAyS/frlpYVnX
AHMFxe4hU9LvYmb3iwz3wlklpFBdhEBx/ZEvBtWdcLfP7bBuG4TZ1OaJftUW
qIknVgYeH8VJ2cGM7tBO1H51FhuvHUXysOanucU8RJ6XKqw9QWAkpDJB9WEz
qmbWJztRWPB12nErkkLm5ah2kclPOsL2qj/b7tyOTVLTU/qPCXwuzjowx9+J
BFu2bguZb6fnNmtc4uzGwNuB4SGvMdhP8a7++7gG9VYOEw4vCRxe1f1hvVQX
NJMveqz8xIZb73QEd2Q91qo7Hf/aQOovQyxEQ/81rDpmX9SQeebXldV3Vf4O
4k8KWFEsCJwazbseg27MHfNyydQfhxIR9WVfaAaeizqNHjcmcF79LrfIkjqM
WnAP5u9kIkd3N8czoUYcvJHUbULuvxIF5auqunrg9XnswZfaXnBk7N9hs7oe
W0Jm/hN+TvrB+bWSn+Seo7+B9jiL9GeN0Vg5i7vd4F6yiV7ayMJdS8NYDYMa
2Gu0tYRTCdjT4dmiTAG94TJ9WwUTXOFW8Yoidbg2LFwXL86EgaZa4WudJrRQ
Yr5//kXy1Dle728/s2CU4vOOl9yvPnakRxSerUTlus8ldXNMaOwOcMvVasT8
G8mmPnEWrITdp3PM23EzJ1TekEXmp9+3/Z72tdBwufb+nh6BlNgp5wLjXiRx
DBQYk///B5CsEpg=
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk41dkfx+/PlGVsydYikdwhJSEt4t0yFRkjS5IaJGsyys+aGpJMlgpF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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwdlns81Gkbxse0SdhOzmeiRGLtLjm8uqKpHEqSU4vNOpQcN9kMS1GtFNm2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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lekbllQS0lCZn5Q9SiayptwkThMzjBpFxlZKCEVIKtnaVFO2GY4w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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8le8bx2WlUtFQKEpmUyVEfFIUQpI2QsoopULZEqFvKCOSVQoZ2WRv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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk4Vekfl0YKN6RlJJORJcrU+GWKxnySpUihVBjLUCQRYqxDISlJE9eS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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk8lWkbRpYsH1KiRcOgRGiSLF+5SFQyYgghy8kSaTJaRciak21EUhp1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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4VXkXPrlM5klRDdVU4jGh6SQzKSp65Tq+ITJIYkwql9yVyJ2SM5TJ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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c81e8bxslICwkNUcqIFEKp5JJKycjXyiwlo4hCQpJVUSpJdoXKLDuh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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81GkbxmfFG7KrVErJik0H3pLIFnUpskjlkLIlIedCWxMKUViHnCqH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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lekbxqVRKhJNUcqW7C0USeUiJSMiMpZIqSmF1AxZ0pTQVLKVRLaK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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk41fkXvmnGpBTJNpaSkRb7Mkj0KstktCiUXyV7I0laJDMoSyFLNI0k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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VH0bxoVoI0m7NUISWcru0iaVlGgnslQkWlT02JJKWlSUCuV5EAmJ
ssu+b2MWjCVj5swwopSd4j3vX+dz/jj3+dy/331d1/dWcPI67CooICBwep6A
wP+fA+LvJPde7ECyoJt+3oZ+tM+f2/77SwkkwtepLFtFYPRcQriHbRa+da+T
CpYgECxv9dVftQUWlvK1Wxo4GFGcpW1TKUVSwD8Sq1I4GBzO1u7f3grbLzvv
tXaw0NqoEHdbkI7idWH7+f92Q95erOtRARVinaPrav6ysevd57s7W6h4OrR1
VkmYhZUBPffKjDux8PyyNjU1PhixaSeynuYgQkyni8YkYPW3csLkIRPVdhTx
bBcOthjuq6xU+wyHgFR31zAC1IKFlFVb6zC1JnFcZV0fTK+Px75LooO38cX9
pzf6sI8b1SC6pxCzvnyVbYUcLHldy+pyqoJxO/3yAXkeWHsUnLwWvIFCWWNI
gjsBmZuJY8O8Vly7eaTY/mk7hkctva7W0JFpb8jYfoYL36sZbd9OM5EURtmk
+5bAxtBy3z55GnxCn4o+zyUgb/orL0M/Gvq2nZtfOhGw0b2QFHuvDhkfFm6K
6SAgULum8FbpddAFX78fcCAwb+dL7TPllTi9/PmzoGo2Di3palClvMP+R9uP
210nIJ3/wXxquhQpMwb621PY+Cyr+9W3th02vr43BNR7IevfqhZJvmt47utj
LOyHX5LIPLZjPbzNNkiu0GLDh58vQNH5gmujjfdtFnFh/Cn3neZ1OiYeH4t+
NcVC8EEZT4syKgT97/eoHuYi+0fb7dCWNpzWeXPIKqoXSuIO1rwzLYgJHu4y
y+GA0ky1Lg9IQsqPvymuxwho3AtSE1aphuTPAS0psr9+r9scv5s1yPambbJ7
xYPJ09QP6idouEy/Jathx0Vcn9d0dWA9pJ03B217zobf0H3pwM58WHQGGJdU
k/UeN+zoc6DB7VaVc+5RNgYb2cEm4w3wv7j/ze5cDsx4smaqN5l4/OZvN+UW
H6ygyC0HKJF4Efa9oP88AalBpX27kwvwbL5ySwqPA7XxKEW63Sf4nq+3rVQg
YGY7OuQ6eQPSuRLL35P302687uBmgUKccFsrGrWbQOiv9KQja+lYHxAqpz/Y
j8Ud+2au+3SjuNa0xcWXhwx1PUX7+Y2Iu713aNaeC92x89Wfj1ZBRjH3ZYUI
gYHYSmU/KyrinpwYktHlImO65lRgWA4WRe0+60Wev9mK8eMO6Xcwj/Wyw8ue
QFfpftNtlEo4HavVNrlLoD7VcqB4rBFCAhscdy3jQqDo6hYxIgJX8vyOSLoS
EA4+rjJYVAm7y1rZXD6BDLc9R3qzipEX7SHo9oMDv/8CaWKvarCr+k+OgiEH
ZeOOdxN7auEzG7xvtz6BZk2FbyVKZfCRXLO27AyBSxzdHnHJJ7jeIkXb6UYg
99jtfOeGYrTmlP7SEOOBiGo09qQycNPy7bVXOVx4Wo88NHRpgb+c6RY9OQKH
UvwfiXbE4+ddB9t2WwK3hmaGnkWQ5/P3hhx9nAW/fatmP9yiw4qiknH5fS8y
Bu7TBO+/w/CpVzNnLxMw77x4wzCaibUH80xPv2IhKE8sz62oBCWKqtNi5H1J
KnSKCIs142WSwy5mKBsv5d7HTOnVYkj8WbelZS9SppcV3NXMxMZlu/ZHHCHA
dv2uuyKMiqjv72f6/Xm4ODzOueBCQ0WjrvhJvx6kbRffbBpFweJ1b1cI5RE4
mrbrVtbhRvx8PiV30ooHv4exrhqLKMhW2Wcjr8hFt/vvC9eqWrDIROrqpB4P
T1x1ti7JL4Lxuw+PwygctMt90BGb1wbVXMeb32dYkP1ofdGnvwrzP3/8FnKH
QKHwp/Ko9S0wv8s9ParJRYz6kAvHrhyBoQfzJ/UI6CtE7pRaVIGaof6BTEkC
yWu/u02vzYTZYb5edhIBiewy+eNHE+FwUXSgljxfYy+fH16tFJidEcxcf4oL
+XPXAlUlg+Hs7Hw6+gSB9PK3kWa0VojLTqSH83shoB77niJwEPrXK5lipN84
TWf+7a6lYvxV7LnxBC4aD1I7C9924WWApZ3uei5WLvUJNt/dBsuwvGfDvQSO
H5KIb4+ux6VEb8sJKw66B0RZZflUtC8o9/hXn4Pzl3LHJpvfIciVflbcigDR
3KF5zK8VFk8exycuHIBW9pc3ge3doGg8PlPq14cA95vbub8K8DImYmz/PQIv
Bc3W2+Z/xhGx558mZQj8J29oYfCjFRe2ekWIfORD6UQLZaKHihrNeeFvwYax
Cr1soqQBC34tkTGvI2BXXK/yZ+cHOPkZe71YTWBYfG/CyrhmUF76nl7F5OBM
747mEo16PAnj9N7JJvPsBcto+bJ2fD6rq+D5jYcs9mSAcXw3mkKPFxpuZuGd
bDM7UIkCyT+82jiHPrhE/HY3EKvE06X18Ww5LvS19FfGoRNV6727Blb9QNI2
d30vfjXUXlWmfddnQ6hrnoixGRUejb5Oppt7YXXaNdHFl4FW5/yuVWe5oGcO
hijaFICQjxa+EMMF73Yqk2HeBiPZ3sEmiW4I3Mo+PEb+T8RYf4NsDwGloMPl
1uwK/FxbCkYvB2+Tn52Sti2GxOAxWR1ZAvZOzxLclWkYMkuVT6MQWKx5YYNY
aQvoZfKP3cjvD91J6kl4xUCv6HK134n9OL9ck7l5XhY2yNxxmCbz7uXT2ONz
35j4eWXxxLVnbTCIKNa9NdiK15KMig0POCjN6VqW2EZB/4fSgJvqXCTekqGc
eEhFudyyKw/q+mBmX6RgwKRgb8aEafgT0v89TkZcEGBgSKbEmLmWi1xJ91ip
tiYENVosTnlB4Hx9Z7Ja13uYvVhtlXqJQM4GOj/HpB7vZW6HqJQS8Fm0SIRi
VIGpp0OTzeFsHKW1MD09S7Erv3dxYBYH3jm0V1dmGfDYdNw+7P//4+/VXjue
hzNaGRKntLmQdusOX2RWhjrJ0d03P5B8QO/fcX9+C/5NC5kvR9aTsrewfCrQ
CIH/3sod4XJg+dJQuHqkBSf9ZtVf7+MiZbZ8lfMQHZMt9t7uRWysHDAzMyP5
pPW6wo4y0v9D5eLCFt6go35//c4McwKmXaFJmi51UM9TWds6RPJNkHR0YMBH
7JxRNqwk82QsREhJ+nwr1LY9iPl4kQt1lYf2ex3KcHjbmXi/RDYaDjQNZv2i
Q0qctlqiqx+RN6h+twpqEFDx7xybx0YH97nC0pRy0EcOaFMDuCi44Fj7U6oe
RTYW0M0i8Jbz38IFH6i4otPx9ZQkBwWK6vcCQ+g4Vs7/VXScDZHHZwyrx1uw
/dEn4++XOTj0Qq/3ZHs7DimstvYv4GDB423h1jVUbElLfBHTzkX/LOV1pFkS
2EE26gVkPpjdXdL56XwzRO54s2I/8nBhu9eITwQV9zN/tD237sPGOZ29pr41
KKEJWSXN40Fjc0nsIe92pKywe1sgy8GUkrKL7gYq1u5yvbSD14vQvccZCWQ/
KqPKlzSW8tDx4b1y4fwSPLx6//O8TwRYHoavRQqaoGsvc85/PhdKcjZsr6l2
eAy/6pm+PQAL8ZldCRQallXY6kR4cxDymeuw/FcDmsfjw35q8TCaf3WQ/r0F
T+q2GjTT2SCZQkGOeAXXifx426MElshrNO9pa8C+Nbo+FWvYmKgtFgrMbUHL
ZLld6DMOBBruejL7rOGyyTNz5jSBjwZjbb6JbbC2EpY9r8cn+XGb5o3RQsyF
HN6/M5aD/x7sqOQbdYFYmrNE92ofMs/t1BuPpqFkuNTwzFcWpLMj37htrcf8
wHWTlesJPHmvMDspU4OsVTJymwx74TetpJBm24GAB3sF1i/hQZ/JXHBMmszr
p6MnV24lUCXkdUDzywusi6au2XmY1Ieu0IudcbX44llde/Qqmd+VnxrWC8Th
UV3xZhNHAp+s7Ja6HKUiUqnGcENcN/pp5ycC6qthLja1WUaeg2qRn3NERi3G
EhRpwc1svPNzZ4UsLIXL65Wsec4EHD2MH+v8VwBNoYKSH084MLq8fUd+VjdO
bpSOuhbTg4Ya08UfSP73uOJ/4vU+kkeUv6jx+xhgdh9MpZK8nz8Zc2SJeQ40
J906g0h/Uf35s2veHBW2nGvPz6ZzwPQprHLzKobu8BLarQsE0iI/GuahGb+N
vpXHcrlI1lheVR6UA37uJYJQJHnk17H1BlvasI0mrvvdph9cMx/vxxtrUW1i
K2RYwYGPrx7/qmY+InLiBKfIeS5p8fqts5aBYYqLZpA9G/JOlsYOe6Lgp2pH
O0zyVr5WeM/dtjZ4zp4OOkfyn7VOdlLIzTaYux2zsyP7DSaajC7eLIeutJOg
D8lTnk+XUjNdGehI76vKJPUdapVVIRZXjmx2qqiQJxfDE3ouA1tLoexmxhjx
4sDx94iHjUsszEX0rst6kPze4fXEcagI4sKp+acyCPwJIexrRdpgZ262fI90
H5Q9nBOW7inDM0/jFdvMyPlf5vUigP8OC4eNzkupE7hTpt4UT/LX64mK9lwL
AhZ5or13+aX4xnp+/CzZ7796qwyMg+jYoXr24idfPl5TW7cUJrcjJj6mRaue
j4EIR8GkYhqmdJr+Mi/x4CR+W27QqBP12lVV1FV9kPTO3WcZz0BG3pKKvzcI
pJQoPlh4qBNCV9kevkYErjP8mwNbmOBd+ng590oPVg/bU+k7v0ItfE1dL8GB
3jqmTNbGBsgSqWMLPveihhnhFVVdBHkJ2nkfYZIHJLq8/6W2gd81yVI27kNJ
kszknh+ZePZibOb8RXKeLVLKex92ITIs0c0thg/ByLhBrcJ2ch+oG4zaxUP/
4/uOf04lYsWVMrm7pH6fyK4qi8wohb3y0+BH5D44NndnR5E+AwY+zBxLxX4s
iD60Or2dCalV+jkP1w2ibv4j0fioTqQpVo7zzFohe4SgWRrTcb3ORr81iQ1K
1B32/VcfkD+nv6iO5Ot5Z2l31hAUCCWKrsk04CChRfDiG+kqFOYeavEU6MMq
xZLnog9IPzjsOFlK6tFDYU7NfFc7HNMdU1NO9SNoQXqcSQ0TGh9T7sV1DMAz
qNurKq0Lig8MV08d7sXxTC1D2sUGhDRMhI478rBoZGngwCYmAjzXL9WLY+OF
5Y3NBiNtqNCRC/3OI/MC56wU31KQSp3qFDXn4V1rvqJiEQMnV2gs2BrOw66J
7Veq88swX1Oz7ugOAgmN8doHPtVDecArM7OVjdPWfTLFVY1IyXat+aDMwTTJ
V7kbKIiYPse/6MZF/vfcSC0KA5E196YGyTwblj7wPL2HDqVJpYxa0n8KIpIK
7c1poKU72Z5q6MEmq7Nl6W5l2CXUHz9Wy4HpI+OsZMNaeM86K54h+XOTe1VY
hk4LBmKumswtIv10nkB2bjBZv3BX0v1FvdBPnk5cJvYF4dZN3Y/eEfi8wirj
9cRXaBNFt490kTyiazKpqJeBiueXf9qQ+/WWb9luBlKJIIwONiYeIPUhEqmz
4loCVvQ//ugMAuNFRoO/LZlQH5/pOGrBRuygw09+RAfYo2nH24RIvaqIrYkl
zydt0eW/1225qImRWN30kwF2bNaMLjlPEuoLr+aHfMXq5VraNju4GB25FZw4
koMUvXNzkTcJrBFz485daoawqp6dD5lfU1dqo8qTyyDTek98rzcX1hvOmbdr
lyM3VWU8mpwfeZpXg8mFUjxueuVH9yPgvSaDUuPCxD0tHffRfHLeb7D1l23J
Rfo1k/0LST1r9yjnbF7TAMmm1VFjy7mQupwQrLqiAX+iQ5Xk1vUh1yxp+vtU
Fu4GnDUvIfcBddmEpNun6sBrs7XjGZB6cG2NHUmMxfBqy62xNgReeFk/OBPU
AR+1iJdunTw4jh21+TYQDBH/XSsukfmwReiPQ2twHur2MtXzhch6iaVfjyl3
gDtSpBZ+hoWH0fNrGR109NVJOzdY8zCSnCNz0pGBsxcGHv1ZyMGf8YOFJ9Mp
2MrbKN2iSurdqLPALL8WPw4cC91C5puaR5P1HjsmiImDExsCWYhxivFTDOtE
dZj2I7HiXtR52yYE8FvxIu3rgNI5FvKJPQ+C0krxRKludKEWAdpmI/66ViYs
V4inL/6nH7xnSYzrfjVwc80X9RAm9+dAg19Vn7/ga8e+yWTSH0MYWdf969oQ
0PP5bCDJ/3tUHzd2h+Yj6mbkcg3y/tqHnFjWt5ugzdqi2SxF8k2FCyWF1N/K
pCj++ule5IuZl/aH58IjxMPZvZJAyczU2JxrHHLVnVPPHCf3T9PQn1un2/Fj
9sd/cv+wIbm680Tc4haIe3EN67X6oTFBFZoxb0WKpVaKsE4/lDwFIRXGgO5s
M3HlUi+uFlwaEMjvwDfJtP6T/v0IpoYe+XKiA+6WhrtNEgjEyFyRoP5oA5c/
OXCR5I2tOUv2To/VYaOQSLiGABumn6oELo5SIWxuklIXSs7PW9FnsZvLceDZ
WX8Hsv92/agrquKlWPG5hHIllItZ/jUrlmkb7uV7HJOzZqH5A2VEwZKBtftO
eBHb+yC9SD7Aa1E1knnXtL8s4OJ6+8Y75cW1sExbanCqoheZv+b+nmik4OgO
s5j4EB6ZlwK5gktaQQ06L9t3mANpETqrntOCip1CB1cLcbFWvPqQcUYHjraH
BQ2+7IJEtdKIkUIxpC1G1yq/4SDS/6z3AdF6TL7hu+sbcTAcX2exRqEK7zY+
j64j9/O7zuv2F85QMXqDlVBj1Yds0d7+JNJvWNaTo+tJvt3TGjTJn6BBqn3W
xiubzLtvS7tvHWjDSRXijSiPnN9rx7edUshF8R+fT//UcZGqOh29nEXDcKP3
UZumXsSZRgdFv4zEyQ21py3I/I8TfyiXspEBYR/d5dLL2KBHzJWevNeAqqvu
6Xu8CRi6u/6rvYaKa1smCrev5iBjdOVKeVJvQUuiVsqR+V4s51Ge/o0BqfcX
NgkVs6B9jNv9zxcK6hnO9+YOspF6km4yb0cNlqRL8LYNcOEXk5c4MtuB6R+C
H+vEeGh5HWUcEt2Kf3JF3A8m9OFSttOnno+f4N83LbKY3J+Tm8ITvEY7Yees
pm73nYVk32OqfgkFOPVtk01yCekngw5qeXEdMJNumOm52w+X6KK9iV+ycMti
sfCOnQT+B2TmF1U=
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41dkfTqQSWUK2W5lU+MlgKPtbQqWSmH6pmJJQImuWolS0yFakLKNL
lKXsCdnJehnXUpZbcb8HkSyRqMbMd/44z3k+z3nOZ3vf533lT7lZOixdsmRJ
LH3+uxPfSvIs7f8LLxqOSVxKI0g8u65s+kIR5HwV5sIMCG4Li1b09Pbi0aei
sHuNA9A2f8/rlFYMl/3nhicuEJhGHp9/8mcX3q86Y64vOIRGq7x7beXNCAiS
21/wnsLJQ4Kv/KpKUZIVHBl+hkD82phEDPsdPM3n0sONuVgzo9ucsKMdLjNv
VWPXUqhatna7de9rVB5e/q2oj4L/x8Wtn6U6seJVpcliEBcbwmeu6JQlYTa7
szbbmiBXMS3CxuANKky8Zt5ZEPSW/QwNmH6N8RI/2/fiFB78sjPq4QEOeCVG
xJ4aDsElKnwgY7YVkr4yzG06BLfmRVcvI+XwLphXfkzPK/JIeV47ohXMGwOL
myYp7HGqMzkfV49m8Y4upyyCAJn1vN77ezE5MqcrpDUMRwmfqDixDmis4Kn/
q4oLFxvP5G8rq7H9qeOohzaBXOCkVYREDUq4o0b+uQQWB263ezkXYVvksF7c
OTq2fOl2uv4JEvlzA1fS8cSamDK/bDYmVh5ychwj2PF5lUB4UgtueUzhhSDB
Ef9coaiIDrCvvxL53zgXQV/seW6uv4z85+UKHFsC5m+Mnmcf2eDziJmQ4KEQ
JJU69iHiMliuxcWg3y3+cMozFM5B0ZioymUXghSrDVOCcf0Qjkxx3eMwjCof
75DCqARwr2Yz9p6m++/+Ejz5uAD976YtGbsJXIJ1evSn72PxUTfD7SiBQ/qI
zFHpLqjO3D7OvjqEKa+igzNh1RCT9Fdar0ZQJiTPYFF1EBdUUYhRJ2jI1oq8
eL0IPmtvXfj4g0LxWxsl3W8Z2Mmoi65zpfEQU0KpQAqYBlo6F43ofaw7q//4
MgsdO4XX8tURjJ2oUly7rx0vmteu0PchaOat9J/dwoFOez+/KY3nxaA3OgLB
HeCfly2skqMQHyoZaDfXiHqyKON6iuDjpSnN5VrVmG5K5hiuofEetbecc3sD
j4P2rxSdubDec2bdvGM5clgfvG9L0/vfSBJ+DLXCe3E4W/Y9XU97rtD8Kweh
MaNGvLeHISltc6akIQ2rPdLq79P9K19T4jPS6kCX/KLXUkOC0lKyLK65E8NJ
VzWDhrjQPNey2H6xBwFhbl33NxHYzB9s7v/ERmycwpukNJpv+h6C8QoNkDer
XmVaTaHP4vYV7ngFthrnH7MWJZgW2Gdcs7EDjXw/RQI3U5g3DfdcH90LhVaX
F6u1KSTmqMR9t+2A6NhH3tPGQ5j9VJXY/bAWtvapenNPCIzjWRkqeS0I9V3G
uMak+eJ8RzHwQCbMlqU/HHAgcBdXaZI0KMcvIrHfpkMIzlxXe62Q34bMUUO5
QycIBN2iPJgZnQi7+Wi9cw6FgWI/5gr3OjCthkM5bgS1DEWRq0c6oLT8PjvV
kIv66EWR9v1F2EGl7pWn8Xx1Tsb0ulIvAm5l/lqzn0JhfPwdVcc+xLaFaQvt
JAhKkilukekBs016rZjOIL5p2F1Mqe2GWO8X7fEKgtSVeTLu4mxEHrbs7bCi
wGcvFDLo3IJdB1YLVL6jsEOReat1eQ2iujbGqv2kUCY7/mGnQBtMHE766gUQ
HNaI5nyI64Ki/svKlWcHMT6TwQzQbUL830+VSjMJvm59wkre2oGQ7SVGOVsJ
5k9+cpE/24z3xrE5nHCCGsPwHyxNDkyTg8q/3ByBU4P/P7YPO/EsvnTj0TEK
1ksX8k7PteC8hLLxETaFzZHpbmUGDTBzCddl3qVw/s9RftfG14jv3Mn4Pk6B
KxPoH3ylF7EKD/YtpAyhqeVyiNrXd3CJNJN9G/cB6s9Ul8dmvMP92kvilyw+
QPG5s677QgWGa1RzDDwIoi7dKF53vAlkbr4wb5GA75+JRUlODzYFySffWqSw
MePrzcjDHNQnC+sx1QYgaJGjrH63Cj4J11aQYQqN98jfV6Yq8V1DMFSKS6Cp
XmyUpN4H5vmsuM/FFFTab3OyFliYqnRSyNAcQvCR/G0ilQ2YXHhpHuFFoC8X
5/yHTBfqN5fKHqD9I5crJh3+8DVcGa+M0EVQsGabUH4yzX9TWYORKApjg1Xn
LT53w1FbfdounkAyU6XGLLELqQELnl4aQ3DvZR/co52AsRpJ8x/2ND/vZjiX
D8RgKvp3W0+an+Z21x7MTvSg39Pk1kevQfwudSTXmq8VS05ctTogRiFW3kxD
P5QNBrWdV0CeghyjoHrWoRYR7uslK87S/BZeVvhINw+KkUVZB0HwUO9P1SC7
N6hN8dK4IzuEDXGN+pVGBZBqfSvoT9cr3mLKeYxazPPsqn1tRf//ZzLlhg8H
XcutNVWKaL1TV+555v0Eh4VHnTYdJNC42Jl4vaAPqhqn+09+52JgueruL133
EKFawlppR+eTeMKjtJsJt4Mmos9pvxLaXtH01KQdhRxCeWtQsBFMas4aqEU+
H9j7IggivlpLtGzpxZBdgUXmCAWFSSmPOxOtaFQzMCy/THCZnyXlLNmN/Dr/
48va6Pl3rZOPK0+DCLtyg+txgk/pvvElBtWQme1eyHUieH4znG9Srxn7gwae
fT9E4edE9BkzvjdgcBuyKzKGcOjr3Jqc0W6EijJcqfpBqGRdlBDZ3A6/sbt9
8YdpvVyf+U05OgbRJxTVt/63H/sL5pub3oLv1CEtH9o/rdVSJoNHX6KB7bbB
ktZ3/s8s6VMJHbiqs0XoD1q/dwiPQHyyDCns317ofabgfiMh0JFRg5Zrmw/x
0/tIkPw1WVG/B0HHfDRrwwYxkBfuu8LpKfjOsty3+BJsuEBO/lRowSopdV+H
X+h8nfnStlUVGGzfE/NTj45TZxB99xEc2yf2Zh0j8Ks1zrIIr8FHE8P/h7kT
sGSFRPRDG2B84odnvSXBkoTepekiXfBMmmLtleeC6Tm12/NoM5R/0+Lnp/VE
TTLd9rRfHaz8Lc7tov1/S7WTDu/3NvwuUxBiYkdBMCSJJ8f1LwRHPkg0suXC
a52oTWYxB32GZl2nOt7jXyjgre4=
       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk41dkfx2+LqCxlnxBKwtwyaDGFt6WkLFNkKeuIQhEhahBlb8HMTVOk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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4ldkfN35KWaKNxtRoEbfNUpMa4pMyTUUz3KkYWSZbUm7ETLZEQ2Rp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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VPsfxoe6tiRJSC5FtNlSSaJH9kRJkbTZci0lS0VxJcmlRUQqIXuF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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk41Vkfv1Mj0oKi9A6iZG9IljTVh5gWFIMkS9mHLNkqFVOhcCuJ0oIS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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41GsfxlGRNclBSkoIJ4okUe4U2VvsWTJoO7xZOoRKvSIHU6QFKSSD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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lXkbPhmfIRmypogGrSo1SBPupLQpIRKVfRmhhFFCJFmGOmSpQwuf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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4lI8DF8oMaSgqNKyIRAP1aRiRyKhUSLK+NI1QCkURDWUlRUYhRHZZ
2ds568zO3Xt3RkMaKPR7f3/d8z7v+7z3vu9ny9pfMnfk5uLisl3ExfX/36OJ
DSIDNz8iSPDx/rXHCXC9as57UpkMCteSkKsHCfD634zI3ZoOOcvBzS5+BNQk
9EW+9b5D1cTdR701BJpmT3yOO9yEVWVMg4zWESTW6a0vXVyNRRvNp65xE3g0
R9Hf6tQPLTvC3FiDA1qlYab1/XJovN2uv/oYATSYyd+jUBEvIHxe1p6NqtWJ
ZtxyVDgtwinrOQKXLbL5pbengn/6hf0NTwKrqz9Itbb0gWFjtuevJQNjbHU/
6oVBHH7Csu+hE+hKN3U2F2rF2OBJtUuKLASsWcjOqGvGcCHbNLmEiUrLrSb5
/dlQD4vJngwkIMhxOEH53oOjXv4dI9IE6Kw8WYFrSXDZteRKpCmBkPtqLcS1
OswsoxhpibHg4qUQWrGvCVtlE1J4PdlYKzWoa7WmC3brh/2LXzPAaBn/VOvc
iV3R/l3xEiy8l4yaulLege5u/uvG1Rys9du6SWu4Aw89A5Mr3VkoTQ4+Or2/
GcXKjC6BZQxMadc/m5XpgcI9trytCQOPBjdKDclXQMZFqLQ/nICltOzp6+09
uOl2uXFYjYHIPLaVKbMP0acUPzh9ZMPHc6W+9pFKdAWWpL+1YSEx8+OBkZBu
vHr3VlV2CwNmJ0Puadkk4PyeyY3DZwnQRutVuJ/04HhBoWdVyyj2bI+dpm6m
IdZcbtTnFYn3uphDXs7Z8CxTt7CxIKDimOQk2NAFwkriPIfOwaD94ukuo3oc
4vsa6mpHoD+phMezsBszGa96PQQZuLk0LzPg2QBsg97KHLzFgEKWZp1kXin8
bIIsBUIJHNUdS9/S1o46/Z2/Cxw4EHnu99q6vRlG63SfDOxmwilQWyy+rQpy
onl/N5wnsMvonPGlK02QOlEU6GtGgBJ7V/TZhzY0NooXhkSNYPLr976mhVoY
QCLw9xgDlSGvGj0/ZyH+hfW5zbbk9Yd/1Exuq0aqonbVKV82hHkvmvp4dsLB
oJjm10FHZuwJZ7/WJnjvFHW1XxiB5WONPTmGHfD6u59zp4aJYgGrnX/di/CY
m829Yj0Lyj1xWsypHrhPEzrdokzMtEuV/9JuBL/pueQTG8nn9dAq79KpB/NG
MXWI1EuzuTTriko3UhWmfsyXDkA4mFNaKtQEgXW/LhmcYcK6atqWj0ZD5lL7
ERv6GCZPZ8z4TVNxrjDVsNRrFCLTxG9ngw5EjKvv+dQwApl/z99LWRWiUiCt
Rn2YiQ7PzaPJqwfA03xK//EaNnQLf6+OaCiH/rMtyZvEWWD3RgkyZUtxZLNp
9MlBJpa48+kcuTGEn9wPNo385CBk4rnv9pOZEODOk5y/TOr3Xb/V4skEOFj7
6fG5E1i7/mRlhmI9qiiDlxJJfMTC6G2LbhTgTqyTlCfpD39Ec6re8OXCJKHx
qKEMgXceo5MSbjQ0R2kInvlOR2LsD6l5uzZclvbl0Xk1Cqtrxiu+bqTAuVDq
20TkKDQuS0w8SGqDusQCW86Kg32HgOC0mzD+Rx96ZE2Avy28tqSYihLzwaH9
Lwg8UBPt6JWvgs9Lf+UvVFL/g4rBp1QqwQj8wvWfJoGASWEjkVU0lLqJ36Xy
s7D3+W37H1o9SFy098qdRgK/A9am592mYS5c3baOiwWuO3GXBFqOo2m79zr9
MwQa5tfPJWrVwTw3sPigBwMyF4wCbUxjIDA9nhTpRmCUqdwo1NyJcNFnA1G+
HAhvNPvjZdMEmZfnTPaaM3ArtlHhdE0HrCz27k7sY0HpWquj7M1a9F2cpfX5
syDC/Lszp5GCr1KdqokmBBTkmDM50xQcHTvoU/yOgUP+oQf5fw5jhTRvoJXU
GFZcER46UtwFB//h30K3WaB4q9onvS8Cl4WHROAMExPnPkk9mxuErcbm/8o3
MrBLTkTKS+4D5vi3y7cWMBGyZfm29IBccOWt2G3mSyCWxmejubQLx5KlV3td
peOVd/nRtIwO3C0LEfXUY2Mho1D2fUInhOaieN+S3z/MivHvzRsq9lksXfYr
n4W1PLPfts/QkObi1ONP+gPd9yWP3NfXOHB1UweF9BeXCL01BxLq4Kp8+GAd
HxNNCu/LKWhC40TT7cxOUv8q+S8vKhZBWG/mtF4/EzIGBeqa/BG4en9UyZz8
P+qor/1BxTY8N97hkdrDhHHqoT85nEFYSMWX2y4eBGXW+0ItPRY7HmoqTZkT
yDxkKqlzpB337CTsTv5iICdhv9LfiAr0f2j45SpMIC5rrrTRlYYX5/oyBsTJ
PGgyZX0wJXUYoXgqhuSVwYM982cGOiGoyFMztZwDHR/LWzums9G56EtoXDqZ
Rzup0iki+SjP0PFQfUlAptyhQPF1M3gv7AsSOM6EUscmia/qXSjVWNkiO83E
oXkNS9O7lSgvDWuNySJg9aVtSMa4HKXyb06ok/wyqmgaOnVnAFpb4g27ye9n
xTcZUNfaDeUSoz/OLziYKdVQXmJQg9aiFvmnnUzELv5eHLeGgpZqxqzuXg7O
HBV/5jrXixXeaQ4StnTQ6qm1L093w+dE8l+5NDoCGmOY3x+8RKTHE3PHK6Q+
ZNUnjus1o6tAJ0R8MwOTm4efrb/fii/N6640rGRh3y7OrV6ddpQ75r9wN+TA
x+qxyMJIOWzX/JZ5lULA/HpeptaHDiS+M/448noEmQH6wQIDrThhdo4iCwKq
LwV0Mze1kHkmtq01gQGrFTkPd6fkQ5LQP6pC8u1zxtEjKSlZWLslzV7Sg8TD
XLN8h2g/RAomViTljCGWT19226FkrF1XYiroRMAuluJACYrA+sC9D2qsCFiP
drHlwvtR7iVumJ/PxpyuZdi9xf2I67ErWVJIw+pcteHZwXboy1s9DK0YATGa
kc/1MBXBohvpP/1J/O4ICg69GILYdnrgYRUGAt5INT0e7YX4Hv76dbdHERmv
dUU18T24uVk1J4sJRNam5ZyYaIPtpjIlh1qSX0ne3wSr2jF2e/eXB8MsROXH
xH7ToOBR+S7GNKlHy+WnhTStKbg+6rTfH2zs011IKDJ3Rl5ix7o5Mn9CRpXG
vtflYNLhy9dt+uT7nTSQXCVGQUYZH/2/clKfsZ6aJ106MF59tS4yaQg6Fzwa
HBe1QHwgYDo1gonJupCwmDxzyPVtMfw/fyITZALZ0VQ0qQutO2X2CTuj8j9V
xAwhVoyP27WWDlvhjyPXVncgNf7bl78PCSTezi/SFGpGs75Er6clAZ07T72e
SDXD88sof2wqHe/5nKOGrnZDVGmD2bpqBmhKjJiQP/nw4u0PA4lfZbrXRaGs
CsgOyEo6XiPz0MJ6qcVsCW5JngxwOMuEAmNE6unZdvgXd990uMbCg/gvx6RU
K2F+4HaJ80sm7sQV7VIKrYTDaSrl3EomGgq21s2crUOsPN9wB9n3LJ0OFHw9
8B6EfANPLtlHhb2V9Z1e90FmRw/v0EEWVmh0ne1e2Yo4/cL+n3J0ENTJhukl
9WBXjM6OkflVOSFtK6jwGLHM8XlHGwKn9u4d88rvxMc1ofJdZaNYvVxVXmGC
hp9hLRfq/djg8jhR5lZE5oFemmrvGQbo/wqmN3I6cce2v8xgfAT6C8vqX/hX
g39yScO2WSYCTsxcGtbwgoz8+JsdJJ77PsU9n6SV4nRA6o15Mk/X+TQ60nb3
4cYFPYpG7zBufBb5XRXchj9Uxw2qigTp20bVCuGdUF0RpuLnxobCzrsz+l49
SODbpT/Cz4SauDvPRelWhDc71y8n+9Hgk+SjL/9V4c63LyE2Ykx0LXtp+Ier
BT0dh0wiJgjkH/iV/YNTh+KZ6PD7MwQ0coxsek1aEFgdoXk1mAUVschnKmU9
SLFUbZsXYGH0/n9/KQ+6oeilmGjBZINaGs3rtLMK3PWLp+Y5JL/CRHmu6aei
KKpO238PgePbY/gnszqg3BuxtDqdDuM1sRU/eXpBdJal2y4bhUtde8ih17m4
qBjEpedN8sujR7si9TF0w9rS7En9jtLvT2s1F2K2MY2IkyTQfv/KZ0KvD9O0
H8te+rBQmSu+UKYQjybPHTc5JN677rGW38gcQE932sfzZG9c0chlsDu0FynK
h/nnPrAhq01ztfnWD5PDpV3tx4dxammJwIPueqQWhjwTUSP5khbhn1HVi9Si
4XeXJodwnhN8+2doHc42fSI2aJN5M++vnR/RhADeWInRfLJfV9bemRzqRDBH
bYDzgQGtk4YOtwIqkVR87mZ5LQsN/2wir0bXI2Uulen68P994vBiPf1YOM3R
hi+T+8Dzv6HPapr1uFj3N+RYGXl+RpadaF0Lr9i4txJTBF79nllaEZWHaIkP
s6kMJi5Z6brSLw8gcA9x5Db3BDRkYiYMPHvRHt24aGT7KIImR/yf69ai5959
M6l4An2PFF/wTlCgzLs2+n4RC9K/CoLVjGnoVxJbHruTjv6HIvc0b3TgZGYu
w9+FgJ/m+CM3zXb8d04hqCiLiULdJe9T3ShI4NfKTTIgoB5cc+NaRS5KQ26/
2apL7rvFajnurZ2QyDls50b2769J9aKO3N3o+2JA7zrHRPnVwD5nlV6sPX1S
eG8AgeFIXpPVfDR8SRX81/GBzHv9mQTf0tew5jGtOPicgNjlFJmKikqszU49
5DpJ9pmEK4Hf3Un/6ni+3sGdjfjhBT/TtBb0Lwqp6G5kIchdPCTKIgVvtM+H
6amSfeHM1kjlg/nY3eQ7m0r2T2tDfx+dKw1Ifp8tSnNkYbXxjeHjuyowHWKx
ZPkjAnXw2Fa5jPTndsNdH9uYGOH6Xt+4ioJBAU/9/AAW4jYkhZWINUPp573d
xzsYOHf6ucW2dxSMCf3KrMxi4XxM4ILSQBvSrVL9NyoxcUxE3U6V0o2Mpc6s
v0sIxHfINfGGU3F5i81kWxYDB9aET1G6+vD4p5PPZbIPOEnvcLb27kXm3czE
UmsWFP5sc36f00TuksHm3aSe3rqYBCUWDaBitFh/ymcI4U6SSmbRNfgcIzMk
EM4EV7Ul8zR/C7bvFXmWcYDsAzwa4iYqVLyutL9mksOAuYKe01z5MPrK8+nh
KmSeH5NQeCjYA9PTB0U3kfyN7TpGYewsgpq2fF892bdLLw+mJC2m4kJov1OI
Pgd0nlrlrnPZ+Oez3lGYPB++eDn73rECZJ1JX/OS7Bubtv3LLYjphd+Q56pf
zgz4RS8ec9lfh8e12m/3kXqKPW4n7eY2gP3c441Xbo5j5lXpt55LKfCV8fep
IflG0y1KDDnVCftSgxUzMmycr2/xNBHqhEVzaDbl/ThktCqkKj0yoN6w5VIO
2cfHpe3CKHvrIfz4b9b8E/L+K7s2WMoXYpPN4vhDrqSf+o3F1+gn4eZ1dc4n
L5KvRqseP9ncjQdePFIlhxhQu1MgxxEi+4dFuffS+wQOLFFc8bi8HSmu1y2O
yzIQrfU10vtPF9KXzIczR+gQl66Le/iuE9a045NS6RxEn+WacIyiICrOV3eq
nol9GVvUHEtq8dmDNzmzgMBc9qO5VOMKaG80olYpk33s3b39IsK9WLlTYfyg
Iwf5d5Pujxl2YWafjqSFMRuVr6fPTk5EQ0nbTTXfmYBWoek5qnQ/KqeOMwmD
UfxsaG/SIvVcWlzwpXecfN9X9Yvc3hXj8uqxJnmCzP+VOlOeHdWoWh2TtV2B
hZw7RSE/FUpwJ9N5qf4kE/EH+b3jKwrA72I88lCO3FehkW8v+ZagfUprhVks
+bwHiuzGg9pA8zor8IdrFNackggXvR5ky82kBD6jY/IPJ9fEuQvU4dwEEasR
2KVFX7s334cTLEGj0wss6LlofsxN6ULc2dTi2zdJP7a7TP0tFor1Nhd+25P9
gr/V9TsltBjr8wtEU6oIvNBLeD6unIziw6sOH91N4jX3fKlCdj8KSuz2J70e
Q2tPVmR8ZCV4H5hbBpD+HlQzURaXScWImsy22BYmKBsqdp+tbcWGewdOpCwa
AXcW9TxPfB/UWo2H2ts+IVtA5eKywVroutufiRRjgU6IXhM7VoXzZ8p7VMn8
lbO1EnAb78WYzZj4YdtPuKydU+l2lYrytzRqBdnH7WafxiSffQd7/eudoeQe
TVx49TfhfB4yr9u8FCb5LrwmeUO3XQ1eOFSx9Y6xYaGaZqZ4oROLlWKo7lIE
+AQ9zVRv9sH9sPzWkWMsfB1QeVxe3gUZo6cZf2ks6C8Z8/R174Khw5f/PKhk
P4psCAgZ+YDH8V8vS5qQ+/sCTaDEtxbf4iPVjMhjQuhbnbRJPwIHaqslokj8
3xsmqa9NRhD3tMFWkr8B3hzO+L4h/NkY6T71l4loQx5NmjcV9C4RGSq5j2R+
7a2ZpTTDqWrOfft+Jl4fO/uuxKMF9Paogz3+pL8EBe8c+9MHdsZVY51nI3BZ
L5vwqbEST4J9ksOfMjH4O1zAQawXV14eubqJysTDnS6JtzK6kKgU1Sv5lMy/
JyHdpW/LkLIg3nLrNYEjpgs7f5p1YtdQ0jcVcm/9GYj+VvCEzNv9oUtzSL+i
2H3cuWDQiptVS3402LNgHLwhXVzhHSiUIdcIcu+tOlGWyv7XiYZgfu+7GqOY
ZA7ZhJrWQSl/Ie8Hqfdv7JyzAywqriqP70i/PgyFwhdaT7cMQMjbpChvNRsy
b26XrPlUhs9nbD23ODJBtVppIKnfjTOh5gn99mzUfU3r+LhjGNk6WdGRmwkE
2Si4Ld5TDfuTPzPvLmEjRaVyhPtnF/buUcx3+TSCNIuspaIyhTDWbTT0Eyfg
O/3Af8sRCrI3BPkYVNHRkFv53E6lHntjjPjukX7Qv87hK3M1FR6/2nYxl5H7
kdsusk2JzKtVu9eESTH/v2s/mp3ux7b706JzrziwpLgeKDCsxLF9n5T537NI
v5GsrttAg8PWfTcNwjjYN1GiJ320F9NHxSf0uGiIkxaq5B+iwCk40PSUGbm/
nq5ymteshkarU0LhehL/sTX3g/LSQRfT2n/vMMkP4acXPY0bULPPmDanzobl
SpVq9po27LJ01xEj+zOXHEZ/eNYhLJ5r4zUdUq+zEdzbVvSAd35V7pA3E/8D
HKgYeQ==
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41dkfx7lpmaxjVErJkmWiojLZft4UssREiyIT2VVCCoOyp6ahIhNj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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk8ldkfx+WnKzFihrIvJaGUClH4lL3UJKaimkSJLEUjXWVmpAhJt2yR
SSJZy26S/XLJvtyrsRSe52FsoUJI+T3zx3md/77ne17n832/j7LTJRtnfj4+
vhh6/bcrPWEnfRaJQsgdlWz/ExSMthf6cWSqMKVjpZO5gsK1ffxpdh7tkJH0
s13iJ2AzLn6jQoiHXzTsFwW5/dgyP6nG1mmF0McR6XwlAoomfcMXM//G9zec
o7mXKaxV0Gi2bs5Hp7vZspYthV3bdzJ8hFvQUNT3UcifwnzXZLV5ahlsfWvG
GUoUfl47Kx1e3A63UlZd+8FBSARktFW15mOBLclnZ0DB2lEyfngiFY+57PEF
ut/1MctrhNPYmDl92FzwKAXL7rOJl36IQ4RfjHDpKQoBd8UThH18McHrm/nB
gYLYI+r3CPloqF6oFiZ+pbBFeZ4VZVuJoGPXJOQZFKhnUSlHdmdAKSH3gacL
hYYx5taNyr0Id/+8WX2kH1HUmLJpeDsWCkJPymYTeBKf6fHcPhsLBkmfm8Uo
nNJ4xNcs0oHIxtZS7R4Crvrxm++GtEIyn/CJbiPge5TRElrHw52GiJ7QAAIW
rSYzNz/woCa75VJuJIkPYg66crVdmLyXWMGwJpETF+OkcrkGKp9HtPnFKWhH
fbJvjK3Ag4MjzudsKNjti+kUauNhwnAhu2iWwHxh7LZnf1XifPP+cYl6Eqq6
N2bHCC5koBIgEkhAzaO6tHUqByLvBrZd3EHfP/BQ6d5sDoT2rNFOjybBl1Du
ki9di5wzsyUvNlH4Z+4Hvyu3X+Gx6J1/tcwo2L+SHTaLuIeGyNqEbU4UDA+o
aVwdakdp365E4VUUWLpOGtGBGUizSoh0sKDwfB/j3B8rOnFQJJYyjaagl/fZ
zpz5Gkfv3A+/+oWEVtht0y2B7TAQymHpRxFY15k32kJW40V8yGTAFgoPP+vs
3yaeDu3brmXxdhS4eStfPVziosvw9S959wbBLCGkV5fV4EXEd6/L3iSiqpb2
r+58AxtCJ+Z8O4lEH+/wVQm9ON8vkwXZAbCmuiNYl+qQvOvC6AY9uv6DMgvR
dDbC5A6XMTNJnJHVGc904qCDeVdmYyyJh0z5+sKoSpzz3d3tZ0whLGlyTFmz
HTtclPl0EgmkzJSt0K2oRfrLw17WKSRcCWOdDdweaFwI+y2FSeHpkmZDanMX
CgqMtLd9HYTBxJkMYn0Dpmvqiws1SMzUD888YHbhm3S4eBGPwIxLn4q1WwW8
1mXY87IohHyz/99A1ls0pgt2ZK0gIPdM7KlwTDW0LEK44zEkyq97+x0fakH/
hKNOtCGJRnmjyBnBbmiHWYS36pAIc6hIZJF9UFdXC4kUHILchq2p35m5OGGT
fFH9GAXOh9wd9c/rkFdrEm7dQkK7WPPhErMSU0bHdr2TpWB6VbbR1eYtGNsD
a6XqBuDXj2tBnzqgoBtz/TY9XznGKsUzcWUIU/+eusQlITe0YOj3vAOCxZrl
1aMEzjon7vcvaYPJX/EbxLpJPDkWVGv0sgwqivfTrY9QKFF0PXLtxwLcy1CJ
/Zeet6Xunul9Xj3Y+fX5hPQYCaYpWKxADhbzuDvPFpFYsBBIjndpQHnvnqLC
ahJviwtyjQV6IHo2X7TUaxADtiVyLSrvEOVt3hjX+h4HtZbvaH7owOILb4OV
voNYEA4qtGp+C0tds/tX3EikRkrwnv7JgerXMGYknX+lA3c3OTu2Ilgj5alf
PoHqrbcC/Le1oaW/bTlDlYT/Y4nTZTLNCDsqpTPeT2LCqeCUzPN2BFb4HLoh
QMCNYSD66ToH0Vuv+6/io/M/pmEp3vUG70748phNJBK8RAM6JR6h4ac/k7rO
UEiTD03uNqnCgv77cqkAet7iRlwN/HvRt5YrNUv3o71J59qcYy+0FOZr1Nf3
o+NFnIOueC/a7I83ua0dgJTmR5sE9wosGjhMP06j8PezxeMOS29h0zL8OpjO
5wFYTXjUcHE4LZsxv4NAgHzu+izTBDya05Bupt+PSLBvDxXkIVji5aeWKgJe
2cvKc8sFKDiaOXKAn8LIlKJTck4tfE9mOpbTeZK6nejsq9qIJ7s7X8+BRHfF
hVi9Eh762zqt1uWTsNaSKfe43IRvvxpI/TZJ8y9KWzXCswgJrx4Ri5o0j9Uv
bxQdbcDYnp/sGFMkQm5W7e44WwNjlytU8CQJ49MyIkLztdAaIpc9eCS8OOPn
m8wfYXF4RfJ/vGYK/Kzi/xMH0+bBllJXSRiEGabdjKkCa/PBd2yCrrdR4EKk
aSHuKhhpBZ2kIKArvzNbqhsrST2GW+V7LL95N1wy0YN2hcTramyaB+mz7Xtd
k+FB3fhyi/aHnGH2nOquSkxK39d/Okgi2OLfU3ZxbehiBWvw0e+Rtds5Jmhj
LZT0uxxL9Sl8kpAvqGT+AynHfxyqugn4W4YdEvNkw8srKvRjAon+/d0nA0s7
0GfxwMqf5sPAfumCHQ97ICB3VTTL8j38xhgz83P52HslVjjPiPabvm/1y+Yc
BPLHlKVaUpiRWiRabjXgjbXC8ZkfSVR3fguOSGnDnuMjZnP+BFY99ez9rsHG
JVsNUaVfKAy5N02I6HGhkCeT3tRB85xzOyBz4ibkWO4xB2n/eY3e8DlZycMs
8/F3lvsg7BsPrORYFmI6/5u0Es33+u33ixanqvB+JnwwmkWiPs/zcOKaaqza
p51Vu47Cma7Yvu9ZOQhrtdnaR/vHy3vVYrQJF1F3f5xmK5EQ2HjrCwobwe9F
RJe/olDpXScZ/MAHU0OG5on0+Ys+vHKzLC7GpM/adjkRKHAzyhtlN0D21dAG
9Yu0nx30pBgVhVD7cE3S0YNC+Jjiau8L1dh7c5A3NULz+fLjExVf/sLaX3Wn
T9D+D45VGW1KqkF5XWXxmxAKjD96BsRof7qwFc2OOBPoSZE0Tf6dB9ek5TjR
1TRfxUxulgW1IKko4YmWO4lNpzzap/t6UXMvasT43gAqHyo3hBZwcCmApa3Y
Q/PfM16vQK4DaR/TjRY2ETg36Zlr7MDG15aF2uv0f2QpXirEwqoXSnvOfNLf
1Y/TvZu12Ws4qJ6OFDxM8+n/FNPKoA==
       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4lOkbnrAbGbQWlbaNpFVt0klk61baotTmkKyUapVjDqVCtc3mUEmk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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk4lG0bxpUWla0iJZUkEdmSVDgjCtH2UqishRAqJEq2V7wVyhYVo0XJ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk0lWsbxs1DHTNlcVRCISFRmbroQydDHFMyK5UGlFQ+R5IiCZnqIDmE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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41ekbxg9ZG8lyKGt2xqC0WAbd0aaSGiY0KTP2n6WiCSVL0qKQipJo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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4ldkfVypLkSyFkiUJM5Ut/YbGR1IprVcbRRG6opRSKLpadEdGhOxG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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lG8fxa35ZUtSWVKUJCSFpNKhkJQsSUppE0ULpUiIqEiLpFCpCJWU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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk8lesa3aIIHc4VuegKaTAlGZOWSkdIoZQMIdqHEkp1pCi2KamUDKkO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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk8lWkbRqaMLCHF5BOKUU5FKNXoEiU0slS2bDGVJFuRT7Jk4qSF7MJI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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVWk8lWkflhpNkaVkSmE0SjWSYyJ5cZmJFiYKESFroQyhySlbmZmMMJWl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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWGk4lAsbFi1IKkopItmSStakuhUV5YTSQkSFdGwde1Ikh5KyRIkSIrKf
LFH2dezb2IeYeWchSUqWyPd+v+bHXO817/08z73N9qvOZ2y4ubi4Li/j4vr/
J9PIeNL0fi8+Tu5qcTP8jAcqZbsve+bjslfmjfxGBqKsGts35GVB6C/HvTfM
CKzbmaosvqEYFouWe03+JUDx/mtd78Z8/Pz48mmYNoE2rtDCsr9zkBNR3bt9
O4G6/qyspeoC8G/S95FYQeClzi1TJeFqdG32/kFNY6L3EO82D4c2cHgT+rn/
ITD/peGDhV4JFqTsnnNbMKDXGrffjU3BMJXbv+47A4r+Qj9UV3Tj0Qb55dkm
LCh9WnpT7dwCgW9X4rCJAb9jsaUftsQhfvOr4TNGBEwOneV9r1kHVpbZjkJn
Ar1LktSWwRKk6dzJsj5AYHg+SrK3vhzO4WIK1H4GFjN+ip2brMKIdPPb2zNM
iN17fPG3Wj9+NlCl5u6MgOYzLr1GqRlnGWmy55YRsLKvHUjpToVZlZ2x4SsC
fv7R29ymEzFRpewpdYWA2fBX7aOd/ciW5t+e8ocFVn/Y1Z8jvfimVrNXM+Uz
Lr6+/jlMtxo6txxfbIsj4Kb8RuNhRwfOqyetC278DL3Ljse3yVTi7qu3Vwv3
EfB659LgJ1YCEcddFyxECQQn+rS+6aYiczRk1lKjB3p/Tk8uy22ChPrIyYH7
BCYpbtVXd1Ch++dt2el3BGw+VNhM36jAbqkc4XgdAuw6wRUytRXQ6jukLzFF
IDN3cpPGyg4Ebx53VVvHgM+C3lStVgX6p53vvjRg4PLPDC4VkQ7wrtS14hUn
cGQHdbcctRdbk0+K9LwehlJc2hyXbgf47b/FBSoS+JN+p+SsQTt+iR17PneY
Ce1Cl2epbnWoS6xaMJscwXCQAX/X4SzEH1jOTg4k8J6/2jdcfACtSUJNHkIE
rHl2F93PLURk5WFup1QCGxa5a8vJ/bz5bNtdq8dEtdju87LOxXiglChpMU7A
WFVxV6F9E+bMfxks92KApj/b/51Gxd0+lcj1VQxMlhWpaNbn4NmpXsfeIRKf
jbnQjyvt6NkZXH12NxNSQh3xA7XtsDh3pcrx0BCUXkfzcb9qBeux4oN4UxaW
PLYu/XuhHU7n0xLuhRL4+SXG4GJuL+K6Ft++LSKgtWl7V7F7N7qXOHmsajbK
NR+NCRUG41VkMmvrVQKSH0Qe/LQowDKPQOt0KQJcCv1/IkqDQB2Irki4TO5r
y6BwmdQgtraaWtoIEkjiN1ZNt+xGWlV+QfdKNri+7lVvxXmcOBRl6G9J3pui
2N4vogHQtNVzFyWfL7cqvrlYnwLB3z194g4EOBzZB1ZSPZh9yIlVTKKjZUfD
VGscFRLfB/8e1GHh6N8BhnIqvagVnRGNWhiEf77ewa3NLeA1/G6izcdAsYNK
Ut7dOhT+FRWZsIyByoY7fywOFcFW23P/enJeCZPnzbde7sWKEEkXG8UvGE6c
CBq40IrylrPZMrfZENRVOL4pshute49e9Ixmw3L16cGa1F64WqlFvGMxMW6p
OMuxpyLSeiJI5c0IIsXm+xJLMyGde/99vRyBj76OPML/9uJkmtupvgwmytdX
qLVGBKHbMF/N2Jqc58nGsbLyOqT1vtCNdySwUk9qi5YsDU409Z06+mxcTqq+
Y2pQDqyWGb7KIkCV/hQ6EV+I9Svn6i0byPkFZT1sPVWNp4H9UdP3GJCx2CA0
UknDVkFn/9IHI2i6Gbm0XqwDClc2SNKjGXChWUfxplShbffLR7KBTITF5E8u
bP6AwhrTZnMVkr95hr9FtjUi0XzucFQYE99XKlZrrP4PzyyUJXlPEJiqPLHY
3F8FvWPrRb4NEXjWkaT6j20XBH57JOfuZ8I82TZAS7AS3ffjVFdmEJC37rdR
zM5Bar/ybJw3gYsrjoUFeDZhIVKOCX1S765a7my+3gXu0Y+JO3uGwdH6tXGp
gopjugLBu54ywXNEsD1CswtPnB5IUZcYoPA/89VRJPXarzs3TYnAVwN6yWtm
FyIWZOTT0zjgfsXR7lHuRNDMo/hwawaOuhn03KofwCVF5Z3D0kxUut7KEBdt
gxX3vxtOtwwj5+Z2XxuecsheYpk6uRPQNpEj7mQ9hhXlNifTioBqtIPBUFwj
HP4q3sAtwkB1tDT37ZIm8NJ2hqZI05GGTBd3Tj0OtoW9FYlgwk4wmPZajYJD
sobnwtNJfnk+bBQ51YPb1xX/G7BgQrXtruh5wVp0XApQ3k3qxUsZV5PHU9m4
OpaRE2RA6nFSbvsP70g8dTn+4pEdyYfY9z49i5/ASuAee/GVAS12exGd1oYn
o45tFsIEqvcXG16m1IOrPeTPo2QmYnhyrIKMqdj3eaLZ98cIeDsEWNqNVPix
xWNEVnBgNH/e/sjGJlSuH73V8IQFA26FuU1NFKhq/BvqTCX9xMXpwquY5yj9
3dEiSOKnpT5qdHbvw0mWMbXoEgeLESHrQhVq8MpG52Fm/QhmjYUpJkkDsLx5
5FxUSB8C3olu/HWkGvFxg02v8hlovyrMVk8YANuvWv9mDxs5JXHOXNx92BFF
WZ5uwYLfm9OD1+f6YOl45Pof6gg4hLmSgE83YnT+K234NgTpsqijDqpNMLnk
NvMphIFxZ92fHrEt+Nvyoe1qFSZsPWMnaZR25Oi0ON6/yYbuBXWx9JgByDlV
5fBocCDM+WDzlj8PBQlWz1LrCORcY5a4XqsE/zGLOe0wkn+vl+17lBkBa0qO
CsOWnKdA4MzWN+0oPaeykGM+gnWbLhScRQqSXPevMlMlEBNSr+i1th/ntcc8
6RcZmLKVK+SyrMJpIb57Y98J2NVuENi5twvaq/UNfm5iomHwhobBiSGk56UE
y34dBOHvJDot2Yb3Xo6bPTUJRByl5N4m/ag/eGOK6jYW0gpcW7tFG9G6Yvmx
sFmSP0ZaN7UG+qC3To4n14WN2fkybiWRHDSMD7qsSSDvw0UwLEf8MWLmCya6
yHzj9vZc59dnbRCb4BEvOkKA3nory868CFn/FLeG+xBQ0otIGTo2hBsSQ/bZ
UsNQXLl3vGisG/v5pG3VtViI3Bsgbf6zGzSdpLCYHibc0iLl7O91Y82ENZty
dBhTAQruTAkaGlwd7pvrj2Ib7VuMEr0TJ65SslgadPhpn1MIs68F063ok7kO
Ezdvpul5SQzhb4NCbbtqFhRcc9zXc7oQ/d1hi4sVA2V34tIG69owb3PBvur+
CATtT4T41wxg+OU54SQhJuL7UvK9N4dDejpse7AJmd8ywrOFKnJhJ/DF9zGJ
l+VQpy0Z1QzVC7Sk8nV0UF7P2eQl5sP75Fd82k+A2+PbZIFKF3yXTi2PsWFC
0sdVge6TjzfS1oz/P78w5teqz12JxoYKu5YKAgdKj3/fORGBKXHZIQ7pR1d9
v653VBzE0RW+7PlmDqZbvbmKZfpxiHedZXESA0qq737S5/MwriN8oOUOgZDX
2mq8nBrw50xuZn8j8Yd+1FlrV4UAN/+pdn8WUo9bX/qS2YaGv2iMGi4GhgW7
35Z1tiLFxNgoVJwFvT0ibWWH3uLjPi+rZkMCLfJpp7hnOyFwYk9ubjEDXOsV
NosX2WEhzJJhS/LzSZL9xvTMDoi+71H8YshB2K2RRyJBfUgUi75pLDeKcZuh
6i0CtdhFfS4cdY6OiX450ayOelyWt/qn/yELXIF2FwUDUzBX7OvkSM4rmu5m
9+1cH6TYLPvta0cQHTr6I8a9Atxbjby/eTIQXHNwW7B1J/5x/252ZoCJzEyF
Z6diu3G3X/zjlU8MSP0OXE3QOqDUacTvvpGNceOC2V1lNCj82SPxQnsY4aUS
WlOKLfiVqv3UTG0Yz0IU32U/p+GWrAhffgAd+5OirvIqNiKkJjd62oyJVOaw
uOvndrzcqWH9UIEDn3k3F/Pibpy/mzDW4NmHg419DzPmO5Gglz07cXgEGf8t
nOdbUYPDVlK83IksBDop5aTsa4PPOEWLnUze5+KZ12scYjFVMBwfROb1dunJ
wDMa7RBSsSCGHFhos47/MXq5C4P7kpV6SX2/YShWR4+lYe286fNOQTZCom/2
JD2tRd6spixxhA434bW6094D4P0TckmO9KfYqJUa4kOtqG71Mb/mwYBamPRb
8/VdoKglnDVyIvlm6zz7zqMG7s361nI0OuJLeV4rJNUj4JOqiYwRAwQ/t/8h
sk9c4uyVWUf6sZWTgWWPYA02zwjyXREhcDD5dvh1n1YI/oplFfqOwPSBmjXl
TA9CTIxe9YOF1gJXpwa3Xtzgf/fZehMLMX1r9e7LNGL4uzrHXYaFkqpv25hS
A5j1+cfdzo0NTnrePq35CnyTz3YcW07qjaYyI0apAdLC+CTkT6BjZ7nGp0P9
+OhaUewiz4Hu8+4V8gKlqPjRYiRF8jFueHLVMq5+ZHE9Ja7K0JHxMXV7ci8N
FgL+EU/Y/cizYNDc6E2gXeQfOU7mHS5u2ctlR4OxQ/2AegvJv2KRTLHDGo3I
SfQ/uUDmpQrjU+aNar34U9rndUGdvM+qbveDxm24uHd/irITA0nlS9X37Jpx
TudK/KQdmR8EDg3Yv7uHqdM6y7ZeIvVwS6HhzjCyHz1z3S+cSeZZ4nXgomUj
PLsZRz+T/utjJSQy7NqMly1Nl4/VkXna9sMW+Z5GiKj8Z8heIvUlbwNhH9qE
gunppJenCZif6Qu/P9UAmjxtQOoPAx573j2P+vUJCoLnV0yRv3ezUefISEg9
POQU9nwm959m9kTEYKYR6mvS1ZLzCRSGYFFvayfkrgXyLJ0n+8+dY3El39vR
/aLV1PEaE982JOVmB3Rje2zci8d0BppWtVUaLuuFipttxwy5Tz9lW28X9n6o
G+1bK0/m5SyLdNXrmZUg+vxVeZoIZLyv/8Ig/YoqdqQycZTE//B3Q+mZAWTI
fC+WnOzFxZKQwGnhcIS56uXsuU76u5r2DkogDfJOXweVBVjgVuFLWxmQAxb7
g5fHMTJfliXz04crcOZdlLA3QcD/0k+Ng7FUeJsKtZYnchDp/E9ERm4H/Eat
6eJ6I1CMM/Rq5W8Eb1FivtoNAj4TIjnj3Y2YUvGVFuIj/Ux41O55K9nPar2b
6RQGikT5JVocu/CKT9ljfTEb1BulZoLxjTiR6P8ljsSvxFed5JASjzwvh8UE
J/J93rl9rSbz09hZNy3v9Rzkvj8dU2vWD+H0rIPXFdmw+xTmOS1I4n/x1WYw
itRH8y2jFO9TOL5C7+EBcl7zpX9oS0ED4HIzP5mmS0ftEMXg3aFeRF/rz1Kx
HYbdDXHuPLEW7Oq446+/hfSHZe+TPpfWIENKuq7Uho6m6Eqm3YM+zJy6szM8
dgRuViNBEU8aECl7XH+Bl+xbPO+DJquacPD+781sNh3VuQUtNTZUcB5PLtzu
IuAupLD2X6d+HIhZ0tW7w0SWrpel+N02hE0ZUvMGR8DDEKRlUBqQZxh7570f
E4H7hnLUPagYOM/9+WQm2VeGwisz2/ph9pfpFgUnNsri9ac6fQZRsYx1S+jU
MASiX34J1++AtZDB0IkoFoxKZX4JF+aDSjut8TKAQKC1QHtBfQveNP/3feA9
C70K/t4zgVW4IHB21Oc3AyN/Vj0NWOzAQY5Gis1jsq+tKQilbq+EvEvkx/hg
Jq5zQkp4FYvBX/NjY84Tsm8oJ/9qWPUWbXwzq1kfyfu7XZdgotSBTzsDJQKO
0SH5d9DD5ZWdOO6Hg6ctCOi6TtcWeTXA7ejAr2MLdEROWxWNneyFXoCKIt+6
IbQMU3u+fuvAaU6ruoMH6Y+Hr3z5m+SPiJXb45vKLFCzw+diSX05nMf5lapF
7t0vSrnJnbzrk1Kab0W/QLd/ic10qkDe+NKeTWcItBk6FqaWtGPHxX3DZ01Y
qF7n+TKvqg5uATzv82LJ75ULM29r5mJfS03Rsyuk/0vcrPTbTL7f/sFASX46
enu40puC6iH3uD9/6xQBz+Xulb8VyxCq/fvcPdIfNXdLXu3ZTd4bXWZxRwUH
S4e8zb262nGaHTy6asMIJNepD0ZEhcGWJ7JwL9mX2Yz21ULBFDRt3bL71i4m
7PcpvjWto4L794iEpgkDkVYDSQ3tpThTs7v1RAKZdzZlH1grW4WbbrMFFr4M
vHNOP8B4SkNRnqbvUu8IrJpjbbOMOnFYyVaam+y/hsEr5WJlmxFO289cc5gF
JS7RvY8e5OD2eMcTDRcSr46op/frOMh22VsEknqVo95AdLxqwwYJiymzGjqM
oiTWvvaqwDBuyzuWM7BO8F1fnGQ/1IL+rXrhMoZy/og4tbk2JGe/Mg24RUfJ
uCZFcImGmYVOu+Or6DjqTtOfNGyDMMXsq5g8HQt16SfWc7fB2vdgMR+ZXz8m
rdlSsKsRI5F5EtIvGNCmih/TZyXj3rnGwEJjMm9bL33M7uhC6Yf1dw3d2Tg/
s/+ls3k7sn0JnfIlJjp0TW8NGNdjc+lJzqsLTGTseK46MdyL44V75O1FWOCs
2OgrXBKIw12OnDMkvt6vuY8b3fPxhPeKRiIPmXdDf0Y5OdfCXzP3zdlSBj7K
PO6/wkvFlpbzSsWkXrm5ePxkxdci9ImctkYqA3oDr7JCBprgYKslYkX2M+35
zM2Y+AfKEycaLcg8KJ99bAshRkXlmj1NUXOkP1FGbXMLdSH0aHajMqk3p68Z
GM69bMdC19iY8wwDis2+JTwHGjBmG/J6QysDB0MvyN1GCxoe8htuNBrG/L6z
8sJXujAeu/p4yYUxPOtqqDmb0AkTxtOlvhAyPxrI9AXff4Pxs3zTskfJvhKb
0vzhZTSWhRhXatuQfFwM/fHXrjrcGB+rGOAQSE1q2Hrx6keIsO+pbSP9h1of
d24iogQ3Xm+SXVXEgImS6OWSp33wpUy91U3noFRrZf70qUpIj4YjVIL0Px13
WduH8ThhOhPJIPnb8O0x+/DlDoxes8kpJPOAuqOZkIPxZ4yuObEmLnUMftlH
JKo/RWHFTpZkAanXtr/5qKMGHWg6Pbe5Egx43YUuQ6Eah3+qr/S5xED5asUc
vdZGqDbPlFBKmAgZ25cpe52CZdTkpwdIv0mYil9+ZrEQHdpE5///3/of81Qd
kw==
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk41ekbxu1ri0YjJGkqNGUpkkwztxMTicgykp2xDGXLaFI/oVC2RKTI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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs4lOkbx5UlWimFKAkpZ1rE6PRVSpoQRWtZQskUcqiQVH6U8+okYdNi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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4VfkbRwvTNZSUSFQSES0zMbR8RFqezIS0yIwkg/zIlpFdMeQia0JG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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4lf//tlMooyFJS6hQCpXKLcIno+wQKkmUIlEyoqRsyl5FFBkZISt7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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlns81Nkbx4efCrW5VVtyD0XubZsSH1GW0a+fS0pWDEVbq4jtQpRIpJTV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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns0ldkfxg/GJQnluAyaIZHLmJBKbg8WkpSplVQjdyWFyag4qdwbjaRI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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4ldkfl1Io0ZUpuVP0Y6LBSI2iqc9NQ0Yp0hTV2EmhbFERJRUppKQs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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8lO0bxW1FStZXIhIlv/aElOogWVLWROVFSLbKEkUpWSJJlJAkZF/K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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81NkfxmXVChu6kMiy6LJJRaui9VCj5FJqkZRr2PnpRm6VSy2JrM20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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk4VXkcxq9IkkoJRZlQ9AhF0TDpdS0tljJGiEiyRihrZUoqg4yIiSIh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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4lOkbVlLtEBF+bbQ5LZXaKEuJuW0pv01ZK4SVWuscORRRG0IHmhxr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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VO0bxmWvFJUipRT1SoX8ULRcIiklRZElISFZSrKllOzJ8oYk2bOV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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8lXkbxm2hxlZzoo0USaJCCeFCHCYqTNMiGhSFd1JatBhEQ5ZKEZoU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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk8lGsbZixJlBxbCG0ijkg5UrraOJRkF58ikSURDeq0IEKdipFQ6FOH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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4ltkbthSSaCqiNGEUJhkhqTR3SbKMLZGd1BSmkDSJSimGaox9rZB9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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lf/7xyWhskKTRDvhk0i+kheiiKxoWSFkKw3KqlQqKzMjUmYpI5XI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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk4lWkfxw8R78gWKaEkg5RMpGHI19FiCSOGRAvFJJUttIx0shRFNVO8
koSiydIgjYNDx35KOA7HUfbz3KeJRtNiWmR5n/eP+3qu+7ru63c/9/f7/X1+
qw6EeQRJMxiMDHr9/2vz6EITZ6odT1eZRVTcp+CexnuUVM3GPzob7qrWENyr
XcuoCH6Bdr1b605Yj2HqlmyI679cfJSa7V6SRxBq93X1vISPfZLlza30+Rj5
6nx9YwE8kvY6jfhSyFxc9fzDaBliM9OuekcRvCwXhei6ikBiGh8UeVDgW+rc
D91UgDn3irrgXQSpX/mDyn/2wS6sOnqrjRjOScqfmhyf4VhEX8PSMwQ7+qJ8
B6b7YC6Omra7IYaRHOOw1ct+FKtlJDR9EoOn2RV9zESIQzqn507mUzCq91gx
FtIGHfmMVkM2BUZACo/xaxuW/X7J2rybgDPTxWOpd6M6Jm9bXzMFlaup+sbm
Rbhnby1tfJwguIC5yh7ZOOeioZLnT5B5M31aU74B4a7RzR3JBM36BvcN7zQi
uMtKqf8XgmR/lqvG0w7Il6+b6k0huNoaqChXXom7lxkbElwJrI0SZqW+7cWM
18xuG1MKxbDJq77TA5d3UVu/7xJjV/GRA/vRg70utRMXaT96vTiVO+u5EBSK
jPfOEbAmShJXT8cifttOfVX6f+6lf9qRGzyAUTv56klNMZLnimRWZLPxvsOw
fn4vgeU2Ge7wsufQtatbtCWegs3j0KzYvX0ITzRL/u6zBK7ipr/u9vZDKFu0
1PwdBe0lR4QOy56Aq3Zi0CWA4Jdvt3tq54sgm6dy2TedwquyxV0RCr8hzj76
0yxd32jQyU8htQGcH6Y6KqUIjBs1mUYmvTAv+bK4110M3QwfOevSKui+jWvd
bECgdypbohDWBnZceSappf0/05fOMS3HC2nfszbhhNbVJMk3sArU9i8zNekE
W9sXPQ3e3Ir3Ak7NgtO0/jK7GSsTKnCubDBVNZZg9coX4h9dBTCZH+uw2E7B
Z0eQ2bPvChHcuuza8D4CrvtYU7J9C/5wHQqdUZXAs/OLoH3jEJjt+zvrh0bB
WNctF7hJALNzFaqfXlGYLGGttZsRwOGPdly4LUGy1axwKPAJ4tfsyk/RkyDX
XCvXfqwQ2cGHXmiGEdjL5LBzc7qwO5HjFE3rl+o/3JER2wSj9oATZ84T5HZZ
fSmu6kbRZLi+2nEJDnhzd2p39+Kx1/R01G0x3p7uTk26xkXo+Ssf5i8SKP4l
NFNZPwQ33vj4a+lhrHuZe83r61PM9rY2fj5EUF3GNq+KE+EsT+GKHl8Mvm+E
Xm9wDXzyRWvGQgmWuffYld/sQgsVwXOMoMC1TpdfxM+CY+p454NAAsat46en
FZ7g/Jo7R65qSWBXOcAa9PLFaM0b8yX7Cd6aOBraPqhDpmWKUgLtB0NR7ug3
Db/CWUmqLnQ3nefHqQE659jw+85/j+tmAnbofh+5HY/xMW5B1o0VBOveB2eF
3BdAlmRYZnLoesvvqsdyOvDxZ6m61VUUJCqDRjVbuiGz38HzXgYFlpbC6nUF
8YhacNxzPX1/+HOjS44X6/AnazZydzzBxg1Q23WkGbp6/KHYUQrqYWe73mj2
4P10l2A8j4LJ1NaH3DWdSG+QD9p5id43u/ZP6PVjivn30MHDYkxt28P1WMuH
tPptb8VZAneNDyUrT7Kh5G3cb7mRYH1kXJxUEB/uOnFzuhq0HwdVtn9dXIC2
9G5tOfp9jG/NhIpx4SgvWTTRRuepeYuJDVq6wRsryzfLkeD6zy+SQ8z6cK6o
xfHgIIEb03tkpJ/uZ5Hgpw00/3g+NktcZXvx1m/mELNHAp9PlbaHlXlIqDmh
ekeWIGu484mH6DnUm28KXAwJah5EPvh3YS9O827JhaWNoaaW6Rl7dBjaB4VC
O+NB3A03NVcM6ULF+N++tRYUys6McVRVmuE2d8zzPv2eq1OeYRYXy2Bg++Gf
N2kEunLD71kDD/HbSyP5ygiazzLWIu7CPrT8+rplX7IY0dcndbRahjC9qfEJ
dXQI2d8cLn5k1Y2+r1ZLYyQEDj9YhV3y70IAa+jZV2kKGWvNx4fKnyH3H7Np
Zht9f+F553DbLES+k3Pop/nt0e/28YOeEGNKnatKOWL4yKUHRRgKUJvC/CtJ
XwI+073d/PEF3Oa+nVCl+RGSsXnnqHkLKoMV4vq9Cdqvi52yNWhevXYpeNk3
hsat2nJZs/3QN/c9k6ZA89lMN/PDTAneWZ44Gswi8F8eMdts+xhFvzSqh6wl
SJTN2iInbEDp7czOUrpffAw8dqZE1CNrJkIkdZbg5LDCxaa3ndC6sqReqp7A
JKOitdJAgOiRQPMgTQoVOT9Sa6S6wfA7a8scofVLEEjlyidA96ufmgWdT34h
iTnmxMFnJ5f0tfS842qbilpZ7fBW5rRnexG0pMvsvjwixPZHTFX7PJp/afwI
Q6UCDE4/LOTT/cMxvrHCS0sAkrd/wQ9dBIXsjUerOp9jsVnpnlfcEXy2HTbU
t6HrD7BEG5h0f9nE35xI7IaZ9jFH4RaCsn0ZTm6MXujyhlUr3Sk8qp4ItDDt
QSyzdknlgBifd51TtJjvx9blgx/V/hTDUxQx8OjNINgfV/uM0LxrL3jYVqEv
hGR8ZpmCyRhccjraskkf2l7qRnK+keD3+P8+b+U9gaqjc/6EkELrKUlkqUo/
TNf7eqVNiiHzU2DAj/xm2H7etDSIT6Cf6HO+qLMDxstNl47S89P9y8qCbmcB
KIcFDuxQCuGTytX510Xw7UyZ9w+j/ZPnW/sEFsM5/LaC3mGC3hsr1kQOc/Be
11DN6RRBnnGN08/FQ1j4n+Un3PtGwfLaW2fIvILA2vKHkj20/jObtB01SlHS
rO59zZ7mTZb6fW3pP+DYI31Imp6vwTkX6roqevEsyIKnoyyBMCbr5km8gHJ5
+1yF9Si45MqqHdxCBF3e51hFn98TI53D0WmB5fdc1iTtz2h8ozO7tR4XN7+6
1OdHYFd2iCS6VUM7gFevROclSlQrsDzQAP26PD8tOn+pGq/djAJEGE66m38q
bwxG8wYHF6axMbdIz+CSKcH/APXxsVw=
       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41ekbxtGQRiXZ+klNIiKRyVLDuI9dUbYGWSMZjKKmtDCWskdMDZ1i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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk41dkbVyka84spo5REYdKobpSZiA+KiUGylEFTlGuJFAnDcFtMWlSE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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VPsfxgkXJTuVdG0pZS9FRY+UFiktSDdLqZCbJVsqRKGNsiWVJFuy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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8Vfkbx1VkiUkooywTYmiTS6MsHxVR0bWFUBFmaEEqW+K2iEIabilF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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk81OkfHzl2KSorlSMlWYpyG9rmTUQtTTnK5mYpIZuKdIeSXK2S1C6J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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns81ecft36kSaTkNr9ChlhtSkR4K9cyRrPVkBDlfhk7JZeIpGG5tHJt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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHk8VO8bRQttWlAqiUglUbZk6UgLQpsWSUJE5VukkIikaJOKSmWnZI3s
WyP7PmYGYylm5s6gIpWQVL/399f9vJ9779z3fc5znnPOyDucP+AkIiQkZCss
JPT/68JTS6JO9bNRt0fVZaU7hTeL088uSmAhjbcvO/A+BSGra7+mbl7Bxtlq
f97bUrhbPrfVc6IBrmpHvHeLURgY8332VaMXejMOBVm/G4CQTHhSnaQviiZa
L10mz4vJT79w6lwzfMziDDw0KKQNO8roF7Wjqyt5Rv5JCka8+euNT3cjQ5er
uSeCD6FN6c+5PpfQuPzU7v3k/bCKZcV6RjngO4t9nL6Tgm/XfynLtBqhrCye
dmIlH03GLv/dfBuF5pCO88/J8y4n/hln3Y1AspvYrW/HKezrbpbgLkwCR/0Z
p/AKhb+WA5nB3o2QpPtN/vjLw6hxyIoXtbUYjmDNwm0+1swR5963ZuD2iMEa
25983DV9K+9s0A7+55cGDhoCnOPw9E9V9UAl83bT3j8cmNf/qF3cxsR974g5
mj8EqN8uN5bo1wOdj0rPhm5xEWAa28TueooFWbU5/x2g4Co7SyvQtRuGlvZt
H3z7Ifh+eI7C7CpssTXf8KGVB1rIO+2ZjxNwTcp1jybZ/46PGVdzzaqweuHS
Jb+syP5fOIWrCldgbOPcfJNtfNjIfIl5YNQBS4UchaOuXExvc9g1EV6BrOHC
zEAPLpzlON+Pf6bhRfEPVu8SCjl/pm+2GMyHo6hZlFgeqWc0TfldQie0fuue
9XSm4Oy/2nf4BAs2T5aW/vrUC03fm2b1nHRUjmZukR/nQfLLTL0VHR3wFnba
e4kvgJJWis68G+XIkNWdfbmPh7XP8p3y+G+w1Vm6KsSRwtwdVPBRTiMmDzRV
jvVwULkloUSPn48DLTeC3zXwYJidvGl3agLKpj2u3OhLYcR3uadafh1WLZn7
O5acV9FDcf12fRrWzr2gZnuIBzsRuXs9KQzIeWhEbN0mQOz0HOPIi4XQXvhB
9iyHAu11Oe3cg1ZIzpE17Q3nQpCdY3Dp8BtolprfZplTWDy1au00Wju20XZ6
BCZTaJdrd2jfn4Sl+zLzpW5TiOnZvvdURiFKHlVLH7nEg9Dx+XynjosIL1n+
8yrpL5ZeypaLK9pRaTRcHXKAA3GLh78nnnWjo2/x2NoqNkLWSU0+eMpGxpWg
AF33PriFVWe9+p0P3fm8tGgDCjOt2mZ1RXRhTEj4Sga/F+bWx3JXraqCtrGa
52NXCnbpEk8Ztm2Qi/eMEJflgHuMM6nBLoXottGJKTk+YsWO99BqU1B+cCvv
kj8FDY63e7EwHUM7spssw/hQHtQdui7Fhn7QgIqb5wCaE2+0iJbUwHP21qys
AbJ/Y6eDRh8qMNCqGbtBlwIlOusBe1oTdvdKu9eHCmBTIlbJWhaFL5121eJH
KAQUn5Z+vLod6mvuit55yUPQppjV8V6deKgdI/NBjIcNBTv1JGvq4SrPv9tV
TIHO76GVnqnD33RhH9k7FLSFdVy8n9XDf1I6Q8mCB+lvrYNXb5Vh4bbrP9bc
Ini5bRc3Cc6EybFGnqMXwfua89y8eDqsBW3bhxZw8a1+t1vm3jbYRsxhXyX7
oe3/HlXIz8T3kq2bf54h88g2v459qxpuZ/o24T2FqxLX9RgbCR8vv45fuZkD
O+fV/kNJNIymLi3xI3j3XZ7/l3GqDadEkxkL91Jwy7UzP9DxGnmFa71Cj1Gw
tfcUdrRn4Fng/uIWwn9HqZ+0G/IdEJrVVzSSzsfYw+9nJ16y0e+7d9rbVwM4
rPx38msTHXelr01ZiVNo7gviF+xqA81leFJDhIMFwlafSx6UwnuicOWce3xM
cItnPLnKQsPOR1679wzgjTjNd/XpXIgnRz0ZNqLwYp1i3cnAt/jrfzLA8DTB
K/axu2c1HSJxTtalpP8yadXiW+52Qqxx3I37ZhC0EQMGa1MTGvcIjpzNIPXl
pp7+wGTB4KXMqQvVfbBOvP3xZSENGS8nay0JPyLM4n5d1mmHWpvoIhkjAZqL
fmUUXaPjieS7be6pfaA93zjIEaQjquHS7gVrKJTMvWjw0a4Zf59PpwrX8LDA
sc3NzCMJw5EelKca4SuO3tDq7ISezUp6R0YX0lSocNfjNWgI3rEsdQsPb6Ye
zZzl3wrHABMNpnw/bDzF4m7WZMNq5wezZ5IUmX/p+yXD6ag01VEwk+IgzapA
fo50IUwe6sqrCVNIjroleSkxBhF7xHT9CD8co/cfC9jQjJQXxQOm6gKw/7uw
smluHPbMOlE26kCB8TFb9pdNO3Ze2NIn+5gPw2bbnEsKsTj93GcsgPB/ZPJZ
Xll5BlSWBGTEeZN+jVIzNPzKRtF6v/zqkQEEaFStZpdGEh5S/7ZYEzz0fGcs
6WXiS4ufd7KXAGLVUrliY4XYPsZ2SiH4hDkePHVsfS4sIJ3mbkNB7t+IS6hz
MZ5lrNK8XkXWEptOSJkHQbTld/Amgp/+/JPXpdlMNOrfu8X/Rvrh8pmON955
GPg8Lhu9gMLon1PMluoeFL2/vUYtkwNPrfKhz+erEJggZyLVQOG9A2OeQlEb
flh4DPN/ELxKavZ/yWvHh5Er35VD+lB9UGnd9dgezKk+qFmp9AWJ69NiulfU
IvTJv6EYKQFyv/q7vNFiwjOlMSTTR4C0b9OVGGiBLKWx9VUAH2m1/0R75+bC
xlnSxI9B9KKhvHpDSDOUkvjR92w5CFj32f5tXgHmJboeirtLwSr2bH/CZCua
J+VMxYoIPlsPPYpXZcNi2kLx8GIeNu5WPhyoHYqlOwMX2BE9C+rTdN8qzsTd
qWs7pSM4MJy7iP0isATL/sxdPyeawhTPS1VZpQInhVtpawoojK/RKuh9xcYO
vyVydoWD2LfiH/PcxVZY+LiO3V/fC5/Vr9w39jShplv/WMBKHhSVevon1TuQ
Yz2Vp1lI9LhVxw8rutGls0RC4VEPQu7/S5GVKITOhM+9jWQ+ydidN7fzb4Fr
YUGKeA8Pe18btNwn35tu2at6y6gPDLm76mIH2sAeerhAI5QHLq9LYWIvE5FN
icLTSnhglcCr+GUbbrwuE5Yw5SG81WiO14cW8D3WFvB9+Sio8vV+uL8eqy59
+rPjGQXd21r2goQu5AjPaxkjehoz/CfWmmrH+0a6aG4wBzaM8lyZ0Rasa2QI
33LkYOP6vV+HSzJAH40qtDch/oaWkml4sQzx96LDZyzmY/d1qdCYZ/FIHJuy
OnqWzEdmcX/9+AWEyU+VhtpRUM2QdHudySL46Ov/TiX6spV1V9qnBCLe3Wtl
yXrVYcn/mBwmrFQsR2SN+bA6Iv3BR6UV6ULPn1JeXBiGP06f4ReHoMX0+DOE
X9w8l6zcxHY8dpNbuqGdgl/choB2kQZsl7F/9pSc/8XVnTl6O3qgevfyCb/v
vaBXl5uEzGvA0cx08YSrRH/97h/VnfYeoVkXLbjTSf+/Cna+jyo4HrsQ37OT
hwPzmsoL5rTDPGLFvcsneEjZeW1tQ3MZTiz58GbWctL/8tM73k1vh/Nxn3qH
dgGEKv5WCBnew/sZP+LUSX/JlGb0PFKiI+by4pzL3TxM+PvELzGoAvMRP1vA
pVDg1DoS2FqEsDNycU+3Eb/bO3u87FoTpna9lHQZIXrmqdGvJVUL+rqFq6zH
if97NVHM29uFoKXleqsedcBF78luG1YGQgRnv7jvo8DrSxl6SeuB70itwdFd
XQiTqivYJtyM5KLxq+p5PKhG6NuPk37ccHFtUWXTAKYnng+0f078a2TUK5MC
HtLV1k1TeMVAzUwT2g8fHuiXPrlrqzzExYsLFHOcKORdcf0jVNGJ4rQk5hz0
g+5aEBDn0gplxS2OUzMG4HL5uKqmAg2v6tfqvI3hwVuT/vzXrDR4LmuW6g0g
8zByx/g+23LcnKG8mUfqIWO2RCEjiwHWojNJa1I5oLUNjSx37QLNJOLZfyGf
IKKb9K5wJQsOHqq2qiVcyNTaGaTodsDrk0noFuI3RpvPHI10KIeVSM+LlT0U
FgTO8ovzosE76FXTw5cUrMMTg8S/dcLFXS6h03YQYdt3/TYhflX5u/XStZ+J
n7ITeabMU8PsI5HzVU+Q/EDlXxc/y4DYl1cuS/dTiJ4IqnqPLpw2kRPVihhA
+SLVY7ufM6D458ph36WkfuXrGWeQjw1R1rMfP6agM3R14ERAF2QPbgjvOdsH
K9MzjvPH2qHc+GPxunN8yOnPKpU8SMcSJYsgUQkudOelfLVqaUG1yoXcAAEf
7OiE4czl3VDmKNI58/lIdtgVacBOxKo6P86ijaT+LvLiIjdZcK0z+yrD6UOA
xUcv6aB4JOuE9H8j/qGoSFLikxQdsoN/t7YF86F75dAvvYPdiJ0/vlPyPx5i
/fWN9tgxIG2YMMo9wUFs96lFb/fHYbvT1V3LCF/lBs8NmLjUY3JOgXaMGg9i
/idPd/+uQ2WCSXkjh48weqP9Vls25PJ1xjkWXFSHS9nu38nCa8uYJ5nLe3DY
8cVjGZca9NT5FG+KJ/Mo6E4ti92MkKcfkH+Tj0Onw6pP3WOS3HUi+SPFg1t7
/x3RbZWYubRT/SDxa5X1/i8Xhtajae9oj9FlLkyKX/lZebZCsKr0TrkqD1bX
nz6o8W4BUy1QK4fwf25dOCc6vBOac7qjSywH4G2ctfW8yyPYFuRnLCPzhr7X
bWgaFYe9FTPLRkienHpuqF72iY6GT5PjD0h+u8hP3WOv0I5pCd5OcjYc5Khc
333HswKa0WdWXg8j801ayMhnqBi6li3ZWiQPqLu/Phps1wCRuWUdwbVcqKfP
v7l6RztGxE94msryob+F7+JmVoHaXJVgCS8eDv6SHS3ra8eXN8oqBjfIfLig
7zLTOwgFbRue19hTGP4cO8+vqQKLbiTRGzV4eGxsqWVl1gXjLvMjB6v70Z6x
VcMtioFGd6d76w0FUNQ78C2npg0N5yUsvqaRfmJ43AkwyQJbIZypRfKUsqFi
q9OTbmQLKlWO5A1istXcwDuSCYbhmZVR70n+a70nWd7MhsRvqQ08n49IDr5b
N6s4FeccfT1zk4h/fXydHrOtGjusQykvkg/GLDLfR15gosQ2n6Mb1ofOlVOH
QgM7MG7plniARWF/5QVGr1gdti1obfF/Qvg3/+wOYe5bnLWc2swn/tdT3WRK
5zULrL64v65pxJ98yt3tWpoJ+/eLbXWmUbigeSiPW94FhrBumMOQAPKpPp5v
/tUgNjN/MG43yaceOqL3mdXoy489vFmCvD9VHNwQmADHhtCUpE0UbC5y47TN
aQgQ3qL94hEP1AxnjS3TWAjTNRxZyiL1epl4RkWkCorK/PLmFaS+n740XGcy
cD+tddeWaYRvb20NJWQroN58wPvYUwod4+sFusUF4CaLCvVfpxCS8vDzzwkW
Pks4S17c1wehxZMdI/qXUdQ+wUsm/mlAPVPllEgiTBwfPHxK8gBl/27w4uEK
iEU4fDcKIeskJdev57vQPLBZZ92KNtxtq3zJlCqH+fZXSt0z+dC6XZV+kpyv
K8Wwji1G8u9i2kRBajEWvPkt2nWJzK/mOob1Z6KHlMnP/nv9oG0J/fm34RDa
krIHZci8kineExV4uQI1mjEP0gp5cJC0WjmvtQPf17Zn0e0FuDnrUO7aK51Y
8XvV3Mg1XzAamcmdVOzE9x+LGzbvEkDu/Wj/v3OvMTttUb+IHoWu+C+36qzK
UdmXwBt7R4GzwXajlEYX8jRun18S1YfXriO39NPqsVyek7SD5LWgoKSFNzTK
UTrQ/e57J5l/6VqMZcfykE3lDl15RMFr07vW1zKNSE5VmO22lPiBmzbdq9dE
wNIpc7PaKcLfRCU5/qIK9Pz3Ld958v/3Uz/+iMyGDN3PoWkP4WvhySXSStnQ
t5gWGkHy0M3gHpoY+wNYuubrzT0HUee97053aitCxs75LyrnQLPGOO9ofTX+
mdC2u28m/VjGfMWeSodO3C1bQTiF25VOHrlX6UiPTu6MGu7HLtttc4efdMA8
L17vp+InPLGx+LqQasXbD9pvF4gQ/N/mN1ObcuHlWUnfRPBwbuGr6ps1IfNE
jUPYWj6mWtzV5wS14lZVQeOsT0S/+cus5wtlIuX9GdoNkgfZCfpPgsnvBVzJ
T7uhykeA0i89WW4QFg4p304i5xn5tsY9ezH5fo+Qit+nT2DRrmkyxApwfJ2b
6x4RPkbCum9pGtSDHbqf+Yfo2e1xtQzlODqOv5zxz76TA9fp5rzlK6vBzRiP
zKgjfnn09xr1VV3IcrqTNE27D6MTjeMh15gYNAzVLlWiIKWmOO/3uk645ftp
TW7kYFRpuMFfqhpGvzebPSd40EdP+xfbMHFwkum1uJf0e1BpFz3SAqZHTFLX
kX57ati2+utoLYa+LSwqDCL5PyfT/GxbKRzfPWC4y/NxZ7pxt9OiDugWbz2Y
UUn8fLb0rb/51fg9XUOwPJUPX7XJcLHDLDT2Z+5dGUwRnbUdvx9XiBEW+sf7
eQi4abr0mlI89n5f8SmJ1Fty49hMvdRqfPm2wUOa9JPu7KKYz1Pt2DEj+rCh
EQ9lA47859fa4Oxh+/F+Qx9YR8dHlsk2wiid+zVeQYCwDTZ2McIdYDuX+DUs
F0Dp6nCxmmkbZOsveJnWcKDjO2iu/KgQbGPmsqckX1XOp2sJxWRh0Chd9jVZ
s32v55sa0pCsxWk21aJwcPTbZUPjSgysv/bPkOxn403aPQe/dCwSX9UspkLy
6WhfVL5HE3706F3ZLMlFrLb82KqxJKQ/ubcsjOiN9fHSD5p2vfhlm5sgZvsZ
VLADTceIBZsy4arFV7nw9uPeN5tVhY+svMxdJD/nCcxaZ+oxie446w2aDMLw
smlGV24aVh9y3fmT6LVZiIR3lQMDCpFlXYNZxM8UGo0Lq/VAq+RjH7t7EF8K
ZdY6c9thvbSVq63NgWJJSPa6qA68vKJxOyBagCtjeU1RDSRPvDa+o2b0//9L
K+NNXDoRidof8VU8FDGFspb8akPKl6O3DR8IQFtQoNjW/hisoYsZ0URfQ3WJ
BR2swbXcQxKWUhTMd+j3OPOZiP+6ws9yuA/t1pYnVMTY0Nl2cnK7Gwf/A70c
IAA=
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81GkbxsmGiiiHxLIVKZXjYschl0QHKlIR0TKdKCwRvdZam0OUHJeX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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lGsbx51S0ZGlUMlEJSIiopWfJMkpIaFIUzg0ScryqgjH0pAllDdZ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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns0ldkfxit0G1NSU6aLW7lMmEruaR4ZJKmlmkmUxiWZUCREJSWSkqgh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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k0lA0bxpFKCElSSvaXSlGUii5LlEKWQsiaLCmlspO3jRZvi2RJyBZR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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8Vfkbx4WZRBmpjBotxl4qpMLQR5NGJVuWQvYlolAK0QwliRhFllLJ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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk4lekbx4+ijbZDzZSsZawRM9miLyojhGkkypSyhJDKUmJQktSJJLKd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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lWkb1jE0kkiFduaTLTOlOEXlEka0TTWWVERlyy7EWItKaqyNDC2y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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VG8bxhGFUEooS1FJkWxlzaVFIluEwk8U7Yu0EYpKiwqphCTZSYWy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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk4lekbx4VEm1Ep04bKOkKFyQy+NJoWKZwQlWPsWxIVSbZSOdlGkoTQ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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk8VWkcxm/GMg0ZlVI019oMQsoSbY8MZUnW0aooZY9SslWSUKRGmEi2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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk4ltkbxxEz9WpRGdllslUGCdH4+VomlaQsw4wmUdnfarS+hYnQUKiG
qVFCsk5IZMsar53XzmsddJ6KIqGJRHN+fzzXc53rPNd93+fzve/veRSPnrJx
FRIQELhNn/+/D3g65A8ttYPl6DyjwiWwU41dd0SbD+u97uKdUgyGs+7y3og8
hFZdvWuVM4HxFU5wal4/5EX3yeg+YeARmfDCoaAUDT5Vty+wCRJcit6yIyLg
HL0m1+sIQejyB2Xac3nI2tQQftydQO60us/SUi9khZ0WI60YnH5sOPJ4czbc
xvVVVY4RPD0esJ69jQsTqSYpmasEFZsSW6xNu5HUaJ9Vv47B8oVdfltOPYdm
kFKU1GkCraY8m8BzSWDLZ9+fp/VZ/vRI7v2dRnAW4wpOJxLItM14z3V345oO
ny1O8xn3R0sfOtEBvktljs0SQU4REzC5vgs+Z9s1Sul5W0nzzGXdVPC13Gus
XQgiT4WKL9a3wcubWRE+SsAfnDVSdazGMhVH+9d+BMFzrudrbbqwMeGivscn
ggDN4IvLQOOv9SsvnSaQxl9v/NPb0TktZZWSRiApf8DMOqIF6jfrxuNqCVQm
CnVeK1aiJqmrknWBoHCCVWrR3A2TAbe8SHkGhnLLfDVvtcD47vhWTfr9jjMz
DcUmrTB6x9P9poJgqlEpUOZECVRCF/oenSAQYG34bSLKHzPvmlVA+Svlvdx2
a7YWfzju1jweSfl4TPdmuQ9geJ9BSK4/g4NPwx36BR7jEzcwln+UoH2r5dod
k10wtl5RwBenPDRjWvN7KrFnUchT7BKNv1HihrRxFwbOabnUSNJ9toYa95d6
OErWtmy8Q2CrrPXt9yN9YIvtnciKZXB4Bzu5icuHpGLzw94LDLzeOoWVJzYh
IJib+i6BIDtav144+xkM7Erq0r0ISu5oLFgcb0OGWriMbC+BcNaRqyMlPKSU
yZgW0vOaRqTpukS2Q0hf/soqPoHYrsuj5cGNEKoQD3lxlyBtTHj/nXvVGJ1Z
K7IimOBmVuXJN23J4GpsKlyi/aH0bYyhHqsa0VXxqiohBJMh6y75WvdhJNbo
H937DDhlH1yHVqXC9vKWXzWp/rP32iTMmDzY/jjT0udJcNsrOXM3rwr33oo2
BvvT/PldnqwKPqS8Q0J7zBlUWhX3SMXwseZk34tSGwYJebaeb73jsKdYoMSQ
5g9tDRTo3dCJQJVyyXZBBn4ZnHyn6nZMDsgHP+IRDAcEWXHk27F+al+fajOB
iL3ZnxVHOtC3MmmV3zyBXm6sJW+U8txNhkREGAyVPV9/+m0PKkRedM2aMFB0
Zx30nOZj4yFpN9NVDLa+b7G0iGlAmeitdQdvE7wU/TQ7vdiJMmdRbQW6L6K+
a8npHz6mHgtFaR9jUDYQqSC5dgCF4ekx+84zMOKIM7k7O9HwIFP89Rda34SR
gbh5MoqSPV6YUD5xgiM+ejfbcbZx2awJnSfj9TfzmnldqBXX8xCcIrCKlZgl
tQPwvBVZ2VXNoGZhvLavuBtju+u+3NjP4OTkKw7zYxs2vlKcMyommNCSyDHm
duB7OTmZ1SwGAjZaOw5Z/YqBDfbDOrSfTQsWN7Fp/XoRPO3nsgzSdp3/Wl6s
HFviXS7N+lD9J089H5NvxVfP3nfZUp5zpjfud/ZwYWzOXj15jfZDtr/xaO4Q
akyruYW7X2JgNrfQIIULZd2xsl8Cqf8Urbx71L4XnDCZWoUzDHQMc5f7+pbj
rJ9VvT6NL9BW+7QwvAY6r+ZSLH4jcI2WevdNShO8Pn5MEIilfKzT3J92XEFP
1Zm6XbRey0ub/57X5eFwfKCC6BPKZ4qtJT9YiOXJ+v+zo/OqFNSoWDbRDI2n
TiF2j2m/tZ+TvZ72HHZqmRxD6i/Satv3VN6swsH5qubv6PqHpGlPtwQebCJz
Nt7LJbinR7Sdv7TBPdO5KH2E+uHimdS50avwXmd315bmP9jxu2Zo0d/gG3p8
6aJ6ZZd19o66FiE63K0/jc7bTiuzrB0urfht6HN3fDaBe8ifUacyKtBgH7xw
4DzBrX3by1vj++FCig2+LmSgPmJu//vKHgwLv9nq+Z6gS86y+PrrWvxlqTuV
cYP639Sd1Va99Yh0UEhriCLwP7GCFSAwCIf9l3p/Wv0SWt5JcSmbC6AuWPph
0I3A42cnqQafSkxPsvce4BAc5ysNsiJb0bDI8hDqp7wnozKg8SfsJkrm0+h5
xMc59Sp9deDomtu3htF1yqk155/1IqzJ4pq2AYOvHn6XvGt9I7pfm+UlU95W
by/vN1SvwR4hl50/B9H+GOX2zIu2g60dWhA9RzB+wqT34+1qpC07mavkS/3r
QXqRegwP3G0bFqKonrJxrpvVbnTCoerbwhPKDAzCs7wUqtMhnT2WPEV5Dm97
oL7zVQGuFUg8U/Em0A/5YGo+nQ9lwZgNJ+l9x8lVW6vMakHcL9+fc6D+L7Za
wsVEivLmc8c6qN579HOlPU73wPKKoPqYBgPL1uRDko08tN09lhqUTHmGHR2L
SGqC5+erxyyofzsn/ZtoUdWIDxlWXhY03nI/E7NNyg0o2KOvJh9N9fY6fODH
eB6UhD5EX8yg/eDaGQ3VQqgtkSwW1bsu1aNnxC8Xy3vEOUGUf07icGrE4SEc
EjETNnrOYEDo2NkcsRqMb5cdPk/v3x35Ws/0UwdQ5i6vOOvN4GbCmvoLdQUo
0Xxo+QONd27s08JHxyHcT92tIzPD4NPWwGzzzx1YmWj5N4/ybU+9yMT5cRG+
Jc1bkPJfyoyXeyrfBV55s+oAnW+tMM2JbK0/cNbkq+zrVN8v85V5Exb9yNJ4
5C/9O/WH0UExhtOOc915gRbU/yoMG086ri1GzotMsZf0f8NJqubifplipItV
OBrTeqZe1hFBTiUejiwInT1Dee3XHfARDMFDrcFpSxq/8k6d7/ZoPvr2CtiX
Ur8bDsrS4RrWQmK1THT5dQKvjgDhmsx+8MIkiYMtg2xfZX20PcGhmIL+NZRX
q5nFv5/FnkBHNZG9yZXgiMHVpHy3eug5Cipcj6N+Y319C6uSDxXZhHcTtF/+
A2K9wCk=
       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8le0bP0ZRWRF6G0RISIRI6kuhlN0gyZ69hWRElFVUklLqlZASSVKy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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81dkfxskyimrSTBtlyxZjaVL2BxFFmSRZI7KVLRWRStKMiphSYxlL
UWTJOkZIt3Rt1869rp37PZKWG5VKI/2+vz/O6/x5Puf5PM/7kfMMtvNeIiAg
cJs+/78FTp9NjXx0GCuG8xbM3QlWkOGezshnCPeOWmyQIZBP9IvR0B/Gv2Z6
pumdBNFfj369RU7CypOd2HKYYGazIacjvhP4NSEh8jqBYWuNKL/9KfZc7DnD
/JlA4FyJv+qDUpRUKm+W1idY4xZS1CvMRbziTrnhpgkwWIk+6pcLwLdx48T4
E1iYb87P2FKKtZJDFaaOBG+HY85fmmejVqshn5PBQ+508/Hwnxjobd9h5xtD
oPek/Mfhv7hgLZrlnfzGQ8DRlWxmzSAYAwfWBUWMY/q4lODZoTtotaiZi3Am
cB4JXoy26IHIBeEjxxMnEX04gv+3XyrYQV5pU04E3KA3ZWlxDDgsMavIKSZw
+PzhtGM1A7w85cJKbYIuToDBIrpQWaRnLzFPYJNzoO2a0wDkvZYK3VWhwGiL
YVnyj6PIwEHpNa3Pb9Ki/Peu/VBbX3KWr0ZB5/PtD+8FatHCFOXKWxOUtova
N7vmoETar/mpB4FfqHXz2PkBFFjtsrtPTaDtrMLga1YPKnav1GXVUxDw9jAR
L8vBJrmCTdwwgh+/u2Wzq1oQO9DxMCiHwgb3mHPirwchdikgNv4KhTu6VlE2
xWxc6ergt4lRiDW4fNctsA9ZSWoJah0U1E/LeRjGNsJWUf/2970EL+0/FVy3
bYWQdPYX5UaC92K3fF4+r8Xr5OIGkW0Ewv5Ndm7K/ZiIvbxq1eIktp0Y/Ryo
x0KH4VKPVl2COr93v7Nya2HPTNW5aEgga/BBac7rAdLEi3fcDyBYZ+j+7vu9
Iaz7VCVWPDKJvliulppYK8Q8j/muWU/re7vN4Yfj1aipiHxSGk4QcyJNeWik
FXG7F3eLDFJYqIzSSx3pgIjLdiuZJILm/id/cX1aUVT7+AM7gUBdKCctuYSL
0crkykr/CQjfkbojv70bKvNf6i1pfWZGZi+oR3IgOq89av03gRV3++7W+n+Q
I8LNbNxH8PTt9KusuhGoHmgU9Fs9Dt6vouOxllxsF6lNuylCELe/U1J28hH4
nfJdYrQ/n5+5GN2uMQhdLZl/lltTCPAoW/2I34/7GmrsuvMUokf95LZFh+G6
91PjGnq/dXZTz3bHsFGgsunJbBIFjdkrkscutCH2e2DS5scUml/ZPxNXa8TB
J8Hemv0Usu1tbZXLOvHfzHgu408KMYIMHZHCLoTPVQuFXKUgq2Wod+hhLurr
zzN6fWm9s2JuTTE7EbG21XSCSaHBrDz7WFAPMjI+Vn5dS9CXUrljhR8H/MDm
AJtbBOcywWrRGoZKES9UtXYc9kLCIR8DOlEl7+xvTeclPyHHlZ/fiz9cHG54
Or1AypTwXIt2HUyuKnUsMaD1bv7KNqhvQcDpDWpv2wnO7A/Nd193EwpKth1y
dJ7Hj2/dE2rchGULnUsHQgkcLfyE5rubULb/c5HLiknIcvS9bWgePJT1d95f
T+sT1M1qNu+GQrD09CY2/f96HnMq6x4id61dEKHnmZmY8WTFD6Iq1OOEvBAP
XU5/lzHu1iJoiZrR6wUKz7fcl83V78bzNTkZmRw6b4w5pxvbRkBCa79cvcjD
1oaDeRtX9+ChSZ3vkXQK9cy7+su0eyH5S7a12r88iP2wNWlepx8yrxj7EqV5
EHj504WGPb140XjzDUeDgppplEKhPhtvZlOMfNJ5iHtxJkDUgg1tgcv6Tc4U
VARrIprcniPE5cByrXEKvM4+yvdQB7T0Ui3n1CfR9nPl+ccTdTisQzl/n6ZQ
dGuH8jmJFigJV0Uw++h88RqNnMOb8LvpGxnPPyhY7qu8/5NkO/yOeXgoxtF8
GMpVywiogv2Bup0612heL7R8axrowiuHCjltJQIJebOD4zdZeCxe+D1kjCBs
9JDRXHAr+HLl88G0367FnRAxWeRij1HNlne+FK67qO7/q7sVrY7jEQ9CKBwZ
0s5WvDKCzq428cflY1B3kma8LmdCu9zINk2Pnk/GvHmnRhX6hx0k9lrRfHM5
1VFY1geuVP+xjPIX0PJe6RA5y8C/8RvjtL0Iip4VBNvdeg7rtzbMDXIEmVcz
Uxqyu3Fze9Leo1aT2Nuf9zCrsx9SxnXr2JYTiC1XKLzkP4z+LAsbxZcTqLZz
FK1734a09bzPrhoEb06NHnkpxYXBUfnA3gEeGCZrkwfL0tFYPhloTPP2ZUEE
Y/DoIyQlbtRsnaNgtnlLep4jGyajG1WjNHkYNw1RvXGyClFhjotBNM+5HkTc
oYuJLA+JSWkxgiD7r7qfTAdRYxN4eJnqBLRyoks8JC4hZmXfHV9XguQQBWN9
1jBktwi7uJXyEK1bXahZ0QZzi12/VI/RfGbucDCatsJbivdAg+7TcYEVB+95
tWPh4orlwSvpfGxVxjzaUbZrc3hB0CSq9apTNugyMWGuWsdSoPVaapKeSQZw
ybE8htDvt2auOO832w3X+E/9bm940NAMa9IL46Cj6Orv4mV0njTm0kPnylB/
1j3aLIKA/1Fv1TqhAfAOhn4rYvKgrpr2duhpO9ampuyVvELQougupSveg3pj
3oV7J2g+qfgbb20ORYiiYOISmk8B0tpVh051gpya27ctnO5H5S9CYx9LcLtU
fDKZ5vG8Zu6uawZseNb++c5WjAf3ipSKqI9P4cz/Np0/RfNIPdaeE5CPTNdd
ngdPEjD8h2YKSpNhVhJlr3yU5rV/rFFk9CPIinco6pkThK+WUrf9swfCZ4d+
nFpNwYNjXnZmOxMuswkXvqnQ+3Rw0z1pUo+dhkVKHLqfoj7lCwrL9qBHSNw6
ZDnBqFozy0moB+wjfyztc6Wwb8y35r+HjSDqRlLrP1HYxpqID/PpQXSGxA6n
QDrvPikSY4Y96HtR7JUnSEE/mHJLuM2h/Tuc9rMkhZL3v/1XnD4C56wHVpf/
of14P9zqwCQHM3wftaWreAhZlrqG2t0G4pUYTqoJru+/IWPpysRX5dU63jS/
GcPm8TbZbRAw0IyLOTSJ/wETE7f/
       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs8lGkfxieHikpMJatyWgppcyhi5aK2kp02p7RZrBXFS1IreSMUNqlE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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lekblqWE0jYqKYe0WPJrUcjkRkqjwkgok4kjWU6y01FipozhMEay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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k0VW8XRoUoCUWGlBTpVymlCA8VSQMhhQYRqSREZMhQSTQgJGTOUEim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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk4ltkfxiVCaJEQpVCmJEsKQ9ylIkOjka3JVhgukshSaCERkVDCYCLp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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lXkbxlFJKMtY8tYpZFCq1zKacI6rN7vUlDXRKAYRlaxTtohXKhlN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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lekbx1Eik8LIUvJDyTFIVFJTvkSoMZJJNTnZ18audNGmSWKYLGGO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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k0FX8fFqUiJVla6KfNliRtKB5JqFSKJCTZi1BJKiEkRIRKIip7yE6W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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlns41Nkfx10jpdyy5bLYdiu7KmxE0tstdt0KXRQpQiWbFiu1iXLXZV2K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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lWkfxk9arEkmUVlrRsgpypwsk6skQhpjKd42cYRIKglR0pmcwdvI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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkbPyolS0TfJC0jocRIi1LJj0bLaBpKU7ayz9jiDE4Kg1QmJKaQ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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lA0bxSUVIkuvsrTInhStVDhEpV57soUklSVJRBFpkZIkSVIhCWVp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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk8ldkbv4kQyjIGiQnllxhakIgvUVTWyRIpzKSiIjW3hEqKMLZspUwo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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns4lOkbVvkpsdUuihxWJSs5n5V1kw5TQsiabE6hsh1QtDoocly0jtvK
iDZqS4qEJIeMMErMGIYcZ77vS1I01TpsRu33++O93uu93ut6nvd9nvt+7nvN
gRC3oIVSUlKX6fX/vUprgZ+TUxeSS0qv+L4jkGpm5/y/24P4d7jlR4sbg5Ax
0P21woiPdepr2FahJDTd23de78xF3Jvd7VH+FDSpRR+2uXBg+Fme7DQjUaIg
OSfj3ocm1oy+dIgI4Q6Lvo/YxcdhNbsHH0dFOJdsfuzwRy6O1/8Q+28HCaFT
TUXb0F9Qc9jEzfmZwvZ8fZcv9i/xz4otkg46XzS/aP+GqbuQtJwNnraj4H1g
glfn1ohN76K29gdQiDqUf4q5pROK2y+p9J6hEOoS6zKszofoAEv/lDsBmcsX
Su0au2Gk8I25djeBa6EeVzWIYixtaWzSc6PAXL/Wk5xsxOH0jF1r6XObIPAU
a3oIv8UjqqFcBK3798P6FjRis1GjatliCjmFGa2kDRspZ2QjbEpJSCRXWy28
utGwujHQYzeJgzc0ba+f5ONr9LGC9jQCCbWVmjqFg9BxXqWec0qIvPgwf1Pr
Wviklss2jZBQdnOM7n1QCa5NTrKtKgW144sTL9Y3IvMxd/n+OhLpyxdqMedr
gUuJR02XUHAdHyuIpeP7+Bg7RPtSiHw64M8q6ALDI18r+DgBP4lNbIJmJ0LK
PtzcqExCC8H1D7K7UJ2YVdoxLMKsnIPbNX4D4ov+MZuTovDFQdhQbsyBIM1U
Yv2EROro3L0qMRcfrk212iwjodgurxTYwodtLs/hgBSJre250pKfW/FOKsC6
VUCiKGh+SZbac/Cze98XpJKYZWTHT13hQVB0JrxNg4Bg/pLuNP0+dhjr4OUm
AkZlKaKmP1rQ1f/QS4nuf39xxoZhVx5Ms68fVLMi8cvA8R1r7vUhk2KMjM0I
IXyf+bpnw13oLQ9g1zAoPCWDrRjbOiFdvdd4/gAJqdCU1UbrtJApU9RhRNej
b+rkJc3I+/CqUjZ/sJlCWa+ihNnSjLl96VmOYhJbHom2XcnpwbmN3xY/u0LB
Kikm11OTg+Rdj2y1HSmw3UeDOdVdGE+7ZyAtT4ARp1rzu6AeQeUnla63k/D7
UlS8Mz0LG9eGld5ypWDbG1nuVTEIcaghR85sCGNbR3vG2G1gLo9U0JgiIF4X
5jR5sxyBr0xa5pkU/jVwcW1504XNOuu7A56JoCMz/EF/YADnV9UJ9kkGYL7T
b2FEXhcOMmdP8xa8QqRIg0yR7UP+zLV4ZjSNt8XyJyyG2qGszhjxDSdwp/Ih
b2X0IHbrOsslqgpR5hR404XFw8W9Zz4eeUCg72Zz6Ju7DThpwB35TJH4kqIj
smjm4+jZAd3cIAIcts4J2bJKVBQeqXA8SuGDOFxK/10/LGy7p/ZH0fgy9GwY
X81GXcga199ek1gZLv346LYB/B5WkyLnOwI/j/gIe2M+GJb1T1VqCawavpx2
i8uHeDbxVtFlEkb29S7V/WxoBv3hV07zhf9smZpMyUs0Hln/YqchCavUWJv+
Ex04WepwzCaEQEms8sRfld2Q7D9oeS+JQORDE4s0Ey5iFqzPCPxE99tgYVji
+VKcqMp2Mt5BYaIgi0FV8PASVVNiksDs29vm7l/6IPHeq3vRksQTR8KniFeA
COs79y330PhI0kpsjhTA3VnJxiZWiHieBo6z2VBe0xu/qYgCo3aLNc1mfJb2
Y0cOkLjRzkmK2jaIX2b3zadxhPCrV2fuOJSFkdSKmU/7KNTOn+3JrXwKcfvt
u6lTJJ7bZXh96u+AtIJJJc+YwonqkCVXb/bBjHGELZstgthR1rQjhg2zEc6b
sloShj7fsIf6+xC4/pjoibUIZm+/LpMEcDBEXFLLW0mC8fz5yhSZQaiV16lm
BdH3/YtWuLx4gQSXTBfrQ/R8HGU9hloXmJ6MgR2WBKSa3Kpcpy7AoXzuK9OH
QklG3/RPo1z8ZKxV2ZdMwt9PI81qaghznk3Ke6pFsDNbOJ7Y+AQTs/Hz0qsp
7HXQi5C3bYOr9l1Tg50UxixtpoWveMgvs0i4bUSi0seSkZvaA4n0w8OiYALZ
eRZCG80WKFQPHT52laR51Zr76Z8mLPnTMUV5nJ5fQfavW7nNSPbxd3g+SoLz
6UfTpBIBUpYt7971HYnddguyXPQeo/pO9k4Jna+xUxIccLUP4YdztDcWCNHO
+nWNQXMnik83TDrzSTDf1vpdUeFCMGj9p7QtCWfFYSe1QT7c9vJdZT8TaHEd
s3uVIUAarnIvWJCIq3rUwF7agdSkx16L7UlEBg847h3txN8iueBz2gQKmXIB
Oc8EME+oj5raJUJrgfx0tlkjuvavm/DLoHAtJ/TNGAQgI9W6/yoT4QlpWBji
24beCf3z1dcprNCQbh5wqEOKSsIL360UuIYZxjrvamC7xE82/RWJMiNW3o+r
u7DCNUflxksRhCZZbXf0y3GeLF5x9AgFc+32IbXoHnj+PuGm8z1B97l0/KSj
AJNDZjFpTULoLDS5MiHmgZmpm+xN61fWorhvt1zgIzOYYaX6la6vs2S58aEi
fJuzrrfOncb3DsFTB9NH2JHVcGObCQUdb9+AQ+erEFPY+b3pbgpJ3RWySzo7
cUi7jLdCmtZrY6HrDLMHCXklAftfC6H2Ps80cbwLocc+vR+aFKF406MnL1Ub
ofir6vYg+n/iOfsAkX8+3sbpRYe7UEhfP37xF08OVA2HC+VpfHyMuxdzqYYL
510vToeM0/ovP+AU/K4L6d8Mlsy4ElDSSH44PMPFkUlfj1GCgJ1xDHO6LhHH
5Vb1iL0pGv+cPZKUfijJ+v/witYjxWuyaZUbOvCVw5qO8yDgHHJ2q9cIByH9
lhHpYyTcfRc068p04W+txxasPbQ/UQhUv2Najeh6JRGL5t93eh5VExIenkpY
d+1VCBRJ5vK9Y/qwvez0yhplAnriDnX9MxxsMSjw8abjWb09cE429QHagzer
3NhI+5vtHow3F6vwYq1/2TJDCkut97HmHnFxWdXMcPI27S9CzXmbFThorZEe
Kw2laF+yQVYvqxdEerBiSSSF/wC+ocJi
       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs8lGkbnlRSKvYTq3JIByWrjSmrwmWaioYvomTLOlUqOaSECjl0IGpJ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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k4VG8fpiRbUVESUaSiohBFbrRZWmQpWuQvhCTtqBCihYhQIrKlKJKy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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk8lWkbVkJqsmV8SM1RiWxRDF+qyzYqES0YYkhCKkvKUjT2JFkiyjJh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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81Wkbxg9NKkwknRbNvCLLyEjLKFqukq2SZCqplJGtkCUVGi+iJiUZ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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns8lNkfx9W2UoukJVvUxEZa5bXZXxfb9hG6sEhFURi5bG0o93QhkUiU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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8Vf8fxyUrMsK3kigyGpSQFb0osyhpiBCSNJTRkFIyUpJIyaqkyMxo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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwdlns4lGkfx4cURejgUCtRORVLRJls30pHUdSgrSkiUeml3ZLtKKdaciqJ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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk8lWkbRqHlUD4jUkSIRknkU5QLY8kW6lCTfY1GoSFtluxLSWWksSRF
msiSypYcO6HjWOJ0TOec941CJr4WSce83x/P7/nn+d3PfV/3tSh7Bx/0ExES
Esqizv9viZOF2o/mOPjbfmfqN2kCxjt2NZxMGkaRs6LI9CIPy1Oft4ZKNmCl
d7ZX9BES+4+p0Y4ZMiC79v47hYcktLNDVmlJcODto6o3W8dBiNR8ZsG+Qbzk
mt+6K+BjXE1l7IUrE5LlQpkh/+Oj0GaVNONmDyxlxUVb0wn4rTWM0JZkwdvr
q/7DjW8h+yVwNeHXh4Mbgqdpy99C7une4DhBH476qEy92saHoCmXHt81jPq6
NsnzR/gw2lvR+VyUgbpVGsKW4SRG3uQnyjm/gGnL5HS+PgmHE5ezaFuHoNs4
v+H8Bz6aOjwMXU6PYbU7LSehdwyLpfslFz82Iyv76KpnXAJN+rS2qughjOi5
c8ZsCbzcn68piBrCgnsecb+YBPONTNgXlXrI/zo8yFMmEUB8X3/aog7Csw6x
ARYkYnQ2ykV2XEXTZgtTf1cSnXbleUFd3SgoXel8woRAhW7SndkvrZhMvT2S
I6DwttHP7949jA6PFJlybQIs3zWS+ZEsKMfvuh9UTECUYZ9Bn+xHxo/eKOdA
At/N+XyZMSaal7d5+DwlsU08955zdwt2Ou4z891DIlmvLLfkv3/Adc+UhpwP
iWrpJmJ+2Qg8XWQFKZU8OHzv+NCqPYKi3IMB2Xt5aDRhvOtpHsDFsaXeZUV8
BCiQYY5LPZA/oGC5KYZAyc2oa0NL/RBele0giCGhNLHN3KPqCeQv031oG0l4
Gt3QokVloTPUYVqW+k/VtvLt/JphCKR8UnwNeLAOtQpxX/0Cm9P6PikXEXA2
8VE4ZsBG+MNdcxf4HHRubsM/wiw0qJcnJmTxcfFmAW8hrx/pN2z3lBUSiFIz
KMtz7IfkvfacQ+cJbAzgXJEw7cesKrcyuo4PKaelgd9kylDR6a7SeJoEvdX+
WpVUC6bzzAzkYyl8ha0DNBk1aJY+dc5uO8UHRpqW9vurWEF78qPWk0R43GFP
C8WXyF3+mVa9kcDHa6xoHfNyKOcMB1/0J3GEltF+pK0Bx7wzha8sEZhT3NTX
k9aN/Of0BZ4fgZoK09rE/hH8fP2lnus6Lt6FcY8qfWzADfEggtVMwOwyDivp
DyE9Z9GvzYSH0mSRwx2jLKgSYdNxeTxsic6cWk2+gK3IzjNl2XwYzJso7Xg8
hJgB87CCHB5yLddF/nWLg/HK4n3fLnLwrWbZ4PJIBra3Wh6WOU5CKNByRdVk
HxwE1+7Fm/Hh4J7uwdrbgRPkgpUPi4ACUfzaK/wVBvM5DujmoVpDgp28YhB9
7NDXxwgeBEPxBmfXjSH2s9iPoNQxOMzFm8mH/QUdoa+Nr5xJRKx0tTM++QqL
SsnMpPd8cNW/crNVBrEmVvGboQoPK5RPafrmMzA9VW47L0fxcaGg1F23H2u8
BjxK6/nIuPdwbuJzCkyeKO1pp/QQ4tqs7RDEBM9qJpdF4X3ibcrOTno/dJpq
9rqcJHDmt/e/WnhXol62xPa2IYmCZqeg7AgW5J6pKZT28WEm1eG5QakVolOP
0mzMKP6Nf3g2GXgNw966Rhxqn7HPKx3iLj1CZtm5ruCDlB4L7nrEdJbD6h/n
GcYFEhPiDYcMNrGRGNBzcyiVC6VGOXt4ZuFXzZR9oe4UnrqTLk5lvYga2aRo
FsaHY9plWSsNNlX31c9iYnzERNKLMryC4fDi86KyB4mygKqQvIBWcIpoTetr
qfnM7hfLrWxGmuK3vlpJErUiSeHqW5kY1i2f0+qg9Ok17iLh1IUfBa6cWXES
7855DSr8wUTU6fPxNnM8GOVG2JpvH0LnFWa0yygPdP8k0+a4KlSzzhbt2E+i
Znf31cymOuR/4HxVXk9i7ZF+93PitVi3OeF7y98ElBhlS9GbGzHRGCPWYUCi
+OJTg7EKFvayPn28/jsfI7cU5f4qbYdWTqHgIeXPwRLNM/qaL1H59n6c73MS
Bx3ejFo8foqS1VY1beokPpV2Vylv6QD98QSt0o5E3gFOdb3GayzfWSNmnUbh
tWzPDbNLT1Dd7ZeToEHtQ+fqOVK6BBU/DZRVBJCQC9hRYefEREDfuKoumwfn
3btGn9L6kKEdYVwdQvmJzATdevYRHqT/rL3VkYRxRPwn+/hbMOBdyHdzourH
iGrleojiUn/Mb9oU3jWZd0WS77bDJvdCsi7lp0L2xY0lY9Vo3T2ceF6RRInp
1umBB41IGCDcuqm8Gqw5uLq1rxMhdfJubCMSQSp3WjRWMuAoyf9yyJ7yc1nz
MV9aI/SlRWQE8wRK33guZFUwsbOde/0wm0DPjhMbvOrbcCP1FKs1hMDIJgO2
TsjfmNM006sZ5MDGVJT56NkoxO5ZlXCo99rZfFafGhNCtVoKCu0EruTqjM+I
V+FTjv0dW4pfZyLEvvKNynChI573D0g08L7TAogijHhf9Y9xIZFhuY4XX/8K
qtE5LQ+beDB+0IdwbjNkf5lx0rlDwOJPT2+76/1QlOjolT5FzX8gPTyx6yq2
nEk4Ze1GosI2nbEx8AkeBAnEf/9MoFC1a8UBMSbUx8+lJnH4ULKenWtdvIFl
joN0E0qParUj1qnObPQKkhoCX3AR+/747OlMar9n9oiXUfngqt3pz6wahOYW
iY9Tj6k8cEv1PjXaggOybT/NlRG4FKpUW5HQAvZHvXipZBLZ0aZGb/JrcLzR
2USayqO7FxU6EqTq8fW+clj/Uao/FRb3aF41/K4bqqtRfpFs3rKgUNoL1e/j
Hn9O8/GL1BOhpUoOZh6xHDsdCcStdSYjj7IwJ/RhQpWaL5k7I2grHMI2msto
7G0+4vMjtZSGGtF6tv6ID5VHLGU3MdN2NtZ7+YffM+aiOs8uTfX4a6gI/4hs
6uIicPRsqO8fDDSus6nIniRw/PKhAsftVYjfZZXzmU71p1To95N/NSZ1Y2z8
Kf9Rm7psl21UhdQNeltSIkiIGsrb0TPY6Imtu92uw4VxooWb9tYo0MX0PT5Q
/BQKUasWfGHjP+956mHf3uBfipGvoA==
       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lWkfx1ERmsSLiWQQES2S0qbvlUmDqBkpKkX2SrY0tkZKi9ceQods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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lG0bxkWLVKK88aJFRYgSpUnqVCQVKktECaEsRSVJSGUf6SVKSmSL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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41dkfx2Vs0UhUI/wwlCRJE36i5k1lSZGkbNGQIjHJmjKlbCUToUW/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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns01VkfxuUSJYqSpHIJkzQSGmLqEamJIWOkRiqSS+5iyuRMcUbCIG8d
VNQQlVsI4zCuidx1znGc4xrn/H4oR725VITm/b1/7LXXXuu71t77eT7fZ2+N
c0GOnuJiYmKp1Pj/LLPzT36cKgtzPiyvM8dJ9EnNdEsTHJSOJ+91yRagcnqD
uJjpK9y41SbTsY/AYE2wllhtD9q2qN2XWjGGqYLhjyX0FiS9e5fy7RMCP/2x
nNA9+A/4zga6jttIXEoS939j3YiyGNuiWE0SKrbxDsccWPD/nBgoeCfE+LTz
w71n2DBL2y6UVyAgeyLG+VbiK5ys2WvXKUUio5OhINvFQfzf3wa/ZwohzWyU
vbe2F7zMxbFEXyFY1f88zhY2wy1hPtz5OYHMbDunkGcPEC4I2O30MwmHiugL
qbb/wUuL+Yai0yRkPvtMVCu/BE0/R7S2ikCChnxNe0MrfAUfq5PsCcRUtZgG
ZfZiUXnct/q9EFWHIxihMxw8NhYxfexJ3LFRpAmiKvGUsahRXE9gtTV/6Osh
Fi4vo7RsE4HC6dB9bdbDOLYx+tXwqUFMTXI1hiWacd7cbFWdPwmfoj+OJJt0
YEH5Z57lNgLyxzgqdHo/yvlHxL6MjMLhWFDc4yF3DB1mpJmfJbHGOHjr+E0u
kn65nmtNI/Ep9OT63lUshP+SrhD6D4EM+VAZTYUWaKrIru+1JMFzWH8hQ5qF
TYHTJhHhBFp/266Qs7sJxfuf0oavENhSZOvh6tQJy819BaoBBMqLmOz7d3jI
kQ7lSZQK0Mp+N/GhsxU7Zh/Tv4iReDCTdnowvBnOPbNlvtT5U/bZF64+N4gZ
ZpxkWugoxFzCfEQFLTDZ0pPsp0ugQeXOW9FwOt4f3p3SRen/08bz2euMBhB+
XL1h2yZKPxUp0arUaqyT25aYdJDE3R8lK19P9sJCzv22+00BAklOD3NDPxz8
0l79q07AQnksg5H/Ageu2I/tzCcw9SBgXMewETPbjudp1BF404vWVisWMpd/
LB/0JiDJuhXtPcVDT634lHaqAHOckbonG1thGaRU8lCZxPiL2HwD1hA+JRjv
8X9F4vKEY7BQ1IuoOqdtJ7pJfBgpKHd6zoRbXB79wQkSDHZY8Y9hvdAKMy2c
zxtFvcO9pN51wwh61ycIZQhALtHy8xnN0DHnJlSkUP6bzH+9rDeM2+ZFdc6K
o4h8OKFl8ZCPTFOP+T1Ko9iVp/5Q3YwFn7n0iTffEZh5Ov1HTugwukiNNdZz
w7B33Rn0VI6NEa7rG2VxAuPnRo5mebRiH4NRHnyT4nsq78bbY+WIM/zTaH8Y
iYSEpwOf+ngo0iMk59hCyGQ00Efjy3CoRO/33yleXfa60b7W96HbhvtlYKUA
ajIWurLplF5T8c/vRhMQk3y0+fTnEhTN7xsR7CLRkCOsp+e3wicrIsRzkoBB
Z5xx8gIXspI9hV0BQpy/P8dq3P0MDuoSSlOHScTqqS0W/FWFdiezpZM7SBjf
yHo2+RcLfW3LgaIuAmb0I0rtrnX4aWzZ++I+qt6uZXD32QHQOZrnhwZfI7b2
c2sci4eTs5wlp9nXSNPPtZLeWQrnhEGaYwSJsGucKZxowoHLbvO6qiQs9leU
eYfWgBWddt3xCwHiWbBmcjgXhvxJWo6HEJKK/VN7u4tgmm1r3mZI1Xc90qma
YGG71J21bYUCmKbRjZQ31KB9c8DBHb+S4DYMJx4I6MB41njcWkpfCc49QUEO
G5mLji88rpOoZDquNFfqBkf9sd1yDoHgbJr0r+aN8DdmqBn1Uf7o+oU7OzWC
QbfzCqF4yrVKbZoguajt8cxVO0rxtOJnm8SW5zj+NUNooU8ieDY6JKKNjyxH
ea0ciqc7+mXB32TWIocmt3wAJMSPGjG2lvYgbvDqlduylD9LV7tPLBjgloar
924qDxRbFvccrGfj5sSWPmYbgaPS64Olo7iocYuKsNxL8e8gmfmDCxtL/a/8
PFYQWMe1Lr0QFAuO6O3GGncS1/+8P9VXxIOWHG3r01QhcqM2HhHRhiC11L6h
vEQABzPRtb8PNuG9rTDmqjaJ78v0ilceacPb8a85NyjeArfoeKQdbsAeoyXP
7P3UeU+lpOxZ1YfSG9qMmGcCWAg1szr5f0O+wdeKT92/RnKNzOaQdlzz8q5a
OE/l0VX2CoWF57B3OOWr1UJg1FL+BdFxGwc+HekoP0OiaeiM6nRfEwwu0iNV
LhBwULScd31YhC5EqFyj9mvVirwZyOmHeC9DdUJfiMx28d93edVCvsvGne9F
ooIdw4xewYa63up05BFIzj/sovOoEClTBpm3qDxyNZxkhvgOYSrMa2Z7/DD6
FHVU7FVe4nWdX+DKcSq/vtP7crO5HTPhh6oTlwnUuHt+ky/9Gta8NXlJ5ZT/
s1vOuMk34geLwGd+QwS0S6tX1x3nQs/MvkO2W4j6S6RycTAfai9VM6ychJj7
1UCQ6fgcbQxxS5OVJNVvdq0bdCth4b/0PZ/ql/B6uRXOGnWo9HvZZmRHItRs
cX9ZMhvcb2V++68aiSWpoMsDF5vgb31mzHGMQGSt9VnW6QZ02i+2OS8QoD0u
dCzkcbH5HLkjIUgICxPv4orlONB8ZG37TpE41PHbGumLLMTra/c7GVHvWUl2
uE4pH57pkfp6vZR+cvTj4eQN/FcpXfSJ4kMlpLTYrYmJGBOOqQfl/8UTXZHf
ufOgXeua4vWB8u+z6UiuYTe0rH4pKhIjQF84wNo63I2y0dTV92YJfJiM31rC
b4ZNs01d3CWKxwHniJYdfVBqiZVg7xKC+a+e6PUTFixMT9d9bCVgX+RotUaC
hXy7nPGoQSHmFS5cOG82iO5KscmMdQIo1UipNhEtqIga2dBzndpPJKryLeZB
73vfvwyfUHzZMD3vvmBBs1fivjyVp5mWhtq9lzKR70IKulwovXkv3l/RPwvn
lzRHY6p/ImMfrVfpTwIvR/ebk9R6HvxTFbosdMSl1N+9TIAxu7k32oiN6x++
hGt0CsCa31TWWZ5FcXjtnD71f9jxtpjh87EHeZ63lppkCORKl0FbnAdGQUBi
Y6UAAyLF6fw4DmLqrzbffiLE/wDb78qs
       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lWkfliUyg1TWKWnzhZo2xUd1nzJCfSoVGppOhGQrUio+ZCsZ66RF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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWGlcTH0bnnZSpHq0kXhKiyKyRHElSZKEkLSgIgpRlArRIlFCkhRFmyTt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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41Gsbx0kLoqMiZUuWNkvUkd03DtLJViJapLK0p5IQh7QhkuXgLRVC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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns8lGkbx9naVikxK1uiiCKylJRS/STkUDoQrUMSpZySTrI6qGikZIk2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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8Vmkfxi1RI4lJvK0iIxMZ1ZDGcj2GqRReSyXSiMqUJULWFyFbI6PE
KHtpypAtskSyPZ5H9Gz2NKnuIwqhNKXSe/fH+ZzP+Zz7nPP7Xdf3d91H1c3H
7piEmJhYOj2+ntm1m3ykVHh4GjH7lneToGBv84EaIx7yWNNbymoJvEqmFeql
+Ygq+CbTuIFgldHlgNTOPnis8LaR8GIQrHyjU2+qAjrqygYVxwh2tVmw7p27
g3MXBk8dPE5gX6oT5PJuAAFjlasOuDK46Ge9dL5hAOPOCYY2pxnkS71tFt/U
gcZPBWvYiQRivjPzM4uSIRPpkH3ChWBhu+K7efteRCTe1ji9jUH3Y2PPK5cG
sHR12nO1aAZnsnSnnyk8QIxvTnFkMoGxRJj32O1KZDQqKXvQenQ/KFZ2ufHw
ySrP634ZweKExAV6u7lY2fVOXfZPghqH8/mL9tdgwmr44z+eBPmzor/sgwRo
H720O/QJgVGSt363WTeO9q5u1B4lYNuOGXzaKUSK+tSTyDGql1BMOSmcC35q
wBH9OAJLpeHbvDw2FCWG/P+9SHBYKBhdM3UFJ44ZKD2n/TiP7NBImWuHhbmT
dFwWQYpriHdQajWEMYP8qhMEnHW3/I+G30Oie8lmTz8CVmBlsYomF+evXZuM
ySbYML0nJCtzAPG3yvSurWXw32NFHxXKqtB2Rqzo7G8Ecx/992af4SPJNa+s
p4eg1KptWs+uGQHHW9wKgwnWhFeEnzoshE3U7VuZXIKLEt2yQbO9mOnhGlg4
Mzi7RuDu0d+EXfv3DI8EEtzfibbF439h3NbzXL0rwbBgAYslyUGAm9mKEdrv
gr0/hPu5tGCm9f3EjlgCuT+vrogq6YLrDbFzLkWUB5WHly0k+SiONo1ddoNg
yjS1aNGrcqgd6vKwo/6wTvilzJ0dQO/vg7G3gxmq63lfFDQgTiZqpRTtv2xv
uTqnrRf3xgp6PRcyOPfFk18dyof2JsNxN8oj51tJntPyJrQNP5CVo+sv/TLF
F5UJkGBrsKRJSOt9ZCoe+qEQFr0diypp/QaXmkKlyjkozS8y+ur/btFW83H1
R9BPX7OuY5hBv06ksPDWII6OJCk8pnzV7LL6pvu0EJkH1v8u206QkbslUE62
Gpz0pS5RlO9UK7+D5TWUl/OOjZmEXqcrqZkEipBzpO43hZeU5xZBa8r2DIjJ
zF0QUv+1b5Q82/6ei/hP8w2xOQT9uUOaTbN9+CnTS0vaiYGi4cmn75IL0eGV
9PdON4KA5sk2yWEekmYu/yJ+m+o32X981qYHIo03I/piDIZlJsSdTnFgOq55
90Y65Y3dZiTUC8Nad2UDY/o96+Ls98v8+1BranB/VpnBWHP163Tqf/K2jJjk
coKIrXJyGvoc6M6kNuSmEVReuGlYcIgDhRpfcPMIPLSkPIbuPkLSrBrn8DUG
BpN/eHjIVGLUlqsqR/3jaLp2sszZYLPI8yehBHnf1xoZ1ubjsfLJuDOHCU6W
ppM95iI4vYo/mTlDeeAs624tqEZV46mJF1S/vOUTzx2yLqGrXaSbQ+u12Tx3
aktuPS7z7M3eeBP4OHt596b3Ql5cZVWzKs2brqKOuQgRPnN57nHNdP31beZK
zEPomlRvLKP1ihzNdK4v5KFOq2X9lkrKl6p+RLFMP6SjPzApvgx6dOMcoiIq
wRp2EXR/5Q9WUhM+PbBTH0+4+Zkg7Wa+IEquH3fqR0ZHTjI4WrLaW2VpM6ZW
hu6bCCEQ19aoOLe+Fw3ec0Y1GgySAleVK30UUd/e3nlC9d0fmmhYe2UA08u3
KgjSGah33RlYqcPDZEsVq6+RQOa6brnr3Xocdj+9SOokQef2S9JrZ5pgcdft
1T9RBGf2WD3mO7FhfMhl7b5IguexweIxEZ34N6Hl5RHqV5WxhM5UySN4fKdW
4j/BoNVsbhTFPZCJ/U/Z1S/0fcqTkemJD2DvaT6cep6gIlPpZZ56H1K8Suaz
1eh8bbyQsLEgHde3fLuyleq9aMfVQr3LLTAL+fxAIprmIduwyySpDDzpA1+s
jxAEr27yD06rQ0tZRp89zcfvlJ7uc7zVC/fmorDXbwj+uK8zlHGwByUvYtZn
KjCoLP7+xcfQChhIHz1tSfVN6bl+wuQ3DrZ+ft0Uk0nzuET1XqZSA6Z3PJm/
6EPA/2KpklLOx8PR0G2B1K+p8iW5jh8aUecVFphC70vm/5K/1XMQwX/oFkgl
MzCXD/NP4LfD0lEv9Searza7XBPGNzwEWz47TqOEoNs1w/lvrYewSFVUML1H
kCCrfVap9iICNDRu/k77NW/aF1/ky4NdX9FwdyHVa/GntH7xf7DffAn77isG
LI9i3V3Nt+A3df+sDO3/+HnOiM6aWjh5WqXkUR5DZNj2+6914wfzJc96Zyk/
H3KGmYRovPnVSmRB378rfIVW8lwTnIszXrrQvP2hbtPKq+0CfMN11M6meVxZ
ZzbP8hLA+IKsF6+P5qe31tyPBe04UjTnuZnuf5qmW0p/bOmCuKVJml4xgWxX
sK5xowB9nf7vEymfgTFywjShCGXumuPLn9P8ls/a++ZlH4YU3d7HGjD4S8A9
uLmhD1X6zdv7fCgfkrk/fWvbBoce1UpHuj+q/CxxcavOIFTs7Flqhxg4a3Hn
7K0bwY3sKF8VRP2JXC/hahsLk/YNBja0n86dQyoWnnzIu94QxdUR1EllbIxe
zEfI5oDXOhUEyR1LfN4qiCA/Y6ef0k0wIrAUxrwWYJK7I/sD/X/QlTeOfyTd
j3cuf4teLWCwR6OzxMHuJiI1FhhZ0jzuH5RZ6PijEObampJhnwiyWHNmIZQ3
lXiRnCqdj89B15kIvwE0bfwQE+PAQE9mj6JD6SCsea3LbasZ3BckbPKd6cGh
DewlCc/o8x4b9/16uRnW5cfrP9N5FTuRI25SbIOZdbPVurSfjF93s+tUKa/a
f5ZKLWNwRY3tWjU7gLEoLv+pN4MXue4RDw1acPVnxaz/0f1v/WvjwrL5VqwL
03JfQedzMrWoPYctQi8T1D30iPKRED5Xf1CA6Kl9XSU0jxRm461l+G2Qbc3c
ERBO8H/we8bK
       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHk4VG8bVkmRiiJpHVIkydaG3JJkq2zRIhWJQpZKElmS5Ue0SkkkW3ZC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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81NkfxkdJraxiU7OUe4baCiuF6pFYCpnSCpUsJUmhi7Vu65a0sbQJ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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4lesaxonMJDILUYatRCObuot2liHZR0Wl7GMjlKGSpDJ0sJMIUWTY
GYq02tglhbIM25RhLZZlWWhZ6/sUokKqo+h854/3ev95rud67ue93/u3xjvk
X77LREREblHn/3fqyagsk02tcGsX22EqRSKUHbpiVcggfvAjP7UqCeFf5/zG
dHcP1owZjA6GEpDis6c6adXwC26fWHOcxDl3qdNBJoOQ2XKsPn6GQPqgkdLn
GA5mNjyxdusVosIYj9PigtEVPt/QSdXnmhvUWb7vQ4D6928/bSSQNTep/1Gp
ElWsvRcVdEmYhKc6tU72QWG+x2/RgET9utKJ2JhOOLN/C/IcI/B1NG9n9qFm
LD1lDDsVEdjknLp5sr0VxkZ9t//RJLHXKzWxM6EVy1ml83MrSFxds8rh4o4m
aPqdpy1fIkCqp89c0WtC8ecTG+jzBKaMo0YzJQbBzo9O6/1VgG0Xj/qmeQ6i
/UDyo8JMAaLq/xrLaGbDvqJA2/+4EKFn971cPsDCbbMvrZPzAtwdvPZBVicP
4Yxq21lfEjnrROvlJsuRviuZT7ckoZ04X6ysz0aNqXPDkA4BkYo4bd2J9Zjf
uCBt4UXiUpzHDqtzr+BROvWUZkUgYTKIZ0HwYB9UyM2xGEUMv0XVyisdHyID
P0ZQ9eqLqwqWZRTjlGVIfbUHCUNaW/pGvVcQfyOn9dyOhMjVXIEdg4v1zmEX
oh6MwkOsjWbjOICWT4GnK7XHcKk+XJB4pgVbtT760O0JMHUrfik274SmXY+5
wIvAZNJLXi2rETuHZhwmdpPQe7K0EJT3EIYetWI21pQ/vA2E4cFZyPIM3fqU
mueJg70MGT0MiZq4dzamo2D23P1vatQL3OO9kFKh5gsj/Napby/H3047n11I
IdF2Mrpmg0gL3kvn+EgmEegW22tS9YWFM4Wv++2fUn4RWMTRJ2uxdOttrIs+
ifSsx6Ve2ixY9Yn2/9JP+UdBJdZcuR8HB6Sz0j0JZKqvvybe3Ia/vh9IrThF
wv+MtDrjfhfoi4G/to0TuKt0AT6GXHDsaMnbK0ehP3Tk7oeeVqgVKJl2FZHg
2s7IyJ5nI/C/h2eiOoSYlfllR2cpGyVHtj1+lidEfvD1q97LenGXp+3cUCdE
/+bWS1pb+5DxwyCmyFkI2q2RANGcV0geH+6m3yYQ7B+dz+xhIkNlxV978gkM
S9qlNPSzcFbJStJdhQD9Rcm3+Yct4BtlT3RT+q8W3DinpczATPHapFAzEqNm
ChWdFslY/SG7rZbar2TkJVu6ZgfYuW8kQkoIuF5RGDFNzISnBv+swTESvO3Z
Jm+vN2OqKDsyTJYEvdjLepZshltN8PEKMQJ15fOi/NBOfL5SlVChQMDewSyZ
G8iElgd9WVIlgS6HxH1jN9vw0cex9A9XEl/9a2QDjJhIUiy/j9MkMuW54tO3
u7G3wFDQVUYiwkiHflG0CKVVkyM6gSRszHUD9v2nHzTjQy0DTa+xp6LEd/pz
DxxFTmy5xRXC8x36eEQHZLmPN0xnEOi031y32boRkqphaXZjJGgCX1pvIAsu
VmcCHz4RImnDi6mLKU1grK2u1af0M9OGhp4X1aNXo1NmtxoJjZKuhpVOz1AI
l9M1h0kktDzQ8Z9rwHuVzEqtIBKBJhvn6q3ZcLV0l2+KIPExvjFCXOoZ7lRL
aywYU/Pr8c3/ofotY27TUOMQaHTTXFO4wITSuNkn8rEAgWk+R53E+2E416x4
L0CAxXVu0s6He1Ghf2x1WxOBLXEWLsEpLIzWqfbOlQmhvFJa4d6XdrjJWw2X
1ZFoCeTT3ObZYCwkiFmvpPw3qBQ81nQeUjkpRy5TeswHblwOme/CwzcbFeOj
CHwqWHnkmB8XqtVWUntLRrHmD+MYd0kG0sv7J5IpfbphA7O2Bn3QlvOI//g7
ibLn9v/u4A3g5SPHrcFifJy8sN+/J2UAcadkj80qCkH/EWbq+p2NlQHLwlgd
AuSfoGUeu8VEwFrnZwdESHjOvfaM+qcXPLkxi78fCKHrcn3/gBIH7on5Dbqp
VN4n5dyc2T8E/qzezcCjfMgpN3TrpHFgGB9i/m1WAGPFJ4aLKbWIlPqyXIfa
p3dMfUF5aA/W6jLT9RapfOzLPb24vRBPPlReTzpEgvEo/aFhXRdePDivfVCL
4seh/Xt0jDqwZ1O2y1A+9T5/uv8xUjiEyR85pnkZI4gpG6WvBwc3VZV8nnME
oJXb/+Dl9kDOT41xTZqAYuuYWUhdH2YCirpWXBfgPdct+n43D3p53gyVYKrf
u4WUXnWKD6ryZufPEPiVrnn4vlkLHJocYpIDSMSpzh2Xi2QizztW+Yg8ATWx
svv5cmwIpWMqOo+SqDauic9J4CBRWbNN7ocQltWiil9bOCj+ueeyFksIV9eY
sBPyQ7imUiVqz+CDrvp765eubkiJrOVtVSchmPokvsm2BQqvv9kLt5OoGk7o
H9Dj4P3BLTIrNAnk9s8eV2NxMceZWtE3NIrJo5tPtQsHwVmeJRNJ8ajza7rT
OgU2aJNlc/ccSZC7VO2KQtsxbNJBW2VL4Onu2XG3BS7u/rSfOW0ogIiztVWZ
bzIOjz2SCKH8ZSi/9EDwguLx3hvjmTdGYcv2EB8MGaBy19No3zY+AiqbTlfo
NuC15VrHt1dITMW1r5IubIWwclZ09yYSu3aqH5GOKEFZrLZTtBsJ8Zw9d1ZS
/5vDm5t+oyHE6rlZmUKJfgQxag4n5RL4TY9PWCwlY2JQTZRO8T31VVvPomsH
BhMlRmRbCfg/jfYbHyyG+cXVvF7Kv0XnXh+Mr+Ei5WXWhll3AjkKcwYNPn2Q
LB1Jue0oBHdHW/Xu31vQ6OedaVpPQLu3x1zahoHkt8ykyztIVIRINPpMd0BE
Xdj8/TIJnyv7FAsvsODh+LI2qU0Ax4iAOGdDFqo4fTY2wUKkJ09Pm51gI86T
KV1fK0SEfk73AZ0aNLKn78hsIfHzO6nIBIkKmNXfKSh1ofK0fF2GvyoX2hon
/R49ong6/mfs98xSfNr4uCR8FwmZzPgbUquZ6BOP/O1GNoGfRrysNrFHsFwn
aJflkgCuhmd9nWKLYBZlcTLcm8T/AIWxtjA=
       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkbPyEkohiUNdNGWZqRlPQrmZZv0ldGkpCyjISk5pTkkBZEY+gb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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VH8fhkdJChFZSkkhRZakBeWhpLL8qFDZQpJ9T0pJJamQRKmQJFvI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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk4lXkfxo/BRKLGjKbSkWQsvWPJUspy06QkNcfWSJKtJmuUNuuZGWS8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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk8lfkbRVmTlAhpE24icjOpqGPI0iQuGSXZCaWoRFnKVmYUGQwSY63J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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4ldkbRW6VSlKJ5JI7aVyipFlMmokuKCSJySA1pSYlybiMw2gol5Qw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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lOsbx5FTkjoloZIjUYOU5MgS30qh1XqKDrKVJaJQsmRXNIU6lESy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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk4lekbx0+ylExIEVH2yDJmMgmZL6UiynJJ9i1Lq6TQHpKfkJEwZUsr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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lekbxiUjWhBqikyobCNjylYmV0iWEuVnp8XYSqFIi5ThGCN7stRB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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8ldkfx5EiJYpiqKjkZ0SSaMF8ME2ENPWTJS2ye5WyTyW5ZMmdpMWY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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VH8bxiVKCllKIclS0iZKpNy0SErJTkiSlEIl/OwtZGmVhCiVkCRJ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlWk81dkfx5mrspRU4lqzTZaZlglpmfFRCdlFi8LIUqKGRBhCKWTKXmmS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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk41GsbljpSls5JiE7FyZJsHcmZfOkmEUeRwsxniY5ikkpKFFFxbG2c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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8ldkfx40Kc2vIMq2yJRlNlpnmosWnUJpKUUIoWyRTWULqhyRRSZHl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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8lO0fxS0lSlKWx06WkkqSUg+PIykpW6KU7CJKVEJIkkRUUkRRUiQt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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41dkfxxEGZUkLkcqEkkZIakTvOzSlyT5JJFui7NRFRclWhChZxlJD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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41dsax3FEiWxDiiupUCdjhRtX5ytRtA/tUqZkCnWUaDAcKcJRna5T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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk81dkbliVKZUmoEBU1GNHiU0lPM6MyRGjoZmkiIXsIRf0kiRaj7UYp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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c81f8fxY2KVEIqlayQvskuIzotDZRNQ2kgpEIKEUq2okikomRkZGaF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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41NkfxydKsyXXLnRBl3VrJdYt4q3JKl1QIUIoxMaSVSjVUHaZdeun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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk41Vkft0RlD1ekGTK2hFGTmjeTD9IMgxI1tmRfswztElLJUpkiIUWW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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lukXVvb0E5UUWcakEppRQpbuSiJJJBIipFSoRBlkjGypaSQk+QpZ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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8Vf8fx6WQEYpoyExGS2VF9TIjqZSGlRDRklSkkBFSKqFQomElX2Wk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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk4lekbPiPFmMZSklBZkgtpGBSKO0uhjbFXKjSVaZo0dXQo2UaLyth+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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk4lekbVmkSUUlhCElUo4YQUm6lhJFQWQYl2TJ2KjFlDYW4yERaUGSX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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk41VkfFylCjJCQIhVKRTKi5lNSKTdSKUljNyhLWpQKxdiuJZFsGYxo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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Vd37xr2hJFPSS5KUJFKJMlTcSiMiDTIlNOhLyJBUyhCS6BUNEiHK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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81dkbtkUKRagxuCo7idAYGY8RUUkmla4xqCw1kSWMyo0wTcUYITLJ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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns0lVkflksq5ZbSmvoUoxJGZuKQYR7XaKgOmRTjEsrli0RqkppTisNc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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4Vekfv9ZpQfRDN0ypaChNk8xE6KMitJFf9USSPUuJmwxZkmIUZV/S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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8Ve8fRwjJqjTtUsmIFCFve5ZERlrSEpJKiEIhI5lZfSWjhZJQKiqZ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkfxi9Jpl9NY8sSpWWMLRUKgx4Ze8o6oVIIk5ItDCMlo1IJSfZu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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41Wkfxr0lSxSyNSoppZORpUSDupUlRBkMpUiSDCnDkIoWZKxFDaEZ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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lmkfNbaJmS9DhrfeFsZWk1IjheJIqEwjpY9UsiSyhJCMsi+TJVnK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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3cg1P8fx40GITSkQTISKYqQ1FNDNEgIiVJRMiJURkMiMiIqI4Qoq7I3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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41Gsbx2UrJLJFRCRLEUVScb6E0OJ07OVQIfVOcii0cLLklQoRCceW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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs4lOkbJjppKyJLbUW21ta20VjNErecy6E29CPKYRGRrJC1irJF1FqH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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lukXtqRVUYR+SYhISExEmVujRQ1qNEWDkEQixVRMhEkYxJcM2RqV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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lG0bxlFIRZIS8UZZImtUWjjppaSyV1QKISRkJ0SkTb1EiiTJVkqy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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs4lGkYxlFOm1QmsshqUiHEppPTrYNDJUoqixSbUzYRqSbEtiapLHIo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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk4lekbtlQTg7KksnWoZEZTIpX1zpKlbBllN8jSkGXISNkKoykaIYmS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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4lFkcHqG0q0hbqWWjR6U2l1AtqlcSttQqG1qbkVtEFLKJkWtJRNHF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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VH0bpohkq1CWkBR5ZWmx9KrblmhBVCqKJKGUiqJXRdIiopIsZc/S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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs4lOkfxp1S5DCzOWxSkegk1BJbdLdFhOTUOkSRhFqxQuzYqFTbSiSh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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4ldkDx2UpGYQW2oT6FZEKSQ2+lihKg7LdoUVZJtQgZNqEpCiyRI1B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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk0ldsbx2UqbotK1FWhTKWy3EJSfCUlSkoq6ReuOYQuMjS4oSKlrjIU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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8lI8fl5YyW5IolVRGqEiUN0JLMkpGVKQkRVIaRKSUkb1bSIhCssle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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81dkb1nSVNVxGY8IkS5KSRjNDy0NRpGJkadMgNUS6vzINuoWytEcq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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk01ekfx3WT/GL8LA2FUanIWBKSpfHWOonKpG4RkWyDKUILksiSVGNI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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lukb1SQRM7+sbWRJpckgkRKOESkjfWMZS3YKY8lSilGJsu8VokQu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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHk0VWsfJpG6mZoomUKmDKGS4kFClKSSREkoEpJLyZSSoW6p0CAliRQy
XZnneR6PmeOcfY5jilJdGb/9/bXXXvtd6937/T3jlrBzM3dYxcbGdp6dje3/
11aT46HVr8Kg/9PZP/s8gdJ38/lVgh/xl3DghWTynjb+VqBuezv2JJyKquYd
xeKvJzGpC2UwmVYIklqgQ2MmzdSUVQnZ9y5PbbcR8K0Q2GprXI4rC6keIfIE
uG1KzTWi8mDy0fHXqiQCzrmuwqr5LUixG3u5yp7AIu3S78VjPQgKab1zRJCJ
XcETB5PVB8C5tq/lkzaB2raM5o7OanAvnTjubkJHXFwCy7SkBluojRk+kgRk
I9w27LRJQvWYR2myCgHW0rWUOp1/YXaI4q44TYeRl+rLuCdZaG2vG5A0JhDq
f0zz9PdmHArdKHa/hYFcRd99sstNcJzePjnnSIBNjTrK7xIGY53s04YXCKQk
Wi3X7sxCr5tL9oIIARVONQUOwyqsGnjTWKBJQCC2ZzwnrQX+HPFZG70JdOz+
9mT3xVaUztpVqsmzEPGHuiv5wSc8CDt9bLUggWKpNP+ewW6YX2XGDf3HgPPn
lQn3xFbwFFW7zb0kQNT1f7o21QHuydapxo2jMPrn6O77kfXIMNzy/lgiAxH2
bXxHsxrQHfAxhJeXAaMyDYchyTKElazcX56kQ+eT6H9ubvUw4OYt/bKKjgiJ
/QoNoR+hcjF9vvQoOR+RjduyesvgWLThkqEBgWEx/m5X4X6U/X26bN8DJliV
vJckbxdg03naV1VyvfHIbGeqdQPC3y7/GJ5kIq1uzVOTiBZs4irQYQUTmKy6
wH4iNQPqI6miW6IIGAj21Jho9qJ0/s+56/MD6Lx7vGbUMRvmj2n9aubk90Xn
XrYz6sFvR/2Gg0s0pKxJX+sRUAmrWkrfnlMMbBq7wua3owzYRh3UNWJAY5tH
VlFHDRy0JgJF9Aho/GP+w969Asz7FiWxPgTERzl6hkWrsElcIHj7ETq4JS+u
l57OhhftdAWVfF7bKhAzJNaA6n9z0oYEGYjcXPWsp7EaHmPn9u0lz0dKIOn5
e76v+LZX28zrNYEtO4Jl21M7If95UW/4GA1m/xU/nHEbxnWHkmeXR0cgm5/j
tyayGnLcySHWEQQiUg42NvJUwLbf1HXUi8DHDoKxw7oTc5LZt4fuUvF0/zN/
9sBKxB0UfeirzISlXoSnXGUWrmS9+8NP4qs1qUhhV3g+xIPM1dnIeehEcKVo
mQbikbS6ia8tgWNzW2IWrAcAlcifvbEs+M9di/to049Zaev51fRulPL9fn57
7ilE3yqUjN0g4BF4fredeC4W/3j2RqgSoPhNGh6caEVozNGCWkcGGqW3mlpm
9qHzaPQet93k86/Jn1P4B2CzNabEgncEbA9Dxe4v+6NGN/aUGvl+ryONS+8Y
VUJrmdGv3kugwMhL770dBfeIP5qHTRlQD749z6H2AaF33qYJmxFwEAs7cpfV
gPgThbqRNQzoTbY5Tc+0Yuqg0h69+hG8LWMcufFfHzQ8haKqDo2BKtHuyf3p
HVYrzJ9s0ScQ+yPBw5bZhS26dJ4OVzoIqQpuj5tNyOFZqFcn8fNGEGce3O3D
hjqB2O5LJL/tFiZVPlZi27TBdRoPgYdfzmVcnS/HVW3N2jPSDBgTzPdfb3VB
o1iDolQziu3bKuSE2irhM/O33EYjOppn5g+Z6FchSC96S5EhE+mZC7EVhj1Y
pyagLC03gsh4Z9nDaEJkkMHEjkYC+sfdbBnh9dBo/KxzaopAbi6ft719Juqz
96Z9Ic+TpbWsHfaiF+Hyry4F7CHxcnnvjMR/NaDVujyJdqZhzjrncPyPFETk
/dEevkPireVVgudkAyziOO2MvzBhGzgeKVw9hHF97V3ys2M4X/jCh2AvQpfP
sNnMagZuWqlvHjLphdngqYr05+OYux3sEOSfA+vvXGqy5P6TI8FnrxxoxjWv
LfVBNgTSTRb3vszoQfI894f7tizw7z2Set3rX5j6bE47tZnA3Kvie7+j6kBT
2V3WdYeOydz0UVeJPnz77GFCaI7CPcYpPV4rDaW+hg9PeBJotpC8GDbWBTUT
AWPz7yQ/1k6f7CrsRKZYvjklj4UXGmM3Zj+3gL/4yB0jYVL/RwJvmqxQoKdp
wdanNQbbs9eLZZ2ewch11WQSie8dBfEOUtpt6I3p7JzVYcLdTbc9NoHks4y9
l/coHfEr3f/90G3AYK/V+ZgWAl7HkjNTPdtQuD5+95csAuozTw492t+LBfVC
vqjCUdzkDD7atq8XzL8UwjjaRvC76HMM31Q5Ar93NLW10UGVEw8o9enEYEmv
orEQAzkT2uUyexphoPn6WjgYsK9m9t6THoTF0OdAuY8jEELou6nV7TgY9NQ/
2G0EOi3eLHf/D8gxyoiUNSFg+dqMqX1mEDtTJ8RP5IxDNjIst+V9DR5xPtlD
fCRwc/VGtbHoDDyt6XvGIv1QdtPygyTuJgTxlqtaXmSAKVC6+m4lBV4H1q01
285C0J2+wrriLgjxe1jH6tJReUc2ZIC3DVJP7wW1knobPjWps3+Qgrgkx6P5
D2kQukr5HLA1HdWPsDl5PYF2fW/u1PBu9DWkW89fY0En4TZDYL4RdgZ7OdSo
VDwrfJL/5Xof8nxXrL3f0NC+xWZ9nnopcpzDj1fGEvDsbn0VmduCXA2V5oQJ
GgYksj0dz/Tikn867N5Qwf1C0dXmcCPMTJkP88LpuHdKt7UvqRdr7MVumT4Z
hnpp9A01Ev/uR1RSmn6QeL1VvXzyeiHk2bbn/I4kkCyw9ueSWz82VEY7rWui
wqyrOzDOrB7PX9ZOKWQwMGMSzHgU3ojmhSn/4r8IVJbkix1K7YMXS/N8DBsL
S6HejZlFneg5eW8DjxoVgj8dBPZa9CBXOMq1jPQTv9d5vc0X2lEqcOtXqcoo
ln3/OXkopA9XnEPFMpRHockm9F39ViVSvld1PrUk9W1Z9kbc9yaU0OTijaxp
kJ29o3MvoRtyXONvP3iS81FxCe4v74LujkD16hSSD+7CLWZWrfCY5ggs6B9B
noRJhFYyBRMj6412xjMQL2bUGMRqRDj7wH97XtHxe9MhWSteCjaovbt4X4OF
K4F71JljDQj6LrIpIY6GgxYrn5P4+zF9Q2/bs+kefPjAU6/lQuL9mXv+HVMa
dOZT9lAYOUg+zWF+OpH0v/aqhgKuPnCOsGRknFiolat7vKqxDQsD9x1205nY
blbsE8zqQFUoH4/aJSY8A0QoYaLFsHfh3HKYk0CCfYGx0/oOiNG0i+8X0iDI
8aHYRq4Lgz1d7Nq3mIhL6RK2tQ/GqSOHZ3+S/Ay8z8PQ6i+HQ+rvQu91BOLz
z85Vox3xicpVEu6j0E5eFD19nQIrXbusZnkq5q6GFXhn9+B81S6/7lIGUg5x
b350oh8U4UpZRT0G2m0Pf/3U1IH7Bza8ErehIf3NDsW8jT2YudHzaDR2GJuW
6Z5f20m/mTE2lnAmELf55s8QZiZWO+Q6LZN5lH/FLVTfsR7qW8sdCXKe4iaP
2b/ufADBX9VckmSe1Diz9tz04UxwJTzTtyD9IplTPvAjWzm+ud2w6BQlYNPB
yxnXQIHzNortTlkG5O9lKM0udcM4SOLqPsVxZHIqmI3PlaPMnyXo60tgu4K6
iG1/DW76GOfKCDFBfWGgGOjSico8NymRMRpYTq9NpD5+QI2+3xMRF3J/eWWK
wfZ+uMpzjxWvo6FVfriCPboSF6vXJIeG0vFNV2fsfHEnUq/Ov5oOYGIxm3Px
ikEZ6KmuW4uE6Ji5fiph9mIBAvuslzRekPlg/zU73bEB9NCV+jy16KiPC/05
sdiJAxkHbL6VMKB/fScb15kmjF93etnSTEOT748nEtwtmO3kqpqZJ/OawLyM
d2w7VPQP5thXEii8o9j+/Ho36j8Uis0IMJHrK6Fm41WDs69UuowXCKyW3zzT
zduNIHHpl8G/CHSt3yyyxb4dq0w3tr38wMJaWmjlhTQKwjdnr1mMYGK6iPNY
cEMH2u+f4+8IZGCd7z+KIXK92GL0O8DHkA7fjfZnF237kW8lmxRzeQA6fy5t
0XN/iFXlTsdryXyhYV0mUpddiRx5dnZ6BLn+BOWBqQsFNUfKJdzdRmErzKIc
dY+DtDqK9Q4TGNJ7vVZwTSfyDZgv1/2mwpZDR69kpR4zV3lYpcWk/rn2fHlG
I/UzUuxQ574JsO268XyXtRX+CqS+NCb3C+Q99GeDwhPEXhqbTiHxreMv0Zzy
sBzTV1adMyX7wU0z1ZcHuXoRqtxW46pERwKHP/+7hEIcXeQj4iXIvNdf4Khw
JRP5rzdlcZDzLhyoqGmwasGLAP//KpeGUfiRc2yF9NtvnzcP+ZST62XaviuH
tUN0ReHpeVUafHPC376JqAS3g+e3Nl7Sf+0q0nbat6FZWv3QynY6zERWkipe
N2JV9pUYP/L8G331j0c7v0XQhNceW2sCmfEdGS8cBpCwXzXKIXIYjebuQdbm
/TA7LpKeyT2EQI6mwKsRFFx/bwauX2Tekcy9+f4ZBS2T3pTuGDI/uSjbndnY
hej8SX23+DHU8sR/iv2UhfXUzMkYUwLW8z82PBjvxfaBB403cunoEs2aeWTc
g87epfDDcqPI1AhUEJfvRJntv8m2VYNwuefFfmaqG1HKAqp/Ysi+o6qw0SCH
gg47md3qTxhgpYUXldW2YkMmkRAmwUSj9pbfB3wGUW7/s27/7ik0BhwZEeko
hRjXZnZilo43H8eyeWPaULDTw8KZzGOf+s71LbG1wcs5JvbDFA2ZuY5+L/tz
QStfKZz8RurDbY+H2660g1l40yJolIkrD/ZylYjVwu6zstT7W3TImiXspNys
wQDVbe0THQYeJqTpaAn+jZPpNuzGpJ6oKL5TGrzbgme1J59LxNBhSS2s0olq
Rldh0BvLVgLrQ6MsemTaEHBLVyvrKxMGWo88Vby+gHKs1qmCzE87T3MeOUfq
nZFUpp/2Ih1WMmZ5XoFtsLo7+maZ9D/PrPj1fGtawTo7wq4tQEeu9O2OE8cq
cKSYwsNB+rl6mWpL1dkqOBdt261XQGCd9PNbfnPd8KtN1fYxGEFl171vBtYf
YMT+cOP0fQIW4aP7JZKqEH9JIhUnGeAKWVN+Lq8fgWrHxSJCyb704q2is3IB
DL6K5u93I/V39t33bqEOrD75c93noFFQox03/DZIx8l5oTOlumS/zWWu4Xvb
As1Dk/uEuxiIVW36yrvQhvX8smYNrUyMzY+tdjDvRPQpHYcyYwbiXmslLj+O
x3pD/YGgywSUkn/WJV7thKBNib+2Ew27q95GD8mQ+Moc16qTpoGqulByyvcx
NO1CiwRIPTcr7I4O2t6AvI7ykPXHGbhS3vZLu+M9HLKKI9pIftte6LeXlW3F
buUT+X2GZL6a0nQOO1CHgan+kdITZD+/KeYoExeFthC5msvnyPVL2o0yejHw
6akzNb9G4FEG9ffiugFwrfmhnCs8BFeJRH0/uUHoa+VyrXweRbVUxErzygDY
+x7nLd2j4IWCwjbNe2Uw6/n7XbQG2V8L3nkHe3SANiIi1fScBjZJfqWF8WDM
ivtv+P//ij+fJgzf7qxAhMHgvFAKAX8/RbvD1T3wMHWNJ6KomLwjJitu3ofg
sGmhkC4qDjLOLPCR+V/Uu7brZA8dgRffP97v4wVb5jlVZ5LP+Uojy6phfZBM
C+7NPMpAa8FxX7Q9gX2eeZ3bKbJvTLUYpBQVQ9cyNa6HxFdr1WFejbtNEEpc
b5W6nYFwl6C5Eq5WqC8dj7Qj9SPQj75Bae4OKmOU7w6T+O7U2RnEF0vBMVZr
zymS33tTPtfHG3TgsIeoT8VjGlxqNirqF1diqFcoJ8SbDovH46u6W9oQd7HV
9og5HT2PG9QeRbVgdYDtXRGyH0f0WK+1jKuF+nTUZmltOrbdkPzx404NjASJ
M2xqDIg7CS6VKg3AMmcua9S1Dylf2tQzXerBNVt0PLydgGZ+1SH1gU4E3aBH
8pB6tOu9xbFE11LkaR95q7eazCfys3Jdt9uh2nU5heo9CEuvUsfvpzPw81ho
keFxAptk8UsmiwJUEFIvHjGwgS/holcYBWbGvHzxJSzU3Qy5pMrogp8zddff
D6hYdNr/+uB4C1z80hv9A5lQH1NSsjGsxwthuTX9ieT7ItvxX+M8bBe9pXSl
hkDphaCMHLZ6JFisDniYRMM3yUeyRqxMWL9I22pJo4M/ephrSa8W7wmPi5Kk
3/A363I/qijHeOSB9Nuk3p99l/Nya1c3Dtoe3O47SAW1elJOPyIPkX/4L+es
YiB6rvrxFK0Gm+ykg72CR+CbtSZ19nwpFoUMdHZtJvsHbYPR01v1WGB8C2nf
SkD+xrKEt24HMqWvRKTSSDyHDP+cEmjHZNDixL/CDJxo3PHpVmA/2Nc2O8mG
0qC08sUmitTrPzdUfZ4sjGJHeEZTmUgv1m8+qnNZk+yrr0czXL714JPYm+ec
ZL6O0LO1eRP3AWXJZ8rvG5B+czTR49m5DjSIDb2/u4uJUPfd6u+u9qOh+Zt/
SxjZf0447y/QGcRaGYGSMA4mLLN6tKtJ/U1L0hD9cYEFS1fX172SbeBWiPZN
dCf98RUPZZnMX4v7l/Y1+TNAPfxMrfBrJXaJWyz9TqXj493OPGfubnB/TZPi
JPOl1DUnq7va5Dz5KL5FqTSIf1Kkysb3YEBFymrbAxosh+n52cqtCLDW7iuT
ZGJILWOVKm87XPfKrpMSZ+LeUb6zaVllSHkz/n52ktRvowDDjL/aEXbSR/GX
IgvUXWdsRX/lwOLoqT35fgSqecJcpWV6oFCSWLmR1OfaymzPuvB/UXhS5+r0
EoGf0oO/H2WVg9vbpJaHzAdxSk6GPi5fcbT7RJTwU3L+vgcST6vGQfaqZVTH
WfJ8Zb4nPlBNgu2ZHYp+FgSYylPzDSoU6CdEMTj+//9xYromMasB3248Z34X
ZGL1mgQns+4+hLqIcMsokn1KjX1w/iKZR3bGBrQwGMiumsi4xqrHsln/X3qB
dBAVtRe4xSjYw1064U7yRRO4uEe9C2mlSle/SJL6T78onETvgLbb939qrGj4
H1otC+M=
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81dkbpgxS2TKI6lKSUF0xMZYekyYlGYT0oRHRMIkWsjdGlmqQnyZX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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVWk8lVkYV8RkyT6DmEGSQsOQpMb/KrKWQlkqI26hmpqGlJmWq4RJUkOU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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4lOkbZqUkHWxbjbJlKanthy05bLhDBzmnVjlLDpHwS8raREXZnHNI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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k8VG0flkpCJUWSkFRUnhKVtUt2pSxRyiQhqSQVpZ6IQraQpagsCcm+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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs41NkfliS7i1CIIqlVSULRUvt7ZSNFcquI7eK27v3I5lKSSi6/3GKj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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41dkfxyWTRKIZy1hCyBqiZCa8LY2aCEnSFdmpTJaGHyoJg5QWGSQk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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8VWkcxm1RNGnamMxMClNRDYmU8pShqxJCBtm3CpksWZJSUogsSbYp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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lO8bxW2RimgRUUmJSpKipDqRpZKiBZUt2ohCkSJk+VoiKkKEspcQ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81WkbxvESReq1DSZLIzslNYrisjYc1ShekaUFLfZRQg01oSPLy4hI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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs8lOkbxq3atkWRcqgIlbJiE0ohl1Aop6yMlbCZjGSL1DisUwihk2Ip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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs8VWkXx49LUpShkhCRS42omUKTaX4kopJbGjWF3C+RkC5SJpIX9bpV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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lf//xjWkgTSMkKyMRJKQ5FIfqfCRlVFkR1pCouzVEiofIyoVMkNC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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41tkbxpkwL2mSskS/7BpZQ8LQrU1aZBlJQ40hKiPKluwiS6hkSWgs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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81HkcxnXIUShCaGVarF27ZZObnnItSjlzZKWW1ESppG1tmrGJ6HCH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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs0VWkflkvJpUS5lCL320yohol6YkrC5JKEQUUNoSIpIWSEjISpRIbI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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4Vf8fF5IkpLIqSUIqScs39EJLVlJmGdkV3yizqVJJdhp8hYwiihCy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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk0lGscxyd7C7c9IeFKq5tKZKlvomghpJJkKZRtULduJpVKclGi7m0x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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lekbxiWZIUlCWeYMJR1pmmpU0/nRRZYsLUIpimRNRpIUn5JMiyjZ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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lekbPiFpUSeMJFRSZEyiTcitRqXzU1nSKIokKdlahU6WSEQaSzqW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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8Ve8fFymbBiEKLVoou/K2UlRaEg0pDckKUX0VIUrDKBISUhnZsilc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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVns41FkfV2JFRViNVFI2olDkVcpHusiljTKjGkXWWrmOipA3uiwl90i9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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81Wkbxk/RaI4lSqUy2dIylJGlTS5zUEpyLKOxn9BrwojKklSWSTVM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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8ldkfx29jKWmxVZIWM0zSNBTVHdunGZSRJIz1Rzdc2UImRjItJqZk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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k0VV8bRqRMFYlUkgalkqQo8iiin0REZC4UZQxNhAaSUIQkpZAQUpnK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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVns8lNkflqSSJMktxarc2oqoddl6VC4lKdqkoYhFSZHLLpaIUrG22ViK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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4lekfxjUx/DARQxhLtkjWCEnnVmmIklBGm+xJlqmxpUnFIOcoarJU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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lukXRlLZUlJKsmXJFBHSTNyWiBqmpJgiIrJ8xRhJElqUraQkmsbY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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VO//xq0lVKKQdj6pJCQk4ZakBYWQFqKESEq2SpKIooVoQZJ8syaR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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lekbxn0aaz9aZlS2QqKobJHS5JIoE6GStXLsZLILUWMblSVH9goj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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81GsbxsdWHUkhJyoiTqc6r4NsleWiaErJ0ikpTbbirY4kW1RHXooQ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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4ltkb/sKkmBpNWQY1mGqIMfo1ophuI2FMssSICjVZpkKEClnCIEq2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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VN8fVtmpaBFfkgohiZKQvJSKlD2pZEuFyhaypFRSiIhSKtlDiyhL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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81ekbvbZGIpGG7JKZIjslUx1JaWyRlFAIV6HMGL8RSipUN01mLFOJ
yZSdlLGMyr53yXVtl9y67vdljMaWpDQ0398f7+f9PH89y3nOOY/WidCDAaIM
BiONfv//3W8u3K+VYmOb6r21rr0EIfJ5TwY7XqLGRP07YacAglAdszpWKdZG
Ev/HvxKceaUb+uFYN2SzAwdj31JwWLZ4wVrqxF3zMNd9BQS+fbvuO17qw0QB
P1KxZwR3tePzNacqcFpyTsLHlEDN4WnbtOcfGDLfdMrSjaCh2rui04yH89oN
Yc77hUj6MmMzr6QAAYJQxmU1AkHpUf7FhAq0aKzuqr5CsC2N57gijQe5/IR7
gqsCxH05UcvXa4Tlr0VDNXQ9jDs2s2UXj8H/3Krn5t4EjPTa5GO8Sih9XD8V
GUngY/hP/M2BTpAaNdnfWASrKbvhT759aDLsMdupT2DjZ3JzNrARSvPxigHT
FB4IWh+wR/JQ8j1johEEVjffmHgGDiA9J1ZRS3QUKRYFk0uuVXD5/hFLzJag
biylOXNVHDbwL7zYSOdPZYUgbxsHXhqDFXnFQgwVt1jMcgahEvmiK6ePwrHC
heKdylyIKTcfEimhEGm8xlxXfQAm6NiedW0ElQPVjm0+9ThnrD/3dS2F/bEm
tpuul6FJ/Fft6f30fEzeb/05jAMnfoVUxTKB8STD2n/fME6fDS40chhBXW55
2JHCXlyZ/v3VdTcKcp/GBisVOUjVN5URy6DAyVfdaZD+HIIN1+dG6Xr+yZ3S
NPBsQsT2xEBHAYFSTJB7RXsHckLMf2pkE2wJSGjbIajDusT5AMYNgn/bhuRY
S724+mRDimgq3b9UykkZTjWqVepXHNYicG+qSI2o6gdLPXDTpQwhSg/oiCs8
bAI1sjXH4iKF7+okZPs92QhyKo2z0iPg6ImJHV1XBqn8l04rwwhOvxn+hiPo
wZfLT900uUJw2FmN6ZE9aL+4cUmPT9Cb/yTeIIiHDpGn24NPjEL5eWJs5FAD
WpXczt5fRzA86RTzOp0Lp3pT3bYFCnkHJn1s71fgaPGbI4do/Dn2MkOGSzVI
0lKytz5O8KxsT3ff61bIu3ln7x6hME7ePfY81YWwUe/TUX8TvDUxYPSG9OLT
Tq/6hiIKRfpbmNakC4Vby8pFT1OI4o/JnRTlgX2l1l+2YQyx7g5zN0STYRAY
3NxK7wPPfGw0VmQQW+p8V+43pWAT/sz11N56hA8kaY0NUYgJsHByS+FDUjFH
S3F2GDkBHSeNF7mwLLxGLRtT2PLIaIXknUasKKtQcnxMYJF2X07t6yqc3Tep
bE3jcQ5mcVt2dEL6VtpZ+dcEpfxU7rrIXkg/4CcrRRGYSf058VmzHa5eTZpt
cxQ+qz/kXSwfRJIsI/OGvQD+t/Y46rkMQMEjSi7WZRQ+JKhrOfk1Nty5ve+g
3DDuFY0zKN9aRHsav//gQ5CYvtfwtfMAshwVwiv8R3D1cwkj5mAXYjqvtexb
GAVD7WjmNu7vqH2q1y7uRVB2IsTqdns9Ypwk1qpUESgMrmYuyjcgJ7u98xtP
gjYzhRiZ/bmInyi10GAStL+2C7By58Dvve7p6nMUvGQdMkVr2rDX4mHa4ksC
bbtvzq0V6Ye4nemrGmshct4nb8i1GsCaTXIRSzRen9r29C9bs2FUXJ9wWpvA
2Wq3uNpMP2Q2G63fJTmGlFmpY9byjUg/vrFYYEIw83ExNq7sT5zr+Cq3kY43
2p4dWXrFxXtc/jZ9C4ERVSCprJ6H8Kinb0NpPQlS2+o4U8LBz94i0rbRtJ4J
+7SfMdlQupGxw2yUgvO0Rb+yUhekMgzWS/AoJLwtn73D7Ma66g8+36dQ2GMl
4vyJyYVha4vxyjghLl1VtT8VNIAT/Mlod+EY7uGEdOaZh7Dscfpr3I/O73F4
vWV3BaS0psyq6Pzj9vrmYQs0n1SZi8HNFMIKy+cP1PXiF6XB6Y4lgqj4kGfs
0l5cW613vGOCwPW5m3X2DR6ORmydZY4L4J5UOlkQ2o9diweIqIMQMyqrnWJG
2tHySzw74wLBmq29E0aX6mF9np2vEEpQJOJOtm/rAyNNTkM6YBR+se/bvZ25
6N7lvmHlIyGkNzN3GARWoUXnT+klen7KsgvlOn9xcepVodHDaCGqHkdKjPT1
Y/wfX8uATCEuC1bt6S7tx5Pg9Cx7RwIT9RjVggSar9qHd9sME4T/dmGo7Ks6
9AQ/vPtenEA1a3pbFbcPcwK1Kt9ymn8cjcp3Z7swfsWlNVCWguDIYOEFkUA8
4Oi8Y9F8W+5S8qpta4Jj8ueRVkKhrdnRQi27GcKa818xpyj0h3M325oOoDmq
YcZvaAzjEdd1RJdeQPSZzfwh2q8SFQP+Djdi47c1Mnte0XqWtk9ix+fbDfgx
Py4jjdZf5xn3t2deN6KamXiy9B5BuUbw1x/FB/DqhNKVSBUh/hYmB/SqdIOj
2m9HLQpRtzn4eIxUC6zWXdMKTCJIKuVqJuc9R8/Srsxc2t/e1d4SVIw2QdtW
bKdZDcFQ6mXdOdt6xBcuZaq3Euww/ImZ80c77ux9xP/gQXCw1VIkN7APjm3W
iV5lQiTYvTnsrvIS13Lzi1dbEXi4lB6xM+UhLH882yaP7sc1llU6WYlhBzeW
gwrNN05Xj7Z9I2IvJ3xxpJKAVRkQOOTxEqv4VQeX/Wg//sHu2JnGeig0zeu4
nyTw/0OMVfKmG75ylmtSZkcxo1m0AT/cQmxQ74WPvgTyYd1DPT69yPn27uKi
C+2/U/ZNYhaFCLfY7q1Fx3He/4tIfsxGiT2/MiqXghYlkV30+SX02Q2l+ldG
0PCFjIjfeg5YzJWOxW+F0B8tiuGJ8HCoK1JyyIhCmaSHtN7NXuia365To++D
t8NxIWy7PjiESx5Oz6Kwz/LeeZWdTbCedPEbiaDAjZJciuW8wPxEm8RfEgQt
Yrv4w97dmEtt9XBypui75kD0v8x+CHMXMty+oDAhriijPNOIQpvoxn7aj0J0
A/ca1g3C9fDxLA16X9ZED9/vaK+Dmbzpu/lqgh+TM7S+9eZBIal+d/nPI5ga
LLPISG3GVpZQJHzVKP4D97u3Xg==
       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns4lVkbxjdJKEYqFbumCVEoSRHlzqGDJlFEKJXDMCVntSPHUWKcohw3
pSLTJCKhjFNOW8Jmbxuhvd/3rVFKiCJ99b3zx7rWP+u67mfdz+9+1vrFxeew
uziDwUij1387u+6v9Fs/CeDtsy7WVINA4Lstna96+/FknpI5e7UId5hXNC8U
8WApk8P70iWCWKJ7s8T2Z2gPkw06rEtB46EOY0KzGWbGR31LokkMeqfp3VLN
h2nzEb7vYQpM9kG7CpV2LB/qtq71IsH8/PWAbdVzXA2+yHaIIzG0/2Bf5OxL
qPJ+Ut+xXYSlYR2v17AFeB2T8tTPQIRj8fEKgmUD2PZQcfYPLyEatwWmdP3V
C2O5bbF65UIcsfIOSTV8hqmS+Ws2y1NoU7cP9Hbth9rXe4kVAUJcsRqZVhrl
QuF4BsObSeC0RuCW5+JcKOW1TSe/JBBheL0vImoQbyS+TssuEeJktqR+YGA1
/n6Kyo/bKHwblWzq4PcgqXBPdMdRAqU+v0fG7OwC+19Pf38tEubz8q4eDr+N
U5y2xnRbCsPdZzJCO7jI+bdogjVAwOBTwMyhwi7U6fcOV6lS8JIadftTvwlP
RysjP1mT2OCqeTZMsQevIsPLON4i+I7xVaQyi6EBajRpLwUl0x8p9035iH/5
MDbnqxBzRqZPldR78I3t7hF0goRTb/OHLVE8FJfu2dLuSSEuPOKk0g0+Mudy
ZvpYFDpyCEMbtwE8Ns1xOV9JoMBOwaanegCKvg1/XGwWYSQreumSB6VYrSLW
qqxFQSg96cwNGABf5KKkFiPEwUjpMd2RQXTVP5gSsxLi7e0vTbWJvfB+8IfB
4CUSWtcT55lq9IHDEV9414qAZD1he3u8HwzW2pqkXSQa9X64uko14w55pPvo
dxK3dlP5QS2DsNNPuOC/+RWuyL90c/hYjw2rLykNG5Ao8WFEvRtsgPMcU6N4
hsQDbddQXdtncFj823PNSgp50oLI8Xs9EMXs32l4mwJjc+fiKJNoVGcdMsk/
TkFHIaCPs64Xw0X3xL/XEJAtbV16nvUSzrtXyR7JF0IqMkNr8ksHWpOLLVlS
FDjcC0VVxxshN/gECfEU2kcVK7NkBAgsrhm4lEugzujHPklWL9z3h2w+ZijE
TKzOdNvxQbxXjZ6NyaOwuHX5ppyQHjDDal2ll1Go1PRzC80rg1iex6si2k9T
09id7aw+GFbObfSrIaEX+sZYs4HW62D2Sjwi8T1DxtngDAe2mkx5lRFaL0ja
0V2rHsTeCP85BQrZdmty1Gv7cUIqmVFlKsTj7Rnvsv16sGvxuWlBAIWbO/y/
/tpeB8q47OqWbBJWZp8LrrTxcL961oTzG4mVXLtIWecBnH/YWfOniwgMx43D
J2ZP4U1KlZLlCQq5fpeZMp3dMFu2r3S4kMBRzwH9U6r9uDhePeJ+XISTgr2F
1wNzkLbXfDbYkULXpIfeUq/7IBYJtMMO0XyGnnpilMiHBcFtzUshUBORkHs2
mQcLx/qzZ8To/t8MfllwgIfgFdYrnswIcbRF5byZTgXcA4IoDb///BlnPVPn
QabPRnluHwmTb5tTzLl9uHhQxivJh0SDfI6yVU0TPlvLOdj9Rudb7cY1Vmk3
HHd19YacIbBDsjaX6mqClH77RzEeCdl6gdDR/hlanVKrp/bTfFDvvW2vlYFr
4FGqPJ+C3X7uti/sQTS4L6h6Uy+E3dL7RdaP0vGtIfwfeycK6232IN7yBeKM
U+uuEiQu+8teXBT1AreuNEw0PyXBKIlj60+egAYractl2j89e33VKG8uFkzE
aW13JMBbE/tkTL8ODnvfZafsovWZUyx1hVI4ZRXqhRjSfDYtDgu7lo273TU+
axzovM3Tnri6sAzhNsJzP+j5sLXGfrz/fwNYHyzv3rmVQqFhn0eEdQPcQjI3
fS8mEac6eV2BonmL+KinM0dgan2CzanpPugEn1N1MCag+0g5FUF8eGlJ2wT5
ilC0IHVCgTkE10XpJz44EMiV+1lmiXkrVp3e2SFlQSLiyPp0t+IXeMPdzaof
JiDxC/KXvXgO8ZtD3k50v8f0c2Yby7shXiGpUK9HINiSfbjLppc+51uvlkKB
Nf+ucUpKB4quUGHrVlN43KvrVdbdjo6WhUXKyQR0ikoud7/m4kKQ/hq3BDrf
A1GMzMRW+ComLr9pS+JsQc/y4PQhvDCyMJg9TYF34+5IvJCDqa5rTGc6/4W1
g1zxAw3IrbAftO4m4bua3ZpJlEBtn/O9Gbo+vSGeLEL6ULC2tHPftBAM5b99
dLKa8Tm3Qp2wITHzaXjraGkLbpb+aprKJDFSopUcNlyLHc1WQX1jJO6oC1L3
rKzGEtUZo1k5CnWW2Sf/GchCijSn3tqSQsbwrkHBCh6WZFMf5x6JoDh3Ryx+
YQ9GNtmlBfUQkK9xFyuW6QPjaOuE4zERxn/KzWQODWBTc4PT240ieKrwFbJu
p6Ht+XaNFhcKaYeMtTfG8MDgRa1620q/b1HaWZupXniMm7w3/ZmERliLMzlZ
BX6HVvtaur6Nng2bnJd2Yja3/HpYC4nspoOKO/kcEK/P++nS76292VtBbXQh
ck9SWwNofoNfmzA+ZdRBPiWB4zBB88rgDdVt241vTd8Pa9O8Pr6ZLpHbKIDu
v43xtuUiZHwZC6n5swtdSRYlbHcSwmO5/MTTdUgIIjfOHaNwX9skptDjKdRH
FuSfW0/7I72qiVsRi0RZUVsnPW8Z/MdyZnF1YK+dDSHpeRYYt/zD/betSIwN
Co0PI+Fxo2jczKgSExbTTAk3CjvGLwyW5/PglLTXRI3W9y3e84n9KA92c9FW
gpMUKKeDogVp5bh94dOkjAWFe8WeU4eMuNgh98s1uQ8E0pcHtGRyXsAtI/JQ
wTmaX+mU/Z6B/vicPjYeS99PYmhVksGxXsSOiz1+4yjCCpaPrXgmH7kFpok2
K0XYFblyPEqMD90VEUYVkyIYSPbDa0MWOM6h4aF0fePbF/1lX5aMDS5H4m6d
ouD96JVa5YMuNCuYLXlIiKBTPV/RRbUcDu87pUVTJH7XehVuTv8PGkzCLwl/
UHC9+ntjq7kAKiXv6mOyRPg//3670Q==
       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lWkYxm011FFMKdek6BqJyohR0cRdkRAaW5SlrEnUJSdCGZFk1CGi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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k0lG8bRiq0U0IyQpYWaSHZLkpRSRtJhLJWiuxLfimKUsjShmiTtEll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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx1GMZJv0a+o30mKJpjBJMeGDq7GNkahUZAsNFSOkooSkVEjJ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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk81dkfxi+qMZiuyjKNtWtncJWaRD2KFjRNUdYShaSshZSGkqVF1lEa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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk4l1kbx0mL0spMISFpRslQtqamvr1SUm9NE0oSoSwhFRJR1myFV4oQ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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3lUTP8bx6cURSWESrtKtoQKRW9fpbJEQiIiKgkVrUIppCit2qWVSki7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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs4lHkfxiVtbXYdCgk5bsWojUptOtxDpOMrsm+SxDCRHHIoppPD2nSg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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk81Wkbxq2VHAajUpG2QaWslVd0SaV4hZlBx0yWotDIWMqWKLTYKoRw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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8VekfvkwmaaSFfhGRMBVCSfUz03Onacotk6UFyb5VKJRlRJk7UqZs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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3kgVPsbxlXKUolQUtaIulGpROiR1K1IlGS7luIqKSFRIpUlUslSrqUk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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx6Ui/ZiRuU2y9IsUJqSaipIPcyMqS0VlyRIaZKsQhZT1RpYS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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns4lOkbx0eknxKrZVOkpoMGhRSbki/KZLVKyJlIpGWZNkqFRESpVESI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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs8VGkYVtlINbl0p6VSCimSW/JMQ1LJlhWK1UQi1aQV2Q3N1LRdlrJl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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k8lGsfJtVRVJJsqeioJJVkS+pSSYiUCnWENjqhJIQWJHEQEiVRyJYi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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlns4VOsfxadEJacQIirddCJ3RaGlklN0SqiQ4gjlUBLhoCJJRYxLfkju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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns41GkbVlsU1W6bRW19kcMqtpZSkrqVdiSnRbUSVlIrh8TnHJFQyaFo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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs8lVkUlYmK0CAVmpAKIzMiw5SW52SkGHM9kpCSZ26KEgmhpJC6Sk93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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3lYDe8bxonSJi0qSyiUhEpoE3clSSlJiSRRkaSFRPuCZEuSQn1Ji9Im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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlns4lOkbx4cQItr6SaJyKJLNioqir7WtQwfH6KhEOsiZxUSS4pqVM2lE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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk41dkfRjcVKluijKVFJq2URslLm1Jkm6RQyDIl1dXYB2NU0gyRiV+W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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVms4lVkbppG4apoUSiSlKUkGSWnoptTgKx0IY4hkoxw2KpWMTyIyziEh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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VPsbx2VLUihlSXaRCFkqLZ8SoshS1oSEJJeSSgu3LJUSKqKobKmk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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs4lOkbxx1ap02bUi2SqSZJJ5cstuIrOa3QOFTIryQ2pNZSRlGNoqO1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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs41GkbdvhEK6m2dWiJTg4RQ6lVttsxFaNZVGwqlLTZZQqpsGnWKaUs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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekbPkgkqqMsadIoql+YqcbWolu2IhWSUmMrsmslihwpRVlDhelK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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk8VO8fxSmKylKJQpaSKEUokpwWCqWUSJG9skSIUBGKKFkqIipKSEJI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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81dkbln3XNC2mUSQhlNapRI8ihEoxjS1ZyoQGFUYhLUYSEqUrS7ay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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41OsbxqeTLb8iSYt0rqFOyRayJdzT5pyUpcjSIiFZIg3ScRqkhJIk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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlndUVNcaxccgCEgMQQhFfdhQsADR5GkQ2BgER4lG8ixEiNKUFpQWukqI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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VO0bHkpRQpItS19JtoREhFuoT5LwaZOyJEVZU6lUiiQlS0pJUrIk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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk4lekfxlFTZJ1CRnRkSVJCDSV1V5YylpAGcWKMGpW1EOnXESrbtJCt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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk41WkbxxVFaLKcohqkGVLqoIak5UuT8lIke+RV9l2qkZKRpcU+jYli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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkbR4tK6TCJVF+ojEykmknWn0qYpu0zKhlT2Y1RouwxiXRIlmpI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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k8VG0bRkVJokIkIhUK4U2UusiSNiSUCElSypYXb2mTlEgIyZ41u7Il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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81dkblmYSKeugIUuJhiSyFNVTNBGKIYwQWRvJWCo1hESWaRGylSzJ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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4VesfxZHKUIZug0qFcilDFLqilqgbkmOIyJg5kX5Rt3BNGUquqVE3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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4lOkblihFEWUlHchKoYNhd7bonrXOpOSwQ0ItOcXKSkiaCh1+tm0U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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VW0bxVWGE0KDUoYiKopKhSjLEKmQlzJFIUVKiCTKUBGSVFIpkpAx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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk4lekbxy0troYokixFUSRJY2uoLynZCuGQLINqNIQoQ5ZSkiRDEUIK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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk8lOsbxodyUkmUZAnlqESl7WQpLmmjJISibJWlCIcSFTlISLKTpiSS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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekbpu1wWi3jZ2LKVsnYp91ym0o/lYzdpCyVbRCnsiQGZUkn2ZLM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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8Vf8fxyVFg9BUKkUXTd8WSb1klKwWGnYohLYohIpCkaRshYaQVRmV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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk4lWkbt0xl7OVrU1ORDELZmkr5SSRCJ1NZSrTw2ZfIaKoJafkKWUoL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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk81NsbxyckkuWmRdeSrcUlW0Td6iOKst24ZSwtSHFHshQmUnNLJUsk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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk81dkfxmUZkiUackW2MWqmDJF9ejJlEm3CFFpEaCxDoZpIypItS4kW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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k8VG8bHipKiSwlCi1EVErZuSRRKipkL0SiQpukKCqRJSQtIrKE7FuS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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81dkbx5FKg6KSiupKmoTIlGzNx75HaDFCGFtSrmpiREOWhGyJipaZ
seXqzqQSd0I3+xrudemicr9fJERXZUv9vr8/zuu8zuuc1/Oc83nez+coeQc7
+YqJiIhkUeP/c8qnIydj/TqRckpo+GWIgHv0tr863HiQ2LHGQTSVwFy1W1BJ
eS3IXaM3ajxJGBWlvg+Lyof4UGpRlQ+Jxs+PrG0u1ILbyDI8mkiiSMRjk07l
fwgwSHsUuJfE/ICt8voPvbAMkFjlLDOEXOPoRYX6JmySPBQulToEbvuRyeSe
fiyvul9ST+XT/mXbZlK0Fxas8KcrqHw6A6EmqkH1GI+UmnG+Q0BpqsTVqYYL
OcOGr2sMBYiIWjjXPtGO+nvZa9nnCWjVKbTEjPSBpvZXbv+bt6i6PyzXoMuH
CyHR5qH4Flc+H9vxOawKNz8kuJ9fSYL5lNZNf9mJ1+KsmwxXAlPN39jdrV04
e4cZYSlCwK/Q9pS9fQ26/jzdL3qawPzv641ZJ/ko62Ccy3MmISOjkteu2IMw
zeq822cFeMwY3CGvXQbdis7v5FkSInemC93DWqH4VONk+SQJq0tZpTbZFTg1
RdyyB4nMzMWwht31+BphYXSohMBG25a77Ak+ut0SeyNWDEErwGBsyJSFV49s
E1abkrgRnBCZcZqFhX+LWjv/IPFcMc743pEmqBBe+66LDIEef6irdCcbzSn3
FTq9SBSX779old6FM6MGuxcCSJjN6F1lXOyDr3MeduoTmH4zp2Gzl40Uc/sW
KWkSYuZyQ0Xt3VBwEE7Ps0jk6y0GDYjyEG5AcPz+JrDNddemo+xmlAUcjXhR
REJvbwL913Quakxs2e8OCHCu19XrtUEnPgQJ+U+kKF6c147GljIx4Tmn+OUw
pTeNL6nD6sWWYpd9J9MGkX/VMWpNxhOkRDbmOIuQ+Lov2X+l5zPsfOnMbsqk
7l/lq8dR4KFMpqyn+c4gxmPyVNdNVEPrd5nQPQsEuBccdjAk+NgoGZNYECeA
yfdAS2nZp9jA4l/6dISE6uGf0kv7eJgNPtACziAui8zMC0M7UGLsL2liQuCF
taiNXloDfLwllmaEkOgN+uI6cm8ApQFdDooVVP5KCclABgcDJsv/03EgYKEc
wIkL7ELUx/2+PdsF0A36rGPWxMH8olaYm5MAxYUF3utoPAy3Heh0v0Tpp/AP
uz+3G7aRu8vHjEkka1VdjuTXwLyp3fxqIQky2+dxjEQHDEwWPL/5Engn6nVl
7YomxIqeCKhOJvE6e1VTkHkXtEwl7KUyCCyoTbk9YHThtdKxFikbARKaJQwX
Mng45KsXwwgiUIQj8fXCBhxWfdpnnEPi4Nd7Hw4K/oTf2E8xjb4Ub69glp3P
Qf5H+WHfDRQ/rdBN+taEf+336P9nSSKm1Tvk+TwH4c7t1XPLKf5ObWDt66iA
i/RoVsZvJCSYWdbTfc14OMktNA0ZwrtVCSpmslw49zzOeqVPopY2ExF/vRZO
zmwn73CK18xf/b1lOHD8xnUXOUnV6+iIw1wbC1Y6dstMqP5rrH9ItMeVgSjM
tpen6hUotkufodmKW2frtiaqkOA7M1eHm7+CVknZee0tw5Boe+6zzaQWJQE3
whKWkYiSp9fWjbUi0pXTuKeKRNoT3T9jCqshZ6ZhdzqIhBYt7nhzOANa2+3c
bd0o/mf9kr0c6yDzmiOv9ITAhpjogr+389DAO5NbGk+998HSfeNjFWAxkzSW
/UKif11J82ZTNq5UnHJ5SelHo49LEMXR2MFSMS3zoPZDktInJp9gq480w3oL
CbsL9ovxoj3giSnm8daMQGyD1eaVHjz4DLTd7lCi/MXkNhkTVYHZ3fT1hzNI
nP6+N+OH7e1Y4bhau24rAZHzI5eu7PSHvuNz5ncq/vq9Y9eEH1pQ5mkY2U3p
O5igpn1d7RWeE1OaHzvfgv7+7ZLQM38jLZtGL3Qi4X5xkuA2d+PtBVX9ia8C
lHTbZZb3NMNIcjh29CgJyeA/fL6zW/GTWuTi9TMEauuXKLRU1uGX67Slwn5q
fZtum/amFkmzj3e2Uuc1n/ndV5vnwew4r+zlHSqeeLWLIrMbtIuueg2plP4V
hT7H25oxulLS3mOM6qdN47LY0g6p0DW+AbtJvN/3/seCoBYEiw9LPjhGwvTD
yCHV1h78NqD+0nA7iXM3Cpese9iIMItUISeW8kvl3U5mw0w4aBhqt18kkVDM
lWydroXyXIoPneLBM1Jl5KErH7oFkTS2IXW+7VnHJl4WyAHrwGBXKl7OC2aG
PwelR92njKh+Flb63X/M5GKjkbb+zR8IfNG20oUUD4bXU72mowXIDb1wk6/Z
jeyrMYr5lF+KB276LX/vC8yqJiXP0UlM3dvPsE5+gBcro3PVrKl+FajLnLjd
i+rx44lKdgTEm0QfJ8x0wPuWyMVVHkNwnexoiOxrwvb0tL6QBCrfjLTyflkO
mF1XQ2NzCRyMiBJjHyiGzyVrz98pP87LVvIIthiA2Jcc+bt9AhQIxeoiPjXj
BvtaDr+Dil9tmlMizYXpYRW7Yw0EaMvmpmxb+7EsSDnKRv0txi0KP+7MfoQi
o7KArwYUnxqrV6/8XIMr5XT/Dur9bsqW4v1L2yGnYNP688/U/+w+ZMfgPkKW
kkbCHMV3ZLa6RPOZetz72YFmLE8iaNfawVomD7fSchg/PBPAZZ1mnU1vP04f
e2Tl4DsEnb8U7OOUeyC7LFQFhyn/86Ml/ZNO+dvrN8aVlJ79DWeFT35swJT3
g9hRdxKbw2q05OgcCHlL4oQhAjje/ThnWdeBKulBC0tjAusnrxmpn09CYPT+
E9rHSbzz+pSkbcPEQZcIURsr6n+NzvxYvYILq9qCKk93Aj7h7wsTxsswkVu9
vI3i/dBCefFYYQOSv1+OMn9Igh7FPy9l2Iixy17isicoPsWEG2dxDZnsGfKK
NwnXxNwXldaVsOO29SrOEMiMdwxaVK9Ei+MeOa+NJDLSe+O7RzqwoHU5fcqC
hLS36ZbjHnwc9D4SkjZL3ffYP8TdRB40Mzrzd1H1S9P3X7VUowWyrtMe1ikE
Xo2uU//XkAen1NEvC7OD+B9S5Lhw
       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns8lOkXd0tsYkItklTKpZJCIT9f0sq2RLpR7iFaSW1FSipLZbcaspQi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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4ldkfv5ORIjFSSg0SKsrWNtOUT9Y2JLRRZGtBl0nTRpaUFu5kiSQk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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3kglGsbxlGEEm3anCzhVKg46qhwRUiSkJAjFbKUZI+yNyGHoqJIomzJ
nj2VfcsyZuy7mXfGEpGEU+R7v7/mj3nfmee57+u+rt8tbnnT8CoXBweHBScH
x/8/PVe/vjFZmwOhjPnUJ9sIdJf/OxsVXQ7l76+4vksxITalw3gn1YZoibEw
k5MjOBhy4JVVSiIaI3MUCQoBkR1s7kktGgLL+Jsr2MNYK2WwOuRSF4o0tznu
8xmFLCVBJnGgHvkXJFqMfFjg6Go2fjRRCcd1Aj14wYRs7OS1hf4qTG9IcpGu
IDB3c9poMSMHB71SGBmqBOx9F2i5vzrhm/9rw7PgYfz76NgrQdcONDxwaDq+
lQk72U3KhaI5sNH1eLr2JAGrQtzPNenAOYGw1eKBw+gPUKKOStBgWR3onig9
Cin6P7YZZxrRfcrSTnIrgbbhgF8Jwc1Q/b0sfPHsKKz9/EaufUrFf/lTTeLk
/0/6XdhgM1oLh2q+yVsdDLRMa7ht4E6B4Uj84vHzBC7o5Rw6IkvFkpioWo37
GPZZtujfV6uA4/X87eLuBDa2RNTm89Aw89f6hvFQNtiTT5opRs2QuIITk2YE
jHvcK338OlBmvCZevnQM6bqPv6+I9+HF1rEr8UUsOOCT90p7PcRYqumajQys
flpVxB/TAal3lY79ygzohFb98cGyCova0gFrNxMQClf7rkqEo5jBc0/PiDy/
mrB07KY6WGDkSooDC+1ll2soZrXILzP8rLefQMsVotX2ZSdKvWJeexcycXA0
of2Pxk946fPXs/Q0AjkL7+JGrDMxt1VFJHIvAe6RVT63pVrgkuaWm8JiQsdV
J0xoMx1P4hM06vZNQGn0HMPfPAO8pTu5OkII6E71CyvU1cB523PJE40ELrN+
Z5vG9oAiN1e2Z98Q9IN1S9smy6B82jW5aYmApkDb1by7NDwT7XS/82IY5ZRo
TVnnHtjrr9EZ6CHAMdtwW2Q6FCF7WFr3zAk4yilq72yuQ0q4iKFhOBN7qi5L
Rj6tQMXx8PpvVkyEyG/a0qbSAUruh1e6tBEIH2ielyqoQ7pfBa82qUd9zpaC
z+kvUcIXcOy3H4G4tPsFXs6tMH8yssqxkQ3KxCLXKpUa+Obpj5ulkvWITWs5
9YaOOPFij4vCY+j1sfQUX9cDF7PPvFEL48jxKvZotipDgouv97cNLDiurp3f
aNsNMTUGfz//KEzzxroTUnKh6NsseOcRgWrZCFW+iUEk0oRejLn2IExAsoAV
XIWg5LRj1GwWTvHOmI+EtmMy7715/wNS76vOXLvqHI0XsS1/8Z8h8EUl4GN1
DBX1PiayUuuZ4I0Z5OPlzQfxytNBiNSX2JbNdxO2REI7mrW69yKBtEdygnba
vSi+z8rkkmNgw3tDSc9/u0Cb3xwll8kGR97Eua6Qbkwq/8r/mDmO3evHro89
G4SGqVpXaj2B9U9fFTw6OQB3Q8GjzXKDULRd3G3Y3oOlnetYgtEsfFn8eX1q
Ow2hBRS1uCQmuFZuFLp60nD61s7EoJ9M1G8Td9BntEHG7XW2y9woEq6KHeru
KwXH5TvKp3cTSDHf2SD4nApNrfEblrdH4OlteVFfqAerhwScdWdGMHye2i79
thsi/hfKDy9PIOGa6d0ipy5Y9u5THhxiozKl3YpHuR0ZAVZeVBEW6v1pLhRK
AXhCTMPovAT8+xRNIg72IN88xO/6IgPdu1U4zWJL4XaQb1ZWlMC03tvyQ4we
RHHJRyv3MZFm23q4TbgGm0q3994KIhDkE78q4EgXriiuFb4lxIAWlzHbOb8R
Twr03mzaxcbl91XVSYd6sf/WC9lnfExQMPyoNLcalYfsjvy0JO+/4NWxM7gI
+8WNZytJ/wn9EaSt+i8V6kN7Ph2OIJBg83vA3CkVI9XX1SpuECBimTt/llTg
uFPkZ64nLBifje58HNkN18u2CecfjMPjd+Daz2NUFAtsatz6axgprqbPp941
obb9xKGda9hYbLJ6uqWvAMqt7+d9nQnwmtB69ccHIJWpruyeNw6sO37iUGMv
wjfp+a/8v/9B9wfPudriQeXKQt9lAuX9XEfu1Gbgvd9w+hM7Ag4bbdZm+ZH1
vpciHqzPAo0dYeRxtwHC7fZ/VoizkKLQH9cTQsNEsvTbt00MiNSKMhidlfB5
ZDL1lXy/PmpX/KnXFTiyhc6Z5E1gs/BA1mueXgwuhbm5CRNYlvlYFHe1FS0c
067yUQS0S9J/c0+kojv0I5bJ/szhhv3fZQ3oNv8etTxD+n1/heUhmT4MWpdQ
akxHwXXr+TujxGa8Ene4w+4n80d7R9JSTwmqtjZWp6QyoZobnatST+q9lDuo
rpKF6nIZp4TRHujs+nVLaGQMzzbulRu/8Bm5SvzvORXI+54dCKLdLcemkexg
vuukv7IvRHLiHQq470rGk/6mX/ZkkD8xG2JhJxSsAwj0N9wayTfugiDnkTOf
skZhruxbb/WuEumKK8aPJwhUuneXuAZ34a+HK99Wh5P+I3KkY5deCyQcY08m
trLA678rtb6lEGtySv0xy0Q5L3FOQfYVmqQz+ZodyX5M5bZXDkXC8MYz8f9I
/9vmML74WD0HFnTV7CYNAka7k/Yb9lThtMHVxFZ/0m+Li1tnvZ6iavCurclN
AkqhBerC041QdDlsctOGhcvfbGYXHzbAlH4gv5n0//JL17LVdw3iqW72ad2V
PjhVpAhLXHiEVguTuCtXCJg+1ri6799G6LTGDdeFskBVmHknvlQHF3POiwdF
WRDyLPwan1iFmED+P59EEni9yc78wTANxSeSwtLUyfyqvP+cb6UOvQMyz/4E
Cwm3p9MMohLRkviYyu1DzufxyKCj33ww/9GCZUDqb4f38lx7TguM/D3eGrxl
Y+b+kRp+j0Tc12ng6dch/TNpsLxSORVCuy0+ZmsR2PRiYlGQ1YPjyS/D8pLH
YC0u0sxtQAd+aZQ7+TOQ1i6TL/niPU7k5By2kCH90PRk5JcXFST3fO3bxs2C
9qXgbImjn1HLveLqncpG+QK9dHdbIT6eoR9M/U5gKSDbu1W2FZKPBWgCgeT3
F/VncuY/QPfg00n3VjI//txt6SbTCN4SbWI6jY1tFFEnQdVmTEr5fT4kwsRa
IkJlzr8PsksSHrHNLHik1ng90W+H5AHj60TMMDSfGjhO2vWh0Spv5Rv3GBot
PZ3W7m3FSrwwbZLMN7M5qavdy7lI4zn8U4qcZ6ewN9o9WzJhTGvLWiT5x3NK
a11EWh7mNbucWrhIvXakhIw4kXymRX2+w5yJnIyHW54sU/FIRIPgfcWE0vIZ
qrNbD6wrFfdEeI3B8/Ir1+cSmTDyNI5UyiPg1rsxwEq3HmVO2m9KspgIO7HU
4pdchxKx2dj+fgbspsxiefs+wdI4d8CFPM+21tfpRQ1NsLsWm+RmSeqj4Wj2
0W2d+D39QK3/AgNzAYPSu8ya4WXwMzk5i+TJ2YLQyXuZIGLesUrCSX167du5
xq0ZZSZp91eOsvDk4JGPp1WoOHT8mR43ed64RQOd3Rk1iDP+slnXi/Qfv86X
xyLKMbPmnsAQySeeeW03PMKKoWqdUldN5k1yeu277QUNkB+K/y9XhYVXv7sk
q0M/g73GwHdkG6nHoL/FU+wqsXjO4XeiJplv9nG63xfbwLtYrqF+msA8b0cT
U4kK+pB0QCOF9Ment/L2naXD9e9VK6ca+xBtn//zymk6nNYp7OTPYCHnZ7i6
uDwNZvs3WC9nEHimbvPoB0c1PisGDG8ZJxCpPLGgwt2L6ru3BR6sjGObtMo1
X9UeXPq0xEn5NoRze883PXelQYcvVkc3ZxwZ/6z3MdzSjHJ69eF6VQaWQh7u
+FLahdjB7T/0Msl6M3re7VaNR8RFDX1jC7JfgVrfrkRWI20DVbBMh4mZfUvc
PhX9UNs7TrTIjMMhk/NA/54WiLW0N25MIPPPvTZR8mgnmKMbBRu+spHyhqdV
JrgXI8J37YxcRqFo8dQkgKMBZQuiYb9fkvzznKtoMbgE/12R1s2qYYLwOT2z
43IBJiMGLv5N3pc3SsR2RbEHroXKMu1mvVBSd1XO4W/GiYcup/MeM2G46bpn
4Swd/405X9XhZaGJX+AaIdqP59zvJHw7JsDhZyrlccYaG4+2m969RMDmfbfd
si8V61cfy2qaZCKL2/SK/fU2uBsFi0/Q2Zi75HJuoKsRtLMRvBhigmM4aa3T
H0NQ2GZUuG8nE8Nv5JMq1NoR9sJghhLKgPu40+Pi4x2o9+UXD7ZmwT951oE7
NBZjZ8o5/EhefhnqpPxNthKCC1ssH8kz4UnxqY2qyobsQk4gheQt7fM8lNen
aAiaXxMpeIcBjrEv9pY7qqEUIZoiT/LFpLfsrkWNPriJnQy0+EXWy97f1Liu
C7U2Lt9+knybfrmk/MC+GhAKLFqrHMn3a1q93T5SEebZ+XLwPAs7jJsrvCeq
QCsSC01JZYHr4VZijXs2FFLmz1EfEAis+iqVIViO6ZdZ+a+VSL1NHtJjj7Rh
/8z91RuLWYg98abiP65u1DYUy/p6D8G+yGqVza5efDlaEagtQfIFXy1pGAEw
vaX6aJTkwdCrYy90j3fhuKXfJDd1BAlf7K73a0cgIv/6mB6ZF0vlTzeXv27B
abpRgSaDgXqe6Qvy3j3YY6OuGevLwrwI1452wz6ciQoP1l7PQARtolW1sh3Z
K3Pl6R4j4OgNpCQmecGoJNavmNQn8e981PPcTnSJ9PK0GDAgru7yfSioG+tW
GimFVWMYK/bbYizTgSCtpZWFDQTyBVW3OsQPYOW1/YBRCTmvgpeqnrObIFXx
OPWoFxvtFE0DDloDHnr+ZbPHkoHNPVy1W0/3IlU0tsilfBhmn6yb3Fc3YL4N
d6eSCNw7XFqxbnUXDoYFOCx8GYH/MYWI9HPlCEntraHaknl59Vl/Xic5X26K
GtluI6hoyRJINqNjjbxzoCvJv+Upfck30uuRd3H7xbVFbHRzi53+dJQKNm+u
24HfJH/sXDL7EE1F3lBfqJwjG0KWGQfCBd7CP8nLaP0uAj938RCuDCqULgpV
jZ0j8Gl2VCLrB8n3agGvTcNH0OjWe/QPFxq6KXqFW0dJ/aVN6dwzpEJFa6eA
s+EoZn6E8NxxpcNRsdhWTmQYzhFydCm1DpxPLqsRI/XUdzNnlN5eBd4yWb22
1SSP3n14pCeLjqSourmSY6Oouu5sOF3cD49rNo8fHBgGjcsi9JFwJx7p71HI
5xuF3cPZ3G/XXkOreUHozAVS76mHPv99vhuVWme1Nr8fhvSq5W+rPOshf/4w
xUB0FLd5OZx0+D6j0KA6gJ3AhF5z//WSW32w/cdjxExrHO932Ku6pbVAubpI
WiuGjTzLV9anq2Pgsp9n5c5tAsMDXXl38t9gUU3T3vU4yX+BWM5JH8BRxctX
eaNGIBkR1dKg2Yq6s7OnlkNHMDdROzxeSodf1imvqFcs0N0EFbtutUImaO9I
6/4xxKdYeaxvocL7hK9/7W8Weu3O3+zd3QmOllzevemjSPtzSvSSRAxY/SrN
EuT9umMeZgqofQSvnqD3Flny99ZGC5+l0cBvZEIfXGLCf0IuruRlNOp7H/7t
SfJrnmqlyZ8PW1Grdya29CPJHxEKdvrP6Bgsi1mf84CFiLCNJ+lBCbCZUfA9
SvrXzObkkNnz2UhXbi7OJXlIKcGuTUPkAzQ/BHWwFMnnpb8GOr7IJ/cfAe2D
HQQeebCSc//pRJyq0V4jNTb4O7gyY/i6ceDhVZk2cv+VDGS43RlvReKXdqOM
7QxkBkfNu5H7xXErYeeVOTLPTejmLbl1OHolJ1mkj+RRtY83rC7W4OKWkCY3
bxY0rqWol6v0IlAj/r1nzhA63T+acFM6QWn/S31hPelfPJCcUKdhx2RLsJ3i
KK6Ivyjez1lBzpWc3tXtBDQU7n9x4qbhPcXwznby/FQ9viMWsS346MzV2ZfH
woPGiD8bf5QiXv7U1rp1LFAsg+PEgmswI51E2DsQkOXpzY49R+Zd7TJL+soY
hl0s4yYvpEBDPrJEh+Tt9seOdHNOKvwZQe9D/u//e51SN2oX4N76d41vyX1A
zcDc03I6F1lBV6jyJN9yaAietxTVQgBlOPEw+bx+3aGvni7VELYklHZnsWBW
r7BZ15YKyquzgoskP9fHNM8UVnZCPDfdZttFJo4THSuxVY4IELbM9CTfL2yW
S7q1qQmqu/dtNT3HhBDrk1JQfDKS8nXSfxgTyHgyLPPcsRHq3jUTN4NYKNxz
ZP1u3W6cZNT7brWegMjbV1xiLz9j0nN6euYNE/KXOPc3a9LRtPlXf0XcCPJW
Oasad9DxnfVh1Po6Aw6evUktdQ3g832ecZVOYIBm0l+9sQ2yzNau8VE2ItQF
IrvPpaM0z9so3JqAcBfHmfb9nWjpXeGwqBshcyMkfL9fPUTLHVWqyX0si2iy
eG8zhGuaPjo3awiUiXCNeeV1gl9gbkzefhTDVsn8u47V4cyC3lC8PxNVWxan
tMI7YdAhzFvuOgwi0D+ur64NEj+tajeRfh3y9uEs07oeleybp65VEtjDdU+O
mCnChjnzj7v6mbh43mvq3oVBdLJMFapy2JDdsGpz5TINlw3t38h5jaDaq2SJ
52w9WjmTnQvfEuhMOSstN1eJ/r9FD7+ZJ7CBs6HV8r92HGHeliiKZeHSVMnB
5YFWiIRbJYnOj2L+rGW379cuCOnKHRs70Y0Zjvw9jYl0HGb/jja4w0bvE9/V
hhwdEOp6MCOxdQxmfxz4UPnzPe5fkPjOWcWERRuxovOiH5vPja+X1mdCJclW
r5HRiM0TjrfZi0xo2zPD2x9346fthVXl8/3wFuL9fEkyGZZqxaf7yXorxcr9
1ttQhtvar3+P1jMRzSfjar2qE5EHgkySw0j/CtEPvsT3HMcylUt4dQlEOxeZ
UPLp2BbUJCUTQ/JH2/GYtU3NEONueGz7jZw/6Tp3wX9aoTSvHrBcycRYrOO1
nc1UxPLIqreS9c1Zf3urBaUMFa+NrH78QWDwoMeb2FWt0OZpcBsh+ewgSz1h
W50n9uxqt84h+3PwctPuNikqHCX/a49IIPNSa+7dic9UjE7ps+/eYOB/bt8k
ZA==
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs41VkXRtG4VCRyv026CFPIPS+KUELFEDpyS4ZS6TSMXFJIiulCUW7R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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lekbxpUsUTQnpEKWlF/JFv0IXSqFEJmMUpSSKSm02mYsI1mLLFFG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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lWkbJooRpglF2lGyE4qarjI+Ko0RvkiSCaEs0YKiDoMaGk2hQXYl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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Ve37xVGGaJBCIkmmUCllKFlIQuVFQqa8ml+RoQyNkkohMs8ZC1Ey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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkfxi9aiVQIMWHys4zRJGSrx5KlRVkShVBjmUFRlLVuxc0W6idC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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lWkbxw+KFiWTJZospdKmkyIN44dEjMaSsUQcsiQpqThTKnQyhMLE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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lWkfRq4sg/GhZSLVlykGQ41E6tzVWIYMvowS4lCW7DWVbeJki7Sc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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk4VW0XxjUJlUwJSWQoSqk3vKFupDSgTCUJlSKZCYmcSlIKiQiJKEJU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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk8lOsfFS0q15WQSqTiahMuUrkd2ZJUCgnXWrQjERNFSkSrJC3WdJNr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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk41ekbxkUaMzHKnmRUaKEIU5Z0k5KhMWWko0JZKjFkzaBFZOzTlMRF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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4VukbtswYM0yLqEkUkamJpjIkqVsTaUKEjKJCKoxChKxRJpkaVCNb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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k4VV0bFpKKkihUkkKEUETULVFCikpSCUkikhIaJPMrCkkiJaTMQ+aQ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs4lOkbxyekJGVyaLZQTm0HP5SWGHxlSUSkctiwdFibqBRLpPDLMUVl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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk8lfkepgZl2pPtWiKa5JAt0UyeJDJiSLbKmi1LSpkyzC1iSnbpxghj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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4lOkblu1AIjlkUmSkJTlWRNm9E6uNVZbYtlRS0sq5muTUOCZpszax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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHc8Vf8bR7RImqRCZIRKJYXyliRkJQrJKElLpRQlK30bRsgqIxnJFpGZ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk4lWkfx5m8Jk0LY+ZIxxZZkoxBi8n0janGHs2JGjSSLGlTR7xCtsQo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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lGsfxseRUnmVnLKlxVYRL9WJhCtrUoRkaXGQao6SObYoHUtlS5FG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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lekbxqkUmZqpQcoWg5hKmowtupwapcQgskx2ypIYSYhCSmKiRQph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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk4FY8XxilRKmklyZoWES3KUr1SCSEtyJqkklKWlHxtZZdQypotS6Ts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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81ekex211NeLKZG1GmRg0rq3FEfrYs5TByFLWkekMRhiJUMZYQhF1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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk4lVkcxy91M1nKlsYakuTSNGUZom+loZAtjMpEYUIzUsOEbC2UhqEa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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk81esWxhUhc9EW1T2KDxqQTkodetJEh9M1ddBtkFmZoiIVleFIMhV1
hHBQCUXa5iHzELaNvc0cvT+khKKccuu+94/f5/fP+653PWt917PW23maOy4V
EBCIp9///weOCR9k+/Bgt3/aI1ybQbaWRqtofRsklI+bHH1OoDSuUhEs/wSm
+Rs7Vp4mSAwwOGaypBoyyyye9V8muJ9lut52FxsmBqXdr10I6owis/97pBl+
WkaCFyLo/SJ9TsazHgzfOOpcGsOggHFzftjUA+svIvLRTgzaFrcZeJ0bRNak
yFtLPoNRrYhDo21cDFTKLt3eSxD5Y1Dohy8fbxusQlWGabxKNRflsiZs95rX
uneTwHHxtVSKWz0UPUSSpYII1pxxvcOrr0f6pdLdqbcIbC/WdKYY90Ihf3g0
wobBtRyL5MGmbizoHXxeLcDA5Pgb1hMTPvY/yevTGyJIMWamb/zagOhgqwpd
XwIjIVvN4v3dSDPJZP0lQfMPKBQ/1d+FlXIxny8qMggPfSf2WZ0Du5BnnslN
BCasPuH8Jj6SBNpEpLUYCKjmnMqczcWob8dvN+wJcsX6Xf7Zz4HSjuzYPXUE
pb6bBEdNa7EgL9lleI7AP9zgS2QsDzib+2liMwPrtIQ7Obt6oMQ31hray4Bj
NmE5fr0TrnHNtW6SDFSGR9Nlk16jwsmF2ZVCcDxES/LwpWZMBP+W2xlFUKVm
zvn99n2cWfwW23KKwDvpnzjVjxwMxJb8SBkj0LjVID/+oBbf+TGaPRcIRMfd
IvT1K+Dv7PH4uyfBOQEz8f/qdtF6WRnJCzFwGZVIvO89gLXiRrzKqwxsNU3O
WrbnYVJvsPWVA8FzXf7oJvFqbAnUt++9QrAwC4eXQ1xEyA0ZJc4QZPd+GunM
qgHnZY5o9DUC9Zk4nlNnFphgzbdX7AiO7gp3f3+YB6/5R6fd5gnOf1c21Blu
gdW80OyfdwkKU0UuuGr0oaHv9R6ZcAZKEzvbxEQSkOJflzRN9flNtpmvcCun
73+8XXiGYEQ0NbbWsgLLBQ45+bsT2MkZ+/KepaNsaXSiFuXZL3emN6K9BXGp
EVHulNcUo3bbDxEJaBZ6qj1H4404LX/y5UMBFu1v2z51ojxlFi09bvgQG3bO
WSjZEuxZMRUWVcPHe0efwz1mDALOGlqvMitAot6A53N6XkB1Y7RXRg628DZO
TlN9ZbqyJxyZanB0hLMNL9F6/9EyITIxgIL/rLvpa0/v7wz0/Djej6EIrcBh
Wt9D9eoSu+WbUHKi1O1FJMHMtegMdk42Th9eOz9B48k0zSccPNWCoNadMu9y
Cap/2dGfr8DD6qjfpmxof8PGKj1usFrhpbs5fPefVN9FlmoIKwUfg0+8NKH5
T8la373+oArbiwJ2bPInKCqYu/xSsR3Sd6/q1NQQtL0vuvPt524sufqlfU0Z
gVx22wtVjRbMdfnLbo0jGPKb4XRs6ESYsPT8mVGCY3/56ayu5KLkRfkR578J
eK3TISeWD8JqxN2X2TCGJN7TfC9WCzyLDr62Sab9P7lb36Y0B9vNFoOe0Plw
VRKNEknhojSpkTH/QOPXqP7sXt0NoylFVpogg5G86y0XdXKgep2l60H1pxfv
eOg4xoEr7/IVxwaq17FH70lpBfz2NCvIUn4jvL/6/LScg8a88tAMqudRoYFq
xrJuPN+4+k0c5dHyyo0W0ZPd2DbxrEtEmUFK0fWbfaZNiNH4/k30HsHsT35i
cQHtUNQ8FFxRTrDaoWxB5WUuIlbVVfyL5lvksjlxbV8xjmSXxjp5EDSOfHE6
sJWLYysyv6l3EDz+yeT0OsNeRK/0v3HEmPpB+HkhRbFARLKltuylfOUa/pj4
qtABmfXziexWgsX7xvM9RVUYr3a+V36e+uujKDvlaDa046WGqyjPppkWdz+b
NYMzKaPlQOs380JnTdPaImj2qAkFU/9dZWx/6cC+JhzdEfVLeBjBuwodfR8W
F6bLHLKEBygvSkuGU9L6kfrpcqn8TQZbVaRypFu5MN9cvyuI+peWjYrXoX2N
iBGoTTa6Tfk36kleKVuIh2vD7GNdCcZbxLufVrch1Pq0qhn1m7QrATPWugOI
nj11OL6QwRjfx968MQfs1pHUUtqfKver7e+82+HPVoice0kQ1y2T1x/YCZvk
NbeUfxDsKwmp2qrEQfa9tlsaOXRe+n+9P6TWgN/X6xS3/UHnf1ZXUtC7DUzl
ymV3imn+Dr2zeeF9GF/tfNxFk8H+sKObiV0rpNQFA0kqQY+7vsCfYh2QC0sf
ZXUTrD02khs/1gEJl677/Go672mBEeyhcuwd0Za0onxkTEWe55fUQtqixjGB
vvdrC+uA+BIe9l1b9+9vdN+wrBU9v17gQnCd0+RwHoF1QK6SuXYDFm/u9peh
+0e3uVtPtaUZO9l/T+5NItjrNKt3y/o1LPODVKeyCcbOPzoY58bBIikyfE/3
6R9tJbESyzvx17ntktILtN+Srpb5p2oQP/7Vwj6A+nfaptnP6a34Kl9RUPyY
8qb93KfBqhO8HI6gGiEIDVf3kS3gQ2f0kXDINgZftNZ/VJhugt3fV/O86TzG
69tViKUN4qj3G0YugoGDeH/43TA+uA9LJPMtGPiuKScPBrqQFrPKRvgd3a+B
r+RlVzXi+0GpQd1Q6s9uZm9czLtgZ2BuFEB5SJBOmFzwbITzL2fuaNH4oYYW
xvpTXCxcUzskyiZQzn04EFvTA8VX/aWf6D43mJsKrP/cD+e6Z2WZcdSf+9l1
e7x5OOxSxRISYVCkUinPOxaDCwkGlUGUf4exdIl8Lz6CPu3LzlxG98vTLT6J
dSVYHdynrXGWYIe3zrazVnWQ/DD3No/688aZFYJZFV0oZGWoKtDzexRbRy+d
5GKTtoeIE+W76khG+BJvLoKL43M+cAlU1F9Nu2fXovf2ZQ0V6rdb5j8Vfee2
Y8tYtOW1Cjr/BsIff39QgDqVOYmz1K85G1jrje/1wUTpcckV6scnZ0/Wb0AV
TATCdu66SP3fquz87p5a2HWP9iQHE0R/U5uOy04Bu05O5CL1U9OULMfcPA5c
3o2FsCkv/wNq18Nn
       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk8VP0Xx6WUSIos7UoKiUSW9PhQSoQWSqVGi+x5RAptlDWFkhKJ9CCS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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81NkfxqXkkth+SJuyksbayn1TVE9NiiiJJbZJhSKEhC3tYkkKSUVL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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lWkfxnWylClhUg0mJ9GiZVQcZUxXUikTqbTZ0mQrSklNyKm8aBnJ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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lWkbPkWlxZIpSaVTyrQM05R8Pg1XGmRpIqmsdU6NmAihRYuQSGVL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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k8VA8blQpFkihKotCqBiX7kRKhCBVSSUJRpFIpkjZEUqiQJfSnVJIk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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81dkbvgxJkxbbNMhQqEEIpeLnoaFkaZFKQogsE8lgMKUrRDVjvYlp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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs0ldkfxlUqmhRGrl3ckmZokAqVx5RSqOQSIbnFKIoSuXVxSwphUoOK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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lVkft5VXKZKyRKSoMDMRE730pdRkRggjRWUfZUka1EiWEoVw6UaW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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k0lG0fFpEtqdCiRbK1I0mSS6K88laUiAiVLaVQaEFZUikSQlnKkgov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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8ldkfxyXhF2lKSfZBKVpkiSn5SAZTsrQMGaGohIxIxK2IJMmWNWtT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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk41Wkfxk/KMmXUlJESpSRNJktqkLqlEaXDiLI0lTXqVSlea4nKkiVR
liZOHMtgrBOypCzROSfLcRzHcmzn/H5JKoomGkvv7/3juZ7rua7n+j7f5/7c
91fV5dIxdwkajZZMrf/vT5VvR9rM9sDyqmEfW3YEOyISO0RFLRA4uFt//4XA
8FClyqHoTrBiisICXQjEZqjdbJ9jwWVDQvjPGwmQip+Pj6xohtpDeRUdLRL6
zPbZ43NVkLgiZMxcJPExfoVT9MmH0CsvDvc8TeKJgnuLuzoHGgMG4UdOEzj6
RspO5xQHgiSPR7OmBLQPSNHjz/Zg/ra3ZtsmMWKl6T5bulugaJDybKGdwC3a
Be3zv7zAcIFblVIgibuabEbfRAYMPeZK6ZYkQp8NnV9srsPZT5kF17aRCNAr
T/BTHUZdBsvbJUGIj/xV5rsGOvCpwSlcfSf1voNmifDVAP49WFjOUBvBSO7t
1DiNOmTlfLpnvpZEjGu3zzJmD6oyuVaZnmIkhfZyVh7sRXFiZUlJAAHT0flj
zL+7sajBtJGOJ/HHXoWt3bJ8xBpzzabvi/HnZT5Z8VmAa8FyjDE2ASVjMj14
joNvVTp9iSMEWMGZjfybL3HCJGDgThSBEHvXq3WzL5CRFJt03YaEr5zei7mm
JujW6B4fMCXxa+PnU4qvXqJB5yzh8JjArPZUj55ONTYJ6g2zvUhw82/d09wm
RLZXwsJg9mtoHuXRM2I4eOL3z39zIwl4laY60d71oCkmtv4mTwSJr51BrlnN
aMsnekgFEqTFwnWRchfif+k2sWSI4XzMdOqNKh+9gf0x2o9FCKIXMYx8uiFV
ZOFnPC9G8hl7mYHNPIQo/NkyliDC7yd15Ydf1eBIh5XCJWMSdK/MENqKPuz8
nZH22UME/RYiIiagF4212e9+fTuCDDsNdbveThS+W+J/eUwEwYGNX7MC+Eg0
TjRdyiTxzM3VbrN3H3z1lH96nzKC0N0TY6rD5bg2HFEqu5KE7U7zkv37mlAa
rrEQW0ig1EdyfIHVgLKn59KYaiQqzxzt6mbxULJ6v8GXaTFU6lTbF7h8zHuM
Tn8XTqC1gfMXz18IlaBlM6yeEbAjVJYd4/MxJDVRvSubhImJRavpdBumxnOm
g+6S+OHnbWOXn/dD/01+25AGAXZcU/LsjADE2lrvROfXWG4RvLxlFR9jnXe2
+ueJYL74jb7tXCksVyg+mwGJ6D9qFz+UdGPeMkrzpy4RnJOX5chbVaBtyD9P
xZ9EomrzpyXzQvC0gyOUt5AYmi6KvXe/B1fkQ+SC91L1RprDYmsyUT9ww93R
iuIdWdanV9UN9UKDv5YuEMgY3pZ5VCkd8ubf15dR/jn3OpoxP8+GdebDqMfr
SETlZu3yTW3GuOZ0Sxelj74Za5H59AkmtO5aTb8hUL4uXjPHiIXptPbdSSwC
Ld0rndOlO7BhQHu/ricJkW2zomCwH/wfd2pVfBBDvlQjP+UBDw95F7JIuhi+
nJp0s+AK/L31PYtG/UdmrbjWdCMPcjGdq//MFGGz9hPG/TIudJffsQ7aTYBv
28zfYs2DcwDdSTJEhA3XDykxHDPwIjTG5PuTFF9Lj3rj5604lCIjtXOIgFuS
QsYNv1fQHCj32ldLwPY3lYr3OS9wytGbbqNDgq32rlLA5OC8b5s4JoEAZ+C6
fFlOD4pQab/EX4T9Qi69aaoZl2g77Ff9ReD0XrbRhjcctDz5Nle4g0BxMtdv
/WIblD4+KLhjQGLMMtL08VAz5v26eXFjBKKqaV4LiU/wsleHniZP6fl3Q5mb
Yg1GcoqZ9DMkjhXNbAlSFmJUMypImjGIkMHgkjMtXOTMcnnCODFYExaL5kc6
wK0Muz9lRsDpQNQ48pLBSOotvHuChPFGa7+C650IzI0X08vE0NdjSPpRZ58O
CyVGqgilXbJpWr4J2LC/KrqA0sdT/Nk061U11hz2PTGuR6L8vO3gb5ldCH37
Xf3xLBKKLy8sfM1lYrmSlGDcgoSE7Whk1T9shKzVPZkZQ0JvMq4izXkAxaur
E9gUn01XL+6U5vXhfPue2ofJI5BRjTEzeN2KgIMJKT9Seg5tP/IutrMNKz6s
GSzxJNB79D+vbAyrcP7owQdx9iTWiw5rRBAC9MRoVm2k/FH+rPHbnmO9yPuw
LqSQ6p9ntERWmMIDJ0y0R7KGwIby9NVhUS2YKXh3sPutGE75/qc+7y7GD6Jq
mTBKj9C4BEHFfDtoLkOLPvkEFoarr9i5D+DL6FOxbguJgq8/3u907oe349WI
j/EiXJxzkyiVFMDQretWA2MEYwmufSsPtEJncc+EUhiJa5dWNdmc7UDBLpla
11QC95OL1ZfI9aEy2ea9TjCB4FW3pDsceSg2ZTzyoHgrGoiV09U7MJyTu7i0
msAPVxSCSj71ocX632/9aQQs15cF3KvkQesX8+jofDFoWtu3ydKeY5PRxcvB
wwRCdePpq0cTUR4S+k8+xeuL+MteUyr/m4alWd5+YtgHlmvfmayFldlVKZY7
iSUuh91yDnfBzIjd7pBLoH5ktsiGewtVriG9l5yo+VzRIUyLHYSEuomVxxYh
ghWbspeeFSLvefgy6WwxprpyAvVreagnr0dOUnkUy/foPrLhYsZ0H9PAkUCk
1MqpKqtebN/MZa9ZQ+XNcFJdWfQSl104u7QfEEhddrrLQaUKiXaEv5YkCaPd
83VD97rhSdPJf3uWmj9e9crFHs/hOadUPBFC4G6GvklQeyv8PzhHtEdTejVM
yGVQfn3mqPzbA+p+VUHSOp8d7ShluxqWUvn9KC0VnXr6BUpbj2z+6QaBspsp
vMJEPm5UaNsf9qb6bdhnoCjXBaa+Pc12ToQT01F2+pMCbN36yORkoAh8Twn3
hKW9YJ7L0CxYT8JJV6AkJ6zBqZBxv+/2kChRvmZr1teKiOOHWi1dSEwqGzde
KGSjMS8g3YLyZ7F1peJHmX4ocMIyU8uH4a122uGpVCM4kwf9N00QGN2dtdZX
sgd5c/1p9uFUHqTZQmVmBX517Uk5GULV/xIftaDMheyli2p9URTv1HndUbc+
XI1YsdnLQQzHQ9uVnIV1+CpsTyVzSPwPGH7Y2A==
       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4Vekfl5Q9oiaVpMYakxKyNR+hLLllGiNrRAxNiy0pE1KGcittV8pW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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3lUTW0bxps0aERvpqQoUlRoMOS9QhFCSKVImjSpKET1lqQSpVAyJ0rz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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVns81FkfVuRTmzTaaFulqaTS+5ZsBrvqcWmjWNlSLosiobuX3CLEtGoT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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81Pkfx8X+VBOtUluOzREqR8lYm6iXjeyQHBlHmsparGRldZCQnKVD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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk41dkftsRUJBWFVJLMnaxRlNLbKGqIZBtMliRKQpQ7REpXhCyN5VqS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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4le8bR4omlVAho6yWEZXoI/FtfpHRQCkJla3MQqnsUpQtyUpIVkT2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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41dkbJ9ljbmZoIaIsSUYlTcIna9GkrGmZLJUr7ZaSQQgtP0qyJMuo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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk8lWkbFskySE1ZmlGWqCwx1dAXumw1GHEsLZM6DkVEODNUStYyVIPK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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk81ekXx5WS8gtJ1CS00IyUXTL4mGoklaWMZFKWGCNrRItCIgnRYokR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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwdmHk4VI/bxtFGqZBS2lQqWcqaJblJi0qSFEm2FKl8pUSFJDuhUBIK2YoW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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk4ldkfR2UnZQmjhrrZklREWT6SSMVYipJisrSomKxRihZFzC0NMZFK
Rkoha2Hk5sa1XttFJe77ytYgKpH4nd8f5znPeZ73fc5nO9/vV+2wn6O3kICA
QCJZ/99ntV0+SRoWgXXjdUfPDhqnPrccquhrQtn3j5TqIwrmvl6WDk8zwLSO
ftixj0bJAne3uDtlkBbZNsR0o2F1RDhZaLYDxk3f1Bu/8qH584XyJ98mON4d
NjBg07CwFUvM/slGVoLzZMYAhX15L6NhUQhKSl0rbi+NhX87mz62Tgf1zmHo
z/00djeM+65k1sNx8IaXowcNA81LqaHa7+GbXBljl98LvcSVvqOZ1dg+4yii
Wkqh9XXmgWMDHQjcYNgZWdmHxfUSdnb7eZjhemhF5vDh8363mL9fLVKMLy0U
3ExDdDLj0DyjAefez0X7GNDQs3XN+ZBXCDOTYjHV7TQUVaYzVYJYWOAur9Dg
ROO2U9kJ2pMFq8XhTSfnKOS2bGPv4eZCPJTxywDBL765XUophIfS0UVnYjQp
KJtMMLUmGsA+9HQdk0NBck6uTVitCW93+Ua8T6cxbn0uMsrgGTy0S48f8qRR
Od7rdMs5FqFHgzVSDhJ9b1CGBuMlSIiy/vtiNg25NsMr4t8a0KLQfjt5hAbD
gsOelq+Dns+2CWMX8n3q6RDZmRowXMdYYsM0BIStjjxakQg7Wt0zlOjn5lOQ
/kHnHR6HHFlU2t4P++y4LdIF2TiTnTA/aUej19LnSYBMLcIl6lRdJigw5LYM
imaxIOmWZFTlTENGU61qbnURAi1jHu/eQOOWgEnD8zXNuFVw8K2oST8uac3W
jrzrQn3BgCw9RfR8aX/epOgBVpQrNMT6EHyKBbY1Slz8mpvuF6jSjy9D8X6m
Pa2wcNjaz2mg0HXUVD3gfQ3k4n8cTvpCQdFzsmV3bCNef+uNtiF6D7L2M2e+
sHBFvKB/4QnC/0EcPyO4BkJFOQF0Eg3/9tDT9+ezsGNF/+pJkp+r7bvDds0V
QOaqu6x7EI36tC9Ke8Oy4WPotOWeLw2PzSd/Zty8jCnD1IWF7jTa6/VXxb7t
hl/z9KJLeiR/G1vjnIvaUCMsqCw+RcHHW6RobXI14vUvW/wRRyHK0Ol0UH8t
ytcPDK7b2I+Sat6IlzUH/9yZfEqr9uOT4I9T2lQTEitfbi78TiH9ldPFYoU3
CFwZcjJZkYaX0r3nWVMdmPd/t/DVHI2wyCvu58vaIKNnOf3wFIXEMpEFgq+q
UcVLcbLJpaDfp3SgsDwPA6MceV1zGpc8jxW/vPwYxR9cr8h50RDOEq/xz+2A
fTnDvNe3D895h01CBnh4Fm0TIfeuD+HJiju5hTykJoTs+GTZhxNW3FtPo3Mx
2vbi0GwA8avT7NZS+zzEWjJul5H38flomNF/O9uw7oJqbzeDgsnIGwO7qh7I
/j7TwgvqR/3t38z95Vuh9eSPWllGPwQEAvKH72oiiGEcrUf0VNG4Ix+5jAV1
zXWOuiMUbG7cHJ0+3YaNygESjjoUrutXdlp7cKEnHhAU/BcNpprqyOVCNsRv
NiMsjvz/8niZUlYeFMR/Ec4PpmG0fa1y2OwriI7zTy1LoVETK+YSua4CY1K2
NpHEX9Vnj8Y2/FaBfwvkG2QO0DgLiYzxbdXoTbFJvG9FI0mw0dtvsACzim0B
W0l+BQw5gnaZHAQWNu1lE/2fZHZnjP3TCsf/mrTa5/tQaaogqRIVhYyP+f77
CJ9dOWu4xZcbYMCssgz+l4K0GdMgP7ADKTeN+CD8+Goon9jaiR7Owtq5JXwc
uzhZFx/QgSZdzd4VfX1Y4RF+LGyIiwsqo5+8hMl9NXb0qsl2JH/ObVuV/hF6
vBjfZs8yHAxbNpX0hvB3emostLYQOrtiK1OIH9fdT1W5zLSiZ4+D5zVDGkfP
qUjdC+RBS+ND4l6Sh8YdJ9VFOlvwOM10z3+uRM9LSsJ38uogbrGVo03yax61
oXO/0XNkbC6qqiD1zCjaPcJO4w2YxXYH77VRUPXXda0VbkXJkTds/UEa3Qmr
T4Zp5MHt2rC5iBnB+2K0wTu8BkfkWPfbRIh+220WL+/qgt459rSJJo3hq3uq
c+RbwP5xbUlqM8n32sh8hloH1u65JtCVwEflT869Eaer4J8wiY0g9Uh1PrVj
jpsIk3peShI5H2XlmR7/2QSzVZTVVC057w+2/mhTAU9hTZ37NjRMJBavdo+q
g8Kur6Wi4iSPv9/aemNBFzSfKzp5mFFgRgvMLn3YgTyHtBxPDT4sTGqKxQS5
sPhQVenAIngPmA98vbATN15UHdEifg7eFQjKp/PgOKZpXH6O1ANWzHH9JiZO
dEbbBpP8hOk/FG5l1GOfkIxXGsEzuGKx1mdtks9NvAK/bxQipM9aKOtwcWzO
I01lDYVeDcvlm9WS4ZwmumkL4eO0OvtmF6Md679HyCYU8vGJKad+/1UVSlzu
ujeS9zoe9OLM74rdePYi7YGSAIX1dOh3ryc8PHk77DEwTEHosMEml3A2CqI3
qvDjKcwt13RuXtsFS5+Yf8OInhcUtJfYeL9BzL7ToYPlpP806DLi27qg4aD9
UdquH4cPaf9pt4SLLVIrnbZtorF3Qba6jmwbWpce2HTsch9UTk/ha0gNXJ92
6l2UIfpo+cT/up8DAdcTEfqkHtDCnGpTdga6f7BD2aQfeomsj9Qu7cBx5QPG
DaSfN0vvlpWo68GmMHtHe72PUFxakH7tHgseO2yHJMNo/CXxR6lQSh4y5zcI
unuT/JR8tzWVasQGo2/PGQ4UxvzO85iSLag//1JY4hcKLlLy0jIzPKgnm415
KvHh9kjypP3netKH+A8Wz1PwoK1mFWcacX1r07QFwdvrN2op5JSPs0miCrqk
XpwRG/x+Po2L3gtJ4W4cGsrpE7fvL38L9Y67Xu0lfZDRrWjV+PoEnLLOwB/E
/87KtGUlSWWwSBqtGSDzzs4fLjqld5oRYWaaOv+WQqXf4TWLhroxPneO/Q+Z
d3rd2BVf/irAzPnwBWpkXtjuzBLKnHiHae9sm+a+Huyz03ptrJMFhaEWv0W/
kXmh/SE3KicT4rV1Z9+T+/4HclCiQA==
       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns4lGkbn0Qnaq0tX9RGErYt6YpI+JGS0zis84acKRraxKgUtbQJiygp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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lVkYF0ZKqwqpxtZiVKQiCj9RhjJ1QzNM0iUakWsNqbhDWsiUBhlF
apTE0JUIN11L9izXtWeZOp+l0pWkjIw588f3fM953vOc877vb3mPmou3jZuk
hIREAv3+/zft6ZKeLmhB7wryOLST4Orq8f6NC2ow+zxbxvsiQcerh6P5A8V4
9So/KdKTIMufOVS6sgvb1ctvW4cy4No+ltggWwTJKMX5zjQezws53ni9CBen
Ah5JehCYrlf9Q97rJhpXueutYBMkiq/tMxzKBpe7sVr5KIFr3dfOgutlGDAI
zLP/lWC7/nXnfFMBhorayg18CNgfsmJPhJbh370xT+MiCAINT07YfduMqMJ7
MX0vCHw8+1YLIYBHjvC1VSDBxcmNia+zGpC3+GVd9GO6To3w2HGLiwVVpXVm
Rwhstii0f2fcDJal3IZxGjfyYX1wDWqBpbvqtmMDBL+FHr5h9q0IfxgFR4uX
MHBU7A7maxUj8d1M+SdvgrkOP50oPVuP1WbFTuYpBLp6bz1E9t1IH2pUCjjO
QNn4eFJ9nhDd2qJ65Zc0f8XJAF/fWPgE5Z7g0vsbagxmktXaoB/LT/BbxiCg
1zuApfIEFjx7USXt15J+5ba+qQ7Ml/FbOcFm8D43wkU+ug3q6prs+yYM5K5Y
uf9g2IyYxFl5Ou0ElZdDBxXvCFHMaTr0cZgg1XPb3yVb7yPY2j30L2cC6eGB
MoFuAxLCjMxwm9YfPGtM3a0BPrdkr/6ZS/ExVR9zifsDYzGO0k00P9ZbDjkX
3IUn7ldzpCIZvP45x3NLaTsO/nvmh3t2DKa3CTp8HFqwkr94XqgSg+wb2a80
3Uoh/farIPEUgWLz8HGdqTZoLUzxIXsYyHLe89ZWtWPk05fJWbQ/gkRGhhvR
iRnxfoFRCgNTiS6vNqUwyK8/42lK79cs3yXe2t+BuiVSyaMsBldDVU5x3Zsg
XaiT7fOMQLX8mCjQngdLcxP+tCvBl3+uKkWECqBd2aj5xp9A5MuVORhXC5ON
Oxc/OkPwTf3NcXFnF/Zs8jI5TflqrH/+3OWcZvzmO8vJVkwQ7C4OtDrUCoMM
sdqACoNRUVqm7hAPZR8/9TrS85OKraMzg2rBl5I4sjiR8mWOVsOi8C5kG3TD
eS6Di9uXOexQvYtwz8FUE9rvRZMhxhqdxajdciTYgfI3VXO5prZRIcw7CnO6
3Qn8jGPcMlZ04M6ypJC8z1Rvqwo4jUEidK/TSAotJwjXlcvWeyCEU9LmEq0J
io/5bLtd3nzw9m0q+OBFMOrIDq6droDO4JqueaEEt36xV4lrbEJSZYtU7CMC
O7+HRfyESrx88XXhtnCKZ7xxZKxNDTpsc7TWJBE81Fy5RHm4FJOqrmkyVC/9
/i/2ZBY+RKNh6YWHtF7uE0v/7oBm3Ps9QzCvkqCnxfXJ44kOOA1Vx1Q6MfB5
7i7KOiFCqrXjr+vGqT/o6pF3S6uRWnbWpvECQbph9Fyj1laMlaltVZKh+50l
1kq6FyEgPakq9zjB0Bzf+a/1RNgRfTG3Z5AgbuLdvHu76rG/VWk6Mp3G13i5
6l6vg6PG+ZdrqL7WLlJLL/QW4ZtLGgd/HCGQexqbeGRjFw6vW3o2yP9//iQN
Wg5VYrGhbFoArddUd9CaE/YIPgqQWX2MIEgucPgp04PqoIlSvyIGHi5pfwot
ujB/1IPdc4vBrS37dj8qb4fjb4EpBt4MWOnDA+tTBCh1K9co86X+EmZ4IJrX
CdOtiaY1LgxS/bj1E5xmVPwcLMwoon6mLCXeK9mGyYSebzVmMygNfB67v64C
O6e+XzWL4sM/HL/y6F4BFO9f+hN+BIv1T8mMW/Zi4chH+7oNA2BYGy5tTGlB
h6v5iIM0g0UW796oW+cg8tqiJ9upP27QP+cV1diBsCijclD9uUdhp0C+EBxF
/tN/qN+6PvM4eaShBwEnOa8PHWAwJOR0zdl2H0vr2v65TvmomvEx/7voJqRs
TnPszKN6aP/d/HRSNzqsI2xGqB74CpaumwXt6COb/GQdGXxdOGIgKKxESAdj
4R1NIGE9eYYzpxZsrfe9dlcJZHXTcN6hFgl32ohdHMEhn2Rb9lQNIiVX5DtQ
vNrsv6juSq9DPb+6tyqVYMrg9BV2Vjck+j+vvRBG84thGYd452Bf7x3ZA7S+
KJsLQZ+P0v52pcv3X2Cw9Mb65ZoqjXjn7XVFKotAKO9jcauuA9Pqfjo60QwS
z27KFba2I2jZS5/bXgxsAnxniwZF0JdSYWWqMmhWePcpntsF7brj0k1xDCQq
88TDNq5osPJbvpn6y6i825uclhJY/Mjzl+ZQfRxc4Cs9U4G8uh+T7bhUj/Li
YNUbFZC3qU/vp3ySKR5P1O55jrlL5la9vUT5yVbsy1GsRsvq6wXFlwl8R73d
SuIr8GBtf/sM3T/fY/d65ffVMOXrHV4XRtA0tuKMlW0FnggzZteeI7gTlqPH
5aWiPdhlxVE6D5s0T1b0OgkREHIgYeUn6s+z8kwMR0SQOvgg+/ZmBr+2+Nt+
LikBb39L9zjVf4nZnIIe6U7k+XP+HfNk0Po7X5Jj14I1VebHvJbTtXP2QfOJ
Vlwi+QUK1J+I6v29ouoGtM3MV1nPo/Poudv5VR/OoTbM09ma9kP6l6hPC9y6
UWTWkHl3NeV31gnbftVkOLN2PFtK86td1ukdYfsS15TenL5pxiCuz/CwaLIb
dh/YVnZ9DL40BDf/9HMFvoSrhVsE0/Plip+PcVsQ9/Xp1p/4BA+sBuuvvGiD
rUdZePIPDAo1lk/vjqvBTpGVg8UV6je7Ldye3SyDL/eh3Hk6P1xOed5lXRIi
b5FCTmYBgdIq/q6943komLlp/RfVs8FHl2usy+nQz7X7PEzzy/eSu31iUxUS
hDonOfS9MvRAfC6dXwzHhZPxEtRvEiOe3xWuKUL2N1Y8B4r31r2n4qccKmA5
sMTtTgCBU/T35ryQF3BkP5tXQ/lawRGn2URX4Y1L23cboqjfq/6dvfxjFaKW
KgxmUHw1U5axh/0EyBwu1XamepYw0ToEtSbIPlBal1xH6wlRDtQejcTRZ+qB
LNrf/wC+P7wN
       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lH0fxaVET5FKIkuRlJKleiLk2CqVkFIKJcmWLBWpJKHwKElpkaQs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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lWkfxg9pIjIqUclW1qSQqbHUpaJMoeyKCkNkSTVSHaNshzDZk6hI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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk41WkbxxFlmYiMsfRKI6QpSfbSt8JkwlDTYIxkRMTYUr2hsWUiNBlL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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4VekXPpUMJ1GSJqMyRbkkozIl6lUjMUWRrirKtdxLblGSW6KEhNwi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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c4lf8fxpFRklUJJaOoREmhvuKOJF+VlVBfmmQklFXJCMkKWQlJUiRl
y8jes+PYI+Oc5xyy0pIifs/vr3Od63quz/W8n8993+/XLXnZ0ciKjYWF5Twr
C8v/f9V/phjXZHfAImU67af5OI4E+fm7TCVgtV5U94I1gXzBPYFvFZpxe593
PT+dgWvVasLH7Wphf/dqeRYrgZaNgmXzw33IkmrTaJPqBctM3yNN8Wa8nHx9
b08QDXz/jtw7vr0XwcmOQ8LuNKTrxFxZ3NwM3d5dimKydEw+/PJ+QZIK5qDa
x9a9dEyYMv4xv/ARd0eFZ19uZGLoyw0V+ep2iOSZXpQ/QcdOwfS/YTxdUPUO
F39qOIgN+oJm4xmNkMir3l4eRcfBSFe+hox+JEsIQNiJDsL7P+61SxFw1KAE
tF4mcFBTWY+3sgAu5/Oevq+gI/2c6v0EejMK3y9oFIjSkJswYvW2tBzbrfiS
6AQdLAmblKYfeWN5OmdI6QoBOY6ay8WdJTA+1h8qKkMglOdTB224Entsd+nr
NtJhxr74SMDpBdy06I2hNgQWTiXoty6VoHq1NN3zDgHK+t0vuHxrwX86/Zfv
KIEDr+xuaLM3Y7Wf4NtV3gTK1lg5sF5owaU4frGGQ3RIuPnPcV6oRYuS37WU
RAYSF3ukiV0FEDzuXlI8T54vpaXHG5iO9O3eOw1PEohgfa5r86gT3Dv6T93+
QMD3jGeK+DAV1L/WI40cNBx5bR/wdF8DJI4FGf82IaAZxSrvbFCNiGGFCLZM
8vncf/Rqlvqg/qHG1f3hBHYxJ+o9NAYgft1hcqcSAZa5Avux77YQqqUf23KB
gET4F1fVs93wUNE381ozAVdPpdHZO13QanBNdVzFxNk3uZR6p17cLIs+Pxz9
GfuZuy3ecFDhuFLx+VsuDaOjjzfP5SdB5/70Zr+9BDbEqD05YzIAfoeSg4/r
CBwpzg9VjG+HT3dHyWk2Biozi259782ErzHrkQVHAhcPzZzMeZGFDInXuV//
JUAz/nWMzb8Tq7aV/qRtYmB1ebt02613sKp29qBN0PEnvbYysLcL3E8MOVUq
mFiIdROW92xHvZj0wfwOJlgOmB6QdM4B2+eH+TWrCSw9TeNN1E9DxtUWg0/a
BA7HeXFN7eyAloTwPVMzOubSL635s1SAnWND3tEXCXhx8AtsZgxC6um6G/wq
IxjaXJg0l1+OPrsZkWhlBowH1r/rU++B2Pjma5tnCOxhGLJHCDQgIWFzCtsW
JiKeSn+10ihBV+GrnBUNAoVsyXDR7sadYqFdbaQ+JIZfJHsXJ0DcsqBEwopA
R5zMGq7wKpy2s6et+kOH9aVrI0dnWyDq+NXOtXYMPC1n9kSZDOFR3CGRt5+n
0BVZNm0b2QrLXcIaxvIE+n6V1f9aXw3ekj8pMjsIpPAnbL+/UAPJlSIJvQYC
Tq6Bdo/j32Ou5og95R6BLbPlH05cyYCL1FyHuQGB7FVcSjEBn3Bii31gTyET
tgPiUt7ePWjqkJymthGY+NXSJeDUiFu76/KtTzPQJ/d5S1FOEW7qhNA35ZN6
uqpoGLjaEzYrl7KFyO/nJDqXuudcP2RC9qXf1RiHnMGSfXp6NgwfS8cIDxGY
vjItn27bj5LErBmOFQaSC7hNtyRTMbZ/ef2dkzTs9jR62X62FzrOXIsbhJig
WAdMLy29Rax+yreN4QQq+QR3+wtFQCkr510DqV+b6UQunqUWWK/QZGK6GPA/
lSQbx96J/NOmnqUtdNyq27dZVrsTVlm/d5Q+IKDwYeJKxXIaqC72rFxnSP2N
Xis9saEV00ntds/z6cicpe/8rdGPZ6W97JxlE1jiNi10+9CC0Z71UwsvxnC4
bdT533tD4KLkK2WuHULfFFEQPkfFYQ3NYpbrNGy3sCncJZKLRckHIoW8BNiG
d7cPehTheE5wOy2MAN3J1CdhqB/FbwrjAo7Rkc+ftqIm04H5VIOz/X40RATn
q409eoEqrVcba0wJGO3ysROn9kDqgchNQX4a2DdqObymlSLNsuH0FV8CyhS7
C8nO3VD+xmlmeZSOHxmzFdzamdCwMDq+w530X/XruPbC1+CUvL42x5JA8CkO
8TP+3Zh1T4t4WjECfyWdnc/vDqF6u+zv5gI6KIyGA5H1vVBh35SirMokv5e7
caSPK56426rssiDgs+FPY09kDlptjJz7/iHwYflAmRN3FhRyK/YPaBFIolyW
3q3XAQEJwZ78YvJ9Nr3+tcmvEsw1nHKfqXQ4+ab99I99iUCHD/tvk/fHsnu+
QmmrG3gbOgKESf1EmBZVhZ5swpbBjLlHdxiw5rt+5T/nWqQWaF+xF2Jge6g0
47tCK/aw6r0N9mZAeCozmiWyHpWa/EJ25qSfWeont9qm45bo4748M/L81Ecv
Qm0+oPbspojAXALLrN0RjiI9sItO2cEMGYPw1YE2y4QuFCwpqlwwpeGWYr1p
4q4uxAw+/GgoO47K+8a7v5qnI0LYN+vadQLVl8X2G+r245892kGNlybh1ldi
uVw1CH+rbJNltQFYB205WJLbje0PVBPuHGRAKKBJxmemCgvmvdE3OEn90wPe
Gf5uBO+BjdL+Hgz88PaSDTuRCX4zbhmLmwTaWexXxhJacdbtZuXJAjIvvVd+
JkW+hVPJGqcN5D6XPf3IOvVKI9if3jqk1jwG0akJhfuBjSjlSDXn02VCjOcC
zYFnCC5Rr8UyQhhg2Z8x+7LqMZJct1k0kH4XfHrpHHtWN4ymHW7/tqBBYZA/
SGZ1A4wCLe4kx9DxoXH4Zl5iGyKstE2TJxloLrufXD1FweqCA2f1yffJruZR
NbyWh1MN78p02gmkW2ZoVp+oR7lcumBBLA0OwQm/91qSepWiJeTcHyV9v0Z0
kVEFifVpC28ek/mZlBO4Lb4DIdsuL7jWMTCpp3l060gvUvZbK28+yoBht5Xz
ykInBE8+tlc6O4h/a5veCdj0weauos90LhMfjEJrqkm/tdHyY93P0cH/0k/3
SdZHxGeUWKQ7DiNO4K2uvH4XGqV8BpZ46JASX7Uky9WB+OOCyTWVTJzoszJ4
qT8M9uOvZrPNRsF/nV+p8HU35DPKU3fuGMdUjZK6wMAAkm+bqB5m0GCp+rdz
bzsVEioqQ+f3fgZ7QvK7KbUmHJDZlCbvzMBliirvLUMqyTOH+PdSCTQYab/B
827oa6n1HvQgeUhSLLkuqxlS1/27brAyMRrrkdBklIBlCwkNKRAw1xAeitzT
i9gaKSFKMLm/BHo23JROwf30v3LZD0l/uY5HsBg24XSsv/MKySfCHn1170Mo
0JsLYr9B5js7c1azXZT0a7lWIP+xCVA8T8lzKA8g/EzWjUZtJubara3vHPmI
xUPOYUP5NLBka6TK2GTiyXzb+D0FAsVXG/ad4ewAn8emoGB2As91tIRz3lDR
yXnoMVvGCIQ25LtVvBrCzlTtYwPig7g1yxnA+7kLhzNex6SRfGg5c3NHTWc9
/viFrhNTYCCiv/TwN90q9CR1egU3EYitIxZ0EppAvTGv5iFMICBr2+5DtVRM
6j8lTrdMoDKxwpWzuBH/9QyZzK2no+vu8snR+9WgprJlNveT89KSBbaxNMH4
VsyIZw0DmrsVxhYqa7HbTDFB8QMTxnm/eVLe1WH1k7W9OutJnvK35lUw6IC7
Wi3eGzGw98DFuqbnLbDdKxR+M46GVGG91WF2bZgaPr2S6U2DTR37lZwjuWju
zOl7N0jAgClf6ru/DYXlLhQVGhOKv4Kn5ILqMPeGxsNtyYTWGcFtygO9kHgw
s2Ej6QcFjXy+38ZdyGCfrPWuJfNIZuIq9UoTakqCOGLmmOAUl4d8VgfKf2jq
7jUbQ/ZcmKijWQ1OFp6d/3Kc5EkW7WMXrxXgKLfe3zlZMq8pbDxT5/wAjlLJ
jWRes/fQDPM9G6F7k8HTMELmU/2TG3jSAROGd7YHuU+pzMcPpmwLwJ3K+oCL
zOei24Pxy5XvUe3QnlBvR+DnuiiHuJdU/Bhrbp50YGBA9Jp87fcuhOkPL9vl
M1FZ5dqw9tAH0OJZ08s7CWy0kFIurO7A6oyo0HGxcfi+r9OS5wuCe4/ZjlqS
V5IjfX618ZRDWTIkuu8LHQaxBjSbL31obFoW6XKg4XxI8+Uzt6gwt2NGCXrR
IBwksu+HWjn8lw32LpYS+N7pcuSNbCX4rJlx1DSSv7+X36bEl2LS+sJvgRtk
/v+82nOhh4I2M6Wxr500nJ4lmmeauuActjOYI5uO1phI73cutdDZVX9FfYKB
FA9ZkYVvfSildTOvyIzjau/fyQ6RbtyLXjb+GDyOhTyhxX3muSBehkklPSP3
/Ttd1kslGUhvzM8IlyRwV2M4Y58tFd6CK02/XtCwrKFiYVfaiuW1K296RSbQ
17nDbKigHKrWcrQAOToUnnDFftR7DuGjvI0F5P0tHMxRec3eBJfkRg71bga8
lG4kuse1wjRYwfPRKlIf80dqbxzPBc+hw5Wi5D6urKl60+BXga28XzXVWghw
vPwh+GNjD/jOFLyIbBnFco7ZAvepDmivv3pe35OApbKaVa9zP7bn2VqWbWWg
s0ti7bIOBWMs9IuvjjNhvl/Ytds5H6OCG8KXIgj8PpOYKurVCYew6zldr8Yw
2h6k153agoD3A+vfJjHx9udOxVaPPnzQvMzksR8Cc/VSjNitOsTH64oIficQ
SUkxYTnYC7k6iV2V1eMwMznLLfy1CCKU+eXYegI1GX5puwQ+gU+ntZLnC7k/
G1R92q9Twft3/Z0Z8r7lKtJj7VirECYerTNeRod9rqgFxZ/0otazIMolBiSV
nlQmCA/hWYbdjtO/x/DmSNKWdtkKqN6FeTjJd15/t7ayKNfAKqLl2/7bdGzK
DNEXb2hBkITYQ98HdChuz605dL0LD77VX6bbMLF/56drLGI9yD7iZk1Vn0Bo
1JUKm9QCmORqeXOHErjp0HiCL68PV81jWFtJvnN5P35Jc64OmqPWfjWfyX0n
nawQ79AHFx9PEQd/BngOcPV4hvVhcq0NJVFxEuFyx03140i/hD6jPm5kIK5f
lz10qAi5P+cWOJ8SUFn7Mf20VCOE81TPqo6SflhwcFG6UQxRVuXZa9N06HoH
H8hX7ETUUswmSbtRTOboxdSU1aNWSd7/N0FgTvZ7dexKGcnx5XpxjaQ+lC/4
/bKJBv8XXXIZEmh0NfMTMy/Gee2/vTMnCLhkqHc7jVZjzSo2R3E1kq8YT3M9
aJ348U0tyGqe7LvRFyXnb5zAfObraCmSr972ejofflCN8vMl9q7SBNTszVxX
sXXim2/hVaG/BNwzt06POnXgus7IQ/08Gj6s2/vA26oM/g5LazcaM/CgKupr
/mkq8v7LGzR5RwMPe1A6c7YYHeHVTC5yH33zTqHVxrZBXbDt0u02Gpg8/xXX
sFFwzk30+ZuRUSRv8r6jUdUBK9+L5bUmDGgbVCY/TepAhpwXu0/RGIa+PB5W
svyICcUEr36tcYya/CnauyYWAbVHBhrPkzw09z0/rImKktjMryFXx5AscEl7
W0Aezm0KP89K9nGfHOLI3DNnBNqo7eYln4/wHip2kq4Er5x0mboSHTrvknmD
EvvhOfJFcqqc9OuR9zNtX7sgP10XuSQ7BIoK/RbNvgDli2rRiz10qCVRJwOr
GuEXU501nMjEYa0d8dsvVmBetmLkizMBGUeZA/yvGtDDw/870Z0OXhuuY2kK
g8i+qD25KnwMERmZOXDvhuy17ZJr1/aiK/qM6p35InKOxs0eZJ9avc7A4jtn
Af7lvCHfR/5Xn5EQUXzQjhLdbnlRUq8XOSXUGVpVuLytV9jxOekf70jftEv1
MNr69QsjhQH2gQu0+uk+HDvnViVvwMRB4wsbH3fmQmirNV18MwFhncWgyNgc
zKq1xHJXkbzp9md+VV4jWGqpG1n2kft5IDnE60QXyoOck+PX0nEughkaL9iP
q658LXrp42Aptm+1MPqIvDe/FNxfkfn5N5tRc7MfvFtyflgd/ozglUdbmCR/
GEZpv5xjYeAPl8jUvvhe2NMe3F5iY+LVbDnD6TwFcU12+s7ryHmXUw4W/WwC
JelFYD3Z9/85tvnXsd9UDDpLbxG0GkOlgu/i2xVv2AT3Fs+Q95du5JpnMpqF
6iaTkNtuBMyYU/FSZ3sgpPpiL9NxAkIamm+jqJ34tY0W9l/IKBSWQx4QRqWY
Dnz+z1GyX08sev2bd2oAA9fXnDufOI7WwY3rwm0/ITZn69evCxNw8ir0yL5a
j8DzykeP+JL90uLmG9bqNvBw/Dmle4cGClW69VRWHdKbojhcK2mYq3y9R3td
Pq4Ttx/Hkfydvaf21JfN7fC6n8f9bYQJa78TnS2bOqGzrroobYqcZz1njXFH
IdLPxTVah5N9h6J+TZCzDhvHLhlyqJHzb+hl0Q7shs+fZ+KVZ0i9VBv4/swp
RFTfYpUF2c8Lm0XsFV98gnX/GZVfwZMomprexZ3dCb1oI5cacZK/77k/TBzq
AHuS3DkTZTr+mIv00ILSIaZ0fbr9MpkfB8NsN5S9h+SZdYcTQggERkZIKijn
YX7pk8u3aAImMwHOJ40GcK73XPysPNmn3HrbDZ+3wa253Da2aQwHKR2zJt1V
uDUSfIuD1LuAGjWpXHwAbNcFZ4xJPs0/KdpG6e0Dx/kS08awHrwqHPVxWd+A
OiO3TbpxTPzoscxl9X+Bb0lOz7bfJvup12fx4JlBdCo0aKWI0iCz+t7KKp9e
XHQYLrU3YSJRX2AL/d0AhK04hII/jaHKMbQzUDQfUtVxW+LJvshyjqNEW6gP
p3fXFwSqk/3YU/gf0Zwc5H7jfh1D8sjFVbbz0UJe6L4aEmlFzq/W+L30mkUf
Tj6x/li8MAh35s3XnLYNOLUst5RZSOaz+ovZJctoMAzpO8d1CHw1Fas4bFyG
pEBBz8UPpH8OBe89GlaEorin5Zo9ZF44GmQSLh34R5GFhzhLB9esj7ipdSGy
tqF1Qy+BuI7i/sNSqVAYz1SpJvubPEd53F3NdhwOi8269HEcXRzOZYcnmnGz
9sA1c3caJGZCRPX4SsErHfCKR588//ujyw5RVBBHnytnkPvSNuEAW8evBsjE
rKWpqdPxP69GD58=
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVns4VWkfValcIiE0JpcioppS+iK1kJKKitzJ5aMpE4VEUoPJZVQouUWR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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs4ldkbPbnUiAk1jhAdGpcudBqX1GBVSkKK1GkkZBRObl3QNCrTFZVo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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk41fkb1WIyRTEibUKypsXWTExHNUrIiGpUv0oIqSktCkm3IlsjhBRl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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k0lO8bxhFtFG3KUrRZKiIlJJdKSNZSJBH5SqQkSpGUkiWyFkqJ7GSX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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx2+SNMky4deobKUSbpKUrY9IKEqrVIYWStOkXxOjn90gNUO6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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs41NkfnrVKG7XKtWJL7U40UYrKJa/kkqgkG7qxyNpY9CuZctsuKAqp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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4VekblS5IxUT1U4QyimZQ0U+JpWhSSSIqESMSijNShEo3B4MZl6jo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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8lN0bxilvaZMkqWRL2mRpI6nLnurNEiolhEq9WYooES2ECJEolShb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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81HkXxz2upbIjcqlIKiSLtpQsfWgVSRuJTWHlLhQ1idVjU2rto31S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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk8lWkbPhVROUYxkt2xfKQaTbYiF9qMpU/IZJSdtOEzvoqhpAalhEIp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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns41VkbPYO+oWFKNySFzEwoRCOTzBIzZlCmTE36RO5FFEOSpNuIKFI0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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8lO3/xSWl4pFSUkkIxbfFEhVyhLR5bEnxiAipJJQ1ClkjZY0WSZGy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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41Gkbx6USrUOsNGqTSg6bJq8kHfhqtI5JDkVyikWRrEOlSMoWYkO6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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs8lOkbxqcDpibksJvNIWo7aAm7lB/VNRSinHMKNTmVHIYmlCjRiUiJ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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4lVkfVYlMSBQiZaYp3YgMRWXJCI/5KBUp5JprqZGKSJQaZuQePiSF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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lf0bxxUhCZV6RAolVORRRkkfq6IQJSmKkFURT6FCaFmJIgqFlEJW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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlns8lOkbxoe0TkuOKYki2pWi0abD5JrVoBxaOR/bYWWw2ayUVkklRCy7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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs4lOkbnmIL1aYtrZIkVErlVD8V3U6L2iZyig5DJHLIoSi1CWnZRLJY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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8llkbNkKWShMT6ctHw1AYS8lk6VJTtmRsUzLIWgpZohJJCU3ZQpHI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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwdmHc8Vv//xmVmVlbKzKiUUEm0roSWCFFoWCWprJQRFZERZVX4lBCVEhGS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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs41GkbRio+OiqsKFskSsmWSNtNckxboSS0JSRy1nFpK5MtZNEi1FSi
gyKSkBwa45DjYMaYEZn5vUOhoijJ8v32j/d6r+eP572e9z48988egQ5eMlJS
Usn0+e+uGfoe8OEcH+tmG4teWYjQfa680ySJg7jWV7O7siismXXU3/AZF0O2
PlLaNwkOxVVTRyeqUWwXF+t6n2C3Qmv4CflneLV5xqygKIIH1arH3ge0o0s9
wizKjcKolN3IfdMGHHIw3PSS7k+7/WHB38MClD6Pyj23m4L6x5yKddUCvG2z
fV4WQaHx8KaUW8x67Ndu2HfWmiBOLGfUsYwDhe11xL+MwoK7KkXa2nxITXz7
c4acGPHGet8d/5eFp7umNcY9CV6U5yzzNMzHHSlG+1JHAqmdifGyAUy87XaM
E7gQVO5LjFQYz8JUvfF6LQ+C831fU+0OXAXjZPgnc3eCf2QeR6282ASHfrPp
X4YIDO7refNGWFAdfVe2SE0CgwtHtYv+rIYm62KznSyBm7X9vgnbFgQ1tRX+
/p1CceXq9LvsGkxL3RDI5xJ0DkeeDWZ1Ii+hcYDHpFDGfBc/GF2DWJPrF33V
CeJTXLXidPmwrgvbplggwrVUxtMJNw6ibmzx79ek8C7fZkvgwWyMdDGvzdxN
YLalaPZochvaHOonYwiF7N2b14r2tsJlKld2p6sYqxQs+83TWtGbtjBngRmF
0OPRrvojPLQX/eSy/CIF+yvvtjzSbAR3qa8uP5mAecntW/7HVjhaj1VtzZCg
j2/Anx/Agdjo63Lregq9r9721aSWI0wrbc2eVIJnvC87wno56HggML3ZI8FF
51DOZwEHgx3fFwhy6Vp7cdXoVyFWEy8bb2URnI+lyFqosPA+VfPf0hCCEF6D
V5M1C50680xrfiaom9C49pTNAaOckfbyHI13xkYzG8NGWl8V7n3mFDQr5ZPP
bGND7oXg3qEiCpl6Lb+mMvio+Ri2egOLYFFJiMNkbi0ib6gybxdSeMLO/2Kg
3IhzXeumbtN4q9cdyFVYWwD2+FemrgPBLactiv8eaEdsa8J04qQImq5nrr73
K4SmUd+9KTuCIQ9RCU+1C8IXZip6Wyl4CKJqHNOa0RjIy2ii8RvKTN/rfL4W
cpHa65wWEXxwHJXrPCTEnFS95P5dInQWPxzcUlpK6/hq/yStr/q4kj16z3lY
+OLthqIfBDvY9+RpsWNDd1VofgyFAEx+KTN5gycHGab5R3phpj3mN8yvRZ2n
6/utoQRCK+cPpZc4ENZ+6v/rlRiTxfesTx7mYMn3XTK3nAnWVlY8mDGrHt7+
I3f8L1O4vOhZ1ead7ZBIC6UYbQSrgsvnzXdrx/OknKcYFINzp8P4nzMN+FpT
ZRsiIpC7J6tmbV+JZYUNBwPoeYszft3m96MBNhOndqOdYFnioUc9Ml24zP76
vIvW1+mSnyNKOpvB21jGad5O83dlpkvO9RYMMnQyLz+hsK55Dtu3sxW3duYN
GnuLoaphoZjjVwJ7k6NtL6coXI86pRIobMHqsjLhenkJ4jIVvCqaeShQeBzF
lJEgMCEdzu4cZH6K/iPGhkIno8vq9IyHsGzxTwo9QtCzOG+Foq0AlNj4upo/
hdvHdkYH+ZbBRaPM8PgVAmO/j4odDfGQrWhl/kv7WU4t/dHeZC7Y6hHDS5wI
cgabP1la1eNidbBa0lwKXH3Dokaf11gSc3qwWYvgrNXLlC8DPARsv6IubSPB
IUnoVMHCbDRXFmz+xY1gua1rUbxOK+zmOH4OaZJAXUtg0m34DKo/1hzNSSB4
fWtRZF0bF41xTQGr0sTw0U/2e1xeiR3lD4tKCwlusmI5MpFc2PdaGB3/3ovQ
OboClV4eahnp4Z5HJMiLFwSdSWtErBpf18xNAs+xlYsf6rwG6/5iolRKMJqc
nTTxjYXKwOqcgWGC29P7lIWSJAgTZnKu0/w59YwHSsb5aD0SvCmM0QvmiUyV
84HFEMr+rrSA9p/dG/aRvkvdiEoOXSM+3oPMJud6r3VsWP49bM6aT+Bz9siK
f2Re4azoo0J7JP2+KvNl13QWRkLsN+1xJTi9icwzKWfB7MSK8vguCl43SbpT
4WvUckWqljT+Zsd/XVo8Uo6tfE+nNLrf7EyBkuZfVyClbDvmTvMxX/2UiXRu
Jt7cuBBxcB/BZxuzwZVRXPxRP500pCgBg19/M1yahZ7aCcY3S3ofMIbzinY9
RQ+jqEUmnCCx8OrDT3PbcGHreY1WF3o/WMxV+GiXhxUjGzlOQQSOgeUHSu50
IMJjVnj6XxKcbA7Yuzy7Deda+iKDdClksAz1lTzasQ0pTiZxEkhZD2tY2leB
GTv2KNeUIHY0+Dcv/RLMdqw5rNNPYX9H/YqZc17DaiA6wD6P1vv+knkKwVnI
rVC3lafzRH2tlq+icg3SxKUvGvbTfhMfHRHqszDx8kqXvh6dDz6rjJau4tA5
YfnoGp0PXPfOtaIUHpSMvUQuChKQequTNo58zL+fbabFofPo8OvNKsv+QKLp
fYuE3wk+VvNl+QZcnHocXFrVKkZQdGOW7/tmCA1Oy1G7JDh+k/F38l4+fKaY
GQ+GxBBF31BS/I0LZc2qPn9fEdjXnGwcrVuxqzwyPucunTcmS8wHNDNhMXx4
+9R/fBgpfxqfy8SjPo0qJbqODzulf1k3C4uffXCUPkjgWTQj+LESFzbHEk68
+UWEC6Ph0dJ13fgtW/gkz4Hed+p31wzN42G5tffIXRP6/2nC9WeWdKDSvXFc
tkCMz9vSBj8zquD7U6JxxFsKw3PkVfOseJAKu7f8fTyFFxWHF45Jc3HaaFJQ
Uk73by6dd8uTBfvZwSM63QTv0qLnXbNrgDKrjOutQesvhm8dfoKH0Jkhpt6v
RfDx+6ZtkE77Y2GIec40wYncjbnaA3xkGOnE9MwVQSqhxyIpR4iV/oPcskt9
aFwZM/CI34ANP+RK6h4T5O1RG0vZ+gR9q3wdHC8R/LnMw9czqhXrd3RJ9Oj5
L71lHbFLKcVK9kb5x2sImoRXp22+tkG7QXlvgzuFqZwK2Rkr6LyOv7gzx5ye
r8h0Sf/ufPSFjLDr9xD8Hy+s0fE=
       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns4lVkbxn1IKgyF0ZCcNU41JUnlFiaFZCvFDimUUEaZGTNTQoRyLBWJ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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx4lCCSOkqJEZWysx1a/iU6FSVIpRI9mNrciWBilJC2YwsoVp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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k4VY/XlaR+UiRJSoYoSmkwJVqmSlKJlJQhY0pRxjKLQpIozYMxhCQR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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81Wkbxk/yTou8kWQtyyA1o5QlEVcZRcaQIhRNCQmTZqKxzbFHRSn7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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs8lOkbxqeSEOVQoUUpRYkiQ6S5Jlq0WaesVYmIXzmsU8ihNNvJFpUs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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns4ldkXx1VDaijXRvNjMHMooWmGSoWvoShScptRoeQ2iFMUIppEIUVy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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3lYjN8bxlPKtz190x5FKCUhFF/utNCGSpuEVFooylZpkYQiWoSUdiTa
VNrRtEmlpmaaNq3vO1MSQpIW/d7fX3Od65rrvOd5znPf9+coOZ2xPMHNxcV1
dBEX1/9/xYw2+WouK0B2iKrWrYMkWPtN7Mx3s0BT0dbfd5YN+qJXIUErehF0
ut1Q4cUgBEo81Nz2daBGb4tPyrE+OH5xk1+1oRr3bA29oqpIPDqn3ODzjglr
F+NXgpFDOHWzN2mlewXUlUWusixJnH+s/1HmSzWsLJv7LnaTmNr0s3iiuAJX
nqdke9WQWHxv0LhCqBG3yjyDhDJICLXoixR5l2DGvCXo1BISdK4zqRr9DZDu
NzhvPkVCd7FnqV1QNCJEDQf325PYWNDvX/+agZBGiH2/T/1/1n+9Gus6rl6q
6IlxJmE5aKC/14OJSluj+PfhI2iiFxOJlh2o8K0zur6GQG+YV5tI6Bt8Of3e
8J0GCU5UgXK7Og2XDm7N10smcFD5QkRz/WvYf2jDtX9IuKzsWrzwmgbuzRqm
N2MIOGTqx/6p6oa6WH3aKvtPyN8629Z9oACOr9lMS6q/8js0L9Zu7MKzqKgV
yfQhaGrsCr91lwmD2Aj6wAYC6bHOK1rW9OEvyxh71gzhb9QhlSscBpy3rOX+
emsYg8Fj/StudEN5h6jxzOBnODgxPcJ+1aPgwee474PDsAzaKIapdqzvtA1J
0eGgT19y1VqzRkxUHDQsiyBhtUNiUbxICx7XPF1Y2chG/h7NRb1JeVB7+kA1
5A8BmzzNWw8D2rDOcre9qcUICvd/yis7nYcLphsHuU+TaNgnbBLAw8C6Am5P
ozk25L312o2EW1H9+/jKTJkReMov7YjfWAe9HYNP969jo3hD+zG2RjeMMt9/
+7WShPk2NeXNlxvxWbW/wZ2aL0XBMqUm1EH1XM7cjRY23HmU+n410UA//pK+
+ikJsbCO9cHOneCNTjXxzSIQIk6ecrt+Ek7SIuYix6h6Rh3k//aXgC/+o9HO
nwTMHqy9jIRW1BATr3IXhpAVzTt5e6YWCnsbNnpQ82Pjxxh+N14LXtnHhTQh
Eo5SZ2o9v7RhLDNNL16DjZDlZ/n1vtEg0W/66Oxmar5QU3zvfRZWPJu/dPIC
ia6uuZP/VDTDtMHchRXNhpj1Q//Xhe9hQJuTjBglETgWaftydSMCysdfjn5l
gyE65brlNB1qWs/th+w5kGYVdE6e74TUYKH4wodhhO11DLUu7YGL4Zbr7dT+
c+qj688eqEfU64O+N20JuP2+JCRE70RMz2mNnIlBrJYpvnPkBAutU9mHrHkG
oOdl3LxhPQtHdefy0ic5uDgUcIvu9REij7MKhizZ0PTzLBVsb8F20ZXpD/nZ
6IliW5/YxcD+uNXtF44QYGX4Jcjp3sFYPO/zfgeq3hfl4SUu7WhOuff21EkS
KuPqMmuKmyH5wuIrj98gxPTt6/ML8qDKa5kWeYTS5+N9qaINbdh8INO7IJ3q
Z/w5x2LJbJT9uX6j9wyJ2obvvcU+VZj66zVNkyPg//HAuFpeB7xCDCrLh0ls
t1kalr/QhvI2SyUbPjaqMmRe5Z1+jBJ58dvTXiQ8Dzaz7ocy0H4vdC7IYxQT
Zq/GZl8XwOU6bROTJNG8asL4SHQRwpo3XHaqJ/ExQMvpi3sNuDdk/uebSSLz
v1ekN5iIOpO/Z+dhNrhmjPNLBz3gp+JbVk3NT1y2lfa9gjYsUVWgh4oNw2Dp
zqAP+u2QENcsT1cYhmPmCysb9lNsndirFmBLQrHttpBUcAw6J3/wlNiR+CUi
GdZpXwqDb5LGsZ8JfP1H6nLgmV7E/eCtFQwfRJXsquFrUrUYo5lVTFyjvr9m
fcfft0kwEuPNuXWOROUXVm6rWicm85U23H3UjznSY3gm7SXizr23U5UnYdHE
FXOtnYkxwcMydrsIvBkfdFZpZcFmj01jB3MEylHQNnIvw/QfuQ3aotR+zW3E
WFUN9Kb0UnaDROoW99h51yywWv+tCab8l8/I46T08RKwRC4n8ymxMZ691lON
rxZ0SyfXcSc2hgZvtMsW9KDyJdOlNogDxwaxrPuzfTj/3wPRB7tIhGjZjbot
CUHdoWDuJUdJuC+uGl8I7cXKrV4xOyh9Gi9S0eHWZ+DBXQFrU48hzL1pfmFx
qxcitH6ddx8ISCSlVlT7tiPG61nonBuJkzy064yVNbiz+O7VLRtJ5Jt3j8/l
NuNX1bZMvc8cyDRv8vXt7YCrYqCa/SkCjqLWBru1H0GFe7aQl9KL421bJYZE
DkQu7X8guIfEP27Blxe2tcBQeljW/weBo207fjr69uDf1eZpXYFMiMz8flgQ
Q8PEYt6XVz0J6M7+NwreJHwN8OTXOkyi9M1XPb6oaux0WvNALo/Az8iReZpA
Gz5qc4os9rPhl7Rx0luhBo7rNggEqbIRvr3j+THxFuQXCgiypDkIH0zbZ5/S
hUCDAomEFg5Wi2pPXVz+Fo6fZCSKSQLyixfb/17fDT3HJl2dE5TfxAiM7k7o
QvBjhdbzyqMI+xkVWa/UhltFHiuT91L91j3s/FsmDwmi6K67SsLo6elIVmEl
riReqKp4RcC0pvvmor01CJ67mpTylwRPsvw7V4NOVD3/JSS+hQP1YbXvxhdz
weS5eG6KyrMXzlxLUht6YXaSX6D3B6WnZlmrC+XVMNilmzUry8Z2+eVOTP4u
eI5E7PFgshE9bB3fGMNCWOgQc3lmNwYFt+Wr6Z1Fgn/R5ofU/TtK9C/ZhwTc
sZJlLISSOBulnl96iYGZOBX63RYSo2kJl+6NfkBJYnTPZyofwh1jVdRe9uLR
5M9N0pFjsPtINI2Mt+JBhFarmyRVb0bW83/qb6DLoKW1nto/ekJHtbmiDs/K
2Z5eDBLcE/xim+6yMHNWptv/xRjir3TH8hTXI/BArHe6PhtG2fN+k0fbYKgu
8trhO3W/TlN+h7mqocLlPx9O5Z30tk/iSfep9aEbh/9S88Mn51vu9IQOzSMc
2nTHCMh9yUIf1Kh5k+WynM1kI8nbZNZtGx2VGT+5GKKjkPhGMreZN+Gza6ih
3j4q/129bq5pfAOmUJzznwESiVOlJ/dENoC8tpH25gWB/G/1r+wHmnDkzYHy
f/+w8by6Kpx//iM0lix/WnxzDOXBZ8eVI6rhvMJ0vpLyY/m4UdsbVP6amP9a
F3GbyjvnXJWJGR+k7p/qsnAk8WxkVW3e0jcIzgxhe4mzkTAv3zXxiwEhxbM2
qdQ6yNXe7kogDU8sDPrzognEHRcU+JtVC10XHrl/ytnQNVHP6btYA5Zt7J9c
YWr/gmaPN3cbsOa9WYmdLrX/dQcJE24a2mrFbx+i9Pk4aL9DrHINdJWefZD5
P48dP3P3olQ1zHLrDqfYU342FxWQvuk8Tom43Tahzre4T1ria2E5zGbUd10o
ICFhlKs0+l8zjva+42hT/QqRE1PQ1krGXFi8aPVFElzh/WoBHj5In98Z4Uf5
ceSWojy19C78LgvxOazeB3+XHJvCF+9g1SvyJTySg4/qfV4yf1vh0PxON4/S
D8fkrkCFUg+2H91+WydrANJE77gw8R7KAhxHfxdK/+eikrUeMaBxSv7rqyIq
X/64qM2I3MFo0SJj00PUeQoelkaaXIGHAM/Yaur7d369NUzoYSLpTHQmjz0B
7t1+nZr76Rg+a3xDYMMI1FYWJp9d2YGohpjeAxTPdIVc4k5XZkCcV9xf1noU
jh6rg8YvdGHhyoSD9nuK19a5ZxuxCyDCbW84qEPlazbfZOBkAVyXbarL0iYR
vsdVbkSzAUXF71R8KF7VFOo71C7bBFm7yNUD1H3oaqd9UnctRnD2yqiAagKp
RWt7x9y6oKHP39BaPoiQm6dUJ62TMH3cqrWLyttdOmWu283bMfk4V1FCbAT3
bO4cpD9tx/h/OW7PDw/BW2pqw+7cBhxdy9tmT+W91pJNEkydFgg/ashZuYID
I7U4CR2bDCSvr768guJpc0PhWOHkTjho8cywKX6eyZXXilfuxbLGW1p934bg
4n5o90geCyqTtBI/Kt8MIp1qZ9624M5Az6dJn2G0bP2RrODdDa2CE78KbLtA
DtTsdJeggfFQ1yuW2t/3XOWFdcJFGLewqLwoQCK2/N55hYgeDMoftkmu7oSW
pPFl+TVtSBewPPr9HYGZK/Ua6j978MfMzWnVp2HYqRfnLeNuheRvW82wQQIf
T0QeF07sx4ynTfC+S58gVnDyiFpfE/498yA6vomAmBm/1NOZhzAX/PyrnPL7
1B+zWic42Xiy/+cJVR4Sftn0IX6uLnCX5smVzXOQmjeeELYiB9y+f2SE1lD9
8Fm+eiGjG7a2FbKGOSRCAy2zzZd2oGw2R6l/E4FxbbtlzRk0KO3z5H0xRvFV
QHJUtwoTx9ybU2QaSehpZyb1/2zHmpnY2GsWlJ/tlX4mIp2H9r7T68tjKJ6t
55W7FloJlaXP7vM9I3E/eOKYQE01DislGC8LJ7Gw+u8wPaMdf5I7T/ifIdBV
aCsW5FOI5xrq3A6q1LwonP7TolOPLR93aXeactC4hme7P28Naj9fnbULISDN
CBs40FAJVq74+zBlEmahT7+1aEXj1sLlie+U3845dNLsah7iB/l6wsyJ6o9R
pH9SUBWqWU5jxzgkHq7KV0y/yoShm5y/KXsYIZc85XmjvfGMnaZgR+nHLEQ6
ao9jG0Qbih3+zw/nGwcYT84yELcrY3COdwypxu8T19TehWLmwQdwper3ntWb
3VcNriMG7a5TBIYzcz0jB+oROcq3fQXVbzu7ONLpczXiiPVyGUMkDBwzmzOE
elClxI4vPTuCtvYktSDbVsT7aE11mXCgLD+bMr6kCYMBXQlZkcOQHrB/2fuL
huGjuTqLnxK4H8cXuWD1EZxVfLcGqffnZE39+bnjrVBZYlD5nZp/saZQlW1d
ebC7u8RFluKJ48E9Wm+V6dgUrqhvxRzCxIcqiysCFF/ZveH5PETp0evNgeLr
LExXfEllLR6FW5qe8vTiHojfdRDODWPD8YjhhcsPKpCc/0lX5wrFs04yPnbv
GPimePDFWy42XBNz+0131+MZq+OeoSkbViK5hwc31KLa5Wjtk1ICKvESah92
5MHj6EHVhGgSbSMXNnv96cL53h6zzJBhSGWHC5KTdBj5TBu+tWKjtIbZrcfd
AAX1w3LiO9iYkIZvcxgdghf/Ot2/R/Ec75hhanQ73AMqRzu/DcDu4Zh6ln0Z
Yj+6u3ybJLBHKneLOZOFddNrDdZu+oS59YrqQzWv0birUFqni8BEfnlmxxwT
gc5ci/fNDmN/l36hwz06miq+qOtsGMK0kFWEjG8LyE3PXjS3jMDP/M67fXwl
4JJTlblaTL0fb7g1SsszcPf3pcvNKf2osjsk8INZjhyjBhV+f8oPc4d4uXtL
oL5UXYd2isSjHxrD6WntsBE+b62oQPEWd8oRH4OXWMSv9K1/K8XjrUtSmkwT
cVuBPi5N+V/0kfXe5mQV7shNba+eICBblyeuSL2vTfuM/vCFD8DqZ0eSlkk1
lMvSPtAz2NCLeXTX6SoLf7F7RMR+GA+f18kVSjfj8juPiouXCLh/FTI/8aoY
y2oNuGZek/hP48Or+9erUGT48liFIYF448m08IZWrDWWslvzlQBNs7pb/9Vr
xHYp3lpgUn7y8luDu3wPHPxtd1hXjaCKs95GM54O4YUddnGWBH44bbkpIdWI
MRvCQNiU4oXjH87FC9BgJRl1xoTiPcVZvvjaM8kIUEoSF6D0aWSa2evt9gp7
2ssOJlSRkF5RJmdMpkPEMMKw3JTKM+m2rclhgRAKIwyXH6fWRnmrs8PuYJl/
oJqJB4mqtQL9QnbRkNw2NlRxgkTGuaFDgktakf7o/E7uFA780iKtyeIWTG9s
uOS0ngPNrAWhipoa3BSSvHpxnoS3aGDCRvdepMbcfPLG6ROWX//SkOnfA7ep
ZPcOwVEMpzvzPT/ZCe3J6pYFMzZSF5gvpaj6E0uW/+P8eQiPFUK5nDLfY1uE
kRv/PRKDJXkttpdzoHB4Z8weym8GmYN5kx98YXP1jP0Bql4zrqJS4cR22Lfq
PfLrHUEi4WaxksaAC6Pwxg6Kx+1yDnnVFXUhskaiftSCQHD7X+GNkSy0WPTz
L/3Rj5TLDozrbgxMqYN5U/ETPM09jMxjmdiWd8OqxYEN9+X6hn0Omdjk6/PI
MZCqbzoidte9Uiiz64ISpgkYPFowDBRpQx1MPU9Sehrce0ok5E4G1hi83e5H
5ee0vXXe+i/1yKgVuqezmQ1JXR/32yp0dEuO2CnuZONNlvK7mmNtkJzl+prY
PIQqomjAe0UthB46Ls+uJWB/JOaw3iEmFnMLtKr5EqgQDrUxOVYKzfKpBQeK
txg2vzMTD3Yj7MkhBv9VSt85mh/ef2fC+VH/nrwHbPy3YXVrUkM7NF6fnKBH
fMJpLcsvE/FVEJ13yOabGoaZRIBUwFAdbnT3BD1eTqKYzl9y25aB6zbSQ0uG
xqA9ZvxcObwGBcFVJW8DCJCcHpZsKg0dcSpXi+uoeXP7c9O8sgCTgjUNdCMq
jxaMfi+IspCqYWidmdiF1K4Pr0ev+MF29XKnaeq+krR1dx2cb8QN0YFyj00k
xHixUV/1KebdVQ9+vkTxZJim6sTiLryaP7ZZ5+0QyMK50a1bq6BIEKM5Ymyw
6nzutzs34X4Rf+CWXg4qLUbTKqj3ydOEzdZzygS4eJaaTU2zUDIuKRVQQCA8
7LvCZ5EyJJ5L94yoI1AV7RK/Q+oWhlRmg39R57EcoHW8rmchykihvOFoJ0bU
snOj77fhl6eJW4PmIATd3K1fvq/BVFtTrNy/bCg21ntt3V2O6q0jlfQ2Kt9H
r29eFcSAffE54dUqHKiUbHnAvE3dp0vitiNfORhV1dTvnKqG1o3PGQ+XkWCy
KyX4djTjVOiK3Fn3YSin9v+suNSMxAuBdKNM6v066v5kZU4qGmKMd/+leNnh
nOrja3tpIKRpFoI+JAJPttVGzLfh7FdX7gtvKP2qyb7ylC3D2IXt4VkcAqp+
3mOpckyMmGQ12Suz0biqxvljJg1felLopUsofpIN+552oBk1uY/YZsYE/gfm
Lvvn
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81XkXRpiKKZWtSfYkFUXJlkfCS5/GHkU1yBJ1qRmhdGXL2EmiRC+l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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns8lGkbxyml3ZDaWLsqp0iW0K7ToJ9CvGpRaYxz7Cg6rN6yKCmnpNK2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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVln08lWcYx7GSVVpeFsVKW+UlRqi8jB9SSea1zKKoiKFREeqQRFQqlIrW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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4Fesft2UtRJakTQotlCUhPkKKhCQhpJJECm1uy0VZyy2icqXsSyXJ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVns8lVkbPaKTpLtc+solk+TWZRoUzTrlFErijFSuucsUUWiMiEoYkpIi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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlWs4VekbxpGMSpKkRpIzTZlBmbZUtxCmJDkNsiNyztDBIERyaGiXMsip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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lWkbLsJE0yIpNCUkjOpopGLMJcnIV8qWaBFiUrYsM5aPVEKLr0i2
JMlWsiRKieqM5XAcjqNzcCwtnleKFmUrjO+ZP97f+7t/z/3ez3Vf7/Vc97PK
1dfGXWLWrFlJ9Pn37RPtLMn90gbTu1ZJo70EFv76Z0b+KcbmD9tSlrgR+JRL
Jw06tcPr8YknBtoMXhzJycu2rsdA7Qa9NecI/LIZoWpsD1QvKxgVWjHgGB/g
jg7XwGNVuQ4nnGBIXXzWX64N0s9/uuE3Q3BemGHjmizCikPbZPdaM9Bhm54z
0mkF05f7IPcRwaxnp+68v2+IdD+bEJYzwaLvBoHNUs2Y2mg6Jz+FoEO9poLP
/Rs/vE18cSaYIMbYfP/5E0/goH6zttOHwPWGXJVeZgsyXSXP7nhMEDEtcc1w
oh0dI4fcQ3YxUOasq1kS1oK5j1Xs8usIFv68JGbVTDXOXPs4l3WC4Fl3Ze4y
jW48uPiq+u8uBhkjk5zjk+3YN3rn80kRwVTF2o7K851wq1Mx+qjK4OgHSZPe
fVwYNaat4OYQeJnLLqzJr4D+5P6rJZ4EsVfHDzVN1GBotWKx3hmC3x3eO3q9
a0fk2cp9JhYUT6bsMp/mGsTfnHZRp3yZFfv5rj1eh8yw2c25FwmIr1+V0KwO
rFu+2v+j/Ya/+3A3mdeBkk+CNXG/M7DcOYc9rMYHHiYf76X8abjZlhT9IgTH
flg3aZpAuujgQG5HI5LUba6IMii/lWEzX60CcOenNSkGlN/H+6q1tqTx4fey
SVvmFoHh3rV/2QXVYWnEy+FJive0wqpGm3QxrFbuyPJ3ZTCSMVMeL9eOGFeD
aPd1DEh37lbJcAHKRz63v39N62tNz692Y0Mj8ftJdiCBFavQZLN/B4o0ecZV
hgz0K+SZuN96ofLHQ3flXAYPQ3dWNmYJIWuyvv+YGu2nJcfm/pNOJCv8MOHg
wICXtedKkicPamp5/ym+Q6AV9JoLq3KUWSwKwR8ETW+W++bI8aBJXCodEgkq
tM/tDmUa8Ky1OPL6DQIFB+vZ5nZCmLw75n1mDgOLzTqKYZuaIdGQm+dUQMBa
Kcju+1AOM9ba5O9HCTb/bpr04y+1CN38vMU+iGAiNT/q5dJOyEwvP7z8IIOX
MU2nX3sKkNI2z3oPIahUtbe93tgJo68TMm/3M9hj62l7W6oMFtLJfFuKb49G
dJ1TYwVMTqYnPqB6+PytOmPXeS6WLv7FYWkq3c92THqxVyl8wj+e2+NBcLfx
gp7Mdg4qrQ/oKUYRBAoWsxL2tyJXa+CjbSvlV++0kWPWI1yw6FIQexEsX+Yj
J+a0YuD4261rmwkS+xoc37TyYHdLsrSolGCgtC/H2rIF2TPG0xz6fz2TszsL
mjjg315k/TSOgP/ALI61pBKZLgkW83wp3uzhVDO/W2j+yUM79zCBibIs71rP
JVi9zEz2oXpRO7kgfr9dN9q9139ZKdOPHjf+tgIVIZ6mvrJYMJvBwhrDvlPP
WpH09JAdp4qgV/nMhvkFrai5WRWpRPUxwbqkz8thQySY2iAZQutr3d/SpPQc
C08E9jMBBJMan3wbDdswftYhwLSWwMlkVfAyiU44JylxL1J+vYrDr13e0IVl
RdIz9scYzJISD26uFaKmXzf8j4cEkQ2/ZtznByLLBDqbKN7Io2lVsUtP42bz
+yJzGgvMW3QfNr1Afvli3roWAlNt8wdSRARFE+582UGCzIKqDXvckpHz6/PI
apq/8/Og+O1vFfh+L0r+R8p37webCBfNVuh0PC7/iyHQybiyt/9TB7Y77Gar
7mQQubFXSkk7CIrNkkP/7n94e+H3Qq06VKO+Z5z6ZaapmYp7YiLyHsaMpNL1
/EJnsyyzEJjMTbMzorE4Zdzfm9WM+QpKg+5UH5nOsq6i3XHoqTTT96brhMUa
nd5Zg58/eKukniR4a92vZB8qxrfmkqjVlQz49V4WjocvIzng9aUAmj9iLiGh
n8HDUN+84ReFBMcM9HQsF7fBOXDwGm+I6q261DA2jY2E5m3FptRfduQbL1C8
y0ZlU5uVYhhB0VR+TwTNLw+1/rJJkvKd4njjhGIZNMfvXu+l+l4nnz0gK91A
/W5M40eqpyNmXBeZmWZMmE1zg4uo/56+Uiu9hg81l9p14dnUX4v+curaFIzB
iKB3Wyi+Gn4NGXslQsch8vMcRQbVA13nr/cKoSyUiDlFz+uvgSMcw0e1YOcH
fGs7S5DyX9VE0Z1M/NMliPek+pxz+4DNdHYKjum5bqyg9f709FSLqmfDuXW9
mZD281lZ/cJoLBea3+ZtepNF9afbt7q7sQFMjm7400sEJdc48d676iHSHDtn
nkDQMKU1ovNVjLG9ez1bBQxG4x05hsMirBSlXp5D55so9tvKr/caoNT+Q484
jaB7l3yJ3vUclDZJW05RPJlxRQ/mSt6EzahOTCSN86IbHC5EilDnJrNIxZLy
R+S2arjdA1uv3KOLzlf+rutlfYK72Ddg7e/iSr/33hcW7FcNYmPPlqLzaO/4
QXFFbDfSQoIOqtczCA0NcJ2nJEDVYFvObjHBk7Y3VkaxIrxYgLKL6gyS5D4e
lXDtQbSHccj7GAbpJY+0ojwKIe/r72dP91OQKGg8JMuH8YGJlug8Op+LU5a/
XtwAy+AVdfHRdB5Ksp5JFAgwUFRrqsOmfuCVb21Z2oQb785/LKH5HeZlf05N
V8Cigc+aOE7Plxv3kXF0J/SFpYXuRxgMvR/x152sRS6k56rRev0RL0M9dwpx
dUuU1JflDHq3zpydN9qD7mnF6ogEBlO5SVNjswVIj9q2ZWaMYPUsJkE+oRuN
jqlP7D4xeFWu6bTRqxi6t6bD2BT/UJFO7wpXDuoVWkzbqN7WdUQ938oXY4oV
HzmpxCBCsK368qJa+IWq8GToeYs9VbYjgPpn3njoVUnKV5QBC0847bB18jbO
92CQGbzi1VbVO9B8ar+a50LQdpPRsDUoAcdciq18hN6H0Fa6Rb4SlxPerA/x
JkhujF7geKkDo3NnQppOM2j06pIO6udiheTRuPoy6mfp63nHLPIxFj2SHk7r
/R94RcqD
       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VO8Xx5ElkqyFVkQkQlkSfYiokFYpvnZJJBUpUSoJKaRoISWJkqzZ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81Vkfx5UlJJFwR4sWk6RRIVw0H4ZKuWnRMiGhLDUVRUaPG1kaNJaK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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns81NkfxifNJlbKpS2RZElFZRHa8PjZaVxWudTaoVyqpWxitS6lRFEr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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8VVkcl1RCQw1FJGVpUkM1pGnKNyohDUpS00xSqChk16ZUIjMkZZsM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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHlYTO8bxkekkCRFCy2IkISEpLuihHYh2VKJikqS0irRhva0KSrxbdMi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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81dkfxm0NhivUSIk0tqtmlFIhPJU1S4ykLHET6WedJJTENCX91FhC
y1gmRZGyXluyRK6py3WvXRT3e65pEdFk4qf6feeP8zp/nXM+5/m8n+ez1i/c
NUBCTEwsi17/7jZLw3hbtXjg2NgYme+ncG1DQOsaLQEUNEd7HVREuHO19iuO
PkfGj1oXLncSJLDSzhZXViBCWniNeZJgzObrxIjZEwS/rIzPraXPmza759g/
gkHYh/E/VxNka0jlB18ahCCuf1tyM4Ww82tiw8/0IcJbaWkbQwgxLd5K3rk4
9M5IawazCFy28AOy+55B1SbcxHyawvs061qbl4X4JudMkkEowYi/m8IOlgBd
BYNmifMUIpyXfFvp3IXwmEXTmDgKGxX1rLd4p6Kterpk2wGCMj05YWj0U9Qo
qkX/5wJBlLvx0ge7eTD0VnY5kkPQYHq6ZZfcEJzfJp55PELgM0YuGxr3oDuP
e9MihkBRMZ8d9pKL74bPd+wcoBBSujj0Qr0D7erGFqcjKMyJdUsfNniCsbuc
Q3tGKVixCth39FoRGdg0zZAiyM9X+qzx6Qk6VJq+0X5AYPe7LT9xxXOERR3p
GzMUYXB8okZM+iG4wpHSflrPiYLt9d6pvUh6HVLVL0mBWeHIc+VUoOFAfGy4
FYHYfpVftOzqwLouOcLyJ9Dm8rodArsgkaXXcOgigXc+T2LjGB+Zk3PToWtE
SPotk3LV4IArdZO3KCTgTvhEWs52Y+6KU+bsCwouy9PCpiRvwH12/+s/aP3t
tD5VpRsNY2t2it/iEwplLGvttXNs8KNiq88HETA4e2XrcoZhWnJHOcxvHKo3
tZM6+GzMljqVqJwnqJDcvU13XoBJ3XsOvpYEEUzK0LKBj5xzriVWrgRHWVt0
lZIf4GzTinsFRrT+mz12Xvp1AAsl2/faqY9DeuEtf9S0H++zgwKr3o5jTHy6
IPIVHyb6q04E9BAYGRrwZTy7kb7ki7aJhAi7BJ0TNaajWClZe25rIgUx9oJT
vvEFbJX27wyk/1OSEv72UYMAO5Z5xoVsEeF9YnOr28lS/Lf+0cpn+wlYKUxm
6ooqsBVWNivrE1xbU8yV0RfgNCNzfToIJpt3WVTqduC4pIzVuyEC49Gvq5TM
ShG03GXlR7oftXbW0YeCa5Bya7RiWpfmc0OrXrkUF45NavaccNoPQ5rOK/ZU
wfGKv3l4AH0+j+GVVNSD3o9k2+QyCpqNxofadAbQWmF2Sv6CCKeDCj17UvkQ
lDDP7n1Lgdv2PfutJB9u3eMHZ/6m4BjZPx94iof6mTV1UR0U4oI/7Nex5sPp
+4TW184UCqPSQ04v9MGl4mm83loRGnwCfx2TKcfPZfuUFnYTCEsGbFtjW7DV
fGOlixxBbmhoy/GZATzQt50JvDkOTZb+4bnVjWAzc61UrxHIlFvK7r7eAuHy
yBbpaJo/RfNRnsAHGYot9ia+BLfnJWd3yNfCoeigdLsywRftbevtn3ahJtdS
qc6fguqRGZ9UOS5mY6pf3XAjuFu+LtGyawDx174tVbwixNF1sXOS6m2wYfFM
PzwkcDe0mr+1TID08w4pVeIEXdzY547az6EW5vG1ivMXYtZLxWXWsyF/yqzJ
zIPgcYlgGeP1IPZU2V7zfTAOvQ7R8tiU5zjTteurpd0YOtbGasalNSBV/fgG
c5q/EQ3XH7OOCeDjtVBx14/CxeOqftWpbVC+ISiWLaXQm8HdmyzVBy0N6bHn
GiJMCgyzpQ8+Q7Byo2UD3Q+ZNrKPuteOoTmHWc52As1/8jIMhyshkcxubvo3
nzZqbR7w70QUM+F2uocIZQ3JjhWrnkHW/27VbBjBz5tdijbbNsLr/h3p35Lo
PGXUpZ1SasPtoybrGbS/Ekq2WGrYhcDINmJq2ofmK/5csvIWPq76llGVbAo7
2MfzymcL0RZUmFkcSEA+ZCTbnBiARapSX8r7cQwO3xMsOD/FXjMn8aFZCmtv
jkzNXWnDHK9oOKKOws8K+oPV+Y/AXJOYZM8gaG7quepN1xf92eQdk/aDW9ex
k/3cXhTHjyRWaAuh6la2ziugH/IxqW6uOSL4Lz9Rv7pdgOmAoPiAN0Jobsqy
7ZiqgOtryRmVSIIYV3ul6vtNsCgrmmVm0nnGTeoy/7YdnldMhiI/UDjkeVem
XG0AmT/kto/S98ekDPveMm2BEUNR7lECPU+8H+V+uXAdU2VRvxCaL0eOmPrA
hxaUzw+mf7QmWB3K9HSxeIow68T7B5aIkCDOulQwkYo441NpItrvIULTFU7H
S+HjcfEvg3i6nsM5tVZ5Lch/9emz9TmCC4+Zvo7Dz3Bqq9ZUZxad1y6cQKVV
bbi8ODWRx6P7Y9hucNGjFubfpSvk0fWUdF+f+zLdC4et0zd6LSlkiEeUGTcJ
EMAgFsFGIvyTJaja84mDJSqOOy1KKKTO1pzxelOE5Xru+36h34vZrVrAGuoB
9TAt4YaFEMMjsxraNsPwcz7B0rEcw5FvUqtDT/AQd+kLy/V/BAsvJXLyf6+B
stFZt+20X/4oHnRvisqAnUVC1j+eBAcSqxcj6vmIGn0rkR4rxOSMnUCrpRIB
97otO+k8WhqNbuedo7j902EdNQbNr2ONvMuvJdi5+osa052gV01KfHsRBz5w
uvx5keYp55m93Mf7+M59U8CGYIJ1nX4Lt0TV+L5wpvH+AgVvMIIdgprxt4L6
E8G//XXQud2oVw8c0c96M0gh6dzdEC/OEGQbD3gpSE2gaDUv/LT8ELrqlH9n
H6Uw5nNfbwX7IR5cNtKeNyHQaevb/TpoGLrbr4rdMBqHUnZbpYdbK2QMDtoN
mhIwN5cxFN3+BHvfDxmtLQSJm/Z3y9cKIKEQ8GduO4Fgj/cbrgQfas7zO20M
CQq3GTT2n+zBTU7lSIa7EJ82NyvPbeIjvX3lYGwThcFJk8rsfd2ofTfyfB2d
n2IqcgbhslmYPG88k0HPzyel7McBchyUfdiUnidL8/ZqKPfY2V5o/JV2LPK6
ELr/M6621e3HDmMp/t8vRAgSn/FNsB7AJx29d8yzFIoXfzodt4OLF3rRpf20
HrdrfK90DXfgMTt07uRVCv8H8nmtZw==
       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lekbxsmSZmwzFbJEC4oQSinjsqQxKOUnhGQXSUTaiKQMMxXZWuxr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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs8ldkax9XkkkNhqChynalESrQ1mp9OTaWppoSKsHPJVsQuRXK/5Dq6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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3cglf8fxSkRCRGJaMlI37JChaNSSrJSShpWKZGREF8jZJSdyP4WSZQ9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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk01dsfNT1KheKZUoZ6pnQJS/GjnfIkQr2ISCSSpyIPCb1KwyPPD3V5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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk4lekbx0UJMVkqSrIkFUZGyVJ8LYkmGZrG2CKiOUrily1bo4xs2YqR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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekb1lgm67QoEiozVJYsMwzRuSV+RDUlEaNx7GPITgtRp0ERNYmp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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VO8bxpFsKUuSUCHao0VS0Y1QqZCyJWm1hRBZErIlqZQ1LShRkpTI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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41NsflihXdP2KQhSFRElFJHnRggopV7kpKkRXRdxItuS2Kku2uHVl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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk8lWkbRmkamUNCpZjCHByyZPlsuWRIY6IoJWQLnyFLhQpTSKXNEsl6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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns0Vdkfvz8TU24ZJKSbaJRHxjAoCh81kvGKQpKZMNVkyiMqTBRKI48e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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8lP/fxUWKFkXWomzZkkopSh1ZolKWSmVLIeSfhNBUUlkqREWLKHtF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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk4lWkfx08SGipb2sgSkTC20YZvvA0Nb42EJBklOqLIkkMISSo1la2G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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4lWkfx2VM9ZLIUi4kjWTJlEYk5CtpKFlKGTRRREK2StIkpCYilIQo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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4lGkbp1S0Q2zWYduK6OAsyqpVv5IkpySUGjnEkJzZVEbNVois7PKJ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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8VW0Xxs0VCpEQQsYSQinSJWQoZSpJMquUQipUnigilSTJlKeMiYiI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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVns41eka3SMmOWhrkBokTCRTSkUOLRq3KDXZ2y3HSG45hSTjFqaGqWFm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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns0lekXVjIphAnTj2ai0JURh2SqBxOTUEqk0Kgkl8atQShk5FIxOlLI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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekbRhJZKtOmImOpmKgsZWbUrYVp0ahGWftZSpTsZafjZMZS0VCW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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VP8XpiRRqCRpISKUpRJaeKWSIltSJBRDEZIiEqKEfEuKRGRXIZTs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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVns4lGkbn/EJodJ+SCWfZFui2JQO2F8rbQexIaM2ySKUQwyWtKJILEWt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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs81GkbxlMqMVEOpehIhLbYFDsxl+TdWsfWSpZ9y1qnVFaicogIYZ0r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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lmkf5Z0aSzSmfBGSCembjFxeW006lmQ3MjKqyfJSZO1DoZBQyU5i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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k4VV0bljcyFRpUSiEqQ5IpKm7J3EBSKZJokGSqzCENKpGQKAmZhygy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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8Vekfx22hsaYhYyjTKNIqW6Q+CmmVpWwzKkZZEzF+EbKkRKGxhDCJ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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lekbxk/2aGJUfpImycGESJNMGZdihIyQOdmbQk4qRIlGWYahQ2Ub
I5WQSom0WNM41pFlzjk4tnCW96UhjWSyReb9/fF8nn+e5/ncz31d3+vefCzI
2U+CRqNlUuv/e9ZTdo/4ei+CIwtV9hFinJq8N3J1dSdYNtcMGzeJQWN4099J
nkfPB09J1hESEXCQZsTw0dejzOXGisHatFf4UY6HQxcDT0qEieFatmX+pX8b
Egd6GlfKknA8cWxT+IYaqPmEqbC2kHBRl5+OovfjSAY3guMphr+EompYAwfN
ScGLBXcI2HjZ5I3UdaHevSxRJl0MH11PI9UoLqznS5oXg0kEj3XRqi2f4Glv
zpi8AYnMw8rPwk7WQzKBbsczJaEbM/u46bt63KNfeqB5kMAjrTVnYxxaERc3
GpDdRcLosuH5lIpOBO6LDRmVFaNlTXLXSMMLtKQK/3WfJHCjfsLycncXQhrG
SVY1gZTIvIdZRxph/dbLUcAg4OS9o7598jHMFlwFpsdJyJ7eUL3hOz5YSoSv
OJIAg/b8k/gfPgbkvd8xl0SI5DvXTWZUwmvX8gYtbxK+2xbkFpxfY0XyoEpE
lAAy3956X2zTi5XVz+a0lAlIXNBNzHbkYuxmEj/cmIDF3IoeDbVuGPMTo++d
F2Mut2jHOnQit3W+dbCHOh9qVsB81YcLtRXVxpUjCMvkSs1crsPW+D0KAyME
1FXwOj6ABzdtv/aHHDEYuXsfLkdzIU7RU8EKEgMNbXKqn3sQWxFXulJbDI1i
WqmSYTPCqtzi3ZkkpDa7njnJ/BPBtj8/kc4iED3YWnPX9wrMDazfs91IyD8u
l975Qwf8+UqbnaRI/LS0v0LVtxraxcUJSutI9MnyYxmUH7i/hgujKgiYznmR
5lN5cIhVGhk6TPnDblPSDrkumHcMpswpEXhIK6Hp+PaA0WfD2k35g3ZYQeB2
jofTBroTP3YQsNecd3l9rA7sy+oHpyxJ0NZ4XFlYzsSik/ExaQ8S7ede7rIZ
7YR2euxO7TfU/eVPd2XMmDgTb/yOT/U/npmlckvIgdG0jm3BMIHSL3jZHq8y
kZi2yGp3IFF4IudqilUJTgUO39/mTIIbs85RP5uNUc2kuY+hJLw5yoqkFxcD
XbkHEp6I0Fit19I32gKlvJWTP/xJYNSZ4JYvdqJjePzeanMxBCeL23xnejHZ
L6mQQPWv70Xzoa+aeDBPa9q+g6ong94UEE/pZXzWhbVlgYDWcYWQ5rBBLIzc
+CYyRQijtdPkjo1VsNJmvmBvJdHazYk6z+TC5LIlM2AvpUfLh6+sztbDOEHg
tOsWgbXXUkPsGDz40jSmUUtAfsScrkbxo1Ly5C+nCwRcF1ysTGYyMHfaZ18a
1f831x60H93bh40Zs/66hBBxyY1TSk/4uL4+h2/0NwGzrz94z97lIuayW0nT
dxR/14z5GvNleCEsPme6k4RQSc3IWbERxavrc09Q/FUvqodWa/KRlOJbE2gj
grasidiXzkVsR5vB3lkRYr/JX9tA1Z+X0evzmw6BOYu6poJnFRgv+dZbhvJT
odpG496f2nGJPUmnfUFgMOz4lsM0HrTCzqy/ny9GWN2DZ2M7uHAI+keCTvlf
d5Qvbh+sRGjhxvFZdRKJDP3BB7JFYF+R6F3vR+K4WZ6S+RIH9LStk20WYrDl
QlTO2FYi52FRaR1Vb6Yu2/BA+TAU6a5XA2tECN6uZzhh8BckahzdJrQIsH1v
GnA1bsP154Jj23xJ6Hfe9tfKakW9h9siK5GAgvmyqd7ZHljlPHF1+YNE999s
3qu6ZojSv24+q0xC4+iCSdf7ZlQKQ3tfUzxavAq9bxkUgZD6D5yLVJ5Weujv
nwjnQqaH5lDNFsFnq1BUmcHH/KHfmmzmxRR3MJVUL0Bahc6oP/Wf9Z+v/07X
eo0+e823vySQGN90P7j/YB1299KXvjCheBqpPdDYVIaJ6TqnoS9JbMs7dri0
tx9JU7tPHJETIldqXbpnXh72T6YqZziRWPTayrz9z2vsVi3xavssRMBzLZ37
O9uwWSdbaXicQPClVZ6CTDZiyNFLQRwCz/dOaC6X1qI+OnTnrCYJHT2167bR
fMhO/3DKb0wE0id1IipzAMqCKtVVQQJoeLbxtjPKcCny3vuNqiTCd02dsB/j
wkzmYFXIKTHOVHat9L4+CH/7BpZmqgga1VOSYapZaM4PrGhwJREjfSh+OX8A
dyxVTt1gCPEo2I9bM1uJgMgctT8ukLgVr777jXEf3uo8b7h2l0AgTBWsa7sp
vqb8tUQi6KdL/241xIbNmSPjqtQ8CppPepriLEDWms32RXYinLupeOfivm5c
J/Wz4uQItExc8X7HoPIn5Fn0rkwBpFLTFIUmQ2Da3u54e20EpQ3pb2I8KxBb
dXi8MYryg/Wn4TZRG4Y5tVeKZih97SXKW7+JgMbQsKEmxffiyJf74pllMDDV
m1lL6V1o+bT8ANmFmbjI41YeIiRv+DWO979+9Cv42JSWC3H16/d2EhKduNdZ
a/19EYFmkfsuncEepJUNt743EcNCSrKcc6MEjxo+GtJPk9guruJEzD2FvMqD
CQ71vuPFTCVHhQ7EmdmtsFkSQ/jQBQ+2pEN1AKLTR0loqZsMTbVyYJK6R3H6
FxJhe4Y+bQyoxMeWSz9ecSfBzM9InBgphO6mQwNXGSQKDJJvNtp24SjrD6+8
LhFCeL/u+b6zG6aOdIYENa80pMWCTOUSCFfZWvpbkGDNTH5m3aLOJy5ZasqT
eL4vW9fKnQcD97gm/8ck/BSCfu7WeYWq+KiDbyj/pBh5SR3Jb0Bq4tWmz5R+
7WMnw+0Dm/By1SqVzEdiBCy460wZ9uNAlcewnrEIg9KZkywPHmrs5nUS1xGg
WZODLafcsedD8h1N6v8h3BCpBHM+GCdMQjxjRFR+uzWRSi+Q0lQ0tNKKRFzM
t82EWR/2t25dkR9N5evpJE+ZsXzYx/32UtKFxOfCpwR7ZBChRLZBw79DyO02
aLDRb4Tzj8Oe59wofX/3t0sVNMPBvdUiJ4LK63ZnYWHlAKyiV1t9rBqGVmFN
X93SDXT4XQhPDiDxH8ROt+I=
       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4ldsbPY0UdUlR3J+Q2zxwy9RgqUyVikualFmHaEDCyXjdQiSSo+hG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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk4VO0fxmUpSVpJkiQJr6wlpbqFhFa9smQrbZJsUZZkl6SorJUSQiok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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41ekbxhGZJiZxoWxtmpAp2WO41ZC10KikkiJUkiUNpoVCG2kiS4gG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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk8lfkXx40YstVPixgjIqIsTQoTPo0ka8meSsithBgjUTchRck0hixl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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8VWkfR9qzV4hQKCXRtNgaXxXVpJQZ1VQTJVtRpLJGlCVCIkuMIVne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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k8VG8bRopWoiT0t6dIJKSFSyVLhPaoLCnKVkqWaCEtpCJLioSiUUJI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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81dkbxy0tarSZSTF+0oyQijRJ+uFDGVosl2wZSxlutlAMohGhLI0t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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs8lOkbxiW7iCQ0pFml2EypUDJUrqiYnIqUQ1qnRqKPdFDRwVS7sULK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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4lGkbV1oUq9E6RVm1KtvJMau0/WwOlVSUnGuQdehDvrKZxm5o02VV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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k8lG0XpqJSCqkkRWRrkQpJuChbqUgKhextRJKlJNkqSZYWSpIkZKdk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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs01Vkfxg+hYlBuU25hXI5YJZWRNA9K46W8iKIhUiTVITJpUokkl1Ah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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk41ekbxs9EJpUspcTJMmXfI1M0vxuZQiQ72c4YhiyFVEQlKZGlXR1N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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekbPpTGHl0mS2SZQqWYUlTq1qqFxq9pI2UJ0UK2GMooEiKSPak0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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VG8bxu1FylIkbUqkEhItli6VLGkVpcVOJEoqqZCUKVGEbMmWbD/J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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk81dkfxvVDpZH8JO7NWJqyZAxGi608NSGTspRukq7KvmQJZU8yQ1Iq
omQtDFlj2mS5lsTY7uW6XNRc9/u1hGRpUal+398f53Ve53XO65zn8zyf99lw
yu+g639ERERSqfH/eVX/4euL5zqgllhnd6aVgGSh5BPX4Fx8d7cmBCdJTNqH
RGyz5EPaROfa4B4CCX+3ZZzXY2PdWoVe7zECW1+nNpV+7sGHprQiidUkfDer
y5w25kGlROdtfRyBRaa5eN4/L6E348hfZA1jW+LGAKHdc0ywZQ8wOgjkVO+Z
SV3ehzrB55yDBIGlzF+HDT5wkbnt3Cu1fiGanQ9m2je3wSxTvr+VTSLjK2Po
YQMXs8UH+y9fJtAskpscM8OFlcKVim/rRjFVnCIYq+XBn91g5/ZfEsrfD8dP
OQ9iIWk2edztX2hyNfa7GXPxV6/lpQ/mYxhO4KqZXuxFl5kgJlBBiHd7Cic+
mHdi8YlIjngDgSi+14p1t4ewimP8Y4rDGFhGkzTx1hfwGNl9Iy+OxLXIXFap
Twl887x3OFqTqFis6/HwaceE6ecwniUJti67Kc/pL2ypXPOLLZOE1u5YGVpU
L9jmn7543RnFZNze9k5K76+3Konl+wmwd2kUrTAshy69vMqP8t9iTLJx4dMj
tKLymPNREkddY8SuDvdB/l/N64YLIxjI+BqopcrFvcnjS4O1QkyIKRcgsgUp
x3pnVywj0Sp4sX/a7x8E5mvX8g1GERRRM3LZoAIpNtruHFcSrMGaYeF/HuO1
w7ntw14k/B+IeihJXMGh1n0Roo4kNnmd9E7dzMG0f8+rKwmjYE9XmZm5FIF+
VlZfX4vEDvr4UeaPg6AXV8gYUOftzuxd4GizILN+U+fTdhLcXHXszmqD1A+6
tO0Myp/mW3HsWD68rGVPZjwkwMxwOmV1iY38Ix0tngMkdB+LpKYF1UChN/Zi
fAiJPAbj9+6Mfnx6yKlvYVFrnwO7aMcbUbCTwRxJI6F9UbEsUcBHC90HfFGq
3rPtwwEpvUg5ZKzW3UbCSnN2nPBvR3OW+v2gagJuqpaGNh8bMDFnYDoiQ2LD
pkxpJ4KHTZ56O+mTQuTs42Q6qFfD98yQ7fUMqr7VdcmMiW6YRJtyRGwof15K
+N8J6UBOp0tLUwqJJ5lxSn1lHdAob7NZnCZhc/963pzSU2z+OM+MofJKrLIJ
iEpvwDdaaExxMwkJKc/rd0rbUbRizZw6xYfj7cI9ZlU9kP1y1ClcSJ2/FM3L
j30Ei5y1YVWHScR8uhBy5iYPb3Z5iiodIuHRJ/fLTweGoJifV9utQvlrJZNW
sMQBb3RCjcEfwaSbhodgWQeuyb2rNRwn4OI4lWXxpRgzrhXyuqdJqJ5/K64c
3gGn9x7uLnVChM2beW++2ISXJlLdC+EEZIXHAqqi+zErl/6u/MQoTkzu6SrT
uIsnjqUvV1H5xo2trojy4UI+hyFjkUTlEfQuix7yAjcWFzmuYSSkz0/dS9/a
ANOPL7tNz5GIte4v2ebJg5OlabNRDpV/wYb8M2r1UL/UuXDxZxL3+xuzfbw5
yDZweMLcQr3XUYNw+t/Q7DgnKaNKIn5l/IVMZhekI+7ImUSTuHE7RSqKzkIG
3W5s2SsCJob6G+MseBC3dOM1TI9A5akxrz6Zj1VDtlc15EnsOn1Z4BeVhP2B
SeJhFH/pz2Lv2OxloXvB4YX9T5TeN4zUPzZVIGT7DU2aO7Wv//X7xdt8DNu6
f/BcKYCgJDeuvJiFOj17dksCiXq9WE+LeR5YK470Z9UTyLP4Jn0mqR/qBtvX
088LEZHoQps5yIO36oxy+W8UD85VN8eFLLh+rJV8vJeEY2Kv1/KZXqzlB4du
FSUQzWm8ZaCVitTL9lbGx0n42CcO75ZvRteBd1fm+CQWeLvqc8v4KHMxbtD0
HIFUqbnE8X2DWL7NmKniTuCuaOibZ7a9uKSlHfggm4S3uR+jqWoIZ8V25Avi
R9DiK3p3ismD0mqRAD1lEouzqukrdGuRJ3tgnGVP4rfbKheOuQ7BVqBs/XlO
gIlqx50Ky6owIH4vXZvqXyP7qZ1fHlD/8fyWkAx/AsKNapGcmUZYjBeKrTpA
9dNQ5JTrdg6eMCPtS9QpPSleCi4RHGhfO5n7/ncSP778uSlnngtVt0hDxiAB
rbWFwRb3e7DGdkOw/HsCM3O+2x895eHpJL28+KgQLJf+jvdeD1BpocKvjydx
RyKqX1GNC4eV04fn3wgRXfJiQqeoBgnZurm0rSREbq55vvjOGeuzFePpTiSi
uXOfW9sisMNB2v49lXeQd5r0qa8DOORW7VGTPYrWded+yPR5hC5rTV9pHYrX
pyab1Oq6kWga+Fq7lOJZNZh+weUZXlls9dKpI1HjHJvyUKkPRaG5t5Qo3ltf
cZaMfLn4zXUffXMfgavChYXCj21o9HncGsYm0Opww6tj9XOc/CctoNKcxBHp
dZIzYRyo9babmLkSiD32zbpa2IfjXae5/kmjSHR297Qr6EH4/bbINbRRCMSC
c9itLCi2nHhziarHp3xAqB/OReUJxUTrXBKCP/Sf69FK8OFwcoGWJ8WDiJmr
1Sk+9o3WhJ2VJ7DudXbWRpKN239+nj9eLcTK+75J9MouFOCtSPZ+yp8w67m4
gFI0fzF/yKLulzwVm5HGHEBwJ+FsYzyGGprfwLRaOxJ+0FeUGiSRpSL3zec6
B+WBFe9vhoxCfG1NZ2XwALp1Dm6WoPph6ZFIMjwoHvVUeTZLBE74iv3aUsKC
PKun1k2R4qtDdYLbVIp9v1++GhNKorCFvcqQ9QBSfkb3VI6QmNV7XKbRmovO
kNUalnYkys5rFk0RbFiJhNJmthDgqu2mWRp2Ya5Qb83JGSHsTOOYZVuqkLD8
7gkfKt9Ht9yYUcv6oVcqrjJC/S+VClVveJ1tCFhiCG6FEggZE0qttOMi3Wvj
1Z4sIXRlnzmnB1VjJmJKkWNKoqHluVxuUB3E5qKt5KRJyPtqVLus58LorZ9z
ZocQjc6TCj9Vc2AlvrzLOZzS++d5Lx3ZK2CmtmikOZAQ+3faXSNhCCW9yfml
mZS/Q1+/Sw4nYKeykcIUpe9/LN68fw==
       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns8VOkfx62Eipp6WZcoly6bGmKTyuKji01SqNC6hErRSsomEevShbXu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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lfkex4/INdFQGZqKNpdJsqQaxHyoSMM9GdMioewyFcKZaCE3kcgy
omlsla1B1rKksiedYznncOw1/B5No5IlS7b7u388r+eP5/f8vtvn8/5udPKy
dl3CYrES6PP/t9LWotSJMAGS3noMfD9HkJQkuHvKqgNua5ztsZ7Bd49P8Dyd
uLj24Ya5UhbBqYsz28wqOxE66FZ50YF+v1E/tdm9FHPvOw/5eBAYz47uV5YJ
Q2y/w+TPJwiUZUuS7rXyoV249MfbAwRyo83Zjs0NUA+oNH35G4HQrm9G/UUN
wtLf7Ba/TKDXqVm5lunDpGumamQOg3DZp2zW6T5cHdhSpXSPgdWmK2WeQxUI
29sqdesswb7+gS9PirsgESds677DQM/SIEviSy2cYyv264YSjGwsqK3lt0Lt
9Nj2XRUEMktl+XpX+ViiJ1yawiMowMOFhOkiVPrGsZzdCMLDTI9uS6zBHebi
P5I0nw1sp0IfJwFG3OZbbN8Q3D/8xXpcsgn7bikzVqkE01oimwA5IQ5Wrw3W
HaPn2/U+25k0YrS4kmuaSOBQGHHZfqoRKkJpfbsIgpINeQohIiHM/V9ulV/K
4M3xIwHLZ5qwENnZcv0OQdWMlDhX7zlCLpgVLnoRhLgZDVSu5GJHpkOKbhyB
wcJr6VVyXAQa8e6x6Tx+So22/SlCgDX63co3/iI4f72z2ItbipsuMTXKvxBc
ezGazPbogo09RysjloFivcf5X38UIb57tyL7M60//ugcM/YEUk/XBT+k8VRT
Of/aqtCGsTtW3wqSCVp/EXgr5DVA+FTWUBBO8EU96vSwbA28LLy2Hj9PYHio
6I/ikC6UaZjs3bGJQei5glUuGVwsb6m3nkgniA0vNwi704UC2Yk9SvcZsO4r
ZyhOeaAxI0FCl+ojOGl7kaRkHvwsJP3hRBCpaZEb31WNVZzvxb+7QPUYH9Xb
e7QLz1brP7C1ZNDbd8td7SwXDfy33Je5BGnPhzt4vFvoLeplZ9D7vI0ODQbF
V+Kxfcu6r2k96fmHL7GN21Dje8FjjPbHv634dQBHhE81TZyxXxhostKnrui3
IjfE4ej6GILvPpZcUlMvw2+lJdY7PQkmbT2W5deLoFKq+7OnOYOJSFZPc2IX
zgw9Cq45w+CkV7m++oPH+D0nyt7wFNV36pnZab1MTGw9k6zkSOsz0G08ycvD
iWwZzVPOBMS2KXFNkhCGqy8Qz2mCTdrrgkRX23A86axIq5HgapDMXHVWD6Ib
/26SC6P+2oxalV4RlpGa9jlxBuq+zeVX2O14V/CwevVaqp8NPJem6mxwe7pb
6mk8T40rV5Kmq2DZk2IY40sw5qnB0v9Qi1WSFWLJlwh8dAw8s+ra8PtA34Hr
hParT9VuJycW71es875M++dxVNv1q031kFSekgwJJmD53OwaGclCuDsveoje
f9urLj/UUAApjbyeV/0E2ZJ556TTiiE1Kjla7ULrO/Ls9b7YJmQbp7kF3iNo
ckjG1BIhPhxaNMql8Qq2yckmP89H7uBgUCjth9bAdpsJQSlSiardPOWHn1yG
2wFFPiRMTQ5YlBNE2MZ+5dDVimzxASmFR3Ser0yO7T9Sj/0VOiLnMII3Kuyy
fwJKwV7b7BRC+5+wXqL9mrAOy7jGcptpvYcKFULk5bvx6wEL6RrKKyuDM9NR
vE70f8t6JLOCQaVJpoeKoA3yVvPufpRPVsPHbz8dzIH54uCsDtVjP9848/ZQ
Laz7/WI0rhOopbANHVz5MMk4Mj7bQ6AkNr4lUY2Pz0+1S23+JLBsd1y7TEKA
hCTDcEda7762jYrJso1Q2r4tYj6K8m0wfLD4Lz6ytf5TGCMk0P4U2ePySAg1
+T0rLN5RvXxwMv7xYC6kfa37/6LxX8d88mhPr4NqR1xuIYdg3MXZ4ZhHO1L8
690f7GBgfnzXcj7nBcz1vPJ9r9L+Lvmze1o+GyoZLF1lOq/Tez+63XVsx+6i
JU6lHwkGZdXE2sDHmtqc6FzKn8ZXPMkDFVUo0ql19qN+9nPlebf+8wpOcTcz
3an/yY2vHYd92+FiuVmpUZ2Bt77syuHAajRE1MmepOf3RB7bX8ESwK0loaqj
m/JHqfTzpnYhlq0MypuXYZAraLhtkNeOu3E7x2bHqV+PLBx7+HUiNHod20qo
3irVHEtM4+swV6NTvhBIeXPKPnWsIxSKohGxg/R70pD0liH7erCMotl+lAfh
K8pTswpbEHk/V8mS+t+m0YA3bVqIeSXVOh2qP6m/w5nAhOdIDiocGKL7waVA
PyBUnNb7+4qKghaaX2yp9MLdYvSPaP79qyvVs222faxKN2STtnR/CmQgxRwd
N7IUYk4jS5iowGB1iEjsSLoI06PattE7GQh71rVeiq7BvuRlz9T8CWYci2Z2
motwWO8yk+/JoJUvZ2ZX1YqaNYtaOtQfJWE26e5+PfiYObumm81gR9Thog9l
r2B18La3XyxBmd7bYwE+AijOHBSTp/tjinNpMZ7yxqy2Q0phNYNpN/5XW152
gp0Tf/f8AoF6YMO1weUiFF0tfbBXgoHZN7Vu58RbcN1eTqhH903wn3ZybZwM
aFccdPKi8z9b5qWdKt+B9zrXXVftYlBR0L7+wXwV4k+e255G9RSibGQS1VIH
iZ1i88VXaL/VWpab9dzHH2lPPs6eJLiodOvDii8N8N3SZJBFeRAjsr1r+eQl
LEaUfQn1g1CiWf+hZjdCvyndHA3Ko9f6bvbyqbjzQLtJlf6ftluv4rFxGao3
ZPs+ozytepfLdVJ8huATxi/+Tfl80lBGan9JLXbfq6yOp/v2tMRkyiS7ExP+
uzSNrBnsYjdpFbsKECjTc/lCG9XbSF/DDxurMMlJvzdJ+RY3s1iZmVIP+edm
podp/h1pzZyigB7wtOVMVnozKBmq7mQtfY7hOfEDE/T8D/o/r5v7XojTQkNO
1yLB2y9vNqrcEmDaZs94Pp1XzHpu4Ex5GQqb+3MSKE98hpU4PvkCyLzvDZp+
TfNv5F4qz+bhXG3ixH/pfouxN9zlKJ2Dd/6byUrq149pZK1rRCdMpk9sOivN
4H+GgMwT
       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3cgVQ0bR3rTJJWRlFHeiJKIJD+VMlIRskd2spJKimwio0JLIiorWUVG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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41Vsbla5Kuq4MxVcfB6UydTSQ0Lq6kjRIZShjZkVKknR0JVNIGcul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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk81Okfl1BshEIiV6ImlQ5XS2/kSpTYcqyWIkabzNboUqGlVFasW2R+
2loZRdKE3De5mXENzcz3K5pKRWtj2/p994/n9fzzvD6vz+t9PrpHw9yPSUpI
SKRR57+7+paZ9qPV/ZheMOUGSonQafOg/G+bYXR9KgxgHybgpqCybN3sIJZm
Oxk4rhehlql8RXj4GbQODbL0jpIoDU1+HdjehNQRQrqQIOAkcFXw2TCEVSv/
eOY6JoRA3bJM4a97WDyiaRvhSsLurFqz6ecyLLey/33uDAnrfOe8hjcJ6Oie
YVn7krgjuyjYwHgMi79bvzbfeRTxbLEs9wUf9KGzelqdfEgcvGoe9TAHX6+3
37TwISHgHnyyyzoDP8inRaf5kaDtmnNUchnAi6+irW8PiLBsalEYc7gLZd2+
7Tbfi0DPVWvzPfoUJ/UbH2hKk3APDikmRkeQYqtiSPcUge9ibK1o2gq7tlSH
jZkEEn/afOjNCx7kvEIKktVEKFExiFW6zMPxKl/2qIcIPQKRd6b+EK6u2GN6
8L4AB/Rb48vEPByLS011ZRGIm4lr/1m2Axo7n5gWMwkwVzoVM/trEV48bf3p
K4EP0n+mVkQPY/pot5/FcgI6u4+OFqhl41iIj2QnhUcq7czGJ4OD6P41fIr1
rwjW9W9Pnj3SgFnm4/vqdAI8szvTLj82wvaC/KKKz9S+O3lHnGPbUPX0vu6r
VAJLIvrtK417QW9qcC6KJ7HUd6rd8+koCmqaDisFvUTcnzFqdq+LUTQTtXVy
O4nElQOVz3glyPpwq9xoH4nifwxQdq8Ui/9lJF4zJlFrsUXN3ioLUuGrK9//
h3/h3Folfxak3Wu2HDpMosJhKatVmw/a2spWVVkhGO8jB41uFEB2xbcQLYr/
OO3zX3V/GkSa+lUlrjcJKW/xL1rpdXh1OsvOy4FEerXqEdzpg+j2oAfEBM7W
SWos1DQhu3DJDg0LEnNNl/KyrvRg213DME46AVV2Uj57gdJniYTgpZ4It5J+
ic1s4IFZs3B92E2E8Xb3PYxvz9H1MvoCg0mi8Xryo8isJnwpDTXbdpdAU9Xr
hmUJvdg8H/hzDIXXZLWubkLQCOJoW0ZORFD4BQStUPPnoqhtJ29xEQm3zsyQ
iJdcvL1W15MaI0BHhQ93+1o+5kv4T5aOCWCsaf/RwaEIP7aukW+kkbiluT12
4XQ3BPEPHhebk8hLfKtFmnNRl77Oa38SgeYSP8XrnjwwAl207CpEcDYztUrX
GUOlecyjNKMJ8Oty9xh79GKq9Pu9iXNCLFXgBGZaVGPyiei5Qj+BbOt0a8P9
deD4b9MnvyeRsdow+URmB7ZpCJ1bjhOQCk2onkznQP3mRBfrJImnUgvV9NJO
XOI/l7EyI/F566mL5rqloMWaxU9vInH/Rtgn7wt8nMowPsE4ToIVaFlT/54L
0W6jStcgEThuan0V/SPQ3+Di+psWpafMQf1epRFMbrD5lEUTQO6i7uDtY/1o
7DBRO0EScGnN5XjocNG2vHKf6j0h9m96GrbuXx706P3hfUNCsB4Gl9PWjMB8
58+nNpwRwL8+1JzFK8WL0/leOxgkLs0rxaon1KNDrBQbqkhiYOxqQciOGshX
rXv1fp6aP3GacSevFybNbM7wbRJRDYOdauIQpFR+LMym8mCKzfT0WD4A20Sj
NC2xCDfHZU/m/NOJFOt9kb7UftWHZR7GsHux0iU6+Y/HItQP6b+5VtWH7MsT
eyeoPLhIn0qf/VgKzZpmcbwXiaFKTtG+n+ohoeryd8j/CPT9nf6uJ6IHW51O
z9D6RLiq13NAJbEaLdm5F3R1SeR/ga+P2yAUeg1S+p6IQGq67dAJ5IHOVYmR
ShChldwgbbG+H8qyzjYHOqn8ifE1zbjVBJfIzOQZyh9RhTW5zo18ROfKKJvT
KF5exE/EFXBxPTZ/ZsBLiBuJ36QCkvpw2YnF/1ZPYCj2GiuNzsFfE34zBOXX
uJgdqXKpz7BBfET+9wEC3XbVe/0oveysebO9WobE+qgDL9dF10NFYVxWNYHA
5+kCvqCrFGTI5yXq3wisXBb+HXO6EQKTVWE+JiQeulv07c3pwoU3+cWha0gw
Oa2XHyzuQ7vWIXz3SYhtSYf/mlEeBLfKvjv4tgDmU94LrsI6zIiP9I1SejM+
n9/iE1WIcx46v392IsHLqjoUM9+PwJuqwl4/ISS8JB8OyefCgRa8+50niVX3
+n7tT+YhsMzNUYLqn3xj0mSsYRi3Y9scS1aRcPLnRO/J68LNooe1i6QI5D9W
cL73vBknfsxxDF+g8nS+fO6cXTqG3mymX6PwZOb5qBx3rsV6Rcs0yXdUHo9a
nVIwSYGmTcbucX8SDDFz6NCK+8gTq1/e+gOVZ806OYm6fMxJhGhPPBdgoEPz
3AflYWw0YrOD4yi+AkwC70WPQkKKqROqKMAaw25DGbdeOF9KqHnPIyD36dir
RR/KcFGD3XnDlPLL+bsn/5yrQeOuHSquFB4/3E60JBnd0NPwPfDIkepPey2Z
vYub4B6h0TLYRGB4U/8N1mgrzqgZ2Gs/IiAudCy/vrsbR3XOSP3RIsJBW6ft
+6Z68JsFw5ek3qfWXVAkXoyDJK0liyn/0l+bpTDGniMnMd2zntKjZNBTg8L6
Xrgr6UV6Jgkxbq7YaO5Xh/H9aeo8ap8eS4O4NQHtqD1fdly3nUCG74zynS9c
0G1qFoKiRTj3RTontnAYXhuL2eWpQriFtuDcbB3CMq0yJig9+NfXxvNuVmGZ
86q8sNVUf1gy97jkP0Yt48ujLdR8JyWt1WtL+sGXa7r47b0IA7vs361k8vAx
yU/fqEgI/+z7Z5jeHEwlLwoXUn3i5mBlPR9Qi2TJuv1OFQRSJsXt/5vtQBRd
lzlhSWBZ/ciVgk0F+OeIcseqEBIFFuzVtGON2OfdPRsaQeFrt7b6I6cPK1hV
km09FF9VIUG5k3X4NfxgowOFV8CWRk7h8AjYXH+5L5kCnN0cM75g2wPp422V
hr+IIDf2cs2VaR7kI2+1zI8IIFFOYyd4+sPyN+1ZaSpftO7ajo0nNWNJevAV
9iTVv47azZMmdxEpQ3iYUP+j/wOtzLSX
       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkfNlKZmEKNfFI0pWUMxUcLcjeVMmUby9j6KmuSOeo4mYoKQ+RL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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VP8XximhshQJkSiVCmlXqQeR8k1KJPuSkCVClpJEtkrJUgolJCkh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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk4ldsbPY3kRsoJuVxjhGtW5GIZSoYk0kXKVCpEqBBFoek2ITJFwtVN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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk4VfkfxzGFjEJuuGVN0UJiVCZ+vU0lITLIT5JsZR8q+3KTmVJZQkY1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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8ldkb10JKSSZjnUiFTGVJTanp21hSKUkaLX6F7m1UGltJETeMNMoV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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VI/3loQ2EWmTpaylDZVKvdqkEIoUwoeypIVQWZIs0UKSIqGS7Mq+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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41NsbV6Gb3EgLkaUokgp1pZIP2iSUba5Euoq0ocjNaFEJIUshhUKy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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4lekbxynJXsQoUbZRtMiuwhcpmUzFzEi2pESW4SeVokZCJ0ukmkZJ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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4VekXVko0EinpSqX50WSSMCblTRoplw6DJJUSSRlq5LjLIAYJYXIJ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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VI0bxSetlpAKFZUSJWvkVakjyVJeS6RIIq2irJGIlCQllZBUSFEk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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81PkfxxXVEiUdRqstkbVNi027qVUvyWod9etiO1wRyVmOlHVOGleE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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs4lOkbtghJOYQUOYaylXGW0k2hw9JhqJzXKSNJq2yr3XLoaAulItU4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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8Vfkbx41kfiGVsVVGUrYsyWiU5MO0yzqV+EUkyTJqcBlESI3QwpSy
5FaypFCy32RfCnO5XNd2RfkeDaUMkmom8+2P8zqv83pe55znfJ735/Oc1W4n
fz4mKiIico0eX8/nH4QcbFHk4eoFP5GRcgLj5KA7ZyRboBeWqG5xm+CCrp59
yp52hBrflXGpIuitNWwPyOehRkY/1eAjgYJ8d2PhZDcyhbNuw/oMFLx2F64x
6sTj4TVmB/gEpy4tfDPyjIfei6eOyHUTKAlVArWHuAg0TXsdmE9wKSWiTlk7
C1O7/W6+dSW4tvzAUrssHn674XFWo42gy8omatHHfsyHn9D4u5yBtHpEkGTa
EKwr4sqEsqO4t0xlh7l6B8Qb2WW+1QSb1h9W2efdBYsy9d3+YwQFUtctYh71
ozyy2W0ykkGktqe1cksWeI9S7isfIUDbF9nxMB76FQ96JWYTmESIT0R/6EW3
pNbP8fsZyCY9N7JeUAfT7sf/yoQTeC93nxst7cfO+qiBZ5cZXJTyn0/jDWAh
f7fWUAEDj3Tfbw8P96IoJP3FJ3sG51cLPo90VKCyf1fIj94EL8vNHHOSumAs
GK76W4EB2+XwonZJAcjtN3HMLgaari7agd/0YvaKKK80nIHIobi9g5GPUeXw
rK/yF3r/l0vfFpryIXlYF7NU/+DqbTMTS8pgH7JTDMcJOopKdI0jB2G4huM8
FstA6sJKR5+YVsinPT7AYxNIxG8vNXHnQVN0RWHgdYLksoRNLR0cpAhk72zx
Jci7lCpZ/5KHE6053XsbCRzcnJ4qXSuHZm2oU64PwStX7sIuXh9+uvXjE11d
BiaHQvsssttwefqo40wBgeLJjWMZ10oQV/9NRYQnwd1AzZ7M50IYL9iTLJlC
9fyY0bgouQK89P+lS9HnpbMcbldp9UHi6rG6jVEM7HZeLLAL5mF96FEt3xGC
xbWKoiV3WsD+azHH7wqBrXzunFl+DmwVQgpW0fkVj1qZRKh24OS+0MjsO5TP
ZTHl9k5DSHFe67C8hIHAUKP25q5O3C1wVTSoI4gScfNJ9+1D4ZF7gh9sGPyz
v5mprmlHyJHgfZ8pPyoL133QHU5Bj9DWvN+FoOHGwyglfx72xG3we0z5kH8h
X1SX1Al/UYeRsWkCWbvFCQcShFg/WS/incSgKv/5eEhANUrXJyYa+NH+6sf8
k97lIZP97VuBG8GZVU1XNiQKcCXtj8L36gwme/IMXdbVINDgrx/ivQjKhUZ/
9/c+xNS5qF4Rd4LRYXtZpxI+xG80vCr7nsHobZuh+OuUxybDWy7BBE2Zt6JM
w+pQys62dAkjuDF2U0LpER8sPavXQ9Rv0WHHbYNqeqHzXU22ngUD9+ixRutn
edh18vJWnaPU3xcr31uk9aG9JvllXRCtqxps6RXwoR9N5jOpn+semT/fS3md
nLdoZTURjGUN+tkP/Ak5/9TaV7kEk1pWnKTcpyDyyy2aKU+GDZfdL5gIkTbu
USkhMophqTL9PwOu461iVF0l1TNMlMVx6G9GTbLeQPRlAiMFd4GaWxf0380q
FNL5zGkLwhqUn8DjjejHAsp7cGv+C3bqQ0yXOS4wpf2yzU6nBzgJsVNpq/lK
HwZKbiq/uKQU4bPAyZntQVBknScl3dWDTxnDBtuonxJ++jHQXfwu8jfJ7bWg
vFhrvnDmpghwyWIXMz1PYPb6NefBdznwfZJjWkzrMzI/i+042QofO6/kDXTe
9zSa2GPvB+HEU4qoUBxF+TrLZY7CCoxOSGhzqZ+3FL3haOZ2wkr64HVDIdVD
bs/gzLIuZO7I2FZI/a2yiVVc6JmP/ubkiHO0/3d2e9ZXHu1F3+p2/ZeBDJaW
/yPF0enEcWVfXzaXwHXLyvVBm4vQPH0+R4x+j1Nkmo/mqQIkuAxfPUP52bhq
KlYmho+fQi2zdJVpXmjHx+n7cvHUcUJtUS31x7Nw2/ipLrz+oHg5geafR8pa
actF3chujy2Y7iUovBtmZ8xtgslvW1uyYun7TkeOO48no/uAcl8tnU+xnMyO
yBXdcAhpfMhuJ9CperFFOFOPgrXqVtdYBHonXFsnPNrBalBPn6L5nfxgrl9V
oQKDYbrihyi/bR43BQ80O5AVq7Pc7AHlObepc8otH7IJ5qJf+SfHp3XdfJow
sMOtaVMUrXNmDEoX9KPaSezLaT8GV1fk8pXftyHv47zaVponKoGbZ6/MJ+Dh
G2nT8K/9pc++9v6zFuN51XaqAQS7G2f2/9reh8koxvuTBtVz9YZcz4NCyMWf
W6oWQ/NmScuszzEe7LmMQesAgfjE71NHJkpgvfHUoAzNy0+cDy+7g4WI5Iou
089k4Ox/4VadZTdEgsgLXSkGDdXVUm2efSiuur87n+Z539WwbtvYLigd/32z
vCiDjS5PbIKnO7F2ZZrX5wbqv+G/xKQ5/RjYJ3qNOcOAnzee9WVZFiJuKFv5
UL44fkZa94eaEXTWevTXRIITmTYqv3V2IY71y1JHOq+lg6kxm9dwoCnBSp+h
emp8FPcJmOyAZ6LxuVc1BHayD6IFhIsOufTY2hyq52Kul87RHoSFf7h4h/ZX
vHVoY7h0NWx19r68fZLm03bxf55KtKNBYTpGq5Dg1lnLmk3NcTDuEztxiOo5
s3+nkfUVLsxiMj6o3SM493/JQU1+I9KH/Nr66L47m5pcE2XIh2NDkk0d9Qu7
UtxFVYyHIL+5BtYfBPo3uzIU/+Xj3Tq5xe84BKxjancVe4QQu5jpZM+j+yda
bEdA5iOcb5EJyDtG+cweun86qhizDrVK4fQ6zy7iqQG/CQ9XnA43T6D7g+1U
971RA652aK+bjCDYfvaZqobWELiW0W529QyG9xTb3FPJhqpqYtbX/4Xhie1z
oWcqkG496d1L90nlu+dLDsr0gsVay9IyYXD2wEhDI4v+n7x1lTWcpHmaav7G
7MYAWhad46vSvCt+1SMmxmpDqedBr7yv+eUyZxfd2oa1A85Rd+7TfXv++WG3
yVoIMzIXq9F8bVk1ZRpB83/2Se42Lp2XirLe8L58Pn7Vn9nl/4VA8CplJOhp
N3aWDZUU0Pp/FETREg==
       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VP0bxgctlIq0L7ZSkrzK+kbdKhUSQipE2SL1RiXakKxFqciaPVRC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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lekbxo9GZZgsZadBQpYMUlTqohOyjGiQqZREMUqWMSGVKYVEtNgK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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs41FkYxyexW7sUFSEklya3pMVWbN9BuZQ2KSW5VS6RikQUpZJQwobc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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns4Vdkfxk+liDIkpX6UGkp0IZdxa95UiImkGCEOudUclzAq01ANxZDL
KIoYg1xKShyk3B2KHOe4HrejqbWLUj/TqKTSrP7Yz36+z3qevdb3+76fd+01
noH23nNZLFYqfb6+tcu1FI76F2FXi4WdlwdBOWttSVwNH88N53TbNREYnQlS
Fmr04rX6i0Nfxgj25OhoOTQ04u3rc7MJJwnGbPJLwnhceN91qN3tR/Bs+u72
XFMBjo2I796/RzD5OdOSv6MBl9lvzzw+QVCV8E7qu4gWSHW0mpyIIzjt+FNz
vIIY9UNrbcrHGWhyh/eyDwxgj2+drYU+g+IxHXer7wfRI8k9tcuNwebK01n9
94U4iq1OASICqaCP4znetXitYh4tCCaQNv6pRUI2D3PajBSG2QRRyVrjUfp1
eGWXUXnwGMGnYr1POqa9sOFVN8RLMVg1tcB2RK8PJhsiObIqDIIfRx+t21mM
Vb935ah7Emj8KMy9ndGMgDyTsPSzBF6mtyOL3tzAQpbGTAJdn5rtklw+2Qc/
ywsNru4M8t/jvM433Zg39mDGvoDAwnW3YYeGCDNrROllngzqJy7Cgn0F6eJV
GrPuBCwP83ti11hsiDBYepDWajFlFecbuOBo5Z+I8CVQ8mS7Hc6/herPMiNc
up/ThZlODtMPTd9f3hw3oPOJqezeGy6E6kUHE24dweOTYcekw+5gZeb3m9IO
Eww4fnSvSR3C0EFbfnYZgylDrotCigALHqZIrKfzmxwP8rh1pwp/ur4yVDtC
YN05+MNY3gAqFNNbGDr/zzk1TxQ4A+DVqXZkWTNoSWJKb9J+BUaHTHkaDDaG
s+YeH2vFAW61SV4SgaGf2dLQ6D5Y24bnRO9i8PzkHu7Lp11oV7LLtByk5wuV
C1kmLsJGn2VHtGg/rCsrnqRI/4GMf4WJkbR/ub6zk0q5IgiiZM7az2fwQ2LI
3J2VV2H7C79Mmep5ar5zX8lv1TgUwHD+H0Dgmlyr3andiEeFz3nlYQQLu3pF
gWUjCJle0b1tlsENJU5TyOIuGDtv2aM2QlC/3Dhp4yeq3/oD53TofHaXJO+4
uLgcLI3+KRlvgl+zf9ZtCOBhS7qaik0k9eugk0NhSy70jlrbrqR8ZCgni4Lf
VaFHIdZhluqz+8U1lft/1CH7UJvw70CC1vbG+Od9Q4jTia+VDmIgF3PrZv+d
dky9ixhSvUAwYbwxj7P4AX4veOLnn0BQYyGddF9PhHWXmqeqw6j/7YJkv1d/
hOUdqYdUrhFMS+jufWrLx3VjcTi7iEDC50K0tCoPqvF7/EvO0PWrVRkrQnqR
Vh5s4DePwdWof8/LJwmQqtJz2InyeyLNdP6MvRjGkaFx/3vH4HxJj2rzVgE4
eyosn5ZRHux+t6825cFmG8dWI4pgf4Ws4cCnbojeKm+XmSXQK1tf06VYj789
365pDqG8Dz3/0OLSAPmiuUaLaC1z6gTbY3U9Xgt99krRuvaPgpEa62EU62o7
jicymPBLnPK+2IbZ3f0d9yjvrMkdIU8bU7BGkZWaTfX2DOoL6lcbhbnzFquB
SwwmuzJ5jk8fIMvfXvbFeYKZtfpBUUk83I6eETyNIIj4wUrfMpmHnPZmaT3K
o6b00KYiyW7EmuU3uU8RrNhvIF6yrAu1HOZzx03qt7Cx1cXXb+B+pl+RBvXb
5cwUQdv1Dsimj2YczKb6/bNqRZVPMmpvVaqH0/PIJsVu5usK0dh9vkEsJKj4
68F4eoUQaZyVDnI0/wpfqdZWjAvQGfkyj1/5ld9+o/UPu6DgEhqziEX52NIk
2ewvRJWx7CWTWoJ4nSMvasK7YaAjvnB7nCBV4DadtG2Q5lIb91AoAyWJOIt9
/X2QUpgWZ0kwOFjtu4zT2gq2S3RpaArld6xn8zRa4fGWrNWn9UrROmtnbgOk
XjgXG1G/29Wn86t9a+ARtOTUjSAC51TV7YbV3Wg6M1qoOUH1s1XXv2zWDaP0
bzYLn9H5SG5duCmiH8V35lVHWTAY51wt93/Vi9XW9XwXqjdnzoLAsTN8aOhu
jXRrpvl3s3R58rYKnJ4sM+HTfN/clBMt6dwE03H5K77Uf5f54yZ9Pv2wsPKR
/24/g4uVF6d65fngbzN/OPoXgaRLnva2fBHKJ+xmvAMYiM2c/vrV5xE2m+i6
pVynfl52pLdFtgWPy4Pfv4+mevycy+NnVcEwYEBO8SjB9peILzt2DoapZGg/
1efJlsF1yz/WIvtL3QYX6rfJqdeehaJhuNUsaxnYx0B0TkfSxvcRvDyuli69
RPn1/HH68UQDJnY5Job9TCA4uO5aa1gJMswDrRqpH5TOmu1bLp2Lk125stU0
X/7Rvqlk3t4A6QTGXY7eJ6qVG64k2ucjiV2Uq0f5V2XP4dr0PsQ7/bOdnmmU
h52+luz6OnhdrnAzo3l0Ns/203ODNpx26xi4Qv01aeXK6ltbinO+t9/U0byJ
OBb2LLZ2BO++W/zW8hqDb19Vhl6LL8ei4O1Z8TR/JoKceflFzYg6oqX5laeM
l5vSzb27AOeC6py/qd/+Db+n82MMVg+FsZ3oPBScvTEvht4/MrkP3NkMouzU
yq5UlEJifq/y1zx7dPjAIm2qp5m/zVG5XIK5CnXbOrSHIV4dVyYcYTCmGz31
p5oAa+s0OnbS+0O6jpw78GAQuifuPdPdy0Awj5v6URgFueP7gvbS/UKvBvgU
sHtgmfLy007q5yojzRiLvE5kqe1boJxDYNz9SOyc3A8nffXfIu0ZyHqoLPVy
pHn5JUVmBdVTdKOngKfYCS+vk8WLsghIgmLyx8Z7iF3SwrWl81M27lnyOLgb
p2+mfftBTPOYsynZIbUXrl/ufEgYJih2qLeKO9yM9sIBz+3Hqb8Tst/vsByF
/2hfqfMzmn8vJd6w1gjR7JJ+UqGeIGRg5kN3+zD+UUw8rNLO4P2A8eqVrzrx
zIpjL3+X6l/b2NYRyIeBumvqnUaCXad8vhTE8VB4rbjFJ5Z+3/HFQKZ2P8oz
C8e0PtN8kNef/+fCJmhesB91PUX/B7gS6lIVDdBOHk4roHopLQjqdN54GzGi
gKlAL4L/AP1AwU4=
       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3kglGsbxhGKJFsiWyglS45KiC7kSKJEluy0SRSlhRCRSElIIkRyVCJO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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lekbxqVJ2YaEUIOErC22sdVlyxINaUGEbENCDFIzhFHRlGgmSray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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81GsbxrXzWk8rU0lRpEKlSLgsdXRQ4W3hKFmG9yRpIkvSCYcOSatQ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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lWkbPqMyQ4oihJAkIyR9WrRcMibztUxFTaZtrJEtS5xOprRQmCHF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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VG0bxyWJED0kUU8qS4uylUL5SbIUhVR2JUUhkopSIbImSngqylaK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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk41Wkbxy0NmkRmWmbEZAuFNjSU+hodb40UWcfaIYoUMkjJKJQlxSBk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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81dkfxnWT22DMjQgtlmIMNyE1GHlkKssgFc1kS5StUFK2Bi22RlNN
WVomWZq6keWiQtm3rNe91yXZ7v1+s/yaUJSl8PvOH+d1/jivzzmf85znvB81
z6D9x2hiYmIp1Phvvn9g0Mz3Cw+VynsLL4aJ8LWPtpX8qx4WPm7bXJMIjIVc
VfA+14fWh71BN5QGIbH5zVX7x0UwVLeV+uhKwuRfuueuQA7MSn3Cup4QYCyP
VJ9/WoqGB8vY0YMEVARtii8G+uDdb5Id6jgEU8vqNeodAgxX7PdM8xdi6K4a
/UtpEf7My9EtkybRtnxE2dhNgJzn5hXvaoS4n2Y+nO6cjszJ7skqWxKsgnjS
ic2DWUz+woajQvwxLshNNa9FZem1uGNlJNJtelW8il9DeWk6PLBWCIfjJ9+M
ZvHgcfSVwdcdIjCkWb9UFvWhnb3mkI2EEKQ1p7mxpwuFU5tZjdJDOHF0XfCn
e51w1WN9GpYnIdbNVZ0/kIC487kxNHcSVUNaTrrbKrDJyW4/8xkB8yTSnNja
CFe6soz0vAgcU00vt19LwG+eZ11YS8L5xc6qBsNifLaYvGt1koT6RsaGalE7
ZrTCvp+ZJxATYhK/RjYFxT4vb7z8jYR91Pi0kt5rLI64zeg+FSJuXIW781Qz
pv+k642mE7itxw5bl92BwIYc7UU2gZ7K8xohJ9gIC36gNBdNQqiseVd3gg8P
qZroj1Mk4syb13iye+AStUX/kzaBtNqOnTukujDNLPgltHUIjuGPuOUZraj7
JjE5aheBAeNZ39fRHAiKNPZc8SPwT0jBBjHDTkye9kke1yExqn+bNracjZT7
9G2fvEiYbvOztr1TAbvD1/y5+pRePtEDP8ffAcczSSHiMAnbWbZXZhsHM+RO
ZpCVCI6xT3TGeIVwHP/DLGYbiah5FeJ6CQ8CD3bovgUhFo2myG5b6vzZtzpO
LQRCgq9JrNThgP6iyE0mWwjd5IvfiEX1YEtCgsYE1d9MhsGy9XJ8TEtyrTZS
fmXc6X3P+9CC5Vm8kpByEbZoLnBcTAWwutKQeytcCIZg0F7uaAGyvTQOMa1J
nD5rORShXg/a+8Tm9ZT/GKe6pSy8OeDwf10s9yBwOa1H4akOH3uMLYYPj4mw
yQphu1T5YG9sX5IYFGG/e6P2jslO+Df9uC9qnwgbXNp1C//uQsMyvwdap0QQ
aN/5fO6+AEVayns8VlD9lX7xf21cDMYqZoq0Ionb86HXVc7wcNJ1ZPLJFAE9
nlqZRHsu8iLLWsosSfRsz7iweK8f/6j1rHBK6IeDpVJZ9uMm1C3Vy84mEtDq
OLr2bJsAZiG91nNLQ5hdzONWL9VD+pF7yKkPBIpNSuyKAupwWvleLKOYQIIM
U7E0qAQnTN8lW2whMR75w7r8BA4Y6ZO99iokJm+0PUs8WArZKOqH6pFojTP3
1WLxwK3y8rliIcRoaGeXi+lzSCQv1ESsJqFbr8mIs+kCZ3dw6k5xEbKP6F73
WdYDz8wTNzODhfCPOlu8O6IXXrKyBfzkATCrNB5YB/LhYKfbW71HBLlkjVs/
hxeD1yN633qIRK6669D0rU68kH9nsfonEtaOc5HraFxEruU6a8eI4FuSPsGf
KIOt39jiRoo/izbTqSmF/YjeI/4sdt1bKLZH3On83Isop+8vfOstQs/H/MQV
xwpxbzRUmRNJ7R+zN1b0bytW3uX3nAKB8WJZZcZXHozODGdkUv7MX+QHv2Lx
4fmo+kzeDAHZzsFD7JgaPKvYnhF0gURmolrOgqQAkaG7NwVfpvyv9WdChWI1
7rZvihNQenASDLcuyd/F3r9f0q9S/VV9MWh5Z/4Gc9b5skqVIhjSLs1YnKuF
8qrS1143CHA0a1u+ZRVj4sqKr+GeJAxLH9D+6O5EkFC+ls8jcCD+eO5PrKeQ
sFgWDwMSEvFhi4P2XfAdZfYfGBDBSOFl01RbOwK1V1VpUXw7mWeiLxTPgmQZ
zab5IOWf5z5SXqxWXPz5f1vLKf1Uk87Y1MU3YEFxbeVlil8e3lmSu2iPYW80
98PIbhJmXvo+j37sRFNA9K2o4wRst0v261i8gntcjKuEOImYdQsH6HufQprQ
yPT/QsCBru+pkl2Bh+6OzbN2JKZscx67q9ZigWDElauTSN3FlPSXb0PeB2fH
uWISSYauFekahQiJN6u4bE/xItuhcVvYboRMCw8ZULyYVRG9+a2+A2XxTcHn
34qwWnJpqsamF9x7K5baygdRd3m6O/F5Jxxbxdq/axFivH5nn2L6GxioNrbZ
xZEY+tZoOOv2K4Sd05JOovLi5AddzvGARgxeLFBQpXhSUKQzMKtcDteP7Os/
bSLRvyiRHXusBXXeJ/bbxZIIS5l6d+XJM8hPe+WlyZI4qPlphZ8VB39F6jnz
wwmMMg2brSbqkTKiYhebSmApPV/9MKcX536PCtQKoPR5Ip6T39eBS2lGESP+
IljZJwuUG4qh+TIwWexHEuZcQlQS00Dxpn1mMJiEopVT6vjUQ/AeqISJHSdx
c0fhmGFBF/otHbhz9wgMG121ZEwJEO9z6a29sRAFf8lfay3JhWn0J/WDTiTy
9mpdNxwSQMZnMZdJE6FK+Gze1b0BepYuR3qPUPfNlpJYeE75m77987Q8VT/7
3Vfu5lfoSzkRsPUsta5md1xutAU2SWvXm5sSWL3WOcjt3xSQOidjqo+SeGws
7HRSZWHos7PMQCDFK+ZB+hi9AZ3Xtrz7LYVA6uaG06yJDnyhGd+3VyAhqv7d
pceyByY5c8mpU4NI0A8f/bBUB8+VK/8ubaX4szdjV5tJLRwrLZyPeBMIsh3p
7Kb8I67LlJqkeGzTpV9+1r8KQWq3Ynx9qLx5UzN/Pp8Hv4c2t1hnhFBQmhF7
SNTDRNns0gzFvxrhw3yZfXXwrdxQaxRMQLzC9ebqVDY+Z14LEPcgUbD+YHaE
XAm4vw6W11LvIwhdGWVbxseQUugvRSspPzrmOcg5NuGQLsv0BypPxDQ0/Tyz
zoNpIMVzp+plxMVHr7o1IWuRJuXVRKDofX+ArnYvdpcUdKedJ9B6gNYWmMGH
C93gfch/+eYW+FbMoQnbvy+V23+KwP8B5UC8qQ==
       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8ldkbv5hp5YesKUvLDMlMNI1pkr6aKJUKU300UhGSELJPTGghEpIl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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VO8fxaXFVhIqZakoUpJKSHSElq+INkmyJVuRJSktVFKJEi0oS4kk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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41dkfxynZ0iJbhn4Yki1NygxFb5VuxhSRZFBJdoUJlZrKWErmWkIT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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns81GkbxhVaFVLYrSWlty0d1mEdkp1col5EpaJ1bqYt6bCVIltRJBqH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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4ldkflwapDBLppkJpkTBMqUk+FYmUGCYJyTomoiYhiSwxirrST0WW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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHc4lf8bNiqUilBmJfGzUlZUdEslKhoykiKFhkpSSGRntZRISSSbZMvM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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81VkfliZpGlvDULaWISRkCSmPLUnIuHbC2CpERQpNQxmi3izJFka2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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk8lVkDvmGkopHK+EqLcfmIYrhE5T5otWRUJutoEmMtsmSJEioJWcIo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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk81VkflkHEi4wmRZEtyyivvGnjESpTRlKKxk4ThmxZymRJltcIUVkS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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHk8VF8fRshPVEobKtqTLSFtHpSizZIWFZEliVRKkyRLWQsVUUqipJA9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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81Vkf1mCYxEhIGFKWmBYpCuVBMYWGUChxVa+MKZq00ExSZCtLKbRY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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk4lVsbxhGiU6aIEEJInBKJkjtzKYpCIvNQfUdppDLzkYNCpjpUIlNs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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8lWkbx7UNRaihlxZLCwZRyCDjJ2WpV8uIKW8NJXuaSIiIJEvWImNI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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2kglGsbJi2kok0l2aKkcmSrLF0SpY5IWdJGkmRLJ0XlSBRZI2tZE5Il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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8Vukbxl9C00oh1UQmQ4Ux1VCJXGQtihQpeyGTkX0ptNgiJRoVBjGa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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lekbxsuYkagwpBgcNenIlpRSwyVLmSylqTQSEcJEp6iU7VimJNSg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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns4VWkbxiXUUNrTVLaajyI1GecwTRO3mqIwjVNSGUKkyKlIQkrJISLn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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lG0bxlWUpChK5UtICKGyRTllqUSbhBbylp0UJZJsKRRZkiSJQrYi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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk41dkfxzEtRn6KsZYsJSRTSmOJeqtxxaQRLbZUlqxFdTOGNKGyFmUb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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVms8lGkftqwoOWRLUmnS1maoJWIrdYVWlBxCUZTD1HZEkdepaepNW7ui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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns8lOkXn4qiSEVFJGyh39qwP5XS9kXWttIil0QKKdpNdNsVlpQ2k1LE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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VO8bxodUshRJCZUklS+lRIq6kUhKStmSZG+TZEuIUlFSiZQla0hl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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk4lekbxynKqMlkVKIRMmGiJJIW36hhilQGQ5Y4JDTZkrKEJmXPTAmV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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk41WkbtiR0TTEzCGksI2vbJKJp3EiUCp/UZAktJMQhjC2MHKUwkSVb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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lXkbxr1nTMlLSaVG2ZpGKtlqJEOX9CIpISJSkihbTmIqQkIMIi3j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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHkgVH8bxSdJC1kKLYhQIZWlqMixJaVIVCp7ZOkXkTUlWpCEIlRIJZQW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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81dkbVpYkRGVIRpYWKSbbpKRHURm5QgjFGFtCKJqRqSxjmGlUKBKy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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4lWsXxk1JJ6ck0rBzhCKhsp0S6lZRppShZCjDh6hERMYM6Sjz0HDS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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk41VkYx1XUlEhZUsMQjaYZoqRum2+pSUpFRAuVXYVKskYkS0yJbJWJ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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VH0fxtHeo5KQLKVFSXgsLRTdPEkpeyUVhShUspOEUKmUSFnSokSS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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81dkfxqWMUrZGl6FJNWok0UKaqIdLZcgu/WSJirIbUcYaFWlUV1Ky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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4lXkbxlChKfuSJYZQWoSR5dNtRFGdBmGQXTRoIkXGIDLRIktkZBtL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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs8lGkfxofo7SB5EdJRZG2Rdrd1KFyxqYRZJCVlHJpaVMzqRJJ2LYVQ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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lOsfxpEWQh1Hi0LKmiPZU5xulYpCKpW0WKIkS0lZKkmlooRUyF6n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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81OseHpQkhRaHOESSrRI3yRw93ajTImeEspPllKXDiFIkjdKnuKWI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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4lekbPgltKlNClCyRLIMotN0YNbRIOWXJHsYoQpslDWkOc6UkhsTI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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekbPsikZWaUUSFrMpbGT2k11V1+MjOYIjFk7diS0qHMZAbJSJHq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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHkglPsXxnFbJEVlKUu2SEWhunVtT6mQJZIlFcm1h0oSKgmXElJJkmQr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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx5EyiFBpWux+JUuyTKmMj+xRWSJCZVRCSIlkSpQtxTXKEqoZ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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4lXkbpqGMpZKobyJNRlR2H9OCW5FlLEmFRjjDSSGKscyQLFMhGUVZ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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8VekbJ5oWpJ/Kkq1oFCVZRrtv0RQmuklly3JTyV50LUmIuklZE6KE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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8Vf8fx5USFVkpW7KahKT5QjLSsJL6KpIUIUlIQqVIVplNKzvZKiHZ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81dkbx2kRSUrCoJEl2RKlUuGjUmiUFhKukHXSQjUSooWUkDuqsSUZ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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk81VkfRqpRdywVorypSNEihFI9mEyRkIiiLFnKeEuUkEoivBrMlKQM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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs0lVkfx10S0xSRVzrMUMqSlCmXCvm6hV6ppgy6yZRcDyMhKZckFSX3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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lG0bxqe00GZJKJI2L16EVHrDqUUbFVpI9kpIpGxRslUqlaRCKiTZ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41Wkbx7WOSJRlGiFU70hZamQf38ZIzKAminRCkhOKQyY7x1ZZ0ojO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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs0VfkbxlVqVOiYyTUUZboMZQyFUY9xqxzhIAyikkJyqVwyKpeSxiVF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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwdlXk81dkbx43R6s4kUk1UlkgqSzLRND5RQ1OaonVK9iVmXCqSpVy7hIiQ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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2kglG8bxRVK9iRJkkpKsqSUbEdSSYWkQhJSSSrZlZBSFFooJFqtSQg1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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlWk81ekbxk+WaJtJ1iQRiRGpEcZ2yZDItMkWskQioYiISUkiS6TJIGMZ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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk41fkblbSoCNGQVGpSllQqjXFzJNcSypRKyFLUVUKWiMoSWozSYg2T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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs4VWkbxvVFyhiUGJ8ODp00JKdPatNdhFLJFCUkbXIIkRShUDRNY5BT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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VG0fli1KaA/tJUv2JUJu5JVKEpEWFSFahFSKt9BCKaRkSVmikLco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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlWs41Vkbxnc5RtlSQomZVEMYBqFJ3ZQ0qRyKHOe1y6EcKhQSphwmoiQ2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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVWs4lWkbpXJIplQITWMrojIxIQ2yEJJDGrPJsajdRBmHwSb5JCMZpEjI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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk81WkflWwV0mJaVMg0ZYpKwqvGoUyvqegmWpSIyhpDkfG2TKiMVJgs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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8Vf8fFhpKQ2V9W0ZRspVU8qBlFYlSVIhSViQzkSYVUoqMKCsZF2WP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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVWk4lVsbpiJFCI1HEhGiHAkJt1Q+QySaODYZtowZjtRXGgiR6ISQobap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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk01ekfx2+2JktjGRnXZG2RpE0i8m5TRBqUEMpWDRGVZYxtpCIxOUKL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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lekbx6kYGdXQaVFCIUm/ytqk9DVSiGyjISmhpLFWtjAle0VjLGUy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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VG0bx7UJbVosqSilFNmlpH6SEpXssoSUJyRSeVCSrSxJhZDoUalU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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41Wkbx5EhJSGFUklpDC1EE6KvvKVSvNomHUsKEYpElCVCIpmJEqKy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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lWkfxlVMNDTRkN5k6cVUFCYJ4ZIsJ9mTZQgplESkiBbClCxFaZSJ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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8VekbV/lNQpNBlmrKqCwx8ZNMKX2bqLRRRAZZo2tfkigVpphEZLnW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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHk8VG0bFiIR6tUmWXorFKWyRLhsJVHhJSKUyFqWKKRIJQqlqEiiLGXL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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk41ekXRxhbaBNGkWgkRLY0+GizZAk1kmxZkqiUopCshbKELBUJFVJI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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk81HkfnyIsLVYSqu1wdMmdcr6VDgqJVSLMKJsr16bIljNnRdGmknLX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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk4ld0axrcGKRWdBjRQpnSi5OijgVsynooGKg2mkFB2ho2UlOFLioqE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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VG8bJipLWUtERWVNQiXi55ZshQhJpaIkbSgRWSJLiEiFJJU2y1iS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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81Okfn6wOFfEj2daQIkJSJKm8E7WOyJXuWFFK6ypExEpytFR2NYiV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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lekbxpUWU0YhhTFlisb8KmSZpOEiKmSroY4tS6ppmLFEKUokCZUw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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8ldkfFkYkSZTq0tStMTUoGUskj0r0QcsvpEIaSSptQ6iMENpJlqTB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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3cglW0flkL0GglRiCIzO2lwSSorSUiUvF4ZRRpCSkaRFKmMiLSMVELK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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81Vkfx2+7CnkKyaArTbaENFkqn9QkKkuRJEIJZekWxvBMJEu2MfYk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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk81PkfniIpR0o3RRpXohDbhn10bGJdoRIlKUQ5GxaVpRRli5RNKNHk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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lVkfR5K2UZEaU2lhFEVlsr99GyJtaCFpYWRudqKQneS+omIIqddk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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lHsbxy2VJS1KUklKZUlZTjv5KrK02MIplV0JlUPJTlLoqEQhWcqR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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81OkXx/GTVCplo3Kp3FuWakvS8rEuEbFWg0JGlJlFJJRKUoskSVKu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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4lWkfPpVKGBnZSslMm++YUKRRcpMKkyxNE206GXtJxWCydELKkqij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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns8VFkAxyfVJo+NzZa1sii2VhNborx+GmrLJtJmSy/aKYkkDS15hCST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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8Vf/XxVW+lShDhSSSzIoiya9aKkVIQikVUqRIA5VIJGXMUEIisySi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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81ekbFSkhIcqoRpFG/EKDaDGHFCWy1JQKyZJlCJOMSMnPVpEaMU0i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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lWkfxokWS5YwZJlUiiilIWrKxdiGxkwhL0ZZEy/JTDLGJEspJSFr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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs8VekextUxh0qZ3CIMMpQoiW7Eo8YMTZpKRSEhOSQp7QyiXHYmJySl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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VP8XxkmLFtmlrFmKSLKF4pFUCEmKEmmnkGSrkEp9VchSiiRbESpb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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81GsbxiWhg7ZDibJUEr0HJ7RQXSEZaRFKjkKdI0JMC0papZA6tmzJ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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs01WkXPsq9lFRyG5L0IQxFRHlichlKGCK6nEEliYqYspLo4h5Gkwmd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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwdlnk8lWkfxg2aiqyjHEoKNaaaNzUV2S7RomE0SVGZksYyyUSy5czEkO2V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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VH0fxkcr2hRZyq602iql0C0UIdlTKBL1VLYeopQsKWVJeipJhago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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs4lNkfH1SqbZVcsi4RbTb35FJYn0wbUW1CLYtsmEpIWUVShBiXlEu0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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4lWkbJ0UL8kUZGUkb0yrKpEy/w2gZIVlq4owolaRCKdt3rFlKZWRk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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lmkXVvjGpKZFxRTFpLK88fqaUrarlBJpmiwhxhYaCSkiCklGtjRk
CSkUUfZ9yZIlW15e+2sS9zNUhgyhRN/9/fH8nt/ze87v3Ne5znWuc0tZO5+y
Xc7Hx3ePPv9/F7atvrL5VhPmKxUcQzMIeiOv598WHoBAxeMdsw4M2Gfcy9Zp
tYJoFUc9zyGIXGEq+lNADaINijLyPAgayza9nmdxYcryeDX3HwZDXzK/Pl4q
xNVYMV83ewLjuOsWfLNc/CJvt09/JYM79vkDJ3Jrkdi292S2F4FA13jc+431
UG2pVk3wITgSHjrrnNiLjfKq/SwRBsP1ZyvFPvTjF31u6bHHDGS+uqXH9yTC
vyRq1yFLgkN7P+oqBPdj14d44xfKDFLN+FZrHexAnsZBqUvDBGYzbpwsVhcm
zMVf640RWN63jciqvI33Aj7HLC0IivWNfwrU7YG0Prv+rDXFH1MZapLFgd1D
GVeRWgLfgFidV27p8Bad5rCtCT62WzE37duhOX7RdGsQweXh3lvfydWi+cN7
N/YNAnaM4cDkxTJUJOuKLzoSJOlb7RAVfYmY69Nhnz0pX/GeeeWmaQhvsPOy
syI4nsNa+ryyCVPrNtwPDqXx3+/3iFl8giG2hV8e/X8g9j9Svt4PUCd2MewU
rXdq9M/9T+50YKuVZMoCQ+PZAt6qSY1wMnSv5o8lINu1Nk519qOOPF0Q2MTA
cs533lnhGXy7z2Kc4o9fE+C89LAK/M6Gy/SdCWSUlNhaCvV4OenyV/NdApXA
fU4N77iIU0phjU0RVHhEhnle7oFaje2qNAEGapJh7vOzvfAQrIx5dZ6B9Mdb
49aBTViuvfFzczrB4RTeG3GJBtQ0X9DOvkUwFFi/JsqtFYtJlt7FVF/kZLhN
nx4HDmESPhUVVE9dz/KWAjgwY+e/O19GYJrKKPrf4WFvz15ibcsgpa7mu6+a
7ZjnHXzq0ElQPl94TrenBctrpUYlownSXj9ZcNArxW9Tm4XVLhB8PTI8PhXY
iRNDaSv30v5XRaeJCa0NxHDTtn592m8d/Vdz5t91gtd92O4il9Z/bHQijN0D
ofjS334/zcCqdE51cFMm1EVkA3MpXxlndDNkSBcKZxN2ftnJgPdoKjX/QSvK
UkUDTyVRvZazTPzV22Ap9WyVOK1f5tZODcVyDgaN5IwNGgn4eDVLksWlOOKX
OLHWiYC38pFSmHg1XIObNgS4Un4eS/esKuPi/HTC4PpZgrh7W1OsnNrR7iN7
c7qK1lOeLWvl3oCfdzcHGfhRvYYUKAe/6sOyoSi/HGkGRisUfB615sAjMX8i
6SzBSYuTBe9a66Dx8BtJp/PU2LPFYdwiD97gOPFsCHJOT7DtdnBw+8in9aXN
BFcqvWYM9/VCdqn9WrQR7adWraxaTD0c5C40VYURZP6TKSH0NgPc3oyau5SP
A/ISZpvDY/HAsmL0LeUz6uc9fQ91+/D1eemdM5oMpq95msRLlcPnz6QlW6ov
Y33TLdK9RWC/P5peTf3g9OvZoHTHTiz8s0NGZ44g6Nwd42OzHBwYvfjDj68o
fs9ZucnJGHiMct99pPmrTHT4hdluSGnLjFam38FSri42RgOQTTf5ccSfwZtf
pXP0khogaS7nrxZOsPRJVSuFxYFc/EzxmnzqL9L/rvQb5sL67t0FtQXK99IE
u640AuNevpP+NJ+4zu+PW9Wa4S7ZflkmmSA0dP87Qb5+TMr/5OwVwkDg0Yxw
5M16pPgH6XVcp/i+lSy++e9z8P96vVud8nm1uEC5MrEDrkfMTEJbaf5rw4gu
7oQ4L9PjdB9Bdoj+qPZgCR5qvOy4QfVZLH31/al35XA0nIp+Tv1hOF3kKLHj
4HjsHuvn9QR2rduPJnN7YaWW3aTLYsCnN2nw9zN/jAceWtSmeMWsBE+wuRxs
NvUp3FxN4C1o9CJlhId+nYxk1iEGkpEBKlpf6tC28GFPOPWnXOd9l5Zv+Asq
1yqGQyMYWDReHUvTy4WN5oT/OaqXE/frji1s6keqhnn8QVc63xUJUSIyPWBZ
TJ2OmyH4EtR53jGTC74V6TVTIwTLh+ZZu3/pQqfhC09/YQbigeVxqkXdWPHR
KHGQ6pEo6V0oudIHbdZdP/49DHyfPv7TzIiL6n/3N3D5GBwQ7ys2DE6EpX+D
sgb1M0kUsOwLs7FiWYDGeoqnKuZFTYXePYwWCTrk0Xr3mR+bezOUgTUNmmLl
VH/Z6v+I/eHEQ7HIiHvcIIOTkHfZrRcDK74tAzU0XlbJIOJocjpOyMyFBFL/
DP1+q5N7LQf5U0ejNj0ncBlp/MGkKgvKouvs4+l5iZ4xmaSpG4aqsebDqxg4
xhGD/uMFWJzu/XzzHIG2sqxeyJWXcDc7s30X7b/KNqWucVYReLMaazf8TnDb
RVzZ2KYQy7YpvWmg8ZfReMNjWzty1aKXZ9XQ/fPzFsXFsz3I+cpXcsiFwU3p
8DcGnwdx57TVUtYEg6qcQuvqB3nY55trI0zng2/4UoEu/024JGv/oEvrecE0
bakcG0BEj7quCNX7zLem2zMlg3D63jtBkPbzmfy6tmn1EiSSiw1j5wnGgsrv
p1a9wHvBSXvPKwSxHWoR67o6wNMT+nSPzttM53rXZ7waXAvTaNvlRuc5335B
UbgWh3uTjS9Qf5FeVhE5N1iNIttYsXOXCBTWrj4uf70X2jHpR9l/MJj3e6Ko
UliBFo/WM4/oedq7K30UE7qxw/cvc4kv9P4goVxwQKMdu/xUWnSp/635NFfy
sagV3XXxct7ldJ+uTqkJFuNC80pariP1O+7TneWlc834MGYrn5NFkL99lqXD
LoNbmUpLBJ0XNeeB6d38LdjrcvnDp0SCf0fOCX2z7IOohOLfxito/2eYoUMq
dP87e3IX6P5W6Svffs9mAApTT/rV3Si/h13fjs42QdOr40xwMN03CWnLxJu4
iMoZP/+khSDkVNXWbze6IDT1Nn9ClEGp0o1sPbcBPNi4yqR6mEHItFfxxg3t
WKkwO7K2lO73yNRdN0KKseSsnC9C8SkWR20SKurDRFzvAbYVvd+khbiMPkyG
nYCJQC3V9/8A9djSAw==
       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8Vv0fxoUGCmUkqaRCpVRKS11FyuMRyioyHiFKKKWBcpdkJSoSCRmJ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVWk8lWkfPpStYjAq2xRCmhaKCpXrKJUtYooWo4O8YxuhkWXkbQYtEkYd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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs8lGkUnoSEJNlVWZdcKmQrZCProVBrNymSS+6UsKUL5VLaSigJISuJ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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lWkbtp5pLKeQTA2TyvZN9ZWlheSSpaFo1KhkhJAiSyQJqYwiW4qU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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8le8bx09pkaaUJCNCNqUpHxUNohAhWSnzK0WRZEVJGZWEJGRlRCjZ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41dkbt9XkJiRky1LGEvnNSKU0PtJQYycMCr+0TIttJJMREUmUPUlI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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk4lVsbxgl9xVHJcMhMg3AaTAl1C5kjQxSiooxp0El1QlHIkRNCJMc5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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4VWsbxpHpRIM0ExWlVDgqc+7iEEVJSmWe6csYJdJR30nlkDgZOmkQ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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VH0bxj2UyhZCJKUoiiQqQl1aCEkIIYRUkqXV0yIJyRbSQkSixRIx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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41WkbFg2iJFu2hCZLskQ0tm7fULJkClOibNmZSCtfTKJSUjRCQiUj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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lfkexylRFCoZW2TKklHTpqYJH0kMpWRLcm0t3NFim8mWRENMdkkk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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lVkDNsO0cLNl7CZJZW2yJIM8pZRJjMrUYEiKIRHDSMrSF0KyZU2k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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2kgVG8fFRXtCCFJ4h+lLG0qHGSrLFmSLYlERIlkL5FSiuxaJKIsIVsl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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41lkfxiXRmLxTRL3qbWxJtkalVHIbS2GkCKk3EoVmLGXJ1mDsxBCy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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns01Okfx6dcklzayD1JHZeSaKVIvYktW6pZKnJXspS0LllFTLbaFW0u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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns4Vdkfxo1UTCV+jAqpZIxMF6mmQvOqMDGEiEiR+7iEEn4ohxq5k+qk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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4lQ0bpyiklJAXZSSVbNUr66clIatCGSEhRVaKtCShEpKIhKx6JSF7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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk41XkbxknEJDUSCjEibdSrQjHuOtkqSkgpkYycIZMcIcboSJS9srXw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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk41dkfxy1lSWnaMFRSsiVNVIPwblCJFNk1GXNJhlESJtRYRlGWskey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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk81VkfllBTaYw1E2FqEBqSJgmPxpooIxOVLL12QumNQlnKTiYikWTJ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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8Ve/bxU1JlJQhSRISZSqSipakDCGRJkL9VP4pIkRUoqKSqWRIJQkV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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81tkbNVoohNSQSUgZSxmjkinjJEIqRMSQ5Q3ZskyTSlFRkhiVkl32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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns8lOkfHXbb2qVyjy6oFKHcitalk1RWbBfRijCuu2UrRLSR3FatxKKY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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lVkYxxFpZaKalAmjUhG3VKPIL1OKUhNuUcoo2ZeyRZZCsmeukm2y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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4lf0bp9TbHshIpERC8hbR0AcpI2VlJSsjKbJSQkmRRGVUFCLrVETI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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs41VkbNRW5hZRy6QujiVLGyEHCikEm11SjDFK5flQ0I5ehGJcQpSgS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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41Wkbx8XblCwhkaXSlKIkhUL0RRmyNZahGTJkiyJKE2oQyZIIJUZJ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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk81dkbx29lJkl7MTUtaqQQSmpaJh/8pM1wa0gZZCxjSbaICVkqDArV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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lf0fxumREe1SSZRIqWRFZVySItIiFYqGkaysh0hmFDKSlZCMlhFC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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81VkbR6hIKEODUTeyjYzJkpAv2mw1qCZNluxaBlmiSEqytFqSoYwa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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk81Vkfx02W7hRZCq0TpUi25tGG8bFVKpXsyVzakK1LWSpT0qBk7GtG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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lWkbPl86kmVSEqEo31SjKEujQlfS6JgWS6LFRJYc+mT5+tFIjZQs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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk4VO0fxklFklTqVSmytSmSslW3JC32JbSQfWtBIUWWqLwtlGSJVJIs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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81VkYxsVMpJuYaVFRsiuRUiTTo1IjmghTEipLGQklVKgsg0p9MlEN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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk41dkfx1FRaNMyKiMik9JkptSthreLZJCliSGVvSlzRTU/ZV9qUEzJ
OjGSaKxFlqyjGxqyXhfXdtW93++XrFkGt3Sr37c/znOe83zO85z355zP+/U5
qi5ex92lJCQkEunxZb5oP1h64NdOfHIMLxk6QkFlt+w/4VFsPEopSI9XpeD2
x2N89B4Aw/plUeKK18g3ve7tE1QO37iDzQFMCtOc8cUktULs21B50SGQgl1V
er2V8zNo6HGPpQ2SGLylGvxZh425bMZD3+8pvNskitbzaUW41bkK8wQC0cbj
PzBL+Bgbz80/vodAJGujXYBrMzYXUllv40mctfYdX0524m2mtcjvAgEl/hWt
Cx7dOHh+hLicKITUXhu2uKwTXv6E0BcUOKbJFwOZTTB1nYb7Egoh9h2Ldyae
Q6Q6Z/h5mETP7HQJ/2Y7uBFtPzMTSbTI8hJ813Mgmx4Q+ViOxH1X3bOytW0w
S6Pm92QQ2KFiqzC/6iEevnF8OOFOQUypt1h4NGFf1ks7UQgJ7epXadmzHTDR
UiAf1Aih0fjfqxvMXpxM682960kg7Hzkt/rOHHTYMIZ27B3CroVtRjnzHMz3
mDew+ATmiqpemBxrwKxRWNBaCwoKE5Lb8LgWLyq+sxHvoWDSq2F0VdyBTQ1+
b7ZJk0i20ZqcCe9FVfNXC5IrCcQX811YvA4UMfW5pYcJGH50nWw8UwHzX1KF
PuoUXNoVVGPAwcIOrwrP2yRMLA/JsyOf4Wqr8Z7w3RTkRY1jMcsa4G4Qt1uh
nsQl++CciEEejn1VpRuTLYDOYecapn0zlFeppW7UpcAwUh88XVUHRm2OkSCX
gsxYxhLrOB5aLgZYuH1NQGL0VlbbbBLO6qcd+saRgnru2OUE3z68FOnM5FkL
8E4tOnlLbA4U7x1t6KTjMbf1ku/k14KyVggboPWp1F5xiHJ4hMj36Qxpewpa
w1MXJBv+hlv7NMvMlsI+RcWqDwM9YA+dnGtmkmDb/PWbYNk96OWOJhTT+4uN
d0qbhnVg0N8pVPMsiVOhGxs+WTbASQMfIltIvPo1U8D6joMTUU2Lgf0UzJm3
U1jiegQ26DGmpeh6nkvhOt8tgGKe80y3JgVDv/7nqyv78LhXZrnNBgGWfN8V
yrvOw/683PE7VkJY9Q+6xS/LQliK47qPdrTeNaultna1oaayI7feg8Kl7Q/n
GVubwJGM2p3TTiJGJqIgraQJI+s+76sMJKEY19YeZNqO+hl/5TPNBCoc/9EO
8uJgOE++KfQ5Aca/9dovMv9GpGipHfRpfcu6ShoPd8Gef2RkzIPECctWGYUb
jzCnFDVR7U+hJf3ehqj8VkTI6wau+3K/xN+JuSsykWRqMn3XmgJ7rLHF/SYP
l7utb4eGCSEe3poi2MvD77k7+l6EEGgMq3DYN9UEBrFgIfWIhBPjgKZfWyv0
NyXvLX5GYkeayr9ul6uhXn8tpnctherJ9tCwkAZMP+1YZ1JI4qqXwLsonQeu
/8q4IW8C2VNmsUtO1kBUqarZcZWC0plaps3zZ/h5Ln1rwSoKEhyIXYz5iF01
2itivQY7uFDdp7IaLceG5JREJDJn7QyqyguRvctDPiiEgr7qDPf98QzsN6xe
dHCm/Z1r7n/s1iXEqOQ9eUDn2/t1t6nct//iFuvhhgdltL+DlJ9GG7VivXmp
lcEBEhcuWBlOtbZB9ormR4VpAmZ+HocEhxsx+zYvMfEN7Y8ZzfkXSh04HzoQ
7WZJ4rfCO6HzXvdx9EcLjXn6vPXE0VNudjwM6GjHGs0JYTOyhtl7jANLQ6cM
vixdvzortUV3LmON9NoVBl/0TFf6sBz4sJ3SHtav4UPfd8WwOv8aijKNJ9zp
uKhV+MTMvxM+R8I79UwpFMaGuEQv8NH1/uTa8rIBJG1kpf+vYABLnRNKht1e
YyRJGB1j0wH3IObS/4JJJK7PcXfJ7EPyfFv/JmshnH4an9jvGovAKm5F8hn6
/Znv9PUSuPhhA7i31hM4JzlZXr4yC5fibVnSX/IRuOQucluQE3/fs1CKRGRW
7VNPVgXqEPwfw4bmtbhMqpSbj943PeetPClMeg/YK23pQUEa9eZdNu2//gzH
VLUsVESEymyn+bjE6/r9viuNiOk4vEk9g+bjx3Jnm9hGfLJl1tt8JiC24Pw0
5t+OLT0pRlOrSUwvtjtl+DUic8Q2yDWJgmLmNnbsrmKwtt2o9NOg1wI/zdb+
TiwsXbgeVyhEya1TuiWjHNyTvykj60IgYGrWwrWWi8DZ9euyJAiMWipJJKp2
oGw8I5XZRWGCYSjXH1OJ0aj01LN0fzD62ewKSmqR6PpPVEY0CeOg9AwXh6dw
/tW1XkD7101QsHbYm49MNnH+yQM+QtYZbB/WiYRmXqJuuxOFP6t2rZ468QTn
Ni8O7o+gcL77nduidzNu3u+W5bApBGQObzDY24SDH4o2Hn1NotQqYiDneSPa
5WpX2NN8U0412Bym3AC9Kd3vYs0p1CePhcyeboRV2fuce0kk+s8kR6y8wUe+
pHqzvpEAtZVOR5bu78Y2FVklTzuarwVVBtaruBg4J86PEAgRUvR1ZvWjCMxf
M2fGn/7Crw+Tsqpl8FdNuWSyk/b7p7w9WtEN2Fsq1cWsJJCfLHSbmX6B+W7n
pLEuAk5yn+L2ieugE26YuUSLwgMJnps2qx9vNZB0VUGAndLZdnUanaifSDj7
YyOBFsFolDVZjICDwjyzXyicOLQoPmXfjw/JdXKlxa+hH6LcLFeYgQkLPZ3n
lvR/wtibn2jYim8Yh6Kd5wgw3Xpdpd+1QLNdzVHtTwoWqX9MpBv14CdVHLxt
LgT1oKDkkWc/sk/t/PTDhAB/HuSlTu7vgdWKG3oWYwIElw32KYgbMPbj7cNj
inQ/Os5ZfVe+D6xV6i5aa+j+QrzsrZGog9QHtQKFIRIhbAvp7Ht12KgicWfq
CYlzzn8tFxt3QqZnk4zkUhLqLFkWa64Z5Xwe924BzedCR5VI5WKM8GyDY2je
mv5uOFWUz4b/ALXScoKEvlftN18deILw3pqPa3xo/hSemQ726EN1kKboNEsI
7+yEmxq/sRG+OfLVli4S/wdD8dLK
       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVWk8lWkfliJOZWqQJYnSiYoiRU1vVztJXhlRGFuIimSyhEqJscbEUShj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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VO8fxSU7lRAlW6IoW1JK6SAtdkm2VIoiSyW02FNKJW2SIqmkQrZk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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk41GsfxoeT5SBapKKy1cEb5eCUjLpJorQIZWkQGkcopo6otBwOLUp0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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41dkfxy0zo5QsLZYSNYqydM1QxtJbUmMpZOwRkZ1IQsuIFvk1hVEZ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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs0lekal9smhWYkKoWo5HShNJrkp9IUORgmkUQiEhU5llTjOqFSMqLk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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lf8bxmW1rUTJDEXJykjR1RQiktDSkFHZo1SKr4iMhpKUSlbTKKOM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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk8lGsbnnaKZEgpJSJSspQS1aUPHcophpNdNJEUWq1fURxCISJL2VJ2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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs81Gkbxkdaimz0InKsHErW6SVt4aImh6IsRS1ZNY7JqYRSEkqUEpoV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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk81dkbxy83GjTSJu1ESWkUTVT0yShpaBnlhrEvkSQ/kzWJtKksxUhK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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2cgVY0bp4QiUaneSkOyU+ovJH6RGRWykxVpqJAGSRKlQogykhJZ2bIy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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVns81NkbZlq3JLdySawkRG1KWf3E41JSuSxdXFaSdEGytElyrQxlk0pC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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41dkfx2+o24gWk1KDLJVlmgmRmHgzk3UqS0byy64myogouzuISaRF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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lWkbVlPjlCRlmRotlomRkbSZlAsj2YZIXyKSkIpkUnYJCWEkaw4O
ItnimDlZ+uyyc86xZESh52hSioYoM8wzf7y/94/3fZ77vq/7WmQd3C2clgsJ
CSXS5783I+uOmfQ8FyH5CSZflRHkuSqM8lP6UGzdPzUxR6Ag6S6x0NsNb4kx
OX4zwbEn8RomxgNY/aOatYe1ACUz4QW/irQhqXxTUEgKQe1ZN0O5/e1wzGnb
ksgi0DAYGHFKq0cHc6twhSdBY+SuG9+aNsLlotvJ4kACreDQjtXWXBxdrE7T
4hC0bzNaz9nNxR4z8c/mJQRmYhbvA7b1QirHZXr0DcErr0+SseK9WNTttD0w
SxC+p5hpntQE49iV/1tJ78tf9sbU50QP1mZPRQu3EAS5vHCQdcmCc1z6WLQ9
QWrcQNh04XPcbDktXZcmgLeTUt60Yy+CkT4R8RfByN5vey6z+mA382gdl9Yb
SdQuzWpmI2Sfg8/dc/S+kBCl0to6WGp06X32Jej666l/Ob8H5dwViiJ8Aqn4
In8+4SNyhcWhwXkCTrNujqczH2YcxcbyCQLHDhOTaPEhMJOFOsuSBEjrHbc/
E9WG/GytjZ5pBNstvlVyE+fi5VXXovulBF9sep7ojveicMtO+bkFit9IWMZ1
8XqsfiU8susKgVrB09gMX4pHsZ7/68cERfZG9cdIP3QsR1mDTgLkMlc7lRu1
giU/znkQQbAu9esNDpnD+KI9wXqQIYDRYAArcbIFnmPLZERiCWIV85bauSy8
03j3IoDiZfXU009Pqxwdf0vYZLgQ6GkxFi6FN2D5WgMbaw8Cpph2mFXRIMaS
KvJ2sgTYo6nHMM7lYVxOEPeQ8kU7nrucmdIFZSPpvYYFBEfLGPtL1PKgrCrM
7D5DkFxSveXtYT60g1myT3oJDrLuOcixm9DPskzYfp2e/5Ox22r1DcSMRH3U
PU35+JV4mP2XJpizraUCbhKoir+6WyDJxZu+w04aXIJhhVoui10F7RsVrwcv
Enxa//FnDb8ejDs19ewTEUCpTLOry6wZEtskepmRFD/7668v/ZiJlaYZroF0
3iA7lpqYdCA8I/9wBa0XFzN0c68mHw5fMopy2ATndFQNtop1IWbZTyd+pnhP
VeRKtfT3gRFy64zQDwL8LX/h8jHRDpy8Up+6xCRgN/acyvt+GNaWqeu5NgL4
HxF/r7ujGSemelamxxDM23gn/fCIi8ApjlR1I8G7nRq6s50t0F0I9dkXR2B/
IEFjf9hjRJ/fO2xM8TcRHZW25zxDSa3l1TtWAmy6W9h3pZ6P5qiJ4y8HCEpF
OWJpgf1IZeTssv1CEJCeEueiPgw7pumvj2YF6ApN0oo5yEWocuKxonoC/7gH
+XvYPChUjFUbjNB690Oyv46vR1b1gFUX5fe6Vp9WlYbHsC9c7ihJ8RT6KNrd
7toDjeDJXHeqT0ddcmLCvRci0q1/jdF6a0bf/lBsxwN//Ga/Lb3v3cUCK50P
peBtHm/RO0v3p3DVicXkw1NYpciafq9MTReZjunEhQAdiyo6/+XKWXNn7xpk
HTjSFE75pT7fxzcN5GHQxN3/CuXTqxX7E8IDWtAho/+yle7P0abwrn4/HyWR
eVLCkwQGQ8HsjONVsDMqUpVzo/VLK21zbtehv2J9LtubwJvhplbqNYTepzLu
l24JUPxd5RE7v5dYlObZeTUIoDwg+yDGKw+3y35xOONAwBqSe/bIPxOqfoWd
qZQfm/7UqVf5/AzxJUcYYccFUFOPvl/ry0bg78EfVJ2p/x3MLItu4GDL40/C
PnRf+cw5nnFcK5QSOldZJRLIFbh4WjD7sOtzvlqIogBE9NH0tCgbjFMjfE9H
AiW5oEN3JJ5irfKMV8EtAoiPSRc5tGHlZtuZew8p/tUmvftuNIK9SmZgMYTq
dbQu5XpBNjQfBI4S2l+WplX42mkeRBsv6l2nfLASU2TPcGtR7WUzlkbx3Gov
nqm1io+wrfNlm/9P+b6QayQ8GgvJiprWcMr30EGF+Wjnbsh4mM6+of7zjanz
IdEbPGxS3m1oNkX5Mj6747uPTVja/VVEJ61fvqXViaR1Is+jxm/H71TfT+Y4
2RrPoHWz6eeTM7Tf7Xs/75BqQ8N5s42DyQT3lxiaXn11mJtca6jhRRB148zD
0/UNiBuwkl+ier52tsNnmTkPr3JjZdd1Uf2rL1YxVtXArs8yI4L2r3T73h2D
+XIYVYo8jzhP7/c/6udzKBsX5Fqe3aPz1+7Q0Rf1qsFU5odPkjRvbCR8PRYf
1kKsNScl/BrBtivDPzY6NyB64PHHU9QPu6qGLQXRnaid3OD2SyqBS3zdi2zV
AgiOuRyapf4kc/HorqFH7dg5uY3vSucLjp147pXagzgPTnD7HzTfjLoU9N9X
InRWTJBG9aFcZfS+5P4zVERuPG4rIUCRIP6D9wkehksmzLPHCHo9np8yjx7C
q7qXSQ0PBXjLktsaENoLY31GmOQqAVQO10RMpjRgyMzQSt6P8m9ALyhd5zkO
Jj8J+aNTgCmVQ1NRF7rhn1Ikm0fzOuiXdY2OStUwCv9e0v0ygevZ9wqGO3g4
KWR0eU0dgeL7KBmPiedYKtjMFX1K/Sd0qX2Dfhdy1tvWrfxv/w9vul9SuILV
/0gX7aP7V5+OXB6fMQC97ff0p4wF6F345myKYil+FUuU7aD8fPH67VbwujEW
b94Zk0f550iiXuhw4GtRPnuU5qO/c1QPCprQWCGVK0/3ubmb03hAlAsDtzmv
liTaX2imZfoSD9fawgwXqH8IJa8IOuGQj5bE5tPfUL25BKjPDVL/mNm8c6dK
JQHD8svhf87VgbVtI0mieVe4eFcgv68eyYUevvo0H/QSmxP6q7pgcT2rNiGf
/q+yt6b8Vis6fzI0vkbzVMpfI2LNcQ5MlH8Tk6P6LM4s571tHIDwE71dZzQF
WMeeETac4kH/t6vMPzMpHr+3tEUEO8OtWMpHneLxTvKts9TGRqxJPp9xgdY7
55uXmC/DR/iDBik7mu8GAW6PC0W7oXn7nTWT4qktaeu5QTsKw/OnpBzp+X8B
twbHVw==
       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k8VG0bVtFGkSRKpUJaZN42W7mkksheWUJIklLqRVG28hZSSQoRRYuK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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81PkfxxHlzFkoGyrnjtCq1Na+KGG3IuXOFkKiMlEiyRGZJCGxHUon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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns8lOkbxlFRW6kUsUjaVoeRHHJI1sVSIacsEol1WNVatKRkd6lIVNY6
7K4th1osQxQ5lAjNOAzGYcwMqWHe9yUUkiIkv/f3x/N5/nqez/1c3/u+rkfd
J9jJX0pCQuJPev1/N0q5fmSFbwfkTmqphpwksc80UIfhxYfFz0oZdipiHDKW
HB7p7sVztn232i0SZswpxZtmT5HcWKxsZ0zBIMv8VO2QACKVUrbLPhISPerh
cqU9kFadEO+9T0BPq23nbV0ukjiOzBKJIdS6ppmcrWqAhdr3PokfSYS5q9re
VK9Dg26Em7whhb87N0c06PKguz9p6HW8GDnWLyzJvEakCg7aXjclYRP+qjNT
+zmO2ljIfAwcRJLbUHKdBQv+aya8xp1JFPk+PP/dXyFwNzQK0PCiYKacaLlr
lglWdof9uDmFC9Gapcd+b4FBt0ugIkUgZKNVmt05DgQCXZ+l6yR4Zg+qLlu3
o9JOe6BGisJ0RYbbN8MCmGx5o/P3BIGRpILEFhkuKr4aCt90goRj+jbdZs8/
oZ4oG5waQGHbEW1OW6MAJ42iU6MiCByyPrtRRrkB73x81wVEUggx3Ri3y6wJ
Fe7zuzVWUNgdldUg7cTC/SjNzydGSGQufat3VtyJqiesRxapBG60LFtIlWhB
ZP1cwcwLElbtYwo/3+HBPfSEfdk6Aick98g4aDVD3SgxPGMDBZVSJZfl4xwc
8NyxetcDEjeq1/+olMxHrt+Kmj39BFKzQqSnU6qRk6x1PeYoBaPrXXd33umH
9GLCdO6dQbgq6Up0zPTio93SKdctBNwa5cuZmUIwOiSda5tFYC1mK/7+bQ1y
zmy4lG1BoTi9ToJ3jYnZLX9c+M2ZQtU+F4Xq4hZcG/X7dXILiVM75jMYDUKE
viupKdpLoH9VV+u1oW5czljeUSxB65V2zNJCvw5u0g/yGS4U1ucWuLJGOjEf
kJ1+N4XCiPzhL7OGOVjqnn/UW0iidFR5OMqS1qdDKfHtDIH8al/DtsJHuHtw
xtKNQcE42GajqIINjdaZ9li6vrCq8qxjPzaiM0QYPSlJ4epY/LoDsWzYKsd4
+ghJNMtdlst82Y6GeM9KVTaJ+J/8DGMquZgZm0pgf0X3o0jrX53GFjCEQwpZ
50hozt4baynpgmJXoeuzXwgQ8htNVKL4EM49kpk2J/B4WYHv583PYWJV2h3n
P4imewViq7he3Cl3HnuaK0ZXRAFneTAXCedtQoa8SRw6er55ezwbw6HWOU4J
FPzSl7UEP+iH0RS3VLhdhNq0L2zjHBphLopTlqR5BU68v+n2pA7Hp2JVw7tJ
sPa8Hf0nngMWMbNka0Xzdl+9LrtsACNsfkvCAIXGTQeXdDh8VI8ZeLwWiOHY
tMY0/TULHN5lYWYHCdPKw8tLB4QQen1nkx4pxhs/e9Nllf1Q0N+gkhgqgiFT
ukTLqwsVopJlJRdJjImuXbaL4eFji955P1kCfrGTi2tO10Hmm8RVs7T+2qLS
yRv+rah4KiXOySExpKjAl5wX4kOYBxXnQmCwMKBh3/IniKvv5bLek8h/mpHg
JdWP4JtBHlGXRLB3j/FnjAugMzXeb/1YDJMF+2g5zWwcFF6oKvWg7x9fqz+f
04bi6t1njh2nQNBPTNEQghX21vdDConfzbZ5btDi4Q5LfdX0S5qPYfV27/pu
aAdcNSnLJSF7hWF2a1ML+tOTh2saSRgJvsx1aa6BLEN3mfwlul9ytNIkG7gI
SNlqdjychG37rx9HzXiQeFbfl6VBIWZt3KuSS31QvJDmUFs2iI+DTRYHTgsQ
1OwQNrxHjNenvuYcfdKMIL75hF4NBZPGq3flyzuwVzg90EfrF3LV9gbGO1Gn
Ene6bFiMonc7C8Nz61Cz/ADjmTuF6KRni4vOD7HtdnvXoh09D80ejaflW5H+
bXmJgh6J3oljbxI4zSiO/ENh830SbwJTsHpHGUwSdvUk0ed3RjJiz6hXYNxO
yekHmofr21YpYyMhRvWYj1LkxPB2UFBb41MEopVreJv2qzPOL40XjPi4dDzZ
yVKb9rNX+24zl3pwt4eREqpGIC80MvO3VV14wcnVvqZGIX9OFN5bVIOIHl/n
hVoS/LXeIvnXXHx2HJk4bEXXC81q66hs9DOHi+1pP5AwNvkc+p4L44Sj6beO
ETBLctrBWGrHVm1O419GJOYMJHTCdHogareqzNtD+1HukqxN7X8QMD1y9d0o
2E9+8hULROgL8qkROVC4lSE7mtzUjUNF7p3jR0hol8vI3525hzUamvoN+hTm
H+xwKazPg0ih/9NhJ7pf9BYym2t46GIb3rPcQKKzyG0hgidAskdF0tfWBN7I
XkxsO8+GSbRyu/40iRNeVhbetZWQS7QxNTeg86P7huJJ5RiEG4yfsviewqYL
ztoVXQI423N6bYwH8aLezNxxLxtVRcO7Ky9Q+KdvhLVdugUxMT/NEiIStwSF
H96Z8iGdMh/4iw2BoCPMRW8lNhx3j6vIepJYyPdwV/2JDTE373mmJe030WGB
M+VsDBrOXHn9hMTjLfYOek09CFo9Yr91jkDGqFp8KJPOx3OrXOXper5nfoo8
vakL4/WGMfwQMSY2T/L2X2TjJGfvQ2XNIUQP854FXS3GDxMdG3JpHnkD67a6
FPGQ6W6ZLNwvRup3iypa8iVY468cFxBOQdM/jZGi3ok23z4dHj1cn1Rt3XOu
8XE1eLZXZnoQIZI93Pb9PNg7yk/axVD4U2C/8q+Fh/h84KTmKm96GBcdorOk
euEZ+Vu4xXECZWNr1bYI2iGXIcjn0/lk4pI/2/z2GfK1WVkjp+n86App71vk
411H+HCwpRgrI7faRnUWotvKyUiJ5t+u9NT6SuwjHLzMbPWMonmsfX7RIONf
3JjS+bDah8LTpvWb3Fs7Ma3dEfbfKxJbS2y/KHx/H87yLbtibSjUPi7etv44
G17NwqF/p0jUhvucF7r2QuCkQGmcIbBv6ezeFXNc2FgOxPvQ+aO50u2XBwUc
fMqoOyV+SP9n9IkVoesqwU2fW3FPl4L3OW8FCWEnXp5RFW77m84nOTtu23g9
LqqutBLkkXhfe/DTz3ICSKVEkIc7CfwP+xnFlA==
       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk81ekXvpkSbZaIaUVlSXGRaiQPWvj4kZCikCxDJkWpRCLrCJHBtFCK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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2kgVA0XxylKUSlLJUVFScqaNvpnKZGiHknITipL1oQ2ochOUXkiyRYi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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk4VfkfxymPbcygQdRkTIMxyNK0mGjeKpRUSOqWGXv1oC6RbIVKWcqS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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk81Pkfx2crraMUUSNqHeVqW52OqFdp0zWErCKVI/1mWzasxlXIulIS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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lekbPsSYmqOMiUxMWcsMZUnSoFsLZRiZBoWRLWUsIUumBWGUbKfI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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k4VG8fRkhlS9ImJEoiUslWd1pU/zZJQpJ2ImSrUJZISZKtkiSRJUT2
NcvQ2IcZ+zozZ8aaVESS3vN+Oh/O9VznOb97/a276GB0hY+Hh8eSl4fn/895
PbU2VlIVoik7uKedCHR88zNc0tKN6SzTZ39/sRF67sBPv9xsSC2zD8xXJPDQ
aLtWinciHDWkj5zQIED7FvRkU0og4g8nfDh4lkCRWDP1o3sXpHZ7ZB2JYYHg
r6y/MUuDz4rCM/9ECWRImkfL5eej/qOM78geAiGLVZ7WjbVDPuLAorW/CVjZ
7n6Vo1aCdWU2A+wOAp6Xx369ca/G3BlNVRPyfmVVX61oV9vAyngU1uXJhUX4
dHhYLw2Cy1zdCzZzsSH89vmWHBoCLCu0tZs40DuqcN+3pxapvNOlfeR99/Ks
iyREWvDfzUht+vIhWB16vHeNYSOeqPzgu+XJgtVXfybBX4Pg5j/3KILk/79S
CLZay4Abncc6QJq8j5DIrsM5reA/tOjU8x1cWPs8jf4zkQmeUGcfrhIBa7Uv
/LMFn/Fe3s75NS8BJdWdY1vFKzB3MkvyWh+B7aybezPTOnFOoK7H35+FhYuG
n7bVtSH04Fw6sY5ARUSXeZA5Hb8FmZ8mZNlQ6nrmxSuUC/6tV8tKXAjEZsf5
trzswG51pfo/1lxMyA+E7GmnI7o2s8A5iJyP6IYMh3MfcVty9lWZFIGlvqN9
M1cbMFcd2DNNYyOvqvzu6uw4uB3bQDF4SCBaeiN/0JI67MtQy9sYz0Q4T6Lx
KoUmcGuqapLyCOjwTa5fvZWOVSH9C4R02aDVdufo9bYjOuuAU4ImE3uiaQqF
ubVo+6qqs+YXgb5NzYGG78pxQH1TmuBRAuJWX1dE7UuAfHRlUegpAjIxEYE/
JlvRq2Ou2nZ9GEL5TU3tAzXQuuQXJnuDi6BLgaFaIX1Y32DweLN8D2gloZu5
nn043v4nOE+HieLtBZZD5l+gr7x+wdg3Aipv1IKa3jXilM22sgYQmFSxdRW3
rMIGHZd9/a0EWHZqKvM2dFxoWGLpcmQQiY2P+PpzGTBeIBn2c5aLnuruEz/q
itClZGuyUI6A5FyOx4vFdAzd1178y4UFytvzF7239SIyV8Mlvpfkk1Kt7bHR
Zly9o/WnIpINlqJh+snZHgjnmM2L8QxDPS+5RIfaitSlTTsSbrFA9alc5CrT
gfi39qfcuCMoznO87yhCRbb3owbrMAKUeJkv11md6DPOyzfbxkFszkWKw+cW
BBrmGalnsvGzw+2B29Y2mL5xDkoVG4aFlNPBRdGdsLe1tXAc4yK+KI4beJyC
ahW/R3HHCMgpT4hJbo7Cbc8O4qsNAe6HzzttrlSgdkdysJIKG0In7UV5Ftah
y7531nAlB46pR+z3lVdALqRfpOIWBxlWZc+dDzTgP2q+aaQHASH58VzvvgZo
9FDCFc8w4f1S18VEmAa7nZIGn6IGsTxFd3U+ux0mb/QPPlUn8EtES4dXj4Yg
p7LmTSTePBI1qneu22D/2LWQrHME3A/0Vlb/pkPsiteCaGYPhAREZuuJcnTR
QyQEP7GRUfJ43cLNbzHF8uCnk34yHlWmcUaVgXynLMbsFAem3USML18RGB+Z
Y2YhBNJVJl0dOyuhplpQp07yQejbsFkdUYuSgHwf/VoOJhIEFr+4VQvDoLVu
skvZqJfN/vvqbg94hYeDWy4OwHYvo1sjkoouftHeqyos6EUdV2q/EI8U3V3J
/JqkX73qYn7OTYJczNSFZD+SH8bx4REGNGhEqhjoK7NB/Te+pqWoEfu46XIX
qVw42Guw3QZbscgD3nmMQVDYv7tCrn0Ar/8nVekAAvGBiqsUUwqQ6bZ2149u
Ns48+FD5r7sGJmu8jnidYsOA4XKtcpwKrVBdygYLDuS6xM79i27AjqDmXQfV
WJjXTNh6yJ4C873WMtZLSbwWnG1dkpCKYq9h5ksHAhMRjObjB2oR5P/fGYoa
G5OjQ76rl1GQcOrLyZh2NgQlNwmNiKTC1EPn9wSJx3Ss+iubrZ0IuXO+8ahN
N+wGvg975fTArfeU7Y2wLvBFhT48qd+OBTpPaOZuXHjbrxz/eMALNHbNHf4L
BHzmLRxFNDpxlI8rJpU5BFu766OdT3tgoPzthPLhYXTzlvoImLbBo6Wqe0UM
E7R9l242v/0MUUuFGwE2HLA81HwPKDVCRnWh8mpzko85huueb3sPf9lEE5/d
BPSCDk62BNNRX1UUoR5NznvymmaIfiYksxIO53aycajkQPOOtBQIjlCHUu8R
+HKBkpPS1IXlCpWv17GYyL/JFBZckIOA2eJNp/cRsDj4gL2Z2oInwit3sZ6z
ST7ZWF141wzW7uGDDF82rAaNggNbM/HFTaJ45i2B/QYpIv9ONGH2W0d1Jul/
9apeog7NRbgQeOSAXikbYQO1p9a/YmB5zSfXhduZKKzuvD71sh3/2er3PWMw
4b6TpfLtdSvKUi9snSwZhNV+2bE6cTrqdE1ED/IPIp/78lj48xqUWm/eIH6D
jbIoaqi3Shlu9yx4l7SKQEphfkznHSocZTveHtrHwrhCvBbjZRgomsZ2HaS+
/BWJ9ABqLZwSdlSHSbDxAjvvLAvvQIQDzWAd6VeGv09vuO/vjci4x7wzJN48
RL3m/qd2ePeytjLZkoCqnORVtgIdXWWB5gWyg6BuHJpXXklDyZ9upoz8AAxz
ww9GyRQgx7qkm5VI4uEwcP5gRBWSljvahsyz8fSsSmVKcyUoDDlGVT4Lh4if
cbSVzXC0Gn45GseE5L8bN+bn6ajiGEt/5yH1z5V5oP+zGbMS3eXT4ixkzJwb
E3lGRYhG8GuL+xwMRegvTFCjg5J2bK+mBXl+3emCJrUG2DwtFLjNYkH9jc4i
S8dgzCfARP88AWM7l44rIS2Ipd1T1EkdRKPXs7czf+gg/qSqy8yw8CDasFbW
iA6L9w4NsRaD4OHrnipXj8OsefPIVUcC0ukDArVeNFhH3RfxN+HA7io726Gh
Gk7D7yjGawn47ZUKqy2sRuTTwbWM8yQ/n6TZNwQ2Q4vFjY4yZEPuYNSnkNB0
PDvhs7rBmewHTzYnfa7ohsKFz0sUn7VDorHGOa26D8KLXE9rm4/gsgCspyPL
cf7wzR4Rkt9XphTHm5RbkH349D2BKDYYu9Y8/rWvCBKjG+/nk/iY7jjcJKrb
i+1W8m9WTAzidp5vR+XvCkx8vFpRs4bA7FKl4ayPLXhpdulviRcBuyVvXFkr
mjETp/jIkPRvbtyMNVOnBFJSWjnGGzighR7PUbDoxsSFuBvP14yg0MOTVeTW
jCJx3UBpMi/K7y+Kcj0Wj9GjMt95yPM0On9wz7Ec2ITTxT9dJiBYdMwzlHxv
qC+xPt+f9Ju8oyGSz0shck/K/IcpgdoRu8ENKlmo1uuQ30/O4/cLY4dJGg0G
9fvad2eTfSrix82K673YIu3cekBrBDMKIhFfgprwV3me182DDT5ZalnJNRpu
h5j/DPYcxITBuRmxZ+/he+dU1SDp9wxxgbA5VRq251+6+2WCi7bOggtmldlY
/yk55tdzAsIvgr3dbTqwbGRA/J5QD47G2PpVuhdCI96weO8i0s9t70+bX29D
7WaNx8LrBxEjdHrJeCkdsxZbjTlXOVgpHpw5pdaEu+9i24uiWdDN279n29dK
/H6g/WCNIxvePKcU4mjB2HNOuOUcOS+eE13p+alkXlwJ671E6rWrvFHRR6kV
i10XrTtzl42QD1krTOSomCrN+DLqx8X5upR/2vFt2Ej0ygbacFHm/UKvatUt
lKYzAypIPi8LUp5Kz+pGn8BFmnQaB0oxg/xn2F/Al+zipB7MRrVPYpyPDgVy
+l1jFJKvsVJrsrtPP0KuS2aSkRV5H7PSbWPCefAOy/Rg+hI48bvU9Pc3OhYd
lNCZUmUjP/khdbF1AQrfW1dRPNkw1KmYWpHYhU1blhfUdhJYyWfH8tMvRIuX
udGFHLJP/Pg++fdzG65kf1aOsx2CzPbZnJDPdJivXduzJo2NqOM66t+3UBCj
Kynq9oSAm5O+XCAfHbEF31wMyT4wwaB7ySUm457s8RNNVwlUQ+/+ZC0DswKH
s/kUORC9Q2Gt3t8K/Sjtu2eVB7GtrPsupaAVW0ZnthVmsaGzmGnIfEL6yceK
FC6JT93JdzMJYEDzaIR2q+kQZqaXj3zrKIKFUXuBezKBF51LT5Q8L0aHi0Ab
k0XOX5CaPKf+AdInQ2N2qJHziY0calN6gNailGcBFgTC/vgtenfnE+QFg/7u
KyKgvN1eb58SHZOhvG+bJvshHu3QyJHOR+3Gq8NBEgTWHqJdck2ph/Lc0gyZ
ajb8jm06U8QuRpTVD/u+YgIzQnK0INp7XD7sf6ua1IsWTVj2Yk492B67jV+K
E8h9EJivPM1AcvPoo/69LPA8vDSMNgvEZxTVbiLxN12ppmkRnY24X8E0ObLv
G04VH6upy4NLYkuqijaBBZwQhdFrrVhq9qBOc3UvPKY1QvZYtoD1oN/MI2AQ
qoJBnZ5/OnHFs1Q4Zrwf75dZxJzZ2o7a8qGxQ1uGoHF4Vcm1H104uuVYt/sh
Ni5tez9FW5uNXZVd/PnT5LzDH/KNVLdind2hxj+v2LCb3CBW+rcMojtLPkae
JPUjus1yOqgIV9ZOtj8m/9faWcyoSqoKFkxF85/HOGjTyDm9y4OOX5qyfoNU
JuJbrv1Wqa5D+ppDZxyXkPoa67OXmizBCA8jq5fUq9wdhpcYP+lnx5VXRnoT
aKNK7xR9SkdvypHN+XMszKifXlgyVAAxreCNvlMkPw/9uvbxXxai7o/vUpYn
MDSfaXb3WRWKGzSXXRYj9wHdvGbP/Eb4GQ14mZP7q5y+lcXtte14/WNq/05d
FgZUz9bt+9IA68/ubxaMknkUoLPsg1cLHtg2v9YQZkNTOak8qbkY6Q1R/L0S
HJhzyw38F7dg9+stp95yuNjOq5w771mA3yIWrrPhbDj5UT9VnW9DvtnHhMEW
Jiyi9zTb1pWBdmuV+dhuDqJffPqeLtKDc2c/y4WPMLG7cGGXz/ZWGH/wvyG/
mey3azd9+7ixGP3Kr6Z+vmbjtGiLpe+aalhIe30IPU1gNzvSZP5aPOaX9S/l
NyHgvNXXwWhJBTYpXxFYH0fgUI5ns0YC2Rf076WJjrEwl8jd2y/XgP2RC/ry
htlIeu/67jGlBDfWTSckGBDYIyCnXHH/M24piOaWCBDIT8pw8vjahvrlx/+Y
63FwttLX+vnObtjvkBo6290PSubZc9d4GViZUOV6ae8gYm+dWH3ZKhFHv+Ye
OKtLfj/y8ZclMm1wKH+dYe3FBo+bAU3fPgkPfX7e2HeTwKtbsXb978thd3vs
xZoUAsv1NDYkF3SAN6jwWa0hF+MfTJNKQ6tAWS6mv0KAA63X6U9i2xtAXRBP
l3hM9oO0CYvmLDqKf9+U3viBhfTUOKYFTytULnYSee6DECo4PL2pPAtWPwe2
h5J8uJisyJOxpRPybXeumpJ+9+Kdds71J1UwqO1cn/qOgOXHCwJzwQysurF1
j3omEz8899sHZXRAQm1cfan8IAS12wRc95SRuZEWTCX9VvpSh7rhaB3cuwYK
HUi/flH4tyRrVw8CbvuwTXnYiHT9Jy13ugs89r8CrMm8HtkQe6PdnIHWWs+S
/hA24ncID0nYv8EY75yl1CUS7+Va1+0M6ZCQ9NTsax9EB+c4zzuvKlSuYVQK
bGNBeMRqv7NqBk7Grrx1o4DMA9ttlBXjNDD+XcvfWMPEzGwDT/ClarTevaL6
7w0BB3VJ0SwSb8qgw+avZF/RemYrZLi5EXoaQpKji8nzvz0y/4m3QdLo+KNb
gQScdmUN5ye1wiLc9FbWUzb23LEdZp9qAsU16Z7NGyaG9Ptr/5ukYOFQhMHC
YAIu381Ltfx6UJpw/MKHbFJ/ilqerxVaUbrU5Aj3JxfiAWFdJza3486BW+f1
RHvgnqN78uulFMT5rMyzJPel1Q/npeflK7GCOhfYqkNAM7Kw6GPEF2Sf2H7G
XJqDsp1bH1sHx2L+/SjXxIiAgkR69NXOGrhLLzPRdWZhz9OvBeZlOTj60OTz
UmMC98r87Bw39qBY2OiKciEXcswXRc5bGFBMyx6o+sOC9JxsbZ5pC2rqu/qy
yH2W8Wd400Opduy1epbvJDAIvwU1bU69tUgmHjY6P+JAXOGJv28ABXrsrxbD
4uR+8V3b+p0puc/Ezq00iOpF0y6++QNWeThZN+r8nbxvsZTx/kTjDigGCHGF
nvZBvKqu7v71LLy82bQ2kew/KqemmVr+NEjWnGkPJvUhdD3+Sa1TP27uN0Pf
yVY8DJt3n7mehw2Z1e27Sf32bNqYYi6QhiDLwks5YQTKVo5pGT+vR8/fkVNm
1qReO4dC3DtLMN7DcDV7QPrv63Ou8p1F8LVeV//1Gnl+if9z+dd0HJdYb2vT
yYE3zeDIe/NEiKVOH/lC4idjt9glQKUTdeeUJtYN9yO4/y5N26wcypqihQkk
f24uStBNupyKtx8MzATMyLx22ZzRsoSB/y7e1vZuZUJC3k7HldQLRUVCKayQ
je3r3yjfi2iBbppgnn4yB/FdX35ZnWpHamZn9aehIThbTvWMmtPxgBrLaahn
kXvy6fqFTVRkeITTKnaTefLt6GXr6+VoDMiOOOTKQVXEoo9CvQwU8Bq9ncvk
okj4QX5RaCteCkoZGOUOQq6O11o/oAbj6UVbsmQ5GPhe5EVt84fKvrYiLtl3
Mpr2OtGEKQheXdxJrSH7ruCht2MF5cgEpUtziOR3oHsBzyAdcpM/Gr5HcwGX
tXoRHj1I0D5z+ymZh0edSuhpW2kYEmkIuapI8nXnKt7EPzSMj8i+LCtjY6l2
vkhieg0sfP/9cLrDRqyI4IW0o/HgNm8IfO9KICJt//EdqmR+cL5TDpP7wf5X
xb2URjqCFud9+h7BBMN+o5BlQhd2KhpTFXLJPNuhrnT8Yjk8GesTWWcIOGr8
suWpaECuz1iEM7lfpT9P3x1xog0DORNc+wCyvwk9Tu+R6YKT0+J3fEJkfzHP
MEuJiwGfW0WHJNlf3iiEG1DVyxE4OG9fWs5Ghm+A9mxiK2LfeIRxyX33f7V3
H5U=
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81VkYxm8oKklNU8pVlrIkjZSGyKNGRZmrmlJhbKkoS0mWJDL2EI1Q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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk4lekbJqJsiRCVtWUSOq4UJW4mhJAUbaOyNNkqMxRajLVB6TeDZF8S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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXlYjekbTtPQzAg/GhOpTiJZCmkh6S5r09CmfZMWklRDizYl2lSMUSkt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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k8VA0bRZJEIcRbIluIqFSUnJRKwpslyVbJ/maJbFEmKkuSJVIoJZWt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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lWkbx+1DvEIabWPfU2mqScivsaaOBlNIoRBGmyxDykihTZPRRiJL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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns4lOkbHjqQQw7ppMkKoZRDibal25ZQUtLJKSKhAyFFq50Qaqm2iJCK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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lWkbPlOjRWWylRMRsmSJdiWuFpMoUjGRSLJVpEUoCkVRQlkrCsUg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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3cg1e8fxRWJklRGkVlGm4zQOMgqlCKpyOxbaZCUkUqShGS1kJmyt5It
rpF9Xa6VdT/3XjJSRkrj9/n99fz3+TzP+znPOa8jbe98/NxSDg6Os0s4OP6/
Gk79+1VHKcDCxb8OQoEEMupkPUyJTkzPCkktaWbDPOW9iGxsK67siyw49XUE
W7ka1+qdaYBvslegBZOJseKTKzmo/WiZr/6g9B8NerL5TntkG5Ab6v75Cp2B
gkkuona4DXlzGuNfTrORcrUvpaGhCY/9ReU29Qyj0jp7s5F8H6Lt9Jw0lUZg
p3Uj3DC9EMrvP4b6iRGodJG32fcoCX4X3w0WuBKIvGP3pXdzIdjJ0v51TgRq
Ng5sdrpZjfibWzrNogkY6Wdk0JtpUPHpnpky/wLBPhFCKKQZvuf4mg6KsGAz
38/KCaPj0XedY0MBw1Dmld+TmF+O+5GG2jkcTHCYBX3Fyqe4Gjsne8uKwKh7
82qxD1WQyDYI5uVkYpb/Znn1xW60t7Ey7tSyYKRj7eyrnIH8o0f93+cQaF5r
cmVGqxHv3plnT0cwkXI2oCWsiAaZqdCbb8HEer/J7GcbemDrK2Q9fqoLiq4V
66JTaPDum9Sfqh4Ch/KKIAn9Ptw7rftgOpUNSy8tBWvuPuRvWSNitIMBNYXe
H6f4PmNS7JG7XxoToRoPE4WtUvA4Of49bwiB6eBFt/0/q+H627+ksIUAYREf
pdZcC7nFl697rBig/Xfbx8mNjh7brff1GP14xVYZKqd1ojVJ5o1EJQFdk3rb
MnI/ltqi24xzx/BXk3pZ6FQ3KmO4T2d864LIumt3Smc6UMv7tmti+QgqjX75
CBT6Ik5D+nKfNYE28ZMtS1aH4oW2LnPDeQJDZ8fPVs4lwnunhAvzHIFyXNJY
p/gZ4UmO513Cx2Chv8tBxKwNQWmGRc0OLEhpti2Ic1PQIKwmUabKwNJ/nxV+
cXaC4fqI69zECK7zCg19P0bF85FIUw0mC6tClZ2d9vViefn5uKZsBnwG0uM/
JPQiV9zfzjhoDDT5q8l+1Xko9Q8jvm4kIGje5cnjW42/XmvvJomzkCv2Wfff
VSqCl3288aeLCcceG7kR4yZoeZixXeaG8VrKsp9XuhXzq5WajITI++H4NHFV
dx3uddfTd9kQ8GDreo2uqYdhmvcuwyfk/OX6cUmmANsczzh5LxK44Fe1yj6q
A50HS8pULjJgyv7t2be1BTrvwhI4vxNYWM5w5B6OgJVcrrAJOZ8iTvFbC7ep
6MeGgZGxYdy0DzflH+pGl68IEDYC/1bv+bL5DqRftTCRXMbCgv+iaugdChQO
2z25zGChctElulTaGweCn556TOq3X/OJR79OD0R3vHiW9YIBqa4+qH+Ngif3
/KKwPYGpLYVe1UfaIfzVceO5I6RerdkW+rkt5L6u3dptwoDMl/osl21ULNWw
GtdsZCJ+/7I7WUaNuKx9OLXpIgHbfLljksFhuPZgT5OGBYGHUgEjYtPdcH7b
GTtm0YmF2v0R1QqdiDn2Y5D+gImQ4w1O7mvboUDlSN2fTCB4hZ+941wuTBtv
vGgzJlC8OJMskVyNha7gZRQVAmflm3V1rlVirdHd6eAWBnL+5isbTtPBvb/L
qaRnBPt+B60Wta+FgM8RRR4dBrSqLF7NBkfBdAWfsKczAZcud/aWb524vIzF
3uBGwL/H6Oc9Kg11GipHLJTGICqldTKEswc+nW2zWcWj6DYQUzgf8gnX0vni
uTgZKAqNKNtcFQ9xmcP/Iq4S2HfAoFVCtxJ/3p5fqH5MYH1mxbwptRTFuxsl
bV4SkA1MMjnwoBOs4vdGv48SCPiYdFHidCrsdnxRFrpLIJ7xQ3KvchlCm0RT
i+cZ2Oy2rKnJ9hPSVsrbvr/CBH//+R25eR3YrN9pyCLvn2NnHqc7Ty8KFM6n
qpDn3jgcw5Dte41O9zjbQlJ/ArZvnYU4BpD6JL04UWsIKVuPqOzXKESlrVVQ
+AMC8/wPR1s8WmD1vGZKYhWBwk8HJsJT29HGIRWne3IEKXpV0eIHChF8WNwt
dwuBgiB7C7uwj/B4fulw+mUCjl53TxxXrURBQ7B3zx4mLF8e+6Kg/wbLPFPc
h4rIeZb12Bn4URHdntX8qp+J7fOy7G3ryqEvWZ4Z4kfqq5lr5zX+LoTs1GJ8
Vx+CbXek57+fb3DjrpegwQ8GKkWX94c9eozepG+n3jkQaBoXF8u/UwxWyd+p
36Tfb9PdF2iwsh+By50Kc+lsFDxae//BORoqRg57Xt/LBi0r6CmtsgcfE6bW
Z6iw4WMv8OTV7ka4WSj8qD3ORgMlJTT1Iw1v9HcO65t+wdluiaP+5+oQsE3g
assyJnSE9uUYd3fgcevSW4mHmdgpE62YpErFQOngl6yYYQjWNJZuzKqCWMBg
SkoBqb8mQwED0QpI9R/btpzMt88aHp6Zl+mQ0zvCb9xPx4FJA5Us3Vawihrp
b54yEMpT5OqR0wRNTxtnBQoTWb2NVzz7GrD1VWV9+wITVuvf9/1KbkfWrHxZ
hCGBL4I0b6mILgTIRNg8sxqAKX2tkqtBHqo9e3b8liKQ2C7TJvauFmlFaR44
x8BNdcPwkgQKDg3otRYKMKH105kzVf4tahpvfti5m9Sjg4f24f01+PE4u3v1
LyZ4smRfSO6uw0rTPn2n+BFwEfEcayQpWH2CkTnTNQzTdOP5bTa5KG1SPWi2
jszf5YFKk159sJJ/KPrg8BBmXixbGP9FQZrkQF3EQ9K/+NcLXR+twjvaqIbY
dXL/bWeDDFdUgWPWdcqZzJPpc7/sbwq+wYoce76sp+T3bOWafr6mYcO9vRMV
VsOIddr7JsGuH1MnfOmDMl/A0zv8tetGO5bENNw+5z6CIcUdNe4iaUiVpffe
MCKwoXyghHG2BYF3pe+qk3n659XLTdtnmjFyeS2Fv4CAeuMzNp9xNmoP3k0c
DiCQGi2uGZzWgVBmhUyQPAtdj0v4lfjyYcgjnfNXhsD2bnaSSEQv2KPCZT1P
mDgss4uX/zsVjuXDOS6JIwgti/Ws35CFls1yzneECdS7n7h86Gwrdkpcoy5J
ZmBis9r33vOVSKI/UL1M3s/8xt7rn7JoSAmeDHH4PQrFoxxvi+IaEXwhP5Vw
ZMFYrXhMmmhD2K1V946sHMbpWJEx19pOvEjmfl1I+n+MzV2bAkohMm5bPbI5
RKD0e6jQ8S80CLLGfyZsItBNk1zDku7Fnrdr6oxcmKjxm8mu7WyEOW0nTVGE
CQ11XtfyzV0wnTkiSF01Bpc0kVc1FfGIz2fzriTfs5kI5b3rii48J+L1Qzm/
gB3BpeLTQ+rBUD/g5gATvtJ1+qWen/CMh/WogcyzwJ3Lvf5mdIBTXXTDVlsW
mrbkqpsotOH7jKLRNUUGAtso06eqOzCvuqTYcpp8P39zrrQadcDh/vIlx0pI
ffxeK5i8qg+ndZk92iQvBJidOWlOaYcv76Ax8Zzkkakxz8HFdvgLNhdvyB3G
QmDYK649veCNyJW+YT0C9SvPPDJ9qEiJnfD1O0Xmlyoj1X1vE4Yu/yoaEGfD
PdzrO2dCJeIfDFjZ7SFgmOy//PdINRY9H3J01IyAlXg5Zlt8FfgKNSJlokg9
ZpZYGfq+x/XavN0MfVIvqiMcl25QsPR8sxJ7moB5/YXJ/4ZKkRhhwvU0gwm/
n0+GCz42ofvp3pG92gRM5Q9+SnNvx3EX0QmDPcPon71RGxKag5UPHvlxxBEo
2eISnjfTBumjFzgC51jgy41S6cyjQ+SpdKTgf+T/Vt5Zobe0Bm+55C7kGzDR
duLc6PObbQhZvYFlQJ5fuq/eP9euGaZnQwVOLGEhWD0szSCkCUHCHVeCeVnY
r+52skmwFFNVJZKbDAgsVdLVFuqj42O9M4dmTT+yniT91h5vgb4mZaPOziHc
6fZwNiD9wuWTf5SsMgOzW1dILcmphqDCQfYTCgP2DMUdpbE0OGh0GinSR9FW
vD5xw84omHXEF3w/QeCGw8ru3afKsMc52/OxKenX3FWzLvFP8dr7+ofs/+er
udmviQctOJzSNbBbhwmHQebRzmu96N4nbWN+ehQ2WfcpIppUJMaqHKq5xkZG
+iVh0YQeTCtFxM88GwOP8p7vka9IPoqZir/0jYkmh2ohqw4arESLHY25WQg8
o+dmGdMCs/UvwvnjGLiwNXHLBzUqLG8w7s6RPMDRwhuzjK8XU1sn/k7+JP3/
oLVrsYgLrvNc+1NA8uh2JUlPp5lG1AQ0P2sg+WW7XWJ0c3E7LLMOfu1bNgpO
z8gmw/xGBAz75MbykvxPvRW+l5kA8xty2x3I+fL9lNwwy6jB94oz1kIHmOhO
VHN+bEnFxQfP+a6uZaKgz0Q2Z38b1DjmCm9Pkf9vCzVWHWpA7LEPJ/JI/7Nd
pjd37mISrMXEk0Xuke878qGyj3M9BB/7VrJuk/OfflM2WFCHm9LD0sekGeCp
UVVUjezHqpwjF2LJ1eJLsvdsTSdeVihrZ2qxEfOdGP+c0oHeHyvMAtexUXRG
5zZNqgK2SyoK7+cy0FerO7PizgDs2s7W51gzIRhZV551rBMBeveiiuuGEc5/
9MnGw3WYH5PL7/Um+9nKr3MS0fnw007naT5L4MHDpfXD3SUYbM70WvWZQCg1
1UFuyVusMtavaDYlsFGFH5f/1aA8z5v/pgMDrg9W6vjcqkJiYVBKpz7Zj8xW
uNhlfsLokHpfvw0DwZSMScVV9cg6Ex7lHE6Ase6ntEVwC5xq6i+GepP+/GvV
wLEjvThdMUixWMNCd+mco+4aCrz3K08nkP6zzjb5pZ4rHfP/Kv2vloyBeCv/
WPB4E/Z9ngg6kzGC2xcGlETuNmGM+/rSzhA2FDar3s+7Xw+LFYIDl8h+dM0k
z6NmfTfUWo0cJ6TH4JVhSPSqdGKW53efuxAbcudXU27UU9F9anoTX/Rn+FZ2
yfVKNMD/4WT8+yEWag79liCcaZjrP64zojyKugtD0vHuA3gtFPnu9SM25B8V
qk6L96KHPljr3zqM3gQv2XMiVPhFGM2uJ/UuoBlkXrqP7F+efhlxJB+6seuC
dnvkYyg35rWYJYFZSsOeEMt6cI29zB0nGEiR3znE5/0BUh+NvBqmGSj81yqg
Y9eJoD/7nmRsGoZaea8ww6Yf7j+EtdIaRuG6+tbi04floPtGhNGoDHRvNF9r
lNmGmENqhiviRhEwKbn9o2c3LMULecsvMtEfEcn8UENFVkmYn3s2C2V26V6C
3O8QQT+8IPCeAZPx/y4ZrO5Bhhsz2CR/ADS2dYrRtw48zdG4EFs+hDz9r1Uz
XR1oJ3JK7qwneWPZgL3AQgvMh5otU8h+HfCN4+SziTRQRZ8fXE/2i+xfpz4p
fmlDJ8WxoOIPgZxbSnyS4dXYeN67fjfZ5wI0Rl/R58sQOfrTOl6CCTdVxwNq
CVTob8qzEnhN8qk6PUv6Uy6s88K8vVeTfeahgObj5g4I31JdPXCc5GvBSrEe
vyzwVr+5KHmN1OeVzouTcfn4b9bWk5JL5rVBu0x6NgXLvznxr/lFIEtW5XpB
fRfUwhN0aT5kP/WhntG5kIAPb817xE4R4PoqL9oXW4+zsvnGVLKPKL54dWrL
Rwqivk947uojQMtrNLXTboS8j4K/UwgTZxv0W36aUeFhG8jas5e8v7PhpfXe
1SDKXpq8uMLA0P16u40X4lBa9SZknwvJs5aZluyYMhj6sZbuIfPT8NJb38Xq
VlhMOrRy8zGw8NCu6F5SHgqy7DjnyPONbu63z1mowk45S8ENAUzwOQndDo7r
hVLlooaI7xD2BRLf7pR14Mjn4OU7LpN6mRpOXlPRDF9T+84r4UxM7BQ+cY63
D52eik0W25lwoaV//L4rExbulf3l3OT8xMsUX30ogoDfr8ySagbECm7+ixbp
Q3X25kGPQSbUubeo6U00gXnp0eL5kmGs9bO4Mn+yDf1xosaTr0i+/fvQnCsh
E1v/FMa5nyHAsz39qOp2KqTEjTfoiTFw9a6t89dlbeDtyRQx3D8Coso0lO8g
DS/Xr3ftJ/mAoEgFrFGqBteS7W+iuJgg2rfERgs1IE1Go6bMeQRajLXWGYei
ISZbWK5G9qm2lDyedKWnMFIyGV9nS+b5u4N7dwsnIcar+f5ekpcO+di/UN1P
Q6ZRInu3yyi4s64YH71dhaWtMl2GRQzEByd9sXFPRsymn2Ge5wlo/fGv4/3w
CCoh1eWdZJ81lb7ModVHwcA1n+eHyD7kEzhx3Fa2GoHxCfJ8fASiM5ISfubX
IO/2qNmhWwRuMlxnTR91Y+ie3NxRdRYGplaE9F7JgUVk0aLCGgLPOPVivm79
CLcXSXI5ZN/3WlzenvCUioB/D0cPvGchP3nw7+r4DkRVP7JYvnkEgV27s6X0
Sf8f33Im5w2ZV+ZH5f75VuFT4p2ChEICNWujEhhxVRgs0yoM3Ez2v9Md1AuT
7SiaLLRl7x0Fh1Xff9/C1bC2Kq5SmeyHMv6aB/jV2+Fm9yfwug4B+6zKF9aj
FeCpSr80rEier3bulL9+Kbjf0x733yD12n80pk4tHqq6xyQD/t/vs8XETWrD
Ia77YVc7yS9uEpI/xeZ6wFImcv95f0blh2YdYZNPIJjnaParyTyu4szfkx0P
YcGkahqZnwtV+aqq1oVQ3VrZTfEkcCDa3Pi3WDeaDjIKG//Swa+/oK1PtEPX
bOgAb90QBlaHScmY9uF4Qabbgz4WnF5qcTiM0tF749lBytgQuHCFUU6pR3xh
t8TWXpL3RpqStf8WkPw87uNB5qvVs0AZTbE+cJzUKX9sNYoa7m0q9rvr8aly
5vynIJJXOG8TzNkMjFc5Hk0k9bp+YQlTmOQPPe5gcB0bhtSW24tRWU8xxNH2
WcCCwLDk5DoVy0oEiyyXb7MjcEfSZCl9Sy66lEZjT5YTeGcjL1sURPJ+w4dC
zdQxTN/643iPtwImGQvbTd6T+7HbRt2T0AYWF92e6B2BouZSe1XxSph709NQ
xITnllB6lDQdJr2xbW8jWHARUTa7NN6OFRvHQ0zYbMgcoGglJ9ZjqP72tVVk
Xk9rd94/tDEdxwPW6exXJsD9Ut/t9cU6/Ova5pL2lwGBY7wiN7UrcdXNgscv
lIH/AcVyE8g=
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk8ldkbv0qyZcvIEsWoSGIkyfY1iDJqLCnLLWsqQo29ITf1kygpW4rS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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns81NkfxmkliUiybuWSW3Z2N5Rtkx5Jyi4Ssi2lSSXZ6bKhNC+kXyqK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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4ldkX1mVm6GcodYZQLjFjdFPSKOrVjRJFqaQRHSSVSK6VQVLUISpE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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VO0fxifZSZQoeVHJUsqSeiW6JUW0oF5LL1FZi4pKKRJRKVlKIilF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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lWkfxsnSW6lMb5QaWxlLK5IkdVnKNkSyVfZUlmzFUCJlK8n+njFi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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns41GkbnpBazVohk1TrkByzorUSboRqY7NhnOWwnZV8H5JSEjkTmwg5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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8Vekfdo1pKEkZKSS0b2JCfpaeq/yQNspIElJJJUKWFMO9KUUqGqQ0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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VP8bhlWyhyxZUrZ2a1R8C492KUQRJSKkbCkprbaiLKGisqQVbdaQ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk0lVsfx89V5kOKupVZ45VcQ8XV0detK+NNplI411zEcjQSCQ2mMhSi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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlmk81ekbxrXJiFKULUJSpMhEIi6EMbZDw1gyhUkmEUm2bB0VadE/Ii0o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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4lOkbRkSbalYTsiOVsqHDsp1QbpWSjT3oZGOdKscabBsqiZCUlUOY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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3cglf0bxikkRTIioaIiSsOs6JKoNJARCXmzehuiIRWlSVaK8KJSJDTI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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8Vfkbxy8ho5IrS2EaS0rS2Ic2H7RYRpNdNbKXSGoKU0woNAqNdtmy
DTOSnRCydoW49l3XPd+b0jJZEgm/8/vjvM5f53Oe5/O8n8+j4HbG+jg/g8G4
Rz//f9cJfameb+6HwOJXnyXB15i2dvWOmuxAqo9FfmIJF+FpgjkN6Z2wTNrr
35zJxZaFrO7R/C6Ex756bPGNA7miRzIZ5S3wtU8NXC3Ig9/TVW5XrVqwj7lD
7kMMhbCugzULXDZqw8IC5dsoqErErBBy70aB0xWOZh8FnSqLly+tWcjYYR+T
cYdAZbdn7fK7p/BQ3lkgrkeQcuL3jVFLJeC8PSZs4U3wDHbqr95kwku02Zt5
iOBrgeYW9/t9OO9dNKk6RJAXJqDon1kKmYTfjLGWIG1slGXV3gtVi57ECi4X
ZekH/7vvWQBl1WNNes4Eyz2Vhva5LBxulrsf6k5h2POkzSX04mcHfoY/KMgn
/lk785INAW9NvcdJFO7s4xcM0SzGktTmf7SPE8TdXPy8T6sXm7T4qyb9KcQZ
TLWWsFqwsbem6th3BFIKVVz/Ajaun5IvVbIgmHujOSQ1XgaZFJvBm+8peBjt
iS91rIFzbMy9X1kEYeej2HLmw8jYstIoK4WD6z7Sq45d64P+U98MZhgPb/b/
rL1J9hlG/9YT232KQDzJQSkGfWAy3qoJy/MgbaQSfuFVK2av9KemjVCwWx+6
ksoZgonxrVHr02OoPGL6XmagEVaSAWKUJUFTX8MLQf1aqP7iU+glR3DzbANx
GhtGwZqu+wP6Y5Bf+8UtKPAFso0P+srtpUB8kvIUFJ8irs+bl6hDYHiqI+KN
cyhS7CPEMp0IOCUXbc1Hq7DzgRWnh64vpZWndS8nC4mT+39qDiZYGH3PWjHS
iUT30+IzdL8njMfC+TgvcO30C05wDa3/8OWfcGnHBMe468x7gn/8LW8u5A/D
rnftvw1MCgz1FvNsw2rM8B1NPnCYIHTVdvkHEv1Yb6dmcriWizRWpcj5kg7U
nLL0FFTkIlSPHFIzaMKT1zw1gwiC/GSV2Xv5+bi6J0h312UC6Si9LfMzbAwV
fqyqm+fign6SljOzDgLsmcJ6JoFbvMnMT+d60abgzruaSRBppvFJ9ddWGDAk
v7cDzauNd4WreA2mFwbtKlMIoqP9sudD+8Dh3/q7QiwPCa4OPHPBZlicXv+c
vYr2O5JF7ZxswGz8z1YCqQR/NMhMnGuqg0npGsnRXbSfz1Xvu492o5yZJ61G
8xHawy1YZXsRz5fuXBFyIQiped268o8OHAj6jhssTIGtNpg3EJmFNOPjUp3u
BOEjP0aLoQA1wRp+Kkdo/bqfPhuP9WHXuJ9lTAHth1OYAy8pDu4HB7QDvQi8
J6WS7k41IFl2+Xa0OoH+npGK7I3t8LKZv+AQQcG3uLpbeqYXXHHmqrReLiYU
1xl3XWPjilHC9kxDgon623NJG0egXjQq4zpPoKiZPF9a0gXf0f5HFed5EP+e
EdMx0IU7x8LTqUoCywOO1tW5I7jWEKh3KYpANCRaINy6EfJmvhv6kglE/uod
5W+vxYE1R1s/qBDofIs2mxzsx+t3S/aBWfT8U6wUrLeFYN9hx+0J9P56s4LW
BbXVIaR4j73XOdrfhWsB56IrkSb0OPQoXd+ndNeT2xRboZEBmTs5BGKlWrd8
eorxV+i4hjTNj2mWn0+xcjEYlSYargH0/5lmwuocNiyDuAWam3kQ1rPqrHd9
iaFL44/UrtL86G/bxZJ4hkRHgxu6DgQbimU/m68dxAcVZpuZ7BjOtTcO3Q5t
wymFqSNtLRQ4jE0jK4z70FF3WnVRk4IXv9e00lE2oidj47VCKKzWJcyTF7Pp
HMlOF6X1NDa8Y4SbssG/16bp4k2C9VVR7DrBAmBxQc1xL4FHT11n+UIHfJRq
F+fo/Mvb1uxvONeDkue/1BX2U9DQqi5I9aDzKtAgkFNG4f3UW+tLE/nY3HGX
78VZgguq4nXm5XkoHXIiFjRPOleKxjdJ1aPx7ERAYQyBdU6u4OXeIbikO3Sb
ZHIQ2ZsYtcepDVd+W7NJbDM9v5kzVRdutUOrbemZkQ0PLqNrri4kpUOZ+fD2
vCOtZxk17Fg+Av2s5Vu6YVxYfpC1CV37BBGHDn3ILaLrtxwJ1rQbQnz8Mn/K
OIFa5/rdeWs74S+utKN7kQuN2TOz+z8+htq4g6EvPQ9Mmt5461ePondTEm6P
CB52tovIlg3B1lTHcZvTGO58PF+4X6gPjc7XR1p0KcxojNxo7xtEkKQC7+41
Ljiel/W+f1KEwObI5ZU0XykmDTbV+ZVYISlpl7CDoFtUdVJbqAnpEoeCnzdR
+OS8UFVR3oAbPU2zKjIETgNFhW8EOvHXoqm23V4umhhuOavFamF//IePZYJ0
P/MZXSY6jTBeqFmaaaWwpVn2MoPTjT7R97Fv6f3srN86Vbd1AJFF6nxt0xRS
vklrzYXn4YTDmQ4WnUeBJ5T1oyt78E7/k4IUnb+GHIMsz9/SETxrHDHuQbDu
lonNl+EeuJllfnlVw0GGv2K11+t8iFRpjOSa0HyfLU7Sjv4XEcqLBuusaF50
TCuU4hrRbBm3EG9F369XzK3Stn44+1XCeAu9Lz7HB40mhAfAKG0QVcodg+M6
qaDPfHWwTeV8KtpJ36tpRWmRf15CfF3DmDB97yQmg2MVuloQ8IDfDXQe29oc
KdQ+34HDqjMit2n+cjG9HDvZhQdmsvbS2RRc/vscgT4W5uZ+1L1K+9tZLRxg
4/EMtmknj8YOUOj/YXj/em8WEuIy3Yr9CdieFWaJ/7IQbjFzt6acvqdPAnyz
WspxPTjtdLIR3b94+Y+LIr1wPqQqPljBRfTqy7q3khqh9M17RzetH/231Q/6
29sw6OghS3FpP0TKdhk5lmD3GN+GenOCljLlzx78w3BYuuCRKkF/P2fd4ri1
AZarQ9RWTBEEkCgWEe8E/9ebteF+POQ89ClykmsHe+n2xullCk3Jlmn53G6M
OQ4O8u3lYZvKjI1kQSck1b1zCul8YYi4ig40JuBTvtDCXXp/S1xmXO5qV2P3
l8j9zEkK/wNWtLdd
       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk41Wkbx71lkDmFhkx2KhpDRNL+VYYSqUzqqGPsOiFJlhZkeE22kWQZ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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lWkblmJkssQkI5WKqSRL9TXV0NUoKkJjfJISypZdmVIMIusnqZDG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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VO0bxpUWeZW1hSQl8RZF2ZJcekkqsrRQyRJZIioqSaWSPRSpRNFG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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81VkYxm81SRMliats0RQVGYkW5klZWmQfJYrI2CWyZFK2GtMyRPYs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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4ltkbRhSJScnSGGWPTGOym1/dFIZqZCdRsqRkiRgMKflqypgsCRlU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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkbV0OolESlbGVtUUoNk+XnI1IpKoUce8JBmDRUhoNMlijmqzGN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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c81fsfx4UkaZBEVEIqIyqVhJdKGSEtK6NBaFhJMoqyc0tGJIpCUley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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8VPsfxicJtwW3uKks5ZYlXbqFVPTYrjWlZInIpXUoW4tsqSSh+REh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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4lVkDt5QtwhTGOlIkS9aK0M9SlqL6zIQsZewaWyGyxCjKkiTja7OG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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs8lXccxzG0qCSSooW1htpcUq1lfcgmZMhIzXCSynSUcimKUnIJJdFh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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2kgVA0XlijKTio7Za2IUoo8XhFJWlAqW0SWkkRUSEV2JRWplFASGqNU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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8lWkbx6UMWVJNtsk2LfY4k0lK48e06ShbipGlolKR7PXmpYZGllfq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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk41OsbxlWiRYU6KpGOkS0VR6ks3ZLsR5aQhEKWFlosOaEp0yGFjoSk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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwdVnk41dkftrRKmzEUk1R3JEWRJNIrUVqUlt8kjAohVwiF7C2kLplI0Shl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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8Vf8fRrLKiiQVoqSS6Gs0PaRIKCupKClSCWVVZBRtQiFbQoi69mjY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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx5FRSSXZShmllG2YSoziYwkpkZKtSAgNgwaln2KiaaRCpCHZ
JqJJ9jCy7671ulxc673fQyqGUqKU33f+OK/zx3md5/U8z3mf9znbnH1OnBfg
4+N7QI//5vIA1YAYfSYi3YO1Ig6OY9+fMpt+H+iF1K6bFWL1XDgV9jKC7J9i
6oK4XpMLgaAMX8iJGAZU5m9uu7+XwO/00xr5gC6EHVbOZzMpLJR0F5etYWFt
VoSk/7pxFKmXNpp4MWD+Nm3p/hiFLr7RN1NPGai9VHJNz5QgdfNm59DZB1iO
FniZdIrgcKTLifnSQZwcWoxAG8GQ+VKO06s2uH2/nBMwR+FOQVybl84TJNs3
htqcJ8hOcYxrku+E9vqdcvNHKPAFKrXWpDujpkguAGcJ7uxyWTQ3r4fbldDY
hQmCAke/llztYZzeJ1sxLcbDpFFuyIvWXghNdVS0P6Pw6NHw0q2ldtifO7LT
roDCl21ZdS6VTfD/2912lzDB2IKajad4F4wfLZf/KkIQenk67ZtkLXT3Sd0I
XkuwX6SEb/tFNh4dnrY75joO6U0a3I2aHVg1rafKsB5HV/smnaALbByWU5Om
yiis89pQF72nBt+l5EeZ5hDkP8uQ2riqHmZ5EUZpdgSiYx+Ozmrn4+K90swS
J4LZDGvGxew+zHSkthcv8CCYUF34bKkTWywbLwtMURjiD7MRAAvZNjpS3hoE
2zsj8tS7GHAVXlmnxqGg7fFBiPzCQu1jd2FfNR5m3Urfu/DlwOe8WLmvK91/
vwFHLrsCW00FNFafJlhQ0bXykavAi2LW1yUPgvWmvstzeQxgTUDy+wkenNYK
z9h4lqKyqXNNjD6BkxslM68RjRGWXeZVmpcUylZjJrMZTM62HbcVCeJqYqPD
pPvg07Of6dBE4VuW182P0sXYPlFEPXYn+C0kT8r+fhbenWGcC6XjHRTZ+9Ku
vBWuyirs5f10PV8S7I4ncKB0QUrAypsL/29PujeIN8LDaUMGU5/CbFiCkWZM
FlQyf363w5pgz+NLm9RSq2B5V1f0wVY6fvoTZ6+WAWgbfg2LP03zEn1N7KBq
N3YfKrMuHSL4K8LCULG3G45KMocGoniQE5v4NiRbi7barNl1yRR85UJ/OO7Y
imZz3WTLBgL974PmZGU4yC4cKIyy5oIv7vFsvl4IIkWZ5fcdCQ41cXVNzAex
JJoxfEKCh7+N5tlBrG4M+BoYuUcRpC/Xfebys/DwReya8OsUZFuylJkeA/h0
/uYbCZqvgmMTQ04m1cjNGhAyMiTQmpVY4ZDMRK/ULwVXWwi2fNHXr77Xil8u
jgg7NVMomwk0OTfZBPt3q711bhCsCmhUpE5Ugt36LYadSJ/n4CJ3LKUCf88L
GJReptdLHrZT7CpwDCwtnYsI1k7d3rpSfRBmNWvuqorT/GurTu2b6MPIqbnG
U4ZcuG79143H7ENT+tWjRQ9pnle80pcWqsJSknDcuc8UXF0ExNVtB2HaNyqb
nTeOggtNUT0fRrBxu5acoQ5BYql9GetTP9w8VJxl/HkoOsqeztbpwaRL64ZB
+QmI2m7MIuGJCM9vrIw7R6C+W37s3dd08PZ8TfW1IagvlHgeqVKLmdDIppf/
5b94bGKRU4wDv7F+eEzzIT2qeHYzXyts82++LWcQPD7wmZPzvx5Q6ktXk6wp
FOS6a2YG9uCM6+Rx1+s8LNUO9oXV9+DZoTKfqw4Umrv9PBaCq+EvomFzWp6O
/yXPr0WtCd2caYnGBAJdT4Hc9yINYHRxruemE0xWyA48/6cMlWdsFBf0CMRW
M8O/N2KB2ZhrK5nGw/6e3L3DOl3wtki69SKMh/igHgdebS7mRD90P6Hz9b86
X7jedgizT+UmAicpFPN1ZJx824wHXq0V215RiFMQDCqQLEW8/P8GbGg/epZ1
uS3s6oee0o5bK5W5uGdr8ntnHhOL79/wXPNp353xbbJe9wS8JW97IS+6H4u6
oVV99fjpIP/rBTrfsZFNV3aya2D4rGjvFR5db7KBc3pVNox/fP1I4FeC8Ob0
xc4VxZAOVM08RfvmvpFmQ9JlJuzE2arLw+OIbPUU+NTYh7tW/kZHqrgQEVKy
NxYexmWJrybXfCfQllf+c8VPnWBwdE4e3EkhcPyb6OodjTDdmB8c2kvXa3Z4
ZkVgHUbN5S1EAghU4lmrXqU1wKD9tvGxOQKF/igtb70q/HZHaNJshoLSqJu2
7HwfKM3QYTnaFwqvhM+UVLbgUM5xsqOSgod1ucYx0T7wFq0tM0bG8eNMyMd2
0R7sD7OI+rOZiyVKid/HpBVqamcvGb+lUG/Rf0kyuRHJwfGbxfYQCFs7/Oh8
rwbZ1w0suR0Urjyy5QQrMGguvzP/l66ftVL3W6JfNU5o3lpxcpmCnCdjh0x4
Bl6Up2Qb0vd7JORh0uqcfhjUL/aP0fuVtZMt0i72Qz841feoJu2bD9HyHPtw
mI21znqfISDt9xRcivpxScJidtsmgh474wbBDjZC9cKPutC81rfWfxeYW4LP
4bsW49Rp358bFmTdSkXkhsgrgbSf4zUPuqxI6UZehVsOvyWFPL2n/uZXKpEQ
EjCslkPzrfbr1sb8Bmjx3Rb0MqP9kHCjXzawBbaqt3KqKwhcpz9YkOd9+MFk
VDCV3q+u+K43+w0Lb6s3t1lLUNjCGOnWOFuHa0z+T58taD85x21JzmrA0d2J
rwXp84tO2nX9jUQFHvLa5uyOEPBR9t7x2TfwUczM9KQz/X5Mnn+twGajpjdx
ZMZsHAf+jNzeFTqKqb+OFMomTUBmQvn385JMzLN2Ov1sQeGP67WWYa4cvHUc
iTV4OQoPhVi5xI5ecBL8rYIYFMI/qutZZZejO9pkjbAVwUM/B8mP7nW4H3tN
yHCBglpqfv4puz4oZrd+cQvjIot7IMDdoRxLM9XOWjEEtQqKktwgFvKNI2TW
bybwssj04deqgey1QxMvJAn6XVayav+oQ7OGlW/iHfo/sjf2+bJXGg7PjjyI
of2jtWprYWx7B/jFa7+a1VKovuEZYm1Qgu23mbKSSgTON+4GyK1iYk73D6fj
/xDoiVYquzg8gBt798cU2lf/B+TTw1A=
       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk81PkbH5aStnVUdJAjOlA/lVRW3otcoYOpiIiMVc7IsZRjaStJl9q2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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkbPzP5pLEbMmTJklD2aUZSv/Kl7UMIUZFsUUeEaOyh0CYl+WQp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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8lWsXxqmTJFQi6pSxlAoNjgyHy0ylQgpRhohCKY4UChEimQrRoEEq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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk4ldkfl6GkBZWlKGZ+FIZRMeOS6YPIboiRaKxZUmPvZuxqpsVWkbok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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk8lekbxo1RCdPY2iyDoYVKxpSGcB1MyBKlorJNyFqdUMNIKiohSdbS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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lukbpWQpSraRllGpSQwlSvJzGhqprIWJ6ovQEMVnihpCJVmyZi9L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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VPsfx0VXuYlSlkjWUqKNK1u9EWGSKGkhlShaCEVJXVmKIkKFK1c3
W1LZSonssoUxY8bYzZwzM0koFUn1O7+/5plnzvOdz/k+7+X1UXP33e0pKiIi
4jZHROT/n92yVxXrXYow+3LtH2fLCKjmEWlNhWUQrKz5WBPDA9PQImXB5k68
Pzbq6HyKxMTAkn3bhEWoCTut0pZPQOpU9vdGJxYsVjsxUlJJHPl6wSzBoBeW
RMmf7z1IeNXoj2ikdCAk+MQnbflh+HgNXFOeYaLEdl7t6lkuVMfCZ+rHW/Ap
NnO+Oo2AhXm4d8g+JsqspcevDZCIV2gT3JzfhFutl8VsqXkUy0ekHey68XTG
YKg4VYiMPwtuP7VtxMoBqSPyL7noMPlcOR71BrkH70mL15Iw6BQPX7SXAfey
BmbKKx6mlz5nDn7phNgxj0umd7mwTJ45JKdAx4v/fFSl+EPIVTqgHHC9DecT
nG79JSQRelqpZMfdf6BVeoNZfozAtJ/GnqK4IsyoVMV9cCKQvbz+hsQGBnS2
BUm+7R2G+h8rucaeLSg/dnxx3BQPMbx0gf4DFoJfFtCmD3NRsvu18y2bbqxU
WVbxiytAxoii7w//VsymXt+rIUWgNbKLpL/uwtzY5F/HBgWIWFDeJazrQnrk
PhOsoO6r9kfo7ehGlLJSVIYmeWCl2zsqTTCw9oXkwhljErVbxZMVJzhoji8s
DZR4j5fdA4XSIdkQ8RZnhEQSCEvuWbpteweK03ULdz2j5rEpGiUV+2GpJPR2
/86D6pNU+f0763BlO+KrhASu+3+vvrmKgZMfxYvnJfNh4Vxr6Muvw+6b8tq3
LHmwwS1n65NvsNP3Mb9Hm8AG5pU13/57ACkLR8eBAAITVdpzq+MZEH/3fVdG
3hDSvavnnpfvxnnhpaHDS0cQUi+h0761ABuUZTfnniRQNUdfvC2rAdFGXOfv
//Fg7LRh88nobuzYlu7EYPDg4PiRZqJbBP4x2ZENxgTy3/302qTVCR0vw9LW
bgFCOR3E8oUnMUG/qPvMjYCX/+SzFQkVkBJw/5ZZS+n7fen7iAO5sKh7t7rx
KIEas9pOYyk2vtG8ZkrXCNC4ZDFRNtKESzFb6IkZJBy4SrVVdxhIilwn1JAT
gD50vbw/uhUpET1J3//m4/LYZyXXlT2oleo943SRwMuXY8MDpc8RnFcxbHKK
AK1/ct09v9dQSPhXJs2GQKoxbe6l3lpcHVH9NFZK4JqpmEkEh47ZHfw7ZpcI
dJz4rKn3shruR3plVrEJnDXwj0vO4oBvfM8xxJCPEAPdINPGPtj33XtWkC/A
1b4HIanBA+jr3RvDmaX80r618eP2LPTlDB3S3kBgdNwxTDz8Klj8JbqOR6jz
U6Mjj9GrIRoRk2xOzXf0LuvQks8c7N50x3jrG0qPK4O/1SVkQnmZky5tNwHL
E3kuH6Mov21UMPEw4yLjzLoUWckKDNbqeRo+ofQ6y3Pw/d6C6MPbmRJhJPzL
X5TN/9mPwKlluQEcSq+MZRW0Jd0Qby39MX35PULlVSYUfS5B+8/pgHpXAjrs
xan2F5txNkxa2W6ah96LHfJedhy8Wfrp5W3Lj1g28LPy1h42fjT4rJUNovR5
xT46zrMNB7qefrbaQUAz5rnyM9ceaGg1dMY1EBBJ4l3eyk/FpdYVc10pvwrb
35JWWrXQ5VlJc+Sp/Dras31FBgML3fRnit2GYHj7esjkh2JU2Z324HRQem4x
+HSpkgOpcYVnfwt5CF3kZ+o6ew0bHr1Qu3eCQPcyOAR01OGurt/MaicSlpKf
x02se6HZpar3vJgPr7OfY8vz2QjX0NroOSzAkE4aQ7qjCB6z15wWUO8b5Wm2
eY7HC5iXBi3yXUwg8mrucYmqfoxzX0mrtwnR6vT9ZtqLGgS1HTFK3c5Dcnlk
6ZV3GbhuuvKhGqVnyc20ozaNbVjdTE5c3UUgndn9sInJwL4whZl19UMYPVgU
oq9fiQALxUBbTRI7/R/9Ug2tQ49gYdFkFQ97OfpzD7p24DvrE8ee0puX08mL
H+cUIKHNiiTECPR1fDu6U64Ffip0pXX7CSgIVdsWiJXjSqye7qtnBMyma/i2
5ddwz8ip1NSFQMS5J7HBz1th4jIVEqpMIPmuWa3lg1roO1j+GeDOw5cfuyv9
LjZiZs8ZKf1E6j5dF0o87S1FWcAvq+PU/LY3VTRqXtDx7/lmh9sJJGxsr0gc
1GLhXvUevf20EVQdNSzTEGPjo5IKXSxcgNxI2o/a6x2Q+5Lf6nWdwMD1BA6r
ugsrL/x0i/en/PqkXt7iaTmcAl7cONbJg6R4Y/AL6vzEUtNNXu08RGz8cIkc
aYUw1OCQszMf/42REnMFDHC/t1h5U+eZvdaoYzo+QvGjUxun7Ais6bn9JkCU
A/1rD/jikqPQ/K9XcufdNkgxF3rPuU2iZM6hbZUjDNyM++f27wEeTAU/VLoK
q2Bdv6lHdx2JstHZwwItOnzuNjyToPw+38oxY20PEzWMikVfrKi8C9dJiv+Y
guRmtx/fjxNwVjCZpD/ohg531eN+cSZi+WP1PuosfNlfqvx7mAuzrGH7s1ID
WJGktiXowCiqErV8ucH3MBDepdUQRPmbrAtvENRgsISVpVFNom6xg9OJyyzo
BurO28UgISm12C41vhblPZ6LQrL5WPT2rVFfyiBEw/YMGxm9x/yZhoF3O2vx
0uPBjvhBEqvl1Lyi5OtwrsH+NpYTcOjSEyj1sxH22qEk/N4wzjm9Ck2ya0Vf
qFd9MEGgc4VWhGDsNVS8RX8VnqP6QOrwgk8LuvG+aIvstzYShsN5euOPn8L0
7qnxpySlF9GYHaIxRcgMLiycukVgKIi4xq7/m8r19RKD7tT/1a+1JdUbYDlK
jxvq40En/430Bf82iCU2W86j+m/CSnWnVn0Wdn0yWzjjTcDds8dznisLSW6P
uWZOw3jl4uAyOdiDLxJ9ZAP4WLpxT8OIbjMO52n2ZahQejwRHqaX3YL5V9hL
rj7jwbUtyjLgXB3E2JsVvaIIJDTeyAja/wZ/TqzxSaonULDYKcI8n4lk+74u
mTv9GJIWCVTWf4T4zmlVR38C0sUxU62pndjESTd8/2sYmeE9MpuUqyD5fIdy
ETVvjIxYbC+tFcVljYRkIQmhxapaadlqaO4a5EU2Ubwxk2wlUHsB9QNxBzQo
f2h/mF6+Y7wZ/us8KlhU/l7+U2p93EwnrJV8Oe4mwzi2UbNbK7kPURPmr9M2
Uvoa05zK5nVi1vl+w+YFJHa7xEg/KqGj24ylfayJC68zr6YmDr6GsONiWWAv
D4smm3dxJptQcH+rbiTV/wpvG8Vn6LUoyizQn6DuQ7V1WXbt1VDQuE8kCg8R
2CQupSRs6McKaTJj3k+Kvw58WLedcRI3vs5saTtMgKjWzzHZwcYqYRDvp/QI
JhkP64OfsKHp9uPAOmchbP8JFT/SwEbk0dwtdLthlMS5pTrmMaDit7HqVSuB
fz/edDnnwsLSMc7e00e5cK6HWtCWVnz18DOViqb40Lj30Zm73ci8pvlTuOsD
RKMyTTuEzRj4e5R2WILqf0TreaR5I+/O37MeVF6KsPLUChX98StNqXqE+t7R
3SO31jIHtwQ+ry9T8xoSyXO0Z1lwoJ0Mv3yBwPJ2pSR5vzaMGJilBVL8KCyQ
cZM6WA8x3gOPw+94sHQaPxWznOLbC1HZO0u4uJsS87zqUidiz+iJGy6j8lo9
ZrPkrh6UfmqJFR8V4rN4l1lhUSfaJr9uX/WDiyMN+fcjRCvhnqgfueEd1R/P
zpKB+blYXrm4V/c+gT/jo3b27mLDZjzTNoklwPTytqPyuiHg+if8rqT640ta
2km9+024W/VA84kXgcxl+9Xra6vhl7M4xzaBBynve9unv1Lz++tkvVUUgOko
pxQd3wyX2JjOZfeGoCAuYBneZeJ7yN7Vayf46POzYznfrMObnqIOlS4e+l4L
8mxie0FcmbIJTSTh/KjBcORDDea7T3FOeFC81X9StmhdFzJ7UytGHg/BrXCw
+qxcDWbvl8Q/XkXgGzc3ME+/D6sZxuqDLpTfVLa52bax4Zzl3XxglwD6sbPy
sx5N6Aw7t+mhIwmXOLXotvrn8CgYFa9vISCqoP/A6wQThl++81rm86GVq5bs
r9iBgYodohqiBBYNcyx+zsvBhEXAJN2RQPweeWbJ/tew2ZUYS26m8qNEQyaf
l4WRdq+sJop3ojIMdNIeteG0+XwDsxMkKkNPOI100DE6M/AoexEPjZ96rFv3
lIClqBBtvYeAz6lyKzdRJpxncgfsTHhIUi7bZTXKgJFaOMfag480J/M6sak2
0DZ15HRYkLiWPz1Zk1KNFSk00wA5Av9sSUs/rMPEgdHEpfKfSNjRvj48PlaI
mfPS6dsp/szXUwqrZNDhtvrgrdpbQ6igz6YeUGViw/rz5NhJHuIDx844xldA
ZnZF05p1VL/FSxhHqbCxWW2J5z2dflSxTaWIteEoe/94STel51m7VWsn7Zn4
NrDPqnqLADO9ekH04/0oJLYtDVtB6W90zuI5eSyY2C8PrKgWwnKxCePrmj5I
XyVIqS4BfrafWZyxko1frEQTg2EeIivK2dG2/eiTWeF2MYJE/tbokazt75AU
sHPDaBgfhemNtpIP2Cj1283bc7AHLI0w67jjdOzLzk/4kCuEztc9D5hfCxHq
fFysdx+BuWci4tcEF6Pl57s66SoCt8IlcvcPNMF5iz9RYkTxi/avc8IsBsq+
iuTI7OWjqn5TpvWVJlx+aNn9xJwEc/9ZpyCfauzOMV3zm9pffI59vtru1oOQ
JGJJxegQnlX6iNVOM7BZ1F0sW5WEh3vpD3cqf/WkJmTqnPjYdqjAecdNFvRL
R+WvGpBo/SzbmzrSBpPRi+r/BRMwyLl4apFOJ4J3hve2/RDgAs38QpFnFURc
lmv/vkL56Wj69mvydBwx1i9p+sDHUOk2To7MYwiLnX6Yx1P5ohnRvv5DAzJo
FkVbb5CYa0d4GuWwcPH4Nj2mxgiibOyXyYs2QWisbqJtRcJeKH2R39UEdVrT
zeA0EmbGq5oZZkWoe6VQo3GP4u0/hjmqfQP4rBzyO73rPURO6J0tUM5Cefzj
wFZzyv/JcfvN+3rRGddyPPsKF+V5LkEPKZ7R3GZ3aquAxNby7/1b6A14dE72
YTOVB3UGEZ/cT1ch+ILgnBrlz+Tbmp9d1ZogEiLSd+8TF8kvT9PHX7OQGhhY
oFExgnjxPAt/Kzr2CO8nmkbzccZGfaFfdT+WNc+dq0rdl6lN6fnmsLdo7biY
Qt9CIM0/hXnemgNn8zuuKdT+de3hMcfbcU04m7Rv+zo/LtXj05UZzdXoMdO7
PlhA7Z+Br0T2fGOj1SHAl33rPc7dMPStqWdA7rJkpfTIIObpGJDmKix8WpqR
OxA6ApE6fBE1uYqgTT13tlD901Bl5O+9tQn24i2LPxlSvFWyNK16Jx32ywZL
7RdzMT/To9CNet8fkk8be6m8cmezPf6fJyK2/4T/2cjD05y46wvTmOj0fR+z
OotESPXEeUYoHXZGiaobfhFQ9E4wiR7qxsP3G5Pk/hjEioRJA6znYMt8t5gH
6jykP3biqD3uQOz0vpJ5GQTsHitJ3pGlY8jta4Q6lcfH5L9tNRP0wsat25Fm
zEOY9xYabaYdCac6Gs2LSURJ9czdaMlBnk98+7G/hhFx5Z8zwz1tuBMsq6f2
lxBPFQozOuZ2YH3PRp+Dklys4eilS33pRnGIpIvaXgLimssLT8g3IXtH8iRj
LwnFPQeGN67sxaKh4mm2L4HpG2nxqZXVoDD80p1uim+Czvk+rH2KEOvVR2Wt
KT7jf/u5+nEdDu4O1+P/Sz1/Ib5WitWJyqibFXPeCdF9eST4lEYLfOzoB65S
+/DE76zdbQcysYRhddac6seXbze23QwsRp2U9jpRiqePzC56/63sAcwmU6dK
DQlcaHe136rzCqxfprOvKL1WFUryzybnI8otx0hA7b8inxubZI7kQzXKLVbP
k/rdI2fIfTwNClL6ksrbCISedDW673cTxg33l/xF8XDu1HWV/V4FuOfg/sd6
iu8iZL/4Pjaow7x95qaHkqjzFpbZRKZUoGhvwNBoHrXfn2RzQ2PrYBZp5Prh
DYEYD7EAh7BGyJRqZZ65Ngyv9HdlblT+79wVsQXzhRjf96vSjuIRM35PdIk7
iVF1o7rnsu3QF5lfrk7p3dBE6LdEuQdDlYl/TDOGIde7Q5vGb8FSeZUpwztc
qJebrtcZ70KKccbRj6t5yO8W+xzs0wUDtzd1f7/j48LGbdcbShjoOFcX5bVf
AOEYu/vys+cgOrW+HKJ4d5e1zsUsRg90N9CGYlbyUNU/QOscDECCc3sRj+KT
stsf5ic+r8f2SDGFg1QfykWNwkakF0ku+3SbqT4Kfe3GbM9vQ8T+Ia5/Non0
D9MPfyc2Q/zLufipToqfR16K/PEfA8bL/7rqTd0f8a695pADCzRzr+iXWcO4
0bzIRlGnFjWnG9ZPdnLRZ2lwVU+8AWGeQStjqTz50kdWzt3Nxrwxdu6BERKq
4f8GvD37AhbWfx0WGyBQ0XX2vi2NhdP3Rw1DOAJUkfJady54okBLVsyXmn/K
p7TT9yMb8aL5cjIyfIzMG7IZIjrBymQ+848awv7adkb3pW4UDYqo9lP7FOfg
Cq0fTRT/mCf9LiWGEdqIb7k+HZht8fA9s1YAj85slcSgZshdVPf/3sVFvd0K
9o36NhRqGN8XvuLjXban6+niRmirvDK1NCXwJvyYtFhfB5SlujTOuwpQd7kw
Uze1Fepb3yqpkSRo1rKb6T/7ECB8VtCqTSJ4Ww7vxaF6nPayznlH7f8xxctz
mb+7wHd+1rOquQ8bct7Eqi/l4EKuufk6LxIDa76dLaTy6tXetkPMBh6+vjnT
qG3UjFyPeeVOFN/FLBx+rmP0FpYWDnkqkyQ2N1Vl3jejeL+lXyIhk9Lrtpv9
3nLtCJic2XxlgRA7rSPDR7TfQheM6r5kEj8LApoUl7VibJ/WHCUdAsY+S1w/
bO/ECdukBXEhQ6Dl27+90dKEOOYKvWV7KL+LhYirbU6Dc175WJQzgf8B+7kj
Dw==
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlWk8lWsXxlVS6SRDRFIypsEQRaJLRYhkqPOWpJJE5mifDBlCSYPK1iGb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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81O0axlWUpZAk4Y3ozRJ6kxZLrpK1RRhrIaRI0liSSiVyqCjJSB2J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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkb10R2UcOoiNTM+ChLCo3qhzYzpFTSyBRCilGIIpcOZYuyJMkS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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VG8bnpAUSSL0QyVJkTbtcouUFpIkIVkKSaEoJCRbGyoJRZKy75Ls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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVmk81WkYvVkiYSyVFkkqIZRGZUqOGQ130IyQJRHGHoaGMlFIFDKFkkyy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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk4lekbtpU0MpYaWxsaMRHZj8pdQiqjg2xnJkJFStYOadVmSZSJyJST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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs4ldkXx91HSkm5TQhFNUmFSsJXZSQZuaT7oOMkSiKSTEWjIt04IbdB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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lf0fxlVGg5JNVoUkJMmIXGRLWiIVpUQ86pGGIqWyKmQ0pEFkz+y9
9x4Hx7HPuc+xGorGk+R3//66/7hfr+/r/n7u67o+72vzuX+PXljJxsZmv4KN
7f9PSbOj+Qaa3Wip5j3Ne5MJ2j9y885n8jEzrbPtbhcDHr/lf5i59MLwyWUF
m1ACsUn1I7MW7ejYsWa5UJUJkad3q5o9+7Cw/aFQ7jwTboqh2lFRFDSmPyiq
zB2E5BfhS2yrGsC9PX0PbzgDM9QEyZ+93ViTEhA/3U4gIDDN8bthHcTzA3/E
jTCh+FWHv5TSgc+MqwIFaixYjIcpf97Rj/Oq57+fCJvA0S6aSYwoBW/N3kpL
5DGhZ5B0hxUZiGe3Gt1VzxIw/GHvd0alETF7rKvVPxP4Exi6/8PTPsSF6Zbf
0BtFrJB6cG37C0iuCLhQZE8gj8f9UX5AHXquVomNzxF4QD939llqPeIYKQK5
+xiYKtrhp5vZDkPptbRmd/J+dm0hwvuzUdJ1iffLDgIquf37yn++gxRfUbOx
B4FDzLkcy1O1ICTVDvzzisDCJsd7Zns78bLn55/b5H34o0uabIUHoSYTGV66
ZxJdLpEavFzdoGWyemfMGVhI/nblzHIDplKXV5udI+ArsTKR834Yyk9sPFF2
gsBxrRsvg870QNG5P8P06wTeiyx/lXHPxxVPlqLBUwJxjp0nNd9TkWxc1tz9
mYn1cSc3M3724pvAO+7i9HF08S7Ti56UoGYVdbXtXQKml078vLeuEp+3uJ43
FiJQFed6r/P3U/SYbDz71ZpAzY+0o4XPKdCVFso51TKOjNPdQdqudaAHx0nU
8hBIzTtR4V5UClOZjoNEPYHxmz1BJaVt6BcsXnfbgIW6Zrbggj/9eBkUJ58s
MYvZV4pJunMtYJ+b0DxK6s0wHo8vN7SDXrww0Zs1ge+OqUXSfRRQ1bZnvT42
hrVDVpQbe2hIpiyxXQQL9CKt776+VPyl6e5ZLpjEqm+T5qUNI/CxK+/sCx+A
6gkbdpYjBTXLDjXqiePw3Vpom1PRBPcbZlf8PJkwP0mVENJpxZXAL6EvVBjQ
Uxm0MJx/joceY/aq5HwdF7ROmFMKkeeyewWnFoFtCVGcprodWBm1qF0tQYfv
96Ht5pZ9GGfd3HhblY5rP5RxKjcGVR+33l1hRODtrNEnk85+9J58tORqSmDL
/NRs/t5ylBXfyTcvIKDYIpvZt4aKZYfwhUO3aPCS9XgYaNuLqpQNTdfKJ8A2
UpDyxr8D9JF7w9n7GSgMD3D+zqTgc4vpPNdfJvLclTolvGkYKzNw+jk3ip92
Zb2pmV3wCtA99dmYCa/SbU75FQNY5X1x5zYXOlIjtI9Xf+7HXEFxX7c/E1bu
3ROqjiNwv7uyvlmNAd8PnqkczA5cvrSBUnWcgZ/UcY+fFhTEJex295ohMPLJ
5kLHSB90jfkN3csZ+JjnUnaA9JNWsBhPjh0Lhc13eH46F2Pd4KmZVmcGdOIP
XXBib8fMtdrlW2kEdls35+yUqED6h0LhCEUGNBe1NQT6qAjVe6eq1MvAYdF+
q8cJuej4JqQlpkPgnxX8N+w1OhDtP7zIs4uA3GZ/cVm+YRgW2vTsHxhElPSG
5zb6Vei/Mb9tcjPpL/5OtdXaA5A0U/vLuXYE3KdqHA1201D3ruXVxUAmYgm7
5athpRi45hm6v5OBhKMJoV6VHQjkmrZI7yNw1u2o25hoIgK4iMc+EQT+Fpgt
5vJ34WuOQtDwLQJCYfZCW7QoiJAjBiV+M6GTzXNaK7wYSgsvVnHUEpiZYzsl
s6IL2TRH5YsXmdj7IyL8jE0P+p8aTrXFshB8T0ZUeFsjmnwTNw2lEohKe30v
fZwCcY5M91LBScRWaeTmpsfjz7WZ3qULBPyEtt2xaM2DveOVfq4RBooqUqyF
5Aeg80bVeAJTuFlo7WBnSYNKTMJlxfPked3i4u+P1+PImfEzkseYCPsp+Hva
sBnfBevXGB1iQFojSMqyvAjsr/2cNt0hYK9e2v1cqQePJQ2lb9QRIC5kRjYV
58KJ+vNkCZlfZ8Zc52lyPTjy3vL9s8BxpE9fW1y/sgP7M2xe7LVn4vdN4SS3
vwXYHvohrdCNQOdehwCH1zUoOvBgNGU/E+n3Qu/z1DTj2oin8eUuOlYL3zIr
k+pFFofKUGwjgdeKtf+Wsij48Xt3QPqBCYjIOk8n2RWgKeIEjd2RQAv9adPq
Vc0wWZIXS+agQ6fo6OQqtRZcel+lsizGQMzx3+xKp/sQfSxyeyHnJJ59blDu
PduMoF6Rt9JsTHiGG5Z3k/moMC40YFXFwMUpTvYpn3aoG5ZpRIMJAytbg/oq
CiR8t/U7fJoAf4JE7+/XFNwRKtvd+XUKbJbDgYmiFSjJljqeeZzMRy113WL/
OHBu/uIS4ENAT2BHUw1POqo16vuLr5H5zFzmNGSEQsG5+lHhGQL57emfzJva
oHlAMDae9FObiVFQzw4a4hT8n3o6k/qpsM0qUu9AUZSNaLEEEwnc1HdM/koE
oo9lrUuAruvw8WoRBTLNh8z85JkQc2F0eKtUQ+Z4m12kNhPNFpsEkweGQPmr
ZMQXwsSNZcGjZk49GPs1rSDFJL83Nl5u7fIA/Fyueo+psBDyjqGrHDgIDlqw
6pq1E6iSMtZRr3wJl38DTRQdCMwdlHIKGsoCN4dpcpYBgQ9DMorXZ7qgqp8X
oNQ/CT0fU24/jWK0JVf38q0iwK3/SV8kggJPnbVPG4cZiG3rWOR9NgCRrFJe
74Pk+a/YuKQqB/H9St3fmB/jyKrfFXQ6vw8tQX5ixtfJfEuo2HxwMQg+At7P
Be0IhImE293fVQrjO4uDSUZMnK5NzprMqUZqjlyy6F4miuKvW0kblENPqcKW
y5KAUzZX15arVYjJ2fN4azmBC/HdZna8dehq3lUhukyHY6/Z8sVnxXDVUMlW
PsLE3PZnRvKdnTgnJR+ndZSOKnG/6TKJlxjWf+J1nPy/l65nt16b6cHyLqaK
6TAd0WMq8gYe/QiveHPPu20EpTfi17sMdqPqGHf46fEp+ObtfyrP14fNBxm/
YrxZUEmmLIw50dC4zXwh7S2BTDWLGJ9/B5AlmNI6Hk/6kUfrHXVdF05vl/ku
3MJAcmNgZKtVF3rvsH6JvGHB9NFvxbjmIljI7bpiWU3q6WF620mOCuxxHmpX
f0f6+2iQ3Jh1IeRK1Z29ahkg/tt1vWtDO3Ls5qdUpxl49ajK7lpZDTo+qePY
DSaakhOefD80gB0KVifrHxB4HvKt/NRaCvI4I7wPmNFR1Kgt84qzEq7bmP1Z
owxwFt6KTiuqxgmHL67+hwloegpf+Szahm7N4G3a+XR4mGb84yVcA3WGPl/G
AKn/+rXxQ7uawNp6Sywsn4HpoMQG1R/1UKvpNMgmeUHxwY8JatQg1smpFYma
jcO8d2vxTscuRLdVlv4nSPJBaeyZyg1UGGccNs1KGIO8rYt93vQTBKW6rfMl
96948RX3hYMU5LP9ulLeNg7je9/937k1QdXeKI3+hAEq40wIfUULnvP98Noe
QmAqkn1fhVIfCg4nzj9in4GIX3PxAb0WeLh6vbgcxQRbadDenDpPsD4XbjtE
+pMtVGXsVcd58FpuOd1P8h8n36zD89V9yDk+nL2YQuqF/fKO4eB2TH04wnef
wkSOZCBTgtyHUQUatOjuMeTVHsqy4qlBusjBrSZRBOQNcxTsK6owLJiR7lPG
gGG6QkpSZyNuUkN5RO+y0LSYb21GGYTBY8slQY0JLJjk9RIjNPzTUa4xz5xA
aGT5a33FOvDeTRbYpU1H4Wa3hqWhIehpJpufFyb96cSZd7enFWH3JeTZSb67
E6p2WCOwGdfDuUdNQN5HkTdGcMoG1oNXrUXI+8V+OXzg6ocE/HO5o4r/FDmf
U236i82NcH9rvdmb5PWqNsslnGrAfU/99RXLDNy8EH2817cUObUrDgmZEfgV
x2+raVUGfX79R422BA5PfxXp03uHvHvlzYfJvG+/fDv3zo4eiLhIyU73TkI3
tlTi/IVaPM82mmw0JufxVt7o9ZFafFOWz62jknquVA7nz32ApIlh7mjye9je
+b+ov34Ru1MVVT6R83f0jD6daj2G5zMb/lFmn4D0Pb69ip/CMOxsto4g9RC3
3TBlQr0FXmORfiM5DDh+OXZbWLcbhI7zaIQDA17pckjP6IavB7PGXonMDymF
c43jdfCbjvpUNEjuP93UtOSMVNT4Wpm8I3miLjIl8Q9XFzj0d+RqkTyiemSG
ypc1iFWy7zuvFtChuUfxRs1CB97NhiydIP35sszEeairC4T3Ua15YTouTdWH
XNjQj9LLe6en3Fko+pPbZryChufrqF7ULDqUR2xFdSZrMf3y20rvj2Q+Nhw6
Y+Kehfcs8/1KMgQUKj9f17bMQplmo2Xqd5KnNnyf4TrfgLi7ch41rkzIUUV/
O337gPTRUvF+DQJeMR+HlsZr4PKF5l5dRsBYJnIq600nZKsdlXbZMMG7gUp8
MczD3wb/4eufGJjV/3o4U3YAYbSS/f4DTHxPyX3J7TMEC/OHIZw8DIhX7HlT
vjIbXJyUcMpDsi8JuioeAQWh+1ZvbldmYOXoVg/HaSqKdChl46GkfyxmRySf
DkApKXL1wkYWpNkOz3IwavG2NdzeSozUh4rn+UfRfqCtORj4i8xz9lMyV8dt
myDpuaIqMp/sEzmdIvfkE9GQQU85tpPUw/Tx/6x90hEtlBpQ4U/q22EVx/VX
bTiW/NXx2n8EXN0L7vFtGoa4GHeFuxqBE34+n0I9CuAyvFVVdpGBLq/ij1q3
+qDn1MZpZEWHXamWpEMjFS+3ZLvV3yHzfei+yavDdbgmXLo5/zHZ//wFbtwK
6kaSqNhDoxfjWOldMXNEox8zaUKS+1IIeDx8cqxKiIKGFY9NJB5MYqDpxfVQ
u0HYlmzXNpofQ9zoNqUTnjQYijRvCWqlQTpmZ8vk9S7c3FJQXtg2CYtReu4f
dhrY87aeSWQwkUnUU7cZj8DthRa7zqopiPMVNVIftqBCgePH3OwEVtf5Go28
bkVA2UZBTWUmyY0Ly/ORPVh69UfuHcnrVTviZZL21GBK12m7B5nPvk2Oo7Gx
JE/ggW+BBAu/9ut9DV41gje6YpNpEdNoC/m61SeYio1Kk9wnq5jovbvmQQOG
MXX1ogDt4TTcc8q7mkdrceKDyKpeUwbcDrWcu/KnA6niETrpD1j4qLJW9+Ni
O7b0hUT7tLFwdiTK3+3rKxgvcd0SNyHw1HnxyrEFGq7apX147T2FqC8Rzcmp
ZQjNN1CSuUfOd5OrW8bHFqiqaur/WEPHKGtzXMMIFePFSaFKT2YxlfUguESE
ggBVtQdMdSbJCQ673X62Yk5Nfk3sNB33dd8fU0rqQcGeyFtSRQzMeSYV2EhX
QMlC76o3i4mYjqp6s8Eu6K3kX6UVQEfi+sCufsc+pIZ/CqlNYqKLLHwm0SX4
4+T+qH4fySerw7qjaAPQyOURTVgxjZPsGhsP7h6AhH+wDIuNgMC2G2PdAhRs
vZY3V+9OB2fe3yHzoBqs+5SsMdTFQA31jFjUESqseRysg5l0ZPx4vMfsVi9W
r7PZvHEXE9s/DKmVKA1j4zLD6PapaUTlC80KVmRA2cQ/M5HsC3VWMgFHT/bg
PP/dh5y3yX5U1L62meyrna0f3jLqxhHBt+goYtJN7ilZTyduBrbwqoaaGLTh
udXedYmVBCS0HPnzFXswYzrq/OEyma+aeT3iMVX4li5xsvgiAwXN9esWSJ6n
vc1MOr6eQMDsys0cZ3vwtjttlEH2aen1hYz66Dw0tUtxJoeR/qks0mBtrMPB
MzLZAvvJfPZe4nLSH8Ty7n4Leus0/LgU5hR7WmC14qeHfg0T0RuvaqpdGcay
MFfrf9JTuJgxGW4TWYY7guGn8zoINLpG5P/yoCCkMP+8PjcBac+CZ+krK2FP
/ZOYTfY9xdGzwrLZPRjPmHDYsZmJMvc4+crCCjS9PsyeEMnA60cKf6XfNIKd
I8CZ8YYBe7bbf9ZF9sHrdgz/Ti4GTE8m+Q/Xx2LOoNspzJXMj70flJVmK5Gp
VWjrfZbcH/t8uZYz3uFwaIV9gg0Bt0A23k21zSi5nvC+35CA5F+zg+nBTfh5
3/OgIcnfhxdlgxZME3Fk8T1riyq5b2zlvulReyD2+1XnjvxJjGsJBDQdy0Rt
8etPr8i+f+HJkteGPY1Yar78O4fsxx/dDr36adWCx7ejfJaDybyT/XJz3rEA
5q0rNPm9yTzbkGNRvaYOnRtW+vhwkO+/GF3Ts05B+HMtgWVtAl/2cT7asUDB
Sgk53s5pAlwBu+Lf0/swYMduFUHua5FH7cqV45WgNoWcP0rOxyor88pu0SHk
FB5w0XJkwZ0/e1ornIInfiX1c+Q86v/V/Mjxioq9x2eulwzS4Rs2tGtqoAQZ
p2suEK0Egl4MZuTOUvE+pdBp385RdP+WC5BL6cI5nSAPs5BJOMpudwtYaITD
5NXH5hsI9GXa2HEUdYNV9bIjhW8KvPOSkbP1NXB/xOs3nETyRHyZlH01Fevs
dqY8VWAg3nK4o+g2Df8ltYpEk3xL9ZSlVJ3MQ7RXvcAleQJNPP1hpzlzwT1X
IzZCziN94PWblqU2ZGtefzsSw4BlSG6RVwENB3wqbe+9JPvfyOVmP4supGj5
x4Tq0JFq4rn3i2c8BCLu3tAl+5BI9VSYwoZGRHWJL5UeYaCjyFbqYXst/qzv
V+8k9VDzd6LXXGsArv+qaec0T6AnmLgiRur7h5YdteQIC0Fpa4oTPrWBbbfN
BS2SP6MeTT/+vb8DhjSoKugwodmxt+1WfTlSF0fmuyfIPP53U76N/SBe6zx2
iPtMx02rl2ney/2Q/e+bvNx2BvQiXeIO3I2D+qzMOqmT5P9nP2qfXfoWnLqX
q3wukX163NScQywL0W9pCVLZBBqoolYa5YOYObVjn4/nKM7OiGu9EW+F5M7n
lp0MOs7u15Z8UxyEvQ1ng7+R51naMTzrX7RALFBufxrfJNi04xai72tg/NKx
s5qkXqjKFoIOpgOg9PO0zvaT+yA1a9CtvQ5zCzGb3P3I/flSN+pJYjfOMVaY
S8gz8D/Pmhbg
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lOsbxh1K2uRkyhJlz0mp5FQcXJVCGyWRaLF1RIpSlpOSyDaWkC1l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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk8lfkXNiFp0k+MSGpIIyF7SYznWgqFIiSKW5YxUcpIKDFMjF0qjH3C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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8llkfxlFhGKQREhIlTU9aJEujS5SlkbGMFpKlNEymlEi9tpFRGUS2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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3cglP8fN0oaorKpkPYwUkbqJdGQQsqXokRDkoQKmdkNK0mKbIrsmZHt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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41Wkfxo+l0IKRFDNZqlOKtMzIkrpVyNaJGea1ZVeWFkOzpDkSMoqM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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4ltkblopQCBNJZcuIlGWyxdxiLIUi+/YpRSoVrRSRJZSUpY/Gmoxq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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk81dkbxw2lKSUtlmjQlML0a1BRUh8hpcaShAxZSiFCZVpJwtyQFktK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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VH0bxoUULVRCllBEhUgkpUvSQjxR1hZJCNEibaIHeSRpkSxJRAgJ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81VkbV/ZlprwmY8kSwkiolKX4kq2EiWhEkZB9aUGlQqWNhJGylKVL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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk01WsXRq57kluIuKVDkSu6ppApjylKkojMV33cVMZUhlREoZRoVp+I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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lWkfxk2nUNOUnRlLRpsOWWcSxVVGBkVNb6PJRLaUsmdNSEJ0krIU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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VP/bRoqkQkgqS5ulSCUp6rYlImQpvkmSItkSpVAqSiVZS5Lop82W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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs01Okfx61kpxCLXKJyi5KEttqK3rYo0ZYiIZVULpVGyqZJqeRWloiS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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk4lWkbPxktZJQYMfaomZEpElNSPwrJviVSwsnoKz5apJAlWSqjkrEU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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVn04lNkbVpSSpJQka8dXIrFKrdpy02/7oFYRv0pKiIRFlKKUlgqRj4Sl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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lO8XxiflW9EiJbTYIlGpJEV0C5W1QkVlF0kpSZtdIUpCm2wpCZF9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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs4lOkbx8ckKUQpwtJINQqFVML6OqRVpBObnLIqtqKVopYQteWQwiiV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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4lVsbxknpkMiYHIpIKkV8hoTbQUSKMuSQ0CFJRUSmBslwRNKATmgw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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekbNtGk0DpSUkapVGihaaFulK1SlmPX0MmeZKpBSAgnKiKhkhRJ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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VH0bxvGUqEiUhGyVKFG0KOoiW4u0PEIUKm0Usj2UUGk1IipLQiVa
ZM8uso6dmTGMdcycGVNapAiJ97x/nc/5nPV33ffvur+X6kmPw6dFhISEHIWF
hP5/xJMfezoMWpBmMTc8bgkfF/Zsd9FMzoE5LdAkJI7AEopEqH1LI0qJFm/H
YgL+922U9Ne+x5RL55vB1wQ875YoqwvS4RkjmlxuQkDqQyFfQbEUl1fnX/tF
XheLX3BJzekpuo+Vn2i3IzBzfWD38IJ2pFy7YixDIdCae1Uq/TEdQp+TNBtO
ctC7hxL67kcLHv0x+HeX6QBCJEwsfeTD0RLrRtl8jgBD8F1V9VElHrka/Pc9
nQvvZjvVqbJyJM9pG9tM40H3nYFup0If9IMqYwa6hhCS43zIbFc97L2cNSQ8
ePDU+/HsmXEjxsUzp+O2E9jEmXVvr/+IN5P7Xy3W5SE9xcJ7m3QH9spVcZst
uAiJ7lMZUXiBby/PpJ46QkA+LuSug1Qjlu/LylDcxENv/oZHRe01cHqnYSZs
yIP1G7FEhd5GqBzzGL7D5yLzxtrhkZQ6tDTYyGu2EKBwVfjt/FZs+6q36PdL
HqY0zZxGr9SCMpghfPsBgYOst2vm2HbisuVKCS7zE5JdK8zS5Osw4f0n/DO5
/pAfv5zvvm9CwjeT9tx9fJw26OnaWdONyGd9FH06H/4JDKcdQnR8v/UjRaR4
EDvni+Q1Pu7B6UEDs6hyNqY/Xf/279UGhMt+uLN+koesFKvs2x3tmL9U8K1Q
QwCxALk8d6IHh2+4T7m4duHXZt8VgZGtOPe5emeKBA9LbrhR6+2aIP5JNiv4
MBcqcwYjuIxmbBD+a1pRyMFRt49yXi0MKFGHtu5n9WMVS1l/TK4GhzzadX/8
S8Ao0UMxR6QIv5bv17m/i8Ar3c1vHqQ2Y2GafPC1bj6EpqMzJmTc8TXbT67a
kcDX6wH2+74zMH5dybHKeBCv+pmbb0e2IMg/2W9pGgcpgeJGcu4NSPeYG1Px
gYPw3kan7rn9cLl3qnLXOw66LpSP7RVmQvrr7rTwpQQq3Uf+2to1IiFhk39m
NYH/BjdcjHOvhaFmbNxyDy5ikt4/aqxsh0apxmrJk3yEBBz4JOP8HCcXSi/0
J+t/TPgd+/QRGvb2Sd41vUHAxb8k18e1EyciRHJoLgTWPymblz3aje+OuYeE
fn7CnfErQuKv87GxdrlG3W8CYUdHnxeVdqF2iVPwkPwQRupSfNa/akUs89B2
dXUCG7xbhybKBvDpdFDkzC0O7Cd3x114lYe8opWSLGcC5x55mh2uaoKX2SnL
VfRBzH+1PGyZLQuHG5KNb9wdxJ2Fox3s53SIHLNeXzDYjT9W8x9FlVMheUVs
fbQiF8H3w+4/1SjGunkOZ4hAApPWJtu9qUxcEBoWOdDBQ+jQfyzVRd2wKXWY
KHQawOnV6v1XIntw9tQEv/LZENT02m5ueteBqvR4q2AZPiK613UYWXVi07SA
YdrDxuX09if3Dcn9vGnh5HkPDkLWXUpMsq7BsgSLENUEDpI/iH0aFS6BSg/T
8Ho8AY29P5/rb+6Cpd92SwkW6T8TCjctLdMwUzssM+ZF4HzCVbpDeCfWTnrE
MyK5EEQMmV0trUWD9G37no9c5HG71Mrj+zC1bvemrPVsKGq+VC+SbANjfGz1
8TMEnM8LLLyc8rGi/auHsTWBM01bi0qe1KDTTXn7GJ+D6R8/9T7QqFja+/wC
rYkHRrjJj1rNVoxkRHdZp/NQxGwJczfIAVVFr7V0NYHUgQj1dQebwNhw7UL4
Sj6MvM/7n+7rwHrl+gQ1PS7UPhf5Nlo24WD1ccOFQjxMeLHLzycwcN3nqTiV
1Eulujvj6ZokmPd7S7wm6xkSUjexLNENM/eroqScSH/zVIoOEW/Fq2avyINd
bKRnyT1stm+D8Ll7NGkZUq/95Sojr8ohtcviWVo+Ade2g7RTmUxsYbOd/l01
AIr1ni+LG1/Afov3yhB7AqXnIpNeW7dBdTbDP3QZF698nga6cXpwp7QoyHv+
MPz1L5XVl9JgY7HSm6CR/XY8pveIbBtixMLUZzI4yP/nbIXRo0ZQCn5299MI
fJk6IyXX2o6hGRpFZgcBrZXhOi+9WrBT5++es38ItM1tGFxAfES0QpWBRCYB
O9WFGYztnfgzV3E6LY+Hq1bLUqIC8tAkcDW1WUPgm9k+ad04Fo4uzrmz4SAb
sUS8s+yiNpyk3rS80Um+37syw1WlGfySRbfzdvCQ9371+mpaFUJSvwjNlBDI
rVuX6r2Yio3/TdoGLiL15wxyhgpaUHF9JvO3GBehqt8mA7dXYZVrYWDoBBfs
t4+1tQyasWDlqifXLnDBZD8w85hHw+8VRl17xgbxZyZ/79zIbjxrdFzLvvUJ
1h/+tEaMdKNXzH9P7VoOpkTcB650MbH/cEtQtrUAlbOaIp+96bj8Ukwm6jYP
J/UPHHbKY8G1aPX4Umc2LDNmbFM2d8PL105u3RIOjM7unvrcm4VPXSFJc64S
8N3dwCo2ZeHeedGbvvfZ+PzIUL3gWSNYRUdTr2UNQj9VI2E0sAVVvnbnHRg8
pNq8uX6US8PMWKZ97hUeVKjmr60W5IHyV3nHiSEuXMK+XJiSzoacsdARguyX
hXsSdxv7MbFhrnL45yXk+b4y4mcADbfif948rMXFtAvd4nl2Lyql+iQO5Qzj
4O7QISdmCWQtFLedcieQpLwmYW/eG6yn9V/nnyL928y1XGthDtSG7HMMAwi0
VN472CDCQIbYlenqXB6S81t9yh6/RUXgSy9FCwJ9Ht+fOD37CKuuz3MafLmY
idZ1D+xkYGzOxJqn4QT4E0pTm881Y8d5pUu+R/hI4XAKmYqtGP0mpHO0jg+3
G8zqeatoUE9p960l9XE8W/U+2IiBc4tdU6ZnhlB7jzmz1o6GtqYmfjw5X7+d
bMqR3lwJ6zPBD3ue8pBiILHD9nAF5De8i5pawMO5MtH7v7ZXQ5/43eRL7o+s
7WkPLpd0oqf12LSQ5xB+tcvVph/Lw9WbvxdPvCVwzzZRN1+IBXvqi0wHCg/U
PL3i/CVvkTTPKPBMAgHpsXI/qjgLd37zWDW8AaTKJZr07aLDoIg280OWQLJv
7Znfh+g4o7/vni/ZjxSvs/KMwg54RxjIWswQMNcumf+c1YL5abvEvg3wwc4R
9xJfHwnz8QMnb5J+cCdylVP9tVyM+E2Ypp8lcCC+ir6y+h2+0CM3d2wl9S8T
P/SQ04onS+TcvZK50Dg8P/3xDBWud0YzZeu48Be7R/dJo+PRxORSWUOSP57S
RcVvUFFcUk1ZZcqDkomxQtGuNnDMHIu3Ng0hJUySab35NS5y1HQiY0jec9ip
/eNaPrb8W7SYkCTwUPvaz1oDJjiH/zF6RPJPRfrFY7qfSnH2nfBuXCQgaGyL
cVlEzjNuVOqQEg8OwXoqx7d24iZ3Waj2Uz6oi/yrxZ/VIGvWJQAkb4GvIKeS
24GLClt/q74i+WN59NwjT3NgYl3iFSJBwEZpifQZp27Y7S9oi7Vjwa6V2x7h
14ydTvofGHEcCK1hq/lsdcPtI8rBD0heGKjx2H01hg6iUCDIauch50nWPRHT
NpJjt1GjXMj7wzfSmhY+gG7YP3P2HCP1uBEqLFPxHpwvvf9dNCeQeCKlYcUo
AwpfxdPaL/FRSyw2H15VjIZWX8mwfaQe/PKtM09T8Um2KNZfl4Cl9CbDc3m1
0LiWts+nnsDpmgvrieX18LlKjM6T54PO6nuQM9mMrzMua1cGc7HQ3ShoF4uF
khfzbQ3LOnH/7nv6qd+tGNumuyBLn4fLlLfj1Y8YKKUWbnTOIbDthPz7szpN
8Jcrq2WT/CK6Vn3T/OOk3wiOrlowzoHj3VaJ971lCKGN+v93nUA13XM81bYR
dUrN2X0k3ybnbJ3rFeqLsJd17DZSny2GwSbmDUzkTmp91NvRByY32/uBaRX+
Oem4MHk+gc9rleQdzrSh8X7qDT8VHkKESmTue3Xilo9Uadx6HqQK1B3iQ9sx
0e8RQyP9mfpE0r6/pw0Ut8YEyxdc6NsOGM2O0lE4j7JMbAUX9TPRaY7BdBws
9dswqS5A1uVl/eWLWJgT52+arP8ZokqvU8KWZKHjbdkwh/y/tkqKo593G2bf
TH0+u41AIeXfscEiBq5KGOxXdOIj+aM28WpFF2hWzDB9VS4SFYOSZxxbMOMk
dECHMojIFTLVIW/yQRE5oxJ+iICPyLr4hvZuJE265ahu7MOxQF77F2UG3nb3
P+Q5kLw/z6zian4HpgpEP7F3CeBakLeXL8pC/dzW7zUkPzb5b7OccuxEvyan
eP8HPqan5l45v7sHvScK/ntJDEBeQWOe+28mkg4Z7Chw4+PLjiaNiq9MfPg3
/eTl6wMQrHs7wjWn4X3cjmB/Vy42V65n/9TugnC+Ug8xyYFpYsBv78vVkL/5
LO4s6d/J4vczRY90onlD+R3bQ33g+L+RNIygo9Ig5VnlAz70tU/Y/LrJgKSF
/M919TwUK42/3MbqhUMEhTB/+QlCUTyT847nIfgsXytG+keMSNkuJ/L5iJ1/
QpNm+dhub6iwS6kbkgnJXfs6eTimGdmuSPKQ/Gk3ruc2Hpxn/wgrtydih5vM
YjUHAkO0wY0BMXWQmLTYfZ9J8ukwNcjubwv2fPXbdZ3kzV9Zx825dnWYU/BL
ZYjkHdHW7jkHz/agKVKPc4msh9T3p9W6aoWgBtW2+bSS/cg+KGeyqRKJNPX6
301cSCW0hi706ERqU8+/fj/4yDqSMJM5XIhLdWEyy/sIKK2Z7tFS7Efag6av
/qF8CM4vvXAjqBUn9DiO46R/PS+wr3bkMzBNj654Ls1F7Fb1CAvvDlQ3usdT
LvJB3B0pnZOdg6Beuo0i+f9Sw95pT6IZiO5tkpCs4sB6Mmrl8lf5WNR/3MdE
wIXknfdO8Q/pCLRNuGhF8lK3rr7A5iULMtQ0L9snPLzyk+07RWnAIvfuDaUB
PBQqSPla2pL9f2pvchLI7zUkb8n9hwWLrpIEof/nI0ZFuLHna8ieCzix4BGB
FGvVdT7CDZjJoF7xlOagNeLiwdv/kHwg2/bnivRnSJnp8Cp0GlHJrs5SqyX7
IV7sl4daNoSG646xrcj9udnzleE+JmQDPibdUv6EwGeqWXZa9RBLH2hLIPOI
0mxQqq5OG7TmdUvlswk8D3WO5hyrxfOfvU2pfuR+ybQwki1kwDhgRuei1iB6
A+xCWh7UI/11nkNAOBcfhAWBhUN96FWSDTLYTYP+7WjOzLs+CA2Vf7saIcAF
z1gHD+cKTBeNpDRp81D6bucKXigN8Xb6zqbRArxiDPPfXilG3POUirm/CChm
Gsne3NgG+9zqHQEafMSK26koN7Jw8MpaSbolB2XbVG032NDglSw6qDU6SPrY
6rKVs344nGnHjSL7105sid7hvTQ8JrycW415oOSntIgqNGJmkXPbX2Nyfcm1
Iu/o7QjYEqX36AMbvwYW6Ry/1YYRttb80MscTCwlJ1Z1F2x0jZNOLBsCdajg
ec14A5aMW3F3PuXinJxwDHG8E8d1pSLY9QIU1c+Xl0sqgMn++A1vyPmtfdu1
qmdJO5iqrWFXx8g8saggUnFFPoz1EoOzY0ke0pya1NcrhMXklyWFdWR99WIn
7rrU4JZWotuoFoHe/rS3H+eUIUVtXgHVlEAxyz1Xt7wLGe9tcpoW89D1/aHI
fVEmTj0eObNUjIBnr7P6qrAPECVOndAh/StkraG57KpGOOfp714jSfY/JVvQ
oV0DhVBx7y2byPtVGG82iqfBoO5Gvo4mAZUVX/4KbMPRIm719tFJAhdG4z7+
CevG+NvuqYvLuiCnRlS8zMgD4s3NKSQPZx4QahKcY+I5VUl5A5cLI3Nu4MQs
DcvOfJ02OE7mqX/CPrPP1WNMWNE1JJ6cn8ly51VG1yB6zz3lDWR90s1au6yU
WsAs3COtSebXKK3IzO9JXaBcNObs9ejFTkPPrt7lpD+W3lO8H0LmR3XWiUWM
SswIFY9YCXHRlliqJGaWjLei9Qkylwh0CTEntyW1wnSQUnPvGA9+zOZD2+c0
4Nf2qcZ2ku9Gdvdoudz4iOnGmo6SYA40TG7VNuuyUNEyHtHdTfJHYsq3bStb
wY+aDekV5eDI9u7W2Y89YCZf27tv7xcwpFxDFN7WYXZkUYkWqa/sx67pD4m9
WHLYLTVCsg/OZXtXdlIzcP6IyIgqkwuhVq2uXxElsNty2tK0gIDa5D2xGKeP
EGcfUJhL8nXI1ZFov+NhGPqq3X+K5GOhTbp//r64AG1cyy4g55nWpZBLH2Oq
sCVN7cl7S3L+ZscaLeiiI61TI2an8hAEKxsUk9JyIeJpmaF1kORJmbWFGykd
kIr9W7OP1EejxHJHvOtDaI42uyqTeVal7HWiXGkcrru5S646TKB/3opmTUYX
Tqh1UF/wCGRkl/Y9uZyCE7c2Kvprk3nR3HiOT242xI02PuCRz6c2Elc2avWg
gl4/W6vNRlOpSZqhcxJ4hdOqUrYE5NKkgo/uyUao46WFty8QCL3a13RUlo6H
o6Hjvo5knskPsmmJyMZc+/kLyuQJxO5hdHrWUeHDanBdnMCDzzzXvVkqZajU
WBY7j/QjQwtVq6WSNVBM7JMQJf0vQyOKsWJtG+bk6uwL8uXh8b04B4MWBkou
zV6LtSZ9ZlrDLEfkDpJce7sopJ6hmnfuUL3qoL9jz/mWIjL/Z5+oeyGWjVOT
rI5zIiQvTOwwTB+j4o3r0eUrWARcXvKsXEnecy22lJb8QtZXInk04Wgxrq9s
L5wiv59X3HKOyO5A7BopneIiAR4uTt9+7XIbhid+usp1cuC5f+13V8XnuHdT
b2nebfJ9XwXiNqfaYOQQIxSxjoMvN/kus6rtqBXYjO4qGQRb3TJ1gvUEqVpE
Gv04WX/3Q4UJi4vQOTzMvlxFzrtdv0U2/6jAyLDqb4MZHhKUyr21+vpIvrdY
rtcyhBBtc7evR8rgPiaR/8KQB8/LGXd5x8m8YUcdCFPhImqwudzAqxdBMnZP
lIMFiCxmJGR658P6wpFCGXL9hbl0I2GnNJTFKzr6knkqXmMkKN+9A6rtaoJ5
JI//DxAIHy4=
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41dkfxy2FhhmSbSIMKiNJpaYMve1kkIQWS0Q/iklDUlPJXohsEWNC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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4lekbx20xk6WNCMXRlLVJljDUt5oII7QhIlmTFkRJRMjMRKESMjmU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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4ltkblmw1mkxmDKNsYxpbKpSt3BRDxC+hqQl9pDIiTDLJ/jUqoZQl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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k0VW0bxjXLW2QIrzmEpEiSIpfKUEppQqgkDWYyVeZC6kWRZEgpswoh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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx6VCQ6NQU5JEdJNUpiyl+RBZsoSyDFHRYr1SdmXfkmgllBoq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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs8lOkbxuVMIp1YpWQr61ArlA7ay6kDYamUbHJIG21t6bQOySEkh0JO
SdjYKVJsxKytnyEmg8bMNMZhaGbe9005zLY5pKy2fX9/PJ/nc/9zf+7nur7P
da8MOrXnqKKCgkIuff5/D50Rm2Sn94NY5VWyV1OK6rqTvM+VXIw8ic/sayJg
EbNLq9CNhZaOLew2Lomj2aWaIVc6YWFjqLRe7TVif9Fxuze3Go+mdR7Vfkfh
ieKcF7o9YqyPud+UWidDsPePZhzNLniXrr6+kE/AbWe5flEhBz7sI5kpYyTu
Ff3LfOPBBG/WPf5NIYW/tfm2ybEMnFnis4dwoRArfyft0HmBB3sLDVMqSawZ
rBv45MKF4bcvFd7eIaGgHRzmZnAF4fc5G0L9KBRn7KrSeFiHLLE6j3GQwqJG
/bP1VZ34YEdebeGTmK3fG02ks5BQXJM7S9cMT6M0K7EYm7vJ+zd6pfAp+FpP
5XkHnM5/5kwNknj7Ovbx+5h6rODeuPLZkILCiqsHz/Uex+ny2ZQQfwqW+9Pe
HLbqxnrG8rZPFQTGolMHLvzZDOvrt13KW0jw/vlOfvpDEza+7DGdGicRzMqQ
F9vx4eQkikckiXG1r3aUfvMUa6wVD4f9RMHNv/kgV96Eh7LWndXZJOzn1ZW8
Y7GQWbvZtjifRPJql+BYCwGcw9WcPgRSkBo8/Nkv4g5UeVnOmXTNjX9/ePQD
H6XOzLghiQwK6seP+R0KgNyRnWhNz9srXVc4612F9x6+DfHeFDjvg8dJ60EM
RcWVfFagwHwr/Tu24xU2OZq+ffNJDJYWlfd4Mh/CiMVDc49QsA/5ViR2zIGP
f+rUUlpfK45N4wdNHq4VTrjebyFgT2iOPinnwif1rOHzJSTSZLrTWzeIsOZ0
0vl/7kjRcYBjsiR2EAKhpb/UmQA1eKPXLp+PeaZx9hkyGezX+sUHeHbg4yGO
tyiHxDm1QxnGM32I0Sra1vtIBqPhE+ZGJkIkNLb+YWlE80HUO5uFtUK5ebJl
lR6F8N9Vhf1UH/7VXrt2xkoCp30TJsXWL1DSFcae0qUwmyf6utZBiIDiNY33
MglcDnkfopHXhLqnbgte51Mo+W7i8UVJI263mTIyNtH9VafLt/GYMM6+WhBt
QME575yb2vF+KGl1qJddpLD/s2f92sUccIdif9F9TOL8bt7rsSYe1plNC8M8
CHxsKX0oO1GLJQ3a8zzpeU+bJ00avarBpTs/+WV4UCjNDrG6PCpCorbr6okF
9PuCDM5HqD2DfP+acY1tFNQtVl/Z9TQTs1FzDdto/168bCgbVuzAjEatzd0T
FKL172nPXfc7nCv0QpI9KYQ1zhuyU3+Ac5aLSrYfpRCgkjWxx6MS84NFx7iu
tP9blscoTbIwpqL6vT3NI8v3ZnRMVhesQtoM9HwJpMhVlQUTQjzNYsR2qxAI
P6miMzv9HA/lcfdvCUh8IeUS3xoeBsMNnhYZv0bklhm2uVkXWDW3dpUzSCwq
lSUHEGJsCGItd2mUIduYcXfHug7seFXvHjVA+02ZtMl/qMXQqeMbNxlT6Iy7
3dtwrAWsYKZQ7EXCubh7cZqtCJqh8eHzUqSYn6USIVUowc6bc0KtaF7V1dzP
JJtfwTrPoFuhtB5rWcXum5U6sCD6+67rtL8/Jl8MCnTvgatLmTyhXYbx4NNa
Y1p88OKSQrfbErARtPNOsnvQFGOxWiB8BWHKzZhDzb/jp6n0P4MdKZwZ9Sd3
d9L/s/E5E1tJLJllhCpvY0LXKXV1oR2FZHPF2GbXerB1So27VGlenByX3VVt
gEiW96tXOAVKacQkRbUbBmLzS3vGpejfOcGwq+yHAuPk1pkaKWovXLcY2s6C
l/IpJ78JEmahOxheV5vhaD7saniAgs/5iJkpBSbme9VGztB+JVw7uj2mpw76
3bWhWpE03xuKl1nuYYPsDwgvGCDRS6Ubh6dz8FdOwKdLSymMHA6ZsqkahP6m
jT/y+QNQVvUOl9wSYsRnY09XHQGjxRwl1esXsL9atphJ66c1/sOMY1Q5HLay
3F0DKJT1lTZ4LGqF0FliNcMkEdQ447VvSz+i9634eTRcBgfz37Yb6vJR8MfG
BgcVEgn1o9LAVc3YUemtEaBD4Zvos9ZUKhOB0ninLFovs0vHgrcvrYCgICrK
bT+Fitm7S7tUBIim+lN2BtG8fZnuOfKsAfNZkVdJW5qHnEhpcjYPte03h3jv
CKyyt196wUOAB7n79POTSCxM6H2SYNmDkUmHiE0SAvOlvrUHM69jKEeD/YCe
v23TmY8uyi3I6kv0m6H3gaVhkUe7fzvs7/3Vlr+Mzv+QDdQsrxtDpQZF11pl
SHmT4LeKywdDrjdqEUbATh78PLeiD+FTD5tMNKRIsInXSaT40NufLazsofX2
cCgXXOaj0m/nyrEaAtVeHpIvVx7AmSc0FdB8Mh3+SCpLb4V1wvrhgRLaX3jo
WDZ3w68p7tRAvgzKc4S28cNt+Lmo6ngFne+5idUFrdcEuPu/CHf9jTSfj+re
t6uKoNgmyf8lRwZ9Y33d1uEOUIbsj0UcEq55cSNrvu/HsjRCr+WsFIK9vmdX
iAegOt9xwHSVBEa7WQv147JRERiY2OdL+1kSesBjgo2qlzrP8yZJVJjfSr5s
IMK+b+x98qLofRVl++jdES7Ufd8uMRYROHxypbpGXD16NuuNdAZR+JU9fNgs
rQqVAQW5pom0vjFl1NS1FkSOdfp3alO0Xg285Qu4+Eg5nSijCASrp1XkpvNQ
dODZnOh0ArFutp35OdnIGouws6T9KZCkTt7RFoObGZikspBAss2//iunqiE+
1nfu11S6n6P3rkZ+E5QqO4112ih4Pq6cDTFiQ1F30ejeW3ReTUec0KXnX7fC
dJv1MXq/nWBoWolFGNs9+qzhHwm01yZWkTwWZMXazxZ4UXSeLT6ll8GDbstg
6d/lJFKecBJY/Ht4dMG3FPQ+u5R1u6dxsBu/GSlZ1XxFIoN87fnlgRCbeZd/
Y7ylYLylcsjgBgcXj7Q7/UDzm7Ti+KXzp3rQUGhfsfmQDLzWMY69Txck2eEf
E2g9t+oVfus8KEbBiwWP00Kl+A9Ihsc+
       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8lVkYx2+ytCGRSGOmrqJGiKlE9RNtM9MgpHCbabGnLKOSrTSJlCkl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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHk4VG0bHyr1pkWFJK1UikSIIj9JkhAtSPYthSShelUSsiUhqYQW+541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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk41dkfxy3l1i9ijFCpwWAshSwNJt7NUIlGjcrSoiQyxpIZS0oGWcqU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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk0ldsfxpGkQSGipEgkVzcpU9MjSkgyZM48pEEdGkkZGohSVJyULoVf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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4ldkfvyMyFU1UUlFIWZvQKCl9bEm0GFGSLSOEqNGUO5aoX5YyBiGV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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2kgVG0bRokKSURSyNLyKnshddmSpFfKa22RCG1EsqRNoUWWLBVCoaSy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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41dkfx42iZhQKkxBTSSUZaZmK8VYSERVJ5CYUKrJVpPTYI8SMtVAY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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs41Nkfx4l2hWS1S+XRShaVkFVJ5a3Idcjaco0QueYS/WiFYiMxwkpC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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns8VPkbx4WVJZd0G5dalZRLG9GmyEdsG0KtVJRQqaZy10VJLrkUipKS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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3dcjf8bxpNEStKkNJSMtMyoL5cShZAiaVMotKiEJhmpNFApNIQSDSpp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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk41dkfxy8TUSrpR5RQGq5InqKk8iaRrLOUZSyJspStGN1Kkl9ZMslM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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4lWkYxiVJltJmJIMkRZSMhHTuaJkIISJqsrWolLJkmbJUx05ka+Kk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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lVkcxnUpyh6qUZZKpVGDkjHUPPZUym5sI0SkUGqaGlkqEZEURqIs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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VO8fxSUKydoiIdS3hGxJSM4klSRESkRKRKmEpEiRbBFKJSSVohKy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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlns81NkfxqWSSohKhV0tISKlNCk9dnOr6KdMQmiNEl0kWSkqWhERhZL6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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk8lHsbxh1NHFJUzoRUZOkYLWPPSS5bUXRSlkS2VEKy5BUpSymcKMWR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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lXkbZkYkXyohLTiO0nwx6Ms2VLeiZWqSmiKVyDaULSOpaLW3kA51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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k81P3Xxid+2UopSgslEQrJFqLLraIktzZaUImoJFpQN0WWihKSkIQk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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81dkbx1VSFCKpUJEsrZM9pI9KTbQIUSGMDKYULUgLojCyZokQlcwk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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lekbxkUqUTGWyKRFDZkszZBILmPPmGwtKJKxNkYY2iwpDQaDhImR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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lekfxjmFikkTI0qWKNpmlKY0+N1kTWoiqaRGshyNZJtQlhIqSfYW
sisKSfYRx54sHeccDuZUqudERZ0oNBW/Z/54r/d6r+e9nuf5fu/7c3/VnU/Y
ujLExMRS6PPfm3GF3LMr78bpbxLPLiQT7DhyVN7b8SlaYu5pmL4QYsGnr0XL
WpugXJ+u3HqS4Myql6u9VIog276BedeZYFOpZWbuSS78i7bc/C4kCFV6H7Zq
LhsjK5NMHWsJFixW3NpawcY7d6MDvcUEj6ZsgqbK6lBlxDGU9yGoebxQTilj
AGW2X2Q19ggxAuWGY8o58Jt5u73GiUDeOcIqxb0ab73WcEXHCGazdT5wG/IQ
Ix1ovegIQZKoI95Q9wlKtysOx5cRrHBZni+9YQC326e+3IoVIvPnJZ8lP12C
9j+lD13+IBDNxq5PmGrG4qiuT8ExBN7f88xytwsQkHbPyyJIiDs/uOTnJvKx
0bm0wuYTwd3SPa9uinrA2KY5vWaIIO7+fZ99Yt0oWFYgsfU2wbqsqnv7Q9j4
WapC0NlC16N3/KqccB3B+3IcX9PzojYrZbFV+EiCiQN3vhBlghdxSwVP0P6t
56F8Iv3/CkP+66dWnGVVqK8LIjCs/nW7xu0mZFsbe4UHEjg9GRTo5F6E1tPA
z4fpfuR/V26Sn1mwfuP0xdKXoDTn1iL1aTYWm174YT2XgHmbqWDDGYSMXOT1
2I1C7DTeoPrH5j7wNCwHG+YIoeZQIumyOBqRXqdeOtL9LELHLyw5wUWM+IOM
8CYCy4cWytukuuDTP5HDono5bvWt4nC7odoUJqkRR8BKWjLDnuhDkc6cN/Vb
qF6KQw03DNoQZs9YqHeeoKTsY4jj5yy0afaWZFL9IgIdxW2qeLAN3W7ULinE
7rnOVbsePUHdj9Ys3woCQckTZ7PZakRyF3yM+ZOe5xq2bN2WKrxWaTQfpnpb
y/j2zuaUIsVe1LnahcD0eZ+iQz0bc22anhVmEQQbH/xeM83BpeBow/IiArbN
PsZ6/zqY2gR1RVJ/MaZivX8P5MHgjIKqk6oQTtJtKWbvg8DSrOr5jda/Qs/e
Rm+2HyOuDRZPLYSQjT/EfaHNg5x2+Z/N7wiMmvd+V7QsgXwvs2mM+r1/SZy7
3SAfRsOVboGjBMUvGddTNTmoWP2h362HoEy08kSZQwMkDTmvwigvtS+khiQd
miD/vfK9wimCzGzX5rUfWLDTUM16Se/X16iuUxTABftt9LqlIwRqoWvbR+Zk
w1vHcNKD9k9RX7zl4GQ7Hitcs5bOIEiudDrSsZAHJvMfqeIZgk6hg2/ebT7u
aMWEyhCC3X2J+tZFFbjIGq0z8KB6HDx5UdayCAp579Vr/7t/lZHfHffHKDyW
KPoznkAsRSZiSiUcbDO2hznth/PaIjXh8n4ET+jGsM8KcePswl0C8UdwqTVf
kpNE+Q56LLpaw8Gm+lTNXc8JupV1lz5QEOAvzub5EqeEsPy3jbXo1gCaP5uI
L7ESQlM7VuqMqB5id07xev0INhjGb5Zp5sGkwvvxqkVC5Oufu5QyvxpDjXEb
x9wJeI0d4VpSAjy1LnylT/k9bTJRf2WgHZoTJMz7KoF2uRbrUns1il/7SH33
JGjWLapcG9CJRE72A0EJrSfE+NfIm8fR+HH1iC6tJ3PdpOovjfdxI/VA/CT1
j7eZotHl1ir89HX8lBb1V9mKmePG+X3I1rQw5zsIcTlSLvpaQzdWGNSdDykk
GF8vecLGk4PYG6L1ox8IhlJ9U/7qzYB5n33UBqoPb+PW+o8RAiSsi9qCACHi
3ijJeKSXY/+hpiuqTILh0n2blZ5x8MvJVSN+AoLf7ocOnO/mYA1fbUp/mkC6
U+r3PRce4bj+U/1xyk9adxlj58UGTPo4VGZSvudyjM17xVog2NumInaR8h5c
OJl9swFc849L9QIIqkQWjMNT5TAI1p7muVJ+r0reDgnqQX5jf1szjyC8vc7K
/N8e6H0pz5ug+fzxzfrze/h9MNM64KBM+T1lbT82sqMfbd6FVgr0e+b+ozsj
SW2oib489ob640J18vkM8TbIGP5onx5KsPDqoLipXyPMbbd1XaB51Rm9S8ck
fwATuxmucl5CRDy0Lnjfm49juulyhTSfz7B2RvI88mFaF5o7Qb9bn2ZxLRg8
fMrtYCb1EszT93/AZzyAXFPm9GmqDy9tsH7Njm587Z8oaKD5o8gPSnh3txZG
TsX+CpSXarGDrMOpXZiOFzCDK2l/PJ2P6Fr3o3T3ypzEcZoPBiXqItsGXBZZ
yoyfJrBzMu/6x7MB7rNqpgJ6X2mJb/qJaTy0Fh8TDUgIMS+08WhWeAvSFZW1
RkMIHviJZq9e4sLeIyxmjOqtnO1Su8e3D/LhGw8c0hKipHzvuYKAJzCYP2/T
/lLqh/AFeQz/BHje2yJ9mfqtqubLixdRjchPsNwwQ/2+IHpP6c2/+zAeNb+6
hvLqFF36SE3+bwS6hznupXk3MuwXOR5TB48Rx5JKb7rO801fPd4FC6aEXUom
5VmdKxdpMQjPGi3pVDo/Sp6H+JnZxaFGbpzjQ89jGC/by+vj4vBzxmAdzSv3
Q4zD/WOP0ZpZo748gSA2N8aWr9eBlf1XIv3T6Dw1PnrIa7oXYkcFBZ7LhbBL
TnZ0dR+E5Ykfx/38hfD70JhhG8SB47KWIBblOxg7xA3by5EtW/JHAfXz0eLz
D6eUGyETJz36zJ9gP89ffeZ5F661aeHZLQK3TX8lfDHiI4Cpd92JSfmO++Z4
ndWNaxl7ZzRyaT0qldk7vHrwWlbbxJLql+8dPtlX0Acl+wGteYp0nqgUDOdF
VGP03e/VobQ/5NXbq07anTise7fajOb7xmW1u96b8JHgFu7w1YnmedeK3zoM
C6EpHrGZR/ONFzUum6PWgrPJEmPZVG+9kxdTmqorcHLIKr3NjeBYxU/mupED
dP4ef5nqJoTDWeY5j5EebLLdmV/UQWAuSJ4hAzxoB7n9dG2W6rGrwWpUMgEO
OnZKobTfbFaUxHAJH65v958Zovk2pGsX+3f/HYj55Gwrp/62Evua5pbGh79v
zxz2QSH+D+FnyD0=
       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VG8bViHZUkr8kiRKWdOCkltSSSURlZCk7IlCISmlQomIsqdFtmTJ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lWkfxm3RiLGHhjdlbEljLVQuRaQsNZbkVJRIeaUZEqZUY0loOmGk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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk4lekbRlLKMiGX5WQQCRlGtkrdhoNja4RSkgwtKoOhskSpJEaLzMiS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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk0VfsfrV4rFZ4oUREeKRXuI1Hx20oZFiVRytAgiZ6pXhF6kZBeNBlC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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4lf/7V4iKkqIiQgNFZgPlpaIyKqtCVtKOyKiPlRX6KPkoI1mRGRJl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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk8lWkbPg4tI30hnyyRSk2K+SrLlOgyZN9zUkqSLCNZkqS+fElkKZMW
WzLUhER2koQOssY5zrHl2M77noPIlEzWyffOH8/v+eP5Pfdz39d9Xdf9bHbz
P+xBp9FoidT6Z096Fv9qh1IjaKXnZiXOkwgYCIgQqsYiIF/66YUTJFzL7qVN
cfLxsWeXh4wjCbHzxltl/Vlwq4lpz+KTUHX12Fz8kgOd0a1X52P4+MO10m1g
/XtM7oycnh7gIyPONqHNpgLRc1Hzhj+TmJwyrTBZ7oel1lMbnsEoeksHGOlB
PDjMpkhcKBaCvot9reXbB9i+sNktlkzgiGqo8irtDqhphfOutRMwudjwuPlF
Jy626y194vHhHVqoHe3CwbacJfZ/z/IhLeLzzI1673ZuynsJBRJhy4zQYfMe
tFcY6d9hCFBbRHe7bB2F4IgV6dtcSBTGsBSuPmmCS1Vl8vqHJHhbj2swFFvw
aM/1Yy0O1P21OVmbJbtx5zxrPGe7AOH9DSGGGSw0igWEHZwgEC/c7CxONkKZ
lmjEoOpbepJdfc+HicCTmdKEO4naBkVCLigXvOjNjsMUfjTR0HuBVu9h9rCV
98lNAMklV1F6ChM+P2mo258joXxspPxRRx+2rDp4al2BADGLKoPD/l2IajWW
zN3Hx1wj8/n/SlhgKK1U3NBDICA06+q143l42ewSqr+dit82wdmWMICCTI9V
+Vp8BNxX+xxV2gFnyd2yZ40FKNVfGKy0aAZDdAv/63sCrNSzJj4K5ehjWdsz
XEkMugQrSsWzcb3TfN+ROhKp+62T9dLYEO3X3JxRR8XLKLbUkq/Dg+D6R+PW
JD44VX7FYw6K7zQTP+4iEVLtqvp8vAzestEGH6jzDO30uFEyHlck31UtOJNo
yv1l7+qCAmilWiXRKXxoE0lBEWQMdE2vzw5S/XjaajbmkdAJnQb2MS8nAVjM
YvbOrF4Qaak2HpoCyPk4IUh8AIV2nt1iqnxwVcJcZ/3qIO4wMhq1m+qfl77M
nmf1aGu8FJHtQyKP5XTm+Pg7NBVLJnKo8ya+5kr6XAM2NoTe/aIigFae5pYX
9U3IjzlxxtJCgJYpl2RlnVYwMn9OTx4gkBVLxP/+Ews32zsGBUYk+O7pt6oX
unFE/VEKlyAQ8si8JI2dh17RoU7mKar/4Wfjnf3LoSAflNQvQ+LqxNhHsR4u
JBPiN8TV8zGVV7nO5hQXU2tWXru9ho/e4fDMz/frMPJlpa/7AInStX87VS52
IJZUal+qJVFRdOWcgW8v/jBcfqh0msA3686S4ecvsbXCpngVhVd8myJuyxfC
xzbQyT6ZxAp6buLknn7olurp8XUpvlhUvW2xbkLVptFmOpPiSxKtK8ilABOn
7K/Cm8SxDd6+R0U42HBkXmW6isSX2pN5o14saHnmOIutJxCdIvhuudiDQ997
vu9nEXgU4aCVpNSL5p8sy275C8Co3kcj9Tmo2StyKGwbiV99kx1LVuSCdeCE
9C5jEr9nea0RF+mE6/1+c49MAezEX1Z7Gpag/m1s/qYQEtGheXHyTlwoPgxT
diwTorh818aQa704edMqkAcCwxeXHMO5TMhOrqbby5Jw6ZWYLK7pw4UbVwy+
0wSosOms68oqhukTxroBim+BgRo32o06oR2nMc+7SKDabqjyTX4f9hoPn9Bp
5sNlxsTqzOEuyMv23U0vH8FG3ZhxZb0eiG7PPhmZIkDqd3f5O9kDcBgTVR+6
O4Tg3XcVb4jxkCqY3WdylEDtLHN7s0YjfhNZVvvhPQlGcUDlK+82eBqd0Ry1
JGEXnjR5mVEHhQzzuG+UX+3XNpBLOciGU8JT0vcmH/pBL+mSgT3oqWi/rkTj
Y3J2Z9rFpiZIb//mJ2RT/pY/9GplGg/nrcdmljkEQi1prwtbuZh8OyIxeZlA
QVB+WUIVG56j+S6HvxCoeOEkNjBWCzUR7dYRJolz77dMJwob4bI1Yc1pGxIf
VUw6zNdTfD+QZ/pNg8SouC43I4SNmiPemqORFN/sZ4//Sfmd35cmcyNTSq/C
aQePS5X4vCn2+MwTEre79Cc9vTrx4kbjaY1/9KI6mZruxQQ/4dnXqFTK/1Nc
RNjub6FHWMEvnsTYuVMef4U24JB2P8csXoA8dT/TiXkuJKRzKl2dCOQ7Cx0K
TzXC0ISllAkSLYKOorWx3ZBMt4ouDyUxR0sMwKd32LFDx37mKZVP2gqmKvcV
Dijf+6/uDxRfpSJjR4eZMDGsONlWTPlr/ESwFMmF8Ca79iqlvz30+amGOyz8
lRZe/eYNCZEiG7u/ZVh4bJE7Y7qKwIwP3Vv5XQm4HSobkyl+RgRILrceLEaT
rEd0AIXP3P2zLSkWTZA6Gil3+IgAO6f+MFPR6cfgwPrM7h8JmD1+vbH75Tso
m6kp7JCj+Lv3P1Gv9bpRUlPz43QCiQeRBVVGln04/TVHst5WiHUHdBR3GveA
3jFMTxvmQz1v5Ve5Ay1QHtqrzmVT+q229b0tfIXImByOQJ3yP4dKC8cPtbCf
+55ucJrEb699tWpFeIjoClj2CaP0l+fjYfixAzZD8v8qpPTPVV+dOa3xDDI7
HJhq9iRYDeFzImsLscx1GC/0pOrp1VJgFb7Fwtls3+dlJG7u/2oQ7sXB4QfD
cifsSJT5+MQsBlN+oR77JmhwGI41f7mpeVTBsznDeOcYgVJ1KTOFf3cjaYWf
ieYcgapPy90DUY04yltsqz5K5VvwYH9wERuRVbpFhVR8/6Bki4pfqH7ISAj7
jo/g03z6ZytlDipDFrOF4gLcenxpZP+uJmxjRW/TpvC7sr7UVjW3C7eif8m2
pea3rkl33JvXbNSH+WWcFydQeCLSduYVB6bjmfnm1H+CdYAzN3WrFyGXLgQU
2Ahx6MWfT4ou1sDdM2HNahGqfo+uX50TyiF1d9BC05/EQ47XtYyNXLRfNgn+
IW8ES/REM8aHLpgk2m1RmSYwt6ZvQX+BieqWPx1lqfnMaNwiFTTRh4Vj14ks
tVFw3xFveHMlcE9O3i2k/D8wwmBTmAQbcRaKvy7eIjEs7awsVteGnAlFmkwa
AfLvyaCAxDpUbQgkpQUE/g+NrMk3
       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk4lGsfRum0oJIthjYiOaKyHdU952uT/VAqtCGFHJJIC7K0yFYkHdGU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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs4ldkXx09Il6GSUOaXmsoMXSTlMmr6qjCHRkhMI2OkQyMaalAuY9wa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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VH0bxke0oZAoFZESwpMU8vBcQiUJRZZCJSQUqUSptFrSRknIHpKQ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk41lkbNm0oyRBJUzHK+MJM2ZLKLUtDg0yKdySkLIkSlZgmEiIqSray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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs4lOkblnJoR21OJRQlFhttZSVbbsksyfmQVidGZEOUyCU5TAezndNG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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVmk8lVkYR4kWQooWEw1RkaHlltTflEER0tiaFnJVQpIl60QkQ8nQSumO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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VG8bxomoqJR9/akQSkhFpS6hUqFIe0SSQtFiSRKFEFKRrKmQbFnK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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlWk81ekbxo+TLamxZpkwNURZImUSucrIKJQ0DUKKREgKJUsh+hOVJiHZ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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk01ekfx62hjFHRlFIqaSM0kdL0tnUqP6HcqZtJighZs99RZCsi+snS
QpgKZVCMfbnWuLbrXm50Gffe71dKmmyRify+vz+e85znnOc85zmvz3vZ7OB1
yklCTEwshVr/39nm5Q0nuUUoi2LfkzchEe3+NT/zHR+ihMcro4cGUTCRfECy
oQmeEoO60edJ/Jo9Z16wgw/ZsZei0ssklmvs6u8QcnBOIjuUlifEvYY7wWpH
hiAY99v8w5khOEw4Oh8K5aFWPPz9/KQILhUbToyPMVH5XSZYIo3A6+YzljXJ
Q5jvNzzrWC3E+oiWfetd+xFg+LSumRRBzVUh3/JMA/4NfzzXpkJCa9Ou9L1j
vZDzvp99p4jEpdEFoja6HMteFH02p/5nUXhWjl3Hhryet1CrjYBt7J7ahkIe
BA2MN18VhQgzPdL6o3MyIg1HV8bZkjhmL7AU06zHg7pUQzcmAeaU/ZY1AxxE
eKqk288IkXkuuvKMfzICnjrSey+QuHxupdws7S1Gvf2M1w4KoRnjEqxXxsS4
RvXshtUkIuujYg5ls3Gi8Ely9DICcd9qRHddX4F3wrK90pxE29beSKP3vQjJ
c8mq8xDiuYG5Ums2F48D6qc/M0WY0fG8l+PfC4ORZuWuZwQ2LrJkbug2IsN0
n5q0Cwmp9JvqKkvl2BZ6YOHJHIGwjuMPWoRvYJIREnmAJcKah8EPtSM4sHuU
N2NrQmB5xucwJ6l26ASPpxhR/zHVlLapyOWDHmJA/ygvgPUK9vfr0RwkJahJ
3r4rxPhwpqI1nwdatHLawJwAal/5vfMmz8F++W6ftiUJsfS41rK8AZj7Hox7
oz4M/Ui9PnYZF1sf0fNGPosQ5lgXcsfcG3kaBvYB9iT+ENKkRmLa8Xw+583b
FyRUIku+iLqrwTM98ck6nAQjxLT5b5s+hM0kMo6aCeFEK12ZdqkZiXNx/jQu
iRn/9fJyv7TC22ro90LqvHwqXXmqpQvXEzL9mu8RSLOItvFLakLArrKeplkC
W4Yjbi/v5kI/dERRP5Oan7mh6SR/AEzOtXSLjwKYX7TxTaV43dJ00pENFcLF
4alqDJMHfVbQNm46pTe5k1/8kpMRVHxrn5MjicwP/s7i/YUoxhYG8whJ8fpN
c//JHAyuU+3LpXgovZvnGa/rR5uMVZEoR4AvrZ3itSNcnLf1dNabJPD9mCjN
3oeHkj+fHU+2FCHR1tVDfYkF4kcVJeOzBNxZ4yhuZMLigtaFfAkStO6lxLrP
bSjxdctSUCdwWvaZy2ZK/z452gbKoSQSJeejimzboaRN5zz+kcDsvhcf4kc5
4Hyi6R0vECLtta3S+Uv1ELdWSKrYOQK6Zl+eKqsNkRqMf9hXCbh11K1taunF
P1LWctmHCKiN7DVLvdgHq1Vigm8iiv/BBLJSYgg3WPU1PkcEWH/uz6CeljY8
CNQuTtlO4nvNMwOp5i60ThQvcR+IoF6u/shrfylMrsVqMgJI8AZy5X67z8GR
Cj/uogSlv8k/FKsYHOgv6gS236DywcpeKC1Zg51rlm56RFB6aohtK54axMKI
eOhviXyEeUibaDn5QNI4iNZG+Zl50ofbHuiA+dyH6y5SemIvm7k9mjQAi66f
/DNrh2FyWn+vcQsbe/r4sp26IlzwukN/p12PuBm/7Rwx6j72NLLX1WNG97vr
uzoCNXVk6JGjgxibq2s4aiIAKRtSY2jdhnfbrty+TuURvb8rMXZzI1Q8Ijqj
SQKxf9eEfzjKg+Y8GcteJYRKgO8XR6IFsYW7cnrKCGRU2vEqGjkwMq6+/1cw
ieuJZaREaC/lz54tMTSC8sutym1OcZgyrhn+eI4EvcAolVvbB6NN/tv5TgI8
COs1t2pio9ixzfbFohD54jkJQX/1YbGU87vnqBD9qHwmtvQSXTvGvM+5kkhr
LVjYXdKNfPqcH+MugUy1ZfxtBU34ttR9uuQ+gQvNrNUpfxfgGONbrDKVF9WZ
tHSZqETIxv9bq0vxnFLlNJ5ya4TsWbOXqj0EzLS6d9p8YCErq6heMZvA1aef
rKYDm6BH//lQqSSJEy2/tspffgMZuTAN1zER4k6Ph6n/2YxWE3uW1BUSwar6
nnZVXEzpjvUdDxFCvy/D4dK1Hlh6r/aVdhKCSUj9u6CeAtvXn1a3UHmbqyW3
3v2/5fCfzNaR2EMiqBA1CnerQH9jL2ssR/l7eKFKpqcXXma9Z64kC5ARS0YE
ugzAJtzGN8GFwIZrj9asWWBhtm9v+JA1AWVB79PFFT0oGGcsCzgvgth0vsXY
KzYudPzjUOouwu7DYUuuwx04bhn+nUnl+6onyVaBHC4Q2yz59DUB3u7HoZ7F
LDit8JpMoPjdXGaovmTUD+/4695OshTf+1WjZivqMaHpePNnPgGa4cQVjawO
tHX2b3dUJKG4kftLtV0WNsbfNW51pvjmHc95fpmHz9V7UuR7hJgNSEHkEBvm
g9NS0mZUvygo9E8e6sCaYxs2iLRI7FBd27/o3IjT/xkpdlUg0RGYubW6vQFT
MREWc0ICjAhvxZiCbOgPdQZ8OEUiY9MGlxsHGpAZcy8x/gcqjzxOrTAKycfC
tIW5Lo3y07S2/NRkKeUH9uEzPiTei90J5X94iZLBqZepeyn9ZO3+9MS4DtUr
6akbBZRe3nYcPniwFKRMu7jVJRJxlqWXxa53wEbTiC9O5Zf5xKO88qFmrH+1
qUXJgYSr3enZAX4vaD8lOfYcIrHyfcR1u7Mt2L86tWQtSJRzbzSp7+/BxMnZ
e+2fqD6wivJqiShH5ZaLZ686Uf114Brz8mQ3sod9zBS3Uf2YEbBp1uQtXKY7
k4t0KL2YHa64xcuHrGIBI8qXhIH41Ss1iWU4ofVALovqC52DmlkMBS54B1ZJ
5FJ91/DK41e9b1yccreIKqKPwCWr0+9WfTsefdUhNRiU/4J+6DL1ZYFhw5JO
zxBhx93WLm2lQVTJeOZtchbCS/qF9nxSI6KHe2YuUvyMmL9ztx++ia2j8W76
diTcW7Z25n7pxBa3IYl4ys+tyDx8y/c1cus8Oe4Z1PumW3e6Kz/EndH0Cj3K
324nVbSkktpRdez5x2PUvP8HApbGKg==
       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8VekfxzHJJCpZujVaUNJm1MhPDX0kZIgkeRHapGxZJiI/e5ZIuIpu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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VO8bxkepJG2SUlIkUSokJNxJi9Q3FFmStJItpAhJkiRri1Ck7JRQ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkbxw1lMmVpRkg1hGTJUA0Z5CMtthpzkSVL9lFR8sOvSK8KISZr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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVWk4lWkDlmVQQqnQIkoRKSRJk9tI9krIaKI40aIGTVJJqFDq1BgUooiS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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lekbx89UlrIkhXapjDMx0igjla+UJdPMVYaEZD0lIstIMSYNv0K0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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8Vf8fx6VCUqloSFJUZDSEUnrJKElIoiFJFA0JWfW1Z0mKkJBZIpIy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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk4lVkctlylsSRRKpUtSe4kGUvUq6QFoUUqauxki8oSStZMY40MEyOF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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs8lWkXPWWiwjflUswQKsmlUBkyxiLllsott9xCTWIQOSoqJiFMBoVQ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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk4Vukfxt9EpMbaKFmGphUZLWha3GqSTGRpGQ2pyFLJFj/0miyNnaSx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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VH8bxpU2lBQV2pCiTUhF4UZESIulkkokKglFKmVJthCSrRJZf0gT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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVmk8lWkflnpTxiClhKTGHmUrKrpMTJZBSoulKFGSUBHjLccYS0ykMqmx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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs4lGkfRohSmf2QDYlVKhN9RFPZblFJtZSGSGE7LPGVSUjjlEjKoZNT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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lekbxknKRI3UyCBFY0mMlpGaymWnMmWd0akpYznZ0mYdzTCpplRE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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3lYTP0bxltElCSRXmkRERUtr1C5K0miRQvZKyWStKC0F/FSkhYKJW3S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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlns81NkfxodySZLEppTUyj3lstpl61FZt4iipIvsGNJlk1xCoabIliTJ
SrZ12Y3cU8klGpkMBosYI7cx3zMWrRZp0yp+398f53Ve55/Pc87nvJ/nnHXM
gL2+0gwGI4Ue/5/7tleb2Ju1Q81BK8mPQ2Hi+XKR9mc+1D1KF17NJYh3Tx1L
zxJAgfQcidhKoTPh3NryM52YeG8Qr5FLIbVYM6wwQoAxkdT2QikJGHNsC7Wo
XJwYVz0e8yMBY4mDCmOSDzPlsHytIAqn7xt78IN6EamnM7F84xBcTRO5JyVc
aC75eNpuiECx7uwyqwIhmnLDt7l4iyAUZzU93JoNx3KV3YM+BMJMtcfeHyqg
mFRy3rGSIG2D8cZu29f4uCU6ULZejPgqnuwLt5fImw34YuhA1yssmMxZKMD5
Qnt9M3cCZfmXYXd66uAstBGPPCCQFikYPgnqxFL27AXfegKbdfUi32A+JlrF
G8q8CMzj1wR2j3TCz3nCJ9+P4GL5OQ+NW63gzj0w+yGH4OTIeP/1jnbU2lvw
JAMUurNmV+wYegW37hqmVxmFLO7+PLevhUiSzT9VGSqGuuxotOgvPo4lG9x/
u53gwnSEi5lLGxZFF5u4vhNDeGPXb4zIaixScIxQySJwWrcz4r/A14iq/Ohy
mk2h2fCclLRRB5IT7l+37KGglVWlmzjegmfD6XKa7hKoR17iKuZmg7s9zM2E
SdBKfRVZ6ShAxTl1/9o/h2CxaUG3Ylo3LDZzdOK0ab3xNvXdh55BkFy/dsyX
QH11jNSxwF7EFd+7mNMmgck6Km1xZC+2degzDBmDmPHY0Zyv9CfCh4WKghaC
qZiGghGVKpiZPJz/RpNAq/HdoWYmF6v3rdt1t4bmZXaCcdn+KUpOxiRr0f0/
E089PdDwEML2tau32RKE3vL8GPioA2uz0mNLJRT0/Ke+jD7ggMzuS5S7TfBv
3ZlPB5V4WM/2uXtiI0Gue+OsoImHkw6/9B6vISBmEo8pNwG8zlSxQK9TOO/N
iUo9wsVJgbq9BKY3Vt72ku/CcqX4Kq0AMZLf68dGP+Ah7Whxmkcoga2509fr
TXvgKOfm4nZZhPDvLuUk7OtBUMpSGal2EZjGXj1LrFqR2NyrwVpL4F2gabgt
8QUUXdc8XRxG4Kqn+gQ69ciw6Nhyi9bL5V6OS2GxUV3subnlCM0TK7NmRrEW
15YVLMoqo8+j5O9c31iBJyqpm1iuBMl6eVRXUB9mRd9GLWINg8nwtjS90g3p
ZKlA0zmCYT0XGYuNXagJFg6kfRKD48styzlchMovuctPJxE8OLj+O/dnHChP
W+rbswiYYzcPhFq1Y/e/49oJ8gQZd0MUtKp+g4Fw83buHoKebUeajsz3Yj6v
xPuwHu2nQxWFrK29MJ1elcO8Q8BR9QyVvcBDUr3R4b8XSrB3gL9hgW8nBjzN
7VbckyBPteNd9v4ahNnZPPPiUvBbaV3h5jGAiqNdtpMeFNhng/X3Z/Jx4JP2
tK82za/GFEcjUIj7d/sn9T9TEJkn6mrse4y2SIPHjiYEp1KnSyY+tINzlWXZ
0kzh+FfnHzt0CiC/y3Pp9/4UHrp/uDVa2gaNBn641zXaTy/++Ggsfo2/Mw2C
Su+JceV98eeVsS+RupYV4RNC8/dm07fms7nInutTLaf7PzFwX+apCxfvelt9
7SMIUOfXGPJrN9yWqo34x9H5lNBq5Hw8AEpSY8GltN/nS+RuhAW+QdeVKqXz
Agp1n6wdp+70Qb7LYdX0qgE0qVhyGY49MP+3aMErUwl+ECVyXpBGZGxh7D1I
86z2qyqv4m0f5hR+d7q3m8KpyEkfvas8nIo6m5l3luZ1PM2sgP8G1laPDnQV
i5AePZFkHNqK2D2MKxmlFL6ouN7L2MpBYv/VfzbS+bq9z7yooK4R3lM/H+jV
pWCnvzn2UCkP7Lmk7NomCrF6ttf3X2xH97DnniJ7CXLTrzxSZjfBKq8lyugd
oX1e5llVW43zf5Xsv7mGQGaZ4s+OG4Vo1Yvfo+AxhIiZwwVBCS3YK6Xmf0Sa
wrTPwQ2WP78Cs5/de/gHgsde9bJOVgPwtbigzF8sxvIT/Pz6Lc2I/U9Gd+EN
CpZW3Nf2Om1YPeBOkuQkmFmd2XPTjIMrLS01Z8sJLutucLro1ouIcYHUq0dD
sHWk/NSdOiHyZ44K7QjixqOineafw0Byupi/hEDvmptHVVgJNC6Ox1sZEyzc
MVjOc+QhLk5JYzSfwOdFBOurJ0K8T9WMs/hejID/5v3+OVgGlRRm6ZgRwfdW
e3fuy+Nh8rHaluw0Ot9/d7BrofMiN33roSfDFEaOflZukaqB/FWDnSpdBFzt
mp4ap3rMjhYZv9Ki92MgHpxc2Y0Ra4PLCjNiZG3eNQNWLYKeCjQI3b9hQdPA
kf6XaOacmOLLEIz4+7q9la6C7Ms+Tc5BAusNoYsseM04c6LmnE00BYaCZvHQ
+nCEOrNCAo7SvP/FvBFj1IT8y/1ulXcpPPeojjLa0o6M0pA0iQwFgT7Xr5Lx
CqbW26Tl6PptLZ7VFru6kFd8++siXbq+kU+THbMUsZ0/Bf9C81ZSVMM+1vAa
s2Oza+5biiH/dgk3VaEMpnIdlWP2BDWllqcC2nvACw+3vWYmwaX2Z5z3IZ2Y
W9SUowsKwbq+H7JuN0LHL+/hj5Agwy7VJESYjnQDKe819Hs7nZJIyVkNoreu
+/N+82HYK+TGfSyshvqt5ZdOlBJs+0XQ2hPfhRjnc/26YjEalKqUbaveIIAf
7vCN7TDca23HNh9vgXnpMuETZ4JPfzRo2Tj0wfb6kDObLUJsCLuw/Gk3bGZD
VuwIpM+z0iNHqFOF0+VlyXGZBEUXDC+svilEcfDQ3tgPFBT0GHLfXX+NBGnG
INuegtUp1/n1np1I+mnVUpVQCe7NJLc/82xH7+Sf2apnKbRFxZh3NHbCO2pB
YJgDff8PDO0yjj2CH/+wtpjWU7UvM7Re0Y+fbJg81gsCUeUyp3D1evCiqkOu
NdD/BTLffreVhxTXxTcL52j9t5sGJ4+3wvTOwtRoU4JyldHGVbcHoMN4joBu
MSpdF5dJpQrgZxOlFVopxv8AnUOv+w==
       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk8lekfRSgzIlpoSlrsU8lWSE6hCd2QvUT2QgaVSaFVKCoKTaSiQqhf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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4ldkfv5XIVqFFaijThEncbKU0H9OoafWzJKZBsmVQuAiRuUmLGPta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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k0VA8bJrKWVEiUpFRaJCFJnpSEhFIIoUJCKilrslUqIrRYQphCEkr2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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8lWkfxlEiO9NYUkLbUMlkS+TSkSU1lgkl2Rq7VlH0GiQaLUrWprzI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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns4lGsXxp2y07Z9lUJFCqFMmLZj2t2knUPIIW1bhCJNxFCSSEcVqW2r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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lXkbNrJECG2mUWGYS4XskeVusZR82SZlWlDZ6mSZFsqEZBRZChkj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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VO/7xylbKomSssVHZa8UofKW4msthBQVEhWVKDtFilAUFVJZIoXK
mqLsshuMdRAzZ2aIiJBK/M7vr7nmus5zrufcz+t5369b2vGyxdllHBwcpzg5
OP7/twZbtJYrtcPthc26yWw6Cr61hw+ZdMH55bvgYD8CcmU0bYGWKuzQHt7O
FiCgnvP2D62nB0aGL+c0TzBxL6/BJyqiAzz6PDuEnenIO1DW8sl8AMcFXNtM
3ZkQKZE9p1XZD3ZP7aHOZcOwaPjwWEanD9+9BKT5Z7+BEm+T25VNhYPWyFBp
aT+Kz2ZLdh3MR9j7EIff3AQ06J+90yIo+GKcaPxJjwFW+bXv6zZ2Q8v+v6Aq
s0EsWtOzWv17oCJ2xXTPOzqKo7/xNUbUwUJt/Ot5dRZuK+cbS4h1oMO7KCRf
ko7q3eZ+YX97sfuIoEfoyDiygw5vmO2j4fxUqWjhaSYGX99+fes7FZSruvI8
10bxT2qo0fZBN+wHqh3GVrBRL0xcb9zfjGtOXsuzTjPwZZUZNeUBBS1X907k
Bw5hhHp03SslKhp3HWq5NMmE8fuQnFxDGuwL+Y2eaNLxestVnok1VSiNODFx
JoaAXbPn8CPzLpzyPZ94UoYNJTHtLKGUFHiqHh+aUSXg1nckcA+1CxFeSrXb
Rpm47ZeZoUvrxroCtL4SJJBEK9jPyuxC5oWEgrJJAv116sVJ8VS4GguXx75l
YMD9vmLIZQru2V3XYGaz8M5JaoLq8gEb5gauNbUywH9HsvlOIhVD+Q9OWz9l
gOOn91nR+QREpYT2udgTsLAdXftSoRNvGG94vYyY0NGT9skOvIXdV/usy04T
qPsr9EdkfQt0KsqWJ1xnovzgjrIUogHnK35O7RUnsKz4j4aJUwM6jXefDVvF
AmGjPZB1vxXWORumSzPI55N6KOKThdDNmFJ8rEzW4/YtFXmvCiTF1YwFHSOg
lYKNDO5XSHY8q+ioRGAvj1TAl+00uJR+ylsj0AXx9iyz679LUMvdenaNOYGA
zd5Oz9XaUOFRE7/GhgV3YyPpgxpUxOz/ISUcS4dzxSqhRgcKlKI1nd/fYGJ3
0Y1/vPGNECoXGdB7zkTlXssSFaN+aMUFWdyfGcHIjcKow8e7MHvtg+dZFhsc
E8skNRL8QFHO+fPAkUCIg+mLzw5UHLJfY9y3fgSL1AOv1vj3QdLPo0/iBwFR
Wkb8HfEyKHLyFYxsI3BovGttxuEuCNZRDnm5fsVH2ehoSPegTnvc4dwv8vyi
UwzmfL6gND4rIy2DgVWaCQfure2G+ubTKqEeo+D7kuL6ra0V7htHUsTkmaju
bTZXX6jDR/5Ay+9XmAjtN546w1WPZ3euJvdsJuA89tqhktEBuWsX5H45E9jR
ZGVvjjLwslZJ+5gxMF9+qThfqhlnw5jvKngZ2Fy7lLznYQskHmn8srg5Armw
pMs9XF+grH5V984FAo9mfY5ZydVDWE7GrkKXCRut5iwpzi4kZ8Z+5NNiIt57
8onCnxq8NDl6cUMgmR8DjS0XgztI3gPco4UI6HWp+Ke/a4TC+zKuthg6mnq/
1ca86oH4/04LxrqMItpzb2oevRNel2pdR/wJHAhgUIMNXsB43emQEpL3M6ob
bo8L98LRfIPf0HwPnC/yJuzPKwbVTeHhMiqBdr2DtecWC1GtudLn1VYCfAOv
2B5iReBqOCPhuo/ADXnRp1WbrNBe0LBRjeTXPn/XMl61OHC4F24esCFQe7Rw
53K1bgQMPFux3oSJlY4ixc9ZA7jPE78psXoUc6kOngmbyqGeov7M4jeD/D6+
69b0FgyGfjflVWJAXuLE/i1ybYicspkLziJAY2lHTMf2IXFajCFx9xuymlYH
PX3Wjp06nQIqRSQ/wyqBC5PNqBubvCdhSf5vv5oxzNmBJnPa3gldOri4DEqt
fHvxgebbkutLh98X10WFa5XYXeNKbWcxoGNybNXa4TdQleAvVbAikM3tfy0q
qxlhh2oT428xUL2omV2yVA7+cWl+bkMC5dnyXVcGHsJodri4yICsB/e6uoTh
DygIaPX6q0lAwuPO8nCVCjRNqM4LXmFAIc7Hd3QFBbpHFD7vCybXc++5kX2g
D48FJGPiFcfAFtc/uDa4BklRdSxXN/L8Y83fBTgWgS5t9Wmchzz/6afcSYpZ
sBi/6TIeR+DJ0g2dId06uN3XsLxymUAk61eGolc1pI7XhBh5kHyFNT3aZEVF
zf/0Oa5oEPC5d2S2VjEdIrw6I8fsCLAypMdGLdqg4RopL6ZG3u9wZ87rdzvx
IrhzT4caAYo8Q2LwZT3cVPzN14qR+/l1AVdqq6CbwD50vpVAq5Oi5NB8C741
zodrxjEhvGmrcnxFL1q07Aru+rIxRKMsvFz3EMGPh6VNTpL1CZ4v5+VuhcG2
+U0avizEmPoLPhJLx9REQ+U0yed4i+zraas+5MRF1UbFj0AwM1/yxOo2+Psr
Sz11ZMDa+y4leFkT+BxktQ9fZKD1bZ5c5kIfCCWn1q8KX8Gje/p8dEkTXqQ5
1k/LMpARZPA2juhF2GemnizHKJK+pA0e5mtA+MK7B3olDKwMUDk1fLwblT62
nDOd/XgRsytutq4CUe5nff9FkTwHVtPUVb5CSF+dr/YZHZXOZT8T+Xrx1t7D
VqaCjR0qoiPRkq0IjnxdIXSLhQZfuRklsl+IaC0Uc1my8Uc2YGDqSh8m6lr3
JB5jY7dER3xbWTnyvqslBvETkMkO5b5C8hn+oWaxxIQFE9nS2AjtZuyNsPfz
Xs7CuWy1XVa/u8m6X/KK2zeKaiqxwFLpxQtuk9St9Sx8NLWN1/HtwmDOkn71
bwJDXs5HZr36oN5hPxogSIf7n7TAQrMi2NeIz1sOMtCjUZrW056OE+4fCL+N
BN70uvglnayBUY/aL+U8Au6db7fkby7G6YULPE7vCEQtNWQOe3fCtjXQd83A
MFzfLi5nBLSBpZi4jPKMiT4RK0mpiC/43JHEZ2dMgCNWccvPWEPQOTZOa5J5
cO5yYZShdCmMmOt2zLsy0XN3vHEXZy2Gb3oFfvNn4p2LWewmyzzo2w/InZ4m
1zd3KP619kVRe8TDfnL9YtmpR6+2tiNcQDLSj8xjcWuj91UFbdCzP+FVqUfy
eVFXv/7lO/y+Jnf6ZgJ5PzY6JFfcrIdkwh+NLWS/y+x547u/ph3lDdoRp4tZ
sBEXUDHYVgHPlEZbHxD4oVfN611Vj7f676sDi+lY6H963/xfPSJ+Kg98r2fi
Z2fGzYXRFjS+lvqk20j6HGHCMtQn+3fwi7NW9wiE893n5A6qwsCT2FTJDgYO
niyJrdjwFjKNOc8HyghQkzZ+nuhuQbG4VGh2HB0c/UOftrDVscryQece8vv6
lyYYkWGfEVAs0e42SyAiMdfCMr0Db953rgl2HgHHV3dVWnwCuDZ5CNRcIv1l
p+Sak5/q8Oymq81dUyZ+rJc+FmuRiW8WnkH9VwkIOi06mAj0oCVjo+fgASbS
Pu4UNuTtgLNNk3OWPhOrjM4pB082QeX4Tfo2CSY4VGSq39tZYWyJtX8ruZ/w
/DC3tYb1sFi365TJCiaeqKce+PvpPSgCPDdiyP6jFLgyo8twAFQ7x56cA8MQ
MmddPz9MQ/SPRsm990YhKEIzMfHuxt7tbarar+hw+3n3220NCvhWbRu4IM6E
oGrscJhkGrr2ppe1kXmUHRT5UlymEylKE6oa3EPQmd2cpeBGQRrHi+JXZJ5f
zz0QV2jah/4x07UvhehYmoy8rJ3TBZ4l/79LT9koXzl1yo+WC4uOkGJO0o8O
ce16kGD2HtwNX/Umc8i8aG7e0SPcjm0X7nsQciOI+0/294JjF3ozxI3T15D+
Gti+RN9eCdU0sWgZEQJNM7YuCycb0bBXTmRvLRPqXnKam22aIdDFtRDeRNbr
TcnXx28fw0z2yInlZwlYtuUfq+ymoomgMRXk6JArOXTmYmQv+D45GQi+ZsHB
2fPQxXkq3vw85fXL6Ss0iAKBLOsOhAq6vv3xhgEDA8+P8SM0VFbumqKQ93Ne
fuU6bZ4uBCudefhLaQj7lN8kFB7shE5w0FeBJTbuKTFTHFYmo51pZhlP8j1U
8mby3OokiKZwhxq5EjAMChOIuNMPlZ9fv7TJjeEBY8uKEScaQqT85n+uZsKH
x8KdsqcHo2fkDVx+sCC3cKOUi/kBzjJ1FQZdpF+tdAjzqi5C9eixBKdKAsWR
+voazVTweH9mpxWQPN/6fPJ86zvEKMcnrvhM4J9ZcEioFhUBM/3f/mXRMeTf
/chguhlKiiGxn9hs1KY+zrwb2w5Cf/PCK3EGfrxeUDkymI+VrrIdbU8J/A51
OpJ4txafAwb3z3vQEXrP7IeYVQOsgxlf2ddYKGg/0y3MosHI/eLWXyOkH6QX
qaXvbMSjkjVrfIKGYfO/r9v7OL5C7IxD6VwoE6IUYftR8Q+YDpQ+vaWUQGmU
Uu3/zlRijjW+HuR6ywQHjfJlNMw9vK0i7fgNvE8sZp7oUFHxUT/NmM1CuZl/
6lzrW3w+qxjFuZ6AjuSn42MZVISKtEiNmA5il+1GsVh+KjI2E9MW2gQ+cBa7
p5xvgM2b+YlnwwyYjszL1WygwT2zYmmSQe5PP69f52EljGYeJhuO0aFU85d3
0aoLWtttO6AzCPX3jrqpBm049PE6d8UDAjwlVbLKd6lQkdhBdylkosoq6UAW
me9UI639T2JHMWh9R23viipcF0sKUFxH5u9FLx/RkB7Y3lEPZ3zphGe/bcLv
u30QqPtwqoB/FByL2pX547dBnPee5T9PQPf9HYN4vzpIV8p5h/cOI1ND3kdc
sATfuB9vkiN9paPJi1usgAIjMSMZ9jYG+HpX/ani/4SJabeENRYkD9fusR8p
lyE8N/cf5xYm2vfZveQrpmKljKFeBek30VtHgwxs6qDWnqfh84MOk9Dgp768
FGzSiStfGBtGneZcXUYTBRl71RvTAxg4qdcXEq7Uj+gDEjxh6aR/H+pJnR6t
xkyHumgeySvXyR29hVPt6GppDhz4OYQ/Efb7H9n2QtDz8u2wXnL+2V7KIbqh
F0Nh4/r39rFh757cltLZiz+T+X9dbjPx4G3B0cwGcl6O8rZMEaYjSH29u+jK
TlzK9jqYWDWIOHU/u7KOWswFyv8rCGGi2F3ZQcmrDNZcVEwmMvC3p7iiP7ID
ggkuzDayXzrNHwlOv1WOG+vny+ZamXDbd5MRGl4Nnm5tGcp+kpf9Sis0a+vw
8G/mCVMagcAwxWe0Pe34NqefcfYzHTEGXftStzzH/L4rroWnCMROHu9e2tyL
45Veu3e9H4LoOSezoloK+HmnTGlzZN5sypxRT3JD9eqWnGny+d2pyxq6LWox
HnLhpJEJgfmTZhllN1/jY6TnPW4XAmP5IhopmlRYtrQR+WReOi6d4zH6XgP5
R9sLPqQxEL+aSu+nNCL5nJfezgQ6flWz3TKGGxGRU2GrWszEIeHKVZe1uxDj
/XOz4X8MyColPbX+nAeFF1X8EqTvd9SaLAifqkSc3AxHmAITGnFTn1WVq6C+
cthYZID0u4BjMjs+PEanYcyJ6yqkPw25JqxIfgt7fZXTYVsIyM7OPKcod8JJ
6OZvji90JDi8sfh9ox1NZ1g2Nh4MXJBX5p1MaED5QuqO5bvJ95WL3hLdcB9K
X8JS68n+9C578lNudSvmO/ombuew4a/2eCJyIxXBZdmbK2KGQTjFdL2+1I8k
t9bzHGMsHKMFTqwtagOFc0TI+x/Jl4dHyNaLnXh87nCQAXl/z106uiqjrBfP
qwOExSls2Mn/d+QolYZlFmLb15D+O997g/Ja8AuYxSmdabFMDFz13fVqvg95
45qcQtuHUTqu+Dq2vBs7cnRGs66z8cO+sbtodzsu/jkwb27IxMXF7vBNTzqg
GaQwt9ZvGKI5SgKL4iWwzO1xLRYlcNiQT4h/sRNtCspOW14QsPm5Ve9d0hMs
i/vfcQlyfuKAidg2ohq3rC9zWmQSWBltUft9rAMbdm/bNEjyTeF5t8LtViEM
rvGdyD1CYJp/bKFxeRvObKk+uq2fzLPyN93cva9BD+U6nrXAgBlvhdWAGBVi
DU9+V7WwkD31j5c22wdnwY7k3AOj8Jpy4c2/UIGqYaYmL4WA2ayri1ZcOVT5
UyI2jpJ+XiTuObUjE1KlXEKfSB77nVdcZz+vQ86xc6F7zJkI3/NA3/tZLTxX
GFwNLyagcfdcHy8aEN8LKa8oMt/rC8Pyp3ow43Fveff2IYxkeuXv3PoRr3Kp
hQ0XyXmRYrdCc66b5OR+pIglyV/IrbUi5b3ouRY77HaK7I8SnV7uagkwiWRJ
LZgSiFH6PThaF4uow7tES8h+eCq5LqXofjsyGlelZCsQMJ1I3Fpyg4r+N/xG
qnl0mAckc52MrQMHh4aScAoLhzyfXBEzSYV7pbvWKrJ/lq4+qs0Y6cAFs7NH
8yeGIJC+8rqQ9n1s/buT9Y70r603NSx8/dvxPSvhAu+jETzUfO7U+aUddbdj
Pt0vZiPm14lZtd5kyGUpBeuQfpBUPBiS/7wUorlXD/CRPuO+9vSR5cuaMRhd
c4r7L8kzSzry3I96ZCc83+hsx0Cx6sfzPz3qEE+P+M9VnPRFyWrVjtEmPKvX
tdMJZyGLYbopP7oHer9TyztDyHl1puDUk5gs2PVXaXmXE1CVrayyNaRBZyLd
yDSFDa/Ahmy15H7kPTAJ3LR9BKkta5o9FjrhFW9IzjykD1vef/JCrQW7Ds8E
SDyiw3nZreq6Y6TPlHn5eLjTwWfq4STvVgCR0dbFveS8qvMv9WJlaC7EJ/O8
r5PzAoeB3XvrkSL0ScnI5jgSSLZ/35HWVwwyrmV6fBnYrGzn32vcja29q/sZ
9uR9YLs0Njb1Y1LyxTJOu2F8nXrqWUT6wdEXxtu75RiIurPnfHp1Ax4+0em+
RfbzhcWuROaBSgQcajUfI33/EePZtV/NvZDfsbyo80Y/6rbEz67a0439uYfz
NB2ZGAl8XvT8Uh4cg+wYd0NIP1Je4tA1L8KlvISzhy8QEJ6bUWYc7EXSBVXa
zwImnnnDoiqrE+5y9dbcz8j5V0Das+JYOxoD0+Ju6tIhnmcaOinZgugLx/+z
XWDi/wAdZBgs
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81dkbxykJYwlNSZFSoSLzi5tIH0wjRcjYJiVLFArJGoWYSGWkwpRk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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk8lWkYtTYYyYwlFWVU4tbcLA2yHSRJu2LKFpcwZVIkhIxSZuwxDFKW
JGRslyguQpH1Wq493Pt9TYmIpkHXMN/88f7eP97tnOc5z3ne7xje1ueEBAQE
kqnx/+xMqu/WznmKkMnixbkLJGi29yM95cagFHXqYnzQKBZfTItbWpYisDDv
2R55Eu2CIjEly33QSjaMFt7AQ910WZqWWAfO33p2XcKYRE5h+8HLQsMQiXZN
oJMTYNtvUtJmNyH80o0kry4CuqzwQxK6tYhzddCtEybxi2cueora0aLzJSUx
ggdPm06hoRtPEJ9tmN21nYSPSpxRsOooGopWWeaS4xDj5epafWTB38xLsmSZ
QEN8nsa/KxwkcN+Z3NrBQ7qOR5CBRzc0l+g6uzMIxEd0jv1tlou7KzZE1jES
CiH8dQJqD/DPg6Lxm4dJqO4/Utgq3YApq7KDUTtJHKc5Cl6/VoyKy9myGdS6
iWhjnhdnEPcF42LXxHIxsRKh8P2mVzhv4Blq6UtCbUZnZuF6AyZhyHnfRyCT
cXJ8cu9dDKzwN9Y6kFB8E5iFex0w3tr5hB1EYPD6ovM8owvlLbNLv0gTOKoh
G2Kt3o9/fQvX72Jw0f7mN9/SDRUoXMc8WK5OQmTYXD5DpRUBsoIVLqcIJNxg
dQuZ90Lq8odHD5W4ELPUNMv64wYCxuu9nZxIrNP+IKhKG0VNk5pGiAgBAY9v
e8OncxCdXug0YU1ixcjqJ741B9bvfWebc3gwzxItChJtRUHpRzmlFQK2cdLb
RpgcrP89jclspvJR+7ak5VgXNCYxFlvEQ9W9PwraglpwsS7hb9EkAmV64xei
fuyB+8uzp6cSedD3fkKz/dyCU+ZCZnUHSKRa7qxjC3AQ+64/YEKO4h/6MvfO
UiV8Eoq3TVD5DT6o0Nz0ioMTHHLYe5UHSdP7Oxc+jqC9do3fVMdraJiyAnr9
2ejfxCl030qA+R0rbtPZPpgEiVXv8SBwZew232SyF5VRCh0D8Vy4fZ8xJ2E0
BLeozG+05yeQslvN+1PECPoFs7S1zcahpnyCrrM8gg38sQZ9iXF8nTW+hxPN
AfuBtX+dDw8fRTvNLhgX4C/77SeNzpG4WHitRaaoG4GL5HHnMEo/owWH9we9
hvQ3z8xpaiMoX54jB93rUVEnEvKTDYlraxtvHX3PxlRCpVzRTQKrF7rK8ja3
4dkvVqdLvyUx7atblhhcg81+9Va+jiSu0OldLvOv8EKYsft0AoGSnYV37lsX
Q8j8aLGsCYnfH9eYJiYVQTx+1+s7ESRsSxvqVCfq4C22RsMnk3rvB43Bk1d6
0LL25LWHtwnUuGQtiQZ3wU5zaMu2KzykXbt1YathLo4JOzQXUXy+fHV8u/6j
Hiw+c466R+l91ce0oLS5Cq7f0PkyILFY1GXP6X+J6+u0rqf5EThutPj6cWo7
Fm7LOVmokig5Z95/pnIY5yW7taQYPCjulYqNv1sMH+axkmUL6v6cwgMSbsMY
/E0g6YcfeGh9ssu3uq0Tze5DId3/8OCmx5Iy9e7Bb64W79568yCwuPK7ok0C
6txj14ZT9aLgllG22lEBjX94zANbSXgeaaS7mQzCQnzYNiyC8pOK7D0jCvmI
auNrlZmTSOE/l4xafIGH+W9Xf71DwGz3F6sZx25UL7ib7jXjQllThmFE4Y2Y
Td2qDgIBuxRXj/w5jLF4tryaAA+nW/YtDIV0QGFuu0rjOgI6M8a1gSsDUKlY
anYamcB0Vsw7F2UmdoiItvhS/D45iWvtusnGy8GU0Lx9XJQclHf0P8OE/rTn
1KQZiXo7zQ7dHSw0b57Rz6Hw8Wo8UlKDODDzmvE1jqX4Bm7+cSbGG2vEhQJ3
nCXxK+S83hQ8h13kEakAar8ek9m+nd8Mur9cZLADgeUPH6sdlhuwuTspeZaK
h3PKJ0/Jv9Jh6DT1xwClnxLamYNT+18hpq3Bf06TxEZnpk+/Xy/YvURsegnl
h6MLKWL2tSgXD8tIWk/CfTDZMZDPhv3npa6xRh6cMn9aKy3aAIOkTSquUZTf
DXTl62XHgoyrPJPpRvlztWvVMpMF28qqvMNlBPJFW9u4G+vBNFw69IJGQj5m
6dyqARvjsbqJ4TM81HY7Vvt7cDD/JEwxL4WLDVIvg66Gv4Z1eWvEu/08iPBd
LjIcK3G1QOLYw0skOoerz9HpbNTcy6uSXeQiM3TGsNw0BwwXmceTFL8PVYUn
Qn+uwSzjwVykM4lk5l/zCqk9WJKUjnm3gfLXNJuQEFo1ou/uPLPDncLPN6rI
//omRPz4GWep8zMuq1aKTmw0SLRmKkRzcdy/Yk4prRMpb+s4NeM8/LlYebcp
ph7vjzLW3zpBQuCq6jmxxWZYhB0RVj1DQPrHLJOEhTqYBI6xCih90vxMtCPT
u3Be763tMhXP+EiLNxNbXoKm5W2QYEAgt9tm1npPP5Q7fO4L55JgK5gZKR0o
RPjVyxFODBIaW3ptrSXjoXI7Zpc2xUdvNvdUCr8JDCEZdfHNJLY9+Tkg/xAL
tFmpvgoKv63yU62w7X24+Vles8+SwFVecF+zfwk2HhazPGBH9Z9L0Zaji7kw
SmLNRFL4HBQbnjrwOnBY63SNYSgB2Wid4cfP23GV1j2m+n99h/q3JL5uw8R4
S1PnGKXHSY59dJwdLPZ9Vlej9Lgs1ZCplz8A0a9mbvQ5cPF+Y/z1lpJeBHvd
k7FI5UGtR7ZjhlGFfeMN77GbirdRpMrCQCayk1MLJyg+xoydTTJdnXDzuJxe
HPMGGeKb9PWTB3Daqp15vnUCGRactZWH2Ai4my6gUUtAI7HITz5wCL+ebDdT
HR5DsuF3H2OCexGjROdl76f6V/zToNGzZbiiv89mlOpfmUzl+vkOqj5rvl8e
UiZQWHpg8Oj9fnSWX/IyHZpAQF+roMG6AYQZ9yaluXAhLLvyRVyrFzl3eo7J
PSdRoApXW9MR1PbLPvybRtW/z6csPmsUbQP1xk7qXFy6M1+v6fcINEbxvQIr
EpJbpveecm1EW53dV7RqAulh6axLRZSetpygD7dx8eqa16NGoRH8LGJXEX+D
B2L+Qyed+v8w6PLeqfYT+A8mnrnm
       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8lWkbx0+2zitjSTUjMqKR1BQqGaZ+mDJeNRWJUSqvoWSnLIWT0SIx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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k4VP8bxiUkIUnZEi20ixKSuiWlEkoqZMtSlErZlx9CSQkJyU5IthCS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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk4Vfkfx4nRtbT+ZJTsmWooioYib1tGUtm37NKvLialJi3WtEjDRBou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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk4lekbxyUj0+Yw2RpLVGNLiH5zrF+hMpXKkaKYymVky5aQGUJGlCQt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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8VWkYVpGrRtnrRoulJtuMTMsN9UhUJC1ESbKNdCOyRabImqVJSIut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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8VW0XxlGEJI+IkJISpUGGqLikTMmQoYQkRZJHSKIkDUoZUhSKSGXo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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41Vkfl9GQFhQyYUK2bkiSJPrwtoxl7MQtWxMyKkuklEp6NaMQFSoq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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns41dka3kqREo6SRIakSWlcyyW9NChJ4zIjUy4pzaiY4riGULlNCEmF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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4lekXlctkpJMxjahBVPSbkFFyb2nIrQZJU8TQQYwTcolTjEujQk2O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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3cgVf8fxkWyJW1RRIMUSsh6KolCKFSkZGU2VFIhERUiu5CWMhIqe6+Q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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk4lekbPoVSZJemZUgYJCJLJjO3nVQGySGRGpXSZsaSNiQToiyHNjvV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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk8lekbxiUjiiSiMTWUpUiWrJnDpUgahBgUg8iSTmkdS4pKUk2iKaNC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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lWkfxk1JkhxMpULJlikjIkxjulRMTYtSSaQsqRxZjmmSrVJhCjNl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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VW8XxW9l+kmIRgqJiggpIVmRqUKGBiQklUipJFOSKA2kSSWZSaaQ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8ltkbxm0VZRtGSkiWMtKUGUQmlyjZs0QqlYSSYhRGKiRLGhoJIdmy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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4lekbPjioCGPSNKiYQkhEIS23mEEYRD9Zs8SEENNUkrKXyhpiFJWI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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs81NkfxmdH0U4uuyjR1S01UULSzZNWU7upaHRhSxEqKipdrEuy0qiI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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8lG8bxZGkkpKlkqRItjapZDtEsqdFVEKytwmpkDKVIkLZQhSyhlGS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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8VfkfxlVEESZCqEhkuIwlk5bxqAYR0bUloyxlqcZS1nZrUgnZUnKn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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk4lekfxvGToWVooTIlTYliEI2QutE0Q9lmrCkxEiWNFH4VkzoJCTGy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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs8lVkbPQjxUUppapSUJEoi97Tciowaim9qktukC+UampoKuSRU0qdD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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lG0bxidaiPpQihY7IUlRaHGqUOQtpJRkKYSsIVtJKKIsJcneniUh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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs4lHkfxtVah0JCqk2WyLZaYmsd2uUebTlFJLJyyGlFXGUdSgjVrkQr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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs4VPkfx0lJDNpqkdtSQjfVFol4C8lSRMhtN5F2VWSrrbBb1rplZYmi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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lXkfxo+aspQY0shWo2yNka3tpXOHslUyTUQhGlvRgmG0CWkYGinR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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8FW8bxkVJi/JLKJUoSVIUIalLhUpIKoQsWSIKZSslSSFUttImKUuS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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81dkbtiVZRxRNiUxZsmYJbU/ZRmmZkS5jj5KJkjKWUIRqUvZCliRb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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns4lVkbxgk1OzVE0ZitJKecRk5JuEvqk8NEDokyMojoIMLXJyGTplHK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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8ldkfx2+2JMskcimNVDRKi6SSfIwkjcbWaiYSLRKplLSpCGnIFS4q
wgijJISiW4i4ltu13sug4jwRJWOpLOl3fn88r/P6vp7nnPNd3t/P91ng6u1w
UILFYnHp8/+19qGi8bYgPjg3fL0uXicwta/7U/9HORr8Zng3niFgvn8/e76j
ASOFfKXjDQQrffb9LNrPw4Dr7Z9rjhM8u3ZLWSusHp2ng5Jv5hCs/3ohfbtJ
O/qijiSlBDDw3MZqalNrQc6Q68iGXQw0//ZcsMyzDnn7CsQ2twk4Vn6Jzisr
IaOHMyepzUrUjNbbXAAJJr8z4DCBhsaevdrn6nGkSlaW008Qxp5/9OzXdqSN
n/lnRywD2bwmp6NdLUiPjXI2289gt6FIoiOwETZXBO+c+gg+3sydxil4Btm5
b2rKPAmSUkb0OL1iSHzTXLr8FINtB+J8XH9th+4fr+ZE+zBwPxIZPXY1H1Je
FfXb3AlOXSoK8wx/gKijDnVVrgTmnMEpt+lVGH9sx2y8RfDFNNYil2nCHvn3
cYv1GVwv3WQnld8G6Q8Cm0FXBqnLhgp4vSLkcQ4/W23H4FqWl82xLa1gL57X
rWTBoEgruPZWeTusaz8qi+j9Fo9mf5Jb2oYsE4XTMc4MjP31VYMtm1AUp3TR
RItBqHDAMlmhFac2sW7cNmcwNBg6LUO6FSslnQqLVRlINBm16caI4VLt3yDb
Tetl/Nh2sW0clCNYNaX7CIIlIo3SzF/Dd0vWC+59AmfrZdnZUrUgkp/7eBkE
GWq1Mho15SjqLalNCiDYd8VcfV1LA+6rTgogJthj1cKztxXi3wjDTSZpBA4X
M1wPPm3EnL/erg16TSB0KLCxtngANnutUiLNVxL/TefpjGpoLVdfwIqkttiR
dfNxDk4uypScciNIHJ7/9eRiPsKOZbQLOQTZlV8gcbUQizNC/YUeBMe3fP++
O+cRTM/drlGm39+Z+KJnH9IBZ1vea51+BqfCPQ0NjtViqvH2dss4ytOk8Xr2
1WRE//DQDHAhuCA1p64vrQ66WY0ZydEELRcVHhsY3EeA6a0//ah/0et8sIBL
eQjUOGO0jIG9yFUnw7kR+QvHpt0fJ/jJ2Ur6RFwyylWUX12m54n3TPq9dBTi
ZKLwj1X5BG0PL63mBL1CYxvHY3oUQaBegv3ZC+1we/1jTjmPAdvbazCM24wv
3G43z50MDPvbl/3TWYa+JK1VAxcJBL/w7rgPtiLMJGTJu1DKr+77w7M2iOCc
VT5vuwkDDUbwltXbjJW/JW6HIYOMXT2HMgqa4LlFK9hHmcG3iSqj8bUlkN5f
qfXtGEFtRbzW6OZ2FBqm1hX+Q/kzHfLYMFeEiOMlj4I1GFT1v1vHOVCMzrs2
U6+8aL5kch9szfobQ4U/7KtpfN/VY9QqWQLoaYf8MuMZAferevy+HiGUddkO
DaUEUZ9nL43f2oAT2mvvqnwgOD0UPKxwpQUSv9eTGSsZsALdVaP7/JC2OSTP
mPLGcHSemj0SITVbb/aa3ZT/0fhugzViZFqUdJU6MAh0kfycuZq+/yngv58m
CQ6U50o58ssgLyd5efdZgjXnfdOzeypxIeuJU/p5gouupel/hwmhXTL9Q3cK
wTfpQlsJ1wrcGGQbK14i8BAbKKRVV+DbA28nlyBaH45tL1f6JZJvZca+o/sV
dVIHZw43wVZaf+NoHgG7eeWGVU4puNldhzYa/7yZgQaf+fUIC6n3KqsjGKqV
l7af/RoNgl4b1WKCtwPVCxM3c8FxPp9eTOPrfbErcfU8Ac5lDTlYhhHYaVzT
t+4qQktZ6Oq1Rwms3k57FBNbiqY2//c7qZ76N/cdWv2+FNnHOx/c86P+KEu9
eMK0oevuDbH3AQbP9GrDBEtT8Fw+0qiC+vPK416Suo0Y4eYGkzs9Gbz+1KjZ
yxYjQOFE6TmqN3bSU4d9776AY0xbY8gJAu0Voyusu/hYH56y7c4NgsG14YfX
DLSBWzJrauEhBlp8TpzZ1zxsXVEwu+sgwaawzepjaa3YaOyYMIvWx/1O7IF4
xWYU7bwX8Jj2s8XGnZ6x39thYVFjeukhgx1SEdVLJipxvdz67MQ1gi5HgWbF
OhGqjHTEE+sZpFuO7O2l/KQWi+epJhEoq0iMafPFmEzdsbfYj8FM9ez4g/kC
XHjuBm8u5a+hY8o5Jxo3Wa5P79B8/jHyQduptB0SC1Y94VF9jltYPiSvmwqV
0lWZ6vtpfbgvJBWHediV/NGgmer5cuap5V/OnbCb+Wk0KJH2h+7eXPVtAmC9
Y7FCMtWPRaEqluFNiL/Qy5srw0Dn/Aqd54HVcMi5b6cSTvXQY4Xkf7vFKIh/
K19tyWAk0jzklRof/47K+fpSPQlb1ci/sr0anO2WCpFU7wdlFHc8986E+Jhn
5hfqj5Z8j0oHyiGIaSZjwQQdDkpNt32E8PJ7I2FF+Tx8doHc+JY2dI/+ZvMx
hkHuksZF2ZXN2PPJJCD/B+UvJcc94Xcekmf1vdOj8fw2J/fYxsstmEoaKLX+
l+pxJTeu1ZSHni3zTey8Ccye8JXkYgMxePWA0Jrm67LBipuq40EIuNdzyoHa
u/yHrZ/6tGJmH0/lCZ2/zon9RkZRJWivk/qvjPLWGTtPYWhKBG5QoV+CGa3n
4g79WEmq3x9t7rFGCManZw7UawuRVFCx69d0+j8wsMHapbcekw8SGE/Kg+/P
3nXZC/nI8r4kE5xIsFPmfMQl5iX0ajb/an+VoNlfsHURrw0ZvvFmFo8pT1Fn
pLYW5mAowMXUkfL2ki2/74SLEJNVpuNGAgLZqq60ybcFCNDWnDtxhPZLRS2b
W0Tnf0JDSxmd/4byHkfUooVw7zO63lNIsK5OmKfr0QB3qFr11xLMX/qX6Fxq
Pdx2ROQNt9P+mttp07+wGWPxG94sHab6P9KYIFtajTsPFa9/ovOld9OEtwfJ
Q7bIiC93iOAu61P+4PwKmHEiJMfovDNf77LR1JeP94bLI61pfNeb5SdFVs1Q
cutxtKbnXW3lSywJE6HDHaGiIdq/0eP2+hGNkCuqZmuNEZSplarlqLRjfOaM
TefA4H/L+sFh
       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmGk4lP8bxS2VUqTQpiyplIiElHIkSUJCiyWVpZBUSkmRyJJs2WVJKUsh
RULZ9y2MMcPYZ54ZRCXbT1T+z//VXDMvnut+vt/7nPM5I2V9zdiOh4uLy4qb
i+v/n2HqlHcnerLguPWM+50TBCJp6W0hPF9Qu01RoyKcgP7cVd3y+iaIRF/u
uWFNIIFTJvYglQZZqd3C/WYcrFM/flGDvwbEhLvb2nMseDoIE9NzVYhs4f2R
E80Gv9B4ebZRHXYpduB3FAtKOrvOP7lCw0jCUAD72yCEBmaqjra1QFpxV+ER
9hCGdROqdEQYcBdVW2Ssxsb3Wcl5mRU01Nw729JcOARNXtfHu01D8M7YusPw
HAHbGwv3nlWWQupitqCpHwvup7YdDPxBRUV8+z8rDxYKG5nV81qtOCtwnM3n
T6AnbNgtel8jPBJYWxWLCej1zG+1Ty2HqtYfN0d3AgYpWzU3+rfi2st867oh
Fv7m6rzeo1cHyZcRehctCKygR5/4WVOPE2b/Oq+KErBP9bZw9O7ERNx+4f8G
WJgRfj3R1deOgj8X1ly6PwhPUZ/XLPcKjPImJvL5Ehiv/PDXcUc+rHKrMFJF
oPNdOtUptBa2DIHUZ4vYcNlx0yTcggJi9fBEkDUHSwnTHnW/Smwp7DJxsWbh
9PVEq8plrdD6qTApbk+AylS2sbErBz009bbGGgL7s4bu63tTkJ1A87SsYeNK
soWgqDgFkQsl72MnONDflDk8L9cId3Pp7HJxFiLrM7Liz5Uic53Y/vYbBPJ9
ud9JplNgmTdl/+Aj+X67b9/w28TAI95/z681DKFzf5kxodOCzarbj89acBAg
ZxAcklGJHcn1g7PTLNzsP+ojeLUGOv3zGq4WLJS5V2lFqZL3eeyu/icmE06j
YkrDtxk4bazlt9OtG1wm0QXcMfG4fU/8vwMGBNw1lWdWUzvwqqgo/qQTm/zd
Ivfr9jQIlvi07zhEQC5i00op8yYUCtsstGqzcUZiRFgjsRii2YYidp9Z+Ja4
T9CI0o6myoJ9SouYMJoJSFodmIvDKsv3SoUQKBvu2q5gkoUDStz2keT55eyT
Wn4uqwlJPoSSlDkLki926NG16HjvxV285Vcv+grn2laqFKNBnF4jTeohfavn
4t2pDfBWnRArqGWj4aRoX4hcK/Q9Nb6PaTMxvuW9z6RqD5im2r87yXkrXGb8
nIS7sKS9JPqvLBscFVfJg0otiE26+rtXkNynGj3+3WJl8LziSDC9yXkWdJK6
12bCw+SKgrsKOa9shP5hWho0853CF7kSEOeJf+kb14rFbSF0XhYTA6Wey1Zl
V+HAN3WlHg82uDwe9shE0LD0lpz7vTeDKAuTj9tu449FzcrOfBcI3NrkofvU
oAn5e29ZBcgw8WpfwaeJSTokHx9pUs/ioMBJZ88qn4/4yM4VO0vu56yfrIKL
eDOeH4wcLz5KQMimaNWGvEpQzTbxBseR98E/G80SaIVAQpbASh0OjK3rVvRU
tuCgLVET1c+CZrRo41K+16jq3mLuRu7X2eGIAsfGbozs3bbsHkYQW6FXpDJc
CslZo17qBgKWyis+NaR1wSJ5bfhhgX4o9qR5B/fQEfFr75ltOWzUDbpkTs3l
4cQzs5BwYQKMx1Hho/dpYPxr9JfPI4CFLX4lFCq8xtMyghhscP+QuPnUoQv8
RbXx1C4CS1NOFMq/qAVjJnnrlwQONtc6xOaEppP3fGaxH3k+BzY+nP4b2Ikk
aCV9dmAhgNN9pWS+HlWv9SJpLA5yUjQem7yvwj0dMcUde9gokLm+vcG0CkdN
ZzOYvhwM7Hy9asluHzzSPBiqYUtgV5+H62+DdoQv35YXt5sNL5egpvMSceho
tqo7cpXcJ9kjdnGjocgbPk+RsSQQK+/I3bexAnurYq8kkvNyjf1YJDx2HPOj
MyE7zxNY6RaXfSiACtW7XhQG9zB63mh/aIqhovi6gExsDQufFn4WOyd0YbpL
UJb35gg0j1RnsEk/aBptnonfwcR23ldSFOUW2DfTVyrmsyH34sjTB39q0eJ3
OOBxAwv2H70rBbxSYfoz8tYqMwIbfu7zN7nbCdrL41F7pjgoiZ95++xuNdSF
jcbb9rKQXvfCYGa0HQ9VrONVnQeg0TW0td6Zjm15xZmJvRxIyvwWuFzeDNdZ
NT2Z9xx4VdzkNclwwg3unpXy5PuMJW5dYXeOhp7KqEqeuGGkXnx9VzOyHGMN
f0I3HSZAO/Vn9lhiOwZWf7Gw9yDwir+3gl+iGnsEf9sFdZD6qBASDfoYBC+e
Aw+6zAlcuhwcv2qIATuPQx9bgtmYW15Y/pFOh/jVv1OGYeT+MJyOd69ughLT
7HSjOBMt7Zq96Qq9WPTYwMv5CBvZo/+10vwaUDmjFKu8hk3uwXfFjJWF+DIV
214zS8AxQOKWtzYdeWGBwUEne6F8o0Xk0bc8ZFbU2lSQ+q16HGH/I6UBa3uT
59JFSD+5dsDoMOsN0uJ9bgaT+VlDyIdK5HUg02D0H+KZyIt+bX7paQe039tJ
jTowEZTjNKQ3kocNOe/vVzsS2L4sNXK6nwq+Gy1CtiYcUFXPhkbdoOF1prLX
pRvfYJhAZx2yKoZf5MeTiQKkPkMqDlYvK8X1qYpI4QoCd5xf9hRaFODfaEwT
fxuZN+Lq0kRSB3xyZ0/vieiHW3DGYhYasNHlRpSbBoEgea8cpYgmOJZ9UIqs
H8SFY12d5j/ioSPNsftE7qeifLZnV+QHHFMvThHVJpDM03Py1usU5MxcsXpI
5uP+5mGLDjYdYZF6/ONGHAQVX5v9NlOAlg2hV+hZBExfGTsfGKuCrEZZ411y
v8b9PSLa9n+Ak3t9kWsBCzU5oS2LO9vxVnDhCv31IPJCavyipamgXEXNwu1h
LGVzHDcu6wBNkHZ0N2MYG2J4S/92UzHrPttac5MDHfe1MXplddg65qvQl0Gg
ZH5kZqGCBt1blxY3e7OQ6LvJ81JrF/IUkjMcZdhw6lM6Z0nyyEBXeq5XNhuK
AydPROq2Y1CVzSloJSBS8NxhYKgCpRoPhfS2k/ptlo7zTQvEuAor9wy5v6KT
sTIjtQ2wkX6UeFCDBdXC+mBP7VZ07pv6eiOMgNuK+QMC423oDA3L1CgfhJP0
5Ed93f/7WfVV5UUjkEu5lvZnqAr8SZH/ZN4xMduxQV6Brwzhl1rWvJBnY/xe
e4r1oXKYb5zYSvEmv5e0XrDbW4+pIIkn3VNMkodmKs6a10CfcnS0KY+FQI8v
9MSkGsx8/S9FaYqFBKmGaxWvKlBS8lexWZYF7SoXEW3NRmwTlXuRpEMgV77y
SkAYFTepr1WO3OZA7szMGgejchivX1NY+J0AYVBSaOZEh+vgO0wtH4DXsM9b
vYcFUJjuETV+Q54n0Twld7ML7o4P34oweyEQyoz54UrBKV1/ziFlFt54co3s
3EbBw1WZKq0T/digVCOReTgXVX4ZqYHBBJztJFLKfdqx42WoisNzMq86j3UL
7M2BcP0+e4frBIz0jmYqjeWBJfQwgleMgO5RJbfbMWlQU/HY07GdwIdEsfHY
NBrUksp9Du4aQFUJoy3Y8Qs+XJhr2LKcQFG97tOCbc0IU60eUFnOQaX/9dmC
u5VwyKxUUBtlQZG+JFKDngm9q99Tl5N8ULJ+v7q+UAfoIf4m2VkDWFVWWuCg
2YkvTGq/3Ckm+HNuh0X4UvDJY0/gfQEO1DoaDBwEC6H31v9cliY537tLO8O3
t+NUh79ljhoH990sTo9X1aP88NeFimgmlvKO2w1Jp2DpvqTgFFJPkpvtM9lJ
6bibmP98J5n3ktUKrqea3kBkwTkqVI1AGo3jrMZKBbZ9MHUjz2P9nU8Srwe7
YJ6ioGBezIAWt9h61oVm+PKL3+/qJtD0YmcA5WknFo5R/pM4NQhrPz/RNfWt
qFDc6dC4cghvwqdmPH5TcLYl6v4dkp8e3T5eyfW9ArRtFiLrjAmsS5r4ZHyY
gjc2hmqymQMwlctfI/OwGjxvAzROJrMR8EDscrdyMfhDdFdakXw4prkk3uxi
B9RCtuzjKJD+5rhOcfv1MoRk7n5qO8lC3hcfyT+9tagpqHvyk9Rfq9BQue3f
Vzj7/koBzYfAv+MO3Nt6OzG4VJLNvDCEhSztFu3Vpfh6b8XGhyS/q2auX7O2
mPSTFCG78oJeDDP9VWbDST71uiGwm+wft/SFoiN3VeHjDisHVZJH0hMesE0D
PoOv2mnbt0wCd98aHahxooD60FRc2oWc//xovrPYB5gf2VkU9YrAddZBlt+Z
Jry56XW8qZKAVc+Q2SgfHdm1NEquNAtBJsr9qbv6EBDXOg7Sn2aP9bvkBDTA
kPdMjDWHzM/pfXwPgprBvc3gT94Jkg8k795dF5ADM/4eMV6SFxd7zDZFajQi
OrAps7WaQMBzn/O6pgWAE5ds1TpSzwH3vveJpmAXatwX7hO4wH4ho2z/CLpP
dt6xsSH1t2KxVkLaF7wsPSn6a5qJHUz/R2vfdKHoW2L5r2XD4FlwPjgtxsCh
Cy9rC9MZULupu7zRhALxKif7pTIsXG9v3zgx9B78n3Q+j5G8Gctt/4RmmIf+
V6e1NrUTaG2T+BvU2YAyrf3Bb5JIP0kf2Np+jIo365Nf8moNQT6o5qpNaDcm
Pr47HkjyyKvr2leW3WtGswvF+CQvqd98m0vCkhQ0BOmvzhJhonuUlz107ive
JW64ZsvuQd6xjKAaqXqs9zb/OPGT7AfOKW+31zDQ9HwJlXJqBIp9Jj7aOZWo
KLid+Jj0Y0Z2vtCmm23Q1HX5YDg5gCVK/oHJvM1Y/thk1ZtONpbtfuG/4jIF
LvucGw03cTCuYTCp97UNWRLe5TvDSN58kby9YmMwjJ9Pcs9dJPMz5mSL1Lcs
GD5OKHxB8oHP7g8Zw70kT4hV2gQYcyAomPj1mSsVhgGWqpZJBHgaX3a5e1Mh
V79XIYd/BOvS9DerR3yFkbL2xZduBG6yjP4LOt8KPa0mz9U8Q0g3W7XykW0L
XPTtneu02Ej/+s9S+1k/ZO59Gbrc/A3jew3Uz5WmYtGxNDHVAALf3p6pDxru
wkW/0r6oCnJeVkFjxhVXjFLNQ63IPrv/4hz74aka6EX2bL0pwkZyiyi3Ok8P
6S+Tk/OnRzDlfIvxSK0es2zftzeLSL/4oCaknVQOy7onh8QXEZDdOMMnFkzF
zk/iP6hbmRCpxT8ZqyoIaVo1LKtgwlSmUpZG+pn374l1GQ4Ehj9aTkVca8Ae
jfVNZkfIvhfwd16lNAYJvfmx/lYkX+U0JplJBKFXJOOn2WmS34vHXOWP5CJE
wjhdmOx7pn05n8xNm1AloTF91W4QX8ouBx6crsSY7KJkQ3WyrwToNPd/a4G5
yhkPi1eDKLB/ahe+k46njqulpAR64VRl01qZWYP9aziKZuvIvmT73cib9Nfg
Cs+F/W1MKGtkeX4LasGVvjPJaqTfZ4hNa0vTu+HydFGfWPQoFPsFLw+60iEY
YyAlF9aPVC3ZNcMS9fC2v7oqZZ6FeY1TfttJv/sVoPEqVJfkB8YgZcV9BuRs
BRab5oxAVvpVpK4LHWK3oiT9jwzBTLeQbzaYhjA5u23eIaS/UPN3cA0y0PUj
QWbuN5n/43+WGfW/Q2yY38AJfzJf2le4T800Q2j4vvXlNjb+TXUGeZUzwNMr
Lr9HjIOxwwdtP49SETebmuahMYDfJyPEuX3fQ/bEuOHjOgLd3yxEbtVX44eh
v3Mahex/fGUt1pROzP6cyp0i80JysDemaqYO/w0k5DqQ9xl7wFTC8Fc9bNIW
RdNus3E2Y8Vcq0IFerpLJjO42Lh1cmlvTmMrZtT9uv/eYSHYSuJbrhAd+Yvi
zaMFhrGOQTn+wKcQ4c0fb3iSfMBFf2Z9hb8OBwyogcGNBDhNZkNprRQ4ZssW
oIuNzuyosag0OiYENFbtvceE2qrfPDt7viK87R+f+j0CkV/y1YqSq2GXwS3k
sZoN24ymzi79HhhSykZjnFh4eT1ld95RMk9/c86HkfkYQPssohrZgWO95ZY9
WSwY7PFymiZq8aOfcWIJycdljkmLoxs+YvOPQqoA6Y/KX5nC4aFU0EdTk7/7
DmPxIQOLz3v70KQpEGhxrhfdg71brsk0Ia6GW5sQG8KnZret8+tb4e/gcl2K
5HWzlhNnEvwqUaX+dKl3LoEBwViZNXdy0CN5njUuSfrtgcrUtvIKWG6u1pkk
9R/Vc/5tznMG7I0mY03maBjXjat4e6ALh6J117ycZsNMYF6xy+U5okp5HieS
eSxSySVyqbASVuEWN9yKWNC3TLPdpfYVj2o3qweMkfsgIHjaegXJN8r2a7Ll
OEjeonrnEl8lKOzgWtHTbOjKj7PfOBagLpPHNfQg+TxRv8AE406sXe0VI0v2
iXnRZ+vCHWl4+fXQDvN+Di4t1tndvLoDv0bnKJ6tQ+i8FVIdGv8aOuETKhG6
BH7sHDOY3kQHr8na4Pjtg2g6IcZYWZMLZYpQjDWpZ0eW7vyJU814OvTFt9Sc
jdNGUbITl2qxoft0VzCZ18+yC68/5GcgWjKES7qUCaf17/aEmRWhROiZdR/Z
5y15lk0N7G+GXVqQ6iy5P2ETwzpxK1/g/J6g9VMkT9oG3w5xDfmM65O9Ndnk
PPlj2RvKbTqQHdxQbdM/hFcxLr8Xb2jHuXKhsdhlHJxd6nv0T28vphUc9/PG
DUFo3p0yxMhFkcLR0aQ58n5EN6tJPKbCb5nUT6/iIQybBOxa+P4ZVG6R23fJ
/hGW82piCf9XGDOjpX4vcP7//1fMkd42SB2dk7ddTfZ9vnijJy2laMh88UH3
Ohuaj6ktaYwW+M6vOBL+nIDgTIH7DlLvKioRtOXnWaDIKP2yvdyIQzYK2dSl
HDwaO9C94049Mq8ubtHZysZw4EDdUybpP39LlFTcBuG1hVbe+fkB1loNfKCS
fcBYaMHZiqcJI9Nihx60suClO1y0f9cTnF9+YVM0mecXWlK1TjWFQE3ac1Ly
FNl/CjWfL99RD6N9766dGSb730hfkYJzGUR9Y6Z7Z0h++hexYX9aFq6ufZl3
4RGBL9S1Ue/5y3HbWUr20RgBy3md0Tg/BmaEBWRG1QYQuyWh+l1gDpzryl9f
PEHgf7+AKus=
       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk4lWkbl2RphCLSRJLkRJwUYcrPKFFRkoykj4REskSylCXJJyEHqSgJ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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk4lekfxm3TNM0hSwuhDinKxLEUabn9yhAZ26WsP4xBkSV1BknGNqdI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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lWkU1m3FEDGKibKNNJGEIvWoqdDCVMpUQpKKEGOPmBhqkrF3G7Jl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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VO8fxadCUqKVJEtJCS0SkjpIWggtsiSEbMnXGpKyVFS2iqhU9gpl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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs8VFscxScKPTxLD0mTUkpcJVJNLRVClEJKmG6EuL3ETVKJXlQSCYWU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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41ekbxhExWVIo2yRblKksWVLciMmeoihTYVJCKEKIRpoUbQijBU0L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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns8VPkbpmLstqXtilapVitdtCWpxcOG0IVc2t0fiRqxYSoVuVSyiawl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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmGk8lH0fxSVuSUWyV0hR4kaS0h3HllJIWUOESGmxtSFEi5KyJ5EtsiXZ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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41VkcxhUmg2nkYbRoUJIoS2Sk5bW10CXr7RYh0YhSKWFUTI+lqUQY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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lWkfxg9lEN4Y5oNJTaRokgzTjCznQt4oWl5LJSH7W4RQKNTYRQ1Z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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lWkbPiktNChMKhktxjIxMU2T9UKS+kIlhEZSdmFSaYzGviRyrGmG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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8Ve8fv2WUUkkKpaQoCclIIW80jMpOSGbJaKgoKpFEyUpIg5Akqm/I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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lWkbx5HCSJ0aU16VImnG2AepiZ91piGFsi/ZJrLXSBQp2RpM1rIv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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk81dkbRipSNzHpUoosZakkaRQe3ExqKI1lkKJsiZBsTSqTtRprJaWx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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4VVkclTLpIldUZqY8e5FCZihmWiKvkopeSoooI67IGAmjlDA9iCkV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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k8VH0blpTCU8haFCopikqlUpckiRZUqFQqJEkihTxZKjyyJVtR2UKI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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk8lWkbNipR9s8oLShNgwopjTaX0ihL1pI0IVIU0SLLSFJKtiRkX84Y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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81dkfxm+qq6aF0AymGkrKDDGkNOKhGEuT3CwpFVkqka3GWEYhU0pZ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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8lWkfxk8SJVqkRpIUvai8llFD0kVRR7ImTTQjJPTqkDhEC6a3RaF0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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3kglO/bxUdFKUJZStbSZsmWUsmhCCWhkihEhFKiRb4thPIrVLI1SZJS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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81Okfl1BDk7PIbuXomEqSa7f0641NRTbkWDmKRVRsk18S2WJXsinZ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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs4lFkDpxLRjYRVKtESckklm/zSSCrrnsuSNHLJKi1ScomStC612qS+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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4ldkfv8oSxqASMag0bTeSvWn00aL6JbfSJoykwhSTJCIlaxRJlsQU
lSShsv3MzZLsRHexXPsdnVdUWpSyDM2ZP97nPOc5z3nP97N8P9+Fzidsjs5g
sViJ9Ptvdc/7tHW/cTFUSi6vkXIjMGseLTsbUw0JltVRxp8gM0LH2P/AE7zs
FeSUHiF4PNmRVK91F9Frk1LynQgG5NhZtct4UE/hqXwsJRBlf/c8n8FHp3DP
nA4hgW/Yh4D8NzzUaEjZa9URiHlc5svyq/g4KpMQeJDg2TELjz86/ZD9fVhv
Ld1Pxyt/Ol3YijS9ngvTOgyefzTY1fOwDfPlS/mXjRgsfK79TudkN16UiYTD
VxjkCXNm5bu2QT9/tZSnGYNkR9v1uQkl8PfSKjl9nMBvs2XuX5GNqBzODyq6
R/Hslfil8lYTMnab3qtMJRiSVVMN3irE599yN2kWEMQPK5a4N7SgyF8uWjRF
6w0a65nqSMVI78r5SyleoxMz3zkO98CfmLI2Sgygwm3Hn/meIri9/StcYy2D
WbIVd78Gt2JZ++6BtCUMrgZ+Tdi8OgesjeGLtA4T7Kmf0ZAZIUC6X9rl4QEC
kjLx+PhzEdyHOZbTZxlYOG4PDi5LxWLnk4E76XsKy+Va+ZZ8OBYnpKxpIzh/
4ptuQncLnGzfW1nNZLCyP+NMZno9PkclGSbEELAyVRuuBmfAY+oVCTtEYCH3
z45FFim4/ufc7H8ov1s9tfN+bC+C5uwzLX6uFM8C1s+HxuvhxZkbEhVPkPf1
2viOrE44m+vKs4MZ2HUfDpD24mFGeJ7qzSyq19jhQR0vIQQ5D7Tu0vcFh/gR
olX03FPfdm0PwYT3V7X9kUXwrnpZ5Ur9pGTDdowGFwbzWhdtp/uthRfXcK15
4K55fScsm/J7ap5ilmQCeGeDCm7T+p6vT4iZfNaGaiWneXb2DI6eOiOx6GYH
VmQxBzIOMeBJfiiw3iDAxDFDO49GgnB4Oocad8CoR/6ObzwD2VMSgUt/5+GO
HRwycgj014QuuqNcg8Oj+zbYXyFY8tSWbZ4pBOmM1VX8m8A2+oHqFs9aVEQo
u0QlELxJTpxTfqAXpTq3FvO8GYQ/vC/dekkA0papzntJ8AU/FNTp1mMn30FF
LYVgLMuiy+NLIZJSw33dXAj0Gq2W3+eKMJTEu9i/kYHT8c/j0VJPMXdydh7v
GIGkzFk3W6cGGHd4rJu8ThDmLBs9EvgCUY59joFpBCofJNh5MtXoJgZvPgcT
ODH2L3q2PcQSvQViY2eCjapRboMjNZCusjcbo3qXVScvPWhTi9E5sskrkggO
Pzo90JHcgWM7Z5Yan2Swaf8Z76RtDeiSj5vWpufO82IaZsm04cRk/kHxXgYX
BkZrPc19UPzo2+9mlP+dDe7KQdfLIOmgbxriRTASWK7kr9SOkSeFenbtBBGS
mSbhfoVQY0VESFC8xYsEjc2TjxD/a4HNFK3Pza9JZSz9CRx8zh+7eJRghe29
LxsLefCK+iATR/mOeq3pomItgHhveJ/lK4LNFeJNkVJ8+O9u4LjWEGxv+33/
lfzH6K15bdJN80ZspDrF4zRBrudtht0zAu6nOmFnXSsUI9PVppQY3BfPFvQ7
t2DeI+srjaMEaVYV8v3qt2Hwobf0JO2fzHV3N0y1V2HpgL+PdAjB4uNGt3bp
9qKoWcHn3CCD7Pmna/tu1kNKIe3F+C2CukFu2Eh3E74lflawukawoGPbrXNF
D2GgcEOzi+KTbL04qt3LRQpbruuVB9XboGboSyoP8dOhz8uo386IOGzlTVVw
WxO18Pp5yufCrnO39bg4/re8WxPNo62KARobOAV4qmr17mfaf8XrpFl94eVw
9dUyavAmSHKOVba7VIn8LK880PuMwUmrVssWGOm2f0uawSCA66rP927FHXvW
kdJpynfgOtWYX59j71sNDVOa1w47B1In5BoxsHxYC5kE7tGag3dd6mDEKgpj
X6b5Or/jJ752LToVev3aIylfUTHndG6UIEml/P9id5pHvue9ZvQ30bxku46n
0zwxrLSqvBoKN67RyDbqD/cHP+1aZSuAFE/zH5cW2t/J65vSVzYixGfmq8T/
+PLi3JMxF2Bhaua11jGC0CfqQ7sq+Bjcpd+9spzOh2ah8nrbAgSp9NtbUn0d
Z9YGPootw/vfmg2fUT6zuYlFq0tz4Sxp+U6D5uXE4o2y5Rw+zJeNhHzuImix
M9kn4ZqOFB3ZCobq+3hZeP50SC2YEvmn+n4EBZEBqTP31CHijGtyehSBIIJM
RLzlQ1Mm9rhgkGBl3ZS7nkcdao3mBHReov11LNtiR28iRMvH1f6i+CYCb0pD
XYRtJT+pW2kwkAn/I0O6txunCsUcjW8MDLPiQvZ6tyB25Xhx3XeCwbd6mx0r
WpHf/vTxil6Cqn1Xcv/nx4NDqBNney1Bv4qGiasdHwcTuZ8OUH/b3Iv55HBJ
CDNLRdMjlB/Wm1UVf+jYwyTokO5q+n5V2JYhi/VVEMSEFm+/QP3TGN/RIt2A
gypzJV8n030WtF/63oZY5vqKSIpfMmP6vsq+dmgp3L/a7ELnh+3spR9+6MTa
BL/bJZIM+qsFo1/HhdjQ77KZkWOg5NkokeT6Ar426pd33ybIcPgaqD7Bx4L2
uCVNlQSTXToWDuZd2GfLar1M5yvPoq9v+4/lyLV5J7Sk/hjjs/XNrB/DcIvE
L9FUn7FBqW7r6JcQjA01bOMT7DuQY/yJ1YLgwYwhfUV636HUfJVhOexC2rfY
nKL+Zrg8jqgKE5whXXfqV/sCId/iYTW8m5mre8Jov7/P6qqmeo1o+x+Qbab8
fXt140JBN/pYw6l7YxiIL8XKvpEUYJaZmji3nvrt+643U+Js2HwZ8viB1pPq
MxQk0urEtS52btEOBj4z4uLmqQvx3u1i7UfKxxHr2LFNE1WoMbJYZhFE/XZl
uUl9KR+FSxMzDWn9ATkHJUoTq6G0k31deJbqW+KXZjKbh3eCZW03uHQ+OmRy
434RYdKHc49FaP8dNT1h6kf9FGvMLqb/W5DgcslA5QGcI54Iuuj8/RfZeMne

       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VG8bHlIpUglJRJZCloRs5ZaEUpKtsYSiopCflCXKlqWkqLSQUlFU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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlns4lOkfxlWUqBxWJ0SEkOTUroruIUkHSiJWSRmt7SDaSLFIjtWuQymJ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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4lWkbR5nRTpmyFZmTDLKUGIkfkiSETplG2YqyjEiWb76SkJQ1Gbuo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       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}], ",", 
   GraphicsBox[{
     {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8ldkbpx9Z0nJFZipLUWkzlaZk+1omUjK3KQwjjMlSsoUWqYyIREgx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       "]]}, 
     {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2kglG8bxf2RFEUikoRokUIJpToouzKVtSypCCmKQkWWFhVKEYpShFSI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       "]]}, 
     {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk4lWkYxoWkhjKWomQpKqWmkrms3ZYcZVRSRJRIqBA5SoxINLZIJJMs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       "]]}, 
     {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk4lekfxmUpCZGuwrQQskUY2Sq3LBOlsv2ytdpJg0mNtbGUpkKSQbZj
UtZSjDiIEOGQDuccS7Kc932LqcaWUoqZ9/fHcz3X88/3fq7ne9+f76PoEeTg
LSggIJBOr//vj77nF2899wSple+me3ZR6NhEqLjufgIPYcXQJHkKdoe/BcVl
cFChTlhqDRCIGzQU3M5gQULorphbMgVnw4qxVZfY2NTptTqxlEI+U8jT73gx
VBX/qmrSo+A2EV6yymEQGuI5JhFGBKxLre6KcHvw256DOoq3SUgd/Xh3/dlG
lO2grpRpUFDRp3hMYw4+/vn3EYevBO5pBDia9nJge9v3c6QggZTM4fSG+F5U
ufq3brYgkH/aTzVGsgMda95KGkvSeqO/nnhS1Q/nsVk9/ikSpTvTQuIshmHW
ISLeWjuKAo2r//xrWoPMLbtcN8tRWI7zVys5OoD2gigx7/3j+EVZnn8tYRiL
OgaFUcoEQovatZTvcFDOKd8cVMiHrKPC8qmLLOhIN73f40TiCk81ZX0fB3nX
e9L8IgkoG2SbWla8gEzTNSubZQJhxk4CEbaNWD3cXOl3nsKlHG3nlLX1uMGc
Sx05R6Hp7dbUqRsdEHyY6GQ9RkIv1zHg9cc++HqrlQUvEPibu33Dpk9NaJu0
FTrgS8Hs8ocH81m16DNEME+YAmW7tSdauxpC4VIO1Z4UBKiaiJW3G9BXXcab
nyURXPU1zV2yH36a4k2KGXw0/mRZl+fVCre83WpMBgWyxTNabfo1WqOTQo6J
jIN9mb3RGmWQrZJqkzej73cr9kepiWTYfnmzdp6uv6L2qrxyRDuYYZdWl1Ek
7Ott8rresrB98oLH0mEKk4TVZZE1nVjutkhKofWbTmcF+drXobtLTudfAwqP
Wtki3XoDeDSwteao1xjMckc5FjnFuO3h+N3UmMIW898+q+1nwykr+/6uDwQM
vBsZqg3DSH7l58gWHYfLFxfFM30tcKs/KbdxnERWwXxwemA/lufWW50vJNB/
QlzXbZyD16a3Tq7zJKEVeN8+KXYACoxxQ/cgPoovvT8ZHtSNlTtUlyxlSEzK
+Yq+dGzHtm/ht607SNilycvkfniMT0UqVoM/UFCYs4jv4Ffh5R29XTb0e3Pm
ijbHaw6BEZ3FLh8mYPpDXYHWZi6k7okcD2YTCPA87G7kMYIO/cBSsWk+3Lb6
yvgvccFkKT7znuDDxXiIrR3WgLKXXTeK9ClIh5k0KlVwYFZe4+qZTCJNQ3Sv
7qtK+AgrRK+ypqDkW5IZf3MQ3w3Da2cU+DCSkH0Y6jWIaJNejYSlcRxPOz1f
t8DFrc0VUwffkchRNVB4u78F3eu1F18vk/C0sWVPxnMga7uB353PR5PTcZ8U
sSasCr93Ks6Ognro13On1zIhs79Voi6K7k+bsfm2ik5M7wi3CpWgz18aF2de
FCKF+1eK9DHaf4Lfan8ZrYXTsax0/j4KmbJfFTba1EO7tXlS5RDtFyUD+z17
y6GQd9e604ECKzX068ubXBg87rwm9ysfwTNG2ucbB+Eu2JWyEEbii8KitQC3
Crem8kzWCVAov3OTsZTOhoLv8pSfEJ3v2O0rJNdmo3Q4o+WoI4XrV2Uqj2/t
wI8sXy1LIwoXItbvetybgpK0P0zcTlFgD13lhLsk4NK1Ctc/PCg8TyC0l562
otD/QunzaxQmZvcw9mXyELUqtlHiIM2LPZ0hax/2Y4NbhmxqLoHO0UuuFzqH
kBzx5sEJJT68HPIV1Rd4yBW0mWqppP2qW1y2rzUHGkLSPnEnKFivK3QvLBmE
0139Ab2dJMY8FXMa/sfBz2lGZ2X7SMw0/ambIlcBWUvlkwm2FNrqhIXtLvNQ
L2yc+eAcH8rHnO0nCS4U/NguqfIEzLJbnN5KtCL0qIk0q5BEgoS/enzScygJ
s85HcUjEDUX8wg4ZwDpO3YTD7Dh8flC9yZ1/iWWByQulohQ2XH+9N/ZfNt4p
zWX53iBQrVjjyGBywdIJWLqYQqDXUHwwxq8XWoZrAh0LKOjwDqV8PM2Ai+FO
oyUvClIvVCIV0I8CdSG16j4+tpcWaez/xkOC1rbEBzzaz2LGzr9rcXB/kas8
5kMhQHOrH9ehG6WrqcDGARIZxpzmKJ1BtMntN56T5KNvxHSgisFGW4i59bdy
CoEF79MtHzUifaV6fD7Nf2Xv4c6z5xvwfCBzVTXd3+Ad/6gcnu/HkyVDrRdX
CXj4jFW+kxjAhhlhU6Y1ra92cPehkF6gfefGkUg+WDWHpO3ae7F7R1SiFYPE
k4WDTJtPzfAKEbpumEpiurH5SoJOH4JObhmqDiDAfFqbXRRegXeBZStY9Lyr
8qsK/6j7Cg/VV2bzX43Bznz2SFK+D1jTP78QPkmhT7xSNXBlO55zBSX0i0lc
tDZ2adcfwdMth57xYsdwTLzEPtalBHuvW4689ab9dGSqqtCZC4abuB6zh4+9
/XXKN/QH8VkM4Xp+JKZ0yx71SPcitCw25Ygxza8NebXS7YMIleBMlNaNY/sB
EWu5315CzpJRu1GGQkx611BCAAt2i7oNmgco3PVsMlj+1oKjukcsyDUURM80
8q7E1GPOPVX1UROJfDEj5k9//gXhe86aQnSes8BQEG3lIikvsE30xBvE1KRY
PL6RB7abx/lmVwqhla9Ul1THMB8rY5+YNozK+ImQxY2t4PJimJo0jy6X6aQK
/ToCSfc+E+biOAR+/Cj81b2Tnm/fV/7TS+J3Q6tnb4rbEX/t+rp9X0iEnV1+
NiZSh4iFO3fMaD6k62oRN3VH4XQ7F1QrHzqanlq5Jp24//mQ8OlOAmkykdGb
4kaRzIppGVGkufksMPGhaDlimFFfEgMo9PiImCvpjiDTIexO8NpxTOZk+I8k
N0Hyvdr0JM1nJzVdjv25PpgJbJMiaP4LmBYKKDaWQ2OoRUbWiuaX+YxF68UC
yJ6NK5y1of8nRTsOPC27hzqBMx+2HKfwqpuw7wprhlJ1hkuNGAX5Pcfmxv/I
RhC33n+Y5geRvCDbwR+CcFovk/1pFIvmdpGSK3goV+nMvlJJ53915OBsVy/E
n5uwC1RJ+J0Rcs+pqYdaP8Pu0wyJ/wBUZafW
       "]]}},
    AspectRatio->1,
    Axes->True,
    AxesLabel->{
      FormBox["\"mesh\"", TraditionalForm], 
      FormBox["\"value\"", TraditionalForm]},
    AxesOrigin->{0, 0.5},
    PlotRange->{{0, 0.5}, {0.4, 0.9}}]}], "}"}]], "Output",
 CellChangeTimes->{3.5457560284218063`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListAnimate", "[", "sincloud", "]"}]], "Input",
 CellChangeTimes->{{3.545755940715552*^9, 3.5457559510961137`*^9}, {
  3.545756040519264*^9, 3.545756086863291*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`i3$$ = 139, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {
    "\"min\"" :> {$CellContext`i3$$ = 1}, 
     "\"max\"" :> {$CellContext`i3$$ = 200}}, Typeset`bookmarkMode$$ = "Menu",
     Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`i3$$], 1, ""}, 1, 200, 1}}, Typeset`size$$ = 
    Automatic, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`i3$1097$$ = 0}, 
    PaneBox[
     PanelBox[
      DynamicWrapperBox[GridBox[{
         {
          ItemBox[
           ItemBox[
            StyleBox[GridBox[{
               {
                TagBox["\<\"\"\>",
                 HoldForm], 
                AnimatorBox[Dynamic[$CellContext`i3$$], {1, 200, 1},
                 AnimationRate->Automatic,
                 
                 AppearanceElements->{
                  "ProgressSlider", "PlayPauseButton", "FasterSlowerButtons", 
                   "DirectionButton"},
                 AutoAction->False,
                 DisplayAllSteps->True,
                 PausedTime->8.734678745269775]}
              },
              AutoDelete->False,
              
              GridBoxAlignment->{
               "Columns" -> {Right, {Left}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
              
              GridBoxItemSize->{
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
             "ListAnimateLabel",
             StripOnInput->False],
            Alignment->{Automatic, Inherited},
            StripOnInput->False],
           Background->None,
           StripOnInput->False]},
         {
          ItemBox[
           TagBox[
            StyleBox[
             PaneBox[
              TagBox[
               PaneSelectorBox[{1->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns4ldkXx08lIVMnU0YoKpVSQqRc+lYkTRlyq/h1QUlKZNSELhIhQ7mm
IpdRh1LRkXBUktDJ9XA4xz3t15iSpIv7nN+eP97nffbzrmfvvb7fz1rrXeTq
bXt4KovFSqTPf++pe2VmqnwvQO7Z7q6HRwnkjV+u+iukDZ7jHRFyDIO+VF3d
oZ56tLuVKpY/ITioWunM1NQh0aP+b3YpgaLiNKsZ9oVo81qSsO8IQciU5N5X
AhFirIXbZmszMBAeSJUeEUD/bvup53wClp+M3sXFQlxQ75DPZAiym2xOPf7e
jsQ4+125HxhML1+0WyemGorXrcT6t2h8v3eO3FcOeiRbW6+5ENxc8MNdKUaI
OB3HqtRegkK5jIuzj+WjvcJ6sN+dftdP4NpY1GLyRVfolEyChVbKNStZfMj0
Z7HDkgkmAjrSEu6LEZqrdc/In0Gtt2+bmYoQ09cLe8sXMwjqnOD4e1dAuc7G
+lQogTuv9q6ptRjKllmcBmcGKXsRu8WhBUuqrbTSNzCwVFmaH1mcjw/aquqL
6Pmt5ZGvU4Pegm3Ge8RJJ2DXpDPKG59CIHE7VkH1Ndll2qvrKcLglDBZ7V0M
DpoPFD7IL0KrnZHCLU8CJQPr9ni3KgwsGDkzM4ogqSr4zq8xXOidlXp1+zBB
T5C+ZGFMCWo/F3oreBN4mQ5rTuQ0gGex3eNcI0HQYoWnLO1mCBwS0s79zCCZ
eTu98EQ67p1SnQg+SPe7Nmq5yfkpJvuMl6hSv9S3TXO+MymC9KPEHF11BqsK
9uq7P69CcXKw4GMi5SHUZ6rRjFKE7Rw8mn6SQKrv30dzEuvh4xH+1+dYqn/L
Sml1+xeYqLiTP0Dvc7wu55PylBYoGIb77VFjMIJFyb4dFVjsnG636DKBskNc
SvYaIZyOWh5a/pXg267h2k41MQqitrf6BDDgXj20YiurC3dlCjgfsxn49HTw
xdJZOBdZ5BhF/U+7PWVyzecyDPFlNob6EZQkvlmrm/IKCrW/DzidpXqbxZ8z
HnuBeBlW52NfqmdqjeaCB89Ry26tL6VrH0nTbrHsA7BLDpwudyWwPG9p61nT
AjmJVPRsPwb5FupWAbZtmF2UMC7nwUDTZF20VtczjMe0Bbv6ENS/MrDvHa6H
3Rf25ZA6grPfuXvn+YnRV/w60GoNA/e84ofcjkZU34kOFPUR7GT/3LQmVIjS
xZ3FxxQYmJhIe7rlVeFDXIHEMYmgzzXD9cXaInimfjghpv4Hu36x8DIQosKN
2638D+XfcL/N1t2vYLHmWsNqf7peynw4ubEd0Z0XhXqxDMInzZYbHnwOY6MH
E/t+JzCt99SOUqnFrcPpUrcyCNLHEpNOJIignMpzdTzI4MTm9hff7tdj6rIF
zgte0nx+Gd4cayzG/t68vc/sGLwxL1z7LroFWhG8m0OTBB4lY4YdSVV4d2Db
wIc4mu+uj+laik3Qid+aOdFB+8G7ZAuF6nAcVrOf4XSA7hdhYfY+qxzr9Oao
SKjf7B7xjirtCrSePq1tFEz1V12qUVb8Bo1PyKyrlB99eY0Nb943wM9LwU61
nSC67l6q3ZYysN33zn90hmDmocKn/sl8kOQrkw8u0PMcJ3n8d0nINeHJi+l5
fXriqVtWVYN1PuTwNKpnUHP5sZq1KfDp9pYsp7yz2GHzS462QHreMwNzymO9
c09Nx4VG2Bb6644O0PhP3SkR6QUoF36alfVfPcRHLXzKrkMrQ47E0frlB1Qr
5Ha9xi93zS1+o3zNtX118OHVBizTyFA/2kUgcqgxrW+twibRCs4/0QS7n316
vjHyCdbywq2n0/0Gx1m/FNtXwXtzb/bxEIKc3Kj7N2by0cIJM5dKo3rKlynm
ylVgRDr8QkAYjQ904Y7VCJDx9yz1Bnq/rBUWO3QdGuDgEtjX1Emw6UD/kMzq
S3C/8r5gO83fyKf6j2SmDNMM9RRPBlL9K/PukLQKxM6V2+5I9Qqaf3HPyd9F
tC93JQRQHnU0PFwuVtZhvfm3jVuo/yfYD9Iy9Utxpttk921aH4WXFzg2DfGg
djtiw3rK407f6ZqRam9hzg741JVK/XyrbMU934BvLekZxg9pP+iZ4qbn34Qk
dxklJxFds2wy5q1ohLT247RaDkH3b05Du6qEEAVGhepRf5WSX/OMPxaBF6Vh
EX2cQFNkV/bStBJLdocUF/1JUM7RyRAZN2Lzlq8ns4cJRqOCBAYKDZTbrlO9
AqrHTb9JldJmJMpn2gX9xGAiUV5G4lAHU251RuULAplRidXjQ5Vwyf7R+57y
J1o53/DXjWWw2USc59L+9XLZQq3ReY2o3Z+bu6+cYGTJwyNqzVUQZC36mppA
eXwywfvjVjXUlyfnrab5xZnWC/LU/kJJs643l/J0jJNiwNnaAo1N33xjtzHQ
2FHGX7GjBa/PB3K5tJ9z/Wflpcx+idQwXmwTrccs/f/dEAxXI19iW+hF50n4
qGwKJ6oImwqTgrfTedD15qv24EQtgqcZxO3PofPTnyQ55ZSh+/FF4QXK//Fr
H3uOr23Beamguf7jdH4Nmgt0H1WhL+E3o8c0Pz+lbjfzIzVYGbItcdZryo/v
+nOGV5pwW+bhdxfaby5/iVm1KkmEnP3mP5m6MJh1LPSeomwlpkfoKw9RXkeS
T951yi+G0j2dWIkHgfVI/+xRXTFGZDuv+tL4ouv/Xnmyjg9P7xhRDNVnzwV+
npqgEsPqndcUKF/LxAvjVbK5sPK8P+0HnX/2O9cJXPktkGTnZ143Y1B26X3o
WHYzwkRZ7tX/EpyR1rsfR/1qvm8+FJ9LYNMWbl56qRRSvUqhqdQfOa3AkX3n
27DqyJx91zwZ/Ll1sCLOtgwBNrozvKkeh/ydbtvxGtFqJTupQutvJN40fmea
GGvGI0cHQhnYdNidsrRphset8EsDg/T/xGt13dzxZiyxCuHIqjJIKrYv+Xyp
Gpnydv1q9H9gkDV/T1F0PcasirRMuAQDdf2rDQ5UQLN8T+D1SIL+xdalgS/5
0DmTVCNP+8uvnnU7srnNuNs1vLpbmYGrkqFaXWMtwiODT3j9V09v1z2xnWyE
wtjZG5qU9/8DEg3JnQ==
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3lcjO/bHaQS2hRFCG3oixZK6EQhfmiKQipJSdYkVIoQJUnapE1RSbvS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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk41WkfxpGkUoQiDGHIqCylQum2vCQkoxjbeywxbbJWskyUZRwjKkK2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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs4lFsDxYkiSRKpdAq5pOKckiHSwlFRKCSS3KKSSLqJyiWho5DcRcol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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 2->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8VekfxigJk1STCSE1aVGiTZYHFfPTRLZoHZKbZCKGlMSPRmRJkrGT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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lO8Xxoe0oCRfkVYpsiVJScndIjsJRRKyZaskayQthJAUaVGyp6Ky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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk0VWsfxw0ZlqgUuYk0XBo0CEkD36KBt7jIeM1d85LiquReySyUkilU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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81dkfxm+ZQVGjCUUhRgtpaLSMwkMhFTNC0Yx9iOwiyShbI3EpRBlL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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 3->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lekfxs8UKqlmZEQl2pXIvueuFDFMhJIilTKJyQhHaH4IZS1FklMj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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4lG8bFZKkooRKRYmK7FFURyql0KIoWxJZyhYtPyShskSKZE+2Etki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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx7WMKSRJkWUsXSqTupZRqvFpbKm0ISGVjMZaISM/EqayZCxD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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns8lNkfx2ejtov4bbkVlUaRW9qoZOVjiyK5S8JG5JJ7LkW6KCqVsjWy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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 4->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekbPpmUbJEpmZzJHJMSkxkhNXQbTdonlaKfpWVSiBip7GRyypKU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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lP/7xanIVkop2aKkiEpKKnVK3zZJkrIm2fORvZJIWVJSqCgSki0U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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk4ldkfN0k10jJliiwpNRTZoih8KNnG2ggT6UYkJgxpNMyUPQYZu1KR
dVpkaa4WxhLu5Zbl4nZdGrzva5m6UQyyTPf3/v44z3nO83yfs3y279nhGXjc
e4WYmFgWPf4/K5XbNXZtyMSX/Te1J09TuPS1mKJIWYDyTC3Z1NghjPjUfk5m
DqCPGUl0eBNwVfjIau9iwbzLJFHqOIVgs+rICsdaPClYbskbIiE5n5JruLMX
0t1/uB2/TMLkWkvWifgurHi8kGpdTID/Y7hf+zouRmekFYlFArpt05NP3fuw
UmGlWVLrKNTj9f/cz23GGk2X/s11JA4vqWpr6rQgo6KuIp4+T6jJzdGXFKDo
fshvBS9IBA0Oucwp18Fib/K5w40Udinnmo3c4EKqO6WQe3AUF8Ijht2W2Bgd
sakOSCOxIF+4r/XMAFYJalMvzf0NaQ2vi9WT1TjVuTFm90kK4t4xiv919WN6
tYFPhdswbgSXIf+LfuiGLKhL9RGYMO1j6OZyIO2a06dlQKGWf2T+XWkjivgy
xjGjJCxDS13CE+qxyb6pN2ctBXbs7/fWn+Cj1HdVbeeGESQNfl+v5PkaSgfW
GshtIaA6kVTaIOCDk+tT6Evj6xVo+Fbj+mP4cZWsiVsUthTYR9qLCdB0V/t9
rnAErD/Pnmku5YGZHrJJ99gIJqzeZ+SVCfCPl8pMgCMFhurBn8c5bRAxI9cP
51JYDlOQ5Wv8hWDxd4YB6hS+irESDYy/xtVQP//5sRGkPuozNuUUwFcm+bKD
K43fufpPXF4r/HeeEe2PphBwnbUibE8fDhZsttYfoHB1j1LFi/1voMbQNxKo
DIO/qLVkl1AKYwlW2aZACjWzmw1qxgbR9azkSjpJwtfVS1bnAQcTY1Z17lEU
Ni5cfVj4dQG2Be9oival0DPYzNLZ/QQ6x4z+u2xHwdByW6LsQD82ip8YblUj
ETtSRJyM7oGltAZSVxFwukuaeDzvwDZKND8uRWEyVGnio8cA4h6U/54hRSIi
2GKDTlAnPK+wlzkKFF5mrmZFzrSALd3rKZSgYK6UFWN/i43sQ6vW53VQCOOF
u1hK1uJtxWReOa3/qm8jNCce90Kj++1MVCmBl7J68UOnGpD2dPzHvGAK13JL
dgynPMCr4hZNyTAK8g/ieyz/7gW18ixvIpLAvFBclHSbj3V66z06VxNgGiqd
V6nrx973V50q5wl8SLjebqrVCqWiI7aGuymUucUmujcwwaj0Lb9N7x+hqFAd
bNUJ1xhi10cJEi3ina4q+izENFTPJLwnkb8odduEn48fxN2zX9L47Qst3jU3
y0Px81Y1T9EIDhTE3HDL5mPIyAj1z0m4mjy84PChAVsPWTAT7lAY3/kjK6Cj
Dr/8pPfXw00U+qL0atzsXkOiQ426pUfAxkV0+WVVAzT+OLrot3oU1C8SlmYk
G7piT8wuZJNgWC4w22zTcOOAatRJNwq9uy0vmDjyAeqvStv1JOrmn9sMRvXi
Tpg2uVRAIcs1ycpxPxctjMNT/EMknozIxn38/jlCWY+07Wm/hXm3NYsKepBy
x+Gg5RwFmfXnKvrmehBl/turs9IkPsREzwtk6/EuvUzqygitP1uFw5orm7Hw
1eTclhxaL6oK9w1v9qCo1cpdLZ2CSfhgoURbMxLf9ngXZlBwyu3QSP6Gi5UF
jRJZymNQCrtmrF9XBIGmRWv/CQqHX2jfYs8ysZ1dRarTfFxckIldG8HHM+nu
LhX6fT+obvId/YqHurt+QzurKeju0Mn+N5UPorzJbOgJhQ8MrSpl7yKYbc8e
O+hJgcecGDUa7EBQiGh6ez+dF+d3pZ+i8TsiWcZf4UIh6vSrFO1Dffi8tG7d
vhGaT3Ghe9D2Iljxjjrrn6Vg/KiX9a8mB86X9lyIof2zeFN3h3xYBQIv1wU7
K1M4wHQ0VbrLw171aOY3dH5mx5Zwf+3vAkN8RukfSRLHI6blHVQ70NTWvDW/
kIBJbu1LM+loRPxs+t1ZDzofStttgpQrEGeoJoqn15SWU4KvHBufO4y3FrNJ
/OsfGhRfzsI3Nvm1/D4KqSvCn3L9XyHlVEl2iB+tf5XqXrF0NgbVTH5dU0Fh
RTrnbooLD3a1UyWKBIEy/+UCje/Z4AgzirViKZRsdPAe1PsTfkXJk1940fVe
+XL3SnpgfUksMOgNiYL3j4UaJgMQCG0yrB1JHF2Oavz05DUq5y0kGatIGP7c
UeyoMQCeqMcjTZLAdJCNop8XF0ULgy4rjUmkns6M01gbC0mdytgG2r8dJ5fa
wus4kBNGcjVpfTNmXV3yJNkQu/55lhggIeO61dqrsgrPjUUty1dpPs2fTllP
d0NOTo+5LZ7uJyaC3UaZdD2Hy01cMwrGnaOKv9mnI8nCaymD1oPdLrPf/xkW
YC7A4Fx4yihMSPuL0lsqMB60Qd/IicLeVR7mW+p48FSUN896NIK87edX78pr
hab6/LRT3CiceJXfQbwYR+bTJ11OUdCfdlncyahC7cw9h36aj69tnXenerJx
Vul4ckIRCb55s/MzzxsQG7/xw2NaX5buiXkc0y4EZV/SPBJEofm+Xdj1Yxw8
sFW5R2TS/pBLGpB58Qi+cgxmKX2fiv37/BTtOhFkXpNWlUQibexgXI9FD+3n
tKT7ewhYm2y9nSbThYt68tccPxBYE2AnvOXdDgOx2U/b9o1CsqYrjnrYBS3t
gGv+shRyuq+cCWd14Hbplwdcmyi077v65fBPvZDsXdbOp/FOC7/CFYX0YO27
R4uvE0bQMMUcK/nUjW+nEucCl2l/VZ2I9jkmgMr17MyqhWEIy4rTk924mNxk
+vdOH7pfDKTO3rJ/gZDUkvbQmxQOGTw+LFwUwExobXf+JolPaWWsX3R7Ma+Q
lCviUXDumBu/1NqP49R+IqeRRJJLynqI0f2/f+FtVw3tr2/nXeyFTRArsJNP
ovtzFOuNT2RlO+b4Y5JqR0iEv2qprc17BY5E45s1B+h8avrJw8GHjaGUkhZn
gkJDVKyvrUE9mk5/MM3xp/GNFAREMEpw+2aNyhSdv5sN7AKnGnjg+BdxRl8S
KMpSn9B/1g73+6b1VvR/5H9SNclC
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41ekbxk8iW4pIKUtUKJQZxt7cpBmmoWLKyJaKElmyhWJOSUWJZixZ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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 5->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkbP2FMRMkc6zed0UQjmfAVFfLzifIZjGJUxpY9ZmQZ8dlSWoSI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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8Ve8fJ8pIGaWpUmlYRSWy3loSKiEpM5GRjJBU4iuhXaIUlRHJJiRl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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8VWkcxlVDEmW5SiSkRknTtY4JPbZRNDXWUlTGUqZpyBJthKHNlqVs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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk81Wkbxg8vLUYykWSLkFPekJSldEmTrWzNSfYtDFKZqZlKWZskpuyS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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 6->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4ldkbPSQRFU1jUE1uuUQhSlGtboQolcrEEHKZMCRdFFFySf0qJd1U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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lO8XxpGEsvSNFkWyR1S2RLolZCtKGxEVUtmKLKkQIQqJSKukQvYl
2RqyG/tgyDrzjhHaUCnS7/39Ndd7zcz1nuc559z359502uOQExcHB8dJTg6O
/38OnN1S72vUA/vr7PZQ20lUx9pJiXb0wnn/OYOp0wxovVPclxbdCBGn250m
MQx8c/XNKNR9B5+3B1KjBQhwvYm2cir4ALsY1U8h00xwKMmIjq3xQdOeuSjx
kwTG7S6L1bU2w2dNZ83vYwTYYw7yxXq9WNqj9OC5Ww8c1hitPcZ9F9eVbTk0
bQkYjxY4+x4aQNrI7A2H6DHolYWpyuzKRJyImJCWLAGO/nPTD8ri4fvz1e7n
Fwiczqs+vuFHLyKsH1444cRGs71Ba4FpMaZyDojxLiXg6cGIzVjXAQten44I
IQKxFZSPZtkfYMmtabeqj4lZ9XOBGY6NsFl99MXURTZKhSaoV+q6EFu2X05x
L4ENM/++lzMoGKw5FPjTl4Bew6xdilU/dC6ITHKfIlAYzVf86HsPZgLEHIvC
x/CN/Sir7UIGlpkzrimKE4jLVT27WbMd2tdS/m1yHIGUvXGQgEEHzDc0Lovk
GcM/mQ8t1/1K4MAV1tKYTIAmG6x762o9FC8qt/y+SECnhv+sq8FHmNeHlqum
j8F2/5GnlubViG3UJNyyWXi9Xa2yMq4K1CbLas4vTAR97P9uduEZ3kjP6608
QSDfyl1VkdGC+h1LwniyyP40MW8lnanALaXGCs8yAlPdXTcNayuwz/p54G1z
As+C/Q22ZVLhI/Hu2L18Jq5+vc1LTciDvvxVDR/yPMd1ykqHu6sw9Sdhz5ft
BA5MP5t7IdqEhfjroeLTBCwtL2ivjmrGIK+un4IAAzX9QX3f7tKwYvf7k8lZ
LGQIOyUs30ZD/8eAkU2qY4j1aDcvry1CsXifjKQUAUkdHz4zzg48FZI5ETbB
wjcd20dfp9JAn84O79EnQHUPnLCwocHhRpy/bCIB4f1Pbu2kF8FPWIP7xDgT
LsPJfxkKg7Aa8Kn4PEKeR2ywjB1ZD7meIOr1URbiXukeXo52NAYctovYPwZe
Wbrfwff54H18t9FKm0BowENFUYsqrLaqtfgkx0TE0Cv/PEYXDCLrF2X72Sh5
crcp/1IXCu8MN58m59U78crx188bob2mUfW2MgvCVhfG9ZbX4E/wpMuE+Rg8
wxu2/oi7AbOpeb5ksh/xP4sEQ//mw1u1U373CwJpwSs1TMzKQX0Qv6NnAwsR
da2iPHnvYex3p0cwgwn7nXxZa0vTcXLxt1e1FYHG/1yD5q7Wonyk4fQnJSYo
a6J3TtlSEf+6W5zoZyDn8ItlTT860a4XNhcXycRLo1QxgYu1OLFbbgmHCRPm
zIHWqMQm0OwLtvr+x4Tot9TgfL5uzG7KYbBNJuDjU53tpkhBbm7F3tUUArxj
nO48mX2YeMqeMKSzMNtM+eOm0AqXgFUXV68gnzM6bVtNGyFs/+pSjBADvNrS
7pfFaEAd5w3ZdWOYnaoZ7TvZhWJ9HqG7eizUVdwwvZiRiOCdX/7yGROgVLvk
9W9+BqGw3qRuDwJChxTaZtd3gza134jrFxOHv7UcWf6vHf+dHv3IoTIK4SPz
h7mda5AoetaCmkr+f+66MP+KZoj43XIbXsPC0hDdJ/MnGtG5kUvEU2IMzy6O
VGUvS0SFZvw/QxcCuavOZnen5aM/R8M6Mo+AwsO7flm0dvxtYNuLLTLBVvms
8GldD4QuVxn0qI8hcyIw5FpjO+o8Zk02n2VgzstUT9CgBtw1e08KexN4pHfq
t0x+Org2OwQIkfq2SPh+SPnWhBd2bZxWCUy8Nr/9QDLkHTTd+IIqpAns2PRq
G92yH4e9U8JNdpP3u1QjK5CjBEGPHXPEyXk6v1OOuXsHDYzlZtP3isnzKbzh
0YlpRZ3DePT5awzMztznp0zS0VzxL/9aGhvu/gcHDeTb4bDM9QTXmRFIFvsN
9SvXwpJDKujGeyYijaKeKDt3g+fryr659wwo/FhsKBvrgD9XdrZ/EjmftreP
l57pxZTvtrG9AWwIXxtRT5BqQUPua4t4j1GIHdZ76hxAQ2F5uoutzzDo6Vpb
Ww+0gHfZHG/lLKkn0qovC7RKMCTnpypNIzBQbdxxrL8bIkHK/U7/WKDolwx5
R7Sj25Mi2+HGRoNzQhhhVw09Jy+vA+ksjKRw64cnVKPk1Y+P2gNMGCifWHpm
MwXW55xWrZMksCW6xdTDuAOjJiJb00xIvRtMYYeo9CH/bfjhN/wj4DjidH/7
4FvIfOsNuB5P9tPILoi/vwjHbPc+fi1P6htxmSbg3ooD3x07ZWZJ/fY+/r3q
Si3yv2vNbC0gMPa1ul41fxC9tZJSmw5NQn3m6zNKTjceaoSMDi5jYK2lC6ej
dRbsntlbuZ8j/SdVsyFV8TWOxi6rqnAlcKj9IVfKsW4wDkJEWZkJSTkW59fe
BAy0nGUSpuTvT/Ao75zPgRfVgbvkEukHku/cL/fQYdV5edvSbAZEIvZFVE3X
48XbtRHOx1mYKizlGfnejoxpy5t2sQwocl/TKYztxEY200P4EIFmjW4TzdR+
jH9sD3mzitQbV2O7mRUVyOX1kpzgJhA9eHFLzNEKZIcXjz+lMtFeNu5zOaYR
rzT1t3O/Jf1hu+5cbigFTxrUJKr+EDAdMB0oiB5AafjQ1r0HxxBkznVuwS0e
ipfoVMkzBLip/kv03KrAUtQBfx4T4e3L+wZPvEeB/t+6eTMWjrf+lDa8V4X7
FpuWrZFg4Ym79b7wr3mYmZgWaiX3k4P/WHFakQPWRj/UNbEnYEPIZdtP5IJQ
vEdfkUb2Q99u7cXKx/B0tx7PJffnR8ZksmRgL47QIyRSyO9fB0eYhea/RX3V
1buB/QR+T5e3V657gUOyuQ+fkv57eJyhFvugCyvCW5Qe55D9fHCnjut+D0qa
9PaVZ5L7v3XPMfcTxbh15zRfgzWB3Y0dBQaLb5HafU0pcpQJZ4N9WoN8udBP
nG3pIf1O77ZzttX1VgzVGlL+WBII0jmmzffnDgrUC0eGyPp1dhxe61XaBwN/
yW1M8RE0pDSnZaYkYS5E99lqcj5c9v9KWvG3GYSJfPuJPvL9M3f+c37YiYxe
l6/a5DwG7Up7GvokAqYZvWXlJB+9SWVeNdVIgaup6NbYQNJ/VtIE6p1bcHdx
/04DkVHEZgku0WTm4dZW2eL7pD99UzUyZqi04re1RntSPQGHw/c43gpVIu6I
70lJLhbmooc7k/gbMds2UdZA6tmIUa/8qhV98AiVnf9wjcBZGl+kyhQdjwyf
j1SXDsOmLk6Kub0HLytrKFJzZL3flfbEFIfDQbwhfpCsT9C33URNuxZhHOis
OcPA6aK5kV0RbZAwoDCSKQxc/RP92V/tBfTR5KNBznfuyRQqwyMPPBzpL+Wc
SL+q5ZtceasLflffC/CWMWDzZquuZHQ3xou6VM71D0Ip9ZXNa59yPAzt0pMx
Z+Fhs7HgegsargapqRSFfUK704fvVgwaqBVxP/zlx/EsfmLy3alHkFswfh3g
RSBM+ZR99yc6pM8c79xPsDHfsqK+ecMgbNzna2OVxlEnsHL33EcaDE6VXJNd
Mob+K35bZu53gffsSXFx3XHIpLtkVE1TYCD92MnHiEDTIo+/y1caxFrEzOIG
2HAImzmV75aIMDOKK+s8gXfiTaL7OHqgYBwhnkXy7kJ7o1TMTA+abPKo6yyY
uHwgcEfix24cUCxt5qePQi/pqb6vSi8eeUltM04iUN7HfU04MhU/e7ONo+MI
3FvncWpn9wD0Km3XPr1M+svumecXxoox8MnH/TnJLyoJUyHGS2ugMmZ2JFeP
QMm4pMAF8bfY81PSY7GFwMTJ22Je3/rBs+bbW42+fsi49FhrBWaROhzu2nqF
nJfm15Fhiu9gFL7lISfJ609CLFhzYtWojKc7TXCQvPWHe5y6pA85NQfvcPkP
4cohJMqo1SM8Ryn46GYWVORXXiyO6Iev4dD8lw0MqAY4nbXV6QBjX/zIwV8M
NHSNq/qXtEL+kvR6XwsWuA24LPOn6XBc7vZSrq8Pub+KpO3m62AHWanYSwwc
1y2MUzzaAaX6ycHsfNJ/KsX+eceQ87I/dU/RbyaeKdr8k4qNhb7A0Y/T5L45
bHqqabk/HOveOF+bI/d99+qI+MId3bhd77bUjU3qb7Pa7ZzMDhjEtDw7Ikjy
vYHjzKrsdNQZ6ZssBJN6siVzSalfASqd5usXFpi4G0bTmR0fQPoVZtMSnWEc
funxN2K0A7s2SR+KnGfBTOOHyeC/DiyyOeW7K0axmprYQ8voQXDb2ewmkq9L
mH3ih863gN7s66PeQd7fbI6NmlMG9iR9Of2G5OcbUpOf1XJJXiTCFtdrMBFW
O6PC+lENAbZNoWwUeR5u1XGflW/AVQD1XU8I0Gu3tRaspaGtJS7CMJwNStk5
35jVLzEeGqiZQvKQ9sQun2VqPYjcaCEz3MgGR74Vy762DteNHtQ6djDRNHnu
l/EZOoZczGcjJz6B/ol289eKfnjzxpS0XRiBpXfQaGFyCP5Me30scCDguOHv
Cj/nduicWq9k0Efqb+UNk0z9B+iO3XU6htRHyZzix696aCiX/X1Ag9Sbhhu/
jVI21yLQ0FEuSYkFLcF9x2wkWvCOwy2k/gQLQr0FtTb19Yi2jDK/V84Cx9C0
bM6a9+haWXdzlIfAVY39T2pfdULvRWG4lt4YXBQU1D6Uv8dE864PTiSfMG5l
20+tLEVytsCvc6Is8Aw5gpOfjjWNXq78/xFYy6nFWpJTh5WiClMWXGxQgx+q
28z2QsX1wZ8H5H4EvRoUpd+5D2tB/i4RUq+bJVgKwbU0JEuUGA0ljiB3WLa7
JyIbp6NBLyL5YHGDMgLI/PXC6ojt7Tw2PAUCvVYGVUO+e1hu9ioBv73iRVlE
M+4vsM2NSb89TucM7xtpwknWEUeZNrKelrflKZYfsIVnXiZqEwuEt2BdVHst
+LJ3dhFaDGgP/8wSPdqHX5NvDCjnGaAePKXz260Lv+znRctNRvAoRzZXvake
fyRcZs5rkfvct+fv+6pm3FtYx8+TS6A48/iCaVAPMoT+5SpLs8G7Zf3ls3d6
sSjiSFM9TMAo0E9/tzcdW2v5j/CS+e3NJ6p8tVsDzkee9vhynwWxTwfOZL+k
YrPFeqrxFSZ+bLcOWWI/BE+fwvEf0Szo0TZbbvdOhFkgR+qiO4EFvxTP5Mtt
cNj79mFGDIGX9caGvXZdUF23N14qfxSSvoT01eCXeByaEhzwgORRu88bjg82
QDhxr8Jxa7LfqZatj50LsIerb70smadpHRucbt6qRai7cbr3FvL+eBuKdxp3
Q9N5Qi41j4VywaE4q7utGKtld1VKj6IgPCJqNKAFn7/IreIi+Wde27D+WHI7
GMFK30WSGRjpv7enf8tTbEiqtVA/QPa7otL3e3EA2IYmXtdJf9q0/uYVz+01
2GYnf+pXOpk3U9ZJc96qhlW+jZ0Jmbe2GObTaqw6cfcyU+nvFwIjlWHRU3VP
IHd2nZUzOe9Ta6LoXZk9qCu2f6oWNgzuZcv2OpH8/0apTdJLaQLahu+KuDg+
YuiQS/0vHwaCXDcJXDQLBH9mORkACaj72nNxTTSj52RDyB8BNl7Qlb13b6BD
XkLk0kEy7yRlhKyUc+mF5NrK5IHyYbz5nZbgk90ERXP1UzdFSD6KanrXuN0P
U3eU1mWSeqcY9jOHL4uO9jlFmU/WE7g7vVq8JKUTtyX4Xi7FEGLCnzzT4OnD
WuOLkV/Xk3nRmyKbl1YAwalL8nM65DwQyh4F1C4IBwnu2Cc0Bq2io7aU9Peo
e3t+p/A4C7cOq6frJvYhiCGpVUMMwmWpJl34eS9KY4iHD/knIDOzwnWrYgtM
hz0sBHlJnk+VMHj/tROmW9RNta+T93dD7dcX7TIMJWiKe6WT/YhbJ31DlYpt
YV7ZGQZjMNWUW9zA1YBnyhuVFiYZuGl7VY5yjILCwk3XnCQImPO9OslnPASJ
Aovc7NYJuPyxzN78rw+aQ/razJuTgMQtPb+uPpQ4fj74UncCAXfq7dzsafAJ
Ock5zTcKlfAKr0v6HxFfKrTDR4ncJ2rYLR5zOsxtlgt95WZBRDA2wP5vGcot
1qy2MiPAN3NkRsexHZ50bpV5PpIXEhxjPa+U45KOrL52HQFXIbsm69hG7A7x
PzdcQOa1hLZP7QHtkChq5ooUJPsZ6cLDp92C2n/HZ+dCmXBI33lqPI/kQ4+k
v6ZSJH97yrLY9u8x1JZj19fKxMSLnnPlyTRoUj/9kSLv7/X7pMgvnwvxs6i2
K4bMR6tDL0nxp9HA+/xAmO46sv71SveD7ag4+tlvkvsxmYc2prVOmQeBYi5k
vIycXx3P672RzE40LzNYfFFJoD29/tBKj9dYUPvv6ACZPx2yLj7m4StFtsE1
iYVPTLCuf6a6hnXBlpobvCeZDe+NfTW/n7UhhHD/nUlhYb3eri38pV24MBHt
oUb6j3rN7giBwEHEW3Hqm8h8RMo3p3N5IRRELwSNbyF5dI5TQdfzSyeU23Mz
toWPgHJZv+vyjQpIBqy2SxMj9eBv4e8k3WyE7is7IUTm69UNC4zO40PYrmlk
yrDpw8bRV3z2Z0k+LXmcM0DyvYhUs/vzLjpeeoom+C8dx27rO4VmR/shfEJi
5mApAxf6H1TkZtVhlUXIJUrdGNbKbHSw3NAMk20X7n3mZIP7Sbh2LDnv5sde
fb9pQNYXdbU783w9mcP3cB1UZeHZmIfIzqjHEPmgFehqSCDesSlC4VIjpITe
Kkb9G8VkVeXNhjwqxG6KDMpakXx84UVZo3oj6ZuZCQNbSX87KpuQI9oGQ58x
ReNeBipsEm3806pQx6Dz/SxiYvlT5fc8y3uxo/jY3QgVAkWq1jlNEz34Jvj5
t9nEICQz9N5WeZeh4aQivWAfgRdh9vOChXREUZKdeZpGMSe+pJJyrQ0K/FPl
zztY+HamaNzcOBsKSvvDFBoJFGpofcySbse2wmT94WoCykdrqsx29mFccsxc
jfQL40lry+FhCtI25ew5Q/rRPYEpjaivzTj7qEOkZisbtp3u+87c7wDvG30j
SI/hf69S/Gw=
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs8lOkbxq2kDDpIDkvY2YqKDSGVuiQsoaUkUQY5TBSSDsqWNoXa1sgx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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4lWkYxoUkRaTQZGkjYcRMGkpzY46YoYSSVISjhKFkmqbsZZk6lhpU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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 7->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8VekflhRqInWjqekXFSohU8NMY+aRmCyFETM1LdeSiWQbEU2iKCVK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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VV8bJZKxUBmiTBmSKSUqWSVFIhVliAyh0kRUlCGVEipJpqTIPEVR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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81dkbtkZDzEhMiWgbpNxMi6V6JFmiZMhISsMVMcnaolHEkCypbpab
FltFxsTkJ2u4tkuXi3vtifs9ljbSlEhpvr8/zuf8cd7POed532fRcj/5i6eE
mJhYMr3+v6e/lFyhVPkMF/+KSp6MpzCj8+d4LPsx6sZttefdCDZp3PDjUHy0
zvRNLXYdgeLAe7G42x04UF4iuhEmwpVV7iozVn04lyyfuiebQi7DFzOaXcj6
cYXeS50R3LcJ1ppfw8d3XXrD01cJeAuYcvZna6HmMZG4V5tA84ZxuvHnDOyP
nfo3YQ/BNa8Vgysj23DMIr8iPodCusP093rXhJibfhi3OFoEQ+sTDM/MDtxU
5EjUCAi+UAbvjOuqUfhj3pQ0i6CXLf+mcYSPiae2q+WmKZRNOHZwrXrxNlSH
mMqOImnLasayu61I5krWFKsS/B5ol9MyVoMcPS77xO8E6fE3A8KHG6G+I3O0
aIhCkvF8hWpsHSTWOCV9sCIYIF9bWdktUPGp1jsdSZD32CE5+RofbcWsBSNH
R/BO6U77Ii4PIXZxjzS3E0iUiNX/9r4O4wGSG1pLCWJL2JSOqBPbXweZTRUP
Y8d8uoKYJBfPqRCJ2WgCwZn3wd4qTVhiMzmQKEawV6xYQWBUh3jq9BvWCwr7
5p0SdRbxsW5WqHQ2kKDWe1tzTWw/9AwO9ihXjcJn0le96bUAjE/ji9fkUWBK
11rMVPLwoHrXV9sYun7J2UqjTw3Y8dcfjlNnKPDHssdWXS2BgWpK5O79BMxN
UZFvDMrhKmPoyucShHv1f4uO5oNjrrsvNZFCp/fTjzx2NVixHhNaP9H9N5Bx
05XvRuDOsVkp+v+ri8JLL8qWgNP+5crsOgJTCdu7ciVtWCK8mbbPh4B0vu5f
XM/D/gJZ1k+PCLwjhm7VGNVj9ESa0eVGgtQqo6Q8swE0sqx2m8SLcCTucJDz
wHOYnPA4EuFCQTGowEFH0Ic/T4Yt9VpJ4J9yP/fs5QeQX5sx+/cBmq9O/yzK
aG2CNkMrtmQFgVOSXNHW+31ItPfZPOpMocrSj8+j77f1lblQtX0EDW2HpAuK
+3Fs8cWnv54aAkN/qULRTD1kvW4nPJmg0FC9o81FshdFtnJnH3XQ73mckj9z
pwC58l36BecJZmR9p0N+bkSb/AFbySyCUZUItbdBDegKEzwqZxJk/xE/KsUR
QO60dRvPjILyOiMfl+h+lJSGjFbdIeiZVEmT62tCbMADSfFcgmNl4q/c39Zh
30nGXKUJweW8bNnHuoNoqZl+yAwUYeUn1ZVKu4qh2uKoExtOoMByZPqLd+KX
2xWZNbMisDZaVFBrm2Drdsf06t8EYo4LB75Iu0JMONejRuv5rl1LVcC9uwh0
iblT6EJQ9Fk3opNfj2ydWaaaLwX9K1KFL1PbYdHHtLRkUDhKFclYM+sRFZd5
82ETgbafeZ/5mi709mdo5paLEOUZ9zxmWzX0Tv9ybkCPQEkhUamN2Y6lKRGu
pYTWU+/o4NjvQhioa9Wwh0ZgyuxcsaG0DtXHo14K+BQ+lHISzZ/U4tZm7vZ0
LoUv7+8xP38/gJtMy1NmfAJbyTaOof8zyNk9lXo1RTD/uKVFK7AWndOFDe8y
CKplgj0+z3pArczRa+oIjfeSTmHoXzsRU3FJYj2Nd2jef5eCeA4WfGA7mBwm
EOmH65TIdsKGq/bQdfcoGh75WASv42L1GcfnD0IJlgf555870gZny/7Q5GCC
b7WxQ1vmu/DE67pHucwIyk3Gry7b34bAaz/H2MRROH/5W3iaeStuKuh5cz9Q
CLWXVLZa1AlLOJ2rbSDYUyf19yWvLtRvroh2C6DnKW0053ioCc72qsHVWrS+
vlnudjTswMdnRs+nUmg8w279ZZub0RCgYhGaTGETK300sKQRYfdffxi+R+Gk
t/Qn3fo2cDBx4VdFgnx2ovb15Z3ocpH0SLMaRXuk72SWLgcVY0OKSa8opAYz
/rf3kBDPPjolMxbR83iq5t6Q04txVQ0zmUEK5h7uG9e+rcTgLfmoTbMU4pP7
q3s41Tjm28VcSPM5af+OZYKsFlTlyK5dEkTh1aReWfjSaux4L5Fm4U6f8y5f
GRrqAcPxbfTWYpofV+7KdLzgIaJ9pYFdBO2PMixJHSsONnilLHkqSev9qMKW
yfEemPp5HxRspcAwj88M8KwEOyxQdYruz7OYM242Hd24+NHQdc5BhMdhbOVQ
xzJscwrXYdF+6mxvVSy9iIfiQo2PTA7tJ9xNVEJ9CxafSHo7oU4gqzIJ9StN
2K2qe3npzwTy+wUp9up8mM2mNjbtovm14ct98TccKL2zbI0RJ7j+JWqfMc2H
J/oZBtYGFN4fiPj1eFY3zqxOyO9ppuAib5OU2iVE3/rPdpNbR/D9Xspiq64A
Gtu9tV6kE7x3FC6wP8yBhnZeVq40AV/rxVeRFB/Z2SyFuHoKdU7X1yrPdCFO
w89y+PgIzK6lzCWE8zAsrvgxPZLC+FJ1l2DCwbRB5RSb9oNtzV6oce7G2MsY
68oICpmdWzhx33oRyV7L8qf92btbOPSDeTUEspu57iEEG60tK0l7EVI/TQb9
ROfX0Y0d0foXUtG7O/mWvieBcem2VZ7qXJwnuif9/Qj0ZPIUphuFODL+z9Z8
Ok9dExL2xMu2IOqOyc4ysREYdsz8a5bLhzD/YGsFm+A8KzPc77UQtzccNpS0
GUFwYExJ/qAQM+rpIXEVIvyYXPPdvEUvuqVUnCpvD0Ms6oeGRIcbiLyf5m5L
628VT82QJ9+JB9p+PQNeFE6xP88vu9QDzYL1vtGeIkyyB5esftcA98ALl/To
vHP1iK0TiPMRKFVbU1JAYcOlYoZ7UQecTmUJ5+JEmLG2lFlTRfvJpPiq9QV0
nu2KVn6V2Ivl13hjNcYEBR1ZYcXajThvKjPnzKLwqItf07YxBSTiBxS6Epyo
4Kw0menGs0kLw+V2Irj95mPMXfgc4TEv/5WihmHqVD+rHNOP7IflTTsvDMPY
vnkbo6EZfV8dyh3KaL6ekzjbLNVA55n/ulVfKTx412hiVpsBDZNczYf7CMYX
hh8K2fMEijkH72keJ/gPCxO/9A==
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41Wkbx5FCKadRGJJjSSXbmIaxflMIkxkhjKwnSy69JDpEiWSLjiVJ
i2VkSREaIhevsWU79p3UOef3q1FMGJKE3t/7x3M9/zz3/Tz3/Xzvz1eeEWDj
JcDHx5dBrf/v87siLT4FNaIyOu6iRT2B3NKjdPfBHBwwjw7s8iYhe7HQRyi3
C41J0zGq/5JIMFVpCNs8gU8VZx/56xOY8tBtl/FqxEPrl1IW9SRoe+OZzIos
BOQPnNpjS+LwWHu4cWkh9MS/BE/YkTiyTa6H3nIHUrnPNLc7kQh2zJWy8H4N
eeuyk8TfU3C6LeosOjMAhdU6nZPSPIiWD65FzzbCzs25fOYdgXy1/V5uh4Zw
I7d2W6o4AYEI+7W5tiGU7Ey69ladh3SBMt+rOk1ILQ/pORxJoixfSdRJagRf
Qx4972viocHuWOivK4O4ksNk5oiSSFk+07CkVQ5BWuBmIZB42WLl9ER6ABnm
/VUTEzxYCofT+XhDaNoq4SkswcVf4sHZVdd70XjI8JHHZgLtDvxStxTHseV+
suKbVi5Ewwt6I4bGYL1hOeNdxYGqs77BknEjGllf2tBBIKFIe0rCsA+dBvSE
vbcI0K5lj6fdqUXn3pR3fjHU/TkZQZl3+rGyPGG2vo+E4J+xHzdM21CoZO70
7hUPdCcbIiy9G/JSKpkuEQTU78QqaqoOwnO2sjz4Lx6eDOYvrmq8hMAJ4kAC
ncSA+TOzn/7TiHvF/LoHmSQOxur+WSQ4Aekjy+/7igm4t7rMdBkPo8RKRKSi
nYcLrzedOt3fB4/cnieZoTxwWqVfRE90QsnAoe70bhJLceLK8QoNcGrw5wn/
QKKOpbMYJMiGeml+6mQ/lc8leN+/Qg14+Hfa370yJOKXq64KBtXi1S3923fV
SVhORrUymgbgZqm7XTOdQF/M+iWp5SbUvgsMLnAm0VdbocZmjqOubilFXJyD
utC46aAfR+F+6SzNtYWLSIl0/k2BhQgNKKh7zyDhrJzc2684hKGPEeTofgIc
n7gvzZ8qIbw4ryd/joTZp8O6aWVjCOIe9JCZ5eGDolo1060PDoPrmgw5HjRN
K+ezDFug076Yl2ZAYuwiU6bVbgA9S2yZNDUSNdNVjlfEJtEd7qTQ0fUKl5r2
+kjJDiJ8yzrLdZWLX49vqhxRm0Dx53a/5AAuahJtr39fUIXPztyoZRUSTdPz
LsrhrfiZtdPu9lMCd+e2NbL8xqApefVb7wIX5+ibpw5KjOGW1+7e3OnXsNPV
Tt1VNARGU87V0HEupt5YB+2p7ILWGstdnOp37WOlyA7PUXwzNa407eVAu9vd
5pMkGzfWkxwyjQkMiV+7KFcwhqeM728tbXBA8+BmCJVUgx5sFV+1n8T8uqhS
dHET2iy8HohUEnB++qp/w68JRTQDn2IfEkk2RrP+Tc1or707PRhCoDKwcqWq
ZgI0S/ut2cJcbMk5vpj8sR9nblYwBOp4SDoj56Tc34x3V8Nvr1H5POIDffjp
I/guL2LjBtW/A1KPH4oxRuHgtj3RQY3SU490zMyjp9hqX9Cs7ED9z66MU8c5
g7idLy4Z8l8e9Bi8pcfnR9DQabLNls2DfnKwfobBM6R/ytt20ZyaV5Wmu3YC
PShVdZRMkiHg+E3gvTitHzvG4xykZ3iY9mz7JWqWjcKwSNe9JA8pNt0v+OQK
oNOfVRJ2kuLNuhB5TGMIqnkvOcR9ihdHqtVtmR1w8dBRrUqi6s1kLjjq9iLj
hvFFrfMkzvJ7n55PH4VdO7eg8ySBPY7ffMZ0X2LFavIV/RSl746CIVPpdNwt
czx67jSJD4k3z8paTyCpRVE091dK3zV6DyLQCn0Z1vPjhiTs1mOL6uva8MCE
5yTyO4ldEq32ZTv6EX1fkbn6ntJ32O41pdgeBBv+49nxlcD08YS8GIUW/ME8
RLM6RPHTS9eisSweyX1P535zJ5HHUNtl2VcDAc5RpqIUie3PXW60hI1AaKB8
u5EGD4LTW/ISll7AiHlUqFuDRGUQ66uU9wBkF3vUDSh+p1+QyT4txobrzh9N
ZnYTOLJRuG+algj1lwdENqj8r+Q7i9kVY0gOH+bN6PIQ/8Z+lY/GRvYfJowx
SSpeYSt9VLkewce2/S5H8aHHtWBD1WQSATpa4tVjHORmumv5X8nCPEM51N2N
hFE4Y1hG5g3s9wgvC5zmgD67cPkc2YQlVq1bMUlg7Qp/2l9tHbjJb6THXOGB
r+4gLaTCG9U7ioTYVLyJpY6dVlcnfu5ROzzcwMMRKwHD2IwXONlyTG+BnwSf
b/0lm9KzyNua/G4HdZ70DMn5kFCImvmUDRGqnvr0VmfbgT6YTyaa8StQ/Fo4
s/z88TAmNFZiVi7zcN13w7EiqxnrhfcOnxgmMNF6IEC8bAD7qyzVOSwCvfpy
45PfphA7um4QlUCg9rsU+ecfXiPvsY5/xIsp1HoHHujd3YMH2fymsUcIKCde
pseIDIHlr/rxix8BJR9Ltsl6J75JPrxRlUtA8965mWnVckQdu7Z8QZsE5/KD
Z+Kx9WDOfuGnHSXRotj4WEN4BEpW6DKT4iJtrUbHnOyDl5FEgL0YgUe+c5d9
l/ORVyRYJmhG1f/AQELhUT6MKtYNQfFes89aUnC5F85i8u0J8QSk3VRUfjvX
DR32m6MpLIp3mVOaO3QbsRFg7vBZkMSWubVfzEJH8WS/r8aeUoo3aQ1Zz/4Z
wMH26vvXPN8isspzeqvKOHLEUtUFDbiw3v216ElYK4qyj5X89IwAX6nonFTx
GRyOo/1hQvWf3v5T4aBnF/ZpvdH8l/I7Ps+9hWLu92AQzi+7ifL/nzev2s62
FIHPVWM+zJWEu9DchK1SHzSHq+Zql7gw4Jj4icXUQ8PWVd2c8pOhF6nBI2ld
aJPVvNedSM1D2vmxLbJZEGCdL6im/EC72WZhNasLfF5ZzW9jKD8S09cu+XoL
J5JTfqt3IXGpJ2+f7+9s6BnepGsrvcVIh//OoZ09YLRH0eeaCcQo2F0uUR+G
inxcatQCgYgnN2tUs/rhvCki1liOgOAZke/8AoehzD4x8zWbg8g4W4vQ2As4
dCFC0Jp6/yI7ZOckaxgyn3+Y2x5N4H9JWJ/0
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 8->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lXkbxk8zRGVJcxRtw5ul7CGvqcw1jBQlKqTo0CFJRLKUyVJJkoSK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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3cg1P//R4UiTWSUVSKVCAn1UCnJyGohoyHtqKyQkQoVJfFBtpCRvbL3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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx1UzKhUi+5pkKaJImManhSaRLCVJFCqDQjOVGiSMkBlMaTEY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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41Wkbx8/I3osUImQZgyxFUxOpvmgTUyFTKiLVUCEaJilEIxqhRSRb
4WhBi6VQ6cSxy3Kcc+yc8/v9RLYoIq/0/t4/nuv547nu63ru+/5+vl8tjzOO
J0QYDEYiff5/e11kWLfmvULIXZnSR0spBKT0TZRu7cC74Sixv5OF6ND5vHJ6
TwX825r3ky0ktnGO+vwjUoXhTnG1pGckzqUYBIlJNUFs9co1HZ0kWHXHT2zO
4ePeavGoJfIElCtUnCSfVUB7jvtkRJLCoP6tWZFFLYien9ZZXEki3tQ2LXHm
JYK+P13GiaGwwSfXNsSrGwhZYTdoNIDHn+zFOP/twOSAglnxZwF+GVJf31TT
iNkb3vUMksSQ1ql00WdNOMfQtSCUSbT0zlmE6bxA3E7XMgVxCi8upIv7mbSj
K/THna8MEve9TZ001Nvg/8cvO1bVkrgWOKlv+Y2Fv27vDGGbUvDr1pJblVcJ
/8JYp2YhCT+xnIRf37/H6a5vgUqiJFw29gmkm3gYSjOVEusXgO8jXnxkthVs
z0VWxjJCyM6SGRo3OThum3t5T60QlvGh0aLXHsFv+KfI63sp3LtVda3XpgDh
foeWLnWl4FQ0mt0m0QK137LjpExJmET1BTzQe4MtD5UOphhTsI/2X77k3/eo
wdsvD5oIeLz0evaFX4sOXUEyw4yEu4qtVB2vBYXWbab1LhSWrAy4vQpFcLSX
dGzfSCHG22Xxx2WtuJDhJmvRQSC8XlE2OaAL+8MjvZ4vFiL6wf1lhr/x8bRN
8Z2UHomHP31W2PWViymzazbbB4SwKbqXXpxZhQK+XfKFaRKzV9uZ2z24sG6N
V2M4CLHuVOsqv5NZKL1ls+mwHQXvyU/xJRF8WGZJ5Kl8FOJ+kNKSAiYXQ/Iu
jz9pDkBw9PVPSV/KoWy7Jzd6gkRjjgxjJp8FqbJJxlEmhbzXZaMb41iQf/dJ
LpzWE1vOMaxkmo/jOpI+O8qF8CX6FRmK7fCcrc3tPSlA449BDa1kDsrL87i6
siSCcuwPj5sXo/+tovYruv9rXrYDp+xYSEob0ZvtJbFkzMD3U1oLHixeOerR
QcK4ZMWxG5E8VPw4asVMIhBt5CsYu8lC/otUbbFyWt9/LdtdldgAhwarifkH
JLzdd9emHWrE6vx5B4eDBNyjpGW/d7zEAlyco/wpEDFWwob8FuhJ3xeVfUTC
UfuY+useHkosVkW9WkRApM4lYQs9/w0eFuZXu/rBWFtE5EkUIML8w3TPMQo2
2S2GPcImUEb5X7U5BNJDYv9z4msXPhjrR31sEsDZx9p25gYbeWX66nf3UGAP
OHiEvGIhXbgszCuEwjrFBuK5VTW69f6OsHMgkdnOjbnSU4+z7l7rZ7+RqHdU
3GdzuxkG4hGV6SMklBk9G2yPVGM5U+aUWz0JtTAR6nEFF34yP5/KKCZh/75J
Zq3/W2x+o9vDoPkti352VNeiBsqVY3E143R9qVH+q5IKzCUNfCyg3/9VDYpV
tChC38Gl8Zr0/G21HFyyj/Ags0jWzbqegN3mlLmzBe2onog8sE5nANmW/CBV
o0asDXsjFTBGIMHmZvZcSit0x55FfLlHQnN1OFuanwiD2jSD0oMU3NeHM6c7
MiE+16eu5kbzcX61q6p3JjazW7/FHqBwrFBuW0EjH1VWe926+RREme2aM3er
0J5R7ljFpfk/3RPMWNwIhqRTqGYhCa+lhWoJ/ylCU9+lEVOaz0unJ6dklNk4
mdTnMbuKgkmg6t6nw3nYcqd/+IkzhZ0+KfpWmS1o2Hpon8IfFI6bZ/Pqj9D7
MVurszeUxHVBfOCoERNUOSdSxZ6CwshEt6lMKbLPdReoplMYUNQucHPkICtV
g6+WSmJeMHqyOKsDRIWEReiUAJYpmn/WJD3HKZWUQ7xNFKLfRS9RcWNDvpsz
NV9N65cbMdfcxEWtf2Fc4RoKDye2lmfXsyD6ubP9Bs1fQDjxfNNbDpIDh28e
2CUEwzLne2C8Ojg2DoYm9Lz8porOmljXIjtG/82v5hS4Hlcv6z7uRL125Dbq
714obb0eGnOzFfu2D43OsAgY1EWb5AVWI7NwfGFugQTjsNb7OONi7NcOtdpi
SGHWnpB4KMyE2omWBXHaf14X557P5XRDV6pcybu+HyYWN/58QHBhGeao/o8u
hY2uVswd7d1oVK5T2kz7zaVzzPjJjGSsOO3d6OlI83q284SEkIngOyNDAU4U
GCRrfWomD8MV49Lrkki8ZGyKn7jUho/bH9mecSUgWuG8QS61AD0pJ8bc6X4G
u47tcGO1QDG/q67FifZL84GrmX08UGe/ZziJUjg0xjAMm+TDoHW6s5bOA+fR
WH/DNzykuL2uuvCzAI/nb9rtludCwU1pwuMSzVP7oGGiLxtPbgSH3moncdVT
kOyd1wWlFxF5+6UHwDNLdvMw42JQo65MLptCiVl99PxICfY4/66624uCkeal
dSxvPlx/FW6paSdAfQ4OjpB5BbMeR/HpRAoGvh9Cqf4ujOY80lhTSmK7pX7g
8k88LFRmKTjcIZCsV2xWHtoMpb6A8cNdFPbllrMXX6lDE++e52Ai7ddSD/V8
t3ZBQdD3dl8CgXvfz+SEXqxCorinRBmdLyzB5VvVF+Jw0V98f/gRCgKjod+3
SjcgTW9nkloPgTymSqXaCBcHzkha3/Yl4LfcyrRZqhzpLO79QQ8KzlmGFrtC
O5Eg7h98ZY0AOlM6a2x4fMguVAWcrhbg7Kzna+UaLmamf38aL0nCKiR7ffXy
RqzcF6Ma6Ufns8L74IRDPHjFXuAyrwghWCpSmRHzHKmHg8YlLtJ6UbxuP87o
RF/uEPX1G+2HDlr+Y9Mx0KngJI/Sepqa1bcZnu9CsLG59IxKL4qu/zCp+YUP
vcuufrNxAkz05n+xH6/HnUivM7eu034U8+H8rlQ2wir/mOjkk/A5djnypUc/
1o8eneb8048JeQ1ZB7k4NMWxL25zp/dr19brR+fbwt0Drj2jJPKag578fL4b
a582Zgni+6Dv09q8OpaPI8bHixvo///Lzm5bZ86BM0vh5Pg2Al6k+F+P3Dtg
Irfiz+3LCLho3tGVr2vG94cXJSpESPwPQ9a+/A==
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 9->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs8lGkfxieHpUha29u0sp2jIsnYFda1qsVKGxvCymFeyjGxnSiSQ4UU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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VH0bxseSJZJQRCs9tFmytXm6JKESQhKyFEKWCiWVKNRTERJZEokk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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41ekbxmkkRVHnNCWmpLGUUakYS7lNYZTIlpYpilPSYufSLpMlCXNC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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs81OkbZWVtTal1KYVI5VZki5aUw5SElZq1LrlWbCTXDBXrUqEkqcTY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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 10->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwdlns4Vekex3eNnEIN06TIuOyaRicpDQ3JfEPCQ3FMDTluI5SSUm6VW9oJ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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k0VP8bx22VrcUuiVBEQkUovEVpL6mQhIpCylLWdqRUhK8kSUJCytJi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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs8VPkbx6eySutSpNiMy27bWjLZlMXSh6JcSgqR2066KWkXUaQlqVRC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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns4ldkbJVSTInIrFKUYJArjNpZynakotyQ0zsQoEg3dFDIjJwkhl0gy
ky6jEocxLrkn13AO5+DIOd/3KURTpCHk9/3+2M9+9rOf5333u/Z613rVGaec
/ZaJiIik0+v/+/II0dzBXd24seRnZhBPIv/w0fDxXf3Yxsl07rs1ApFJm4zo
2Cfg5gVvqjxKweKuw/3f5PvR3uJiX5gixFo55thcWB5k9+64Pv4TBfe+MCe9
uj4syvhg9lcCe3xF/R5r8mAw7epWHUNAoHRZfWJqCHIpyR41cQRUzgVLV/7c
jourCipLq0n02W++cb66C/O1cqGsBhJfTeprQqbr4fip+u9LMRQM67MVHjZX
wkLlhY29JQVHzxexS+wurPCrcHW/TOFlo/wwk9mBhREt/up8Amqybcr73rJx
wo3ffYNJIOS3ir82DfThuefnilaOED2WCsEza7qQ3/iz/LgniegsO0HVfCos
xoLDdjAozMbHFTMcilEo/i6iyJNCnuwai/cfqpFgfXmLJ5eE3u/fDvi0dsHS
f0WTrCUJB2tFu+ohHjZke7oZXRdAkHussuxMIxSDbE9u9KZgZaajKzndCeZZ
g5CMUQKxmfGcL00csBOZgo+dAthY/iIjmVIJKTtb7TBQWJQ8wihX5WCTphrj
dxYFM73MM8bjbCzorN3YwSdg9U5fn+nKQu6vw/5PvCjUBm7dJ94eDfbqiKo8
Op+oIOBbjpCHxFs8ya7PBPLmVzFY/RmwfXpWYEDXw3bYHXNXpArBvSUNe/Up
BJTpm3gnt+JjYmJ//24KUlYLtlkferFNMNhTl0BgwkRHXn2pE8kH7llqhZBw
4ewsEhsfgtrVFcamFSTS+Cannc9yMeja/zwnYwRnJJcX/+kzCGbatUTftGFc
id/Q7+rbh4StSzV7Zggwx5qjOHaN8FC5XWuZTUJS7rsLLJkedG9mXkr1p3Bu
JvTtZ/Vm7LMRM86i41ta27I0lbiY+F3x+uR7Iaz6q94YTt+EXu4fOtdpfuaH
pYvnSDZAYNB2LDuQgmZrJHuf0RAumZ825PkTSAgLXj11/CXa0gTy69eSMCsM
tk8Z7kdn5lzsLoqE1eI1H9PzbHTKF5b9qELCzk716C2/AbBrus19Aul8eZlE
Bkqw/PD2l3kuFOrSuxQcl3qxR866mLGKQvuWBWK3XDN0cpKcmDYUCI08exi3
4lDDzhkTDZqvogFjTnbNuFVwcO/NtwSOubAOLQS1QO3z3FelGBI5lqHSS39z
kK6922B7Cwmlqq1/P6+tR+ljzddJdH0HDkjen3TuhVFhwHrNAQqZkVI6T7e0
guni9Sr4CgmV2fUvJ+TbMHtxesh2isRLF+tXZTID6MtSKmmzo/kSYvxbc3op
lBSdLeP2UfhyeGL/pthuWM5oiz0MIzB7uUUkMZGLNYS5fQTdLxuHi06x7/TA
1Flxu+ckiVpP1ZOyE7HQKBitDPShwNJ+Vhti1Yfi+3Puu64Lkbww8UrXvgxZ
GSHtkb4U0sh3UuUe9chQ8qxYJUKhQCdRYyOtDwpbLi+8aRUiyFI7fUNeNz5l
cptkz5OIqjb4NKbCxuZCUT1POn6uRNHQkakGBAdK32yn+Wa5h+GSl9SDiEaV
liYtErr7g5uSvXogyHQN17EgsDYllmwq7YL2dO1HPoPEAu+RP0eqBTkTB2uW
EkhwvBYMI/SaodbqVKEeRkEwwucwU8tRPiSvO+RMIcXl+6s/iw0iKvqvbUkC
AnK7bnyMXXiFZbNfrbvUaP0we+yXPJIPKikq6qA5Bd7+l082FjQhl5o6euUR
iQuDFRV1qRx0r9s+8+VbEhr5hQfcN7fCZJOVWMccgc5w04J/2X3YuSbE2tBe
iPF/Rk92FhWCH/BY+rAbBcpSqMjw7kHkZH1s0JwQ3UP7SFYSF+5NmsuijQSI
vuV7u/ztHfyxwzTS+ACFk2LzXw0Ps6HXELE1lH4P82rewOqT/WhWk/Vy1R9G
1+lvxHOsWBgNUhALP0JBzVdk3EExDf6DD8Ma6XOI9DXHyNcP8E9OaNZFWwrI
rwuai+FD+5lqV6oRrdfy3ywtmhWg5d47n8sBFEy8T+9xpPX24fHwDGVNAosj
3X61cT2wmeFNbfiBxEoThd0PxLm4cmGovyOJgrivy4PJrU/QUVhixneioBG3
5J1U1o3lBTmjLnEk/v0j+kE82YHuE/ISkj4k+AtPr91s4+HM2fnRc8YCcDb8
tznVvAW1Mcb9C7+SYGpX6v0k3oN/q9hxOxdpPj53+fEkiwvFtr3pfHcaH0ao
cmhtHwyJAY7qGiE8Il1HCve/QuqB/NGMXiGiPaW5CQ05aHfRWnmM9isPR+9A
UwkOPngSoWszhKhNeTx/VaUYjFW8FxxTCowt4wEp3r3YLiQc/qL9rHZ1iTmL
KAXB0Jds/UQi2U35rtp31YgO9HVq0qPxPZhoGCY5DAld1+HwTD7SvozkZsvU
4kYIX7UtiEJwGFM142oXFvK+Foz9R//fa/K7qEA+3FPmVEP9aDyNN14w5g9A
e4qKdT42jE6JsYLUN+2QKnsxse4HCkWHjhvtFBSjhxe+xkeLQvM1XUFAQB0+
cr6fClSm77VL5/2iKtElEflpGY13k2jjm50DjXBQ/+x9c5jWu6CUO9vch2CY
6hQaEy0AV36YGyLRgz87JqxlRCkkRHhNVtTVw8zv+EpNJQrv1we5qXe/gP/t
N/PuLBIB51lTs1fu4k/Cj3uKjr/MS/rQKf9BjArWrq6hBChLVc4UjPXgfn9B
9rk6EuL37i/8EvEa46dXPbokP4j4B86RVlODCOh8az8cSeDDzQrt0ntPsHg7
q9iV9h+rJLVqDfssnOAMK0zT/CxnrXMXOV8F0VxetRzdX7PrvhhprayCMoO7
60cmBa1n4TNKJxqwt+D9u3ha77ZJvzNPFu2BRwZPZewpAaWcDIvIonYk6nY+
Z9N8tLjwi0rlM3o+4P4QtuMIAY/ASZ8uQ3o+KV9xp+QfIXZojMlePVGPmmxl
ubmLtB+GmybU36mDg/PkxWAeiWOOhx/lEq1w2pORIzQmwZMit28e5sOmV9kj
8ykf+qp1XwpsS6AiE1jiRuP3P5l3wkw=
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 11->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8Vekfx/nVWCLKXqloMOqqrsjUUJ8oJgwZezMqSwklKVS0aKxFRVFI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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3cgle0bPoo0KNRX9KUolBESUqpLJELKKNqiz0yRlJXISihERiWprJCZ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41dkfxyUVmiQko5iuilJmCDfF/N4qGVvTWEYmhUxJClmKpEhlC1kK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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs4lVkbxrdESChla5CRKHTQIFKXG8mIlBxSkpEkqhFNySmRHCJGUYQk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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 12->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lWkbN+1SkaRkIkb1USRENfhRJ9SYxjRUM9nKUupYs2dL0glZMh0y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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3lYTe3bhuv1o0iJBkUqzYQIJcWVkNCEKDQpKklSGYqSJuVNoyFNKjTJ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk4lXkfxu3RgjkjLaNNGTKKGmSbbiJLYaRCKLKHlBLGy2QruxYuIyEk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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk41Vkfv0KUJSWRStYaLZQtTfhYSllDM2OJIVmKurb2URRetDB6K5eM
LGXp0jbXDAnXLlmui2u5XPfe38/WRqaSaXt/7x/nOc95nvOcc77fz3a0AiM8
ghfRaLRb1Pj/fIOz2tJfWI9zqtEx8x4kPr3As6K5Eni3aFsrOJPo1PjelVY0
gGHNQK+21QQ0I3a21nHzYfyPXf9dLxIddOsGl5h+lJSnvvhvoRhTEvdlTpxp
hFhnl0ztOIGi4AoltdJRxCY7fI3YTKIwKslttREXuT9rHksPIaB0fkORUUU1
gmT8FBWtqPubVc12LFRif6CUS/V2ElyXPIWQjh7EyNT9Z1ZFhCBZYZ/Bqlbc
avx4+msmCabb/LShGxdW/UOGJRYi/PvTQnysoBH53ZzbgWEkMJat/Xaaj+/n
aoZeFwqR49d2+mtKI57cgyxDi8SIBls6P7MFm66PWplZELjuc/Rx9swwaK+c
26ZeCvCDfavF3PohFPfKyj1OEiGdXmh61awLvlmpnj1HSAQkrjx7p46F0MGd
ucelSShmlY8sN+Iht+jHkw8WiSG0TSyMRhncy196/BJEQmqybHiA0QtFBaOq
lEACZ+aEd6JcqzBnMxDLzCKhtF3+KePdMHy3H9OdvSfGI72pVL3tXBw6L+X+
oV8EoZZkkeHVIbB1q55PxgpxJjOOt/prG3yaVdUEiiRWesmem/PmQNHHbK+W
MYGpv1yc4o5XQ7bi4RCZTiKoMKR4chcXCnFLzP2dCfhMPCq8tWEYpxNzV5hk
irD05U+fo642YMNv49rarSTMPinksyYGMe/2lkk6CKG7RnlddjwfDoEr2sf+
HYOm5K4RY5dOuLXvK9QvEWOfpt4y56AuOBtqBi/OIEDwjfUDYhrwpEDWOGma
hLW4v/SV6iAmR9U9pUbE0L1Xtl5swIFOrr3g1BExlMK1EtM7H4C9pdwxNphE
2B1vWRVfHhKup8VJzVH1L+bp9NL44OpdsZ+gk8gTRLu/UT8Hnm3tdml/Epqi
yRKjRcU4ZshwT3ah+MGfVago5CPVfdfTA40EbG8XD/x4kIsg3oFNl6PEaHJg
OecYtcPs/VDYB6pfrIsGqZrJdyElOvdZy49EQfKrPJdbgxB8FehozAsRoCpY
lstORW/1Hv0rv5J4K3o1G3e5BY7n5XtcnhKofKzLVvd4Ar/hqHL2NhKPypt1
GAqtkGQJlhx6QcDq+FtSpXsI9JQftJ1DRZB+p9ut/mYIYZnfy/x0Reje3e62
YVsbvrdtPPZqisBKqcOyRvFsdKUVfxvdT+IZf9IkdVUdFrYwKrttSGzp4oRv
dXyE8q4XLxiuJBIbPivPGNfD3rxl8WWQKHGO3HlhIA197f3FI1Q90T6pFqqb
ujAtXlfP2EJgbfpN2eU5VaCb3RtmviZA22sYPf2yBKduGnS8tyaRkmUcaxhU
B1nihn+qOonqqncVcxrDIDlKj1n6JFqOEgql2X1QMrhmb71GjPhf3atD5NOh
mjxt5uRLgm5w+4t8fy8eGpWVlCQIYRG2kLKIzUVa4GuvETMRJOVOlL88OYj2
vbVxpWvHsTRRz27yQRuaeEzWTi/qPcILx2v2l0PP2CplF3XeLybV3AlXPt4X
XIypoY/i5qXECR/lQTRE6FWqiQkcKTfV8rAaxGZvj6UyoyJ42PQFyyd24N4n
wz+6/hXDMnPdQobMAKy6K5r3qAlhnfQxtSSjCVNtEeoSe0gI7Q748tPqkLs+
xH/7LyTkpenT3/16oP+aM3NeRozdacrStl48jFiWSpS2i2Ht5y4Z43IDl23F
UUMU/54dLlVYFMvD3BpWRi2lz8j7k5o2Eh2Iv4g553Ex2J0O6d/0egCax8wo
xT+G+UX4pjXDV8W1oOsTAcFWp85/knhocNyiTUsQwUv8m7nKoypEx/i2RMwS
sE+WClko7YFRcsJQ20YCeRYq9/lqiVCfGv+wkeJjvNxpQS2q4CJVYR62i4St
sH7OgsnDNq+0iLzNIkjEl8t8C+TgWLZ7cO/fJGKSElZ32Q0gr8yLE0n58ax+
Y159TR7CC1SKKg+R+GIsiKMv56J9yf4opgOBn6PzqzOLuNg4LNUdlUiglPmR
+2yOg4/BGmnSdgSW1Fk+ZC57DPPzcka3E0lE7TFP9FLqg9nRbZ6tAWI0GO4c
8Yx9jqcqW/+yfEeAPcO4uSL9BjSakiwcKHxpoRb1LJtTuLTZ9OgIVU9KzqkP
O5xaYPMtVNX6ZwKvd95iNUrWIOTxWJBqOAk15TFHnT95uG+SUPHgMIVHcshz
VfUWJO0okzykS/XjLt+87PdiRJbNHKzypPZf8QkRVwzDZV+lrWa+EOw2zkyb
dw98x2OF7YUkBu+YnrxqWINLMkaf12hTfiyFM80mnaCdnhh4I00g6qzmMMus
BwaXft/EjCQgbyyt+eUYB5drMxua71Nr5eV3De92w3Vscj6gUwTb9/OfjXuf
Uz5r4mlP5dsm0T/7jrc3I3Jwb7h+MJWnWQc6Zyz6MN7Zpc5dSiB+s084stOx
9MAfPdlUvnKcSpxHXJ7Aa5S43r+DBCPOYEVO/ROsSre7utGShG5vldWrq03w
sdG9fKuTgNBb4uFzmzZUpWp6OSkQKPPMF9td6kWuzMAgm/LbI0r5sfsKmsEK
5D04S+XfpTKnjbN1ddgmlDV1iqD0yqON0e35sND3fqBbReHzYvdErf8dDK7X
8B73pvw73zSzcm0C3DrKAkwpfAbZcvVrj7aAv9dwyaH3BN76j9Ct/Htx8kr6
bptZMWisJtnJL57Q+uvaQWtKHydG3TL1LTtwuHeO77iW8m/GmdC+5lZYXGQS
wTEExDTrAA0TPrb6h1aMZYigJtEn3h/7N0796bjVdSulx8hVljnSXVCPT/C6
co16X9gaekdzC+YFSw3k1UhMVXov/JjdAAtth+iEFAJ0mQG54549CJR7xkiN
FCNasNL17WkOChZlZK1uovJiXI5+piYDVmcV3/QdpPylfkSn528+rlmPdcj/
KsSFUDpft7UPygr+deHDIuzLWR66flsrsphRE3FGBPRO7CY3/NmPzTLMzsw5
6v/jcf+rT1ke1q2IjPyN0s//AAiAo+w=
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 13->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk81PkflqRDlkibxraS7eIntFlH9SjtlpxdsrGRo1wxKqWWFHJEUtGo
UDEm66jJlUWOIcyMzBgzGmlyvL7DJt2XNPT79Mf39X19Xp/j/Xye53k/nyU+
YTv8lZWUlK6Q7/u/XuexldEWCdal23vMdJLjP8WzFv/wJpRK1lg4HqXw5lVY
PLu9CoYSfmVrAIXFM2d9rnkgxKN3sq5SNgUl9rby+qIo0PYE+633oiDk2X50
ihHD7N7rn5wXyeEZeGdz3tFaJDFSKhUhFNhfpNUb/TsQ+cxf2nuLQnGjkx4v
TIj/9Dc1qHEoWIZeseOzmpD/6s2GqSPk/Bkmi9XZHHAr7WqNYsj+1MN7h8zL
UHbNlnvHn0J2vtoFgWEf2r7aiEcOylG3fiAkOYKHIVaDtD2FQuMRx6Zki3K8
51j/u5OsP11wo9l15XmkVq6I9iV4I0fjufoTIrx4TffjtFG4N/DKdFasAEeb
S8RDfApVyyM6M627wFzh+6cBwbcwJmbrpSEODk7yzSyiKKQfqbK8/q4Z93OM
DXfHUQgRZeiLfXvhoOcY2G8jx4pjP5U8SObirvpSVd5FCtIUPQvtaB7Es4c/
pJL7V5cVlr/yqIHZ3Eqz+8EUHGU6wulFYpxi9ducfEsh43lS9At7Nk7snki/
6EuhJMHs0w+9bSiJaKBdjyf7+RsDLmR0wmC6k5IgkwKdtc/xkPdNRP+W+3Kf
NwVzoSxc9UwbDN/bHow7RcEzMmEnJWhCtk+aFf0YBT2DYSvtiTz0PN7ewibr
HW9+C8xeI0T0a97ev8opJBVc3y5aJ8BPF5/kuhK9XaMepGzM7kbfZPAR8SSF
hp0GeuKbEmzn7+o22yMH3f5ZEsujG6FFmyyYM+QIbzxbtUNDBsFJu20bC+X4
QfnyUqeKxwgpKdjTO1+OQm+nPvWua1hXqaH2lehxc+Ltr2s0y2G/VWcik+g1
f2H7UPdKAbRu3KdPa6Awuu3S68b1YlzI/bjz8wiFv5RU1prxJChc+yn7mrIc
tfPq9XXS63BWssrZJ4iCQuird1tLiEsujCDHBxRYWf5M1u4u7PHMPuPaQsF2
htfpTI9OnLPMj626RmGDLHVVrhsfE1rb/iy6Svhtf3dY5+cOOEgzB67lkPMC
fOvP9Umx1WXawNfLcnAGNcreNXGx4J5fjVUS4cvhbYXN2nKwucKI2QS/UtKx
Iqf9EnB6mxPrXlLIihpjsI+I8HGam7FbJ5lPmDbwbe1d7DpeyzIm+sarOisF
ZfdAhw66+nQ5DA9ppakxODgV6knLjSD8hDb/pgguwooTLir0/aSeZMY+6gkX
HL761rnE71PPAl8ajUtwzCjcmveGwieZ221FQgUqH52QaR8g9fb69ldaX8fm
xSs7FITvzS8K1GN7e8EPiR0U7ZNjV/2Ag4luOya2HMgB6benruoPOppbEWAj
FRoQvyns6hjJEUJImYpdg3lk/pekrwbmXDyXhrHepBN/PF6nEXm7B08DP1jm
fCP1eLnWllcSELF5pvLO7/oeUmT0t59Habbb3yHf80LZhpZYHQ/9oB44krFo
Mv+dV+UDsObTjPihZL9t8FuGezkuzFNrnU/4PPB12YjZKxFWP3Lrmikg47bW
YP9BIXhhfjS2lELhsiXuuU5tcFANUswi+E96Jrr+NdyLRTtW26bGy1FS7v3p
8qIKLAscEceS85jcw5rBqU9Q4/vw48ByOaKsO1cXp7ZiwZxG29mnKYx5hmge
fC3EPqPTLoHtFNxNPix/5yyCCk/r458kH7wPKV9NbfkHoyfnas/xIf3mv8Rg
029iOMs1RosnKNRZDT1PMeBAZ2ww2CaS5MVlXf7kOBtHR4eGW4je9SMD3nPL
HiOUpq1ipiWHZek0mv5tkh9hKvLSdDkCekYSf/bqxtFV90aOD5P8khj4daqU
4/7cOvYNgr9wf3V1wb+1qLurVmNBpzD+fovpmYReKH+56VDsJ0fj88sDWcZt
cA1WdKkQfTw18o2drpXByFBCxZH9Tyy93CKiOqDqFZc2xSL+VM6tC7ORIvaP
4qTfHUl+fWBsTSq7hSBT0/hEkg9vROev669vhLF9iuwEqae/1Twuw+IWbs9q
cAon856NudrzqvvgXHtizPWsHAt7I95ITB6i8MB5pZyThI/tisT92RwEBEco
x5L8yaV9tLKbEuPxghjnH0n+Tq6b7YgOEfqzPucpfaYwUBCvcep4FmoGWW1t
xB/mIvPAljQmJgw5Lh9IvUiDOTMDQmqgq9fKpweS/okrvd3o+wj9InbJ+XMU
es6Wpi743Ip0A4ZLWhrJ78MvdpU+6cKppQX0qx0k/woW+tm1cPF71anANWSe
6xVrn5fWg+FwDffdo8SffiW2iRsuwmFTjMYZUp/eN89DR16Kha8Xixf5fu+f
qsTO7jKMtc6XeRA+03+sPBgTx4Sz+Owwn+Bb7XPmeKFaE8w/j+vQDlMw5Zw/
5rGmBm8PBKeISD4lxYa7KwqbYeYww2Ul8VvJU2OtrO1c6BkVyOkMwo904pbR
Bi40i6zCx8m4ui9waUZ1PXwTTTePEv53mb3sNNrYCdVnm4IKC4g/rB2c5svO
Qbygaqc3wWvqEWv7BzMPd+x/cWARPMJV951W9BYgWZdjokLyoyjmfwUVX/io
6ghNuELOT+/onNBMFuIuZf+N10PuO5yuwmZy8UdXjtKTC6T/1bUWNbwXQ/AP
Y/JXkrcVcznZsrF29JhFbUlNJvgZe0eajvBge7d7qj6D8F+nw7BJFKBGe7LH
uJjCrJM5JTaaItwdn5rhISPvpa7Upf1hFZI1xJfYRL/0LNfZzzLFkAW6ynQb
KRx1U/3g4MiH7rkv07rJ+9mxpnJedrUU9lXei/pA/MksblKN5OIYzc7nOak/
x6Wztm5SAtculWbaXjk2P33/9O8xAeTr+4v1Sf8y3SHQd38En8HpKx5eobBk
eb7FaH4/RjVMLKxMh1Ftcsfi0gYpxtsuRj+kyWGaOaVkd12ACC115komBU3N
6MxW42pcXRaWd4Hod/D3yMPhXd3Ye8auO4rk+5wWWq62QoDSFxGM/yoo/B92
oMld
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3cglf0bxkWppIkivaEk2aMyUpe8vUJFVkNWsiIZSdKShCKjiBBSSUj2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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnlYjekfxjspkaaEksRgSJqhaRGGcSsqSqRS0jKlhBapaRNxtGgRkiSl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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk81Okfn2RTUmG1FuWolKtdWkIjb6KiVVLa3IayzlBUzlb9bEQnSUKO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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 14->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk81ekX5jaKoUVGdWdiRGWkLGUvHqlkJEpCo2ZKliiXMEWllIgryTJR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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VO8bxilFkpREFAlFZSmRpO4UklCREL6IKCSioiQ7ZSlCJUrSYivJ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk41dkfx+/PlGVsydYikdwhJSEt4t0yFRkjS5IaJGsyys+aGpJMlgpF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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwdlns81Gkbxse0SdhOzmeiRGLtLjm8uqKpHEqSU4vNOpQcN9kMS1GtFNm2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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 15->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lekbllQS0lCZn5Q9SiayptwkThMzjBpFxlZKCEVIKtnaVFO2GY4w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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8le8bx2WlUtFQKEpmUyVEfFIUQpI2QsoopULZEqFvKCOSVQoZ2WRv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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk4Vekfl0YKN6RlJJORJcrU+GWKxnySpUihVBjLUCQRYqxDISlJE9eS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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk8lWkbRpYsH1KiRcOgRGiSLF+5SFQyYgghy8kSaTJaRciak21EUhp1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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 16->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4VXkXPrlM5klRDdVU4jGh6SQzKSp65Tq+ITJIYkwql9yVyJ2SM5TJ
pYNQhtQZdEaEQzXkcpxcD8flkEuZvcvkGvOJCt/v+2M/+9nPb6/1W+t93/Uu
FVc/m3MSDAaDTZ7/v9e5GlYLvqzHhpIfpHMiKXg6rgn3jehALP1WeLiewiDL
Im1/oRApKvpqYb+R86TGzdHHRQjgdWdyFyiItVWTGfrPwWQrapsHUnhcrhls
PNEHzFzMYlnTeHJdvPfQ20Zk+0lqul6j8KpLXzyglYHWkSXDJhcKMk/KLGtH
anBWNusP2/MUFnzOvmOf7kSqvc6udc0Ubk4s7VfPaEbqpSwH3h8UqJitOYNy
vbA5bPbDDXUasgblLKlSEYaXuyoC+ij8PBgv6PmnFx8zt0gWWNLQ0N8SdaKL
hxC/XSmHPCl8lZfvp7vQirzCNKWMRxRmIl9vmn2UDJ6cjXwMqQc+x+WOnBbh
5dP2Qo40jSWBcmBOxhB0Gor5shpv8IvibsPFzS1gBffMfiikwLrRtD0quxre
j9OZEb4UBHFmq87e7saLwQmTPiUamzdt/WdRXIG+VRIP73lQYAxkRFut64W+
7Aavb8UUvh4wrHFK6MaDqCu2x3ooGP94vrZ+UYyNx65JR4fQuJmoF+5pVgWP
n4pNDhN8hOIlGTfzZmw7kNR49A6FhOmYlfLUTnzkuspLCymkXeA9Lid8juor
ewwEU7A1YMvWKHThyJr2L5OHKKS7s7Ji0jrxKHJpzJ38z+A82zakI0L4PWZ6
yBsK8t8Ez+9tDcRnQfHaAwSPe8fepaWk1ELy6MXuDMKvccQDxv3BAozRxYMR
pylo1FVtnDNuw39O7FErv0vyHb9Zo+Z8FcoBJycsSPydR/w9s/YvEbnd+Ne3
l2m0tksJeMf7kcAUXTp8hsZEqRHzz3dCtJ+7eCqnlEL0s680VUMzsU5dQvI9
if+85w+h65X7sBnxOBhP7svl31nd8LoWIwyTr71DKDzz48pGpw4gcSH7hkw+
DY5DtOhDYg16TybuLPeh4Jiuop2U34srH7W7kw1pHLPW3P1MXYw5XeUQf38a
vyu6JQwbdWHIWCg7S/Rmf+ZBou/uDNzONDfuJ/dHM4PcNo1m42yBo2DDLxQm
3q582C07AKnh7D8jiL5aE/cEG7K4CPeYsltyJf/Lzu//vTkDIfdjsgdIvLyj
OEzf/CbyOqy2hpJvj+r0MHtOL5yaQydv6NKIDjq6rV2ej4GO718H3aDADL3k
prvSD62FC+yoTBqW+7SD6v37EKdwZ1WUPQ1/5xMqd5kC1Og5WbDJPFmfyHd9
M58P48HWulpS3+Mvg+2n34kx7GVe8PA7kj98Qu5oSjg41v2F+uR+sdnP5sKM
Cjzp19xs5U7BYfnyvTY+HxMBHfm6LArt9Q0TJ036YNmif8Zfk4a8g0R52CIX
gcv1yqNnyPxKVsyJ7Zux6rf4oZAUCpFr7NaOSolxeMvnoJvvSf9pTj1rTzWB
0/JjGYvUtyaSnfftSBUeFJ1Zf8SbQkNhnEKJO9G337hVshsNp9xiGzvtNsgE
Lr5OfUqBE9eifOJJNQoMgniT5yhcd+3a/oLfhgIrvUvbSigoJ6WXTf7dis+x
6RwPkv/ixr5FzrUuBLn7uGiMEHwj6/PaHTmYyzqZWkr0ojWcHs85WQ6pg96z
mm6k/t98dBZXCrE0JalmRPj6cH5uemSsBQZ7dTS5eRRmvRgM7Sc9CBm8Pn9o
hugtX6rO6Jsa+Fdnqn70I/GVxRH7vstBnaJ7+l6Ct+nndkWZ5QG4Gl3xnD9L
Q0J3Y1O8bj+aFBQdtW7TKOVJVTce7cYYt/uY5n8p+B/eP8h1jkHdx6IkY8LH
ZMLstceJ1ZCYVnokIPO9P9LU5ZexdnzSHVfm8oi/9CqWjZj0Y1mj+uivtjQW
0hq2Wq/lQea0jEkM4W9MY+knx7pK3JCYerpI4hlDqrrgVSC8zjR0DfG7Ofn6
Fkt0g7FVIdVyhcxrjlLz13JFmJtRfv6J9H8xSaumrKMZw76J9R1ZxG83/Q3d
nlvoXZ8uek7qK93p7FWyrw9/nVBymPlEocSeFcsrE8KcPdCmVkPq4w71r3bm
w8bus2Hlr8RvLoyNqe1rwlgc8a40gn969Q7DXSVYUOOU9hD9RL8b5UxpD4Jn
Kvv+vD4N66xPug9H+uDUJ7Q7IEPjUMAOu/dbhNieWXG+spyCyhut0jtLzzEf
GJbrcJHgV7bPotirDqahUxZxYRQOPh1P+vtJP5a0ysaiAmhM7d28+sCzPnjb
xDFTSL5cCdF1b9N8RHp8N8MmfGlXvKgq/NQLpn1Al58GDWNDRR0rKxHMVQ+y
v5imkC3ldcgKXfDuTA7vWiJ42WWz60xewPr7lOD76RR43cvmjT4v8SpX2lYd
NBifblVlMljgN77ScyB4CdpMjrhHVuCWvunlRMJPtKKXtFdDLI5wH/qbkvMU
p8bp+DoeevOz2O/IPjCsVa47sLMbV8vcJksZhN9ij6nLO/rBLSo0t2TTCBOZ
57dEtWDCyCw07x6FLLy+qqtUhYkrsZMTZJ5mpOUSdo7WoFa+LHrvJaIHZmRa
QW0dCvpPBcwTfzT9XjY3iuqEj4GvK6eV+MX9DRUXTPLha+45GU/w+PeLRZvK
8QY8HW3KfBRLQfbfD6paC7XI1pUcTfWnkCeKcI53r4KiXoiQRfQkocMXuJwf
Auvc2uoiHvGHlXR6+84c7LIIOa1B8sn0rUsqN3sOJXXqtCrZF7ad/6hczW6D
7ZENEy7PiN42ZSbLN/CRMvPXVss4Cnpz46cyGG3g8CvbA28TfzCbdnUWdIL9
QnPc4DnZN9ta7wrzmzC4wItdSSDzzfJ2LH8lBsTSZe3aNIpdftxsUfICvPHr
3K4MChZ9Ch2etztQWL4od7CagsJGybZKjhCiLatkwrnEr0b4y8HhLyGRd6WX
/5qGxTlmqktjAwple4bXkP43xk21XttRjfW3F3xVSL8P73leM/q2GoLmUsUK
sk9M1Q2s9guEWHHbaWVdRuq7q5Ej6hxAbtHDVbt+pvE0mdcTf6wbzC+0i/Q+
UvgfNmrIWQ==
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c81e8bxslICwkNUcqIFEKp5JJKycjXyiwlo4hCQpJVUSpJdoXKLDuh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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81GkbxmfFG7KrVErJik0H3pLIFnUpskjlkLIlIedCWxMKUViHnCqH
iqSySIQcay3GMecZ4zBDNOb3mEJrhaT05v3tH8/n+Tx/3fd139/retY7+Vi5
iDEYjGT6/HvXhD++ap0WiqTffmx9Z0/gUL9E8Z4lH4cW6mqlqkZwyT21UUJh
AFKy4/e0TAUoV+6Y6eQOYrXuF5u4NQK0iQcs2/68G77BRzxWnh5BnndErn0D
B3M+M/tm1ojgnnb/dHtCJ/50vFI0OEWhsPn1BfNP1UgwtNK6fYnAqW6o/tt5
PkSTbuFsVRHuCsKVMyu6wb6kJ1LdQIGX8ca9PbIcsaP+fV6/EKyXPNQ6HVKP
sZy7Xjb/UGBImfa6jLbj+67D+nLzBPvHZj525XZhs0BuT/JGul6o1bDsGz7C
O555W/YMQ3+T2Lu1bVxoz+72VPqOQDKo6aN9ah4Kxmc4zJMEaTZPVniosuGY
yV+qdYcgQaYqz3u8EGH+lyUdjxAcPi7OcHneAIdQTaWyEwQaB8dGr57jgR06
pz++n6CW0pn0nufB0HQx57MjPc8TLjyZtj602P5HJyRChCqdX6IeB/Agkd5X
Pj4rxBez3p68HB7mj3g98d0ngoFzFX9LeyNGthzXb6XnwzRb9ZTZwcUxXUuV
eG+CydtlGy72NaMuJm69WCkFX/eOapfaOmgImOumCYH8HjnR9GAPynaW8pQC
KLhznJ/ZUwUQE/TlZlsRuE6LW3AUODDdsPrkpVlan5jbuhHxLLyeVVdhnCX4
5FzJWunBw98NUbtWc4WYir2j4KTbgUO/qItbhFCon7x+P7y9BoUzEctHbhLY
71uu9t+dHVj25z79Dx0U5B8EffUQdOJlh+/ilj8o9EePlbkb9iP5XkStYwvB
JuUmKo5wUCe9bYVKIYXkAzvXaQzxkX22IOLkUbpfK/Gem+FNaGOvqpIypfWo
CaK687thvnXecNEVIaJLJS+G3ewBUynJ1thGiLz5LPXd4T34fsn4XV/TEZg8
uWFYv6UaHvaeo2ddCUwOrDnEWfccldwknlkIwfXVFT91Lx/A2tY8Q08Jgl4X
JdaCPBe7nrq7qodT2Js+L5hoaoMhq1L+LZeCsd7DDJ/uQQijFxRlTwih6VXy
iPvjQ8y+GlabPUXwrVXi/PiefEy+C3l6QpGAJ6PKPm7SBoaGsbLkBAWnYzN+
WWq9qPv6g7SK2wj0LfuLL2hVYpb7/u9rewkia04+KTXuwt7t8mp+bArRjemq
dWd4eMW+NuWZPowMu88uZSMZiNVUCpaieUpUK0zun+hD51nXY5LlBAbeEgXx
iVHoL3RKNzlN4BMZF3i0YxDrOMo5j/8agmjctX+gl4UXwYYn+yX+5Xk88tLX
BJivb8i5bEcwd7dWIZcxAOMxT73ZYyKkmASlRFM9MN/crDumSfMZIl8xYtSI
Nu37zRllFOTiwjYwtVtg1P4h2jyDwq2pm1MkswiJmn2PbocR1LCL5qMLG2Ah
26aj2kbhcNa1uN+HuXgZ40V9U6SQETSXkfRDNarWx6iyaP2Bt5wVPSqbYPdF
L5J/huDqNgu5cjU28vQ+TUQ1ESTtsd9RYcOCoXbQjYcxNH8szkHr/VxkfJnZ
ek52BNTj4ERDzxpEV1Z/+HsRAWlY1Z8U0YvEvfdPuXoQvHsjJlKsq8TuFC+Z
1O/p/fi9m63I5cCgbvdmHUcKd3h60+zDXAiyXyaoJFC4p91o2ijGRc2QdvhH
XSEmm1V0Szd24PMQ0/OMIYG7UcaqBU4HsmXUa6Pp/HFQLiDXN1+BwVKvtzfo
/LzsR309Ud0N23X1/t50PeVj6cs3LSoCf3SHgYQ5AffW6o23/9eKFiOKUZlE
QVC0L+HTljY4X2GslmcSGE0GnBnNbYd/WidjehnN7+nXDsKEfKgo5593cqbz
5I2UXlRcM4b2xOSuoPlULpQK23CgErUp26P6c2k/yv40mW3Fh1q8WEmFmRDS
b1Ld127kwf0zORrrJoSipf7IO9V+1F+3+S1Sj8CuJP5Zemcrwqv0zfguBOfj
UwMf5uRg6KKj6h/GBBaqe/qC82sgmXDoV2d5uj/rMdMtdL5JpelKjirQ+sUv
BL5IL8e5CU5zJ52P9+y+PopUbwFPyH/f1UUw7PZe5U50L8KD1dRsecMIsbka
WqLtC5kHX88scyAIUlcvP57QjReCKXnpGyPonnNjvbpfhXbRiv5GQoFEjLOY
O7pRW3qOt1BMQaz+speqBgccAWO2keZvasigZyK1C1ZP/LcvfUbAiH0kEGX5
o+u6z7dVtB9Cbnr89CGnCna8/VIqNA+aPUd1y6270BpmuTWqnsB2c4Tbl84G
lF3OZ+6IIBDoqCzWDGdDa0nT1l2eBHIHs7p3FnEQNXHhfmM8gVCrILRoUx+e
7ow3d7MQIuHEtr+uVNTiS0632OUBChqmNpsyxbpQxQ8+uDiFILNR9G24lA+D
ZIeXrGkBLEriBYnIRNn/bJuP0PptQy3dHt1hoVB59qNwhkIIZ2NsTbUfxOa0
+YTuX3NFZ6Brzks0mG6XLO4lyFHgrVT24+HDyiaTtAaah4WhiBRmLSaPrFVk
rydQ3K9idqyxH/uDtEYLvhHMtPx+uHeABf3A40oetD9rv2MOh73vQ8KpW0eg
SxDjUpn+9FkTrrtaHf9Bm/YLFVcn83sW5EsDVjTR/2HNc4eYNuMqlMYLX/lU
Eeg+S1P9LMmFZEOjr/Iu2g8OzNoF+xz0+usqTNP5RMQCeSY/18Bqm5H0wnsK
R41sGh/IsqGwRe7oHZrvTL+U4JK1PBischIteUTnl0YA9YHqgPmGpQFrTo3g
oNYQihN68Vb6iXTx3WE4zP26/I9X0ZgZtGBtpefFMB4JeiyshMPbsxauB2h/
qQ3E9PIGIWNnfs27X4B7hcEmxadfo6LTp8SpjyDjt+WKzEWxyPux7O1DW/ot
UJDMNnuAjBaWtRTtJ8Y/Bclu4cXwSFTNqaT/h5jx9I462xq0MIfPei0lkHn4
wi257hW6UrUGpUppf2QLqDL1TOwNspa97U4QpsNxE8YM4JL4c6ed+fQ+2D9n
24134qKaj7X5aQr/B13w0Yk=
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lekbxqVRKhJNUcqW7C0USeUiJSMiMpZIqSmF1AxZ0pTQVLKVRLaK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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 17->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk41fkXvmnGpBTJNpaSkRb7Mkj0KstktCiUXyV7I0laJDMoSyFLNI0k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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VH0bxoVoI0m7NUISWcru0iaVlGgnslQkWlT02JJKWlSUCuV5EAmJ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41dkfTqQSWUK2W5lU+MlgKPtbQqWSmH6pmJJQImuWolS0yFakLKNL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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk41dkfx2+LqCxlnxBKwtwyaDGFt6WkLFNkKeuIQhEhahBlb8HMTVOk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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 18->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4ldkfN35KWaKNxtRoEbfNUpMa4pMyTUUz3KkYWSZbUm7ETLZEQ2Rp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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VPsfxoe6tiRJSC5FtNlSSaJH9kRJkbTZci0lS0VxJcmlRUQqIXuF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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk41Vkfv1Mj0oKi9A6iZG9IljTVh5gWFIMkS9mHLNkqFVOhcCuJ0oIS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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41GsfxlGRNclBSkoIJ4okUe4U2VvsWTJoO7xZOoRKvSIHU6QFKSSD
aTnFZIlsjX3POkMaM/P7lU5HSAtJvPP+8VzPX8/3eq7vfd+fe4NfsONxESEh
oTTB+f/tl+5T6TbbjVpfk+D+qwT8WsRM08T6EPmbeYG2Hx8Rct/z/cfqobCz
xqJEn8R9euZ00P5UZJ5WecY+SkLop0robu9UqMX4RqV6kTjksqSAtuIJ6E68
hN92k/gQtVhbzmcixzDsiUsAAam8xX6+URde9+0/z6cT0EgJy5FktcLZ5+mz
nnAS44qXAmIozfinaWETmUpAXbiZGWM5DINcarzq3Ch+ipvplOxl49g+VWFl
Oz5CQton6vZ0Is0qJ/zONIn54XWtnznNsM4387f7QGCPaezL6TeJOHtF/eR3
bxIFYVSLvLUcGEpet7L8NIwEF9YJ72EWpBfFOo7PcLHUvCPO8s4QmIY5mjP3
edjly5ltbuwCKWPPCaolYMGIWRW6gon3cpUu0bkEMmySb0QJ92CvKc2J7UYg
m2Za8DWrD+fL4jUDtfg4Jrry07K9LASVJB3bpURgw9cVqvllxZAgzg0x3EhY
T2/vePekGMqiYvuYx0h0HVRvNLVtBOW1VhH1CAlZG3qYSlEzfJOdB53iCCg5
Xv7k1loA3h87RZ+GkqjSrdSyFipDxLH7Mg66JH4yhorrFjnI3LZt3OYIF4tv
Knri4/pxqIdBkV3zDhxZqQNOlBFMWLXdPvGSC9mWJZFpB3px32ilgnIoD1Ws
DyMxkoMo/Tso8Y8zXHj9SScp9g3ADe8R7QUCXBGFj3vtMuFobsn2Euzzu0/S
8O9bW6Az2taZ/ZjE8g7ph4NmA6Dff6ySFcGFkr9dS1x+AqZq1jple5DwHq/a
didxCE7t6QZ6/+WhtzBxRNz5DeQ3nnKdMubAAzR+ZXAzRmSo60xOEPgYejig
KacZF1/Whe7vFvgrbJPsnMtzhF3JoIX6kgh5bl0tpvkCjNJ6UyuSwId+SoLM
3Vo0Scnka4wTWPqtrKJoHQtZv2+mLs3jYfnRAZ2U5Aa8FT2raNxOIOyRtYZ4
Rge6t7CsHywjMMeQ9eXlD4JxUqatO4wHV36joY7jCP4tP2zZ+F3gj25dholD
A7T0wucqqwlcj1jzp+ZpFsY7YzlUKx46fg02TGY2wGftTUm5AyQ+ptw+e4nk
QEp4MahLggDL9Mcm7YznMNMv2KsXRMLW0DLDeEUjwi60yITbkmjZwPl6jVsD
jqH+xocPCUxJxSj5C5ejOeW26TZ/EisX30/o1A/Bq7KarqLORZ2aI0civBa2
v8yGKRIkti1++9HMLUFicIhu20ESRX9pDL+42QJpZc9dGzpJqOdeqP52uR5/
b7YPuKpIgmLd5DZw/QGYC3bcaBsStMSciMjVTdhHb1cRlSLBHPrlw07qhLg8
NU9EMP/WOeF5enYNuNpnDmgK8mBypkK/bnIApV/uKRvkcDE7b0b1NGcj9u+E
quOLPNB+PeAx1g5h1vbhXNo9wf6qhRPf8ssgUcxUK/uNxJpE+urkSA4KFb+/
XX2eC0ryTVMF5iN0rSsuv+pIws6IRwT+6seXqJ9z4zUkdgktTLortEO9NPgq
z5nAiZBcyr+GnRiLWR2Y4kfA0GSLouoJBspnCmkOPiQMwT43PMNCsZO43HTU
KGh5vobU2QGkjlZ0GAzw8X5gz8f+HDa2rG9jN1C5CL1+uc4suA0Ob+ajazeT
UPvIXbdGrh9L++ON6ZJ8jNR90pUpu4dT3vGueoK8OuhyRFcYt2Ewtu15/wQB
IS27f/R8emF/Z1n07aN8vBCJNcq8MwDVS820iiMCHsif7kl17EMvXdl/3yM+
mjTcasNpLCQbjR+6ZiR4f+HpDVuqHz49pbzbKfh/UcOX5XYWFWB/1X0qpCDQ
49aYorn7AHCSNDb6zMd46u2qzvWNoNqn+8jSSEhdk5RYdpaOSab09x47EkpJ
MVHHS6rB/CKWYCTIp9KZ/hdmH2pQ6xE+NSfQf2GH6x/F7q24MCFtnl1KYHPQ
LjXtpa9xIcr5SGolHwrpaktLjPuQrfCO2l4h8Pt/TlOUpgrx7sYa0aD/kIi+
wG7OPNsEK1Xt67fiSBT6HEyuCKwDPZaW9WOGwHq9pAXbtNc4d2psPl+Yjy7X
yZ9ryXo4C9UfSRogEGzx+/botF6M9Uj+KM8j4LmHsmQt4xWW37v8WHyUAGN3
gCgzvw4jWUc+qwv4ERJoOhrG6cdMmfuirwcP6uUaWV4uA8ifzjDZUciDrXCb
sVc1E30+p0xkBTz8qiE3+MWkHxc9P13JqOCCzm6Mn3jfh3+PPxcSvs0DxTUl
4PzFdMzO9kXQBX3W4RT4V55eIwqmslD9goB18BS1xqcbsXX8c6df8dFvcVTE
P/oV8nLvDYzpCfpPy1rkyepIrI8buXuTQiJj52Wlo/XD0Pnl8UBMiA/15avW
r5QogshWYYPXgjxSpGVvtvqwUSqm7x50jQfG/HQL8ZmJJVqtTvdFSRCfF+Jz
cvtw0LMhjSrgl1ab0Dzr6xDCEmfsT6/ioygytSLiUT0oc13xQYI8Gsg7eLj9
9QZLzGtc51R42PNsTsz1ZCFa+ro3Nwn4vKPd4+RRw0Y41by8ZTlG4EW62pDn
/l6QhzssolRJuF8T6+Akt+Fc26i8dBWBQ8qb0ibpNAyG1MiMg8RVvYWp3eOt
6PWc0brRQ0D+M6NoldUIztjsCKy5wMFI090gue2vwTms5Pswl4/rk2WGnNxX
iNtx9yxro6Df3iv6HTBkQXkrW9PyFA+KJinZqxJb8dbrG+uVFIHxhIV3NqUs
vBQ/aBM8z4WuCNOp5UYjOn567zebIiAyZHP5oswAnPOoW6518iDlol02tNiN
OPFoE3uWoI9KN4tklDDQ/U/GwccC/Zb9SO921+nB8M2rX0a3E5hNjX4SmViN
Aq3UK+niJEoqlnwbXeyDQoa4U/dOAslKqh0GFSwEN6o4hC2OYh1dP2lqbgQx
sTNja7byYKz5+HBoVxEyQlZJegn46MfVkH/i2oM/l0v7lT3jo41uknU34C28
JvT5VZ1vYH5p45AouwSu0zLvI5VI/A+hYbmV
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 19->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lXkbPhmfIRmypogGrSo1SBPupLQpIRKVfRmhhFFCJFmGOmSpQwuf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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4lI8DF8oMaSgqNKyIRAP1aRiRyKhUSLK+NI1QCkURDWUlRUYhRHZZ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41dkfx7lpmaxjVErJkmWiojLZft4UssREiyIT2VVCCoOyp6ahIhNj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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk8ldkfx+WnKzFihrIvJaGUClH4lL3UJKaimkSJLEUjXWVmpAhJt2yR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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 20->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4lOkbnrAbGbQWlbaNpFVt0klk61baotTmkKyUapVjDqVCtc3mUEmk
kOSwKoOhnQiDVEPO4zDGGOcceqelcvwpovJ794/v+q73et/r+577uQ/Pq33M
2/q4DIPBiKXPf+9ap0U/8g7yoAVe71V3Ar3Rpz6/BlYi96CRofY5gqp8l4bZ
z56D6Tw5yfUkiO2YelaXIsbLjhuvmQwp4ha2ndhdKIT8rHX5W/kE+zJ0l/x2
qAwuhuWTBgEEFcwHAydihJhUznv7/jGBn6XM5w96EviYycU+2SaFwtJHvOnh
TKxQLP017xjB37Mj75TdagKLE+UyXklQ9L+8y77WLUiJVgt/vkkKrQVlxw28
s7H0yGybieME0d8sF4VtqgbD8HM1uUVgFKTfYOwkRsDevlKlcYLZjhYbalyb
wJ7bXcF4TfDYcHPEx5FnmLn2x8gHH4LRZOalpJBa6Lao2s3mEOTq3JDNPNWF
tBtD2jMSKRx3GAbsySjDd41debcpnp7BzRnGjhLYkL+MdRSk4M/hpC/j5eAH
Tmp5kzOBJND4q8NaEaIj4w/wBwmIaKcRd1SMh7b7J/hjBEs2in+1SJSAX3Lq
vv0wrf93Fcknmxr8vVZTru0KgfPr8c0R8k3oW1HnwX1DoKbgOOgfIYZ566PU
AgGBz7LwYykSIbaFNSx81Un5GpbRHTpaDpFHca93IIGmdnir5JUQcvZV/NyH
BI42JFgntQSsTYaf5l6k/Cjc2nHoSxUuGS7krIwl6Fetz7/f3o6rK0ShXhFS
yH+o+T686xnSqy2SYzwIjE+Tdt6VVghf/B70daUULN8qpwXlDyEnjPD53xH6
P/W71fLFEmjqOKq+spRi5GCl0/FFdfAVJJV6PaL9DCLvdNxrYapnrbQriUDG
efXJM19zcSSh9L6zK4HWBmfb7gkxcp8Ff+4fImBz+7cG9DTi/JM1d4ViglkV
c0b4p1sRNhan7hksxdWP306fX5ILxTar2METBOGh+iOnz4pQNDrT1nKfoDJk
u3JemwCy7T5PE25QvlXWugtmmsFOcl15cYbAv3qLheBKNiQT/8r4Ur7k94+Z
7a+txeQcZbYgg+7rbk9f6voCHgZpsd1UH2rmPRMOPpXYf6B0rmEc7d/rNdov
quvwQF1rVPEJwVK8HKotFSI+zsFyopCeL0/gR/s0IMpuNu8VXb9forT5m+A6
6LhPb+XkEJSpBiV/P1EGwTHunc4QAvEZGzuPx6W4F39tjZovwa5b83fX9Igw
1nZj0uQl9Y+s+mp2TCP2ut7PSa6heipqkf8xqxzhq5jSCRb1ywcTnxJuGpzD
QnR/OUqQ0KtmnbalHGvfrl7S4kdw2VBlltksERrmB+U0DxCk/HB9l4N3K4I8
mdqeCymfttIepvITGFjunV5N/SRnmpyiNNwM3exe96OGUpgOMo27exqQHmEc
uYrW461ecN7bTIL2qQ3dm6zp/n45n/bgTsxVWOlUl0jzoDjHm2VajPwS+x0c
b+oXr0fcqIQMKGfcvi5D/f0GCUNcbhk4iqPmC/4imEpLzfBUF0KpyIKrV0RQ
c8HfSKujGSWlXAfjRVIUTyjiT4kI7ze/P3G4h+Dzqrh59mFCyCjk9OVVEGS9
FzFGWEK0qJn1FuQRsNax3t1Vy8bTLZOZtyi/nBlrMUOuEooJ+mbPQwl4vH7Z
pcWNMCtQHq8ZpfrkzaoKdU+BkdUWlgvVszPTerg3uBFyn+4ekKV40Z+3/ppf
ExwGPZkOVJ/mfTEDqR+rMXlzRKAfRrD+cM9HbWcJJCp6iyWrpTA3Cgn6Nqwd
spdZQRbUL5ZZHmu2J/Ch5G7m5X+W/m/XqTfTLW2IenhwpllWCr/QujC3ZglO
2eYVjS6TomeicrlmpgDbvz0s+TOKQPTXnYl1O1Jwwk5caEnr+8zfm1+r3AHL
Ib/wbaWUvy9TfY+ZpdipjpVMyrcpx+3VWFwi1rLn3VOl5zVyZfxvJfJx8HjF
bm2qLyHbcve1jn/g2HdRwKJ8tLp9PhS3uARpO2yyg84QnOlJnFcX3Ab1ODeu
4Wmab6rD3u4yMfDYpueS7kTz27Vwn+rAS+SbDH3KvEBwoS/q3z/ahCg7aVWW
do+gPea6mehIJ+zyRiuqrkthq4YLb3/JgQbnwc16yofBmMc3UwPtqNqzuTCY
fv/euY9fDymL8aZQpynqC9XfCkvm8qgmVCdkqWpMEcxPLyx9X8+HpIit6/cf
vqZXq867iuHFvvPVWlWKuQYyiwNV2KgnztMsqn9T+xn/uEghAs28fr5E+WO8
bGKcqg/ADt6exk20fnM7r0/+uvXo/86E/EH963g+0H3vuioQ4xfhGtdpntiJ
hndqVUK+2SH3BF1nqadu8I1uwEnLoTmHn1P8l9m1tysLEOpW0b2WzstQt3kL
lrXUIkaenxsfT/Xw9HJNtkcLjhkq9rbvon6IfpbzobEY46Nn3Cxonj70Ohyi
aSlAw7ne+etTCa7m6frK+dTDauud8Gaa182KLmaD87qRz7Ot0t/5ButXmmqy
F3QgrUTlz2uFUmjc+12HEy/C/oJEmf5Wgh91x1x7NzZCf9GovFIWAd/pq6ts
ajyC3LpEUorXx7H2ScT9DhQkNG+EJ+Xz3vxLbVo38fMP+vF+dJ/BtOsqXxMI
nXNdoSZ0nXx22bt9OxuRdXKwoqWb9qf+QrS7exXyk522hEUQHBn32Gi0phlv
0wIWs6QENuPWJHFjCfivs9um6X0hbnKgPqaMB/8u+5IwN4J5O62yNAIEiLh4
MegU1ceFf3g1XjSfA5d3ZlbF0HofCc50lQkRi6QD7+j9oPV1sGja9CXMt+5L
MqbziqNpxfhpYSPs9uyOdimn9Vid1egMp/ORrbOlboEUqTonBcipw1L5PZnp
tP+eUwVcSXwx7K2vD8nQ/BYO98gbkDzcbJmWXKHzglHwE68gMBJLbniWnqZ4
+f1fVijPbYHKquoHmculMPa3Nxm8LYZd/yoTySeal0qRvyn8chdDD0OOF9Pz
PV1Riedn1UJP3Kz0hfpfxCBHi48VonPA9mMSxfvPvwPdjw9mYt8ufqQ99df/
AasE1yo=
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk4lG0bxpUWla0iJZUkEdmSVDgjCtH2UqishRAqJEq2V7wVyhYVo0XJ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk0lWsbxs1DHTNlcVRCISFRmbroQydDHFMyK5UGlFQ+R5IiCZnqIDmE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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41ekbxg9ZG8lyKGt2xqC0WAbd0aaSGiY0KTP2n6WiCSVL0qKQipJo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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 21->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4ldkfVypLkSyFkiUJM5Ut/YbGR1IprVcbRRG6opRSKLpadEdGhOxG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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lG8fxa35ZUtSWVKUJCSFpNKhkJQsSUppE0ULpUiIqEiLpFCpCJWU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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk8lesa3aIIHc4VuegKaTAlGZOWSkdIoZQMIdqHEkp1pCi2KamUDKkO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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk8lWkbRqaMLCHF5BOKUU5FKNXoEiU0slS2bDGVJFuRT7Jk4qSF7MJI
NYVsCfmIONmO5djOQbac932JPmYQplB97/fH83t+91/Xfd33dV23spuP9Vkh
AQGBZPr9/59ZMXPwlezEuOoahQvvSJiEuM7GmbJgUi6oPwUS4Xar11b6NME/
wOhZfi6JK/blHapOXHiIeAtucCNQudytPXKhHyZXuW6n4/iI03go+doiGY8L
iqdb3CmEm07te2j8O6qeaq9tdaawbD0fOCswDNfpvVcvWxDIOPYgw3alFrdF
VTl7ZkkI/bLynpE8gOx02bINpiMIeuYdkJdejY2GXr8cdKTw2TT+ob9EN3gK
OyX2sghkrR4c3uXZB+ezFZPv9pLQ405+2ViYC/95vY7akxRMhlvCDbseI8f2
+jtjGt/kvXXdePBbZDzR4p8OpJCTcWCgLaQEzB3jj2evUThuIcyWedIDu77c
xptsPpS0GaeJ8VpUbPn9pTHNX8TL4Gl2cwk2qf8dH6ZFYTfDO01Ilgszh96J
Tg8anzdt94lTDzllt4bqu3QteW1mSuYtbBS3C5DzJNJ7wnqeq7DB/TQxo8Cg
IHJp7UqUfzeSz5SX7T5CwLC0T//ZNi6E1tx2+WRJwjeNEeO10AL58j/Nv7gT
2DqcY9DZXoWl1Rpj2foUuEoeEzbZ/ahln5geEiIgEHl7qvMoB5cs3zFqxwjs
SY/dapbHRptymtUqUwrqYy8OhiSz0IZrvjqaFMSIVX+f0hiAnayYvUgbHxK/
Wbmdz+NgS9Xd0O8fCGyMVDkUcbcb8kLbE4x8CCT9a0JcpZuHxnZpQoLmJ9Gk
cV9+vg7ZGvO8D4MkXOvCxn48Ug9/p/Jg9+skcv7zSNZqrhXNyc6V/7pDYH+Z
jez0tn4ce+GfG1FOYOb7YIZHUBYuz8ofzXCgYM3z+nnZsBtpTRdGm2/RfBQO
q096JsEk5/z+1FMUBESmZYbOvkSL0jv7aF0KipzleCF2N1Ryl6T3BhGwu3I+
vqqlEZ/W7+oJyCdx2IdZqUU0YtH8R9LmDAnJ1KClz7WtSP2a8CH0EYlgfXvj
VxFdOHR7oE/TjoRBa85t5RuN+GiGScNhElnjWzs8nvSi3uVk9L05AuEZNoft
zduhx84IDBAhIeeg7/HQpw8aCTasHb40H6FWStuwE1lBzI2Z0iT+iBCffNv2
DuafPzQINY/AkUksHbrDwwgrOnHgKR+pQr32RXSdI6zyIvvyKJpZ0yd2jzXD
+/k9y9xUEvs955jtVi1Y7RzMTBEjoXujLq4uqQyv4+aVGbR+WwY/xn4U60Eq
ua5jWI/uz0EzZVQ8CkPXbil/o/1iYHhNIWImDW6M+fSjtP57bAPtri62wy7i
TEeEL4XmccdnLUzaZ7KNRvqLA3CN0Ly4vbgWlckrucwNFBQOTvmPZNZCwf1j
7LQohYDnxnwN4SHsEoyqWccYg3DID8KEbiuuK2zx7Ugi8SR6GeoyHVB+XtTQ
Q1BIlRqKVjdtwVYfZgmD1vOVmMIk8V1vEMQ9l+btQUHJ4k/L5tkHYIb9sanU
jsJdeeJpklYvgsOiNQvSCOwTOKzevzAI8Z0lstKDBLqjWYsiV3pg6/fDN6+H
fBTdX7zwU9JbGJiL8ftpP1UWHrqvq8+DYsNcATgkRlNfR0ydzkCqH1f8hA2F
hKhv8kmjhYhctWXojRMF4QgN0+If++BkdXnOcJEPCxW98DXeNVi3fnCaTKaQ
0XasrvEIFy2hTbWicfR8zT5LvTSpRmIUR6t6M+0fo5V/CsDDUuUWJ18BAo2P
VhUO5jageMn0grEBnX/zNb7a9rfwQi2KyKPxFJtjEtaMd6HGdepmbSmJc9Eb
8j06aT5r871izCjIvWTdaTWqQvKen11Uj1OoTYNFokgkRnmMhB30/l5ePFQk
u4uNiUZV5eZa2m+U3/4ATgeC+RIedQYkfu/sZNpmsFDBqnW3VaFQf6+86pZ8
J0rOKAiJGNN5+2VMMNG9B9yMzV9vFhEwCG7wNHXhQiKjz3w8jMAvZc6vyk9k
omRCsM7Ylu7fflzGZ/0wbJbOmX5PItAZvrC1Sbsc6/wLE3hhFPQOBaecqW7G
Hk7XlE8N3U9mWGuV8iCSlPKXmsghiLUOSrV8e4NLvWPpcgIUnB3lAnJLunCg
aJKjdpTEio7JAU0DHixlGIvhuaMoFi8NaZHnQZW9HB2SR+tDqqBevTQUEvVx
L7Jp/huyGZ6BOzkI2ZkveYRFomJh/639Io8R3F1LZRlRYN5Vet/74AUeffpa
Nk7P0+u2ju7SUgMO77I+wL9J+yd8n+XnpGzYDankZp2nUGxdcPWpzGP8OuJS
6nmCwsXdmewL0xxoLP70dZLOD4GLX9PTO0sQ+KCQlE2hsMdA7JXdQgM4/6RH
st1IMGM3EL6JFTj81/k7fptofK6SomReKz692ha2qorESPeNMdeUHlDlPoXp
qhR+W+317PWBdgTco9YhhMTONvaBHfx6CHtsls4rpuezkCFpXtWKU4lNRY+O
kwj8R6vdX60bXiPyV26M8aEQIGVSP9uGTA3n+OjvBF5z77euOA3C8bvapX4Z
Epte8t5w/LrgqMw9aaYxhtJHCPNyGkCqv2C16jYCaqtdWWuD2Cj887haujSF
mROaZa+y2hAfe1mnaYnAE8uLu61TuJA5eO5X7t8EeNZDNblvW9Ho3dbTkEPf
j4pzVnd1eIiODPUTLBxFTmK5/9ByNUQjW7866NB66baSqgyNgMX6S/9VcqHA
2i61PiGeh8ycwiqRUlpfnM3WV2eboK8tl+V6jMKpfyvM2a3qBsO5KKYhmI/A
TbCKTubCMnb4i54pnZ+X/ppdt6cRon7KWWV0XjCCpHNdjvfgvXhAmsktPjo1
8lm7vRrxxjc3JXAzCcUC0U5Fuy6Ez4Rlem+lUNgRXsi804/nvlNqsT2jYCmZ
vjk53AX1j6HbMv35qCjvoNrRi/y8UJVKSwI5ujVPzNaX4Fib9wI/hvaj3NyE
B9WFIzMuOjX0PWLvu+ofE9+DYKPHbMeNY/C87pAVIdqLs3odUcxSPgQaHrqL
fE+HrpWW+gCt1/8B25S++Q==
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 22->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVWk8lWkflhpNkaVkSmE0SjWSYyJ5cZmJFiYKESFroQyhySlbmZmMMJWl
lC2ylUmLJmQ9HcfO4RzLHFJ0P8j2qkQJvff74fk9v+fDfT/X9r/+qm5+Vp7i
YmJiSfT5/9tlWcsgy4MPLfZz0yXFBFL8x7Obj7UjOM9F8sdpggKF4XlT8R6k
8HxYAT4MnHewYy8sE0LWfLvsHQUGd70zWPbvRXhddKe+P5tB2d09o+lurVDv
25YyW0iwJvNA/lrFIigbFE6PeBI4SjzTqYwuQWl2rEHcLwR/+y+6tjz8BRKa
p8vi1g7C4I9v+0zVK7FZVcHHL5DAZzBsicxkAwIa3JqfRhKo3WJ/2PhPLUrQ
7W53iWD4aJhS1qdmHI9SfcF5QjDWEFRY/qkTp87aXskeIsg42PvKuaoaB6S6
jvecIejlZ+60jalFz/5KyZ6/CH7dvaVQaetLyBo6uxSXMnhUWZxvfqcTqfcK
34fJMVDj+emLD1XDS37Z8tv0/O/jpiPmk22wHD/oYz5JEFqcZlie1oiLYufk
9XMJPgfdKnhm0A7Pnb6K7FGCphrrrfu/74KI/KK6251BQfXR1KbURhjz5mYP
ZVJ9PvklthyuR1bedd93EQRVserqnvJluDk8ZB3iQ/Ax8POk6Y02aPG8DNVb
CLK6Wz9Z5NbC+tNK2eirBAdd9S2GezPxzswiRuRCIJbcfpWj4Ia3ZpcrWMcI
Nn9ltdo0uQM2dnEmMyoMtH6WkurQvof9ivHsnW4EetqeTkx+M/6rl5MfkENw
RG1N8PPubjjpGHjO6jCY2qRkFm7Oh2WhneRVDsHqIr/FWxeJMJFl6vlNMAMT
6/vZwV7PoLWk2sffl+od+q/3gnQrElfZmYn9Sf3bd9VWQqoLU+wfJldoMMhT
Cd2+bLoB07Gc3aMZNG/mck3fPWhH7onSAPFygimNYxJrpjqhVZowMyTN4I2+
iqVxFh/XNQUvlHiUT9iQuPE5IQL6Ij+FLGNQFaVjJUf/L6ViIPbBi+CBhdHi
ieR8tGvfyxlyJZDYO+DQltOO7ual07NtBC2y36Vbfi1CBBZHV1M8u9eYfjZP
a8clV5/9tq0EJhtWBUZ61sHoMi/sPxR/3rWy2pxNPAy62HJU/6D8qutSW5Uu
4h/llAt7qL4Kk1Vp4/M1kD7wKHwnzeeN+JPblTU40PYVxEnT7yi3lUViKjyA
FVi8Por6e8/14JuyJtwPciiyjSMIu6kToPtWBKvFz5vmDRiwmwOqQ527Mafj
37crkEF9LjfY35CPMIWYU+8fEvzUdHWswakD8ofHPG6aMui9LR07eb8aIxmR
7kl0XhaeLFg9vSBAELtmyelx6qdloRL+KoPF+uEWqVME6x80nsvaQPMoa6wt
sYSBS2bYh/4/eVBsC7PrjyYYiUiZ0FzPBffmopkcmkfHu41alfIv8aPTsmSX
uwxkj3kq7AIP3J5LWrXhBF9LavCf53NgYhG64wKdj80yKkmbL3Yh5Frhj4f3
MJh7pXuj7bwAQ4sUG4ap/lWBDmcGwmOwabzU0IPqVzD4+oNOrggZDZxxO2cG
8mde5QiO1iFsPiA6/SZB0ZGYkoZrPZA60OEqeZvBg3WuTjaf21Gh6yV5ms7f
jlax8mZNPkJvJl7ZW0Iwt46f+axcgMZ0OW+DKerfUp/X1lXluDKx/geTIIK+
mLr2VfFlUHF8qhlxkvq5sGFjtLAW38c/DiuIJ5Azj8yNXCeEklCU9V6MQUho
yV1jMx5a+wV13ZSvTKP7rhyzJpwel1uQfUDxP1uesCepC5pG20KcGIIIufSJ
Kq0KXDmRxbnkT/vp+JF98e9aoSwtr7y0gvKp3xvlwAhw8Xyv+apZggT/74XZ
Bhw0smp/d6H+kTUs541KIiR1bl3JimWQlp32FWu0Fj66Lzz7aF8FmIWEX0zn
YmCTd3MO7b++gse6YwbdGJZprtD4lcH1115lv/7GhcbOVw9q2QTn+kvH/fXa
kdM4oNjdT/FYnjzGmqvFn3fWphrT82nFFW6N7/9F4t41MffPMuDL/BTFOLyA
0n8S0t3qGcx2Wd3zuMjFqYTvVliG0D47aPTEUfcRMhJttG64E+Ror+P8duAR
NtL42dN+Vyuz17NMr0FBdnBpFr0/yin/I1nLx965YC6/kvI7JXotodqBiR0N
t4VFBLos3tSTv0V4p1i37agX7achl5wNsQJE25CNio1Un33qDRoBJbDtDTif
TP0qUAksObOlBhr25h9LLtD5Fm7ZfKSzE+rlNiaRbwhKvni3KYrqIRG1KbQu
gfrR9tR6U0QTVrja9a+m/TxXqqw/bdGIVf6OY8G0fz/uUX7Z0VKBO8+Vf3fz
I3DY8S7lDykR1N5/bugIYaCyftRX1MKDmqa80tnzBJzWmanLu5/CLm/77i5v
iuelrtG21ULsq64OdaJ4RwTmDiuXdyLMwVrua3kGUSuNIvWTuqEsNhkYZsXg
hvcJ4fybLohz9B5OGDE4pZXok15ag1sJgycqLtM+jIh77NtVDha7e2k23Y/d
/VzDCvZDjCVv6NziQeAC96UrUtqgOVejt+82QV3BWOjokk4Ezuh9mZ8nSIkp
2GKZUox/zT+meVC9vvGR6LJ3aINjrmS6MZ/gbKTeupHfRBiIuL6/5hadt5Rx
a/eTXdBtGzl0yIaB1Xkl5dPzdbDwPaJvTfXTGHTlKsbRvKZa/Ny6mMG7PCsl
0UI9eMWpt/hXKB6Z6vpbDgIQL93JSaq/7ME7JvZMFkY84rTq6T4S9r4Ybx3u
htS+Ifc8WwY/DPtX5+xqQ+XlRy4lb6kffk6SqXSf/ZUZPH2c5lv2zS+tfQMC
XPM2Pq8uzuDbqsuB8XdrMXfvceM87d8b7AHTcbUGBAttEr2TCR5Zpi/ks3tx
4CeZ6avRVO/0Qz0z3Id4kjAYFEjzaLpo48jy1a3QVZnjn7lPsNJHIjRWugtu
hs6qX+h+/lJmX6LdLEKg1EimRBUDrvCt93UTEUTaZ/sMjzKYt4vpbN7SAdsy
jyB1ilcsQ3A42LQIcj09hnZ03wgvnZOLk6kDiy8/KpVEMJ2yQjTu2A6z8Jk9
XELwPwvpyYM=
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWGk4lAsbFi1IKkopItmSStakuhUV5YTSQkSFdGwde1Ikh5KyRIkSIrKf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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk41ekbxu1ri0YjJGkqNGUpkkwztxMTicgykp2xDGXLaFI/oVC2RKTI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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs4lOkbx5UlWimFKAkpZ1rE6PRVSpoQRWtZQskUcqiQVH6U8+okYdNi
kViHnNXEWOdjwxjGIWPeeVuiFbYNm619f3881/PHcz3PdT/3/fl8VT39T3it
FBERSaHW/3erEMbu+qUBeKd/6PYsIzAeNpZapsOBrMyLMO9MAeST7LOFWnkY
HedcMPQh8UL/x2GmSSO0u99lHt5DQtPn+c6lmhbQJxQNPz8TwiqyZbteRwUk
Ix5efuhHQved+q42/16Qc2bqjz4QaLH/UY8u34f9zYEHBJZCWPRlrO07w8Pl
46/unj5OwLrCNZyhNAx3mdM2d5b42Bkf5iBu0AC1L0lhD2qFWP5Hd9B5Ty9+
Tx7McWAQUBiId4zxYGJ8I/O3bGcSDPPiO5vtSsHcZHr+wD4SEXSPiSQTD4RZ
2mfKnSah1r6lLL6/EsUG1kcfUfVZzRhGa2mUg5zsD5K1JmGsHJOzld2EYp2h
GT0bEkM67YXNrVyYpvuk0qXeYl2MT/LS4DNIJd6YGrWg7g+ZWvwtW4IdITc7
jQ6TOMsMfJT0Tx00m/j2zh+FiPW4ccwmpxaXpI/qa8aSkGJJ8LivXqHc/tSe
DlcSF1kHJbZONuLJH43ehWIk9mpLrRVR6EB51sD0ukkhPnZkWhqHVGGlYZhf
rT2JWSm7mPLuYZy75io3xxlHbGqh+XO1aiwLOGyGFwm2jqKJjVYxHA3u72qi
/uciPtEVWMTGRc6kYVYkicOtElZt1YNYZrY/78wisTrlkHKtxABi2uzanB4I
MF7EvKnVOYg8Q5GGl3NC8FwUtyQYs1DUf7FiUYQE6Rvg1Enrwdmpr7TMSAKM
/OawHx40U+9MlXCHhViUqX+Uu42NlgiZxZomEkrfLDkpCvsR1W/h5TkkxNtN
BgpXjHrx7IRp+h1HAn0ZwRV3O54iZ/nqhX9ukcgr+IV8WzsI2hfN3NIsAuuM
mZmMT21g2xxI9KsmMLVNrO/BaA9Maq+bhfFJsKLyrxv/G4jENP86GWq+O47Z
FrLNqtDXaepJO0WiJlktnWdUi9g+uSv+9UJsnxWkcRNGsNu8QXO9HQHzS9tq
PuoPooSuvDHdgoDokotcxLU+ONN+8zNro+Ynvr1tY3snBKW+elU6Qix8Xf+S
21uNE+65rPcnSChaO+0Sv1MBtTbbp8GHSGTNJuomTXMRWWc0yLAVQlbR8NcN
64YgKrbGQstMAEK7psfenIsnOkmZmQoEVNSq9/rLlOL0suqOUYo/Xrnow+OV
nbgwoj0W3k+g0Zoho+w3ioKpBpn1quMouHK9b5TzO0TUgveEU7zZ+bp7X0nI
wqZLDQST4uNz3FjFxigeQgTsdqakECUtmZ9mV4wgQPf6+V9XCFHBCw8pXewE
Z6jZK95XiPAbuQW6kmVYHgwvjZMh8V7ajffFphUS8rv39t2kzg8yR1YEc3BE
ya9m/Drln8sbxZDsCOyts0yJcyfhEDl/b7tdD+RVLodVdhJ4MNVrt3yT4pP9
SS8lTgDx/T2nOOBi88Ga3ncaBHQbfmaNhvZi67aez+HRQqhpF1xh33yNyKaF
uGuUb24zRXPZejwUlt+Izp4VQOWn+6G3+feg6xWpUknxvd45//A2ZiPafBfp
cRSPXdmGbhqfxvCxpPpw08IIhq99637W+g3ytbvCREzGEXGzsuNqfQPCPf1u
jWWT2Gn0dE5qQyfmHfT/p98oRECdK2l47CU+nH8WxnMhwTzE84rbMICUj8JU
WxUBWAMbO6W/46D3WvkbG1USKt7zrLsjGZjeOr01m+Ir9Fj9L5NBPOhY55h8
V8jHmdOKL+olOrH/KMOSL07lg0YSndFbhiTXG9E/bSNRtbrXbkfoACrG0ibq
NgnBcDynVbKmEfJn5ArPkZQ/h36QFjZXIHPv07ldRiQUpvezfNprocl8sRBs
RiLH2jgi8QIf70/+fb7LcgTMhP30J5TPZRc970t8Pw4Ru/Oy1VW2SJ1e1aVF
+ZAZpa7p0/EYKZsKVGUdSQScnXL/8Oc9BNMOtkT+SMLA668NYYxR/GJUl9bj
NI4c9p5NdavZKHPLZ1WmEbD61//QTEo/xgNTlTnPCMRmGfukS7RC3rJ62jpW
iCcJ6rlBLwdhE6ghKnVKAH26j6eFNw/lo8r71lA+BUQZiQYH9GCFh550x14h
dkRP/0BIcsH9OengkpoAxnHOa97VdsN/reBssATF68EAye1mTJwRHQz5TNWr
TwYlO3VwcVRmKKm5iMDdKo0a0aNDWBx3VKVvHsPRUbMW1wk+6OuUv2QcFqDU
41L8iqbfIDtjrf4v5aexZu5kUPoYqiYmBfd2jSE/kdiutPk17rdnBCazKD8v
SnblbunG1sXLf+lRPmSbmpfO8Lnwv3vke/vJcZQZPWj5sGoAUnSr6uViARKb
Vb7RtihHCX/GZzaE8lW/6KnvPjZ6+XMOywwqL44fWKwXo/ipjZTvP0sgQqok
ja2TAFuXMbqFGwlaXrMs/HqxXOJm8DOVZ6EKrux99C5cnabF/LlaiLhXaSXW
AYNQs5rx8F8SILxJI57p3gXP9J09eW8IJBeo2iU86wNBi+GvESdwe72C1mw4
G6W7PzueIEiMuu9buWjfjI+yCHG4JURq/rHPGyvZCJb4XuqqJgEnjaVQ6dlK
LAT2ZOlrkyiSLETyrX6Ei325qhJL9Q/sx2L7WQj1OnfHaECIgdDRtS4ynZDr
n+FPmZDwr1zY7LCFi1Yr1dbdMQT6jUuOu1ZW4dtpg4vJESSOmBXTaC9HoBod
kH1ykYAIbeI7i9sPsVnktaQmxVu4Ta+Sgh0HWhH5TmIhBOSCpn/yVO/C468Z
re1RJJzFhiXuRfGRY2bhpuP/Fk6Rs6+vDYxAvenrc9FgPgwHH8Z7aPfhd9MM
zvtYApb01B5I8xBTL7aw76QAK1cprNFU4oDmHighOk/gG/Niex5jGDuCo7v/
UCIwz/qje+Xia9D/lldepHyiJb95fPtcMyzzGh7NHxNi3QsvE1YLF7PyxjXz
qQJcF2h4r73MgS7TjFzaQsKXY8U5aVEN3bKaHJMLJHYf+VA2kNyOP/MU8x0o
f1Ntg16fCqqC03u/y5kGJP4D0gCudQ==
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 23->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4VfkbRwvTNZSUSFQSES0zMbR8RFqezIS0yIwkg/zIlpFdMeQia0JG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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4lf//tlMooyFJS6hQCpXKLcIno+wQKkmUIlEyoqRsyl5FFBkZISt7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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlns81Nkbx4efCrW5VVtyD0XubZsSH1GW0a+fS0pWDEVbq4jtQpRIpJTV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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns0ldkfxg/GJQnluAyaIZHLmJBKbg8WkpSplVQjdyWFyag4qdwbjaRI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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 24->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4ldkfl1Io0ZUpuVP0Y6LBSI2iqc9NQ0Yp0hTV2EmhbFERJRUppKQs
iWSJkVRk7eJasl65sqt0XpIpCYW6/E5/vM/7vM9Z3u/5bN+jZHdst6OoiIjI
Dfr8eMdFzAqbZ98N5euxE+JdDFiWCa3xRS/wlpWy16uQQCQ9c1hG3QJ/idbP
XmNNwElKTr4i3QAPcSlf5WyCX/pTvt2L4qNauO7Mm3sEur2LuJ01rSjKduWH
GjJYtMUtbPoIH91t165aPSOQOWDrUv64BZJX8/7p/0DA3t0XPjBRgd2tqu+i
zxMENT0djmjnYnVfzdfT3gS1gXaZ5XY8xKeFLPkQSLCpNSXLMrYVwTvFekX2
MeBomrgt+h6KqAiy9QCtb+Gcb4pegx1ID3rrp/Y3g88nXKdu6bVjcY4g54Ml
g3LXpHLDig7ccL/ucMqFgfql9QEX7F9gufZc/t/FBPofgufWDFXCoC/XufAS
waehOdenm+/A/KBkmqMNAe/1do/E8WKkyVo0LHSh4zOXD/+zNxNz1n5wibYj
uCPRtE3OORE2XRrfFen8O+Ybbat6quCTLZuaH0LgLJ1V2ODQiP1loj66WQS5
bznWVTYdGPV9Y3CI1mMT1OUmqpSEvF8Gv66l61PjBgwevu/EA1PPnqnzDF6P
Ko7XhzRiW97TVDbFky0gf1Zm8GD1RWTG4DSBYVx108gbAYpTy+bJviO41heS
GOj4DKo3PkpJHyfwHmWN6hyugt/x8cHXVwhe3xkYq+4sRcQq3rJKLwK9pC3c
NMlOaOvbjptoMyBL6/c2y1dDnFOq8FcEgaIwtL304Q3IME5KORTvCbWJRjE1
ATgnj1dpL2Bg2iYRKJn5CPuzJHTLHAi4MXtM1xg+gMnAp8ll9gQhSkc+rwz7
F4zLWJgu/TY1Duit2VANiYwKgSnFx2ZSdmQWrZ9VY7Vg8DPBBqtNd/wN85EU
Pznr6BGCXl6cQnB0OzSfb9BiOzOwCrmbf12uEt36xkmXQun/Jv97ft63AFLF
nitKnKkedFaoBPW+gHX5T4UZXIr/8L0jFtbJCNn26i1D8XXidEm3FtUgN9Mu
+TDF43tODOv2p5dQZqtcPWbBYMOMipbQvRS6jnpt7zzo+dOCZboPN8GdbdJf
T/mr+v7H1K/GzZhv7NaSnEL9oaU5b01ELJZpJBt1Unz8v2rtCb3Iha3RalW2
J9XPVcGM/A4ePPl6nQ/8qJ53beDfnN0GdT0V6TAnBtzYunYzo07w54We6qf6
NZqo3pzxKBJzL3R4Hqf7Tf0dKbQLbURXPXuFDvWnYtzPxdkGGUhzDetRpfrr
l2rhSHm0wZSsPzi0noH3v6qFzlwB9okFLfenfpNJr1Utym2Aet38ZpNSgkGf
3fsjZ7+C7bme0M8fGJyIxwkH75fIDjNIHP2ZwbmJgIqtdlyobAxQUqX1vxQz
m7p9rgVfuFpHfSjfq4uEmz1kqP9DPC97lFA+52r0q11OQbjeMVdJWwIpQajI
n2fL0Xdr8Xy2L4Hx3ejidWtLcENMy/XADzzn1TREujymuaKu7OVE+Zex3N5P
eDgoYP/Mo35XXq4gG6BWBfVKvq/ZGYL/3p2rCnCshmlTrFMB1WO0clRUhVUt
DB6nC6/dpueTypLPWhmPi44syXGKl/jq/cE76hpwqCq1PCqG4OBk6fDZhDI4
y03Vpp4geJNcMh7RV4NZTtM7n54j8Nxns11LPRprVnGXx9P1Nu+8HhyUSEH3
mNyuWqqXrsmCvfKvmhFUwa4+2UTnW+s9WHa/FVt5l81vyTK4aeFsr2r5EJr/
Xr3oQvWv3OB/mtPaACdmXdtkIs2LQP+8hsBMTLg93T2H8iV+QuFo0JJGLF3w
3fjjfeonrq5j5qlM7AsfKcuk40bGEfxo72yIPM+Y/pEv6vrZajuePcLwxUOH
XjoSnIlZuDq7pwg+nxvzu44SKA01GKuM8NC+7eNDsWMEkab6F3xSKlH83mZ2
VgCB+9TwTb/5+WAnnhppof7gDMpP5znwoXlWODCX6tcbUTV8/Zcw1w0XmzVJ
oCWfvyhmYwXq0mt/d6Z4uSclxtx278BKJc0dKasYtL+PfWI49RjhpbvsSih/
bPuVad7jtTCNlSxxv0n9KLqp8JFMKzY3v1fsHCAoXs2M3AoRYLewWz5BlMF/
gY06l2JeQmPxH2stvhK0l2xhjaxshDA23pyXQ/NPrt5rZk0zFirkn3keT9D5
5uMvax++QIJB3xXSRZBi9TWyUoMP/wAra5JPzzsgKlkQdB8sszqj3ylecs5v
Kg2sKxHpaSjMCKJ57Fcxt2MwBbJ+psu+UT5vZAivyWxvw3ZR3QXdm6jft+xy
cpaqgtoK8VwxmgcWmk81D80WwF/Co3rvHAZrClxYKrnteFJ9UvW0AwOHu2Pm
KvYt8Aq5u/7FW4LSpkJRdrQAOps4KfxxAh/jZafmJ7YDkr4wof1n50arn9Zt
5eOCwatguSSaB4XvI+W1eiFYb5uo6MlAKW19QcQxLt5dW6GlQPtfUeurnYlZ
bdi8ZdHY0o0MnK/MOZh3uQilr0rG9hwi4DeqdjmgFVEhHnwVIUFhaK+JD6sZ
OtcDtnrkErCKXFnBwg707ldecfkKA/b92Vf1+XxwCmOa71H/37xonvTMuxlL
zIz2aLfTfJY4aWESwYO2bSMSaJ6+lknU8FPuxO8hxxxX2tF+ULZWpGdpC1jv
ObZpw1Qf+lrXVbwykB3859Rx6vfvPbdvPUitwrTZP8nR1K/bNbLkC+ViETfg
dWqI+qlbQbkuS5qPxVvd7kXyCHbsGcpx9K5BjeVYgcQFgmRy2kPWtRoB9sVf
win+9884wkm7Er5xGbtW0f1ED6dPez6h+quJrO+j9YimSx8QqLVhePGCGQtl
yp/lbfG41Fq81hrNGEyg9wdJ+Y2cJTxI/BFc7Eb1KxL+v7rz1x4i+Df5db9R
/4zmnNcJXVCJ/oFvJ0/Tfu/u1VFaZ9aOId+sL22LGSSwJG7NP9qK7grTX6V+
6L2gS3dnYgv4M1GFcdQfPZ88dvaK34FV/F1rG6qnHb9tcPEvy8OTCItzdYcJ
/g+NLruv
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8lO0bxW1FStZXIhIlv/aElOogWVLWROVFSLbKEkUpWSJJlJAkZF/K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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81NkfxmXVChu6kMiy6LJJRaui9VCj5FJqkZRr2PnpRm6VSy2JrM20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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk4VXkcxq9IkkoJRZlQ9AhF0TDpdS0tljJGiEiyRihrZUoqg4yIiSIh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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 25->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4lOkbVlLtEBF+bbQ5LZXaKEuJuW0pv01ZK4SVWuscORRRG0IHmhxr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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VO0bxmWvFJUipRT1SoX8ULRcIiklRZElISFZSrKllOzJ8oYk2bOV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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8lXkbxm2hxlZzoo0USaJCCeFCHCYqTNMiGhSFd1JatBhEQ5ZKEZoU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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk8lGsbZixJlBxbCG0ijkg5UrraOJRkF58ikSURDeq0IEKdipFQ6FOH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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 26->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4ltkbthSSaCqiNGEUJhkhqTR3SbKMLZGd1BSmkDSJSimGaox9rZB9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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lf/7xyWhskKTRDvhk0i+kheiiKxoWSFkKw3KqlQqKzMjUmYpI5XI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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk4lWkfxw8R78gWKaEkg5RMpGHI19FiCSOGRAvFJJUttIx0shRFNVO8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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41ekbxtGQRiXZ+klNIiKRyVLDuI9dUbYGWSMZjKKmtDCWskdMDZ1i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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 27->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk41dkbVyka84spo5REYdKobpSZiA+KiUGylEFTlGuJFAnDcFtMWlSE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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VPsfxgkXJTuVdG0pZS9FRY+UFiktSDdLqZCbJVsqRKGNsiWVJFuy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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8Vfkbx1VkiUkooywTYmiTS6MsHxVR0bWFUBFmaEEqW+K2iEIabilF
WiRbSraELq59d+1acM6NZjBoNJaW3/f3x3mdP77nWb6f5/08z1l71NfGc7GA
gMAt8vz/rdVvZz6Y+xz3c5+y57bSeCzz/cc90Q6cZ8prajBp+B9UXvm+vg1h
iy2VNRooMBYb7WqP6ICbnsNdA18KjpUCZzddeA2248Z/TL1oGD1uVJ0xakdS
0tvH9U/4MBCdVKl9+Q4FvfvkFjgUNO68+/rn8jasuWWJ8fJhmGu7hkv+VIUY
Zd3bkodp1EXo2kQ1D4BytVPwNP6A1DmjqrmROmQazmbr76EhuLihwftUBYoH
hkaSttAQMcn2YGhUwbVk8+kQbT5cVtwUFi7oxbJtS70v/UMhWFZ4kXBxD9ht
3plzicPwuiv/r49UGjw2yAh57qfx144EF61PtRARXScXaENjXdDI1yDFamRa
aM3NFlLgKhdlTbZ0I+cbI+A1awi/Coksik6qhNFx97RNRjSC7W+fLzNtR1nn
aurCQwqlZlOTJ6KawPxkvtBCzq8FcfPtyuqgELSYV+BJQ3Xivq1heBW6lUaC
8yRoeKT5MAPYtUjR9PucdIXG07P82N4lb7BVpOfQCWcaqfM9cVNiJWDyqybm
SD0WbLL8rq5thfuSMSsxfQp9oZK8fPk2iBydCBP+lULn15Qw3/gqtLgLeDCG
aOTpG4ncvdmCL12aPD93Cqrl/y1MGfOgOVCisHCHxNNr+nm68SVau0fVRW1p
3DBveC0b24yr0ZJuttdpaOnf4sktpGHXjE+YGdGnaau0nTejBuUS3hqhBTQE
DhZe6clvhtdUh16LKx9sc2eGRVg76ms27iiaoMHuHYgxNKlEy800I+Fp4k+a
Ven8thShxytl7DfScLL5j9Eb0gdr11ldM+YwSromWg3S2yEif0dKMp7C5Pye
n817K+Dyc+Rhb0k+LL5kvz4YWIobJ+JY5YTXkoobE4xwDp6F15Vt8qDBEns/
qn2xGjU6gqWZwjTMt0VD0b0ScSynHFVxPkLlju09u24Ame3JJ/dWDoF7+ZnW
No0eqIjMxBcpD+Mrm7nKq4MHi5AXzjFBw/C7VD3ueLcYGu53GE6+NFzZR+L3
pt9Ep1jElA+pD0vqm+Vo/wM0HlZxUCfxBeh/Y1KWO0J82Vk5syM02hgbO2Nc
0rHd3n9pPKnf5IpvEiPSRL8t2/sUHPnQa5TPqj5SjJJXqy95nqTB2Xy0+VHm
ceyMPscSIvZ6jIBpK/sHMD8VsP+5PeGfijTvUn+Cj98L9mVYk/jOZXV0biLY
LyX71FxpjG5PMUtWJP44DfuYVjSMu7IX1Zc+gknD+CMDkp/HVv1yt7ouiJQf
0iiq5WNJVohYiy0P3dqWHQduUzDXFV1QXlaLcMujCuxGCjHdoUPxn3shk5Om
YntsCGfuvtv5PbwWM/GRvUX+NE7YGFRwt3Sidy53/MADPjR1GfaymTy81GsI
aqumUfR49VPVyl78mP3R/xfJt0nnxdqM3zjoszeT4S2n4Ru366DDtTbclXfI
zW8dhty83acrSzuhrhlx3X9wGC7sobeK17h4IWArujKJQsNGseIRMl9sxa/c
gTOFoRxVS45hFeI0er8d0qGh0zyvrtaWigKVyT3ujjRkOooLuYaFSCp/9eaB
AI0MD8nVOXY1UKubb2KdonCjP8Cv6XICDisa/nTOhcaG3awzC0EJ0Pq0Nz+G
6KmYf6in5EQ7ItrXC3r+R+H0yZ0JvKIOGLOq1XuODKFf9rVPgslbOFQuCd6g
ReZRnHvPEflIHIhr4LwnfBSzBSUst3DhX1Gj00X6fzb1Y62RbgmyJMKsU4/R
KOVZ9zmcKUF7IITSTcl5luCtPx/noU+pPsaezFPZtm1jQU7d4FiniPueG8ai
cSkhu0QOHkwGKyU+oXD8Q1ziJ4NWKM9wX7XkUbj8Njs2dDUXoxZrulNHKYgl
7Z6If9YG1RNL/FmEH47vy+T9DtW4FCGlIE36WYsu3fGHaRr456+rLj9IY9XA
w9vn69pgW0iCsPgwOWWlVHjxCVK+KP3eQ/TY3SXuTxt8wHrmzcIAUn9X18hW
6eznEP2msGp8PeEx0jDus1Yhfv/sJuZB5slz+q03L/kRWktNb7UTnltaTaQW
/96LFEaoSOpiCh+jyq/oxlYhVDk3/WEk+X7D/d2i0224Mbxi0kmQjybn2OQV
77hwyHDyL/9B7A+lv58e6UPI4VNPJC/zkf/i9BhHtg9Fo8s/335FY02E8coG
9W646k1IH+AOQSSxZ/ZicB3M2ELNTkTvVbN7RzTmyH6oeJBs/WMY14RjAy0O
cKETOXq+QYjGl7wML3mlAfwxqqbtNjiIsbyUV9FXi/CwfnPPyDcKgnFZ2eue
8eC0pv/znioafWsrGwP21ePLb19bbltTEIjwnE+IOQabsXpXbXLfQaeVGbyQ
ElRk+vDT/iQ8Xr8w7PC9GuZFE8s2x1BoC5JXmopugN/D9Ge5pB9+0Z5vr936
Hh6RJveG5T9CzWifO0epD2JX5etKA4bBMnRUcHT0g7Ngsf9Vsi+NvdK8f8qr
wvBStXshr2loaIbID7q0Y4MV08dNjML16F8FmEc6UaXjtOPpcT6CjouWKhvW
IizWauB+ArGv/W3G6nwuDLpPHqgh/cLafbRi4YsN/DjLogxJ/lbp739ZK1iP
fomUc6cJLzui9Mv3j/ZANlH+nRS5r4OsRmDesiuI+MQc2upG9sl0b7vcx0bI
WAu84VUQ3sRrkzgqfpjsUnsjR/zV5YheneF3oFxl6uxuMm87R0+diW5pxA/P
1QISZF9acUatExIJH8HKzAtsCpsFGfPFu5rB/Hv8WdQYyU9x6cDRsJsoMVzL
jT1EI9Q9kVsm1gHls4HGpYTH53+tr04Xioda8DpTBunnvw871E6b9SN5/bH0
nlSi30rp/R+ao7BNv9Xkb3JuNTNq77+9BJopcFaIJf4u1Eb17WnFq7wC/fFN
FKIqo8Zyi/pwS5zhdj+H/D8kXswI9SpDiNUSw6/hNPycTCQsMgbgfizadDCQ
Qnf4HcfMla3g7Ku5xzpJ4X+1+6m0
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk81OkfHzl2KSorlSMlWYpyG9rmTUQtTTnK5mYpIZuKdIeSXK2S1C6J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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 28->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns81ecft36kSaTkNr9ChlhtSkR4K9cyRrPVkBDlfhk7JZeIpGG5tHJt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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHk8VO8bRQttWlAqiUglUbZk6UgLQpsWSUJE5VukkIikaJOKSmWnZI3s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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81GkbxsmGiiiHxLIVKZXjYschl0QHKlIR0TKdKCwRvdZam0OUHJeX
XimHzTGZkUNRTETGYacxxmGMmN9vImlDsbJ229/7x/N5/nj+uJ/7uq77e2+m
/+B6boWEhEQ2df5/x/90SsNNahh6ps2bBreNwUi8KPN9fDtkDUuHzpQRiM+K
C+RU8GH0+OBgm5sYanbrPn6qb8NUnHymk4BEjNPA8TRvH6RxD/B0vidhy4go
DJh6jlBJxdPW4SR+dg0+W7J2COP+K4Mt5US4mtzGGEt8AKvf/K09gkgYsT9l
hBax8fUG3+23HMSQ8A72YCTEwvxQvZKHNwk/eqRz1egANr1V3xLrIYKcmcgw
U6oLt6R/zY7XJjH8wlAmlMnBvbSuHfMmBDiHStK07BnIvFeys9CLRLXuFZtQ
s1qwj+TbLWWQ0B0lVL4K5EJmYtJSupVA8vj2fqFqK+4vWsarOpBwtaY7TRtz
wOx8smvfMwItuak+22iDkL1Ze6FgBQHP71q6yix4WHFK3t22Vowxtartd+5X
gnd+vbVhCIlKA/Z0vC0Hpmr3Iy4zSJSHq9/Yo8aHed6001YVAsHrNSV1v2lE
gvNfAfRfSMy8VdRfY1WH4jG+IwMkSstyGfLsbljcbK3TXybgk5/w8YL8Q1z9
8UBO4mkS920T39Pt+Vi9wH6yJ1iEtSY/Sc86v8RXhQHful8ikTOaEmNkM4jD
c0bWbTsIuJQm3daLrsTljI6+2FMk5AoXzJzfcHFvufNu/mESjndZLLrBCOL0
ZI3ldEj45Ky68DzzHlTTC5Pj6FQ/Su93HSsTYn/wnIaMthBPIk1ufIl7hdQj
KmddthE4q3zETIrHQ/uOZyN0yi/lDY9G7b4aQXTGj5E1wyKkusQt7fyd0uuF
pyc9VYTokzaRG94O4EfLvGvlESR0qrM0LAwYqOjxU0g3JGH58GXk0Y6X6DlB
i4/6SMDSoP6wXn8rbqztY/c4UnpN5FkpCvIRci3L/K0biaLiJL56QgscbuTN
JlJ62Suv3yMX04LAd7FxETQSIcZ/iNr+245VgktCLwkSa2YT7rfQ+6Gk/djF
r3UciW2RhQOSnfhBMU/4aJpAd8vy7myZNvzQ9+KZDKXHpwtuRRMOFegptlSi
H6Ly3cwQlZqWIjhGGBhP5cvy+PyyajsHXmu+2RzyLQG6KU9DjhwGYU/Ia4WL
UJ70+MjjY33YMBj9tKWbwHTrquz5mhEkHHs+48wUoaXeO82hjgf5m6ExamYE
vIy9qrxyuiGVrmH0z2UC8x3bdTKWGdhFK7U8aExC9mrTMEuHB8/KX9cTf4jQ
pNxY+XHVSzwPrRvSUab+W8VXOKzQj6hN+eWnvMQQvZj8IFwpgInKhG8b9S5r
9J9bq/V4SBDojDjJEvCeSQoZm2Pj5ETazJ9U3hfx257AyWp8OxgyLe9Ooknk
Uux2nAf1rQdZX95Qfp1wMJsO78PKOW8r7XMk2Im8ENcBFkwz9PekUHrHCLQi
xs7Fgxmbum6LDwnNTTPq2ZZs3DYPembKFWGpwCZy8gMHS8uLVnqjJE5K6hrR
1PkgKsqKU0hq3qdS3c83caBc0NX98JUIGYdVI4db+dAcqrw7kk9C0eTGXsne
RrxeciwvsCCR6Jz7y8aJCrTr1g6Kz5A4kP4p4HNHNXZeTF/3wY+E2qWc/KCE
bPztNGnTR+U/+LxJtOfeEjS8f39dwZNEcY0OyzDqFZS6vWUYQhIv9femaOey
oJR+Iuu3NhL3Ymo/5in24e+3xTebM8UQX1I+lPZ4ALp7E525NAIxb8ZlNKWS
0cKtChBTeVB90PzzTfkBdJCtYQN5IrxOUa3lWnEw1xEXs3mcwJjDRKeZfg/s
LmupJVD1l3ZMND6qe4WOoOSLjbWUf7JaKrtqerBJ2KAnf53EJOOs98PqQUzX
zaYLuAS2HKtMenZqCBP9IknhItW/jcC127YZLoFz4UxK/+K8FH03p25UFPid
aZ6leKauGJ2czwe/SkGXyyTgYX/788y1FBQKSoa7KJ6sLeR4bC3kAKnSjgVy
JKr0jwYlFgmR1tx+wkVODL7Owqy/Ag+blNQW3K+LYH5fXzJEsQv8qbLqdQEE
rDVpca7yfGQtHTz5HcW/yas5p5JWduBCQ81gbhoJLTOpMOmcTvxj4TbmS+X/
dNl4X5/5CF6XGsSVpVB8Y3g8quGwodnmsl+ngESUTtzl2zP9cFV6+rufFzVP
0zZPdhgLkVox6+lSNA7jMu+jvXf6ERRyxtG7UYREv4ave0eZUFvB0tpI5a3y
+YELgrwB7M4V7VOj+NJj433lwWEeCv0f1unUUfr/Fddw5XwDuNE0r6cUP4rR
OJEuy4X0u6qenkgCffW+JxrpL/BqaOLlTCiByAjPiP37HyFR+vVWGjUP2wVd
w3PWHBgw/X12+1N+rVE95rPYj3QDlWAGbRzDFjJlS2sHsGC7UfPvVBK8zw5r
fzrUiWCJIsMvFN+VLbat5rB6sK5d82J5Owmv+iC2ZFMv7r4ezlb+jto3saK0
WwZM+LJGCzMpPkctDQ8x2b9jfMvCkyElaj+EScSUL3AR8PPnlqYvBGzOjUQF
q/fhj7SrDR72YjjOTNm5vu3BQ3+FKSsZMcI4GvPOcoOYoWlWqFD9xLDs/Hen
DoG7si+iQ/MNDhmp2t+ZZ0EhmdtL/5VEd2DSRe0Oaj5rfGYeh1G8dRhd+T/P
TijsLtLYThPjwISbIGGMA2MTzXe5imLY3M1VitHohXnTCmzNEMGO65P3RLEV
RyS9rc5QPB2evl6SS+NguYTm5EP9V3lN8pWajQI0198WPBOP4ZPitepg935k
t9/hfkPpNWlfS0t50I+cA9p9/XyqfgQz09ZXiNhqx7v73ERgNmaHZTEHIC4N
c6/Tpvzc8KdU1KoKLPNjXowmUP74VHZpOfbANGG4ebGZ2och8x9sKp9i25HA
qYWnFL9Xe5cczG0HuzMgMVRKDFujufCrWbGwsz36XsWXRJyujLTT5W50N2m6
FZ+geMfufceJYMHj5j/RbptJhG2E/VRbOZwfKDs5BJJoc/0rwf2kAK7hf16q
rnyDoaOMfUJnDkpVnuoep/b9v6ldt+A=
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lGsbx51S0ZGlUMlEJSIiopWfJMkpIaFIUzg0ScryqgjH0pAllDdZ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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 29->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns0ldkfxit0G1NSU6aLW7lMmEruaR4ZJKmlmkmUxiWZUCREJSWSkqgh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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k0lA0bxpFKCElSSvaXSlGUii5LlEKWQsiaLCmlspO3jRZvi2RJyBZR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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8Vfkbx4WZRBmpjBotxl4qpMLQR5NGJVuWQvYlolAK0QwliRhFllLJ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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk4lekbx4+ijbZDzZSsZawRM9miLyojhGkkypSyhJDKUmJQktSJJLKd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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 30->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lWkb1jE0kkiFduaTLTOlOEXlEka0TTWWVERlyy7EWItKaqyNDC2y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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VG8bxhGFUEooS1FJkWxlzaVFIluEwk8U7Yu0EYpKiwqphCTZSYWy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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk4lekbx4VEm1Ep04bKOkKFyQy+NJoWKZwQlWPsWxIVSbZSOdlGkoTQ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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk8VWkcxm/GMg0ZlVI019oMQsoSbY8MZUnW0aooZY9SslWSUKRGmEi2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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 31->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk4ltkbxxEz9WpRGdllslUGCdH4+VomlaQsw4wmUdnfarS+hYnQUKiG
qVFCsk5IZMsar53XzmsddJ6KIqGJRHN+fzzXc53rPNd93+fzve/veRSPnrJx
FRIQELhNn/+/D3g65A8ttYPl6DyjwiWwU41dd0SbD+u97uKdUgyGs+7y3og8
hFZdvWuVM4HxFU5wal4/5EX3yeg+YeARmfDCoaAUDT5Vty+wCRJcit6yIyLg
HL0m1+sIQejyB2Xac3nI2tQQftydQO60us/SUi9khZ0WI60YnH5sOPJ4czbc
xvVVVY4RPD0esJ69jQsTqSYpmasEFZsSW6xNu5HUaJ9Vv47B8oVdfltOPYdm
kFKU1GkCraY8m8BzSWDLZ9+fp/VZ/vRI7v2dRnAW4wpOJxLItM14z3V345oO
ny1O8xn3R0sfOtEBvktljs0SQU4REzC5vgs+Z9s1Sul5W0nzzGXdVPC13Gus
XQgiT4WKL9a3wcubWRE+SsAfnDVSdazGMhVH+9d+BMFzrudrbbqwMeGivscn
ggDN4IvLQOOv9SsvnSaQxl9v/NPb0TktZZWSRiApf8DMOqIF6jfrxuNqCVQm
CnVeK1aiJqmrknWBoHCCVWrR3A2TAbe8SHkGhnLLfDVvtcD47vhWTfr9jjMz
DcUmrTB6x9P9poJgqlEpUOZECVRCF/oenSAQYG34bSLKHzPvmlVA+Svlvdx2
a7YWfzju1jweSfl4TPdmuQ9geJ9BSK4/g4NPwx36BR7jEzcwln+UoH2r5dod
k10wtl5RwBenPDRjWvN7KrFnUchT7BKNv1HihrRxFwbOabnUSNJ9toYa95d6
OErWtmy8Q2CrrPXt9yN9YIvtnciKZXB4Bzu5icuHpGLzw94LDLzeOoWVJzYh
IJib+i6BIDtav144+xkM7Erq0r0ISu5oLFgcb0OGWriMbC+BcNaRqyMlPKSU
yZgW0vOaRqTpukS2Q0hf/soqPoHYrsuj5cGNEKoQD3lxlyBtTHj/nXvVGJ1Z
K7IimOBmVuXJN23J4GpsKlyi/aH0bYyhHqsa0VXxqiohBJMh6y75WvdhJNbo
H937DDhlH1yHVqXC9vKWXzWp/rP32iTMmDzY/jjT0udJcNsrOXM3rwr33oo2
BvvT/PldnqwKPqS8Q0J7zBlUWhX3SMXwseZk34tSGwYJebaeb73jsKdYoMSQ
5g9tDRTo3dCJQJVyyXZBBn4ZnHyn6nZMDsgHP+IRDAcEWXHk27F+al+fajOB
iL3ZnxVHOtC3MmmV3zyBXm6sJW+U8txNhkREGAyVPV9/+m0PKkRedM2aMFB0
Zx30nOZj4yFpN9NVDLa+b7G0iGlAmeitdQdvE7wU/TQ7vdiJMmdRbQW6L6K+
a8npHz6mHgtFaR9jUDYQqSC5dgCF4ekx+84zMOKIM7k7O9HwIFP89Rda34SR
gbh5MoqSPV6YUD5xgiM+ejfbcbZx2awJnSfj9TfzmnldqBXX8xCcIrCKlZgl
tQPwvBVZ2VXNoGZhvLavuBtju+u+3NjP4OTkKw7zYxs2vlKcMyommNCSyDHm
duB7OTmZ1SwGAjZaOw5Z/YqBDfbDOrSfTQsWN7Fp/XoRPO3nsgzSdp3/Wl6s
HFviXS7N+lD9J089H5NvxVfP3nfZUp5zpjfud/ZwYWzOXj15jfZDtr/xaO4Q
akyruYW7X2JgNrfQIIULZd2xsl8Cqf8Urbx71L4XnDCZWoUzDHQMc5f7+pbj
rJ9VvT6NL9BW+7QwvAY6r+ZSLH4jcI2WevdNShO8Pn5MEIilfKzT3J92XEFP
1Zm6XbRey0ub/57X5eFwfKCC6BPKZ4qtJT9YiOXJ+v+zo/OqFNSoWDbRDI2n
TiF2j2m/tZ+TvZ72HHZqmRxD6i/Satv3VN6swsH5qubv6PqHpGlPtwQebCJz
Nt7LJbinR7Sdv7TBPdO5KH2E+uHimdS50avwXmd315bmP9jxu2Zo0d/gG3p8
6aJ6ZZd19o66FiE63K0/jc7bTiuzrB0urfht6HN3fDaBe8ifUacyKtBgH7xw
4DzBrX3by1vj++FCig2+LmSgPmJu//vKHgwLv9nq+Z6gS86y+PrrWvxlqTuV
cYP639Sd1Va99Yh0UEhriCLwP7GCFSAwCIf9l3p/Wv0SWt5JcSmbC6AuWPph
0I3A42cnqQafSkxPsvce4BAc5ysNsiJb0bDI8hDqp7wnozKg8SfsJkrm0+h5
xMc59Sp9deDomtu3htF1yqk155/1IqzJ4pq2AYOvHn6XvGt9I7pfm+UlU95W
by/vN1SvwR4hl50/B9H+GOX2zIu2g60dWhA9RzB+wqT34+1qpC07mavkS/3r
QXqRegwP3G0bFqKonrJxrpvVbnTCoerbwhPKDAzCs7wUqtMhnT2WPEV5Dm97
oL7zVQGuFUg8U/Em0A/5YGo+nQ9lwZgNJ+l9x8lVW6vMakHcL9+fc6D+L7Za
wsVEivLmc8c6qN579HOlPU73wPKKoPqYBgPL1uRDko08tN09lhqUTHmGHR2L
SGqC5+erxyyofzsn/ZtoUdWIDxlWXhY03nI/E7NNyg0o2KOvJh9N9fY6fODH
eB6UhD5EX8yg/eDaGQ3VQqgtkSwW1bsu1aNnxC8Xy3vEOUGUf07icGrE4SEc
EjETNnrOYEDo2NkcsRqMb5cdPk/v3x35Ws/0UwdQ5i6vOOvN4GbCmvoLdQUo
0Xxo+QONd27s08JHxyHcT92tIzPD4NPWwGzzzx1YmWj5N4/ybU+9yMT5cRG+
Jc1bkPJfyoyXeyrfBV55s+oAnW+tMM2JbK0/cNbkq+zrVN8v85V5Exb9yNJ4
5C/9O/WH0UExhtOOc915gRbU/yoMG086ri1GzotMsZf0f8NJqubifplipItV
OBrTeqZe1hFBTiUejiwInT1Dee3XHfARDMFDrcFpSxq/8k6d7/ZoPvr2CtiX
Ur8bDsrS4RrWQmK1THT5dQKvjgDhmsx+8MIkiYMtg2xfZX20PcGhmIL+NZRX
q5nFv5/FnkBHNZG9yZXgiMHVpHy3eug5Cipcj6N+Y319C6uSDxXZhHcTtF/+
A2K9wCk=
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8le0bP0ZRWRF6G0RISIRI6kuhlN0gyZ69hWRElFVUklLqlZASSVKy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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81dkfxskyimrSTBtlyxZjaVL2BxFFmSRZI7KVLRWRStKMiphSYxlL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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs8lGkfxieHikpMJatyWgppcyhi5aK2kp02p7RZrBXFS1IreSMUNqlE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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 32->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lekblqWE0jYqKYe0WPJrUcjkRkqjwkgok4kjWU6y01FipozhMEay
lQbZSVlK9iXLEYnjoCxNo/ebjMqSFkuT3zt/fNd3vdfzfe/73Pdz3/er5Hje
8oyoiIhIPH3+e//tnzkzZtYJiUGt2Q81BM8KPqtHeXUh7q11aulrgqhvMif+
mOqB7+LCpeXyDFLZ018tdgthphYRNKbIQCRXmeu83R8qF4WROj8SeE5VqZVI
CaFry0u9NUhws0R2JlY8CXEKdQ6j/9VP6NsulK6EtNK6rcUcAuuB8eQT7Kdw
NZ/wsy4jSDUeTV6hVYsO54B7LE8CK8M28ni+Godm3noEexCIfKybXO3sg3bt
6ow9dL92Vt24zAIB4mqVHbtqCZSiT47uE3+G6E9JdnvVGCSe13oXm8NH3FP9
x0ExBAe1BgdrbvbB+4WbU/U+BoPDLyu0WPV48z85RZkAin9L2j+uNg0Y+Td1
xb9BBBdNOX25gjpsvGzW6U/7yTFKcJHgFEPuvrP3t84EDw615Oa4dmGVMK8x
oY7gpZFKgkLAFXyIsHv/He0vuMpVJ/CnDkwG3pfyTiN4w7f+OPm0FBo97OOL
zhLYJoeslfrah/11i8QkFzNotJX0TkuvR7K+T3827Se8NOKIhHErJG+xDxvw
CIwTiUqAnxCcVzEcV0KQxVmummH/DKbVzxDqwCBGX/7NFK8HXRUlUU+UGTi3
6fjKWj7Hh4nSefYtBuJOXL6r/H3I2J2t+EzPz8laPMC70YENs1t2514jKN6g
2JAlrIP9+ZKMW/4EXxwG3LNqm3HB6M3RyXCChek55WfutcNoaoOv8AbBi8gE
Enm+H5rW8i2sTQwM5H/gu7fxkOeayXWn+HWYcx769pUI/zw6N+dGMG0zW2m0
vBlWuRIVBVcINNJtKoe+lOGE8cGQXlcCb4tiTr9/I5LdNBsXcAkUP+5c4zD+
HNtF+UYfrRj8Vc2zZh/rhPNYtLlqE8G4cfLQhPoQ2vXXtEo0Mnj5NtfC89wj
PFYfnVEOJrgSxXrob18GEb9jA1y6v057/t77pgKMbXbI4XUTHPFMnHDSfgDR
2FWCSy4EMbdXKh0OLEJzzGTEVieCQ25DI1lnBIgocsyYHSYoNEiJTp/uRWd6
76UWSQaS69UxFtQFqVUjQZ/4BD+zao3NzbrxWsd0g/Y0Ad8qwJfdmA2NnL9U
ZhyofmV2aghdGjGVozoVE0LguC7/cH1hJ6qV8oXNmQS/fCNblV8nwC6z7LMN
CxjwLtkJLc+2YKrN0c+V8m97TFftQUcVGnLNX8VTPoPfD4R2p9VB/Grx+EJv
grZXWRK79RqRzpUWbP2J6pm5khBQXgXNmSVmEecJLP7qKHnwugwvMGcwR/F6
Hh/wi9euheS3JYqKtM6X3/yR3/UYcgW9EYgn8BXvHIzu6cNpez+f/V4MRlql
ObreZVDIvnbgKOWTdT9+41duDeZ951Y0+RDUrOI+NDblQ5VfssmV+i1MJiP3
YK4Amb8F/5j/is7/UOUO/79LoZYYEnGL6k+lOLHOY38RVHLePI+kfCe2krGZ
j80oLfJzMaf8WFx75yQmiMRCMXYam+qJNa3Jfvg+FpeNvgkIp+vpljOtJhMt
UOPXm7tfpv5bzUuyqGoCf77LdPgiwcQRk8pfdDrAkj+otq+SQEzdV6Zu+3P4
Bx+UlmAxeDsyNxrq1Yw1prkP/MII7Nc1K9z+vQfakjbzt1YyUJbQ1PlTchBW
CRcWKesw8N5yY9iruBsf1n+ffWCOwIyot7qy6tB5bdbqH5pnjhV3zH4ZbUbS
opMrwmMJbj93YDdx+ejSPbXidRLtz9rNr0GtBdFHqw+JUnwL9dwdA5NaEbLv
Qn1oCvX73LYtn4524ad8A7OUBgL/0Mm7V7qeQvmdg+VxWnf4ciXGkzuIY6qn
jp8KZPDwTye5nTHFKNxs5GJC86iyojVb7d86pCtwhTVetB/xOeuUtF64aFXY
2VkwkNE7vaT78FMMeTaVDD2gend8FdwwmQe1dtnwOKpPoymlZesOV0Iq3st0
L83bbY/EP62X6kPintXS1eoM+FMi21R2VWAm/MVujXME37qpe9tlNuNY/AJW
SDQBjcDBG5WhMGge3nmAzmdp+O3RjBDqn7cSJcVCglMFag0rD7RBqU104vpV
gtIy8dEIkSdwN/gi/etdqsfwhTEcUo57yVXLxSifPZv22+gte4aRm+peyw0p
/1u3XMzo64ZF3nWdBikGBQLJzMb+Xsx6aOzqVmWQLbWt16qiB6KbHvXKiTII
12U7RGoPYpC3bbH+YwY7i6Y8uYolyOswFOumeguvzi0/pjmI+F9nLbLzGcjp
KlUUD/chhcNWy1RgcN3f65OedCPaJZZqjf9MILB8dEm6qQ2al8MKU25T/Kfl
IhrlBOAsN0n42knnJfqd7frNfbjZxLEbYuh9k/7GsMi6F82btP9MmKXfG+pi
XOQprgWXH4gqp/6d6OiXO9qOI2tzj78vpWs9w8zr+p3wG0itKSgg2J6/ZW4+
qA9nLq9MtLVkkBFKfhh70g2FP+I994hT/Qp3uN5N6cHMBZnVWmsYVI3PRmk6
16J1KXOqkvp5+2XHFPsnHfiaYiKXSvd//EqkQ2O9ED7bNT7vukPw/pKT7/7b
fFhpngjTpfn/8KTRuOFKAXbqfx7aR/0asqy+NuztXdxs6XJLYhOcDtDKbvS4
g0+sxff06VpGtnDCZmM79vL8txbkE0TbpVRqiwog1uBb9p2A5slIdE3/nRbw
gmJruyMJqpZeVRj2b4GPaxrHJ45ANJxrooMu7MhcnxpG73/P8zpDf8j3o9CZ
dW2Y4vUti0oVffkEuWvr9f6h92dMhuLi/btrIHu9yNeT4hMp2NPhbHsSUpzC
jTuo3pZJu//I3OyEk/86+yUvCSzfWSUkyDSjXRC4bA3No3uBi9wMpVrhssRB
34Tm20vT742U1sVh2lxGK5n+X1Cz9v45mu8mmWEh0GeQ9ztP1qNbCJE9e2IP
jVO9bL36xWpRPyKe1Mpl/8ZAIat/xmbjIPLmQzknuQxOn+lU0lnbjEbVtos8
et7/ARBFteM=
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k0VW8XRoUoCUWGlBTpVymlCA8VSQMhhQYRqSREZMhQSTQgJGTOUEim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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk4ltkfxiVCaJEQpVCmJEsKQ9ylIkOjka3JVhgukshSaCERkVDCYCLp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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lXkbxlFJKMtY8tYpZFCq1zKacI6rN7vUlDXRKAYRlaxTtohXKhlN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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 33->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lekbx1Eik8LIUvJDyTFIVFJTvkSoMZJJNTnZ18audNGmSWKYLGGO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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k0FX8fFqUiJVla6KfNliRtKB5JqFSKJCTZi1BJKiEkRIRKIip7yE6W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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlns41Nkfx10jpdyy5bLYdiu7KmxE0tstdt0KXRQpQiWbFiu1iXLXZV2K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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lWkfxk9arEkmUVlrRsgpypwsk6skQhpjKd42cYRIKglR0pmcwdvI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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 34->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkbPyolS0TfJC0jocRIi1LJj0bLaBpKU7ayz9jiDE4Kg1QmJKaQ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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lA0bxSUVIkuvsrTInhStVDhEpV57soUklSVJRBFpkZIkSVIhCWVp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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk8ldkbv4kQyjIGiQnllxhakIgvUVTWyRIpzKSiIjW3hEqKMLZspUwo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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns4lOkbVvkpsdUuihxWJSs5n5V1kw5TQsiabE6hsh1QtDoocly0jtvK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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 35->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs8lGkbnlRSKvYTq3JIByWrjSmrwmWaioYvomTLOlUqOaSECjl0IGpJ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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k4VG8fpiRbUVESUaSiohBFbrRZWmQpWuQvhCTtqBCihYhQIrKlKJKy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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk8lWkbVkJqsmV8SM1RiWxRDF+qyzYqES0YYkhCKkvKUjT2JFkiyjJh
KntFUlly7I712I5jz3nfY6lTiFQm0/d+fzy/54/7We77uq/ruuWdvY6fXc3H
x5dCrf/vTayOoFTXXhxcUJPcZsKBS6XFJ2eNVkic3Zg0cZ5EkDyZz/iches+
wvvTzUmYl8znHfnQi4+0qdtRghy0O6m0n/q7HtHlHjn5AiQW82TOs260AEHF
5Sw6F0mtLo7nwzpRtyq6reYSgbxdEznM1S1YzBzqOjpFQDKlTPCHTQPqSx/V
VQwTyM69ofTYpwm87tdMWQ8Ccz9/74+JYyFKhqnuGsTFWtlKy6jhVugFfd2V
8o6KPzzRX5FeCn3RDXNOILHZYOGDul4P2FLyDf/Uc3Bvuo3vw0w/tPVMeRmf
ObBLM0svCmfgzd0LdfRQEt9eKwol0rrB9vp+SOYuAf8zl+YtlPrwwrYxq9lu
AkyTki7ahw74DeVfXLlHwmdS2r76YzcaPvVuSQkmsHZFAUrHalChLc4Xf4wE
s/6+eqpQHe73Zac9ekfi5BKvovgsHZtUdX6ujyOx2tq0PJjXD/3ynM+8TyQE
fnSknR4bgLGOPyNaj4ssE+KKqG87hCKe3KATJPgU/rwcOu0PEdG8WXFHEp6v
WAEJN3sxX7o/s+QVF/Sn4ucumYyge/2O6djZcUjLya3pMxyEwkyMa8sgBwmh
UuVOMXW4Pndc3HcvCdVzPWMJehVQ8mNNm/9O4q1LdtO5GgYYmn87JnIJ8Ikp
Vt7k94a1/K6fbKj/dETVjwi9ZsHKR/JuyQMCrYx/DU9l96Np3S+LMje4GOFK
aV1wHsJ73YntnpjEod23s6qr2PC4upjFXuDgK42pvMc5CzZLKt63bUhYGY6G
CPuxMZx9ZUpz7wRU5VWDUr+NQtbafbq9dhLuv+mEWvOXw27MQPjfIBKxt08O
JKo2ItaXdbHImcL3cuvtdU5sNB0QG//nKoFnse/uxI2XY3uR7pBhMokKEb0S
r5VulEux3tWe4iDJUTA9UqcW3ZuCt4yrkZh2sze6mvQcWxNeHyk8Sb2Xcu58
8ZEncDjUIsp1JVHby1DQ3leLIRmN08JGJLxjijXGip9B6uGO52+p/GVfb94n
Ld4L5Y5Z+qdILnhbZXLrRTph2rkksceEgH1h5qrTVWOwFRgR2KnPhZmbyx+3
VOqxb3vVxIs9JCS3rf/xxncYuhlqg54lBKafVaqmv2/G0mfBQUSRcP0lzUP4
KBO0TUPHc6dJ7FI+ZS74vg0k40dcQQSBT3nH9mvL9EFk2+nKX6l8CztZZSuB
dEzP+4V7lRFgV3R5p/RVgJbxWFr7AgktIckdVUrFqAo/3SnhRMJJIkk1baAd
ZtbhzqFvObgjZjn59M4gVFexlGwKqHzCFBPP3xtAWIzMnxvEJnFXRJhfndJD
8v2F8r1rONC6YtiW/20EC7NRmR0OExDzfKnSZtGCo9Hbm74Yk/BwS/zcJTWC
Kl2/0QPrCbhiPcl5w4bXkTSz/1J8P7Qq9uuxR6/QqvfesoHiH/OVV1llSCEu
RSNo4CiJ6/G0o/zoxk8Xpb9OaFH4j2bSaX01CPIKvc8SJGF8JtU817AR7orD
kr+LUPd1OnTcrWsxXkLPLztM8TmvOmJ1dyoSdsfveHiGREC7w/PYrm6ov5aX
eHmNC79tBVaa40yI5ZgO39jKgZi44LjnTjpu2inVgEHxR6tho8uqbvAaD4ck
vSWw5efSlhCbfqxNv8m+ak+CJ7DzIH2wDqN8T/dX7yJhwH4jsj+fjTXafU6r
N3CwUP3k+xpuJ07omi8GguKntumfG+MZODgeHCgzxIV+UnKp2qleOI73KrEV
uEhOfrqLNkHH9sx4Kc8XJMpNpcLOcPrBYtW9UvtIwOkxuax/tAjyc5vPVFqR
yEnefYi5k41rwZYn7ZMoPAWz3vOWBzElEJbbRunD6WXByr4LfWAevPbtBo2A
YfykvocHFbeoXfiVNoECM4syPd4AHH1TGqsjKL935u/b9G87ouY2dOfKcBHh
07IoHFIPsx0re4Lfkshdv7jN1LgSzbVWblPWJLKCzIb8NnXAYn5m1v4AF5bK
LwrO6mcjZuNerQZKH02Xc4p2PqhF2CM9UaN9JEJManqMEu9iSP2m5E9UP95a
V+5xftAFpXaJwSenuNA66zr7m3Q3rB9Oso/MkfjnvkrTVYM+RGbKZsTPcbDm
TJV/tnsTDGJse2dSCfS1FJ2WdGvEd7nQqJwOEnkqVpbPnjHwK/vw5oOBXDhm
2/PlnKyFrhFjo+0igbhI29kE9zTcsY787Hic4ouekONJxiguLy8H5rWOQUxx
5XukZhmI1EQpgvLvv7wbhNZfb4NsX5qsBeXvlbd9DsfM9iLIzlb8ywQHThqS
ms2aEdg9aJ9a+wcJOuNangrxEvd2dNXPXyURMeXaLL1Ih5BkqXEzjcTxvDcP
gmi9cDFU/c+tJRIsPWPrN3llyJAZaDohS8LObuF7ncdLOMyUdgSok4j252Vo
SLTA0rCZNkPNMxebqBOii3XwsKtWdO8jEZXgGfclnAWR+eDCA1R9tHPHo5Qf
PEHbpoOP3HVJHHBXLH5l0I0nzNwX6/xJPNQ16hC/2AsLe8mynfxchF0Pen5l
XQ9mQ0w+OgQQEIstHPjqdR8tJu+XM2yp/vTUhcqF5sK9IT5QTp/il+tFzXDv
OphJzqsN1VJ+4mLEGbjQDhGNP5wHQggsDtaoJyk0Qklw6/B/m6h5+FzEtR2N
KMscmXKLJLFyacutb3YNKDW+lebKT6JTM1p925YeaMj52C6OcWCtx2OEuTSg
91pybAyPQIW3QKcBhwHX9Mbl8i8cBET60/OdhkF+0K2mz1D9V7ZXtU9tAy9V
Tr4ylgCPqzNeHdmIhtV1UtUUXmKl4SXEhwr85VBZBMpPQi5PtStci0RAtHD9
tAPl/+9enp081I2mgowviZSeK2Y4DybjmJAqrOiffkFgTf2kh3kEEyc+OZvX
fCOx1s03sXhjE3qWuwKTE0hsDYm8p7aPieglUfd3IwQCBhMeP1yqwYJVmPJX
Ier8qFaqr+QAti8nVPE/JvA/7iLH9Q==
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81Wkbxg9NKkwknRbNvCLLyEjLKFqukq2SZCqplJGtkCUVGi+iJiUZ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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 36->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns8lNkfx9W2UoukJVvUxEZa5bXZXxfb9hG6sEhFURi5bG0o93QhkUiU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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8Vf8fxyUrMsK3kigyGpSQFb0osyhpiBCSNJTRkFIyUpJIyaqkyMxo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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwdlns4lGkfx4cURejgUCtRORVLRJls30pHUdSgrSkiUeml3ZLtKKdaciqJ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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk8lWkbRqHlUD4jUkSIRknkU5QLY8kW6lCTfY1GoSFtluxLSWWksSRF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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 37->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lWkfx1ERmsSLiWQQES2S0qbvlUmDqBkpKkX2SrY0tkZKi9ceQods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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lG0bxkWLVKK88aJFRYgSpUnqVCQVKktECaEsRSVJSGUf6SVKSmSL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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41dkfx2Vs0UhUI/wwlCRJE36i5k1lSZGkbNGQIjHJmjKlbCUToUW/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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns01VkfxuUSJYqSpHIJkzQSGmLqEamJIWOkRiqSS+5iyuRMcUbCIG8d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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 38->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lWkfliUyg1TWKWnzhZo2xUd1nzJCfSoVGppOhGQrUio+ZCsZ66RF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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWGlcTH0bnnZSpHq0kXhKiyKyRHElSZKEkLSgIgpRlArRIlFCkhRFmyTt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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41Gsbx0kLoqMiZUuWNkvUkd03DtLJViJapLK0p5IQh7QhkuXgLRVC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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns8lGkbx9naVikxK1uiiCKylJRS/STkUDoQrUMSpZySTrI6qGikZIk2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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 39->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8Vmkfxi1RI4lJvK0iIxMZ1ZDGcj2GqRReSyXSiMqUJULWFyFbI6PE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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHk4VG8bVkmRiiJpHVIkydaG3JJkq2zRIhWJQpZKElmS5Ue0SkkkW3ZC
KckydsNgjBlkmzNjbSNFie98f831XnOuZ673Ofc6UrauZvbz+fj4bObx8f3/
0+sSpevFwmIUyTqMp0cRYNtukjAq6IT7yNVtQWeZEDNuKZLZXIbSaU85hgyB
6hmH+wvj6JARlH/YVsLBgFZ0kR5fB4z5Ps6jrh5EU9dm9arZFpQophZFGg1i
Ns/AR222FTaRrCoRLQJ85d9iNWQ+4Verp2PpcS7u6e/a4bkyDwofVmd03COw
WD1l2dehFvyTO/byxy4eDDe8+Smh3Ilnp9wT57czYMO+pWYU2A67irktu04N
4G9h3NAzlQ5QxG3K25q44PF9ONupW46qHyW6RQQHEgenBdxMmTh9cOTNiEw/
3LQtZjtp76BnVfBL4CkHoaX37xJWjRA3WSGgfoSDmQLv55zzdRjvjfSI0uIg
xexM3QqvIqyjXNzo4k5AZm+IesaSLvz4INAjG92H71bRmy+7teHPl7AKy2ou
xHa+9jOvZKE2Sl+dIjKAggj1nRvDGZD6lkNLLCAQWtYrOOpcimdJC1rD7bko
+3rkqYplFeTWnYyJWMkFS+K/PR/PJMPP45/VqCGBSw+btE3NK/GzcXdnVh2B
1XvO3lJreIP2gze0lh4hMJTV1PxaNw/WW7pGxb5zYHq1Uzhdh4Hf/yw1evMI
1NF2FpyoYoHPx3hP76UhmB6WPqzxrAP2l18La/p24eWnbO5JgS74RgmaiEpx
YHJZZ//wyRSotzHP5G8hUHK1V77vXzUyslsyGyc5+D61pMiLXgRJjY8aat4E
tE9Xj4xPZWDpx6S9KuQ59SDl2bIkFvqOWTzs9u5BX+NNN2mPUsQ1CjiK/CZg
ptXxT/59Gx6zli342DKAiMm6DyFjZXik1le2qILAlJ6BtERgJb7OC48wW8iF
c5772e6jdPiZ3KoVn9ePhN7AsFW/02Bo1HthxJL8/SYfR5p5BBxVXGyv2BFo
HFcvD1JloHjf9eDj/UOgCv/+bjXXBoXcD/IHpIbAp/Zyp0R8C8bXz+vb1UNg
T99/7x91NcPGduUkN4QHRrIBf60LFfX5zeKNSgSUJyzyl2d3I/hNyw/dpB4k
rJn28N1bBrXJVuGQSg6kX9yJ4bLb0bqgKvylOXm/0S91f6Qr0dAuflZ9Hg/6
R4wO+a2th4PLJx9ZLwI3i0ZW2ERUIPSE1pIRGhcJ8W/DigszsXis5DJDh0Ba
7y3Giwg2FLz61hfJcjEWsH3rZvtatF4LW133kcAye4Uv2uLvQdEI9vYg8ZHw
+/TM8sl4NNXkJpibEpDtfOGS0cRGuu+eOD5ZAh77zkRz7BgIkucNadO74DYi
qHc/NhfvHOdPRUsRqA38q5b1jga30nTFVdoDeNfzT7T4K4l3lwvy/dMc6Auf
XlRjWYpI9xZLKpMDhWtBSvG/2qBSp95tFjwMffoPjpEuFcsVIuaqyXn5zUM5
Q63lMHyxOiK/jQN6iJg/37zPkPNmTRxLIfE/prd/qVweFtdZXvJzIfDMeRvX
6GwHjhiZJGdEtCNO7bCz3INWWD4sEo3Q7ccKIXrBoFwDIvTeDE+Q8/nsX6rU
6vliujVga9U5Ag9adNNr/2PB8uvG5dKqg3D+QvVbiiZ4rM+scF8+iN2CEkJV
aR24WnJ0C0HeR25ETZryvgBWkkW96oEE6HP+lYoTQaCq7Q8JOUPuvwT5ClvS
YbbaRi4gg8BfTztLwVNM2HpVEc7ze7F1xWNarBYTM4tmTeMnBlBz6Yb5lv4O
CAuLhl55NYjcAuntJec+4XP3Jb1iko8+ZgNCmqSeHdb9rpAWw4NShdW/qaWl
WLjnbt+89QS6R6qiC2+woFFY8mH2/BDyXrBXP/Gtg9Mv198rv3BASf4xe4KR
BZlXI4IC4QR0pdnj1IoPKDNfm1LGJXA2g9/1AZUJrbVdLp41/ci9si175Ydc
OAgME78uEDhesobDyKQjO+da/5HHXFgon5yxMGyBDb3D+3MhD331d77/21gL
a3eer0MhB8ZezIn2e/UoPfPP4RGHg8iMIspIZzESvVKzvbcT6Iv34/hSmNio
u/ztN61BEodV04YqMSjbLBJnRurj3msXDHolGqDmtkaGKsyFmk9y9OOkdvxp
7DAZLiP3e0J5zNMzF0IP0+y1KQQqvFTTVP3r8f0WN+y3IQc6K0NeLSqjQytt
yn5Sg4OpqNPCCkEM/GX+kLT43Y/jYn9eq3+jY6tTk4RSwwDKymbePxWuhUDD
8Kv6fwT+2xrhk+DbAgvzQJM6x0GEUg4fVLNPx+i9vxdukniRu+U32x5QQ+7P
nH5pjAvqKvETlyuZGN/ufF+qpRvOyinKIw2v8UncONnOlYD6izlK7ZlarNox
vfIem0CpevD3o231SDrj3bVIl4M+2cpk/stVsHCs1jnRzMGa4gChjmVV2JNr
d1RqMRei2k//PpppwpoD3p/u1Q2CnaBFi9nWiYWn5xy92Fxcll2mcJ1VCZkL
DQIh5Pt+Xrpfem1YHS6LxGWc/saBmF3LCr/NLTBwuftQrXEIBe2fz8nXVMIq
cZ96/F4OcgN7pPZrF2LLpAR161rSn4QzDj2tqUbpzjdsbz4C368lqx7/lI0l
D48apjoQMDEX4nPVzMPhw/NWvk0i+ed18VsSwQSfxuvl4XMEmgIvuxWJdmMo
Urmn8uYAQvevcwvUyEeFvGNyynsCYfQLdVcodESWMXkqKhxoPbG7l50dhXrd
2aJf5Hz94sndvbxKJPk+GLZeSN5nsZOMmS8b0TNU75UaPJwVWlVIdWejvkCc
A98hxFlnl2uu68DlJNEP7jwutGMpDXM+HVBPUZ3+I04+T5mSz618Bto7vZDq
iyRfQxxN/ba24tsTh0XnpAagp8DncU6HiRhbamvsSgIUkQqaeUYKtA7z2z22
IuD2bWOYV2saIpMdHkkfIuATzhchmUNDpA8l7Ad3AL3vH0hEz5YjO6hQguHI
RWaeWJPNgSyIJe/IyBEj4CtQzN+1phWrJYSKTdqHoGl0/+GTundQtBVTDXQk
wDply7DMosPpuf+Ft0dJfao/9/GuXxt+Nmyry4oi8Tm2W7FRngFeofevxPYB
1C7nV9wgWQTn4tNcIRL/+oGj84Z9CpHdxrxt/pL0o4/GroUJrah/uslQ5yp5
LjGbt8qrHfZSkSkn9Uh/8u+PTdVsB4ux2IhvhtSH5zRnqXKSL9vs3MoP8KA5
ejHgN7sBM30rNBaTeKiNyvlU+a0M9LGGtt5fHDiOyby2SXkPzWfxCqL7CSjx
V7rrRjKw9n2syLnbg9BUDjQrKqYiquasKKRJfBYUytboN8HSWG5suRnpRwfr
Xnc356LXv1hpew8HBIs/X1S/HvY0TyGaAhebZ/Blwd9KaAefabRMJZAZ9DPi
kQENwhQ/S2bvAM676G1MFKdD2iBqR1k06Z/rLa9f3fcZ1RJWwxt7uAjSW9UZ
9rMDiVv0cxSPD+G77s6xHfvYuH8z+e/HnT1glZ97YuFSh6zdW85W6Q9gmZrE
mjDLFqydsy27fZsH+mP57umUMux1TYmyf0Xihavf2mpChfT07ZFCTS5yQtZ0
DxY2Qk96yWJ6JgfvRoSz3kx1gpaz4tTKuV7cPB7Mb/+pDZtm4gaO0Dg47vLI
YOZWOvgo2VNUTwL3h887dDayoBdHW/jCfwhrOg64MwLrERdEpI3e40LzWnyW
JJl/vnfGpSQcHwRf9eMuFTc6lhGah4y5HHiWZmhdOFOBJ6ntqt4kX1hNtXsX
MNLg2H5TNYb088CwC27n5qg4LP/xoeBBLiL1xsq2xbRjwSgz9Py6Hmhfatqt
zKJDgLlu1/W0QRyjq+wKE2ajdKWxrOvkCBI7emLVHnQgKMJINMSVi5NDg5Sv
oomYrytz9eYuAiP+AWqHijtQ2njD52I9D0OiKenGjz/iC/Vuqh6Zvwv8K5R3
VjbAOebNq+f9XCyWOODHz6mCdsXGEk2yHxysa9dZ2tUGxvnTPu62/bBjjO0+
V8rGeSr3R4TMAPpaQ45GWaShLPPW4wx9Aq9/+1KC+ZjwDHboyzk2iGVPRcqN
jeqg/OftFUKWB1urzdyuS0wwn9Rm3ucNAQPsJ6P3WShdYq3IYA/C/9+YxIn7
oVDa/a2VdoLkQ0Wq9qXwWmyzSd3WkctBjMtCT+udtei0dnU7LspFTNBdv9cX
mDDTHw5fak/i30/JOz+3EpcXVep8XcFByUTB3mT+Bjh+anh95RQPMduLylMf
lqKI9UWT6cmF/7cNnR82siAy7UY3Ne9CROeYh1IxDUEV0zsqSD7UatH4MiLu
IEVRfLWhNYF1I2Ie20h+frhvWrn/4BBKG+RX2lswEWnx3FSZTs5babxttq0V
wXPit3gKA6AoVR1PzmiHvsUmj4BQLjzDJaRsikvx/WwC7UEoeR8P5U+3A1Pg
JlmdMuNM4N7TVHHnG50Qmd8vdyBoEKuHhDto89rhHXFkidhgP4JrlnwgpN4i
Xbk32eA2gcqp4NaJlApQdxRQFpP5vVOqfp3RCAtyBhckQiNGQZ/oC3ZhvETF
QbGcQh8CK2yt+GoUqZj102ZSKBwI+xfKLBZqA+Ec0K4rNAiTWDk/7VQqkiS7
d1wn80r5pQmtrwt6cbv6l8qgbB/iDiVUCEiyUNKREx9kxIX1++aL+x6VIaFD
Xk/7CgHjvtWCqYoMKMVdWd5o2g/Nvh/OmaPl5HvzecWUJPNrmUmQ4faneGe0
wmyzG5lfseCU1ZJ2OJ/Ps3a9Rerpxy+6gmBi/kL+nGExLvimzI5N99DBs1yf
dvIkgT+Bk9OvX7FwjaHPjVzEgZfhIf5dC2lIu+3DVz3BxekZ69+MmBbErI6S
PEzqzy72aepFJgPvZm4d6iP7552hH9ezxrthPHTWo9ZwGJzuHfx/H39GYj06
Vixg4ezTjjPhA69hOc9d3YrMUx5jc6xy9Tas3UBddn3ZILwik/NSBplYbPjv
yKWbHNT+C5a6Y56LqzYW79U+kf1EOfPkg8RmpMePZd1T48Df/aB+SnQAaKrm
4zI2ZL7YZn8il9FG6mrPeVWS/36M9K6ehHaoLF3ktIbMmZm3soS6dMpBVX9p
rx1H5iHH5t3lsm0wPF+94N7FIcixlQvNzrVg5Mn1K1dnuTDuelf0j78DBp2G
758sHEPuvfjAfOVorFcq3AlyX1yzE/pdzzsQ3SDv/jCb1J9+qul79U9wWsQv
eHQ1ue+dicnSh3rRaC027praALvm3tlc71oomo6aFfQNYK78WDrTuQ0pyZm3
TUl8xbhZ8e5ot8Po2MNJG1HyfgKdGuV6qTjKGswoJ/vZccH1PAteC+SvStsm
8HMxVLlEaCL8HZRWB2yYJftEvsT8M/1EE2TrVuxduIGD1PHw9ZsVy3GMzzkr
lvQrkYgfM7SJTIipS1U0k/mNIh+gn1PQiC9JahdOqRCIuy14QX2gB4/GClXV
SV41mjzo/KZcjwehk61rXXhgLqNLHjKpxL70iA6TtVz8NN5TUbqvDd1jwp+F
yb4qMipxwi+tGcPKUXbX7hKY0beQDLFtgb+Skvxzq0GUVcx1pVlEYHWtn+59
sl8erzd+QD3aDPq3rX+WCAzCONpnw+8Bcj/Sg/12W3ik7l836VxahUTJ4o2u
hlw8fxuRWRRfjNC72YMUIS5M7J2z1iU2gDoSYzBL50HEQUjg6ON6uBqqCi8l
83x+7N7Zy+8YECp6GbhswQCcdbh778xnQk0k3VkhmYP/6j5+WrebDmunLe52
+v2Y+vViyrS4AOkLvjv4kXnh0WIJw/icLjCee27W8yDzsETRj6tOTHCZm/xm
vvaDKTjxZ9apA3LRBncDZXqx/f7MLgWyL56PuNHa3d8Pt+0jZQ9mkrCqhioY
doD0A+efYxfq6rDe9LOsFtmH9yZMO71vY2B3eZnYFnJ/An+vuFTdY+Iqn1OA
LZnvPdg/KLMOTTj0Q97omSUXL9wVMyilrXAfb/Rk8wYgaOwil763BjbvYv7l
befiVtjFO1p7CmF9Wf3vCNmfH/j/3bf8aSeuhe7RwK0+vHsYRN20kYrReFrs
WhcO2XdaddbPZkCvMcXX/BTpR+l+g3WOXdgwzo5Wd+3DvcklROd4OYj5Rmz2
QgLjzlkNdx9T0TjZ3v/7K7lfFdmME/FVSHBucFX+TX4vLhOjuusTYuixVtUH
uBCii6YkaJVhk/LzIqsmMi+zCZ+kq2nw7zt1+tkxAvwORV6rdjYh+Ivm1ad7
eWBpRBzaGFEOtd1ca19y32Mauv+te1WJY2XR7vluXEx9jz0yl5SLbicdsK4T
kLdsNhc3bUCs01jonBn5vJhmnKpFMw7ybu2xNeHB0FVlucYkyff/OncsJPPV
npc9dfqP8+G9YDgktJXA8/AWdnR4DQbkXituCeSAf2OKiKp2C0rAM70TRerP
ilyj7uYyUDyadDK/ctD4QcUq5+97fH3cMio38f//s0oDIptqcKVJQZLsXNDO
uPHBx56G+QbP2Up7CRiqiE8l8Doh62FTSDMZAv1PQUyqEwtjR4+FPVk/CMX+
s86cP2/R/bzy7dQeki9HpNWerPuMpFbPmrckvvcUx1ouFCX7aV613LF4kl8P
ZPVN9xejInIJf0UVB9Y/acxFF1mIZGjN5sX1gu/4+nzqkTL4n7qyp28ROc/x
aOpJhTqYWJaHd6twUXbydAahVwj/6qI1reT+guyVjljKMHBXg6gyvDuEknCP
2NOX27H/WTCzgTsEgcsNvbBpw+xuhaVaj0h9Tbh+ytqVgcDZ+lGrG//30z8n
z1/JQaeaT95F8qzDcLKfdmiB9rHxBXZkXuY4LXM9X1WFb/UCBSZPOEjPl0ls
utqNl0VNy7MFyLMKm7dpeRfMsiiJ8Qv6seuY5HmnJWzoxD85PxxM5sVqFfs1
qkwc/TK27cwuHkKvPVhKuZOCIbndurfJPKRzxsDiL4uJ71Hhk/k1XQg44b74
wDwavK5v9C4SJPm7O4UpYl2NApWdclQfLqQmDYor29hQD43KuzjeiWrvpfZy
rnTI2QS75q3nIEHy9wnbnkSM+9/tWEfmSedrZ9QkhemYCLhI5Alw8T9bYBW8

                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81NkfxkdJraxiU7OUe4baCiuF6pFYCpnSCpUsJUmhi7Vu65a0sbQJ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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4lesaxonMJDILUYatRCObuot2liHZR0Wl7GMjlKGSpDJ0sJMIUWTY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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 40->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkbPyEkohiUNdNGWZqRlPQrmZZv0ldGkpCyjISk5pTkkBZEY+gb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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VH8fhkdJChFZSkkhRZakBeWhpLL8qFDZQpJ9T0pJJamQRKmQJFvI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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk4lXkfxo/BRKLGjKbSkWQsvWPJUspy06QkNcfWSJKtJmuUNuuZGWS8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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk8lfkbRVmTlAhpE24icjOpqGPI0iQuGSXZCaWoRFnKVmYUGQwSY63J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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 41->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4ldkbRW6VSlKJ5JI7aVyipFlMmokuKCSJySA1pSYlybiMw2gol5Qw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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lOsbx5FTkjoloZIjUYOU5MgS30qh1XqKDrKVJaJQsmRXNIU6lESy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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk4lekbx0+ylExIEVH2yDJmMgmZL6UiynJJ9i1Lq6TQHpKfkJEwZUsr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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lekbxiUjWhBqikyobCNjylYmV0iWEuVnp8XYSqFIi5ThGCN7stRB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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 42->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8ldkfx5EiJYpiqKjkZ0SSaMF8ME2ENPWTJS2ye5WyTyW5ZMmdpMWY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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VH8bxiVKCllKIclS0iZKpNy0SErJTkiSlEIl/OwtZGmVhCiVkCRJ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlWk81dkfx5mrspRU4lqzTZaZlglpmfFRCdlFi8LIUqKGRBhCKWTKXmmS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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk41GsbljpSls5JiE7FyZJsHcmZfOkmEUeRwsxniY5ikkpKFFFxbG2c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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 43->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8ldkfx40Kc2vIMq2yJRlNlpnmosWnUJpKUUIoWyRTWULqhyRRSZHl
1RQxdpEsWVKR7eIm99qvXXUeIxojS0WW35k/ntfzOq/XOc/5ns/3/fmcR9HB
7bCTsJCQUCx9/nsHvVPRnMwPxLkJpyMGtgT8ihNVV0IqIfzyL5mLlwgC9YyP
ZgmakG11SfzyMwKXH6XPBotXQ23d+doGT4KdUp8iTn7ywYWd3ra6dP3d6KQA
HbEOrLljxB08xGBIRn/MVLYWYXoiy7iRBE99nrEPaVaDN2n2zuUawcGrrL0X
3SoxO+v1NOIiQZDarZYHU5V453vtoWMgwW5Jw6S+oRrIdZ1PrLhB61slnvKk
rBa/jMW9Lr5C69HmF4a+r8UW/eSXJiEEn05r8PWkm5FUvH2MmSCoTnMYTFct
wPjKOin2KYKuR7L7jMy6wJFtny6VZxC3YCMQBPfCRYUrqC9mwKnimdTcasaG
HcMrjAUEo1NnFzZuz4befa+9JxwIhspe2G/u5UFIqir36nOCBgeZTO72JuRl
/q81ppZALDLiPke/ArcjtUWLvQjMh99fqSnsRAwvLdLJmcGqn/euGjVPBWvy
obuKPYHvZLz+r2wBrGXiEgvPMyis6/yh27Ud1zdFza1SYMD3yBurfJ6FReKC
j6N0/4YX2cZHSDO2elsx5UsYvFJPsfmmUw9dybTRugiCmBqJSB9WAy45jUQG
xBGM39q/2LSXi19O9gxExFO9UkYm4m5XY42D2/j8f/21EL4ndTMOQ46esiw7
ArOF1zFB61OhP7bXIpzW96+Gds9YeCWCZfu+cnwJkuTlN/VwEqGrfOCmFZ1v
WGO5r3or5aWQGKzwI/g8Zj2Zf78bwo72+T6GDGLSTGzuNFZj93icrHkAQXTc
y+ikMxxUdWnl1N0k2GK7IaEosgt7glf7zWxmEN/aIDZb34IXNQde86UZqDUF
Tt7b0AP9I+u2zv/JQOrexPyoGg/V+bbSigUEJS3XHALaanDQZ/WQJeXFttRR
KYTFwzKJzSMt5QQkRz5vuWU/mr0PKxiNMPA0Wxrdqd6MB2e25XLKCNSCRHsV
LjbihxNTWuw0AoNwrfldch24vWln05LFDM5MGMfsDyzHpMZe1m13gq9D3410
Hq8GZ59HyW7K3/VGx6mk7aVYkLsc43iW8um0VPIP5wKEK3nFrnUiSMmYmzE9
/Bon+hPWmmcS+PxFbqpFNeGj0sjf6wnBq+xP1WuTX2Jf1PC4uytBbNMA28u6
FimiXNO629Qvd+3/Xi/Nh2TTpCCB+u/9udh1tgNVOL9KWDyO6qnzpwc/w7gB
y3trlI9RHhU0lhT9m8BBWY7ud6nh9PyTV9mKBypgruOmvMiDIOJy42O+Xzpk
tbRGQ2h/FY7OWBkui8VSduDqNOpfna4jMSdvlOCUsUHty9MEQn/nDh7UK0WJ
eXRyKR0LMkeUjYQ6UWzW4Lr5RwYZbW6TCmYNUBa/d07+IcGy/NQY3lgobh0e
OmRBv1d944aB3+pn+LB/z0/WLgTLVdJtFgUUQlbM7vRj6sfjFYrCQentcC8P
z9tvy2B4bGks9xQfl35V9jUtJRh48218TlCAIfHjQ5edaX1SMZGz0zw8kvtj
p38VgevGPoHgXgP09PcoxdN8kZoX9bdmmjHbe33OfpJA3KjjvZZSJwgrw2g2
lMHyjj9qHi5KRF3WOTkdym/JhTzjEG41PL1dRSOCaP9SrS87yvdC0DxYpO7F
IEz6zIwgsAfrZzXagoIZuFz3UtRKKoPeVydhL8qDjdMxSf9LjfisvmJlVjHB
SjNZdbPZCiQu/GN/lvpLKDFMNEcwrXezuPWsJtXD16akWDelBJWzXypwjsDj
7hWbqSd12GH0bEqf+tf3cZDIb2+4+KB8lSWIJmhPEHHZUdeENX7rCpzzCexC
98wLsx6j5JRf21lHguzeaFX70zVoLcktDKV+Oqkaxivpeo1t/kIK7lEE8yvP
zEQFtUCHzW58TPW09I9dE9zIB7+2vduim0DzfptbaH8SXjx4O5VF9ZDY0Vd8
yIgLdmpCMyub8to+7HbHjI+AnCYTyQc0L2affO3fkAaRi2mZ4pQfF/9be04s
fQXdEGtlX5p3gSObPTJ3t+DnK6ELJm9oPw6ZqWsavoHB26NBtQ1UX1sNobe6
AmytXzlq9hsDxxq1dQs9BZAauH9oL/WL50ep5ak/dMPzqqL311MMtrX4jLF+
7UPO0nHBMe1BqKpXHm2QaUBy6mevmRjqv9Yii3tfSxHF9X26juopmF7zUO33
EvgVaA6JUd6WOSVHuixvR+4c36i/keaxx5YJzepWPLyzJD9gjKBj8G2pzJIe
NLe7Pp3LZ8AWUhTdmVCFpu65t37U368kops1y3gYUDGx/JnmBbtAyftgRzcM
hv0N26NoPi9cr92mUgultqLAFXR+kZxmYo4CH+8edGzsySF4oXPEM72rHrJT
uQ/KKJ92vwfa8GaS4DrmlelE9R4wjbYzcEoEZ5NO6y461q/7KSkgjIMTFr+8
t6L+1bMPUZBv6gBbPdvK244BLyHHzdWyHQU+uYvdZRhE2D5pcupsBfM2tPWa
MIPocdnWubxydMrlGqrT+zmzYnqxink7+uTU9PZQPxyeF7HY9VwAd8lzX+gq
KFvV77gsUYnMPu3k2xdoPrivvc6SbINjTF1glxIDywO5vOm7HNiFl4edCqW8
x9umHI9/g+CiBAmzWJqH0wc3iORWQCY2dMUB2v+Nn+3H/vnWiYBald4t1M9b
ZH5/OjHNR4ugV2dhgPKWfXxYTDUZfVpzfc/pebMuFUim87g46h4tIpFIoJ1R
ltF6oQuBwSr1zdH0/8HZOXbFmjTImYiTg5Q3Ep7u8KG9GfP+ftdsMyh/xYEv
Vc9nQxCed/4LvR8F3iXC1zIqsKNXP6yK1tP14fsDja9a0c+deKW6iIFd3q6U
YgEfEfFfNtyn+1lqfP+jcT8HJPHMxUdXqf5Zif+w2rux6NnNciaPgXSd8+rk
PxtQIDcrlEDv06oabTfrN50Inr8T1mHCYPFgpunRuA6IJW/s+CTC4N235w5S
bgIU333x0dWcwf8BuArUKg==
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8lO0fxS0lSlKWx06WkkqSUg+PIykpW6KU7CJKVEJIkkRUUkRRUiQt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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41dkfxxEGZUkLkcqEkkZIakTvOzSlyT5JJFui7NRFRclWhChZxlJD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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41dsax3FEiWxDiiupUCdjhRtX5ytRtA/tUqZkCnWUaDAcKcJRna5T
1E4qQgqZh4QytPfOmGFrD6YTe/9+JJWkOAp1f/eP9axnPe/zrvUOn/e71viF
7AuQkpCQuEmt/+83yjg5up4voWD2p+SYKgHNtanpqx+1InYLU5wbRoDhfCA8
Lb4EnvdVNT7bk5j9LghpOt4DIylyZVS6GNmbPs8UHOgGoZp61d+VwNvf87SF
vzYghebxNeMVAY587OL9C12YmH+cmV8jBn20cXOtOQtSs6eZBhdI2PdnBW6O
ewqyR/4lnU7Cwl5h50LKADQTl2XRFEfQj7fTvjv40N562/3nNjG26njuLnvc
iEA9lbJ7xQR2aa54Vt0rQKdZ3+SNVSRY56fXsGgCHNXzrY+/OQyfMZujXLty
BKnonTQNIHF8wtxtKvgFjMy+81rEBHS7TRl1TCGisqecFAoIvA9MaHi4joVL
tW2mdo4kxPQdfqKyXug8Hb+U/EGMyZV2OS1v6iDzbLPI250E/c5g1N7rXDwJ
fipVLzkCteOrCSduP3Zbb+56oiVCzqzlUlv9HpjrbBD3dojxjyKSLQbaMHtS
llj0D4FKxf79/Hc81IT/YGfoEehePHz+xMoMHNROXzDyJBG+5MtYrhYXaYKC
q1LvCagmBhR+1RaC9fmlk66pGGNnVTWFwx0YjevbalhDYN/3jrT7DX04bOKk
tHUNiffX1KyrBGzYemfqyBHUe5Yt1SXuHMwpR5MHpal6RTSrBxNcJPpHT/wy
J8bRZg7HzKAHx7f43FacEeEWs/5z8kUBrAx1VHnFIuwPkllJBvJQe5P2/bYW
gQRYNxpMs1C9kfajg03d/8B5rV14O8r5Fbz4TwS0s3g5sZFF+CVTNoVJ1avK
RGZ9kEcnnOJMTxwKp/zbFI8UD91G+5GbGaO+JI7uemfkd6ATW65opoWNiJGX
c9rTfpsQEsr2KS6vSFxa1pCZ79KNPafrXZNUKL4YM8VFrRzclfKTMn1EgBZ8
RsFUUISm63dUHKj+WRWtYVXurYMUK4ZzxptEWf5Z0cd9vVgcnK7aVSqGZJ3m
9oaNXKxaUnntwWISBteXi9TTOdhk5Zel94FAY9dFncI/ozAaFLct3ovEC8aK
2AuSBfh3rKSeEnUu3JLvHebYDdtfz53dGUUgI+DdG9EIH90VT6MN3orQ7Wol
+9yoCV9OZm1jeRAw7TcedFJpRkx3nell6lxaqLY2bm8z4hiercxQAupDquuC
q4SwOr405hbFqzI/aanAvhtKxjGrrB+KMZXO0fumx0bh8vo5X38ScSU2xtsC
/4bEvZeHQ5jDkH9M+7ZcwEVu4H/LtDaLsT82uq19joWDfBm67S8kEhR5uodk
2JAWvE47l0DA+tjowQ/+ySDt9EedDlG81LmQTP4AUm7ZuK8yE4HWqlL2Vr0K
/danPrmfISEMuR/vdI0NWrvA9cQVEg90ZhMrzr+CyXyIfFqoCIzQR6mWQg7+
Gtlk6kXFt3LM60VwWCOO+LuH779FwKj5j1/P+XNgUKzxoGaWwI2JU8E+ihwo
/1Z75Lo+CcYgU8P/RAc+ZEwzWw1I3MpoWXr+dBvqsp2S91B2nZjL6V75LCi/
LDGr30NAWkEvMu/UIOSYMwv5Z4dhm/9Is7y7Ezf9R0okt5HQJjZdilnbgYTL
r9hdEQQkBpWSTcYSIX93X1MFNV9R/O9V/fy/YSXNavNIGsDkEZWkJsc+OAWO
W+52GIb1KunqKlkuXvc9uMMUifFN3zSJP/4cOmqyTdup/B0dHXP7KoToxDdG
RLwYbo1GyRlNTeiPFn28MkUgcoNhdJCoE1k5rrXjhymejvxjuYvnD08247Ic
xeMzl9zKv2tb4bU9NSryqxixU3adyyajEakw7zlC8WWd299h8JQHuWHLiRcR
VDwfFU/VUPozEHd+fSOV36PoxhDZDh5sRPEuh/opvemcPjSW2gXZJRafhQti
XNLcEVBS04Anzqt8kr4Q8LHpS0vjXMPw1JwuzYfifVFJuYtvHqTpkaqEE4m2
x7opFYw+7Jh80ni4RoSxabc3C/saUJr30JKUJCHxJsAodyIPLiaxBrKWVH/q
ddSZKSWo7giqz99A2d1OOt/PLIVl3ZCt7h4StQJ6Rkjpc7AlNOh3wyj7hf/w
zQaKIPGybXks5b8he03E3t3t0MeFtcuaxZBIzvwo82IAVco5f5y3FqOlfNBe
aqEPSuwe+pkfQ7A+ESeYk47D+oTSt/MUr/YD6wyONg5ip4eere6d18ix+roz
xuI5dn0y/vx6O6UnX9dZcvdWw41XuugrqHxb2iXGlbhgXQ5/bG9IItJqqJY3
WIrxPdo//9eFhKWcMIC5pBwxsVfkC11JmNs/V/q+jA9P7ezO0ztFsFmRkq2e
3Y/xMM/MoaIhnAueWa/9ezeUze863ogUQ659QubC3QaMJPWOv75IYsxh8mKt
XCl8NkT9paFDosnrU/t09itsCmFGPKsnsJXtkLK9rwUPavUW5iopPhWak/Tb
b6LSKFjDhNJLTn7G+MbfOPgxMKlB20LFG5q5uiS3BjKVWifErwnck/yzRWZG
iOXvQ12N5oexj+18/36iEH902c0G94oQ0mpx7+QIF8eSxtOlykn8vIh542oB
F64pKoWKDwkc1vTsrXET4tO/qt5d/YtA77Rly+UnLWgbah6qNCchvVo0Y27R
jnlfi4wvQwSUGzmjW/MF4HDtptVkxDDZ6R6UL5mHcTeEfjpAYmPqvM08emBX
onnPg9L/TLmUMB/FYvSe2SXTsJuEmqG0TFV8D47N0ktUQsXQ1orb4H+pE5kb
HXyNfhODd71Wd0l9K/waUprSsggcTQ8hFwp7oKS58NatT4RDmzhX1/i8Aq35
gtmxXdR8Rb5hXPmpHR58C66xCwEHFV7Nw/wCeHeEehlR86MsSHP4ktCBZSHW
vJYK6n/zK5ZWNGxHttpAqoAk4BHn3XGqgI1IYa4+PYhE6W2vc78zSjHcMIXd
FL8b1SMYWxrYOED3NrT8QUB+XUTVx6IeTBczrZc4EzA+OWL2cawXWqyf+NWn
h0EbNU7M5pYi3rZnhbMbif8BqBW2zQ==
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 44->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk81dkbliVKZUmoEBU1GNHiU0lPM6MyRGjoZmkiIXsIRf0kiRaj7UYp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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c81f8fxY2KVEIqlayQvskuIzotDZRNQ2kgpEIKEUq2okikomRkZGaF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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41NkfxydKsyXXLnRBl3VrJdYt4q3JKl1QIUIoxMaSVSjVUHaZdeun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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk41Vkft0RlD1ekGTK2hFGTmjeTD9IMgxI1tmRfswztElLJUpkiIUWW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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 45->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lukXVvb0E5UUWcakEppRQpbuSiJJJBIipFSoRBlkjGypaSQk+QpZ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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8Vf8fx6WQEYpoyExGS2VF9TIjqZSGlRDRklSkkBFSKqFQomElX2Wk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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk4lekbPiPFmMZSklBZkgtpGBSKO0uhjbFXKjSVaZo0dXQo2UaLyth+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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk4lekbVmkSUUlhCElUo4YQUm6lhJFQWQYl2TJ2KjFlDYW4yERaUGSX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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 46->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk41VkfFylCjJCQIhVKRTKi5lNSKTdSKUljNyhLWpQKxdiuJZFsGYxo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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Vd37xr2hJFPSS5KUJFKJMlTcSiMiDTIlNOhLyJBUyhCS6BUNEiHK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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81dkbtkUKRagxuCo7idAYGY8RUUkmla4xqCw1kSWMyo0wTcUYITLJ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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns0lVkflksq5ZbSmvoUoxJGZuKQYR7XaKgOmRTjEsrli0RqkppTisNc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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 47->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4Vekfv9ZpQfRDN0ypaChNk8xE6KMitJFf9USSPUuJmwxZkmIUZV/S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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8Ve8fRwjJqjTtUsmIFCFve5ZERlrSEpJKiEIhI5lZfSWjhZJQKiqZ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkfxi9Jpl9NY8sSpWWMLRUKgx4Ze8o6oVIIk5ItDCMlo1IJSfZu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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41Wkfxr0lSxSyNSoppZORpUSDupUlRBkMpUiSDCnDkIoWZKxFDaEZ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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 48->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lmkfNbaJmS9DhrfeFsZWk1IjheJIqEwjpY9UsiSyhJCMsi+TJVnK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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3cg1P8fx40GITSkQTISKYqQ1FNDNEgIiVJRMiJURkMiMiIqI4Qoq7I3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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41Gsbx2UrJLJFRCRLEUVScb6E0OJ07OVQIfVOcii0cLLklQoRCceW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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs4lOkbJjppKyJLbUW21ta20VjNErecy6E29CPKYRGRrJC1irJF1FqH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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 49->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lukXtqRVUYR+SYhISExEmVujRQ1qNEWDkEQixVRMhEkYxJcM2RqV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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lG0bxlFIRZIS8UZZImtUWjjppaSyV1QKISRkJ0SkTb1EiiTJVkqy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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs4lGkYxlFOm1QmsshqUiHEppPTrYNDJUoqixSbUzYRqSbEtiapLHIo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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk4lekbtlQTg7KksnWoZEZTIpX1zpKlbBllN8jSkGXISNkKoykaIYmS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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 50->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4lFkcHqG0q0hbqWWjR6U2l1AtqlcSttQqG1qbkVtEFLKJkWtJRNHF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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VH0bpohkq1CWkBR5ZWmx9KrblmhBVCqKJKGUiqJXRdIiopIsZc/S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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs4lOkfxp1S5DCzOWxSkegk1BJbdLdFhOTUOkSRhFqxQuzYqFTbSiSh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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4ldkDx2UpGYQW2oT6FZEKSQ2+lihKg7LdoUVZJtQgZNqEpCiyRI1B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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 51->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk0ldsbx2UqbotK1FWhTKWy3EJSfCUlSkoq6ReuOYQuMjS4oSKlrjIU
EXVlSsgUDo55rHOMhxyk/RbdrhJpMP32/eNde+219trv83yfz/N99lp7Lwsn
QQEBgVj6/bcuNlhVkXG4E9n+LVKfPxGYJoVnusU34pDGTKjmXYJ00zi9NYVd
0Igg0junCBRG3qy7eLEOzvodIyPXCfZNFxTb6abAuebcXh87gnKt4jSVuBoM
2188o3me4EbjCcvXdRyYhJO08nICTt+muP9VPEZRpYzdMD3fX5EwtHWgF+pP
TVNi/Bho5IqKE+5T9EVmftjtQHBLevyR7UcuFIaeJYfUEUyGzpQ6W1dBhX//
5i/nCIKSY15cF25FgLSXx0QSgcq7zHzOvW6YeWSl5L0h0BERPllQWgchDzmn
28EEbuVHD3K+1MEzmb15bzhB9O7nX0QW1WAkb8zv+wWCNJfmBtGsDqxsEq9z
7SMosb1wa/u3hwh//LLPlsa79/T0shcfeTCVtJWLPsqA7HjRdTO0ANZ9S60u
utB8L/1xqqrgFTTHRyqkaL632YUxDUc6UbHTaoHyLEHtzZEp51Q+FL5LP63u
ZaAQOCP474VK6IQ5zfLPUn0M7MSMXr9CYKfHkEQ6QVHmCSGnmD60maTauMUy
aNRoPJWtnYbY6FRV698JPN5VjmsZv4TklJKd+T2C1VOua//164ZRlLbAFiEG
Br9Uj++QZkF/5taLUU96f15MmYhwOby0lC8N0P3KoP0hG/o7Ya3+Uyd9kmBK
eMJdaLIPUR0JU0OtDP7cXvdez6YcG83TVxbT8/bfBmZjrzVB5vJEp04sQTvv
WmZ2Twfus3TCrYUZjCdOH+pK4UG9vLxEewmD2M+C4hE+PHz47vZX+mkGdofd
in+VSYeK9o8fNTR+G0s7s3cBPGiuVcyIUGdQmvrutlAkDw05Gs3eRxhY/TRT
/bDgIcwb5Mw8qP7dx57805XQi2VugVUtjgx2nmOtrl1QjShjSamCAALJooSE
6bJ+SC1NmVhbwWAiqeBfE5F2GCYLsUyGCTq9TE8abspDdrDUtq2OBLwkh5X7
nrTgaVp8g3wOgeaBDRof33dBWmzjsol1DNgxryz/WMmBb7Ou5fBzAkdxtkN3
awuehX3N/VBEUP9cUN+krgF/ss7XO12j++CFrYHur2GWk5Q2EsMgPN32Y6V0
G7KPZxb+TvXS2p7ytbqrB6I9Ho65c5TnSz+jjl6uQePoV9aXPynPGnmzlXPt
yL/qWTFTTTByf8ql40w3jk+fefNNjYHo/bCBPEEOFkpnpX7qJbA2DrEZUmiH
QnjVzEIuQWWhqsVLlXqc36sheSyCIN5wv/+YfjOKXJ77S9H4JFR6Ii6N1UGw
t8cs5jLlMzjfVmyCjYHBucUjQQQa4f9UPYnnIpqV+E2J8h9icuCI1JkOKO+Z
JcV8gkPG/LD1C9qwx1a7ZyvlzdwuwsahthW5ScdqhWj/FXQvN6qq7YFu65xr
nz+DKJbW5p49HDxcdeeteyWBt/XMbWfJFhQddBfdEkYQEDxbdFy5B2siVdd4
dxIsDvCO89zRgMaSyKl3d+j//np4tMmkAKbzWiKMM423irx30E3EvOWNL6KU
B48PMld9B3kYkWf5WJyj/qFdeXb3PQ7CrWcmLEtpvc9LXlu+ohRDG7P3tngQ
WOlpau0SyUWm7LbqHdRfBN38LdpD29Gs+2B6jJ7P/7hcKU+FB+hJ5ukpMvBW
9JxuukX9kV9i5jVB4y0Xqir71oqK9csWNtB8Zf0bmwLbqV80ZO5XpX6z6Tj3
xbBcE07O3bOav0nw2OG87/rpVrgMSwyLFBOE2719NL25D+ljn0IbFBhweeNR
nrbtiH0+WDJJ+VQTWrDKobILXSwDwZBdtH+V9GM+xeRCYB9/rJPGu/5k/V1p
dj7+dvO2ekX5VRP5sf5UFQcDCv2H5FuovqVXH+VYtWOSM7LLvIPASezN9itV
PBg9kHJO0mCw3mFQ0fc8B2kSOjoatB5LuHG//YzMQngw21zHnmDR5eJS9b+b
oRRxvKM/keCBslKCcmIDnAMM6ycjCZxX3evgf6nAoaEDq894EQh8TfPZV1mJ
TRfVirJ96H2Dn2/1X+Jg+LdR1TbKb4nxKdV/tnbCK0rCb8kggUH0wd1GIfEw
Uitj820JWlcoZqxCG97KKTaveEr51LeX6whuB09MNqWGTfW88/bw9Y0d4M00
H3teQf0qJC/4SE4WMh191VVovDe2BV3tChnE451ni1PnGRR8ZxtvsK2A1PV5
duYflBfXma4o2RJYyAduXkH5CTAPfc80s7Co96VWjC8BTsr4WiztwaRnTlzh
Zga+Dllzlvnd6B7mr40+QOtjzrFtW14IzeLTwobU31UEE9RfOXRi/48N7jua
CT6f+bVkFY+F5fFY4kD9UdS4yUNZsQkzoUb5u2n9ZZdxZJUSq7Go3GRylPbX
ISXXE35SfeCORSc7yDJIMs5fwd3SCgnvD8F8qrfAp6XyJgGPsMkw7K9cyvcz
75mkz+vK0W+bfSeZ8iueIdmbdbwFv/NWzwsXEqhvk1j3xJEL59wOx0xCIKbj
tIDzsBFVNvLibrT/Ddrst5iK1qF+u1GQLZ3H4zdcfklN4sCiVnC86zHVT6r5
q2NQLB6+OtvaQOsRNh+WX+ZaCxWD0exFIQRX/fXaxX/WYHVPbLcanY9nXXfo
Zyi0wqvYUCYqlObjE8xb5FaP27pvn2VQ/6rSHttgsKcetdUL9327RPNn+50Q
2VOLhrIT+/6m93XydwZ/GWvHZwl7fh6LwChey0+vqxpJcrqXB/wov3e1Ely8
X6Oce6z+nBGdj5+iUo86laA07OW9u+4EdhuGfy07XI93dsl5OdQfquy5gQcX
12Ig6LqgWyD1z4Vs/mPVfvis67XKCKXzaxezjZvViFixoYFB+p4xWFkea7Om
CBMPXl/wOE3fM2/2q+oEdsMnXX/W6zcGrjmn82N3+WNUWe3mdqrHFZ24IjPv
SviLjOZ2eBPIrA3ZSS63Y4mPYgKvn+Zz5XT6nEwLkoflEyejCCKnNCauu9P5
K5h5J1GEwf8Bs/HS1Q==
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8lI8fl5YyW5IolVRGqEiUN0JLMkpGVKQkRVIaRKSUkb1bSIhCssle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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81dkb1nSVNVxGY8IkS5KSRjNDy0NRpGJkadMgNUS6vzINuoWytEcq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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk01ekfx3WT/GL8LA2FUanIWBKSpfHWOonKpG4RkWyDKUILksiSVGNI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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 52->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lukb1SQRM7+sbWRJpckgkRKOESkjfWMZS3YKY8lSilGJsu8VokQu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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHk0VWsfJpG6mZoomUKmDKGS4kFClKSSREkoEpJLyZSSoW6p0CAliRQy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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81dkbpgxS2TKI6lKSUF0xMZYekyYlGYT0oRHRMIkWsjdGlmqQnyZX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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVWk8lVkYV8RkyT6DmEGSQsOQpMb/KrKWQlkqI26hmpqGlJmWq4RJUkOU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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 53->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4lOkbZqUkHWxbjbJlKanthy05bLhDBzmnVjlLDpHwS8raREXZnHNI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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k8VG0flkpCJUWSkFRUnhKVtUt2pSxRyiQhqSQVpZ6IQraQpagsCcm+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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs41NkfliS7i1CIIqlVSULRUvt7ZSNFcquI7eK27v3I5lKSSi6/3GKj
zO7atImUkYrcb2PcGoMZlwZl5sxEW0whcqnfd/84z3nOc57n83nPed/38673
OOPoLSkhIXGTWv/usxfOaZ6xKcMz+zX+2ocIopzk/cVPuHDM6jEr3CWEkPfm
SnoeDxwLdz32+GtINLkUxLOskRir+srwJIGf6zJ68T8VOGXzae/lSQFe616f
vzl0B/4sN93BUwQGJp410uI6NNdbD643JSi8a3/XhD+Ab0wGV2bpU/dLq6be
2jOhlJi86n6aABH7/G9/Mq1GTouOTlMRwYWoXF+xqB2Hsyev5O0g2F940ejI
Lh40RX9Jfwrjo/zphlKaKwvs6OrOZ/kEEsfV4+yPXkMGzWJm+2mCdzs+tP1B
50KmrHihr0cIemWnedn/KmC+2yEmsZjgjkbRxcjPRejtdWYG7CawnqDT5c+x
Yf/ZQtP0FoVHHDX2Nm0AxrEt0x4/ELRZn8z+vmMAlhWzdgxVggmdE5kh8Wwo
/5IbGx4kQFz5HmulHDYahg6oJ7YLkKK1Tm1ONIhd820Bx2cJVEK31Rbu7sU+
r4kyLSmC42MOIZvpQ9hsmlXoWyOA3lxLWGdPATrGeQ3OJwh0m3e3TlkxwG7g
mR10IpgtuJ78X+UmpFqW50rZEsg8uGAoGT2MNkvGp3VTIzD0S9JQbOBgecN0
+Z4mAa5HvG8br62DSkbxtxcZAsxeuq2g0J6H1W5t2nf3EWh1v5GmnU6DuqDq
7brjBK93jiqax3cj3zJgx/RVPhreXHtmPf8MZQNcuQgXqn+kGy3DrxHaXjbV
+tJCuBxPqxB5c2Bc3u9b9AuBr+3Em1f0RmRreK2LLSXoV8roO1BLh2T+F566
JcGMUfDmjc0t8JKjt81mC0AP1onKohVD//aN6ZQggiemUmOxz7lYPKyv2Dsi
hJpQcWregAHnSI05m48CPDCVr3ha1YvqsA/MTX+P4GPf2g8+xlzEx9t2QZYg
5HRLiUtFL6Jmfvp2MoEP65vtXkNNJfC4WKib+9O/eoi77X6GgdsFC8p5Rwlc
NmazosJbsbRqJMssTgDbuen3fiu6Eb640Bki4OOSWoT+ggQNEUFxPH1K78E5
SeRX5yE0PTAZJ4bDUDD7M1GZ1gAlJ37CMJegTsBy/Wnb33BWM324n+JLb3mb
xZcb7TC+f3p0jwHBJsbtiNqdXIxvkqnMI9T/mBE1Es6G1Dvl1ymUvnyC6uzf
JrNx6pOP35FjAoi/TOgs5dLh8Z05k/MrgWMFWRu5uR152+R9k44QFKVYZjMT
u2HlLCp85kpgtdVU2mLhPuqcKmu5lJ87fR2y5sf7sbo+0j3mO4I133cdKR7t
hO29w4dUc/jIjC/68feyFvxcoek06CTE6PjRx4GvGmGkkz4fsZ/A5GDOPwOJ
XFyasMw3eUzxb1bS3UzVS1b7eVG8XAC2qmzURzYbnzXPWSpN8/Fflqt2q3oN
6Fkhro8o/2/N1Pbs3dyPl9J1SeGPR3BThnE6wK8Emjr2UiwK76nFr+lTuZ2Q
P6jzSky9x95uMt6Q0wlR/dBSuxKCo+emrrp38vAo1jayeZHyk1V7zaQCF/9J
Lo6o0RNgsmouvzmwG4EKdhEKzpTeve3ds3tawGLq3317T4Am6wHvM569iLjg
833zDB/38vtL1hr0YmpSqjSmUgiZh1HFuUGZaDJjynpS/LKlGFlr5J7DtKM9
1JaaHymta700VF5i4VYsr3GPCL2DP26/rsuB/BIr/cs0ARIKVRQv//EUJgEP
ixfdCMoNJxrFj+nICRoTn7QhCH3u0Zba2oNu3e7oFkcCelhQSr5XHqJSb2Tf
8SL4GjTlreXXA/O30fJMNz70aEuKcgQ9qKRdOLTimBAa4jOtgQoD6H7T/mKV
FR8tqjGMyBMMyK30aNeoJpDbn9v/wZ+FPx8ZNdUfFaC/poVroF+Bjmtlkg5a
BAnpC1Yu9HpcOTm/OmSB0m/3y1TdQKreQb/S9L1CqAt9UutWDKJ75uNf542H
YdB4Nk/+NQeFqQtZCkpCbKyhb/Q17MQJtXNykxTempyjG6TLSiEzouAtiiPI
NQuX1jHqxybO2lCrDgJFJQdFzfschJVV2kdZC3DVzX/XLYqfzG/PZ3jG8vH4
G+/ok5/7YdXACn6xgeBp9m8Jks1sFKgFGe28LkSYVKzssrkSBKWfXzAJI5A9
bGikfrYLtJnPacEpFL+/WVYGpvTB7UTjA9VfBFC/ZmiqvqUPCsXjc+duEWQq
z+idiewBf9/rltxZITqq84+9sO3B+xcbbFfJEFwUu2oXMOrR8HGwwdiKwA6/
Rn+160OQU5mlfQ0f3dVqtee/NEOr6Am72UwAF53UAKu9bEj3rpZvsiO4Wt5n
wQ/ox+7C7UfmDo3g3oEEn4IiNmj5yzoklwrwvO5iSrL6M4gUNIfMt1F5lMVz
YL/kgJt0wOvFMB9i67JilR3VeHh3sorXSpC2SqnFTqYUJw/s3ZJ6luCyrFaB
EYMHUUDwWdaxYeyrGVYV/DAA7xUtPzrn8+HilXm5q7sCBzj6atmSBIFihlbv
kmZcVb06HVpD8S1a3W4SxETbgP57cyUCSeEWuiKFf3raPmMFNY+rFrU0o20G
8MMr/xt2riLUfafcN+jIRZj2+oRQphBaNLshzmQJ7q9cPpaYRPk3ztKMNtEF
0dwhW1nK3wYjGX4717HxSe2fLYpbqPlVkZGkqMmk8s6tM8KXwuOg/urJ32zE
xS/odlH50n9v+9ekd3SYxVbf3UCdaWncQeOnfdBfLLR4x+Kj6TJTO/RlLTRL
rFevoeqZ90mzPD2u4L39knkOlX/sz8wXjolszNw33+8qQeWVNqtguKsPMZEd
Z0eXiXDt+dCNdfyXsNk5Nu13jPJfsMriaH075GlbI9PdBbhROK6y15ULYY14
ldUjPm5u9armzfSAnvx1gGkkAu3UeseYax04fUE+8Hd3qt/Y0uQ5m060RoYc
iqPw1N0pDlmp2AyHrN3P5ySFKP8jbziv9CEYDXp9wz4EC+GX1ozKtcMuhrGt
34San16eNJPpOlDa6FhF+eP/dIfWtA==
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41dkfxyWTRKIZy1hCyBqiZCa8LY2aCEnSFdmpTJaGHyoJg5QWGSQk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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 54->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8VWkcxm1RNGnamMxMClNRDYmU8pShqxJCBtm3CpksWZJSUogsSbYp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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lO8bxW2RimgRUUmJSpKipDqRpZKiBZUt2ohCkSJk+VoiKkKEspcQ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81WkbxvESReq1DSZLIzslNYrisjYc1ShekaUFLfZRQg01oSPLy4hI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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs8lOkbxq3atkWRcqgIlbJiE0ohl1Aop6yMlbCZjGSL1DisUwihk2Ip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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 55->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs8VWkXx49LUpShkhCRS42omUKTaX4kopJbGjWF3C+RkC5SJpIX9bpV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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lf//xjWkgTSMkKyMRJKQ5FIfqfCRlVFkR1pCouzVEiofIyoVMkNC
iI4th8Mxjz3OfRyrvlTSoH7376/7j/t+3Pf7fo3rup4SjldMXVZycHCcXcHB
8f/XtVJDUt3ixaiwOfp38DCBzUqp9h+O0rF0/MRP0SYmfogHvkwTLAFFIZX/
ky+B6MRTJi6drdjdNF2v2ctC5ivzebOIYqgkUBnP3hCo8BRrrrIeRE1Izoc2
+gTs5SO2HlKsw5nA3js35lgoCGasq3HqwfwOVs+2DSOouv/bw7qqGz8Nyms8
PkzBw1fXKOFeLmKv0bUDAgg4BeQ7rRB6jQovwpp5icCm+1enVf3qwf279eHf
EgLtASqe5vHVuPZy17PRCAJLLpTF3DP9SFFULRuKI0CjHjn0NLwbt4wq/FoL
WOicWZbQnx6GMKpiVw+OI5sn8tKwcS+Cv3z8k9rBRBQjOuntIhWZ21WuUWxY
mLPJCZPcWggtqaLnhaoEghc47WiXMpHhxb2cKU6gRMgpp/0GA2Z5h/w4n7Dx
VoA+E6mRi65YkwPHbhLwrg7d4ivVi1K/6nvgmICugBt9Uqob6kydNWeCWXhr
+U9MtXMnwnneixc9HoWV6HWzvBf5iGj+G/S+mID0jobtGtFNiFPdvj6xiIUQ
YYkYz4APCNX93bd2ngm3rwrRdv1UxN3ZY+3lyYTXllpbTjoNet85kpyuMFH3
9XNfcUQtVjj2qit7ETjN3lHivacPBn1lX3c/YuJ2Ws7t/HAKaMZtyXWrCIgv
E0mc8fm40czzOI2fQDeX76FDYp2IbqmxkH4zhtu8F3d8TuuET9GtyBw9NgY7
h/bXqLQixuGXSbs4E5pOh5K8ZLvwQHC3jY/+BIK03l4PlG6H3vGD/33QJaAp
4Rc+Y9AG7ioed+U9bESV2dpqVzVg2YrxVUGHCY0k2V0ix5rxMlLh9yEBst7/
rv/0Zd0AxAx7+n4oT4BvH3fSx/ESBKj/oXzXIFBDiU7edbUOtPiRv0+us6DK
x3j6gNGLy/tdrRp2TUE5VM9Ql2iAOdVLztmBrFfMQcfwleVQeiEY+fsegdWB
bzhTZytx9lTtUbNcAqnfz6k10h7DXKzR9MRpAsPJIWt+bH4PZ22FN2aGBJT5
llU4DpUg33hzflQ+AQprfJpPvh9rnBtGeTXpmEtb6rxztQq5Gh+s53lY8On+
HVtfUAv+u7mlhk5MrInr8NqwqhsN1YKXf70j5809nGhu+wD3yCa3w94Erpiv
qCldGEDT/Y9QDWHD2EW70MOvBcdcdvxruXYCHZ1jp+ItGiCwp8n/mCgTNpxq
a+vkmjEjMxevbsWCy83mDZfZPeCXkb8utZ6N259cXZ58bUSas2HgrDMLaR2O
61K0hlBQEKT1QX0K7l2fJ64J9ELzO7/cFg0W3u90pYtco8AidOGrOFmf1Ey3
iR4pKny0LhkabmSBw7LNamaDO/6kaTyrsSPv1zQ/F3FLwLc3SfVjZwg46sqY
/qQ0o/X+GjO+W0zMqdm6VSi+xCndsoKUswTO3T/U4vyJgUK10PMPotgomG0t
WuNHR7n28k9Dcn8c5S+zcy3p2ODCdF0SIvDjoeZZ9/V08NL/6fH5NI6tSX2b
ZGUaYayau25VCPl9i1jm+oD/INz6cGMZ2a/2xnNnwgXL8e/89WoTLgLakr9W
tVPpUC2+pFhxjA05d6Hsky+qEB1yw87ZmKz35hdjLuYDyNQjxN4VjCM1r/9A
4IY+wPNk/I3JQQQ/v8O9va4VOjoPEt8pTWB3VazH8ssCrBudf1NCzme8gdf8
cH8PPpiErXdYM4Tfde/WxKX04NuVqISJsFE0XfWXGp2rxFJKvpFvNoFtB+eM
vzOKQKS3djnPELDneBDtP/MYf5HvfOYCAe5goxIhaivcBP6hej9jomCe0aFr
UItMPw4LkVcEvl0V9U/M+Qjb0d2nOIIJZEQIyLwL7oXohb79P0UnsXReQSbx
QgNCH1O84vRYsF+t5sl1KhthCnVXdmgTIIKyjOuZ7bhxi1M84z4LB7cznmW9
GoRNVeBGHc0p1Ik9jHXZ1ISOdlOJS1vHwT2toelS2IkYrZRD1GIm4pU1hPWU
KDBTmha5VTgOZb0NOm5mpfAJqNSwMCH18LfJpbxbXai792zQRYSFH1cjFT9H
UpD0jTab3kPg4f6SxqGjQ6S/iO5l7mRhVCQ5xisqCtLh7MoERwJWVjv/0GY/
gnGEa+5kMekvlB+Jq0m/cMtfoXwwcQrS+5eadt7vgvBec/u/zmzwhS7Giuu8
xbzUTr8FAwKm/gmfNut0Y8TBYKa6cgprIzGdnJmGpeWC4+eDCAx66W2Kd6Cg
JZ827+1A7qfsWrGne1NhYpTAuWxDYIzhfU4msh2O5wNU/yxPgJr/m3qyshtz
6wxvU63GsH7ZVPrqYD/oTJPWuLtsKHcsPo582YR9uvo9zmYEWluad7cpdYDX
SWxOAhO4qL9U8sywBxNfA3gO0gg8F/N8pfKqHZ73JffuTh+D44R353fRXiTS
LyV4fh6Fjvys2fCXt6j53/LAnucEyk9LfbJ0aIfhoeW+hsvjaLWyuqMiQsfZ
Z/8ZiRZPwPhWUMiGGgYsQ0+uYjwZhbhng19e81NoWTtkyZD1ECv0F9n1tgN1
8tKHDdgsCIskFxwTbUPwrKfd964xrP01mfMq5wNq9XOmLakE0rQtTjuof4DG
pf1mdtVMcODTrsdl9/BGY/7erBXpR8cema/eTUVAjvWm0VPj0DB7GqjLokGn
9ud6B1s2AoeUTW48p6NARfbozAYWLh5ZZeQhSINiUZLc6R4WiIEti4eiKCij
xf7UIfPDr+C/dIcL3Wiyr2S2pZD1VN/8RnffIM7G6NeyQ1h4F9VTKh/QBEmp
Cp+51wSenevc2+DZidlbMfds6pgQ/3zSjpYyAl/zpsPxQkwIldkd/qzUhRDt
txGlEmxkaAX9c/ReJyirOM79K8mG/n7bRN7NHWCwZd8eCx7BWv3K9UWPOmDm
UxJ2h9Rnz8Js5TNCQzhut0K/5uggqgXH24erqUiOrTddliXAsca1lTbgCgpH
Zoo4qX9/mn3usrl7Yc0tFbW+jMD7KNMXkd2NiKHGTyXuJpDzbXdBGV80ZM3r
hdodCLhIp1fzLnYg0u762O928v9OzHRs9q4DZ9u5xWQyTzi3jzgvb2iEt/+u
f3LzCNzeO/otzqsaBXPvkw4rEugR5Z3ZK0PH2wmtbZHUSXSKjHZ5izUhY95v
SfAqAeOsT+b7cqIRXlp2cpMtqS9fNMrMtFIQRh9QyibPm/Lbkj/oRjU2357c
03ZvAiUxPJoUyy68n3otM0LWe7sZ5YQzbyUa/gsx3rSXQKzk6wRFXxr4DYs3
HZ+bwHGJs+UlqxqRemrVqlM8BNy+GSUaH6iAqSWn4ehXJsZnPa9vsu9AOP+C
x9zhMfgq/9S671GDuDH3vj0LBN5a3GKkpabAZznuuwR5ngXFjiqw66CjcWso
jsKEjrTk2n7eWqQ/UKfmirFgKJbumkIvwmWxgXXfyDxleGHkgsVbBqyqVdp9
BCaxq81QaU6kF6HHbSUqZZk4HnF0tZp1LXTdXObmtrDARzhs1x2hQf9yyXO+
J+PwHfo9KT04gHM0YsVO3inwsTQGledTkXWhMGqRzLeZTM8m/c63KPy2Stxh
LQGhdVkVwSHPYftrx68KUwJz5qkqpd/KIXf7uGR3KYGCiG03v6W3Q9v/9t6h
Iyww7NaWehrQEHDHvWhr5zg8FgpSjJ6kgXe6bHs3mWdtXkdc0+aqxPt72gEz
0iwshY0vh1KqMZple5JzJwHP6fBbrYaNKAx3UJYfYqLEfAu/xddKbI8NbxM+
R/bDVt9lSKAVFlnSRXf6CPzKfCaqntKCSM4fJZbvmVBr4jrc1UxH9M/iKaMK
Alt1N4U90G/DwFkJTSeXcZgrNz5YebkHujvTQ6nnxmCkudOI/8QArNZcTTY5
ysKDVQZz4efboaAlDoko0n8uf98up9gMKb3m1Fovct+VFR/1BNHg+rky7XHS
GL7J54i7DXRgMqRonCuI9M8IFbHPFQ8gUDFiJmhP4PHKF8U+j+nYevO5dbs2
6U9B0qxXMS1QczrvkL+CfH+m1/JV50fYE7ztudl5Am2NveeX9jHQEjqe4p4+
gOh8LTve9EEs7kxdFGBOI/dXe5fpqSZsff03rs1+HI4KsxFP6b2QDWmoXGk9
htefvXPOx96Eo7oDXYz8vk8s1flaaC80zmt+WO3LRLuk6obXn/KRKGshdpHM
I/NSdfX2wu/A42nrRf1CIFHuQPIT+364zdt4TX1lQ3codZ9AbTc891Hk9nFN
wj56ow1vzRM0ddEFHEi914rcas9F8sMu6/vbf3lNIpihISIb2wjH/t1f3pA8
5WHnut9Dkga5penQFzQWrHrSJHaWV2HmwLjqATK/xtXEmwwf7Ma6h6JpIzUs
tBspRZo/6UbeKfF/WTvZ0HqUteQnUwhXz/qrDNK/NL7VOzsIDqJF4MTfMJdu
xJaIHGUEVeAkl4Kc3SC5Xy/Vt5RENeBm5KuB9gRSD6SGYl0FSL6wk+0ZujMF
U9PCW8f9nyNQsMdloxOZN+TvJGn398KIfiT0sRrJOxffqvXb1uKuuGAok4/A
tPzGQEXhJmxqucnM3sFEw6J5xqJLOxr5/tfyq5nUp5hnIcWjfeBLHMutkBuA
94paq6TIGnK+HYd1hFloWumye+JPKYIeOuxNJPNybN0dhQt2LzFJT+BuPkVA
Uic47adBO5x+LRqmx4wj0Oq80UTSEML9jitrLbHRcr7/sutyJ0LPWzUokvlH
OcWEV8W+F87rLwmfHiPzTQOPy9P/IjAbKXgvidTX1VkyfR/QjJRSva7CRQIN
rV0Be/o64c4tIadWSeaZXdetLXXqYWbxIvdTIROxYiYmjTp9aGD3xfO+YeKh
WlKZ+iIdd+1Y4v+LJ3lSKtBPr6EP0gdHtQZZkxjO6VIJ0GegwODe6jo+NrmP
C1km8u9wUzvpdLsrAffPxQpfZnuxs6Bw/ACZR9duay1clU5D6orLnmn/joPC
6JPJm/GCatx7Yyly/spGjP8c6G+CW0+gfY/0OAjjyaCq6kaIvjGwu6TAwoTv
xyqO/F5sl7Q+OXeX7E/o7Y/tC9lQPGFc/sKfwGhfwqkfQllwXv1M9Qo5T67b
LKS4TRgQ1g8df3xuGqlWaT7bT39ER4aa45/95Hk0fcwPd9TAsjMhnrjOBOUp
O1FVuwu3LuqV62ewoeaTdHuQpxNdKv7iG9cxIfzvNQ3auVq4X1HfO8ZF8vzd
h+ui+5Lw+tgoIUeenzJ2xodvRxbCFPskr5iTvL275/KfH6lYH2OxKYnkzcdD
edTtgwzIF3Jv5iX7aiNy4UH2cA1oPP/RLHSZ6OJvHu1gN0BYh2tnviUBi4J8
i3fxFIw6cZqbibLg0b1/4LUrDSkXZaJNsyYwd0/zk8MkBZEdBoxnLwi84Wnp
a02lgnfvl/pfZkx4bO5Z4bAUhy3UxRwpsv4aHcl7Ypb6kHn4YcbH+BGY5n2M
7mvrxRfZyxUuAoPIlacelGuoR7Zaivv+VUwwfrx8rELy1I0FmY3WHqQ+RXBF
0/wysXqli1cMeb6K87597ZJleOj7supDBjnPumb7dPyKoTyc+VsoieRRqXOG
0ZY00LdVDJf6M3E4m0PaXL8a89rBqfyfyPwZ80SeodiHdwrJGXmC5PxlKyvk
cZZj9H/dwRGk/vg0f5GXvdiBoiPp7/v2jMN4arMYt0kTUoyyzdlVZN62F+rR
1R+Au0hvFk11ACkrtdyFzOrQ0H9t6QjJZ8etsgvyB3tRKt9Qf4R3HHwGRaJH
XxXA98HR9JskLzUZUZPMUooQHK2Ur0DylfjqzxseCH6ET1ypmX8yydunRaj2
Xe3g6kyq0ib9/EiTAmrQhWSJlaUDgmwIXXVViS1MBfPXtntzSgSOBNC7Iubb
cSXXutwpcwyy3jmBVo0MjFFteLz2jYK3gaVtnPAKHhHU1ddOkP4ZllqxlZkO
U+a+hI3KZH6wT5ZNfl6GAc9A3xRhAltst744ED2Eh0Hr1j5/yEbDgHSL5MV+
fJeM4hkZJ58/wQpzCupC/BtuW/XeMWRs2F2jy98Lu6LhExeleyHRaeVGZAxg
wUxzRpNg4XOTn8XCp2H4Jv8zSRTOgE8uxUkivB8XHwQOUlqZSKz8zmMZ2Ifc
PQOawmtnQKVsfLxvieR46rBmOdcIbP4EPM8O6oaqiLdhFoOJbOW2OFX/ZoQU
6VM/KZH69nvptOx0FcovuP+030XWY0FoUYerEykfbXnMSsj3R3crW7K6EHi1
YXEgbgzRNTw17yJ6INaUd4XmOIKzc8cOrQsleSOjuOT39zGIv/5x9ph0IqK0
jDRlL5L57WO0z8G5BmQIuWrsWD2Bg9u4igIja6GTx28uZsqCt1yV3GmZarzJ
OZajEkeAr/TqvrCPz2Eo1WqX50zq80u3HT/4GtHiLEIbvMuE6v314iXmdRA7
biVQJUNgWE7R44TBI2zEsM6CG+lHVT605oPv0d98JjixnIDAjlOW8bzV+OXz
zbi5idxXZ6dYYdde9GfxGe7kJOehh9Ep5l+Is3qxDk9vkM+npvJ94KIjlfou
YtabibUi6cebBlphveuED6OFDf+Md3J5e5ug4/TqwhaSD0fbNv89M9AJx9tb
1Zc2TuL9gSMckZ492M+VEzxaOAgOT4Y+Ta0KNdM5BzWvkXkrWFj+vUYv3u5n
nLIi9XbuxfcXW9Y0YXDTqs9P74/D2blluUK8GjeVUhMkwwjsjjln8/URHaHq
KWc30cdQlap51y+tB/yCaxJEzCYwq0mxff+XBj2l2c7lHJKPVau5JataoSRQ
VM92G8OPo1dnUjpaEeszlUvjH4c+/Vh5SEAn4sOcQ7+T+ndhMkBknU0PCPpt
er/rNASvcNZL2gyhwfRL4pcbUxgXumHAul2KKAOfLRvIPJrYyuvL8bcY9oTd
6WfkPO+PtW1MzevAQpmW/NfcSYwsyMyc8abgjWfi0Hwt2c+TkiuurxtENMwv
mspOgTEWuCHIvxgHXpWxlUn+Lx/bbk5/WgO9Ob+Q0yUk72kmWFVpfESomIHq
sQIC/wf2n/ul
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41tkbxpkwL2mSskS/7BpZQ8LQrU1aZBlJQ40hKiPKluwiS6hkSWgs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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81HkcxnXIUShCaGVarF27ZZObnnItSjlzZKWW1ESppG1tmrGJ6HCH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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 56->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs0VWkflkvJpUS5lCL320yohol6YkrC5JKEQUUNoSIpIWSEjISpRIbI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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4Vf8fF5IkpLIqSUIqScs39EJLVlJmGdkV3yizqVJJdhp8hYwiihCy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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk0lGscxyd7C7c9IeFKq5tKZKlvomghpJJkKZRtULduJpVKclGi7m0x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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lekbxiWZIUlCWeYMJR1pmmpU0/nRRZYsLUIpimRNRpIUn5JMiyjZ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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 57->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lekbPiFpUSeMJFRSZEyiTcitRqXzU1nSKIokKdlahU6WSEQaSzqW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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8Ve8fFymbBiEKLVoou/K2UlRaEg0pDckKUX0VIUrDKBISUhnZsilc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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVns41FkfV2JFRViNVFI2olDkVcpHusiljTKjGkXWWrmOipA3uiwl90i9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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81Wkbxk/RaI4lSqUy2dIylJGlTS5zUEpyLKOxn9BrwojKklSWSTVM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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 58->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8ldkfx29jKWmxVZIWM0zSNBTVHdunGZSRJIz1Rzdc2UImRjItJqZk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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k0VV8bRqRMFYlUkgalkqQo8iiin0REZC4UZQxNhAaSUIQkpZAQUpnK
PM/THbiXTPeca6ykNBff+f46a6+1z17vu/fzPsOak56mznw8PDx2vDw8//+K
H3I5Mb29FpdU60899CXxJvX0wQWhdKjP0+VzShnBkBQteHNQPpp3GBycCiTx
10rQZN/fZoR8/LPyedYwmqvqOowed0L9pt/+/RYc3D0ntvDetTqsC3Jrqcvl
Qjfh7aeb2Qz8/j4jmRM9DKldtWvf9fSgQG1qvHtuCGaaa/00F7Sg3cqGNDw+
gvzM/LIbWQwIVncoaNJJdH76/MCi/SUaZg9IDbJJpOhk667aXo7raUznsnoC
+/1pa5Q/0hC+ofPKqPIIVNk8Mn67GhD+g6XWE8VBn/73Mt2l75FhnWTNnCXw
N0chO/MpG0vHrvL+8RrHTzvd0xlVbCjIGH9gT5GIP+g4T/FSD5bTNt/IdRnC
TSd33Xu9bKzR2rRpVnIE3wJDjg8eZqBjXrn52c8j+CBqLHrTvh5vLcWKIqn7
s/RVZ8YLluLOIdrxuvME8tNa3K0kqsFcrLPsYy0JX1P6HD9PLfyPfWuTUCQQ
3Pd4x9YP3gh1+VWgc4KEzfs76tox7bDfuEbETosDca/XZX6KhTj45OoHeRES
pu7+iat5nuPs6k2a4fbU/dTKxUmmsdD9Z9Ay7vkQnoxPtdEq0qEZwdJa7U5C
dZFatevJfji7Daxrj2JicdxxOa0XiahKjP9vxoWEnPNOy5QN72FDk/Xff5NE
9bT3Ss2HZXCq79x7+TqJgIV/rMy2tSF42vyn5zwCS3lVDV/pdMDItP2t8zjV
H2OyhNVUj1+yKepd8sNwqHrysjWrGrFit8nJcQ7eOwsvvcBuwG8p7+hL+0jM
928SUdasQ7VHv5TLWS4qE1lawhG9iPma0PS4jVovOJ/EtG5D+PojfFU/qP/H
yXWfRvswN32DfieFC+32eeI/yEZkfPjiP7SFhKiDtJCRRhWMfH88np0kMFv8
RC1Evw88m8ZXC8WNIiBEgm5Ja4Yxg33g3xSBClrNj7u3aJAWPNkZaz4IhnWi
ckUgDTdOaiQXZg/hwKOrNaoWXRjKLPDzGxrFYvOh6qWKlXhqfmP3h50k8vaa
rBRd2YCrr90XRekTcDqxLFDuZhF+CnrNTG0gMfLtBvuPcxfmNi3fskaFhMxe
P5ZADAO59qO/I++NY6hC038rkQRtEdf7Z91IDJ3YFrbR/R2EXEstyvoIaC+f
mdPJe4fpw6GF4o9IzOmZlBmwqxD+ItzXMIYLGcl3h52NGLCILGoezuDCa0fW
gw6rTKxM4KvdqkuCZ0Gix+ZSfaiuLm9fT+FjLCUzTHJ+GXj25Oz3+EjCSzVD
eEdzDcwM1Hr1dxJImFiSlnUyHdm6Vy47OFJ4ic/gjA+Uo1battZQjtr/JOWK
x9dGHDnx7OxExQj2jT1IiOB2Y6x860u9d6MIfC/loc/Th3JzpGueGsWEMFGb
LstCz/GmiYYPJP4Zm1vf8WJjfXz0NM9hLqKwR88/uA2i4lpSQj4c8OydH7f4
exAUWx5b6lH1CgXwhWn+6YNWaFpwUjwJpZfW9ppWnTCu711B6+RieuZZcmVO
D55MvwyX8xxHu+/2qQgvJiIZXrF2t6n9xsfLDZS6YBOS07itfhgzwSbrNQSr
4LJ9ifBjMS5aR9YnHxKuR2ndHX2eRC7kLqamGwa8wICOu7KMM4mNSZxbYY9K
EZW9UHxhPong0yVSAt868DNXqiJ7kAPNHVtPJF9joX7pshz+umHwpI5LNEbG
4Uiy2vEAqv6NiYpRQycKsT2Qk3FWh0SrVeQ6xo5mBL+o8gjdSOKzlvCZcnk2
QkRKLIMIOoJ97+w7mpyOeDsdOYdbJCIKPK5OX3iD/e6mATHnSThE8rMz+Oph
L+Zjuj6Ceu9bmS/9A+pwi9zm8GU+F8Xi376s3VABX1eF/X53uWg/aisd403D
n10z5jGaXFjKvQsQzm2AbZmXrWAbB3YiJgkhUSxklHMi+jMJ1EwYEzuTmdg4
bfdPVY0DbbuwRlffHqg2vw2a1B/Gzv6j84/eygf/tzrWEhMSFwtD11mL9MBs
+50EXW0CuqP679W+deKm4Tt87iaQbfPeZZLbiTbJILWYGhLhp4v6D7UyMV/h
WbELVY89m66T+YvarzZxf4XrCI4c5Jy7ZZoDwlG2f+0hErVvPpoIGtGBce29
pVeoeV+X0KBgk4pd41F+UyDxQYt8oyTWAPk6gmNL7Q9eyGJzdhRgN31Ez7WS
4rMXpHH10U7Mdz5bXN08jOklvOw64VK4G9tqDR6n+PlbvoqhTBl6f+/4es6d
wPm1GYtkHRqQHGS3OjuIC54rU6ePWqbiott930MUX4kF/p738kcX9E6slLB5
zkXzj9/Vm6XqkKvF0lQ5z0VefmVV8UADDLWenx/w/v+8zS76bMiAucKL7lka
AfVVAWNqdxk4JUyOHzAbgXKry0PEFsDgfuUOAwovlWZpTdH/+vGsKINPczMJ
oziHw6UXe3DcQ1rtH/WeRYHXn24QZWJfrNg+I0FKL9zsxG6HdmOuCTm5klwE
uHrftdnch9a1Cm/mC7PxoetpQ8OuduQJfb/Lt5ZA2K5+o+Ph3UiuDe9ttyUQ
8mi+xuozbbhsaz+qOU2A+WmK/7cGE5mf3kYwzQmU1RrIx36i9H9heutWSh/c
2gp4TDb2YH0TmZa5hICKfkz0HoovZ5R+zTgJj0IpoLqaHslGPd/iFSaFIxD3
7At8T6PDt/iwM4vqV97wfPqpCDYSilMFp6LHkLMsr1z2QCWKJt06Y5tJvOZ1
OOcgz8C6e3oSyaojUBO25Hp96YSs9skrcf5c/IwTf6iAGuRFcAx3h1DvW7Ow
UTw8FZVrL8vJaVF6Xeqe+Xq2DK+/NbQeWE9Cb7/mVykDBh6ra6buesGBlue5
jjXTlTAdXH+mJJjApw6GZ6V/J/7EVrwctKbmlbH5+59YJgYkPycetRlFqIZ6
nCWHCf/hZvEzKRS+PBQvtSu34FKT15feyyTUvw7P5f9JQsZkd8glYwqPx5Ku
2fF1ozflzaTikT4szUiYp+RQSelpDfP2chLayglfjy28ix92Jd+DT5JI6D4Y
b6lCh+vDCBOf1GFsjFZelyVQgqEr4+EtDyj+njntOrL0DtYtXJ1jT+HDTV1K
1XdzLfT2BGftOkxiQ+4Bk3gNBtJd6OnckCEccixv2uPSj3N+XhM+1wl4PhMx
ffqUgW+Mz8YOxBiC3/C727tmQT5GQFqa8ics1YmXHmMM1Gf3t69L6Md1580T
QzwshPn+MlW2GUeYbqlg8bVa2P8cejVvD4lSlm6gr2UXcl41eb2xH8Un0UD6
DeU8nG+SahkuJuH9ucvR0rcF+k1HjfIFKD25tLP79PcmJJskXi3TJfDErvjq
8JG7cDU3z62i9GXx5chtSVbFWMO6Mq5E6aOLXbLchvF21G4PVb5cReCnUaXt
1yvVqO2y6cgpI5DHY+upoF0M3nkz8crUPJXe3/ot0YPynycP/bKIH8FsX+Fc
x2AV8q2/TsYFUnxYWN82OkDdlwHHWvUUF9lFAiOT8UzkeXibqU9zwJdbZONj
SseY3QEHuYhRHHmj4RS4OxOLslnS1ZRf2iDxz7TetR9WeUlWiZ/HcFfux2DK
DANe/RWHfbNG4cXp6nD+2gqzLUGdrkUc5JObM7wDWvFpEWte0i8CIvuX3/9n
24EXD74r9FLvebWy1+X1nl6MpW38kVM4CC+9RbMfqyi8NMtzyqIp/Xty6/4v
uSPwjb8Tpk69t9M8W/bOuXior+72/HCEROyKDPu5fTXoffiDflKVi/Cb6hEL
XrVghUqBpLMrFyqOzpI84xWw/e6w81Y0AWW/c6lBh2g42DYqsc+HhPiCGJXf
W3qRJXC7+vPcCKo5+Vbta9qw1lHzC402BEFRXn4xmUbM+nzZnTBIgKecVh1a
bw8Zos71BVVPYVxq/Yu/bCTGdQXeWDmKivqvN0t+9mGL9bSxejMHTyRqEpLX
tqP36RKWEJNEucm0jLRZD5pLqy217g5Dfdnu3pOPWJjt7siKp/iglbk25+GJ
KoxFrov2CiIgJzv4Si2mFGZzlaH1qiQE+HuahI2r0b7okeXhb9S8Se6+dIcV
B95yjzu/vKh+enli7h2l/PvIjzgBOgfvklZU2We2wuS1pwpjP4GBqJ3X513q
xK7D//TWqBEIVQzg639SD3q+oGsBVf/1C5ULK3J70EK0HK/r58LQ/GAAFg7i
v8RDHlkqw8i7HZf5o/8JTAWWbrOwI7HghJbGjsJuTD1R3cN7ioMcL1+X3MAy
VD356NjsQPm98+1041EWCnIatjpLTWAsy43/N7cIy02L5Y7mUvxe4HVciPkQ
IrdkpTUCSERZRI6blPSgSjhSXDRpBK8wGyfJVwn55TefqkqRkE5R09yzj44L
+Xur+gWHIeR/8N1jJRqq2p4oNMT1U3V7Lpek5j+0bksU4dYPreQJ9nyNWrDW
6/zZtobAGdfC3WctGvHlQg43QpBEY9ZIrgXtNb4cKPNODSJBtgsE+mrRYKJo
YGsRwsXK/JdBWxRaEGv2M2flRYofGj+KnLBrg2+Ipn5YGIGxUO2gUvMM1Nzs
DB43IrFkzGAPp28A2FS8/LADpZfRAYcmgmvxO0D5jqgRgWVbTGb3r2zEx4Gv
1ozX1Lw7e+/atqAQCVrRtoV7KX9nbXVbl8mGjFf03W3eo9h36N78Fde7MROb
tEaDygMLnkp9K9lUhL27vteZU3qYZjB/9e+DbJgO66uWG45BOVxxMOFSLvw5
o7PJNlR/aeT49ZclcNIeWuNB+eVpl8ihrVFdkJ2hd9oVDiPh/KoUSeM6lPcN
DiiqcOGWwIxd+4MJ6WOW4p+uEUiq/XNe8HsLPv0+87FHggS/+FvZeu0uRPry
rpI/OYoxmYml8ulMlB8VPfNOmoNKMd0Xvvw+OLP03jlRaj5KF1th4F0Vbh/c
/dmjneK7PWLMr78KoWcUr+g7jwTjVHvCaGQrPDi/uj2aCdwRC68KmO6Gg434
haT+Mcj5mcS8Ki1CrMh3F2vqvPLouxmmHSwYClx4Vi4zApVKdnshOYConuOc
3+w+dF5t/2hTmk3lvwNTjyso/jSr8inT7kbiTdkv/i8pvzg1/F1+3Qv8HJKU
uG5BQmJ7YNNDWj/Ku4Sd4xKH4PvvgPwZqWrYuR7k9/tKgH+wvVZUnoW02Yur
QkfGEPuzRzmstQeej7r4BPgH8N62S1TbswaGX6ROrImhzv+kmnZomIHZlntG
nl0ETuppKf1Sb4J43XKx7TtGIHJ0/LhiaAdi+tivj82OwOtbUPFn7gt4Jb6S
KFxHYqY8JbQ6qBARSb0BTBY1H9m7NfT4W2B4W4L/pQIBaSXi9zKZZvjnpD2/
HUvCLmw6dAWrCzz0UF0fnhEsloms63Zshfix/7bpWHDhpP40nY83BYvSA6uK
KL5zg4/tulQG1Oe3RRvLjyAu0qd6sqQfe+M7MlKODWHbv/qLtfRqKj+dfXr6
FQfB4h/imdsLIFJTXSy7gsRdOp/3Hip/K3wlVJekEviQ03a8woeJL5zhfydA
5f2URe8K5zUjfpXn5KZdXNxIXMJeFNeEY84pW2wLubhd9oiTuqAXZkPM8jk9
AqwtPm+V1+fB4Zert4EH5Qf+yhpLBdFQfsFoq4zAMCztZPRNtVnYmL9Ke8pz
DCd8uZMbmpuxMcq+PJnqx8xyiq8xvRue8u5q5u4D4N+Y5P2YxUajxlrbA35D
qJ1ncyroOYUXr8DdBtdGoZMs4iYU+QxJuTPaYhqUnoSPNXLFm7Eo6HPpTeth
eD13U/tk0Yq+XKG9KxyHIVLneDq0ogpHX/8dPb+WxKn7N66qV7Ui9NHTyPls
qj6xULdnC0qgNjL4lL6MhOYh99tJi1lofXx5QvP7CCYVNWo2OLKQG/K0qJIY
xZuScam1mV34K/bvyIN9Y5B1Fz3sc6MbQgd2rbl5ntIDo4r1a3grMC3m/eXx
JInEpXYe9Nc9EHhcvoQhMgwz+o/uu061UAl4mKV0iMAttoL+I6MWRBXUf5zy
ovyAS++CK9Y0qC4/dyR+1zBS3IPSaz9WY3E8oau7gIuD4o2nc0pLwedk2Py0
jsqvCn6XSZFSTLSq9eR8JyDUKcI+vIkB2wP9jj4KlN/ektgStYQOg2jxUu+8
fiTYpGbbTjSghpyICPvNxUTqqeoVXWxY8U7tLCJI7BFxmuX1a0GtwpMrQtS6
eLeioKNXL1bWX9bIKRxCnuX4e/nhNLio3A9rpPyEmVP2AyVbGhTFyt5FU3if
rY/4bJlWgKX/vLUu8VF54Zq16yJ6P5LO/OoTTB5B7L/Lt/S1mCjmkqdExDkw
u7r9iA+DjrAXc4PDvAS27Np4uTaeAa0rWw8rFxAovrfqyFRSNVYvlBJBBwcu
NrTi1eb1uCGvq5PWR+Wzir7Lyk8bMTG3u9+KwnPATGtwTmM+mFISSkczKP5S
fG4lt4iJq9EyOreZBBjqt7ZnRrXD5rVw/cloqr+Ripjwi2x87vVzWraJQGPJ
+jKaFQ2JtxStH1P+Kzt35z4j+yocmCXKXIK50BS6dKM/oBr8qooPCkNJKFte
LpRNbcb2hzN0rVkSQ+eM7n7my8Xf24+mJym+vdi0emlHTSca6ytUDKm8G6xz
1liqqQ8/rfcomg8Mo27jaOSzEgbqhFaPCbRRetjx39Eg4T4Yh4gWmGRwEXst
PYC1vQFKTrJyAxSfFRsQxUqDNAg+LDv/sIFAhLHmhvKMLtxY8fP8isZhii/0
Bh6OdGMfb8DJKwocFKdJL+HRS0CC2Iz5zClqPvkzs9SLr+KxyBIdGqXvwYYe
bh0L3yDZsObich4qL8SpSERpvYV2pMt/BZIUX+y/phv5mIHqgm3KF1xJJPUI
yv73iIFRi68+x5JG0bmDpLeto+Ok1Vv995R/NOWN/Nht0Uz5u7ZEH+r8EEbr
/DHpHsrHXkz6dOwDhMIMD0d+Y8Jp0w6NCscxHCl993zZ60Ss/6CnoU+d3/hr
a8ZbtzycGOI3taDWAXmLlWIc6eBX9KGpfBtGqWUJdue9RXW5lcxWCwL/A1jD
BDc=
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVns8lNkflqSSJMktxarc2oqoddl6VC4lKdqkoYhFSZHLLpaIUrG22ViK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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4lekfxjUx/DARQxhLtkjWCEnnVmmIklBGm+xJlqmxpUnFIOcoarJU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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 59->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lukXRlLZUlJKsmXJFBHSTNyWiBqmpJgiIrJ8xRhJElqUraQkmsbY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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VO//xq0lVKKQdj6pJCQk4ZakBYWQFqKESEq2SpKIooVoQZJ8syaR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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lekbxn0aaz9aZlS2QqKobJHS5JIoE6GStXLsZLILUWMblSVH9goj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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81GsbxsdWHUkhJyoiTqc6r4NsleWiaErJ0ikpTbbirY4kW1RHXooQ
b4RD2VI4UbYolCXLTLaZLDMYzMzvdxyijCxJ2/t7/3g+zz/P5/489/W97uvW
9DjvdEqSRqOlUOf/N+1TaHmJVD5kntUbVB4gYdZn8dvXylaEW0+KKneTWExW
vpTs1YbImNGjpS9FyNY+qraVdQYXdoL3z0kSOlxpWswcBzyuQ8GX1QRe5dpO
Ho59A93LRjr2CiR47hL2xfc4EA/X9nsPC+HRL3mi6u0g0jLOBsSWCCCeiRPb
KzWjqv9k0pqtBPyskz7Mbq+Dev6g2HmaQNBOX1lbYTdOPAhcUn+UwF31QZeP
4cNYYzt+tUJXgOji/F1inR68V1Rf47ZDgNnqzulgWRb852Xb82SoemMVnjZh
rbhxPfZUXiGByYbQuuZOLjJDvy6OhwnADtYrv7rIgyhapstpehgq+8Jvx+fx
0aldOBSiI0CesMT3WR8b25mGgWtjCDCLT9VtYsQi5Vx29gYGiYgtL79d+akb
xgsKT39uFiHpfriUzrEWXLdnRGXuJREdPFxH/9aGw1IFb7yDCSxMfIhYY8dC
Zq250j05EtlnHpltoVXhu++A8cwxEkHrZYWPNrAhtzffu5opgvUrnt7w5nLk
WjbvkPMl4dZWutAgTkPttHrinXMkftCQXU6s6kbFk//+pJ5EoGnnf5QEzq+g
2RyilPKAQLjX46I6ohGz14rt9FsI0A6uEnb//RjuU7+1RVmQWMi6ydh0sxFO
u8L8E6xIFFwYmYhr68Aasr0sTpKAfOByrd9H2uF696lJkisJh5hjw6N0LsrM
h/ZcsxKC2RJ366VpK8SDB4JruAT4bcXeDNkBZKR9jTu+MII6ZQ0ptnkPxnip
mj8ri+Da7HHxx9g+vGgosnKhEXhoEfI441wvauXpTn8QJFbyTQN1ExpArzFK
tBAT0HjYV2rWXoi0af9ml0sk2MqMfveDPPCMHww7RxHY/EBfj27biLkk/mdT
eRLMKP9S9fvPcU5B4qb1LhLhE7HNOQfKsJKu8atQlUTn8LFNNQI2EvO4sVq+
IpzVlHh1aL4ZIXfVOEEuVP9nlDXo61rhVdNTWFpKIJF74/pHl3Ic2Xp6Ucaf
xNWUqesZ8iyUTBFe4hLKjwsx8dKyXbgY563FNxRhnfQ6x4Gc15D5O5XznNLz
fYtKb8S/OWDq/bL/IUuEURXzbrXYbnzKGHry3E6EvSzDUke5ctRpumZ7xZLQ
/ufug72NTPQfknD2MiCgGqLq2Kg8AD23uSh1MxKJzJyPEw/bUfSlK8noGYF6
Z8e1u/JYmKxxUJMzIiG+MrJkn009XDa9km9cQUIifPZWSHU//BLGMiaFAiQb
12fGB+Vj/0HHixnbSRi7XdEmmGxwDidODjIIxHi0bWgxaUJQnfrf4nnKL3VT
H7u9A5HJNHkXR/ldMuu+g4xpI5QMYqrc9pB4xNXvX5vSgUqddgbvMsUz3abb
4kE3VkhVdHUGCVGmKinl9HUYHjlFjXOSAgj2CAsaRx5hX5T84lY1Er8+0Vy0
OMSFSrhnpWKvAOXVRlwXzV6sdHKzu82k+utdrmt//jU8Jtrv8P8k4KDtk/7Z
pAKR8fOi9wdJyAefb6B7csFjyMsX76f82FN8Lsm9HX8K5z9UUHlSSxdsjOnn
IDfH2dr3uQhr/6g540zjoGALy8ZcSODUvgtJn84w4ZP4JL/zKgnXDU/dRni9
mJY2CFsdKwItxGPbiYIKiAvuWPnYU/NyJ1febqYD16MqQ+zpIqzu2G62Z6EL
twWhS2nJItQZ+67aZlQPlSoFt5c/kJDy0c8sGW+Cn/FYcQTFI+BmuNOSoDZk
HxzxuKwqQn9PZcqHi/1QaXnteEdE8WVfZW2Ur8FGYlTbnPLvm0M5CjJvWZBM
WN+ebULiXmhkpMLHPii8YjZu203AknYkfT2XC36dmpVv6Qi2ri/t3JXai2x7
yZTNfkIc6TmQNkfx7wueDVl4LYCP4e7gwmfxcJbK6HA6QSLzr4rxpJ+4OGYa
8+NDAwG6tEOThzrfoPfF1MkpOokVFxeCLBMGMfk0olfWQgBaj7naXHgu5IfZ
C9W21L7YKzFiIcGCaaCb60QulTdfPu+QCuJAyNRV3Hia0k8reiF8CxsHGLfc
eYdIbFqVCl2DAWzcPmtcTenh1/RHtO79EZS5MDcwPIfhlklRKe6AVfL95NGl
BAS1f/5DV0hFdtsORW8qHyM1Cbtdqo2Qkx3c7TlHIKA01GeHRQeqrsf7yzqS
EIhuODzuysLne3S/cer9wuq1QflaPFSd5fxcmyIEzXeCFrXwAn784uPS1H+i
bR2mv19KxeUlKxq/nCbxuSnTnzPxGqNhK+rzbAlo0WXNjH7vRflyKd/xLgKk
xJGQU0dZMP71aXDVNwK8H/QHX1o3YaXZ7G80GRKbF92XBrQ1w1HmmthyjEDu
p0pVg331ONL+hneDyq//HF4qmZ7EQ6Spv7XXVwLLyiwlWz27UVTHTqw5KIRN
hNds1sgALLHs8HwCifNbbjG0otho/2VW94MJgaywKf3l79oxphVUonCZ0k9y
naKi5SBaFaKmvQQjIJd8OLJ6qBXvtXfvMdYkYHP+9o682z2416DTvPQO1b+W
wv29p68hYNNfkqPUPDND3U/qy+VhOPJ7VhPFkzGgUC/2rEOpUYPigA/l17OT
lSfO9OBJK9+4qJXEMqulBtG0Lsi+XJc1T+0Ty3hWZ6psFAoPHzshTdUTeKad
53/vhNUtp8dSi0LY+of1ZFzj4rTRt5hihggvHqbyy4rZmG0Sp392p/J9Ju1K
mqAC6TkaRpupfRn5NCgwxaQVem9jrzbpkQgJrmZevMFBmceUK7+MgNhu/e9N
P9bDLziB0Kb4ksEBmYyqDrwzO2Co1EDgZMRbVfkrHJT+clxJ65IIafxbBSvX
9mFm9bseueNChG67kK8ewkaImFO+O4+AtFhdAfF8sEoMmTaGQ1g2bq7RJlOG
0X3WyjRq3lInsmeMtrXgr5m8DVuPkijaIj3UbfYCKgFsZ74yCUu5oJI59y7E
jhl3Z3SL8K/CdP7OuV7sP/n9chxfiP8B8VK+Jw==
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 60->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4ltkb/sKkmBpNWQY1mGqIMfo1ophuI2FMssSICjVZpkKEClnCIEq2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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VN8fVtmpaBFfkgohiZKQvJSKlD2pZEuFyhaypFRSiIhSKtlDiyhL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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81ekbvbZGIpGG7JKZIjslUx1JaWyRlFAIV6HMGL8RSipUN01mLFOJ
yZSdlLGMyr53yXVtl9y67vdljMaWpDQ0398f7+f9PH89y3nOOY/WidCDAaIM
BiONfv//3W8u3K+VYmOb6r21rr0EIfJ5TwY7XqLGRP07YacAglAdszpWKdZG
Ev/HvxKceaUb+uFYN2SzAwdj31JwWLZ4wVrqxF3zMNd9BQS+fbvuO17qw0QB
P1KxZwR3tePzNacqcFpyTsLHlEDN4WnbtOcfGDLfdMrSjaCh2rui04yH89oN
Yc77hUj6MmMzr6QAAYJQxmU1AkHpUf7FhAq0aKzuqr5CsC2N57gijQe5/IR7
gqsCxH05UcvXa4Tlr0VDNXQ9jDs2s2UXj8H/3Krn5t4EjPTa5GO8Sih9XD8V
GUngY/hP/M2BTpAaNdnfWASrKbvhT759aDLsMdupT2DjZ3JzNrARSvPxigHT
FB4IWh+wR/JQ8j1johEEVjffmHgGDiA9J1ZRS3QUKRYFk0uuVXD5/hFLzJag
biylOXNVHDbwL7zYSOdPZYUgbxsHXhqDFXnFQgwVt1jMcgahEvmiK6ePwrHC
heKdylyIKTcfEimhEGm8xlxXfQAm6NiedW0ElQPVjm0+9ThnrD/3dS2F/bEm
tpuul6FJ/Fft6f30fEzeb/05jAMnfoVUxTKB8STD2n/fME6fDS40chhBXW55
2JHCXlyZ/v3VdTcKcp/GBisVOUjVN5URy6DAyVfdaZD+HIIN1+dG6Xr+yZ3S
NPBsQsT2xEBHAYFSTJB7RXsHckLMf2pkE2wJSGjbIajDusT5AMYNgn/bhuRY
S724+mRDimgq3b9UykkZTjWqVepXHNYicG+qSI2o6gdLPXDTpQwhSg/oiCs8
bAI1sjXH4iKF7+okZPs92QhyKo2z0iPg6ImJHV1XBqn8l04rwwhOvxn+hiPo
wZfLT900uUJw2FmN6ZE9aL+4cUmPT9Cb/yTeIIiHDpGn24NPjEL5eWJs5FAD
WpXczt5fRzA86RTzOp0Lp3pT3bYFCnkHJn1s71fgaPGbI4do/Dn2MkOGSzVI
0lKytz5O8KxsT3ff61bIu3ln7x6hME7ePfY81YWwUe/TUX8TvDUxYPSG9OLT
Tq/6hiIKRfpbmNakC4Vby8pFT1OI4o/JnRTlgX2l1l+2YQyx7g5zN0STYRAY
3NxK7wPPfGw0VmQQW+p8V+43pWAT/sz11N56hA8kaY0NUYgJsHByS+FDUjFH
S3F2GDkBHSeNF7mwLLxGLRtT2PLIaIXknUasKKtQcnxMYJF2X07t6yqc3Tep
bE3jcQ5mcVt2dEL6VtpZ+dcEpfxU7rrIXkg/4CcrRRGYSf058VmzHa5eTZpt
cxQ+qz/kXSwfRJIsI/OGvQD+t/Y46rkMQMEjSi7WZRQ+JKhrOfk1Nty5ve+g
3DDuFY0zKN9aRHsav//gQ5CYvtfwtfMAshwVwiv8R3D1cwkj5mAXYjqvtexb
GAVD7WjmNu7vqH2q1y7uRVB2IsTqdns9Ypwk1qpUESgMrmYuyjcgJ7u98xtP
gjYzhRiZ/bmInyi10GAStL+2C7By58Dvve7p6nMUvGQdMkVr2rDX4mHa4ksC
bbtvzq0V6Ye4nemrGmshct4nb8i1GsCaTXIRSzRen9r29C9bs2FUXJ9wWpvA
2Wq3uNpMP2Q2G63fJTmGlFmpY9byjUg/vrFYYEIw83ExNq7sT5zr+Cq3kY43
2p4dWXrFxXtc/jZ9C4ERVSCprJ6H8Kinb0NpPQlS2+o4U8LBz94i0rbRtJ4J
+7SfMdlQupGxw2yUgvO0Rb+yUhekMgzWS/AoJLwtn73D7Ma66g8+36dQ2GMl
4vyJyYVha4vxyjghLl1VtT8VNIAT/Mlod+EY7uGEdOaZh7Dscfpr3I/O73F4
vWV3BaS0psyq6Pzj9vrmYQs0n1SZi8HNFMIKy+cP1PXiF6XB6Y4lgqj4kGfs
0l5cW613vGOCwPW5m3X2DR6ORmydZY4L4J5UOlkQ2o9diweIqIMQMyqrnWJG
2tHySzw74wLBmq29E0aX6mF9np2vEEpQJOJOtm/rAyNNTkM6YBR+se/bvZ25
6N7lvmHlIyGkNzN3GARWoUXnT+klen7KsgvlOn9xcepVodHDaCGqHkdKjPT1
Y/wfX8uATCEuC1bt6S7tx5Pg9Cx7RwIT9RjVggSar9qHd9sME4T/dmGo7Ks6
9AQ/vPtenEA1a3pbFbcPcwK1Kt9ymn8cjcp3Z7swfsWlNVCWguDIYOEFkUA8
4Oi8Y9F8W+5S8qpta4Jj8ueRVkKhrdnRQi27GcKa818xpyj0h3M325oOoDmq
YcZvaAzjEdd1RJdeQPSZzfwh2q8SFQP+Djdi47c1Mnte0XqWtk9ix+fbDfgx
Py4jjdZf5xn3t2deN6KamXiy9B5BuUbw1x/FB/DqhNKVSBUh/hYmB/SqdIOj
2m9HLQpRtzn4eIxUC6zWXdMKTCJIKuVqJuc9R8/Srsxc2t/e1d4SVIw2QdtW
bKdZDcFQ6mXdOdt6xBcuZaq3Euww/ImZ80c77ux9xP/gQXCw1VIkN7APjm3W
iV5lQiTYvTnsrvIS13Lzi1dbEXi4lB6xM+UhLH882yaP7sc1llU6WYlhBzeW
gwrNN05Xj7Z9I2IvJ3xxpJKAVRkQOOTxEqv4VQeX/Wg//sHu2JnGeig0zeu4
nyTw/0OMVfKmG75ylmtSZkcxo1m0AT/cQmxQ74WPvgTyYd1DPT69yPn27uKi
C+2/U/ZNYhaFCLfY7q1Fx3He/4tIfsxGiT2/MiqXghYlkV30+SX02Q2l+ldG
0PCFjIjfeg5YzJWOxW+F0B8tiuGJ8HCoK1JyyIhCmaSHtN7NXuia365To++D
t8NxIWy7PjiESx5Oz6Kwz/LeeZWdTbCedPEbiaDAjZJciuW8wPxEm8RfEgQt
Yrv4w97dmEtt9XBypui75kD0v8x+CHMXMty+oDAhriijPNOIQpvoxn7aj0J0
A/ca1g3C9fDxLA16X9ZED9/vaK+Dmbzpu/lqgh+TM7S+9eZBIal+d/nPI5ga
LLPISG3GVpZQJHzVKP4D97u3Xg==
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns4lVkbxjdJKEYqFbumCVEoSRHlzqGDJlFEKJXDMCVntSPHUWKcohw3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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 61->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lWkYxm011FFMKdek6BqJyohR0cRdkRAaW5SlrEnUJSdCGZFk1CGi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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k0lG8bRiq0U0IyQpYWaSHZLkpRSRtJhLJWiuxLfimKUsjShmiTtEll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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx1GMZJv0a+o30mKJpjBJMeGDq7GNkahUZAsNFSOkooSkVEjJ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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk81dkfxi+qMZiuyjKNtWtncJWaRD2KFjRNUdYShaSshZSGkqVF1lEa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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 62->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk4l1kbx0mL0spMISFpRslQtqamvr1SUm9NE0oSoSwhFRJR1myFV4oQ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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3lUTP8bx6cURSWESrtKtoQKRW9fpbJEQiIiKgkVrUIppCit2qWVSki7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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs4lHkfxiVtbXYdCgk5bsWojUptOtxDpOMrsm+SxDCRHHIoppPD2nSg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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk81Wkbxq2VHAajUpG2QaWslVd0SaV4hZlBx0yWotDIWMqWKLTYKoRw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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 63->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8VekfvkwmaaSFfhGRMBVCSfUz03Onacotk6UFyb5VKJRlRJk7UqZs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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3kgVPsbxlXKUolQUtaIulGpROiR1K1IlGS7luIqKSFRIpUlUslSrqUk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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx6Ui/ZiRuU2y9IsUJqSaipIPcyMqS0VlyRIaZKsQhZT1RpYS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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns4lOkbx0eknxKrZVOkpoMGhRSbki/KZLVKyJlIpGWZNkqFRESpVESI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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 64->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs8VGkYVtlINbl0p6VSCimSW/JMQ1LJlhWK1UQi1aQV2Q3N1LRdlrJl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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k8lGsfJtVRVJJsqeioJJVkS+pSSYiUCnWENjqhJIQWJHEQEiVRyJYi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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlns4VOsfxadEJacQIirddCJ3RaGlklN0SqiQ4gjlUBLhoCJJRYxLfkju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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns41GkbVlsU1W6bRW19kcMqtpZSkrqVdiSnRbUSVlIrh8TnHJFQyaFo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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 65->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs8lVkUlYmK0CAVmpAKIzMiw5SW52SkGHM9kpCSZ26KEgmhpJC6Sk93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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3lYDe8bxonSJi0qSyiUhEpoE3clSSlJiSRRkaSFRPuCZEuSQn1Ji9Im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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlns4lOkbx4cQItr6SaJyKJLNioqir7WtQwfH6KhEOsiZxUSS4pqVM2lE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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk41dkfRjcVKluijKVFJq2URslLm1Jkm6RQyDIl1dXYB2NU0gyRiV+W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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 66->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVms4lVkbppG4apoUSiSlKUkGSWnoptTgKx0IY4hkoxw2KpWMTyIyziEh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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VPsbx2VLUihlSXaRCFkqLZ8SoshS1oSEJJeSSgu3LJUSKqKobKmk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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs4lOkbxx1ap02bUi2SqSZJJ5cstuIrOa3QOFTIryQ2pNZSRlGNoqO1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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs41GkbdvhEK6m2dWiJTg4RQ6lVttsxFaNZVGwqlLTZZQqpsGnWKaUs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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 67->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekbPkgkqqMsadIoql+YqcbWolu2IhWSUmMrsmslihwpRVlDhelK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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk8VO8fxSmKylKJQpaSKEUokpwWCqWUSJG9skSIUBGKKFkqIipKSEJI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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81dkbln3XNC2mUSQhlNapRI8ihEoxjS1ZyoQGFUYhLUYSEqUrS7ay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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41OsbxqeTLb8iSYt0rqFOyRayJdzT5pyUpcjSIiFZIg3ScRqkhJIk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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 68->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlndUVNcaxccgCEgMQQhFfdhQsADR5GkQ2BgER4lG8ixEiNKUFpQWukqI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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VO0bHkpRQpItS19JtoREhFuoT5LwaZOyJEVZU6lUiiQlS0pJUrIk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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk4lekfxlFTZJ1CRnRkSVJCDSV1V5YylpAGcWKMGpW1EOnXESrbtJCt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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk41WkbxxVFaLKcohqkGVLqoIak5UuT8lIke+RV9l2qkZKRpcU+jYli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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 69->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkbR4tK6TCJVF+ojEykmknWn0qYpu0zKhlT2Y1RouwxiXRIlmpI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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k8VG0bRkVJokIkIhUK4U2UusiSNiSUCElSypYXb2mTlEgIyZ41u7Il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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81dkblmYSKeugIUuJhiSyFNVTNBGKIYwQWRvJWCo1hESWaRGylSzJ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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4VesfxZHKUIZug0qFcilDFLqilqgbkmOIyJg5kX5Rt3BNGUquqVE3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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 70->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4lOkblihFEWUlHchKoYNhd7bonrXOpOSwQ0ItOcXKSkiaCh1+tm0U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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VW0bxVWGE0KDUoYiKopKhSjLEKmQlzJFIUVKiCTKUBGSVFIpkpAx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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk4lekbxy0troYokixFUSRJY2uoLynZCuGQLINqNIQoQ5ZSkiRDEUIK
IzMkS1laLJFtshzH4Vg7zvugkBoJJfq9vz/e6/njvZ7neb/3fX0+96vg7nv0
pAAfH98d+vn/6iClVvyWXQ7rotym9MMEX6KVFkR0OdB5Ny5t94YHpaGIve91
ODgfKbjaKHEYVtutx1cfLEeP5LDf1lSCFNveQ2E/leGyo4xtKQh+3Rr/YWXl
a+gqczbttiforjN245euR6xgj55EJ4VoVUfJIE82joybrBtK4EE5q8x3ZH8j
pk1XDRivH0HFjmPFt6fKwP2n5dFrO4IPgnHpupdYmP4usU8lkIKN43bhYnkO
vIKTYlLshlE/MdYi5dGL423bfhQIU+ALaOjKPJ+F3FzhHaa29P7gcJ+8yF6Y
OEu77IjkomjyusEB6Q6sXWcXUM6lQPQv2g4ZtSD0yXh3VBeFLpm9aLvVAZ2F
9bxmCwLeeh8LtaV+bBT0nBmPGIL5GVNf289MnE0f/tuazueT0xNW/LkF8j7u
YzcdKSTqH/zRuKYBxjoHE4wyCGL+VBssEe7A4WEoLZUS8J0p81Y0TwJ5rJBA
uRKYhA52RrmUw7He2+SyD4GLrtFrWaoLGxLbItQFKMy+N0spde1BoETvozfX
RnC/oraUX48JZfO52ooogo7swCab4Md406SaeuA0gfHVzl0ZRt1oUMmULBal
EC+ZTX1qbkXtGvs3yb8Q6F79zPsc3oOwv6rzY9ZTkFWsMpDe2I973nsST6RQ
SK8ztRfjr8HHbU/l7zEJuDV98TPZtzCUV6Ld60GQY5TE/vVZE2b9SyPUAglE
z74rS01mI8efFbShnYcnE4YOtRuakclsV1u6RnDByk97II6JSS3mu3wRgoxM
pL2NYyOjbPqH6B0e/M5ltcpGsDH0n4Uy0R0F95WzU7N1JRzXbl++N5fA0eSZ
sRw/C/kPug7qj1JIKZxTNfunHWsNdOp1Ygku8SWtaX08gLZ09prMUApF49u6
bo1wIClxQTNwN4GYfUI7n3gbPLu4AaE3CYS+1G+21+iBHf/LS1YbRpDefMx1
aXcdGlvU/9xD36ffvtFY4wkbM4JbpWyseUgXebTY+LIZq15oap4poMDdZslY
X5EOmZl/s13dCWwFryQ1JrYg01chMEdiBPKCnVd/UmDju/Yn0UMFBOm6lJvy
fzXoGqtxUKXrH78nrM14sAK5HUPMDhOC+S0trx5nN2F8IPyLJc1fnlb37Ff/
KrRKB+887UYguW/nl/DiHhxVOme8zJ0HMa1VZSuj2DBJSyqsNaPzHfNzYzys
QpHPUa7dHgIrQ5PJ3oIWZPW/XVTQJqhZ96lPms6nfvzuxF0xAg0tgYASSyZc
c3t2+9A8DSsuiHNOlUG/OmZ/63G6vw/kCy1ruvBMfjlRZVIwmIuUOajOAlPc
0t2fn8Ik8+ueq4840AjOUHF+N4JPLa6zRpv64F4S0BYUxIOkTmB49oce5C53
mRO4RfMoHNBtHRKIgv4oBYFfCWRPxI7VFHDgk23D/HuKQl5xt8iwAwd6qS9i
XIRHIMX7dszGvggxJxWnXCLpetzpSF65rxE7vixMeZgT/Jh7FsTSY0HqynFR
UQ/6/A0hdwXlqjEvzbfDq59AQFIkbnMsC+Y1Zw6tc6NQ8fDTkaiiPrq+ydU3
vWn+4g6uDwg7BYF6jtKEC0HQq+uMEJV8jHfHUEdpnvkis210+67jzZPLwlIn
CGYZHobzp1lQ1Pw5fYjLg0JDos7nD134y++cgJcuhbPJVx6GMQYRGyXJWF4y
iH8KNHf9UfUvNujeZ9nlExi8oBw9+ZPAmI1/OUnzbjXn3Cj3ZQApfAJFLVXD
cMLh6UqtZiimjFYe/pfguYjOjVP2fdDdfvHjDTcurLyGs+8XsvBJZ069+wGF
X46XbGbodcNg58TKhRV0/hLxe+eiAjGbYzVlTZ8vdsCqKXW+Bpv9rZmUEcGo
iEzXcHsj/Oef9V0+RH+PZOt5aeNquKwoNBv4SCF5frKyCf1g/O5oc+MmDxtD
ZVJtPJm4P7G/+t4fFOZ3LzPK/1aHyxpFCwaFBC2GZ7zujTXhgOlo1JWnBJqL
2l+XWEz8Eu3FVfSk0ETaA+rcyjFZICSYrUr7qOtKkuZiP6oYzMmUrlH4FQ+k
SIc9gYOKp9+F23R/p22lTjqzsSpLqyzaeATtIm0sztoBGEQa3rwmzQXX/2dj
B7MhfLMyifhYOoaq+JNxYn1M+DinaQ2H0fnFdfJlXqdB/WHHQrwn7YtlnvcU
l+phmKNm9ngvXe+i+RmeQB2UwlXkcnPo/EnOj+T/6MB4tjBJPsKD4u9Vd4Wa
HiI+Rak0muYtUeV5p9ORPLh6mvoVWxKUGGhGS090Y5dLpRxTdBRVF5fU0h7V
oCMkbWMPPe+OHWk6m6rOhkdbt8oBA9r/1T7v3Ve8RYKohJwG/xBeaCnX3ab9
+z02eu4Bi8Dy6cWSyxZduCuUmGCWyUPa78EHll5yEGqkJstP8z85tcVsJmIQ
3necMi3qx+B3oS5tbNNtpG/dJ5vhRPvrQUCIhng1NJtcXK54EXB6LmzbZd6A
i9OO2sLPaR9a67h7r6zFFpt1wYW0nzirbLJSy3vAupijwHGnYMFTvpQm2Qj9
00wrx5MUnIRSjuqsZULv+6H76hUEBeKVqxcNXqHBppZRnEGhJMDDwWcLCzum
b198mECgeFW7MN+hG5Zm75edPk+Bkb+/PODtc1yVMp0OcaTn7VxIq0YBG9HB
ci9iQun+Lqr5XvutFwMzU1LCp+j56q3VlpPVhnz9vNWqtQQOyodlVWaY8PLJ
1H93g+Bxp8vevDedkG1Qee2aMoxLEuEnRM3T8M17TdUJ+n+gflG9YLCoHR15
kZOGyyiYWl5oveFK+/+UvZDHWi50C5bHeLNfQfupTOuoHt3vzzZljLgOlDTH
hbztI2BIcVerxbPwm+9IfKMU/b7oKGvkWSxUNH74rqD9JH/E+PzEuXbkhH0t
+0b7oCS5wf+naRacPCbFlGm/+Bxys4jIYsIiaNV3oTnar4JlGXEe7rDqyane
R/O3bNPx5fzbWrHTcCZvtxXB/wB1RK6E
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk8lOsbxodyUkmUZAnlqESl7WQpLmmjJISibJWlCIcSFTlISLKTpiSS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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 71->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekbpu1wWi3jZ2LKVsnYp91ym0o/lYzdpCyVbRCnsiQGZUkn2ZLM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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8Vf8fxyVFg9BUKkUXTd8WSb1klKwWGnYohLYohIpCkaRshYaQVRmV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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk4lWkbt0xl7OVrU1ORDELZmkr5SSRCJ1NZSrTw2ZfIaKoJafkKWUoL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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk81NsbxyckkuWmRdeSrcUlW0Td6iOKst24ZSwtSHFHshQmUnNLJUsk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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 72->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk81dkfxmUZkiUackW2MWqmDJF9ejJlEm3CFFpEaCxDoZpIypItS4kW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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k8VG8bHipKiSwlCi1EVErZuSRRKipkL0SiQpukKCqRJSQtIrKE7FuS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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81dkbx5FKg6KSiupKmoTIlGzNx75HaDFCGFtSrmpiREOWhGyJipaZ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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns8lOkXd0tsYkItklTKpZJCIT9f0sq2RLpR7iFaSW1FSipLZbcaspQi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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 73->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4ldkfv5ORIjFSSg0SKsrWNtOUT9Y2JLRRZGtBl0nTRpaUFu5kiSQk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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3kglGsbxlGEEm3anCzhVKg46qhwRUiSkJAjFbKUZI+yNyGHoqJIomzJ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs41VkXRtG4VCRyv026CFPIPS+KUELFEDpyS4ZS6TSMXFJIiulCUW7R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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lekbxpUsUTQnpEKWlF/JFv0IXSqFEJmMUpSSKSm02mYsI1mLLFFG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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 74->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lWkbJooRpglF2lGyE4qarjI+Ko0RvkiSCaEs0YKiDoMaGk2hQXYl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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Ve37xVGGaJBCIkmmUCllKFlIQuVFQqa8ml+RoQyNkkohMs8ZC1Ey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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkfxi9aiVQIMWHys4zRJGSrx5KlRVkShVBjmUFRlLVuxc0W6idC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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lWkbxw+KFiWTJZospdKmkyIN44dEjMaSsUQcsiQpqThTKnQyhMLE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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 75->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lWkfRq4sg/GhZSLVlykGQ41E6tzVWIYMvowS4lCW7DWVbeJki7Sc
NqkQxbF2Rka2TI4iO+d0LCdbU70vkTiULTPje/rjvd7rud7nfX/3777v5/69
G7xC9ntLSUhIpJLry31f/u1DfnItMNceq3O6SIEp+BhvUvAcY9+tj9K5RmG3
/kqtFQdjUa6nsM/Sg4JUy/0nvBE+OMcPq27JovBTj5Ti/FwdKjTqLlmGUQhf
MExQ3NGMDzzpmT1pFP4yOP5Il8pF+kqdK5meFEzLl78+vboXyoW6FewjNEIf
Drnw50vwRn5oqv0IhfQjkXEv8rsxJScaWrubhvnXO1/uG+2Ah7fNhiguBQm9
SzJHQsNgvEup0pTgYTBHOdpWXXCef5Apv0DW1pVh2x/Vgb9Z4aNOJIVBLceb
RxNb8RfvoQUnn4JelqbS0NMucDPHbnRNUqgs1wwKe9sK2a9rCuWvU6h56NWy
JOzF3gM5qhauNL4vM3jubtOPnhjzjf5pNMR2+csSatqQ+qbeJKKQwvKAf1iO
fwnxG6f120eNFKTtPn+cihLih9isac3PFNKE1rExYX04lM/P7fagMX8owL6y
TAiNzQ4n9sxT8HqzSfd6xEvstl879vQiDZNNe9RlqVbs5Xul3imjsPpoLu99
dy1qqntq0oMoHPUdiR5jt0Jh1xvxRB6FcUm/ruC0Z+BkbCv5wr9MyP2LA2WD
GN3yrnnvAxr5qo6XPISDWNo6bvM/qWEopZoxB7KFSBvsdJAeJXrNmQWVNotw
YPCsofk6Gvxz7cFPl4oRmydoOuhF/PD7n8uiPgqwvMgwSdxKYT44pSFC5xmS
1jSvso6gsD7BafHvoPtoO/tMr5xJoUks8ce/8x3Q9p2cOtBAgW2kJJPyvhvz
tWu/3ihDo1I7upljXwf/n8on9X+lwGJzDp4pzsamUEU1T/J+vq6GV1DsAFKM
yvQDrxK+rznfMV3WAOMPFimsaAoOE0457qr3ERRbzuKQ/SWFB36R4XGQ+OOY
XQfxV4mKbNqwfy9YWU6/dVjR2OHkoflErxPsm7+2uFZTiHa7pyvn+wKuCSf8
9tRSMCxpE2uoZMAt0txnkfjJUljMMj37Akmne7oUqygEzjoEOzk3QLxnRcbK
eKLvuVLHgPIBxLqF77pqT2NbRBqzXq0P38+9ahjyIfxphvWvnHsCN/avitcC
KfSwi9Yy9EVQW68+m7mXPE/eYLClQIQr3wwNpBJ8TyKkci6aCJDBvWvV8YDC
3ltbowIXRfBI7UnUIueD5Rm8/NalflTrTJlGd9HQ3hlm++31UqTtdM0ZPEqB
t8ZWgxHXg2y+qfRrTRqyC5lVx+cKUWM8ot1A+GCZ3bxhFt+L8cnmrAUpGmNn
uOu3zzTg1c/MDZ4s4q8kbS+OZQUKuu1fDPpREDUtNprbPoZdwO5lCf6Ej4TI
JdfsF+Dcnmyq66UgbOnMGNZphr/SRKwHOd9uCo5nTn1fjVPX5aJqSL/D7RN/
qmkMQMpnJHjpDo0LwTnJnnMCnGCa9t2gib6ugfzOhC7M1HOSDQne0OOrkwSj
zQi0khztv0r4blz6J3uOB9E1vYkLoRRue91SK7IUQvtAtUZUH8H7vN5CYn81
Zi3umawj9SS3mS27+EmIVp9VN0H6Y4Yaf2qczYaq/oWt14k/3nizK7Kz++Ax
zXVpVqcxXpFQanu5DdEHzl1lZFIw0RncfHmpBDNZ3EWK8LnbuaQkILAYrG9W
fagn/jcMDjRXYTxEaZJmfKg3hV88Dw6rG/XiivXivyrWNBwqLBrFVdVwXMPv
lwmhEHoE7MN+rTBR/tx1q4SCWDvlm6OzRfhB3UJRi+SbwzGDQV40BzdWVaie
JPooq8R9qsspQvpJtd5qUq9V7ur2ALc+mDhvEfztRcPwwwUXxvZeWJ/bfHhQ
gcYvOpXKvnv5mHGxtAmoJPgS/pP2iZEHaS3lqUPke11lZVleVh1oayoUKdVQ
sK16Lz5TVAcbfV+zsFMkP0PGWjIiIpHOrGPsJH7vN+yuZvS/QFX0bJH/e6Jf
tqB79ORztHSVXi+PobDD/tmWa8kC9G0LFwySehNm0jsmWS34lKao1U3mg3nB
+YJJYR/kQjbZmgfQUNE/z46z7kWLV06ejDMNX86dadXxMpwcDE93If5qW1+1
4/R8PVR2vzJkxZL+69wNJW5xYfcyt6mG9D8ud/i7Hw2fYlhWd+wEwfspNCb3
0coG/JFinZ5F8iZLS2QVaZAEt4zp8/sJ/uL75bONgnakykgqaP5O8iqu5Noh
zzo42nrb7TpN1hPyncy1LdAIW3MxLpXUU+v8LOgogPu4nAWL1BP9E9knkuMi
J5nS+lI/fERCPDdSjwiunfW582S+pfzI7Buth4+BlJE3mScmdcXLty4rwlkb
CQdjsv9d7oO3cieLwb7LcHhJ1g+4v62yf/sckqmrqwsIf1Lxza+92+vhoVbv
fOQMBe+ktY89Q4QwiHeW5RK+lexujLgaCuDhnt2JYgoK9mbSLfLdOK9k2flu
I40mr8zgK/oPUZLEY5QS/xjZZ83K6ZL8NzWJcb9H9PSc/dm4ngMPt1A7HaL/
fA4vdXxrPy7ZKEby/GmEGzudTyTzyaV/BcNOkeTDCn+/2e4BuLebtjLaabT2
lQak6AnQ2vHVph23KFRxXapilkSQ3366aorMv/CfTYcf5zeCqyOWvEz+D05+
Ntj1lNWHGZmN1Xev0DhWuutjSHwr8gt0w/cRvnjshaWbC+WIHlJeV+1DzpO1
/FdhEYlIm30Wa0f0Kk1gLiTZ9iBp5+2K6f001N7WvkqzHICLeBsCKsn8iytU
nZdvR+EJtq6Y5AHn9+TaY+8bURkRc+olySujbt3EYR8BFJr/To5vprDpJz+X
tpjnUL4zU7uQRIG/RY3Jcy9E2KM8OyuiR2jh0bzXH7lQaPdd9Cf8/TF+LCRi
pB3y+Wq5l58R/3z2fthx6B7y+BKSt0levDvcJrtfVAuZ6egN3cQ/OQtB5byz
Iswv3V3HJ3wa2QePvuwYwpIPpa7+iEab2jGO/+Nu8P+79EBmkUJiY/v0idtP
4Pphg9F2kl//B4svwu4=
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk4VW0XxjUJlUwJSWQoSqk3vKFupDSgTCUJlSKZCYmcSlIKiQiJKEJU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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk8lOsfFS0q15WQSqTiahMuUrkd2ZJUCgnXWrQjERNFSkSrJC3WdJNr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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk41ekbxkUaMzHKnmRUaKEIU5Z0k5KhMWWko0JZKjFkzaBFZOzTlMRF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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 76->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4VukbtswYM0yLqEkUkamJpjIkqVsTaUKEjKJCKoxChKxRJpkaVCNb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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k4VV0bFpKKkihUkkKEUETULVFCikpSCUkikhIaJPMrCkkiJaTMQ+aQ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs4lOkbxyekJGVyaLZQTm0HP5SWGHxlSUSkctiwdFibqBRLpPDLMUVl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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk8lfkepgZl2pPtWiKa5JAt0UyeJDJiSLbKmi1LSpkyzC1iSnbpxghj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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 77->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4lOkblu1AIjlkUmSkJTlWRNm9E6uNVZbYtlRS0sq5muTUOCZpszax
K5pKopwNY4ucjUHGYRwGbbTfN5T4dVCpRb93//iu73qv93nf9zncz30/TM8A
Zy9pKSmp6+T777+MeVlLPWoQHt8sfa8ZQ8Netq6TXlsKnzNWaue8KLDdF9HR
EhYu609NWxyh4CQZKeQLOnEt4OrsOiGF/U9DJk71tYCro/6NaTyFymW67x62
FMLIoc02+xgFRoGhr3laNW5FVdXxgijM+r5YKjdWApXz9Qb6xylo1X1W0B1I
B3erMLib3B9r67boN00+5nYeU+JdJfspbgWTN0QQbTSti22iwJH1Fulkp+H2
3e1zHcTedsNyDc58F5rkRMppPAqdd+KXbDfMxXyGecq9oxRcdDsOyivz4O5z
KyfiJIXUb6cM0gVCfG132sW7mcKB4nj7Lzb98BAqBYRL03ht7ZbMzBnCQIh1
UEA8jRjHvNGzUv34nf/x55TjNFKSvdX3j5VhcMzEnk/y07lj3HV+Sy2qd1t5
9PlR0LbyiU7OFcIrX2HdWDWFYIOcfocvHdj6Vsd7y0MK9m/6c0+0ijB180LH
xCwFf+3Yea+ERnha/2LMjKLwpe/iFnOGGKvk3zQaHqbRMcFWtFNvwriiqc33
JB/tvNf6TOM+tOT62cXq0zDYdbZ4/Ew/er9e4hK2nca1x66FEc+eghovdc2P
o5Ek8XMN83+KpLMxzGA5CdiMJAuV7kG8dKn8+xqbxukaGwMDdRE2dlzoTVhO
Y/xJeek/iU+g5JNe+KiAwo1RybNp934oGPk7z2wi92s83BL+ex8mNNrGWYY0
2PtPS+r3CaAp67BIM4zgITd/n6yaGI320p9GL5L9A+WLUNCE3j09n5MvUQh0
/G1jdVktpvIrfCdDKYQ7czZEBgmR7Cd2XltBYT65WequshiVExsnYog/u6vv
yqve6YNt/sywQIOGwqqKoR+ED1B8M9jmiicFKb25iYS1ZqhqNz1rQvCg9zaI
Nv2hDF1JXgcvnyD4dflF+dI/j/HuvM6QdyAFk90yA9KUCAfuZ4ZVfkXjxxVr
yp0/9qFAaZhXbkbDKdFhk5lbI1hqLHn1CAoeyl1WFmWZaDgyFLHEgwIzy6t+
8JYYBQZdTff/oLHMfPueuoxe+Ov2GrDeUVCMVJS5hGsYdSyaSCP+SC+80X5o
1zDYezx6dPxomBjs3nf+2T0MBxpsUCX+s//02K9W9BBqQ3XmuqcovI1Mdblu
2AOLvVYp99+T+JyGLOXj8qHjYrLjv3hrnaSXuXOyMVNS39BL/Fk9a8lTWDUA
D4egtb/Z0oh76b0tqk+EO3+vEci+pFDM8T16rLgcBjwB84w3hSiNOebmo31Q
5a9m7SXx7vRzU2gQDuDAyNzzjHOkXrNfHT79vwewkRiH/Ujek1nPiR2xrEDp
xTmOmOQzMGChVHx2P9pXenusnqNwUjtAlXVOAI5n4bBMAsnXtyGb5twr4aQr
Lyj1JfuclRk5V8sQnmW/J52c7zi0bf9HdT6Syjsl+dEU0jckx3+R78T4Wa3l
+oRPOK+qzO5O9SFC+Yne99/SaDxzy6/AqBwviu2KROT875+GQg6v7YeeleLH
WoK/pTMTu2pKxGDPh3G7Imkk+3cUscw6sPKiyoeaNOLPl4Ovnm+uQQ5D53IJ
qX9CKvTCv6mDp7ptQR3BX9nQj4HZnsNghKeNmebTSLiZp9L16DEirezvOhK+
0mUMufcoiDDTGWz/WoVG4NN9cmuu8iGVtB5NcRReu1cbtR7qwT3tf7tkpQge
gqz02yRCdBcy160g/NJpvcD9lc8wBBqu0aqxNKb9U8+PWAxjZulHc51rNDJH
uet/JfhLsTlaVC5LY0tCyci71kZUMr64tMcSvjDXNTDZ2o+cpVl/nHShsUZu
i0+ETyearzct4HMIP54QW6xP70Zkz9/1iaMUuFV7L7rsqIN9KMUQEz76aOaW
EnynAdw7YWpRpD+3sWRq0m8PQ0178sMxMcFj/a9Xtze2gjLTNq7OpJDM3FV7
qaYB8s7NWWORFCi9wnS3xnZIjt1ePH+D4FU/p9khKwx+WT3PrQi+3dsaZo03
1cDtyV0Xt9MUTrzTCvbQ74R6xYJlyYT/pL1hw6oSQEEu1ijgJoWD2gel/2pt
w6Fhnc9O94g+DDPMVAta8SiQ0bWYxPOn7jbJG49uqCfsqJ7sIv1aP2JX8FMv
bu10+JD3HcFnacOuIsUEhCEi8SfyvpaAV69Uk4yBSEU7FllP7z0xaJZzA7lH
51XWkP6orDNeusSOA+fYO0J9sjbZasfSY8fAaE5Zdzexr10mrLkc9Qg2idJc
rj/BY550kXCUC1zRS9cneAtd8rJ3+YAIXhvWRbw1orFik2HwkrZGiBKjZUKT
SD4ysjZayhzEqjKmkel//pjxd2/UFSMhg/HChtTL9vmkZnVWLmQeFF/nEj1i
Ry+Kv1qXikzGS38esS/bJh3ytJqP4lfz36kR/u8M4PXUFPDgm1+3Ou8XCvGz
LGl2KB+DNn0CLumX+6rnai12tCDfUn0ynOiBJJ6rMxHXBetWGWFjI9HDlpLi
7zb3Q/BvleWUDo032ss/NwpEGHPjlMutpOHs9LjgvE435hfPf21N+GXNrhWH
Y+aGoLAzYo/9SRoyWfpzqaYDUD3uJlCdJnxkL3Xk02MBjq7iCRuzyPuDk0wt
fjdci/NKaVKffIb1tZpPQ/iqOfRZTguNs8Ib01qOXPyrpOzpT/SdbZ7p4lVR
ix+Op8+phlBYOErPGobmgrf30/wbko8Li2JWrewfwAsx33Ga6N3D3uGZxCN9
0D5Vzn6vQGOh+NiGJ8sHMJXmf0VhHw2VX7vH/jxVDf16Y8efSD+H7wzRNv+j
BN//Vbl6lMwbD7Kd5cYe9EMSdECjwZXolY7Ww7hmgvfM47fqbxJ+v+y24vCj
diSxF2zWzCbzSELsgpsyzaj4WdChdYXCuLu84ZvZNvxjlLc3LpfCh5YnYk1X
AbojznTEkvkmofv2+3KlZtj9vKB9JIbozYmMPYneFajMSH0vIfzqW9U6psXr
w/0Piy2j1Wj8H8cJrF0=
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHc8Vf8bR7RImqRCZIRKJYXyliRkJQrJKElLpRQlK30bRsgqIxnJFpGZ
m00y7jWuzb3nXjsjtMTv/P46r/N6nc85z+t5P897nG3nbxhf5OLg4LDi5OD4
/1Wb+21pUEYWtj/Qp65aQUA80l4i8VszkpgWBzxcGDj77JWan3ULEhPdY6xX
EpDhjHF1D2jB2Are+zJUNnRPWs2ucGiHWufC5Y/Cw4hYmkVVl2rBacukUw/W
saGuJShu45oE77wXGuMmBOTV40SUljWDHWl5UFuEiQXB+68ND/WgPLHVfXoj
AzHW/UPnVOpQd+XCiLkJE07m+V/3ibZBrWPDc/cNBGpq1S5zmCRAyG2F7963
BOoN/tw5/C8f6eeMNp6pZEIsuk7C6WU21vRYmk7tIjBU6TH1xr4QPNSTHvu+
E/D0/jnhe4+C7Tc+TYjtJaCetpwZ/7MCgge2pog9ZyH1whfe68saQLX+bhxQ
zUDsOV6/SJUSsHt+xBznZKFcJYrqq9qAvpr8Sxp7WJg84Gqsea8N8m6BCqut
ByG/kN6jp9gIz12Sk9muLOR8fFgrENKGLG1FHn8vNnxki6iqLo0Y3LBgn2jI
RNPLm42tol/hvtJ18/cRFprS7ZlrrmTCo9MjedCbgMlpRvey+SykyypIiCwl
kHVf9bMrJQ3sZfLhSk4EFGyOy8b9KkEsnSfQkcTndKPYK3pREB48Xf1QQJ+A
lrTMxMj+Zhz2UYlh7GHA5/SSuxKUz1gRVHd5SJ6FBrGKxUxHCpoq7ybSTQnw
fEo38vRvg6X9xkYD7VEI6C5W+21IRcPRHJd3DwhwxPG/fa5uipbRdVmS1gQU
tfzeRm9txobjCk58kQyMbZO/sja6AULmJbMFbiyccuZdHM1vgxBzcxhNYwjB
dXWtokfbQIk6YKorz0BugCdltqMPZWfuT3ArtMCFrqgJjgpoCxwJ2r5AwFhi
yTovRToCHqoN7F49hlsrOM4YzdQh1LIg5ttzJmLZa5nLJ9rgpxc3VnxzGCbt
YsVEXA0qQrS8PjuzwVFuauEwXo+zQh+9Ej8SeDq7fuZQRhHCpJRqHLyZ4I5S
lb3NasfmUMW82oNMtK0Vjw4vL4PxsD7/uxgSn2X9Fk9iSzAjNM2ZL04gxpFt
4pbVhOlt8d+UrjKg+PLElIVlEyzqnyamprGQMGyqNiT8FWoR960Mylgwqrp7
yfVvAkSUK/Pa1Un84t3/vOAqQrTaRg45cv4m93pd4ulKAhf138sjLgQS0iWc
xDyb4Jhy/x+HPRMVzrmG94k6lEa/ax/JZqHbK2Aw5GI1VKqEFgu4WJD6XlWS
QbTg42dx31fhTNjdVk0ypNVAdnFnJg8/E5pnffP3TNOhd0d669GOQaA/cadc
eRumXnY22skTENg3XBG/vhUVnN+07vIPYonneo5wyV7EiCd4ZX0dREbUPuZU
QDE6f5zM/XuTwJ0007nmohy0BPZnr/cgsL3E+6drRC1qLfbKdU4yyX2QP2pE
y8aMdKys2iUC1g3jyVMjzTgSojk+YMuEjPTBjkJzKqqX6lvbGgyS/PB49sim
Nhgpu4j+ih8E46STQPObONx5oep87iIBe9qTkIYGKrRMn3uIvGajv9Njyq7o
C3STD4bZGLPAERnJyptKwbRMr62kAYlvV14r/QUNj2SeRFWDhS2/F6U4Rzow
qbf42HKsFzVSoWmDrcmQcxemrrxBoKzXr+JsViH+aPZlr8wm4FVjkfbWohLi
EvV/ykg+PFF8teaUchPyDdicTRJsVL9U4fEVq4WY/pvpCjEW/PQX4z49bsRB
s0iHf4ZD8P4qMRZ+qw5band+ivtKINcqvSDrcjNiShkh+qEMlD76LqrW2gyK
xAfLhOUM1Eq3ihQH0eHIShr5wcvGFbejB+jytRhKFEuRJPdH3IP24F95B6id
Bp2jlsNYNlTOnFpSBUP/Gcq0KAvqf3daVU08R0a6xKK+DQHLyEALyvoOHLlm
t41vZBizkw/zGa/aYWVyvjeYzcTQtEH/nAcF7JNxXUXmBJZTTHZ2c5Uj+IGu
Dc88AeH4FdJbhJvB/yqOVavGwj9uo5y7fH1Q82WaPu1koPycx2DO6Q/4/lLv
1prn5PN0jQXPL63oafzu9GiAwLVkDkpLMhUpgna/vXQGUDy0oHhzcxmkkoci
1gcyoW5e6M85l46Ez6Xqp0m+cThfYnfGpwob9V1Gb9GYSM70Uw6P+ooTjyub
k/VIfs19sHVPdjo6ywYOmGwj8ObumhNOLa2QWR7FcFLsBJs19GBXegsSNnSf
7WOwsaPsd8YG8W9oFc9Vb1o+AOPKDwJhR3IxbaXEu6BAQKxJyP7n0kqodJnT
LpH9MLmm61OlVgveLwkuR+eYEChsXbRnBkG7THwg1YwAZU3sfV1tHyjuORyj
Y0/OY8SQ/00WDccMM3p2tTARbCVYJbe7CvmzP7MPbiZAqCzOm+vmQSox1ouD
7Mec0p1VMnvbEfAnXPnKfBeK7aTf/Vmox3/8nqebdJiYr3/g79dfj6qBnh/9
I2woKn0t3pKUB/F9DGducp6zDul9+lyRiktukhK2SQRGgn4sKqzpQjarMfXN
5haotPQZ/vyvE8ahl7Xkudh4/2TifTR5/2uLfGW1HYmbZu4voW4azh57xTPh
ycJSK63cB3nNKJDRTBedYOEzxGPGt3eQurrj2d32flD21vVKT1mgMPiY+QWS
38U+9nluXRkPg7CEHzUOBJbIcMffSqzG1cclrf/WMuCgRrPNL6Fi+/1ce1eu
Ydhw2b6ePvsOUkpdeg9PkH5BNNK2+E8bvPuqwzsLRqF4uSgw+U0LqkZ2Nw9L
sSDwlJoho9CIuUN79nC+GECexIHwgnd0FJ6deLaejw1Z4Ytx/95VgP/XfG+K
EhviKqGTvGk0rO8stDsUTyBiZ5palF8Dss+K7VbiY+FQ2VC7XOAXKF6fWG2q
yILbkpxRlUPteLcu74hw+gAqdJmnnWs6MaLVoqU52ovtkqES+xraICKfe93i
UT/SRszauUer0Wt4jncDqZ/cvy+vLd5ORUtbeEL3JDnvfy4lfq5vRRdCPzdJ
skBcDEXC2zTsChuXvEry1eFDoq2eDaS/uLjuofRyAoyt70an56ngSklY+ndu
ENvXHdVJf1OCtgNbNkfUMMExIn9zmYg23krJzRiT/TY78OlY6/aPCDDqtFve
R+qPjKvxwbokdN57M7DXiIB2XsvW/o1F8An/fmDyGYF3hHtSmUI5vpamhp5o
YuFKTaLj3oImuL3juq22yISfrb0MVbgb/haPh04mDSOB+FVBsWjF6pEVv7et
ZSIi8dpsmEAjcsYou6IbmdB22uhxKqcaBa5TJ6+dYeJie3P5ip3fsKrj42j4
KBM9NnGxtZN1EE/wk5biJ+t9o3TR6l4RlPcbjl9rZuKXo79+cnsV5IOcOT3e
siBWSh/Zql2IiLuhM/f+I+B0KrxW36kV23NSL0h596O/10fdaaQSphwxwcpf
mdAalZCrtG2CygXJgBf7SD2uunCxKKsS7l8qWbzHB/G6/KyGfUU1Qs7EBh4h
+Sd2xe57ClfrQHC6Gnr///3jEJc90o1W00dBvby9MLy8qrDqSTnu0srKMnTJ
fZJnlP2itMD7yYEuKqsfZte8MjeufQuO9x4ZWWcIRAXNTQQ1d0DwTB/LZtUI
iAKNhOEllVB+ttXS245AsbB3o4F9L5Tnm2mCP4ZA49zgNcdJgQG9UOkRqcf9
ll8F730PxbYd0eY5pwn0D9aPJHjkIeS79JN+sr7Y0OKF6y1V2HvtGH/5CNl/
r9odTR8rYHOw+P1+Et8/tF6rGOEm+Ox0Xll/gYETjid0qjZS8Vv94vGkx4MQ
euE7kebxDQLlSbbTcgwcztiSrTDQgsCPbo5X1dio+nAz2vkDHZO6c7NucwMQ
CxCOOPnhA5qul7w8H07AJcxPrkKuEzc86AJjO5joixXNOHW8EctyJff/SB3A
wRmDErn7OTCmZxpx7iP93sqMrNTOEphqjLe4PiXwq2FRRli4DZo3nUqi45hw
2OvjqzNaD8ljHFWiCQSENE592jbSiG+bPFZujCIQHKzt3MdHx9Owuf1+pN8i
XGJeLXepxdhe8RNrgxig3zIqEOb6CCHR5ZvidUi+TfbLtZOIx5Dq9PVR0r9n
hz4Op12lQkIy8JSnFQPd5TU6/UfKkfVB+2MWF1nfM4ulggGWuGu+NkmD3J+a
U/NW/FMUTA4FxXzjZmPyy51/m/lIv0yLezEgR8Dn2J9Xsn+rwL2tMW4PB5l3
xlOcI8i8sj3q/YAgef7pOvsdtOBPoIoXnn+2hkDa6aL93B49qEt8phd5itTP
pO0j5l2ZmLySdrFdg4Dd7r9nnA7QsP+6hVM86Zc4OJVvJ8glIH/FudKxQwQu
nBiPqXb+Bhuz9f8MBNjg2zujcruhCR0iB8x5FlhwcN0sORNORaBDa4dAMgt2
Ef90Pvu0w7vDauMXMq+kHedSy10sAyNSQZOX9BvLA42zHdaVQEWDNpfZS+Kp
Iv9YWa4c6pa9E7k0Fk5/vn+vpqsJ8eJsFl8GiccVnv09ynVwVDFn7Cf5wngg
jvciNw15t32WFioPgtKYb/rY8hE2a9xn61gRsOGnxiuFteG9g8oumWmS31Xz
/IubayHt5r44q0bqN09HgW5nIrQ+ywU/JvXRc+Lx2mqWKxoiw3iWkOezIjkX
RBeyUbeJUadTRb7P2ldX+nsMPhbHKj+8RuaLa4ZL3T1o2H2EV81cgMxnbnXn
CmjNCB5yrDtewAQ/2/r1kzUUOITfXuJ9h4l8x7jRremNiFWgehjJDWIoSHbE
vqUExa2rpJ9Ik35HME/lh0wNFCv7TCTzyH3qvZ+zISQFM+sKTu2KJf3Fmbds
C95sNBzYM/KNRqCcrfxS718buOpEqxI29sNojKf66NMU3PhwQ7T+JxPrvf12
SbgXQ1jA/HwpyW82G95sXGZUgHtPL3mLlxOo1tBgyZrRUSb0n2Og1yDcHQPp
ntO9KLxp2P7t+DC6b2+L1Z+lgb9ueT61ngkhlxUd19QpSG1p9Mm3Jflgv5+/
rFMGZLkzZ968Y+LLm5cjF/I7oapwP2tKahgPH0jHLrtBw02r1JlPdDYoDn+r
ufQDIND67Pn5CwTihJTodcE0vMv0ZAXVM9Afu8b49pI03Hk4u7lyJ8kftdWp
87vIHFWzag5KAxDg+zpmsUjH+nx1u8NjTBzaomHeE/4NfK4ak3yk/wtM450f
vVaOLr5XJzuOsZDtal3Ck0HH2IWow2rxJN7XXkr0/o7GZ40U1xDy+xRZW5P1
kc2wev/qlvUkA3eUNCeTr7ZCSePf9sdDbGi3n1mvycrCmiKddjeST9/LSh5S
2pmA8wvxBdpk/umVIv7lBJL1q9xh36liw6LwSsprSify7kamVnUNQM9C72T6
GB09QX9FdsUMIWFRQDOslo51HA9CF6sHcKh4hh2aTcG0rvGXUXI/zeZcz2i0
5yBQ+ZKC4G4CUmt+GJQubYeG8+8+YcshiDLXCilvaAJhc/IsdQUbETd96Xpa
tbhX9X59jSrJFxvvyTOrExFzxXI46iHJbyVZwyKUD+AeO1ZXTOYbhbWLbczZ
bvz6T8MsoJvEM7yN+1FwFt7bEtNWlgTUhiwbee7VwnhTiF1TPAt7zi4zWLje
jaiUH8pa5Pf+nF+b6D3bhvOZu8vcakbgdvaT9IqsCsxE/YlXcSPxE6nMrFha
iICALeohZB6UySm8yYyuwfdKPLvpSEC99NPgDdVEhMk4HDHbSsDIXYBXPucL
5iIrRRpbWND4JBuQ/aoTH2LZ88e2MkC00OaTVlHhlPX8kTGd9CeSaazHqINd
TvikXxcLjvqunUYmnUje6SWSbjcIpX452YD3LaASw4bBIwxkDaqJLJtPgLdF
4wNnMr+VmvwVUdlVh9PenyrNXBgwyjPnLnrfjOhT8of/7GHj4EH/pzrh2ZA7
px5ELSTrH93GcfhnDWau81eb6ZN6pKDzPLuzG4r/DQQcpw+BO8jw9euKSvxV
2ZNdQ+6r/uSJ9N2X63BJMND6TQgL5RXZv/6W0vDhSclDL/YA3vMObyj9kwnK
g88Ke0h9UbhvOd+Y/Qm+4vkzgmT/WeP9UZeX0BHrXi7DT/JzsPH5LVYnu8Av
IWCfw8dEbNdRnomjGbDv2L2jn5zHeXqC/Q12NZJNwg6HGRPofhfcGnKXgp6O
zJd6T5io/+rcuYr/C86lPBM/9ZPUB/8CruJ1PYikbJqyXTYEW73ch1K7W8Bs
qjm0k+SPydS5YA6xbHQ7xdT1q5F5KuWh9UAHmTeuKBMpGwmca/qpqj7YgdXv
VadMtQfQlMSnpmNKQVXYpgtFowx0UrIhm1OGwtBv/qvJ+g46negTLv8KRuHI
M73TTHx3oCYIk/N/e7OpsUkcAwn3GihdOY2gpJVetNrch37/N1HXqVVQmHD0
OrSPAbO9YuaBmZ+wMGHzJ5PcX81eQ6RLU8E6pzmyppGNXyemlLldghC81ODW
FOlXqVZH7HTDa+HTeTGKj8nAWN3JObHhRliMLxUP4GHBVuz0Gd9nTYh6Xde8
5DkDnhcevEu+GQi+wvSDDmS9nrI/Nh00isLlGo3wsFvkfOqMmM0VtaDIn2P2
ngcDFKnD7MmLvqhTNfIWIf2QsenBmv6FDog/VHUtzehGjeKp2TcNxTh89l5s
bxETeVc51EWX9IDLLMbr8hM2lAx2SsUmNKN+YfXjuzUszP32Dak83QaDcw7j
WmuHcAWzfRNX23DX8ueSvwKjKGyr4kieb4JLyOqIpGcMCFZ0RPhGk3pTH/+f
Rmg//PZM7vD/kYGnqsuenfj//4xcdpzXz3os1245eYzcv0qZmb7xWDqe3y3X
+ifUDw7CYvJW9B1EyNh8qyT1TT1s3K/waR96nv5o268yDH1i/c79XXRUa6qU
fL06AJtsHwPfn1+gWVyZx5NJwC07SPe1QhsoKympUZ9JfLOvHnHqpkKeJiJk
uW8QAu5npk+8ooBvSM1JJ4TAFmW2VfbxesSVCtwUIPNv8HGXTmfrNsyZCe11
JPWwf9mWyCL+NCzUV+06tY5AE+v7a534LNyI1jhzh8RLuCDebHG6Gy6ry/0M
rNj4H6uFJqo=
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk4lWkfx5m8Jk0LY+ZIxxZZkoxBi8n0janGHs2JGjSSLGlTR7xCtsQo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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lGsfxseRUnmVnLKlxVYRL9WJhCtrUoRkaXGQao6SObYoHUtlS5FG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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 78->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lekbxqkUmZqpQcoWg5hKmowtupwapcQgskx2ypIYSYhCSmKiRQph
QpM1mpM1WykHx3I4R9ZIz8tM9bOlaZL4PfPH+3k/7+d5n/u5n+v+3tet6OZv
5blESEjoJn3+e29SDX88frsJZ7badSQkE3wzbnDtT0ETZKvGIyrPE8xqLSjn
1nDgULLbdiqWIClLvaKymIveUqw9wSb462rNRZ3FOrwfaH+6PoDgxg7tberl
rRgN6/wklEgwPPq4+FALG0vmYx8JjhFwVulnDGiwkaAhmp1Iv0tSwsfibEpx
/7fF6tWeBC3mJs+fH+Hh2E1jnx2TBKGSAaLy/l1oEkt02NROMKJcVHJwaTvE
hS1SEstpfml+c7/tH4CYwME/LJhBvWWegcSNZLx8NT/00JnAY5vqjNuKbrRU
lgX4VRPk8+84zba9RKJovepqnzFoLknVjehuBmfFYGrIbYKLHpwqtnIr+hSb
xlUyCHSdzi6UcttQ5pncfCCTQMhy74M3S6+jOHdpXxKNL9vn/7Tf8gW434k0
tJgwyPc6a+OzpgSe4fq+cx4EEgH9b15c7sf623r7nO7S/F41fpj4PR7hXkrJ
HnR/r8prTshYK9gZ0t6dtwis67yvFrj24O77pR7+5gy+P1Vn7xLRhS/ndCJ+
aqN6TS/E61yuwZ7UQTOWL4FJQlLql3tsfNTX2sVQ/USFd8pt0OLjtBp7I0uF
QXht+pZ7oTx0icSy7KoI7FeZbrmwph/BgsHfhnwYjPCfhDQqFmHl7MwuDXd6
vy03QzQ147F5x12BE83vko38/l/rH0NbSSo10o/GXy43uXiyGmPqzstj6fln
f4758FZWgF3l2ZcOijH418Q4cifTi2uzczEaRgyEdo0Oe0UEQcGNW69D47FN
fjBea96ILIPp6KEwgnpD2xyWQT2Wzs8cOhtIYBGwVuzl2zuQFZcRUXYh0Ltw
vTgvaBA9n5UKVzoykE2Uj4pPfoYh15jl//FpN78gc9m0AVxWgqHWKQISWHLD
gZWNIFUl9nu6P56z3V1V4xGMgjqyjSlvFneiNcVGcjH6o7OuuytBpNWB2yMc
HkQnwvnR3QRZ/oIthZFZSH20PX8/3S/9wTyvJKATngp1hdaFBBWcyRfOob1I
8HkeIW7HIOCNZLPalXbohz6JLK8gCC/+svxccBt4Q6F1vHsEOVK3lknFs/G3
6zX9WHo++5hsiUh5A0RuGOt8T/Xs/5/MRp2hXuzj6pWd2sPAoKPEUmqiBdW7
/LXG4wk2aNeJaJoIoOLbFuGtz8DpXYD3hW+asSmaH/Uv7a/Ptml/JKlwEaQ0
5pSeQ+AyGaSw7lYVao+7T096EWQUs2x/WtaIsGnVe9KRBKyjFz68VmjAtf1n
ggOCCJbonZF1SW6GY2LMlSiqp7732cVMIx6WOjukbeHReP8ssxE86IOO4F1e
zAkGFsm++GxdBP3JGGUxyktn75EZufMF8J3mqOu5EWjOi/DFffPgFjd/tIvq
m7B7kJvX3wqvGjOzNJqf0b2untP+MVj9EH0H/+Nf68tWlfdlkPi5b8SB8ptQ
63czdEUrXC2FJjlpBD9dGgutf1IPK123XR8pHyYTJ4OlxZ9AKvV3FfUzBH/2
VI1zJJrhzFrj+OkKwcFslzXW/XzM5QRPsUQZ7Dssd/KZNBfzhg/IA9rfC0fu
D/7t141vPpqVf/xIYCDtFaUt0YU1grI6mde0vhrLuO6sRvDyVRsHLlA/DD0X
wIoshs6fYu3K9L7zwx2bPphmwFL9yA1VyofWxJX11aOduBilt1qB8pEldEti
ZUAzaj2/7gm8TvCV3ahaQu4zKJk9tXwTTWAVt8QzdroTawU7jksJaD8XrJ5U
EPsDE9Zx3klUL6GdFolRUfFQndKodaH6LLuXGr4qsxlXe5mbltmUX/tfIg6p
/QH7gcI0Ufq/8aXIMt/TDWjPsp4KPU3rdflAYGcLD4LAsEX1Jsq37UMvi5Dn
INfmVUcuEvyrNdU6nN0ATuhB7++CaX87zyTH9QxA40HpTleGwS1h55aHEx0Y
4gWmrS8g2K0ycWPfXDfko4SSN7wlOLKwZnO7bAOSDYvaiyg/WelVpwZfPIbh
L2nXU08QqNVVDX61uxyXPSK0pH0InIbul0Yf7sWBDWNmgdoMatOvXczT6oHn
cNic8gEGHjy+W9IYH0n6d9ZpTtD83A0HZ+O50B6o1fHJp/pcCTlarv4M/gc7
Vq4OJ2jP/3Zg+hIbyvK1eayjdP3b0+kSWfdhZGc2c4Ty91gyX15FRoDRw2p1
auIMLqt9ZWjOL8VrSY0BcerHytLXDW6bVmLd+ed7+N4EscL8kqH5PuSUBr2q
8WfwTk7bcMN+HurbuCfX9tL4Rl2vr1r9jqqTm6/40XoXbrZvFDi1IOyYQqbX
HQLucSvFrtw2ZOhuOjTxkPpVpMc77/WDsJxuFV5oYbBZbNa5QJELvZEauXQ6
f+z+clS4Y9+KBP6KYwlJBOZFXrs/q3Tj3adfvdsHqZ5eNsU+CqUwGNSRGaf5
hpyV0bGq5CHdtC3ln1cEEz9YFijs6sFUxdexrEMMvJremLMlq3Cu+LSBO/UT
oX2/RkUeHIDJ8rgVK7wZrCqT3vhjVR9abjQ29bozUJLzz904/ALJpuzQ5FHq
58+5UcE6PCw50ThsVUfndX/m1rCUamSppDnmUX/X0mKnfpppRqSJda9RCu2P
inSX/m33cTSux+oL5W/KIWXux4rb8Jd8ynlNeZ19+0JvW1snDHUlp7c/ovMv
c5txpaAH+dFXA7fO0362Me2IvlkOZdsZ1mPqT4eHJv1sGocg2ya1t6iGwZC8
ifmiKR/8cNGKmjeU50aDHMfgHrgrhlvsnaX6r4vYWenagpR2+5jz9wm6cuOf
sBx52O6TedGGSyBeJuyhy2mDIk4uri2hfpun5/MouwxBp6pfqtJ6v2Uv7BB7
yEUx966PJfW7d7kKPmdyc2CRscH2O3of6YUGl53CzzDh1CpXROfTcYmZ9HVJ
3ej3LvcOXM6gzDR5L2eCh0GRPbXVHQQp0xd0ShV4KJy09mXXUr0KMnM9Ijlg
98dg4SrB/wHXP7ud
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk4FY8XxilRKmklyZoWES3KUr1SCSEtyJqkklKWlHxtZZdQypotS6Ts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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81ekex211NeLKZG1GmRg0rq3FEfrYs5TByFLWkekMRhiJUMZYQhF1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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk4lVkcxy91M1nKlsYakuTSNGUZom+loZAtjMpEYUIzUsOEbC2UhqEa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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 79->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk81esWxhUhc9EW1T2KDxqQTkodetJEh9M1ddBtkFmZoiIVleFIMhV1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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk8VP0Xx6WUSIos7UoKiUSW9PhQSoQWSqVGi+x5RAptlDWFkhKJ9CCS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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81NkfxqXkkth+SJuyksbayn1TVE9NiiiJJbZJhSKEhC3tYkkKSUVL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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lWkfxnWylClhUg0mJ9GiZVQcZUxXUikTqbTZ0mQrSklNyKm8aBnJ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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 80->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lWkbPkWlxZIpSaVTyrQM05R8Pg1XGmRpIqmsdU6NmAihRYuQSGVL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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k8VA8blQpFkihKotCqBiX7kRKhCBVSSUJRpFIpkjZEUqiQJfSnVJIk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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81dkbvgxJkxbbNMhQqEEIpeLnoaFkaZFKQogsE8lgMKUrRDVjvYlp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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs0ldkfxlUqmhRGrl3ckmZokAqVx5RSqOQSIbnFKIoSuXVxSwphUoOK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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 81->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lVkft5VXKZKyRKSoMDMRE730pdRkRggjRWUfZUka1EiWEoVw6UaW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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k0lG0fFpEtqdCiRbK1I0mSS6K88laUiAiVLaVQaEFZUikSQlnKkgov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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8ldkfxyXhF2lKSfZBKVpkiSn5SAZTsrQMGaGohIxIxK2IJMmWNWtT
uiqVicpWXUK4wnW5tkbc57kGlbhaKDTn98fzOn+c55zn83y/n8/7nJ8P/7nn
iKiIiEgaef4/YsNL1bY6Lqw/J+d83kHBRuyUaLFuK8ZdrFvltSmIj92zOL+l
Ddf6ZkRWH6dhv6+0PHlPMd6qpR2dOUSDJUHrWCpykZ1y8+kch4JJXGOiRns7
MmU3Pr3iSsPbMPG7bR8LS7yFrp5naXit8pAsTG/FoY12zCBlAeJtWA+Wm/Qg
N773g965AUzd0tfMP1eOv2xZr/b402joc1sxb7oPOcF1lUHDNPQ581t87W/i
f+oCRV8QPRyjSx5qN/DN7oBKgS0NkYl1ebMDTZBszJ0u7aSgsunwySF2D6pe
jcjGkP3G4tg9WvcbMTCwgd4XQSFZ2sCW94GLc7fCzPKIvqLOk+FLa19D0jj+
yfUWCma28eV5bhZYKTZitMmNRsZvQoq2rkLDnwdVl66h0X1RVv7jDS4KbydN
ngzlQ+0Y+5owJwUGzzTH+w7QcLzzQPs4twOpQ4+iXN5TyD/twlr5Pgk2Mx8y
+sl+M0tuPf/2oB6Zro+mXHfSaDq6qK6pmAfrhOoeVQGFufLd79jcWkz5z7Nx
kqNRah477BbzBrJDWv9u2j6E7rvSZ218H0IsYiuLu5vG+z/0Tqp6dEB1+Wi/
LqnX0kXv4lQ0yxC54OB7y3k03owkah34kwOPhNnHLmwaQd1F7M0j7ZBcV7Am
6vMg8nUCiiInmuC9DfqRWRQygu+eLivkQV1VnLIXoRAu7p3QwDyPyNTDjEKi
f3GacZJcdzckfvYLjv15EO4cuakUoyqonr3iHONAI9YtU9NTuwq8oo/+v+nQ
aMt9Os0QPkPGqi+BZb/TCBhj/HDk92LvDkZuTdgAzHgbshOmw7G3rtHsjDsN
3R8xuhrfH8L/Q4h9hx+NdSMQ3bqkC/tUEmbPidKoNeLI3bvMgtgCldoLeaSe
+cLG2J3V8FVWCtgnT/xgdzrUvOcCnNxNvbKI3pCHV+PKEirwWN98bvgJqZdC
7OzyBh6GPtm2JCcTP3k06P0jdR+mOVlMby8aUcZbyqPlXiHSduhThSr5XhD3
65s7HAS46uk91aXBUJoUE9VpgW+HwPJiNg2nEIfTRsFsTHUlfhUh7xs7tufL
+zSiVOtd+Or3NOxe7vzb72M/hsqS6pVb3sLrssY1tRM1iLDDGOKJv15szbOS
r8Cq0F+ZxUE0BjdKR6ee54KtFzWcu4ICPWaYncd7iX81MwN8mmkoyxmHf5vr
RUqy+KTAno81F02WMo2asfJzykNbNwHMd5sIlz3lwCB6YrhklMK4YW2E+qUb
uKxZFPfkDxqfLtBMpZJWaEakaEuSvMrc7ih8Y/QWuxcu9uwZ4qP7cc6CtVMV
6D0ymD9gRfzue3ex/kIuDIteqZRn0HBWTDluItaIfWazk3fTaZQ7DK2qtetF
08H76fGBA8jvt1bqqu7DJwllj2jS7/DmJXNGe+pxQtZRc/d+GsuMihy2OJfD
VOeLeMc3Cr+Fu+9c5tKOxvp2v9oYGu7+28R4rTGQ/jVy5ocLjflN+iGGlzrQ
SVsdWVbER1n4/a1VMhXQ3cG1e0Dm1zNlGfsuvMRw1/r15zooiD6/wVCSbYZi
XXWywJrGKZvvXyVZHCh8mYrSDqWgpGYtv4v1GsmO6+1fk7zTJ2b2Zmb1oOmv
LCfl1aSfE1/oo1WN0FM60vuc9M/GcXup7/duLFmeO/+QBR+13bdCOak8TDMs
11YQvoz2BcTHFJVDdubUxizi35FTXl0Nau0ozLYTb3jIx4x5maRqbAvUOPyo
UUXiz+b9DJnOZzgqPPPVh9Rf4OMRoeHbBdaI4T8TeRSeJG70055P8tdQUzNP
loLB9V1qVvY8/OR0mznoRPwbbxJ5x7ge66JerJH5m4a4ypze63dsWJXlnNlh
TOpbx3/rU9qO69qL+o4mUAgWXlx8RfMx5A2ZqdKGNHiej5VEJri4I33hxtkA
wnNGpRjrAAe/Pru4VqOHgjBA8pggkwcnseNDs6EkX9trJHqIfn56tp2iNeFj
YveVKaoTj96kndLeLUD2oZJjd6VqYSIye9avgPBez/ISw5qFaS3hihsJNH5a
xvj32doGFBWUpRiICOC0Zu+I47ZWbN5VmhlH8iat+kNh9E4jmiy3+9eS9Z6Z
Wi2hzHo8cX01TjsSfnSaxCkuLMDVqpuOOwn/XRU2fo4240A2ftKRRc6nrnuN
5sLNXXggjD5d7sDHuKXGistxpehiV+VsVqMx8HFLPdu/E1dOZe4KPSNAvlTM
szl1LuKgfymvhPilpPKrpfc1uCgGlccQfv8yHic2acqG/FqXq1LjFJaZjGke
ON+O++rVAYOzFJwMpY6NyDzHw+IXAxaEHytPyJUZWLDRx6m4sieDQoiXU4jP
iUoY2qbPX5BGeDm0juGn0wijX4wt+LV8zHJzsmf8KhDl5LU0SIHG8GF5kXPN
j6E+MzYiRf53mBuXlrM4Gm2igWHmB0kerNT0XIvZqH5y/3MkmQ8ILIq4vOYf
iM1T8vNyoaCb5GAxN1UMheBPLwd30IiZ9PX6+1ArjAL5/MoNFNyTCs+ejk6F
TFuxynNn0o+D8rMF917AfDq4SjmQRsQ3qxl5qX5I5MDdeQUft/7qebFotBrH
pmpMmWdoJPuGOapfb8Ojpam9B9P5iL+UVlwyVYlifacQT+Jna/+msMrJfLwx
9ZB8Su4HJu5bi5aL1+CMzbbN9WY01Bl7r+3i3EaW7FWXBsLjcdsVr3cppcNC
WGc5Sng0XfIjY/ZuHx7luoUlWvFhbTCxeb9MNWqqBeoBhO8PPF2Z+fo8LIyd
C6x0H8QxSun3qA09eL6hfZXrNj7SJFibVPZy0bv6suC2HQWN3/PDrGT7IarF
1bGq48PeOKB4/rp+5Od4ijgYCZC43XXUp7UCPU47kjNGaVhaWqo4n+iDeuvW
ATfCI4ZZqGOSXQOMrw7qul4j5/OSUGamfA8KqrriFUr58D5qaub8Sx++F0iI
Lq8YwPfjiptCdZuhKXTUCGqj8B//YLPU
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk41Wkfxk/KMmXUlJESpSRNJktqkLqlEaXDiLI0lTXqVSlea4nKkiVR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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 82->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4Vekfl5Q9oiaVpMYakxKyNR+hLLllGiNrRAxNiy0pE1KGcittV8pW
ZLIVkS17yFr3Xrl2Kedkq9xQU7L83t8f5znPeb7v+57v+9me7waPE/u9BAUE
BFjk+f/7NruNGbm8G0GFmZ1Ff9JY1thg3HgkHX0qVnGj7hRSBe9++kOdC1aO
SFnVMIXfgv7WzjDioGS7ZPNYEQUxBxNhx6l2tCp3jG4m9SDFj8MBOR348Uft
onhNGr/cf3OgwqwDjg9LbK3mKJTbyviP2tVAX927Ne0UhbRbxhYTGlzwjHX1
ZT9RcLStF2pkdiPGbLOZXxANH1a+bKdAHyY0Vbc3n6KhdkxkrmahDX+LJf4w
LqZQnVL5q861aBQbm0fbu1GQf+e97bpbP74vP2t08wYNkdEAFnugCzkpG42y
TWloFiTZmn1sR6NeiLjFRwpyMvLHUt42w6/r5ItNcRT47bts6h824kXeyVKV
yxQEVofo2VkUYY9U8BTfh8J01AfT0KNc6H9dM680RIEnLGLnYdoFyxhVw/Vr
abwVtns0EsOFqNOvKbk0Wd/xftOQLxeVxSfeCVIUWPFqjuOrefBeY277QYQG
U2Nbr/5YJjad3yNv4EHw+SFT802bg54qs5LvlRR007dOTwT1gFOuLylymYbY
rkTu3MMOhMi61PtK0IgL22XYvKUaLl1LumYCKUivY8kti3sIP0PdgPxDFD5/
eXJKqKgd27gFpXffEH6SW2dPncyHzuC2V86HKXzYorLk6qUCiLiIVlzyotCY
KTNa3lMJxfDxn9JPkP4rRdZd4lTBMUdP/2UAhTHbCl7ddx5eXr03q7KExtDU
E/+Lt7hQSa403fCe6AWLTTaJJaCwRW1wjPChtPdwFkO9GsJO/XcHyH45d9W8
xvkn0IrN3uzqTWHAlanvQ/BY3sOvW0fwEzddVaA51wXH2blqLR8a0lesbqwy
40HJV/HG2jYK1lMNdRXNXKwNt23ZOU7276qzdP+Lh+LQjHE5dRqtF7lKixbz
IDnn+31EhkZENv9+kOUFBLe4KtmQfgRrJXIOZfVCk2/vVXqSRh0jOl06pgFN
2fu730US/ufDxCdv38M/8aMrYoj+pRKf2ns4duL1/LTB0kU0ygNlzhrIFMHm
xthKHtGD4Ox5lQNS3bjd8MVQw42G033PBHkfDpR8pByqiT8MY5ZJXtJrBysY
fSXdFNR2ifJFb7LBX1pwvLiA6DfcpN3APAYmyjsCHUh/2z8vOzig0gunnyN7
WEdphD1yVtAieAs6azNnVGjciX1skZ3bh1fqQbGl2YT/gytFImpqkfiaMeId
TKE37+rmNMs2aBq1jCxvpFBXIcg1H+rDMVNHC7XvNNb8JZ6soNqNiCW86aBD
NKgQM/2WxTX40EEbtQRR8NEy+5C6OA/Lokd5ezwpfJNupYJzi/B24faOYV9y
35Q6+9AHRWgQmc8UJd/s4UqT0MMl+Dp0PUzqCAWJt137nNOaoGLtEHkimoLD
zoLDWz2aMBv59K3iTQpPxNr9rS5UoClkXhZkP9/1oRJnrgOzznn/DQjRaKbd
H+0SakdQd/Csw3MKI6NtDGunaki4xG+5QvR9tF5l5ueFRmSZm/yZTM5z4b5T
/cZrQXlC/HBuAtGvW5rZObcS6Oewp+1JP2a+QslrLNvB8LQ3NSV+8mv0/Mcy
vAaT1Jm6WXJeRPj8sJcvCzNjbq+eEfwbFT47JtaUgyq2GNTyI/3zijyr3tQi
2XnylvvfRN8rOb/7Hs4GY6tEcxLxq3uf1P1YyR7UmUTUhTnTENi8aJX4fw3I
M4yXY5D7S0d69/pzaxF39rZTymmC1zfxiKsmTYhbX9uZEEv+v3jgzielYojY
CC+o/UmhUB6vt+tWI8/CySvHn8JzN9lMS7oSUV+SNXWIf4T2V377It8Fzw+5
jnWbaAQn3xtQPs6GnChrqCyDwlK79fr+Ghz0RX2VZhG/uCvpmAga5aG/Rz9Q
ivj9SOmNQwZ3uHA9+bBLoonCOoHzD3Zn9OIvvS0CyU9puO9YMDa70oOIN5Oj
LHeiL/edtZ378jFSqrdPmOgh3ayU82O4FgeVZUzzLlDQ227h5hLAxkovpt7X
VnI/uw7dSoVXyKOVVdWJ/oOFXZ7lxjfBRryMmcokeXnZ7MgZ/xeIOR4rnETy
VXHvbOpRhxYoSmrVxT+gwLyW+fFzbDfOBBSdO+BKI30y7/kpiw4cX/vAmCb5
kLRhUns/ux4ZClZGG8IocO+3PLDNaYfkBu1vqV8InomMX8IUL0DIvG/cmvB5
s/nm3jPvX6A1qi3A4Dype9YMy9afxnyziZsRqfMHP59KIPy4/Gpw9zg5T16/
t9D8fjfSHk3ZHvyZ8FmbH7hP0xVZTrWMrWQ9O9Fb5iiTA5sRP4dh4t/CijUX
qzLq4DDU/WboHIUVQs/6nXc8R577RG5jKIUX8R4xHrfZ2NJ7VU6sloKt+vjc
4h9Z4PMcOXySz175mS4Oyr2YMr80K36PBj9WdPf14n+x5Nn2/kBS134sKxR3
lo3frS7qBZaTvEsyHDY90I3R04wJxwAa7Kny0O8MHgSU4qr37KUhXKZ7QSf8
JY7Y7VAMzaSACZv+pKe90HDbfeczyYtwvsLut0Q/IaPrz1JWNEzSyzIEGwqw
5pDYVCTJ/xav/kHNda+hIXH6srYcDW/RRfWS02UofBS5evYYhYXkGWX1YzVI
fvpSZzyEgsnsvxrvDnVCRXOjXZAqjZ43zHxzw0bY/duiKHiH1JuiVi9nteE0
/7L0LcL/inrGFe22Vizr2SYdQfTKWjq7yvLca/zm+HXLjDQNhseLmUkyL6ht
Pnu9j8wPNt7nk5habdh5d9+F5akkP/4ZXppyh40rW2uiJsj+YsFogRURtUiL
DCqpInhbHhnT8V3Bw3umUm6ZPY2bSgl+0VJciD2WtfLnULDzTK0Q2ciBisJv
1icnKNxIC5LpmOzBT586Fx0n80ZgqE6UAKMezER8HIyiMPi+ylzXvRrWjNq8
X4j/CpuzohWu9aAM1pX+pN+fAi+rijm0weoTXynrHplnrnWs05fiYOPC8DT1
mML/AAqFt1o=
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3lUTW0bxps0aERvpqQoUlRoMOS9QhFCSKVImjSpKET1lqQSpVAyJ0rz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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVns81FkfVuRTmzTaaFulqaTS+5ZsBrvqcWmjWNlSLosiobuX3CLEtGoT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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81Pkfx8X+VBOtUluOzREqR8lYm6iXjeyQHBlHmsparGRldZCQnKVD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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 83->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk41dkftsRUJBWFVJLMnaxRlNLbKGqIZBtMliRKQpQ7REpXhCyN5VqS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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4le8bR4omlVAho6yWEZXoI/FtfpHRQCkJla3MQqnsUpQtyUpIVkT2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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41dkbJ9ljbmZoIaIsSUYlTcIna9GkrGmZLJUr7ZaSQQgtP0qyJMuo
7OmnoVtMRLZs5d7rIllyfc9tImv2Jpnv/HGe85znfc573vO+n0XV46z98UVC
QkKJ9Ppv18tjmZQPPUZ9gL5sqRlBlO+CVv56Niqfvq8KESPIME9amC7nYL/m
g5u/rKYg4ZTep7y2AZNF2t6HcwleGdhujVpXjTlxNR3pYwRChNrf1+SOz2Wa
98+4EiimBlBMCw4M3Ye9Zsf7satkC69uvBbnknykuqYp+G37QWiE/wYOq6KF
hnQp1PC1qIrfOfihPS4pJFkAT8cPx8MUGqB5/Y+Xn9MoPIledvy1zzsQw7TI
f15SqBx/PkDqItHb6C+8zp2gIPSw/EspDuS1K3z2dxE0nay3/DG+HlFOhW//
fkUh84HX6qqcP2H61btQU5dgNCAkuZzLQaR3n+xlJwqf7/56NOJaA6RbFjoe
tlNo7QnkMlp4qBdsExVZSyFDh3U/RpmHt1GyHsp8Phzzp1Vkz5fiu3Vt9A82
BNFOogEXLzZDMiVg6zYjgr4hC3/f108gV8OQHGESeIWP3zjv1YmBNUZllkwB
FtcNRPDtKrFr/s7ITCKFnA1Mz0MZzah5d1RMh0/3y397gUlMC3iuaokpERQ2
ZOQcMnjQCZf4IxabXSjEilKM7du4mD4elOtiI4AYlXQrYQcPPK5e1vaBfmgZ
yIg2LuLAQSEgu3eFAG5mzSZGe1koiMnMvniY4Cdpv8chfZXY4Lh06uQsgazV
Iu+qqXZ8mZER7Z4SgN2lWvD7zodoTmOY2nsRPC0tHS11r8WN3fNfW0IIFAI9
Y0Xj87Cy8t7Xa0cIzBjMLRUiHGweldrLlBNg35LDbge5j2BhvNHRcwPBp7xE
iX8SG3Hq3sfdgxoCnPIpe/tc4xU6soZa7dQJJFvv7go51IFzSyw3G/Twsa/0
xRg7OB9lYXULbU4EHj62gvL8RphvNJr6QuPh4PaJkTyDVgx6HNRmvaGwNlCg
uzK4FXHMcxnq2hSEdJR3bJT5AwyRluilHgTNx64kZ4sl4rpYhZasC42XhKB+
xkgt4ic0ey+CYPnIJ7Ozblzc6C72tfMkOPxC3ULm3jPoFcQNW1gTvD7ddVNe
pRN6B6xqroQTpJ6L8/Sg43898tr9zY7A5K/wwHXlzSjxO7pdW1QAP5GMuyMP
KzGr7fOQfY+CzWO3yvDeDjSWPzHcaC6AV/pjKWW5CFSp//75A82XMtae3DUX
2PBLlvdMVxJgR8u3xubLLPj6rl8WF01QMvzsfslVLqwZxvlZdP+FxDalRYU4
wvnXWX11+r7QGgYipirQn7PshVcOgV9es/S53RxUpyqtznsrgIRdZtf81Avo
O2UPbg0giL0RIeNqGoEr/C3uI24E7/fOJd0d68Z3/2Te+O1+VClYM1d0sxE5
rNiy5kcK5pnc7/lzHJxYkBYWtqdQVrjKQlO1DY4NW+J/Hu6HaBpP7HoAD9+f
yCk/0uvHWi2+8fTlVuz0SWHG0PjoyxoYYnpz8UX+G6drsh/pQZ7DBc+74G29
dF7cnMDC3MQi+MIbfBje4BpK41totb2V1jUlLHEShx79P9GlAlU7Dx4SYiaX
DR6icDuZlG8I4aLrrnXkPKcf/Wkx0w+2taDYxK1PHBRezUz9VmRTjR4PZTUl
PYLLhYWiSQc6cWtny9KUZf1odr6gtiW6CTJKJxdxXeh5kLQEm09PccL5R0ez
5QS70n6aE+ngwtky6TE5RHCJldJWMtCJicWZQU/c+jBr1HJd9zYLGpbPTl+y
Itgxm3TJ2TwSEq1nd7jQ9R7rULvt5F+NxLA0a5UKgjP1tl/aJlpxeI/rTxU0
P/WlA5Vte5sxo5shnk7jY6e23YLUfCtUju1rkK/nw+vMESsP0zocvMB0Ny2n
9e9OyMfry3KRUh977BatJ8uVigZVSlqw/Fc3w/frCWYn/T9V/lyBhLQT33SN
CRyWngi6878mnA0LXp+gSaFIpSbQk9aDylJmVp4krb/d8qNURieEfNuE968g
ODJmrPq3cSs+xkg16ND8j/lsMJbFe4CGR/WSTqcIzrVLVU2mFkAidCq/mz6H
Ji9i7XR4D/ZyifIpRwpf5hMDFQ258I4fHg1tovDnpw9m/HvtUHzYyMlV6keE
h/TTgOfPUcjokmDQ9cdmeYtt/acKCvKrboinEOwzXywZzylFRySytE7TcaWr
86YWPNhG309isPlwz6joTj3VBh2jTKvk4H58fxeVLS/cDrc117TW6AhwUuGJ
vVpIF/YcsUkwFu3DzWGTOIOeNqy9ImvUE0iBEdV0K/W3MogYDjWyaP7PBkdu
omxfoah7+Z26GQolb14OjY3V40D2eOhmFo2vdPEozgQd12IL149SCJWM8HXd
dQGVDl5FDfR81crD7/dU8CATO7fJVYOeR9kf2y9L8LDjju2wA4uPytGCkyOl
ndC1VzEZT/6It4nZXdOOHKxuDjevCSOob9q4oJH5F8ITJG0mRmk90n+hYCzO
huuBGdutQzRfdpoM6ns9xPklQ73F9HtrZ/a+zTXg4uZiVUWH2n6YO824XG5q
gHr+iiEp2i/8Wp3zu6zq8VLRWU5NltaDbM6ohFMHpsx1ixW8BeAF69xMMi2A
hzmbtUDrGVu9dMVRQxZ6WxVXJ+sTxPyZEB5H+6FNWV1jN50vus+2i+fVCGHD
Qi8GrW96E57MUstumOk0md3Q4oPBmPTY/bEHfVOOk97/p+AW9/WklXsKxqZM
a2f+w/96X27Sdx5enkldJ5JK++PKK6KJjHZo64Xp5JYLkF5NGWw+z4HqzQ/2
TtUUIkZCZcJyGmGScDHBbI5CnlCs/9XKYqTvHT6z8jjd35z5q1n2OdAwrY5+
d5CAF/136mnjahQ9XcXXqCUovr6nma1cA0dvt7lILYLueZ3wkWIuMsNt5P7z
i4JQbYNp5TJ8rdm3z5L2E6XUmZhaHhtWsesGux0IqqrSNDZ3dmCTm4GcAp0/
8XvEL5BuR1He4yAqUwDZoYZi8aA2aKm6DNgwaTxHFtQNSL7GpsUHxJ71EDiS
TaeVLzXg+Pkxvusbgn8BfGq29A==
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk8lWkbFskySE1ZmlGWqCwx1dAXumw1GHEsLZM6DkVEODNUStYyVIPK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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 84->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk81ekXx5WS8gtJ1CS00IyUXTL4mGoklaWMZFKWGCNrRItCIgnRYokR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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwdmHk4VI/bxtFGqZBS2lQqWcqaJblJi0qSFEm2FKl8pUSFJDuhUBIK2YoW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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk4ldkfR2UnZQmjhrrZklREWT6SSMVYipJisrSomKxRihZFzC0NMZFK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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns4lGkbn0Qnaq0tX9RGErYt6YpI+JGS0zis84acKRraxKgUtbQJiygp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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 85->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lVkYF0ZKqwqpxtZiVKQiCj9RhjJ1QzNM0iUakWsNqbhDWsiUBhlF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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lH0fxaVET5FKIkuRlJKleiLk2CqVkFIKJcmWLBWpJKHwKElpkaQs
pSJlypItBslgjBnGiMzMfY8tknZZ3vv9a/6Y67p/2/me8zlq7gEOR8XFxMQO
ThMT+/+v3or4Nwb3GmGzUFq/+B8CfOJzs9giFoo1++5XmBEY4376aKDIQqbF
oWl9UwQEL+a4/hp4CROLpfESbwnsDQi5diL2I1TX/46cN/gJM3InNT7wa3Gz
eTCxYgmBXR8dFHVp7ahU+ZCatqsfCe6F7GqlSvj9dSqL204g0NLb62s4B+Ez
T6fnDZO4H3gpaqM2Dw2n1k7TVeqERTQ7SfSHgzd321rC5/UjPfbkhY6ERBT/
TqLPdCQgm38v+bt6O1Lv+YrUPpLwf5d+JlarE8teJ/Z+CCJBE/HtP04vw8qM
8j3sLSQSg48H3TbLR6mDwuDCewS8vrqqMzaVYjRlaprvLQKTxXc/qr1gIfp5
qsGiQQHYebGaUeteI0xpY6jyJQIDwcs/rWB2IGdfz6rxk70o7o3qEmO0IyMm
xzl3Xi/SYwijQzI3AJ89+xfbE5jxdq21bBwbEZG/3l6O6UGRtt5xiyImKsNN
5EKf87FiSWfSjLEO8F5XNAWIEfC4UTi1OqwCC+6xooxKhOBe4FTmzqFDdcNF
32vtQqTNaLNGYj3Ktmfu8PwsRIStUexgnD+4eW/e3D9EQMs259TNVW14Psxc
8eQECfsEiVJf0ywM+jXaR28mUPWv3JnP+p1Qv3jRrPkOH4LcZKsnu1pwcqL7
ZPE2Asc0ejSHDvDgO/J4vZ2OEMtjTEedJbigO+y9sHjdJ7CqkhfrT7XgXs4n
5oJzAgiiHfhaGlyMbaxvWiTXA7mKLzU8NgcsCa/UxGgSJ5oNnhzQasHxwx2G
izwFuMeoYcqLdWKH4VILRng/+oqfMv/JLMeddE8l32tCeF4TJTlpd4C24K+v
xxch3ossTOkqZRiY8Gct1SOh+qg62iSOB5stfy9E8YTI12wTFzetR6XBQZ+f
5wlUWl3YqqIRh+1Fj2b/cSOQ6PDWYyKVh4PFJ2fF07kIezU2pny2ATal9eZf
U0mM3Mq7nq/FRMkEv2h+H4l8rYLy/GN3Yf7aRVzVg8DrZT7ab87XYNXh8CnN
BgFuQXVrXlAnDDXTnPsXD2Hlgrc6SW4N4OVVG372FsH67lC9xvJqBCtW/iPT
S33f4uEX49MdiApcNVQUSMLPb3Cn5uUGpKZ1mt7+ToKV+GGr59JWtD3dobWW
RulXZnSDTCwLg8ZXTon6CaQGDVxi7W1GqLj29SoRgaWzhp9n89tw9m2RzWSd
AE8mkzN+/EiBzDRueCX1fgydFD2rQCYSDPY/0W8WIn7/OiLufQuK9b1K6Owe
PD8nPbetvAsJcc13pocJ0fNjTtDuGxnok+xfv+0ktd5s8Yv13dWYGV87UyOY
QDpdilsx+Rgez6Y1BkQQaHM/4rT8BxOp1xcOLOWQyL37JrvSiQmh/OYHJc8I
yBTrxxS4voPFaRNhbhoJ5mYGy1HjA6Q8HvETvgjQvSws0VinBfm8xsH8JhLK
BtZJeht4KJzPviUt1wszx4Rb16NZGA87LVp3rB+Gqw/wxd1LcEs6IOq7MYnw
RQohS5hNsHOxk+hYIMTnrsjrCfRCSKwzSGYRBLZ42a5lv2rFekd7sb75BHR1
/0a6HqrB4sLHRgfvCLHyVt6mHat4+Cfg3LIkQS9Ko1Pe/l7UCMnE6VtSBgiY
zWw/7NceBs3Sn1cbDhBgKlw7RNt2A04rb4rNpvQgNqv1UbTbPdh4qE1d3UeA
V7Ws4EcoG8eXTzU37RZC5eUL0fqhevQtqZpr/JqAy4Wnbmb+HGSf3cN5I+Ij
NuLIaOGJZuRUOStnGgsgK3VmU53uI6zljdz/c5xA5NmB4ZoYHtTW7RxbMdwL
+w07Ty3WrMRwu8SDHh6B6TX6sQdd2lCh4KLsoCQAkVg9UL+wCwfuTXwL7u/F
0gTlaw37Kb99N5s3/rwbC1/4dOtZtMLqSIYp7ZAIv0OrlmWUtUJWu+RVrnMf
vCIyojzPtOG3iabXls4epGvsFJrZp2PSIDfTPojAr+2jI3K6j/FN3uWInDcB
m4ThK/886cQtZTWxK0pCzLB533tZn4bvjoaGG42o+5mcc48R8B9OzXrbcZaa
P8kBQv9aeS2Mx1b38jKo+9WrsfOLPYGUbRP6eQcpvcmmJ7UsZ8HK1Khpw3w+
3Jdb9/dr0GFsbul25a0QrEL++VWmPEhHkfNgQoJRe9hPCxyI5vlXDPkLQRyK
CK9rYyN2gxFDcVQAg9iBGzMrOnG7XGGdlFCIWGnjLOPDbAyvHbBaHyeCVI9R
vENDFy5OcdvlUwm48Y/e3nSzGvuufLHUbCUgkZebatBZjCIj9Q5nyi/DWj1W
FdLZaAy10zy6isqbH/k5XvMzMJb8uVvBlIByd+Oc/ot5yJo1t+ypBYFVT1f3
rfBowbKik8GWXwW4Ynp05HAnC/Jh33ZXUXnabRjcQC5sgjwjxOvrVQHE+O3f
Nu3LA6N0j2MA5d93JH/WfP/bAPu/p9TOUfmYGB/umSmXDvmMQB9FSh9WzT50
pefVCLxuuFrcm6R8brpGG4cFtWN/j1x62YdHq+/HrPdoQsjGx5wb8wRYmh3i
G17yFOr7SneU5RLgJtcqkBY09AXImCdcI6Cw9lLSfq3HGHasrQ7WI+CqnA9z
xnvQnG5nJ7+g9N11q7B+kgV7ldCrbrYERhoPdG9eUIZnnsbu95eRmGF47tr2
lBaMb7Or2xsqxAY1oVxOYTuYmgE5xTsGEYo+NfcbDTihLu4/+w+JyjMxGmY7
YyGuO0v4lXp/Jl9mn7iIgZbmJba2XBKX6bEB9OY6zF2v8/nuOur7xxOfz3Wq
Q9SMrMyichIaQbtHSDUmfiovT8g+SiAzr2pNWWEnFp1689/3Ai72VI9fidjx
FrXfu6SMQwiE5tzSMppoQd6ZPnb3BAluhF1BuPRrZNerF5+Vofxq7qH67E1c
nNzMWRJ+tRtDktbk0HAzeNcM1ZXXkkgfcira974R5J6je2VG+Ig/QNorhTRj
/oa8I0+nBBi9mnvoVTml34odjmcmepDl+2tNnns7DMNvxqaX9SHR+sGd2+aN
KNS7ncKRFMJMRyX1tlIGvOK1Dyaepfhpl1NO6Hk2AFX9MVofRnLj7O43lcM9
2oHOovL9SYbh3IJJJuTmiM7kS5EwksiR/aP2EW9t5hc1FVF6OOtgKK/PxPfL
T982Uuchjo7vZqYx0FU0t+G/cQHaDIycNVS4+Nz/q32LIoGKygLf0XUcWBQq
zyn7xIN9/sOiEssW3Ljt6DJiR4Bt/29TAScfNnN/sr9YU3n6cF2SVZ4WsoY0
f6+l9Mlt2W73Or8KqjLz1u2ZEMLNd4lLhkw5NjEefF4USflTx4HGRcM0ZLQE
DKyj8kOs20tF0u8aaFdy9DZT+jH4qWDkosfByhdt2f7WPYiVzx0qIXOh6hz/
YvAMAVGRiWeCVxs6XGa7cOcK4fEqsFqmtAW/p71zqbtL6c8gzTlYuhI9ae0b
brFItN3D+vmD1XD8mhYRlETNp85rsphxAvLWzhw+tV+rV+ItdZLNKDkZoW1G
rR/1rvajZGgHfL3/vPbIE1E8aZ63xacJbGmp/AwvAdyKFwi/GbdDVev5/vgg
ERKjLgY7d71AZErFzf71lP81B7s+/tWE5OPSspnqAmhv81lcU1QPsWF+ibku
CW+Zee6zR94gfVG10Jm6zxkxWbw5W9hIM5T06Yzqh1Ps1GHHG0UIK33nPLKH
QMRQxnR7rS4w7VroK26I4M3/ZKXi0A3/Swv65fVEOP7kmdaQMwMfvzfpKE4K
YW2bkeZd3I5tpY1pqrq9CHTps9CrfoQQ1wjjXMqPxPTHrMR6wjH9XJr+Our8
SpIZUYXHGrA12rr+TgCJW/Q8eXYjCzNF4+nK1P4TVmSlPQ1qgsNCWu3vChE0
Zr0o1Hhai3TrhnUaUUIYZhlOS6piQ354ZnyrDh8SgTt6LYs7sTryhKKurgCd
1sFyH53Y8IjplOczCFz+zglbOv0jWOe2WZxKESGzUfuAC/sdSv7+mP5OlwDr
QYtN93grDqS6PrpPF4Br8q+9z+4ynPV0qNmfQMCosLDj5VkWVLeRtpmHBjDq
4Mm7qsrD3go7E1oLH07fhKtuLbkLRVXRI4YrdV6HpPNee5/h0fu0pJxQAh9P
V67RymCgJl43kqZL8YH/+hr/zd3g+Mx1P3CPysdnttzpPTQqf5ukDtpQvJD1
T859fKDuzbuuaZTEMPfFsmli7QiRdfjW8oWLwMIA1/MFKfDofVlQQPGRt/qI
cZF4O+Y/+37p5GU+mAvdBH8OsbB5pL5/ASnA/RVhLxdacJCy2dGmLIaa5zH1
5jD3Mow1S9cfrRbCPUcjk72UiYyK65aTQhF6ctJGLv/biK3y0nrsEBEKZL1n
Rb98jw9L7m/IWCOEHT/PYri7A6rumbZyWgMobWXetd1eh0Xk+6Tlpwm0L99y
KXacjUA9ifSODyTEXWd8UPnahvV3bo9MN+oF89E+sV06NIzZ9pFO4hS/NXyO
zb3XBtZ5xtGVFD/saZmttm1RA5IP8gjXGwSsnVZJZkozwGtR4Kq1kZD1Ypgv
rMmGbv+VowJqnlXfFIdlZDExUs0IjPHgY4Ocda+beCd8niZrzintQ8Tb5MOH
g1Jgu153Kp7K/3RnyxSBfh0ivQZ9riqL4BZMvrdisGB2bZHfTONeOK02yhkN
KEPnhPb3q+LUPGeGHYgK42JKs057xuM2WLi7NZU6c6BWf5XmeJNA/uwy2+iq
RwhYoe9u50ngt1UpLUpEB/N+Uveul0LQNTQFd/+ycLBd9lzIcRI15cQf8wge
qmMv3pGLF0EhOtU09GwFSoXe5g+o+XxSonDFh96Ggb3ZL5dFkriStkOHtpUD
DfU8nRL9T1CKVHSdpPrb5MWzkn+n8cGTGE7UUmzBk/NHH22l5ldq5tJWy2uv
UDXg011vRWDOTzfzActPyP+lOf2FdS8iLpzwNiprQ9CDJTlfHEWwMVLULHCu
xfQ9CHnyf15acyH9SM8NCGNGNCepPPNvon9d6NWIkD2H9o/4Ufzgcoq9/Fsd
uGcGQztGCZgM0OXOLa7GlPwRNe4cyj8CU4oyuM3It0yQvb2fRH/duI6MURdS
/S4vlFH5BM7fwVmaKmxkBJ8Nd1pKzZu70y+xVc0Y3vk483UdCb1Nh1+/yS/H
UutPYo6nSBgMnS3uf89Fvf+PjRFb+uGRXUK//IWHkW+LZTaRItgbi6uv2vcM
Ed7qHsFHCLj/q2GvWt2KQXkf1/OUnrbPeRavU9+O8AmtQ0ZTfUj5UXItqIKH
opBv87Wo9+J2Zz8Y/VAG586KF0MmQoh961E6/LkNg+8Oum5+RlI9YoZZmzcP
/i/EzVaaiBDxgHVyq0UI3j/M0k6h/Cz0G3dtL6MEOrYf5k2VCVHZbN1rWpuO
V2ZEysQxAsNBBVsUpjjIjc0olw0U4KdSsHZOAQfqng0aB/72gHmclkTz7YLC
FmZxOZWvJmb7aE4yTfgtLfdwXj4fGerWH4KDnkPgsULquTGVp8tOa74qaKTu
IR52lymeEg/dGD6NAYfTchpLtlJ87plobiBfjH+KZ6ngHIH1rHROTH8HOI6V
EQ65beCGJhifKqmD5cXHm+f9ofp6jGXS8opGxG5xz4RAhIpDbkqaD9tgmqFb
0/ObQF+13K9tbo+xX/nUoDeVv8yTa2y1cwqRkhm6v72EgF9YwNhoOwPdX8ci
H1B85i8d0qD+h+KDpqxEbjHV91dyd24Ny8XyEynFvyn+pT//2yr5uhMrtLrO
0zi9ELY0L9VUokNak54xtpFEqpkDLU6xC6+GfHs+zyJwM3FedF8EHfOOvfMl
LUWQLazd9TyuBf43z1q+9u/C7YMeM3WpvrB6WbBKvFIv5PxyLXfPrsMVO4tj
q7YKsX71aeWm1Hr8R/LbVYcIOEn4hv5QbMX72++dJv7Pu4E0zvydHLhWSC5t
3CPEKZFtVXg75R/mE11X9Sm9Pciq23GmE3qnh26knuoDQ3F8X0LIe7g/v8tj
UPp3K/sWqLWpDLc8JYh3DVRfn+qXkmG8xM7T81+N/0v9r6phExL2DkOKwxuL
VlLzsm2bZ3ZOGeYXXlDdQ+W/mNjW6PmDB2DYIRi1pvQ0883aXyEmiZjN9spP
pvKEm7RGhSF4BcMdB+38NhJQ6Ulc2Bxci3gr0wUBVN/9tnOTQ3dgK2x7+u8/
fciHHkuodzX6KYgTb57KgoCa4MSW4NEOmM1iPar42A5RcqVF/5dWhERLziXN
BAjjfpH6nVpJ5f47g6I4ym+/7rGWim7Fz01c3Z3PCejNsabLb32CT/tWypsc
pvabauhMU3RE3zy5jdup/TrlTTeNOcKBjW3GpfEYEk++moVWzW6DwrJk3Q/+
InTLD44ZR1dDUGmtY/OO6vfiWc26FS0Up+tW6niLYGg+T+LkiQ6sM6x+O/Sr
F7z95TsTREzwYvQVkqJIDHzyMUl9yYZZTZHS8RTKH30Shk3F25A+qP0zMo7E
7/RZKrnmFI+ExSkcOy5CWM3jE+f6mMieU+6heEWEXW+t76c206FHT06odaT8
kKZRUSJXROXJk2jNGRRPrxUf/XEsDwO63jn94ZSfr3kaYsGnw2TTXsUSguJj
qcPj2WZU3zm3e/61DQTeb3DVn7Sl+r+yc/UY1UcTZHwMlP1YMDXY2Ht8dg8i
2H61HMuXmOxsGpei5mXDDNVFHvZt0DvzYmbQwl6MOFp50RKq4Ky3T/tTqRDa
Cgp6cVeoPpd37G9BNIEvW+QDzz2sR2b+0SXTAknsSQl6tlicjZud0l/KxIRg
r3ixZGZeM9T5g9+tg4WgHd1wwfz1SxyQOf1OTJXqe8cUJ+g7OrFP1TOdv5KE
2OOw5H3TmnD4vtKgSIHESI3dxsZgNhbV/LBVaBPCICNP+LLgA+h2cStWtQpQ
e29G56XAj7iT6Wez1p/i18USfQN1DdBcqSBdRaPW/+I98PXfBsxoCmv9NiZA
z+joyZTIHPjXftq7yYnALJ6W0+QFDtZ+kZ3aKuLjSlf54gnlGrj8N87NEpD4
H1OICgM=
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lWkfxg9pIjIqUclW1qSQqbHUpaJMoeyKCkNkSTVSHaNshzDZk6hI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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk41WkbxxFlmYiMsfRKI6QpSfbSt8JkwlDTYIxkRMTYUr2hsWUiNBlL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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 86->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4VekXPpUMJ1GSJqMyRbkkozIl6lUjMUWRrirKtdxLblGSW6KEhNwi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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c4lf8fxpFRklUJJaOoREmhvuKOJF+VlVBfmmQklFXJCMkKWQlJUiRl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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVns4VWkfValcIiE0JpcioppS+iK1kJKKitzJ5aMpE4VEUoPJZVQouUWR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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs4ldkbPbnUiAk1jhAdGpcudBqX1GBVSkKK1GkkZBRObl3QNCrTFZVo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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 87->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk41fkb1WIyRTEibUKypsXWTExHNUrIiGpUv0oIqSktCkm3IlsjhBRl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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k0lO8bxhFtFG3KUrRZKiIlJJdKSNZSJBH5SqQkSpGUkiWyFkqJ7GSX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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx2+SNMky4deobKUSbpKUrY9IKEqrVIYWStOkXxOjn90gNUO6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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs41NkfnrVKG7XKtWJL7U40UYrKJa/kkqgkG7qxyNpY9CuZctsuKAqp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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 88->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4VekblS5IxUT1U4QyimZQ0U+JpWhSSSIqESMSijNShEo3B4MZl6jo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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8lN0bxilvaZMkqWRL2mRpI6nLnurNEiolhEq9WYooES2ECJEolShb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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81HkXxz2upbIjcqlIKiSLtpQsfWgVSRuJTWHlLhQ1idVjU2rto31S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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk8lWkbPhVROUYxkt2xfKQaTbYiF9qMpU/IZJSdtOEzvoqhpAalhEIp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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 89->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns41VkbPYO+oWFKNySFzEwoRCOTzBIzZlCmTE36RO5FFEOSpNuIKFI0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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8lO3/xSWl4pFSUkkIxbfFEhVyhLR5bEnxiAipJJQ1ClkjZY0WSZGy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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41Gkbx6USrUOsNGqTSg6bJq8kHfhqtI5JDkVyikWRrEOlSMoWYkO6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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs8lOkbxqcDpibksJvNIWo7aAm7lB/VNRSinHMKNTmVHIYmlCjRiUiJ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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 90->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4lVkfVYlMSBQiZaYp3YgMRWXJCI/5KBUp5JprqZGKSJQaZuQePiSF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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lf0bxxUhCZV6RAolVORRRkkfq6IQJSmKkFURT6FCaFmJIgqFlEJW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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlns8lOkbxoe0TkuOKYki2pWi0abD5JrVoBxaOR/bYWWw2ayUVkklRCy7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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs4lOkbnmIL1aYtrZIkVErlVD8V3U6L2iZyig5DJHLIoSi1CWnZRLJY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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 91->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8llkbNkKWShMT6ctHw1AYS8lk6VJTtmRsUzLIWgpZohJJCU3ZQpHI
lsY2dinri2xFXuLtxaAf51Gpvmx9ekt85/vj/J4/zjn3ue77uu7rfuRdfa09
+Pn4+G7T9f8vt8J7aMntKaJ8xfXmkgjsYtkpA6xO1LkG5CvHEKw/MmUhGtiI
kjLzJhEfgtTJlYhs0WooaIVJrz1O8NBa+O2d/g5EetpkK0QTWKp79eueDQMr
x17b8BjB/R98Qqc62xHuIDIuFUjwywtmu/VACcYPnzhk6kZQknHcI2tHF4ag
81U2nWBp7bxs33AnXjQaporR95u1bwp+W/0PNlnrhPmHMKjYxafiaszFoa9f
nnxUYSB6a++PPwW3QHPDL8YW4QSeVv8etaxuhODuNaUOpwgML61xH/WJAs9Q
KsCK4tmjLBZkfOw5kmK0L01XEsjdu2dUEdKKx9c2Wo6GEEycVFvc+bQPpm9X
iScNELwPcguOzWEj/9Yx3vccgr2rCr6bbGqGhvLImNdZWp/QrlDj191YfpVo
k1FC401P7AyqzkFJd65eqjNB1pWUlvC6PtS6rXICQ8CJEzb/fHoEv6efiE2K
ZiC38cqlXNNeWAq92fawlIDNstap0h8CW13VIXg9g/4iXdvxRyO44PPXdnt/
BsoLu53vBfXD05pvj9UIgcZiTYmEDRta42yJ3EyCzirGYPnvXginy+9rLSZg
rS69/eJbHawEZ+eET1M+ZMX1fcdbkGeTyl9+kYAvZdUM395mWPykb9t2niBQ
ffMOV8UOSO3Umc5PIBB4Xas2vcJG2vlTX7c/IvDbV7d7UrwD7Iuxk9wwApO5
u+OX4rOxJUa/LpPmW5zq8e3mcD9enWqKH2ETNC566okWvsTCqEv2aUMG9u9k
eTFho+hidSgfjGWg6mezvu/3bszJPXwTc5PyJXVdekAzG7WBgVlXaDzVQ3IR
DiNssCLPWL9pJrjx3nHN3fFhzHTXFp6OZCAt8ECjKnQIdQ2RRUe0GCx/S5PT
j/gHBialdxTfMvgpOp/fOWMYJn8Yl+olM/CUSTv+8eXf2JWcpJNH9achsOPU
rBYH275rtyhSZODPC7BK/m4EhZejGc8MBglnY9eI1fTjprfTkdJJAh9PHffv
G4ZhVqDMtXBlkHY1Y6VspR9asvX1vjME/7XbeM1vdReemNWsm0+m/OtCv4vq
I5yjF++ZS5DuMHZd/iUXndEZLjvtGPDlnQtm13AhtHXTriJtBpZbY41vmxai
hseuOOpK7yfX746TuA+jK+mdn2g9vCq5JQvN/dh2S6j6IyEwX/FzsBN5gUvy
vPTDbwk2tgYkuEkNwE/2ZebkM7p/RjH1zvNyPI04GDXmTvDI74C2fQ0HPyi/
yB3RY2D4MMij2jQGRpF/fHOn/SFs9lnfYL4Pa2I+2Au8oXykFn7RlerGhXCP
eQWqT8NcfwHPuH7EtUSee0719W7CxK30cz9YrnPb2CyqH/HfXPZ6t2M5eMbW
N5Lgi3eh8XVnNgwrDiqpxhJIfkiJPHifhd6jevdagwhaDpfc0DzXB/5VvPsS
NN6r6ggTi9gyLKTe3exI8fJxT0oFiWggIV4oQIPiM+ecTCvI6cOV+OGtv85T
/pae7YnRroOk05iKE/UnOcmqnOuayZA5J3Agl54PL1wnuKG2CvfOFWtpnyCo
l57THHzWAv9qCMX6034RX+BT0uYgXl6/QtSKge2U69c03lNoVlZ7tafQ+NP5
+6LampBmfFgs9gxBmewijzEvR7LBuhVViu+kw8RMsCYbZroFs6qNBFVLMYUV
hI1lG9tPErReZ2X6jleWDcHaui/q+K8MnBMZs/2pieCcUQuPp/iuuhhUR53k
oPOW70Q89RfldTEGjWZDEHqsEpmQwCDLluyvCcmHpsIDRT8Xml+wwNZWhT7s
8ZR98/dj6qebvM6H3uZi/wNN1REbqm/t1rvcnOf4/pv61toaild+4p2OxXOs
1PCCrlYRiGvCyfj9EDLcQ3P+Q/UewPo02WXUhf5oO/7UWwTOKaVTmQqNkN80
Nn7Yj2Be4X1MC/clAm3ecG5uZJDoMb1XZYyNZzNixU49lK+Ldz7e3vUMQgGO
1kcpv1ub7k+4SPQhoSD/WhfNP2Ffvtzo7jxotyjZ21D8/beFePoiA+gK/Is9
sYGBae2WZBHqh0Y3x5WCAhi8CmHlmPmXwuas2L+O0frqbkndoTtYj+ioltOE
+teXCHWmUY+NmdZBhxt1VB//sryaZdmGsA2Jm3Oo/7MdpTtDs+sRVtcjM+xF
93vybkg0dePgXKrPLOVzg8dR/biFPiRmtpfbjxJYiwXxO2X2IkH3g7JvIZ1f
DbKLVgcKwbl6t8GS9l90kbxum08PVgp2ZD+l+bBGI2RMnlyEdaWaLyh/gabK
3i4ZPahYDvntaCrtb4NEc7ZoE5YCf96sQfVS9c8q6Up5Lqadd/BWtjAwV3I3
UvHtAOe8hU7bNQJv1aS0GRUWUqxOrrWl81EySYur7deLJ5xF5YMVBG6zeUb3
z3CxIDxr0XCBQbrsI9EPzS8QtKc9wv8LPZ/Tq7b+FBt6WcNtXoNU77fiX8se
8kdwRrmkNsW3VD4lK9M/gOKOI0HDn6geIlU9lgMLoPspVyqC5jejRtbxfumC
Y6LhOWE6f+1mD/AyG7rAzyfjrp9H9X9hNVtfqw/jDvxrb3QT6JfxDyZJPsbK
tWL7TlrfZRFRgQaFQdQ+KCMhPzPImZWTK1rigPWZq9ZC+8m8/c/UH7exMNej
KfWRzssBv8snCmoeIs5R6XUN/X9ov3v5lSCPjeIey5LOJwR60mesj/cOo8rQ
rfnIHQZ/xXgstCS24Fp/fYziFYLnf+6f+JmpAlv8vdYKvZ+17kPAylw5gv98
KJTjQRBlEjM9ye1EmKNgyuVEgtUP9js8yhoAqYtjfRBmYCfJOaXSWgnSlm+7
nfpBVtb84PmxbKw97R3hS/11RrJAz6GoE07KCjmNEZS/jT07NyS0QZAVobRI
/aqpXv1b6N4xxGamlw0pTqHixynftfwd8FfXNXhH55ffHxbvltRYeNA2bSVA
+f8fz2q7/Q==
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwdmHc8Vv//xmVmVlbKzKiUUEm0roSWCFFoWCWprJQRFZERZVX4lBCVEhGS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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs41GkbRio+OiqsKFskSsmWSNtNckxboSS0JSRy1nFpK5MtZNEi1FSi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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns4lVkbxn1IKgyF0ZCcNU41JUnlFiaFZCvFDimUUEaZGTNTQoRyLBWJ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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 92->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx4lCCSOkqJEZWysx1a/iU6FSVIpRI9mNrciWBilJC2YwsoVp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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k4VY/XlaR+UiRJSoYoSmkwJVqmSlKJlJQhY0pRxjKLQpIozYMxhCQR
Ia4hXNPlkpl77zkXFSF/Ssp73k/nOc85H/bea62915KxczN15OXh4bFewMPz
/0/pKL7YhO0lGJ6TmndYRSKC1lm0kq8DYoMxZaevsXCPrlx60KwaUT8S5BQm
OKhzvUVmvGiEsW9+jqALFwoux9sE6PVY5Ty0rOE+C1FfRIJ9C1rB9nnidzR+
EIu3itpaJHeg00dm6+RNFrxOXlxI2rbgmvnt3kJREj9SFtcr366BrPPe36Wh
JAabO2OZH/PgldR5PdGVgCsvunfvbgX9ZwvE5UYg7lttG6hQhRLB7zw+3my0
TBhEmT4vwm3rTYJfgwhI6Po1Fb9jwNDTxqjoHhvf3YY28wXkQdt+/vQbEOD4
8963jS+A+blN0usVSOQnevBeNWPgu+BKdZd4Ev1rmUcq3zDwLcHnSVEPCfGx
EyEGZU1I0DWnN0wPovvCRAFndS3qq/kzTply0M/HyZsZZCLffGDaSZWL6hWq
R/2VOlHpHv1hzOsrDHNf6ukXVyNGevFN0ooDDWWH4qeNDMSGTU0093PxQWb3
+VNh3bhx5re4PG0QHUI/fycVd6PG9I1A9kkWlqgP/kmJasOx+ljF1WWD4Kkx
6c5ZeALHE8X2e9gQaGja+OO8cDUCsu1qR19wMN7JCDf50ofYVD+TEw0j0DnO
V3985QXk3R0oqaX+Hz/w63GKbAEWrmycWJNJQGH/ycq6rHwYCtiKDm4lgPKZ
x/6MXKhW0zeY76TmrxhqV9bPgE98t1DzoWEEBf70PXR2ADt0buRxfIagpbBV
KXNLFcS6JzxebSOQ7jj33qiuGjNeiSMrdDmoWrDLqW/dZ+w+vENGMpXEuvmA
zVeb61C3376I/YKNQY/zqf8akrHXqlbPzJpA/3TbdINOK4bVT0jo/OnFkoWn
FwSeasKgZaqc8jYuju9YrK25Lh9fTWvuhy4k0HtRezxhCw0xzHD/P3cJ+Kux
DizQo8FYRIAMP0JALSzQUEP1LWJTOjXdbxHgu9Z2uD+0Gh1Tvur2DBJJ7q2e
67YxwNreuUoskg1ml8Vo24UeKJ7CNe2dHHi1Vad1ETUQDdr4IHgzieJWp7rY
rlYU7DsuYHhrCMJnEzeH5TZib9nS6g8H2Wh4Frkm8xMNJjr8MTkbqH699A0O
RfYg8cGGg8tNevHd9q5fvuQXCJr3WqzMJ2FDahX+GGHAmqc8PeAkBxYmM8fG
yS8YkzC6ncRioWN2zsR5vhWvBMYMgmIIBLMU5C3rb+MWXbrRmcJz1qF94Ms6
Cm/hydEIir++C/Nz+Q42gVF4PTnTkIP60trXBcJ0xP0z/2ehT8Dw2w4906wy
dA66FM0ac5A+o+Py91AVXuYlp/Hs5iB2w4eHR8S+YCvzd36r/VdcKdbWvGvT
jiVzXqPuFb3gb9q/u1KnCpP9glxvcQKTVmX8y/W6oO3nU75i4RCUtshulVWh
YZoucqzyJIEtWR9NPZZ0gZbMX/c5hIPta5dGbDxQj8anubSsaS465cWVdzFr
8cHz9dmPMRx0/n4yP/agG3HjKvQd0d14tjYk06GgBVt2tVZ55xAYLDTyO5lc
CprNzfrkFg4uOLyQXFLXg5Rb32TLRwegIWL8xmNzE7Znreb++kDie7YTbS/Z
inm1QBk7/yH8ut4pm/u9A/F8cY6Wq9kYHm8fFu7PRe2sdOshaQJ/tyW1Xc6g
47F+2/YOAwpvuRmpw6l9IKytDqjEfoOSlsJmooQOFXeJJ+xZAnN7PlesEaXB
tVFP1fYxAYvlqRK9Re+QVrcp09+Jqve1/hmh+F6MQuLN0iAWyp0vXppUaUDr
z/n/XA4OoeR44UYf9W7k1ZNmofEcGGSIrCiXr4awrIeZrxkXtYUPxztH83FF
bZPeSCEHxTYy/WFKDMx6akkGnBpELjm4RHFlD7IfbtQTSCGg4/1A7cltOmiL
2g86C3BRLHLQPP5CE0SbCkQ85Kl6mPUFVxqfwja58NLycAL59IC9K+kMhOh4
rtHLJWFwapr18h4Dlkb0+jgTErYjlveu7s7B1iW3Al1sCaj/9erfxmRAY8+l
I5/3cTHZ85nzx6ELCus09KvtR/CSuf/Rs5r74OX/79VPip9O8+I7xm+UwbrL
7PzBPg7YCxJW6LozUULbftHLhQWd8uZ6GujoD8pgh1zmIv2fheai6xXIvJqz
bECWRPqjSkebvxWg/e+4/C0RAqPMDQkmqt1It5lsPdNG9bNMP8TZjg6jM7cd
Wsoo/rombCOm03FcTunk9AEC+z/+EskrSoSB7gXvm9T+/+6RGyFX+w4nE+yD
5e05kI09Wna8sxXSA+Lp0grU/vRb4GAlmYzn33QntSj+ug97ZYYvaITyI/c+
j88k9sTdE+t178TfFxKul771Yzzn0/U59zLo3PSXrU8jMBb2QObOnSb8WhLN
fEzNe79HsXtqMRM8H/8cff2KC77XEmlSwy3oEPDP6eUhUX9h/IWBQj8Ei0aW
FtlR+o7wmlC+449fNHZ49mkCtom7fv/xrsP6MyWiZBSJNA/PTm+XNsS8lx55
O0P1X997w1q8EgK2yl0ySgRClQUjxMdbcPIscY9GcBBDU9M1bCyAQoxn3V1N
qp/TlnPy0s9wKlHnqaE3gfK6Neu/uj6EovA7G6NTBFTSV8WZbKLBSKBTuoTS
F0/g2661qtHQDrFMF6XwF85OO3Q+6yP8lBFdbkTAqDqJPy2iDzlPXWWdfUis
WatBXhLrgsDSDzpRXhyYxe/f+O9mN+4H3fwZ9YSFM1f/1utwqqBn/UY6q5mA
fbvhTtH1HdC6eenO1H1KT9ENivoeLWAyAo0laSwET+00i+8rgFZ14eeYEQ56
1QV7YoubkK49k6idRWLtslftdLcWaCePvM84RqBTbz7KriUFV+515EsEEvi3
uMm4XYGB4MfNiSatBLrVjqoIzbQiWKh5e41/H15W7uNRzMvEqIdmm4ouAcG/
X+9L/W5Fa0cHn1TWIDxpjTVqH3vAfGHWY6ZKImOfpHbvaC/e2ZsL36b2vXFd
2o/b+vlYOWMFj+cE6AVVvTf0GbDKXX/xWzoJacmdwXxaz+CldnzsnD2BxdoR
Mr8Xd6Aqtnc+7yAXw+s1Vf8sbAebh/dRukwf8p7POqqrdiGGwTTJqWTD3Cfm
5IWVTcjcaGAQZELh0fa3MmnoMmyNdAJjKDz0U3yzgh27UeC+bNXNTRS+keIH
jPoaUZyUkxA1ykXWy9IvwcVtmL/jGzGhzoZh3qldLUYVMNSxiBlz5UDi2F0X
Mf8WGLjE39b6QWL4etYld98W6OzRl46YYmNKslDl0a4OZHRsJ0QceyD8o67w
o2oyNHuL526fISCZahUlJcpA9FXUTh1goyboqo3z/i7Ibf69hRbIgZbf+5en
KztwYlG8K8uGi+g0S2ZPfQMGrxU/Nv7FhqPnROPzc60InU5SSuSywedKXjXN
rYfEgHL/0hoSvCvk1h0S7kF8krpYMIfA8jQGf8bpNghbB03d1xmCdJxaQIJ0
M8Ruq3ckPhiCbfynIN3fD6HANYx4Qu3f8emotN6mLMxqneoqlSFwZIHXI2IX
E2G7lU7IaLLw0Kd8tfUeOkpSqxvqSwk4MLTf0Pc3I+5B+mgG5U/PDBpV6qjV
4vJHX/0dAQT+5N/el3m5Dnq+52X2rWeDh/7AOoLVDm9hN9FwYxaKhR6fUEhp
hS3h1FBkzIXvHUZ0wHgFAnWfWYVIEWgaeXOv5fID1PDumos6T8CuavOcGhgo
3iMvl7yX8jclGiL977rwXPx6oaXRIIhoviw/typsrJEcXslHQmzn0u3nTtHx
3CP2NP8Vqr4VC9b+FG+kfLjQvyhlLrK30gRDVTqxyC87YFEfCy/fxm3c6MuA
8mneTnKEhXEJK8s5g2TsehV1ZasLgRvR6hUzlhXg2edguyCb4r/WnH6NVSVi
/1fn/SaQDct623jb6HKU1bsX+voTSBtMPWQv0ons+oa+6AA2+CczGksl26Dn
eWtfmzOJErMH8dNdLQj+Z0LGP2IhNn41b3FzPj4+pOsFUf5c+k6bo4WQFzYv
SByopfye02/B09sW1aPTL4Q1ksRB7Q2RFtPkJHSKHdMRoL633F/kWHWeCcP8
C/uPjhHwfPdXPoG/BbekdHkOsFng2fH1XNjNcki4KyXvu8aBcUf+99X/esGe
C+yK/cuFhaJGefRSyp+t85s695eDe1lFg1+PMhGq1fHERo6EceXrjlUiTPRz
kr5PUfoXFzURiJ6mo+qkpQWPNYmGIaUDA+ZM/GvcsOMrZxAlC7r5XtV/Bltv
KtzCnICYlKCHC5UfJA5bnr6ydRhvdff0CFp9Bg9HJmKU0n95+Wze54WNGG9T
frlBmoOd+c3hATdacXewbrs4hU/nP36+SN08bA3wFOfnIRCmonbEpa0YIXkV
YbvmKDwIVTlFCTqmD9i4vZRl45yb8cMnXXlgWAcyUyUI+NY7F9693gy1ne3M
MUkW1rHWKPZHNsHxZ3HrBmpetYG110rtPqHt1gbLExRfKv2LD6+7y0DD7N41
Gq1D4BmwH9eNTEZw76m+FKp/hZT9nx4PF8FQzt7hKeUnmLMtdqMqdQhNFlJw
2M1FyraNBitfMzC08mPkQD8Jhatsk+9uZcg6uifYto/yl/lu7h4LuzBg926z
569BDDM5zWNuRTCqukC+iSBwV2rZy6VxDLw0c7KMoPa19OKAMCFJBixO12/W
Y1P37MZbO+mKJLiVKbfkU/7EIuGdldHrJthmd8lXrOMi6vviLR3UvVj2t/qB
ysQQ/PM30k8ZvUXSIvaDtosEctfRl9Q9o8E2anb1Ukrv0UGhma7d1TD63wY/
Xirf2hZ/8FIYbcal8OJcoUwSGiNeo67rm0CTG6s2p/LgoIGu+dynT/A16jZc
LUbdZ8Nrh+NzumFc0FxQGsLF9NcjeuyjndjZu8r5fjPlZ/9tsLQxZeAi+dhc
Yi0XG2IfXOu90oi0xLJXnmtIjDvbXMSrSAzW7T0dTe3/lPzZmaHwRoibDO6Y
X0Ngu0utR5hXLSajr+99msmCdadS+oUTzQg7e+T3DupeK9/b8/6tQD+6Gjlb
ZOJIWO9TNvQ+2YJ9qiHBf59wIL280H5XXDtmdLWm9PIJiH4j/9eiXQs1px1c
eheJ8Asey/IjCzFT+igtSY+ArJ+Xb7VSBe7VGsodfUqCu+2sy+fZNizZ9Odh
4W8OhsvT5DM5X3D1g/ZUm+EQ1p1IF3l1tRFlqeV5uwI48N06a+f/pwMjyyqM
1S1YoDfO38kVrsFCF6X7UpUE+PvyJtZsK8Z7W01F07UEiNjDuc+PNeBasGHc
AYqP5RdmVmlsYECg09EuuIoDldF1LdeWdmFcbRufhS6l50kuvWhnOpJejymb
HSeQuNyvMC+lDtdlhrSl9hDYROudlqHys1dUTjoPpW+1Y3OhPKot+GTg1S3V
ykacMGPubt07dLeX2DlS+zVnZOAA8xINQ9qL37ZQ96rc7pBvaFcTfpu+IA/P
shG8R3053/h9uBXbS9x0pPRmtczabIAJh2oy+eZ+ElrDDu35mkwsX/bHpo6a
70PLeN2Dl5sRv22N9LlfBJ7ujdy/aFM9EiLqnuYqceGpabECe5pgKpRZokrV
V5XtGekr0o4/Yani2pEkopc25Wd45uK5oeLjeCqPRYY37StY0gj5kRCfmlEW
BGmTxLGaGjR8KA6ppfZZ0NrNbiyJOjjd6N5zhJrn2G1NnYdmbeh3eu1tP9qP
809ylT/mtyFa6qK8nMgQwg7/zKgR6sf1GyaPpnkGce4/zgGexh6YlObrnShk
oX9SV8f4XytOrHMSGDnMwauPv+Iq7nVAQf8s7cqnIYz/aEKiXS0WdolKetpy
Earg7PSruhPGY6uXSuiSsNj4UXzL2Sp0y3qP20STeCtyZOgTelEtoMxnKj4E
ru9G3vTBRmz2Ech1pPgrVTZ+1Ei/Fd57pA6EUXrjGznd1OFGh7Fbtksei+Jv
Q3Dl2/BnsFOIvPua8jOu/MVlgrMUv+7zy1Tl90Pc6vm8wvO30Mq4aLztEsXv
E4pJyv1MPL1z0Xac6m/JhWQzNa0GSIfLLY5+yIGO9vr/yJBE+CakhYb/v58+
pHF4QV4lrLzNK3mpPP/zwSWa5FgTxAIWbH15g4vn1hn7r6a0w1VQ9PjEEBfn
pM1z4qTqML885c2XBRSfFs6WrvZpheaaaCHLWi5c3XYrLuL9DJkZ8/Pf+gmY
XtmtvS+qE/6aSavwaAha4+0SIcNUnhflyZup4iIwM9JI6HQjOpxulB5rIdF9
nmVeIl2P0tJLsxombHSKa3yIvJWO4a9B7E0UX1Vk1m+syW6Czt1NNRN7ScQW
Oa0nySZEFNE9iqn8kZuqYVDwIwX+4pavVHYTWJNasZ43phZpvmdDtv2h6llc
t6EtkdrvI11ZQmXUvVziHJRwjIkHpamuj8Qof+QcRqsrTMXU0EXXHZ5UXhS5
K7LQ+T6SVglb9VJ5Iyyk2HtEvRLpGSrm8s8IeHEJsZUMGmL4vaSyrlJ839yv
c9f0C8r+NE7eHiBhonjwudwLKo9a9Dp8l6Hee289k01Jxf2RD7tPuBMwSZyt
WXmtCVMTKV7TqlzIekswdth3gfs++oQ8he+c+dSP6Cw63HVGP9G7OVjScbPt
ekI+3itu8vHSILCzRaVCcZ4BT91tO175UPdbUzzIhK8JCU+ndJdT+JVOWqwo
N2yDZ6n3rwxWH/pN9F80U/lDKzqoYfrUEAx/bplR2J2N8YjJilEvAnWKB3Zu
Ha+HwMPH2fVUPQospcpgmU8IL9Tx37CdQMMfwiftZCmU03Q6Pt/gYNJx/p9z
Sxf6jL4W8AYMo2Si8cbFIzRY9JOFGtT8yx7Fs9VXdyJGevr4u4hh9Kotj+fT
68O733e4F06yIGua1znb0wFTl355zQku5myk95Xr9YA3/NCdsb1foeV6NP8e
wcTxoPLvP6tH8FRN+uoZrypUy4auuHyGxLkCa49Ssad4GfKpY4zCp/zO48X8
qe34qp7a9HWkD020vB4LJh05GasddN25VA7OfPPv+hc8b196s0F7GP8H8mMT
dw==
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81Wkbxk/yTou8kWQtyyA1o5QlEVcZRcaQIhRNCQmTZqKxzbFHRSn7
khejaHuzxSHJVpYs5+DY1/N7jmzjFbLE1PubP57P87n/ee7rfu77+t4Kjp4n
nQUYDEYCff651d/yPJmJHRgLmJnZUz2C3Q0yi5MFlYhqs1ujJkcwLOAyma7Z
gnNhi/3lVgTZr8UHR/1eoG6XYrFtAEHeFs7xxsRmgC8p5bR9FFUSciU+V9vB
XszkFH8g2OjzKtXhpxJUXNYykthOcDUtLdNbqBufV8ctnu/lw2l/1i/momzo
cfLu9zcQnLAJKFp4X4X/fR6ojowlUPEKTf/6tBeSBX+dydXgI9K5ST70dSs0
i4IrTMMIbigvNpy2rEVAzcUvDhYUpkKXv2XX1OPi05sqcysUfj8+6TeokY8v
RirfFl8lEIhqLj/L6QRv3fOB7n/qq1JhXziYCa7s1gbmJYIyqZ4T458GoJXE
YopuGET3W98trb0cnDaxsU6THYWqkXLsUu5beOWURz1wIFi30661LJCDYDeG
upgkhbF8jjzD4z0qf9p5/thbAtm9CUiwbMFLbrR7YB3BjLS8W993r1Cmf7Yv
JIrgs4iNffK1KmiXB0WGaRPEPFHUmVtqg/qClqhuN63P7c/YHzva4bE8TvEM
+BhkpYVpNrVh0/botRltFNxyujZQavXgVM0qP3xNwevMbn6AVRMaJ162N5bT
7y9PHb+/qxsTokGhEQd4UDzF7Qq8VIs7DzbddWMSdEpFL4f5crHZ1rswUYuO
w5LzDUO4cGwQdv6VxYe9+XW9S/qdcFcS2GBePgqlyz+cdZMcQO7V2u/d7lPo
fVTkKjnOheCVuvCTjyn4ZeQZKXPZkF6dnRpRJCgSvNf/7N+9SE1ONdioTrC+
UOOE99dWfCguESu3IIhkGbmvvRCFjGTHJl17AgOlFI2k0BZsTrplZZFGoZFy
FBbe24dsw9letV1DeInLO/KMulBWFfHfsYc8JM39KivhzoFSySMWMSPQLP/Y
7CTSioXqHM3EXwmk0/oUO08OwO36OkmL2GF0t0+1rdcvQO107jYrT4LfUsI9
N2S34pq56s06cwJByzk5M40qFAWPht7hEhy2vFGab1UOZqXCSmgGwUCzQnfI
w14MJUuPGXUOwShH5s+HB7qg93g8fdiGgL218GZFXAEOO1FVn+j8FWdjSt8v
9sBDixW1RpQP1cazdh7HuKjdKLJjVY+HvIDnXxiB+VA+cyongNbDXjC+wDj5
BuWxo973CgisZBvaTZ5xYS2fJs4K5kNJ8WZ1l0Y33D7GXVx6SiF3ueA2Q/UN
MsIvSIQaEvg8+BduLFehk/NkZ8M+gj05QweNj3Vi7RF/zugiH2rzwn/PpbKR
VnM0KrCIh4w/jIXY2uUwzN1lL59FsCpqYDd1jAWVzfu1RxQIbCGw3nmiGUuh
DqoZCbR+CVbu3fEWvJvVD36zg4K2jZVEpzvd78+KVH4i/f8mSTzXmFbo648r
x9F8OPS97L5hqgbvjn1N+cuJQHvBqrkF/UjTTx8QHeNhZsqCtdelC9anmeuH
2nnoLrWTHOl/iTZ7ccWsuwRTPzlnyHVz8c42gnKf5CHkumCagTYXYnsabL9p
4aGs7JfSHZ4NuGUson1FgUJyskF4aG4d9ld7Cx34hsBMR+bdXFwbhBIK4txd
6Hr01l3Ty8nHq/ORC9+dJggI0pH3KsnEWmux5SlTgm8/+jTvyn4FwfWTO2ON
COR7qje9LnmPx6xFxX4ehVXfnGz19nqck/nx05wQHwmcE7fSPnZC2Hv642Wa
J2Yr4kMWU3Uwu6Y4+tqdgDR9/co364bNo4GYUE2an72y2rNXmpHRaLI1/AOF
ivyxmrY3bOSx+qW1nhAwZluuCVqWgTX/s01/CAFX7yjy1nbi4I25QbnrFBIe
Myf2tbRjZptIfGQuDzpOEgnBpzoQEi87tmmRh4TAH/4wzW2BxIPvZFpp//XP
zmWL7u5BtLiUif3nUTAzs5PmUt7CtbRHWuEMQdaKSmFgQC0WxEPfHaqjoKAq
93ygqg1OvQYmL/woqE7OG5cmP4G0necT1nG6H2+DXX4/NwgZ/rPDV2VGcVjl
sqpLST+sNr4+csdkEEF9yhzpNa9wO/VacZ0XwaOHt81GfiuDasqAqfshuj5n
Aact7h0wdRBecP1Kx16/6dhcuohyV6mhPT8TmOq0cqY/NYGb8X3uTCZFc7Rm
ODWyA7ejJz56NdP51s756SZw0BAv1mbTSPMy+2dVxoE29JyKW75Iz5d64P34
LYq0/3eraPbl03zpuL8nz78dERUVO3RZPAwbHmcZq4bA3zN2QpPO56O1JrbG
uhS75Sxl0h0Jlg4wVzM9+qFbNuK57u8RmItyfBOLmxBkZqsvyCe4+7LNZ1Cx
AbpGDsVZIxTK5v0mjWLZuB5UebJajOa18zbxm0n1kLrnZru4ShDHiLmlMN8F
rqu9lJoQD4anNzOlZ9mwNu1pdZfgY7iuZqDiaAqyPhmcj6H1nwg/aCQhWIij
KX9HZvoTsKQUqnOs+zGRuz983QvaP+6GNWr67Zi0atkmP0uBbVd+ZUmpGqWy
H2KMDhJkjBVNNpoEoldHhNNG8/TfvveUnpIOVG2p0Py8xMcXB0Fn9+VarLlX
8KbkKO2HZX8Dw3ed2J3xY0LDLXqfr/ii2CgTC9kMi1Vaz2HVwtmGwU6Yqcg6
R8wQmPgIOux3bMWwinPY1UW63rgL5nnxMdDcecQW9D78j6mwh2b8ANKYbnwN
z2FU5iSPLmb3wZyMNVYeHIFrv05sRFgdkrO3X3o5RiEm+kB9diEXc1nTjsxU
Ckm554UVGUUodmmfjqDn50zDC+Z5sR4U34lOsN0/AqbIViGBei6UNZ/0DUwS
ODGGm5mlXDR66+6UWOXjmcviphHjLjhYKvitRvERxD6kFfpHLXp8DU810v2b
91g5PJ7dCbX655P7JD8gXezEhoG/WqCjdllgbJ7WI2XT6/ShEcEXVq+v0Hpc
JPv9zwk14tBSwivNRArT4v5exsYdSP9BvPeTMMG00+CRR5McnKt8KvWGQVDC
PacQH90GyVT1lUPfUPg/VOXMPA==
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs8lOkbxqeSEOVQoUUpRYkiQ6S5Jlq0WaesVYmIXzmsU8ihNNvJFpUs
HYVWRUNYZMs6DcphM2bMOKtm5n0nKjmlsuWw7++P5/N+nn+e976v63vdt65f
mFvAfBqNdo06//86jH/6166iC7KM61UpNhKwfrcLNe4/idR4VkuXD4mF8uqL
LH6ux3SeR06rNQmXmCfTcqYlOMFQtSwxI6GR/G7bG+ZfePBZZ2qFBoniRsu3
Pcd7oCJ6Wm/DlEL79sTEuVM9qDrsWxYzJ0bUdvWdzLlmBKq50q5nEpDJPOzQ
miFAgaqMwa0hMcLkvUyKD/Bhrm63L2k3idj0W9r/znsG7p5DgR4jBJRp5bsm
6Dz4q4fUzzEJ+N9jmK0jruGqc4FsjR8JhYzrGtofGqA1uzHKYBOJnIbe9NUr
ORB2m7aqVBKo+/olbvkgGypb3XJnGCR0Qk4Nz0sRIuHH+0sqrKn6avnrS8wE
CE+0ea9vKUb98uGah/ICdBW2s25XS8DcJDtr5/grHpjZGE0eJBF3mC/SHxOA
texLk36/GE7XdsYmfuJjvUbHTy/uijGdOjfwwpuDpuFQr/VrSeSvcWOeqemB
FW+rO/OCCKJdF0ea9fNQrsPM41D95ibFbQhv4qBQ5c8gu2gS1qecV3FvPoeX
Ode2MoGAwcNLOdERXFhpNlyepe7NW6rpLkt5GKCpKpnfkUDOpEiQOlODrDXt
cTWUH7xZZYPshHLUVHT2uoKEk/vz866WfDiVLRAIEyVYd86/kRYhhM7gx0Ws
aAJ/MOTbJ7x7IdHYM9uWJ4Ke9khmQ0UdRuhHpyJ3kHjjqLgyhNWDjDwBjykr
QslrxZNxmbehaRyepudNInX0pXgfoxX2V8tcEkNJTLkLXctVG3EmI/PcqIiA
knyAE7u4C8IQUXp0rwQD/4jjx6wH8A/XQXbdThHSYn3pal87sGGkTeaOEoEH
Jadzmm06cS9046GeYAka3wf/sCCfj9UDTccaT4vRxZ81fjzahIvLY6UiCYHw
7kIP/V1NCF+aesFGj+LB7ddS7SulcGGVdq9kUXrK0Pl6JnwsbN38acheAs+5
s+lVaTzcm6Erq9sQGCwMP3bySj/2S4sur/Si/OwWfIps4SH/2v4o/6Ukmh9H
ZUyaNMHrkTt9yJ/yo92uqSa/Di6b7ATn+yj9wt+8r6zvwB2RafM2BQKqeUul
zjECbPIL/1VrSIT8bBf3cMVO1J9m7RjZIAZbJXnqckUTDq3iD3Sakrigkh3m
LNMPv6inw/NnCLCvvm0uPNiPsUe1nKcQYcrg79W2lVx4botxjL5L8eg0Vdyg
34ZbMtl1H34hsDXMMSg64AVCxxsiVtBJLJ+q2jHuJsT43nfy6xhiMI9oZKav
6ULjyssm3IUEbmwR+RifysOTtFOMzcFU3oMY874Vc8HwfyurukKK/Pk9h43q
OmGuacHUY0vAKba1WnG1EYq6u3vtnUhMfojXiT3AA9fr9Xoapb/b/ptdWX91
Yn5xxvkr5SKwdH0tjvbzELlxhYL2KgL3+m3JC484cJ9JIhXDqH7/OCQ35yxE
kRxhF3VTghfFM4c8I6tRkDraEKZNIlPd4dkVcT02L2zZH6BKwuFoX8at31rQ
8npRKl2BxLsvZZUR7wWQqt3+qXAzCbnQitkUfgUUklOrP38i0JsqVO4QdGD6
I9t6fw2BTKNqu7VjRbAv4MQm2lN8PnDNCmwWIlFnhufbLEZzVVZ6/d0OVOU6
jv6yXIqsEGuTgO85yFJsn/HaS4I16OdZxOyCOXvguvtv1LxMV3PQnYrEq/uN
CbMU/3U3YwKTj/ShPuCM4TeKj4LAdLWCJV2ImpYOHTgpQV3/x760tHaM5ppF
9yRJMOYf4anb3wdH/dBLq34SoWrYuMilsgmqmnnVnxcT4FmFrcx2eIK2AsNF
fdtJuI+S+RoJHWBovHnMHZEg0ndjyzPFSoTXcYN6E6n6ss2NlCyPIN4tbrca
Nb+9kpI6xhc/w4SCXJxWN4EUrvll9o4uvDqrNjFlRGBx6TUigtsNbtH3DLJG
Ap6ChWpGPxuXEl1XLbQhoZigousTwkfpXb90szkJ7D1q+oLmcbH4ePTmd7ME
ji1tuMVR4eNATHu9N0OC4dE7VSnlPTjtwzayOk8gNvjMBfMSNupYZdLFASRm
ZzWDWBo8LPOxDFxeJEHQq7Zig+PdsPfT2J5BSCBau0+LYVkPrf8dmm9pSEJm
X3+s3mA3fH9kEEE/i/FkMt0qoJ3iwYPbnPKZwNy4Z86ZZCEW1nxU8DhL5V+6
IWeTnBBHZXrtGB/EyJk+bxqizEMJ0yLziy41L/sMa3WDe7FhJ7tv1zjV7zGT
AJVIAWjtZSqJdAJywgVWfw4/xcOrxieOf0di7P6rLcWRT7Ddfu7OiDOJaQPN
osLbHTDJ14t6RO0HrWjdqdzop7j8bMnnG7YkhoJphTJHOvF02Put4QkxhM6y
DjSrSihbLfm6I5DEi7m2NXpMAdLsDGJu0yQ4rW93Tp3Bh/T3pVFzstS+kuE9
j1fKRcwD9r086n9asp2DLnONSLyYcNziDYElKic7VEuEcOFOltKPUXotrqV/
u94Is23be7uPEYjq+9N6maAO7lNPOoWLqPcu6XfrJHOgGWhRU55KIl36w61a
wx6Y9lelxxSIEPnzxpcn3VohOeL7netaAqzd8z7+O3wFRVsnc+IpnmW+rE7d
s7YeQRvFYa8DCDhV7Q2d9hVAmaCdWm8ghiIpqO6K4ePvA0bzjEYJMGlXFlWc
6EaB2zML6xARms82tX31eY5K709bDK8R8LQd3OuTzMcD45JR+jkCr2pj5KQr
+Kj8ljB65yW1D1JTCl/HVCB7TNNN1ZGEfttjnjCjD/KRmvJpAZT/zIbMEd5L
KChVn+DEv0QmLfhxrqQH5unfeUR4voJe7TL/rQeE2GZp83VQXowhHbf5Pn8X
4qj8Pz8kWVL5eRmy6WJsK7YR4aLCZCp/R+X2ErsacLdHUmHLpfLx3Mo/a7IV
pg+jVt8fIGA2oSs8eJ6L+BzPSu80CWw0WkziDfpQxi3N3e1K1VM+eUOmrBxZ
24+cdWaSOHgu+6aSqBlGnHW0jAUk/gNgpLVg
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 93->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns4ldkXx1VDaijXRvNjMHMooWmGSoWvoShScptRoeQ2iFMUIppEIUVy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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3lYjN8bxlPKtz190x5FKCUhFF/utNCGSpuEVFooylZpkYQiWoSUdiTa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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81XkXRpiKKZWtSfYkFUXJlkfCS5/GHkU1yBJ1qRmhdGXL2EmiRC+l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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns8lGkbxyml3ZDaWLsqp0iW0K7ToJ9CvGpRaYxz7Cg6rN6yKCmnpNK2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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 94->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVln08lWcYx7GSVVpeFsVKW+UlRqi8jB9SSea1zKKoiKFREeqQRFQqlIrW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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4Fesft2UtRJakTQotlCUhPkKKhCQhpJJECm1uy0VZyy2icqXsSyXJ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVns8lVkbPaKTpLtc+solk+TWZRoUzTrlFErijFSuucsUUWiMiEoYkpIi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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlWs4VekbxpGMSpKkRpIzTZlBmbZUtxCmJDkNsiNyztDBIERyaGiXMsip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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 95->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lWkbLsJE0yIpNCUkjOpopGLMJcnIV8qWaBFiUrYsM5aPVEKLr0i2
JMlWsiRKieqM5XAcjqNzcCwtnleKFmUrjO+ZP97f+7t/z/3ez3Vf7/Vc97PK
1dfGXWLWrFlJ9Pn37RPtLMn90gbTu1ZJo70EFv76Z0b+KcbmD9tSlrgR+JRL
Jw06tcPr8YknBtoMXhzJycu2rsdA7Qa9NecI/LIZoWpsD1QvKxgVWjHgGB/g
jg7XwGNVuQ4nnGBIXXzWX64N0s9/uuE3Q3BemGHjmizCikPbZPdaM9Bhm54z
0mkF05f7IPcRwaxnp+68v2+IdD+bEJYzwaLvBoHNUs2Y2mg6Jz+FoEO9poLP
/Rs/vE18cSaYIMbYfP/5E0/goH6zttOHwPWGXJVeZgsyXSXP7nhMEDEtcc1w
oh0dI4fcQ3YxUOasq1kS1oK5j1Xs8usIFv68JGbVTDXOXPs4l3WC4Fl3Ze4y
jW48uPiq+u8uBhkjk5zjk+3YN3rn80kRwVTF2o7K851wq1Mx+qjK4OgHSZPe
fVwYNaat4OYQeJnLLqzJr4D+5P6rJZ4EsVfHDzVN1GBotWKx3hmC3x3eO3q9
a0fk2cp9JhYUT6bsMp/mGsTfnHZRp3yZFfv5rj1eh8yw2c25FwmIr1+V0KwO
rFu+2v+j/Ya/+3A3mdeBkk+CNXG/M7DcOYc9rMYHHiYf76X8abjZlhT9IgTH
flg3aZpAuujgQG5HI5LUba6IMii/lWEzX60CcOenNSkGlN/H+6q1tqTx4fey
SVvmFoHh3rV/2QXVYWnEy+FJive0wqpGm3QxrFbuyPJ3ZTCSMVMeL9eOGFeD
aPd1DEh37lbJcAHKRz63v39N62tNz692Y0Mj8ftJdiCBFavQZLN/B4o0ecZV
hgz0K+SZuN96ofLHQ3flXAYPQ3dWNmYJIWuyvv+YGu2nJcfm/pNOJCv8MOHg
wICXtedKkicPamp5/ym+Q6AV9JoLq3KUWSwKwR8ETW+W++bI8aBJXCodEgkq
tM/tDmUa8Ky1OPL6DQIFB+vZ5nZCmLw75n1mDgOLzTqKYZuaIdGQm+dUQMBa
Kcju+1AOM9ba5O9HCTb/bpr04y+1CN38vMU+iGAiNT/q5dJOyEwvP7z8IIOX
MU2nX3sKkNI2z3oPIahUtbe93tgJo68TMm/3M9hj62l7W6oMFtLJfFuKb49G
dJ1TYwVMTqYnPqB6+PytOmPXeS6WLv7FYWkq3c92THqxVyl8wj+e2+NBcLfx
gp7Mdg4qrQ/oKUYRBAoWsxL2tyJXa+CjbSvlV++0kWPWI1yw6FIQexEsX+Yj
J+a0YuD4261rmwkS+xoc37TyYHdLsrSolGCgtC/H2rIF2TPG0xz6fz2TszsL
mjjg315k/TSOgP/ALI61pBKZLgkW83wp3uzhVDO/W2j+yUM79zCBibIs71rP
JVi9zEz2oXpRO7kgfr9dN9q9139ZKdOPHjf+tgIVIZ6mvrJYMJvBwhrDvlPP
WpH09JAdp4qgV/nMhvkFrai5WRWpRPUxwbqkz8thQySY2iAZQutr3d/SpPQc
C08E9jMBBJMan3wbDdswftYhwLSWwMlkVfAyiU44JylxL1J+vYrDr13e0IVl
RdIz9scYzJISD26uFaKmXzf8j4cEkQ2/ZtznByLLBDqbKN7Io2lVsUtP42bz
+yJzGgvMW3QfNr1Afvli3roWAlNt8wdSRARFE+582UGCzIKqDXvckpHz6/PI
apq/8/Og+O1vFfh+L0r+R8p37webCBfNVuh0PC7/iyHQybiyt/9TB7Y77Gar
7mQQubFXSkk7CIrNkkP/7n94e+H3Qq06VKO+Z5z6ZaapmYp7YiLyHsaMpNL1
/EJnsyyzEJjMTbMzorE4Zdzfm9WM+QpKg+5UH5nOsq6i3XHoqTTT96brhMUa
nd5Zg58/eKukniR4a92vZB8qxrfmkqjVlQz49V4WjocvIzng9aUAmj9iLiGh
n8HDUN+84ReFBMcM9HQsF7fBOXDwGm+I6q261DA2jY2E5m3FptRfduQbL1C8
y0ZlU5uVYhhB0VR+TwTNLw+1/rJJkvKd4njjhGIZNMfvXu+l+l4nnz0gK91A
/W5M40eqpyNmXBeZmWZMmE1zg4uo/56+Uiu9hg81l9p14dnUX4v+curaFIzB
iKB3Wyi+Gn4NGXslQsch8vMcRQbVA13nr/cKoSyUiDlFz+uvgSMcw0e1YOcH
fGs7S5DyX9VE0Z1M/NMliPek+pxz+4DNdHYKjum5bqyg9f709FSLqmfDuXW9
mZD281lZ/cJoLBea3+ZtepNF9afbt7q7sQFMjm7400sEJdc48d676iHSHDtn
nkDQMKU1ovNVjLG9ez1bBQxG4x05hsMirBSlXp5D55so9tvKr/caoNT+Q484
jaB7l3yJ3vUclDZJW05RPJlxRQ/mSt6EzahOTCSN86IbHC5EilDnJrNIxZLy
R+S2arjdA1uv3KOLzlf+rutlfYK72Ddg7e/iSr/33hcW7FcNYmPPlqLzaO/4
QXFFbDfSQoIOqtczCA0NcJ2nJEDVYFvObjHBk7Y3VkaxIrxYgLKL6gyS5D4e
lXDtQbSHccj7GAbpJY+0ojwKIe/r72dP91OQKGg8JMuH8YGJlug8Op+LU5a/
XtwAy+AVdfHRdB5Ksp5JFAgwUFRrqsOmfuCVb21Z2oQb785/LKH5HeZlf05N
V8Cigc+aOE7Plxv3kXF0J/SFpYXuRxgMvR/x152sRS6k56rRev0RL0M9dwpx
dUuU1JflDHq3zpydN9qD7mnF6ogEBlO5SVNjswVIj9q2ZWaMYPUsJkE+oRuN
jqlP7D4xeFWu6bTRqxi6t6bD2BT/UJFO7wpXDuoVWkzbqN7WdUQ938oXY4oV
HzmpxCBCsK368qJa+IWq8GToeYs9VbYjgPpn3njoVUnKV5QBC0847bB18jbO
92CQGbzi1VbVO9B8ar+a50LQdpPRsDUoAcdciq18hN6H0Fa6Rb4SlxPerA/x
JkhujF7geKkDo3NnQppOM2j06pIO6udiheTRuPoy6mfp63nHLPIxFj2SHk7r
/R94RcqD
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VO8Xx5ElkqyFVkQkQlkSfYiokFYpvnZJJBUpUSoJKaRoISWJkqzZ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81Vkfx5UlJJFwR4sWk6RRIVw0H4ZKuWnRMiGhLDUVRUaPG1kaNJaK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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns81NkfxifNJlbKpS2RZElFZRHa8PjZaVxWudTaoVyqpWxitS6lRFEr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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 96->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8VVkcl1RCQw1FJGVpUkM1pGnKNyohDUpS00xSqChk16ZUIjMkZZsM
TcT0imT36BWJl+U9y3sPjyznmmyhULaaM3/cz/3cz/ncc853/a1w8tjrLCkh
IXGXPv+/AzSd7C2juHAyGdaKTCJoyfyS94exEEbS/vYNWxhs+f73jMHPjehT
urzEsoHgeKfwwvu1dWgpbeyQ4RDcqL/wXLucg/Yd8lltngTT/pfjrbbxsXXB
5jB3ur64cmdtREYzbpeqdOqeZiBiBb1+t48DOG53XBpEYGM2XTpHUwDxbfv5
m0wZCCLnybyya0T1Mr1xmUmCfS9S1wzMFYNtFbVj5zUGX6yLS2uPiaDK1m9/
6M6Ac1JRw/thGtxXqmYfPEpwKDRfjvWZB+/BiH+ERQQaB2xiM2XfYmNlQGz2
IIMp9yW5Q59rsGhgyET5HoH73Xan/rVNMG4YrZ41RZBsvd9Qlp2CQ+MJn+Mc
CZr6ngWHL67Gb74/Z+5IJsjSi2ywpffbsHV1TVgaQYH/T+tf9BVCqjyC0fYg
GNba7DV/Kg8mdfIts10oP0+Xv7h7mIfrF139bHgELOORKIkgHq7kPHJg51K+
fMQyr3dWYM1Y+GnZWwRz+yd6DcBHu/r97QkVBByvn/jbDJuw6fSk1Op+goCj
B04WMQ2wjtec2T6XgUNrofWJSCGsa5cordBgYJb5yeyHISFadj/9Y84mBj5H
b3zVmN0C476+wq0nGNh9q5vlXNsGk8WjvbIl9H/ocebJVmPYZc/6zscE6hFy
qtmpTVDuzlNXNWTg7pTH3PilGA629/9860bP16iJzcrhQWAwtCOumcDUp/DQ
/rEmXPwjeN6C9QwGeBdTDe9UQfGWPNMXTWCWu3WNkd1TRKulXl/iTFBZc+Hd
zY587GX5Bsacovr3P3wU5fcPujaOZAY4EcSwJetSRGXAhsHJxEsEqZrKk0pu
QgQmrsuO8mLQETO8xlY/Gb95/1W5i+pjHyv4TWspF8zaL8WiFALI6U1kqjTA
49sidmnr//tpy920aIDXTx9MLpYQlL5/kBBW1Yy+1cURmacY5B24qWy/shYX
WQe36FH/s5adeJyTmoP9vo8+yrtSvEZ52636OQhKTRSwvOh5yZJxmeI2TBPT
o57f90DkK2WtFloGt1mHql5QP58P8vd8ENAAG5Vl4XLzGFxtCzPb59SKl+oh
YtVKBkQm9e9f1QTommucmKnNYN2nTV/PSVYgX8Vj/VAogdXypxlm3BpoVYZy
7ai/3jkJogLjXiPtSd7xTuqPgk5lYbIDB1/2NJ/K8KF5rDcYcOithNLVCbmZ
69RvA6ddwvrLoZkb1+BIvx3HFKd6dGuRmdjZdozqG/fifH1aeiOiXVvNXQUE
l1Z8o8P15YGb7lqTX0bAdtb4JtOiHn6x35UGdhJYRnpcvdDVjAitkoWbfmGg
KBhT1Hxbj8qyBJF2LUHwPX/dRWo8VI4eJyWUv/FZOeG5Yh5G7EQJT/gEytqr
q3wtn2NkR08EQ/vh8wb56URtNmLu1k9UuhO8b6soM/6xDQFPDEYtwxlwWQUb
XPZWY6HtoUIJiv/wljZWV5gAPkNuzrz5DBylDI7o7MtB0J5ASUOar9qsM+bH
TZrxq7ekquAugw/bbfZ29fKwTr6524L2TweH6x2dnoG5reI8Heqv+pGZk/yz
VSg/eqcukuY/To2l4fL7M9g+0lRrpfupS18/nLKDg1ll3Bn+WYJN/1670fG4
APqR53Y3UL9u/vvK0x/PiMDX4RkvVGGwTXHLrk/FMVib0++UfoTAM+dtt8eb
bDjw9/6sd5xgXdGuiXOqPNxju40n0jyrupWVhJo3YyA/2nR9NAOnHiMyKODh
df7hpIqHBA73q6+GHONBXbB+5Tjtr60xKeMXdLhYtESv7XU6QXuAnYXKEyGm
99k7xq5iIC2bF3zvhxT8kHLjiQvNw7clwtle7vUoq1hXV0j1tirkpae1taNw
JirE9DODk0HPnYu7ONh4WiZhjOIr3MKLcplshcKR257d1J/SyzUf7DIX4CD7
eUkuzX+yxTYjxl0Av16ppgTazytWFWrq+QkRbxTsl2TD4IEw/Pyy8CZomZnr
+78jUEiuEViveoyIhU593scIuLdWcLUuNyNw7P60QQjVLybllUirAsdnRqUv
XSUwsKpy4KRlI0U9cViJ8m/h/3HSZqASnDV7Bq7dIeCttJ05EfMUVk0dDxMo
nw63vbbld5cgf7W06bMzBGuNOyTrf8mCjYPx9xvp+rteMX/8TTEcTXrFHKqX
Xf+BM4OBL/Fx6PUaWdonEnuTXCwW1MDErvrcglSC0UerTPpD6hBRcFc8IKJ8
hdaUVC8UQ91zymLKjME/Ouyf3R++gdafLrxdtwn+1JUPHksSQtcle6WUDgNe
a5BrgEcGNksqtE/Q+eO3u6015cdGfJQa0LZspHmtNe3iLm7A0dopbu8HOo/m
8A/HmudS/PnBHhTvZMJsPxV6n0bdjPfn7hO87PVdbTerAdd75qeJZghEX3UM
lE4VoTy9fNkiiiet8OC+SrEIrDONRZ0+NC8SCsNTH2k+zQMu+HjQPvNhNxn1
1UFv8glvQSmBntaEhGFHC9RaJqeCPBmYnzfU1TargG6gdJnnZYrfn3dw2rkW
cmrC3fceEMR/eDzYE1oD/pTE/r9onnVmR0vnWLeBp5QUvLOFQUHGwaw3wzyc
sGcn/Z+f4OFuaX2nv3DLeTRrM/XfCTFWedXVQKhYVr4zg+BrNVf5O+O3aL5i
eVhDqQfeEurpz/WLodb6coMUxZNsJDFguzwaH67t6Qqn+clafmmydGMLpGxD
LmldYZDWde2swvxGKNp2KzMtBBuKlqa6/dqEPQn8m3EjBLpvkt8r5/HRMWUe
oiek8zR2qezcpSK8XWnK87Cgfj9ywzTBpgGSw+oWnf8SzJ+O/5Qv5KJmxZ38
oHjaLynu7zVfClDvECQtAvV7vVlPTMEzJKtMt7+i8yr4UOss0bAYpKrrVRjt
JzfXv2Uz27OwlK2gIEf9xhoZmzpi0gSZ2/rz4nsI1OZ8HNI7+wpfpaJZLRcJ
/gM5Hd0r
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHlYTO8bxkekkCRFCy2IkISEpLuihHYh2VKJikqS0irRhva0KSrxbdMi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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81dkfxm0NhivUSIk0tqtmlFIhPJU1S4ykLHET6WedJJTENCX91FhC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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lekbxsmSZmwzFbJEC4oQSinjsqQxKOUnhGQXSUTaiKQMMxXZWuxr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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 97->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs8ldkax9XkkkNhqChynalESrQ1mp9OTaWppoSKsHPJVsQuRXK/5Dq6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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3cglf8fxSkRCRGJaMlI37JChaNSSrJSShpWKZGREF8jZJSdyP4WSZQ9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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk01dsfNT1KheKZUoZ6pnQJS/GjnfIkQr2ISCSSpyIPCb1KwyPPD3V5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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk4lekbx0UJMVkqSrIkFUZGyVJ8LYkmGZrG2CKiOUrily1bo4xs2YqR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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 98->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekb1lgm67QoEiozVJYsMwzRuSV+RDUlEaNx7GPITgtRp0ERNYmp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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VO8bxpFsKUuSUCHao0VS0Y1QqZCyJWm1hRBZErIlqZQ1LShRkpTI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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41NsflihXdP2KQhSFRElFJHnRggopV7kpKkRXRdxItuS2Kku2uHVl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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk8lWkbRmkamUNCpZjCHByyZPlsuWRIY6IoJWQLnyFLhQpTSKXNEsl6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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 99->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns0Vdkfvz8TU24ZJKSbaJRHxjAoCh81kvGKQpKZMNVkyiMqTBRKI48e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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8lP/fxUWKFkXWomzZkkopSh1ZolKWSmVLIeSfhNBUUlkqREWLKHtF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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk4lWkfx08SGipb2sgSkTC20YZvvA0Nb42EJBklOqLIkkMISSo1la2G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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4lWkfx2VM9ZLIUi4kjWTJlEYk5CtpKFlKGTRRREK2StIkpCYilIQo
ZasIZS9bjp1TnGM559jOeZ5HmJJqzitmTnmf94/7uq/7j98fv+/yudd7Bh30
FhcTE0ujz/9vIaN43z8hA2BaB0sFq1Bo2dIcmR3NwhZZFaEfh8CJ101O4awq
KFuu6gxVpuAobvClxbkFwpboREkNClZ6ZwQtfDYonfj6iU4Bon7ubAsw7MeW
xkf1h9UEqFJde8DsFQ+BM3mzehcmYPLn/bWJalz45lzKaN1PwKYhtCZlZQsG
DS0u2PxNgt8XoHK5KwtTAp/d8YcpaJv9dMHt8FsoyFob5hUTkO2fGnQeYGL5
5s9J18xJbJWyXlhm2Q2jkUzSIZmCpJqHnTSrD1maD1rPa5Jo29x4PuvBCCpe
LWbV76VgdKM04p5WH7TPOUi7LBJwjqs0rlrGRZplQGGxngCZDo0PjBk8RM+H
vrE+Q8Hz5JFdDOEQ5sYFGs3+Y8iUaHuWrMNCkuWPx1g2JKKOrqJiHF9gRr/j
2y1jCnrqooCFupdweSbfqOFPQdSOooUyLqDMDlmw5EPf+7n0zAgLQpUrjD1K
BMrEOZ2SRizoxX0zv1NLICqIv2N91TD4rokJd3T42JY/sxBp0wP3iDpJ/xIC
h4pf/n6F1lvtUikZckyAdIfl04rpA8hnKbU75QqQrBOiYzXaCEYcb2SNDIW8
5bm2k7kc1MjImzuZkjBPNfVL3NOCv/+jfT1Kn8Lt3YnfShq4uOGeYNhVRGBq
TtqwPLgb0ZlyJ7fS+yjVNd1OaGWjQrdJ4f6/9PxIoijz+yiwStOuaDvt94c1
A0q2BQgMUOnZ/yuFtLX3uP4EGz9cF4ZFvyNBeCVJpsRxsDMgimc6zUfYe2uD
akM2Woo3pUyXEtCXEdVLnOIheKmJF3lPgHdX5/SHE4ZRbNPX8MloFGLP79dM
THXD9/Zw/oFrFIJXjHHuL23BPn/bPc/vkdjvki/7yyADWSl9CYt5JJQrM8NY
Yr1YEauk1NND4Ppz7zTz9w8h2zFpu/QshS4F1V/vB/ZBISvmibMkCTZU7Tnv
uHiendrV9kWAipBxa3vyDWpeZOjwqgUQ3omLr5XsgDEnnmkQSGJOxJCSUh2A
j1m1m+cwgcA/Sj1zNw3jgBxP9PUlidZm8QrmtreYFGzwDXOnYHFBzWy3TCo4
Svpamz0p8FOLbcXW5SOSzwhaQ+ulGj59Qi+ZibT2SdNjuQS03ch/EdKBZIuH
brPSJDqc5DJ8y3qRetE2fSyLwMiEbC67lodP2Z6jrv0CWJR0p5zc0oRsRf9S
IzrfvS2aAUPPajHRu5JjpEQh9nv6AS0FLpzNz11Uth+He7PLlvMr+qE15+ze
XUGAmk3oavrGgS9Rj/w6Pk7wC/d9sR4A/5GWdZMO7e/Qpl5inuaDirZw4zid
z/RNSZFel2FafWBjC72f+DlT5uRvDXDxubR32TCJBcavHa/mhvDt8I7PH5wJ
fFi/ue1pVQd+zvKaULAl4RJetVed1Qn3vtuDn01InPSa3Ji0jo3wyF3BUiIC
Pbvy/awfd+FNjeqFN68JWDg8zIn40oGitU7VX38nES56+niDdiWOHzpYfeMY
hZJ51XcRBAs+uq1s038EYHY1njKVH4L9SLtHRi2JzGPrW1eO94N9XXDmvJCA
VU91lcGnYrgVFnX/9zcKHXuOstRd38JKRHq0uZCYyk/d4TnFQ7ax+aBc/hgq
jn56H2QygHINhQ9ia0gkSzUbSdQ+AbWoPRsWSvtpmhEdqv0EdqaKdStpPR4z
9L27BAyceaSX0bGOwsav1xLOMvvQaZZ4d7CTRHwoLupf6cObga3ZD3gEllZn
39s5MYbwsGI/x418rHpw+qZH/SiODm9/tvkqib+UGGcN3TphbLRT1yuYQkMu
h3NWrA/jp72EPqE0D+XMb6r3vsZLnyW30idJBEeI9Vx+9gTGx0tn4/ZRSN5h
xR3RzAHP3KjM05t+54hNfIxj4si/S1qfPiRw+uZ84ZIYFuYKGnTvWAkwYiry
KRE14WH5kbiL8RTMLcrz3GvYiBc7uNrRk4Be8rrtY2ajUFdsMy31GYVN+3YJ
16pX+Bio3/xXJQXlpBz7Mt0mzEQUfL2mQ2HZQmYoh1mHwCSvnbZ/UOAQftpx
e3kYMCuLXvWVBOW5vETZkoXPGpIaQ3T/rHyko03Uu2Esu0xBX5Pu+8MNjYtC
BoKj1nqeekDrofnBWG26GjeLle0/0PvVlD3ZJzzEQVjIrco/zhBQXgzseOQ9
gB7GRNLmPQLUCB37fDNpfXZxPHczSKT/vSyNCOdCOLvB00GSD7Fpx1NMcTbc
YiYnKGUSsR6i6u+Vw7hSXrXqvTiBWJ3Y4untQ1hDvZ45PUrg+/G7kV6Dr5EQ
wcw9ZUnhkW2l3d1LLKzQH3edLicweO5FQX5JN3T/bB4aHyJhoRtwlB3EwtIs
9cAeawIlT6X+3JrBxiCnwFt+G4k9fZdsc7PbIHfNXnEHzdue1bOqyi+4+Ier
pllB8829PsQ2fjcPMVKLtZJ+AvB7FIeNHG+hZbVVv+dxCt89yn5pjR1A2/yJ
opQCEne9bsgu/ziEoPxzj/U30HlxDrnQebUJCwtVTt6PKTD7Xxe1/94Lu7eH
SoNIErJZMRotTwtwe1Qgb0Hzw6pqW7ucaxcKk2c3ytN5kpCf87Y9NgaG6N2U
jIkAVxum3p9IHkDsnfYczdUUCmplAmtSOJjstrITM+JjqV+I7kV7NqaNjKVM
DCkst4sxMLBmYJ/YEsFhgsTlW7s+bhLwYPV22+TOVgF8jfNMIsk6GETdGHSg
eWgzqCwpzRhGkPkR/9y5MfCjSAVeUh5yktS0jtD/sYX4z0zr/c0Y8yp+7FpC
QsQxZciRr3DQ6kCfkzSFNvMK7Styg+jNjcjdGkRge+FwKE+xFwF7tc688yNx
x5dr6ZzJQmX9D28n0+g+u3ik6mcWQjfgv8FMmgepMwOnZ8JHMMXhcrb+SCHe
NXveZN0gVNrnJS59FOCnj1/idor3o37JCPkik0TOeQ3TN4rV2MV9Yfd0G4Vy
Ke3kxSNDaJZhXZRYQuJ/brDNoQ==
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 100->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4lGkbp1S0Q2zWYduK6OAsyqpVv5IkpySUGjnEkJzZVEbNVois7PKJ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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8VW0Xxs0VCpEQQsYSQinSJWQoZSpJMquUQipUnigilSTJlKeMiYiI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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVns41eka3SMmOWhrkBokTCRTSkUOLRq3KDXZ2y3HSG45hSTjFqaGqWFm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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns0lekXVjIphAnTj2ai0JURh2SqBxOTUEqk0Kgkl8atQShk5FIxOlLI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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 101->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekbRhJZKtOmImOpmKgsZWbUrYVp0ahGWftZSpTsZafjZMZS0VCW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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VP8XpiRRqCRpISKUpRJaeKWSIltSJBRDEZIiEqKEfEuKRGRXIZTs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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVns4lGkbn/EJodJ+SCWfZFui2JQO2F8rbQexIaM2ySKUQwyWtKJILEWt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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs81GkbxlMqMVEOpehIhLbYFDsxl+TdWsfWSpZ9y1qnVFaicogIYZ0r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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 102->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lmkf5Z0aSzSmfBGSCembjFxeW006lmQ3MjKqyfJSZO1DoZBQyU5i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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k4VV0bljcyFRpUSiEqQ5IpKm7J3EBSKZJokGSqzCENKpGQKAmZhygy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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8Vekfx22hsaYhYyjTKNIqW6Q+CmmVpWwzKkZZEzF+EbKkRKGxhDCJ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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lekbxk/2aGJUfpImycGESJNMGZdihIyQOdmbQk4qRIlGWYahQ2Ub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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 103->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4ldsbPY0UdUlR3J+Q2zxwy9RgqUyVikualFmHaEDCyXjdQiSSo+hG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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk4VO0fxmUpSVpJkiQJr6wlpbqFhFa9smQrbZJsUZZkl6SorJUSQiok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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41ekbxhGZJiZxoWxtmpAp2WO41ZC10KikkiJUkiUNpoVCG2kiS4gG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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk8lfkXx40YstVPixgjIqIsTQoTPo0ka8meSsithBgjUTchRck0hixl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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 104->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8VWkfR9qzV4hQKCXRtNgaXxXVpJQZ1VQTJVtRpLJGlCVCIkuMIVne
orJkXEuhiyzXdd17rSFvnnMj41ZvQtMy7zN/nM/5nM95znOe33dd4eT1s4uU
hIRECr3+vZvtvDZ2romD6MwN72QqCdw76ibvJXYjbMFfE5VyDBa3XZo6bcPB
nGilOyEpBKLAlVLJic1Q3/dTxE9pBDMJHdUml/KxpfbRTMhJgjTzukDZ0S7k
qxfMFVoyIJ5rJpRi+lCmF1GhbMPg/Unnh++iWzFc7Zr5gO4ny5744XxoL1il
aWJxDINi95kdK7aWQL5Jv/3iKYJV//z0t8ObQRy8YhXq3McgKjV5mZyoAfk3
O4OkQgl0ytdGTto3YaZ028nw6wR+Nx9beSztxD93fL+Ecug8T76bWq/MQfk/
k0WuJwh8uT/rrfmrGuoHNbQNThNw9pE/Uxdy4O6Xatf4gKD0bv+xz7rdyFnG
rvaUZDBzPGRMNLcVHt6M9dsbdN7Bm2FOS3rgkXy5Q9+UQbhrmdlwARtmNlH8
onCCc4vVFIP2N2Aq87dMco3gaL3Qta24Hv+tKhl9eZlg1Eawh3f3GdRsOiTE
ngS/Z9uv5/ZwkWAYEbm3gUDFL+lGvUMBrCtCJ15TPC0em6ur6neBd9hBo2wB
A9sXM4eWKXZBQ+1EWrsyA4l9NoXaowF45D9kbe5I8Zcty3JL78SkT7bx7iYC
Z1H+pbiiu0hIWucRQue/eP+t+o1tJbhusadP24XAct52vxuWddBSlGYEFwn6
fVlqisr9kM8wuescy0BKeaO/gTQbQ/JukuxAgt3utqyn7D7Eig/cz/WifK08
+TPnSxNCOOUrRun79C8RstduVMNhs+XcvLMEK1fxj2ud7MP0y5Fg298YcLSy
9JezG/Gs6PJSVgyBVuRlJdVRFubvdDjYeYYgVDt+vIibgcRnRlnv6Tyhdl2J
7Ak/CHc17TOjz8ON2lw3nzZkFAcc+yWS4NfEpC5pHhcpjUN792YT9Pb+unpr
kwBT+30eDEwRnFiTf2hjYSnea7NFa+m8i/JLVKMZFlTCPSJzPQjC1FJLvBd3
w9mk8na3OYPYD7LfjacFCNNLVxp4S7Chu+lOxAIe7M1mCt5XUfyey1j59Oei
b/vK3PWUn1XLP444pjbh62GWWxbl+6z8GTVHyyd4HL4lq9CNwHVdfW+9+gBm
u3wix/9kIH/f0r/gUTt2erTlb4qn+lQdW3lQswF5hiPvGyn+Ja+bon9p5aMo
fH7JxUmCGq/lMV23nuHIE753jjfB6Y9RHjoX+eDm2Df2DBLwXhndCnMth95X
zu9e9H9+JvxYcZAAJZGDqlIjBBJtSa/rO5+Dpxlj/YLqr26NXoBlWwtECjFn
fan/fHXlXsa9HkTMG6tv23RFkPrbvqQotw/joc2pRT4MEsyE8QH+XZgy7qy9
SvW2ZWiDV1VoF0KkHW65KDGwFw8Ja7S7IY7MtNJXYOBcYLF5cZUAw2frzW4S
gs/8xCF33YcQbf04LUn9rMLT5X0NbsGuDiJ5L5PgwHLlU84fBTA9JlzXR/2W
UzF+9bYBD+IVSTEp5QR/XMutzjRuBskQpJuGEfg7IG9yZy0+7OjxG7hE0BYa
pHmsrR6r8oKrtgXRPDhjbu6jxMXeQAer+jyCgQNODy2qOrHrS9QmrpAgO2cr
J2YtBxKc76X1yQRSeeK4yrp69E4fWNsWQPVzO1j5ykIBPqk+eFTWSWDEEej0
RftDKkLK6F/9FctZrH0n04TrNhmj3Vepnnq8vPNnv8DkYevYWyFUjxZ/Cgu5
tTjp5mbYS/kcltZY5K16C1OjAZrB9PtI45lPS0x7kRs2Pd6kwiBtV2JrXkkF
1N3MWZcof3LGv+rXJghwWEO1JIXyn6AlqdZxiodwcVbb/scEtk/n6WUd6sQf
tofiRb0EZ77aOnf/PYgWqVlnNmuJMDTeMawV2wcTe5sBd1kGmzj3DTZHdyBv
Q1XeYC3FP2Fs+oKwESojE+8y6PmKdT+uZyweQs6+KDnXiUDPxfjh5hddsDUx
9sjRYXBx7ENjbEAH5HTaJHUqqL9X6BUrvh5AinrL2w8FDOomdHk+4zX4fjpu
8Bz1u5Ymyz25oRm2j/ua7lF96bz6oFh0uhPnStylLwgItq9zk3eU6kU8WT8u
PYcBv0HEf1jeAJ2rw+InVJ85DqX9CtE9mNzumGtwgMGhqrvynoIebJQRbqmx
YBCoqRGXkPICrkHx2UuoHhYZhNz+T347UlpuLpDOItg6XsZa7cGG0X9nfbMN
JrjiNJY60cJFc6XfGys6v8Ru/wdhhSFQPFPWb0n5SNBxbVshJ0SixeT7+d8I
WGHeHiZyXUgfeb141gxdf8Sm2lmhFvyE2dHcCwTXGxRW59rfh0VNw2cW9T8v
KERjQpKN8OJSFQuaf4pVnt1hm5uhEJa1hH+bQHiE6bB+ykNRpL90DO0X71aW
wtjBfsSouJxzcqT4Khnvf/6Ug+3l8vaXKb4n5lRoJIuqMDUl2ZJL+6Emzvx0
UTobS+eQKMMImj/BpWbHR/iYy3KXt3xDcOnHisrwr51w+vHKB/MO6ifH2DWe
tXw42e36X+Rn2ge+R/aTbU8walBrZ+xK89vS++3xPe2YVJLp/JH6Y8LObnDC
7hW6z2sfUqX+Zz0KsFD+vRLVVWm8szQfb3zVbpsn/wq5gZljZ6VESApLF4SM
lqNuUGeVF91Pa8fTgYrpDJRqC8Xzab+YvLkQMlXAR77p89F1E7Rfd0stfuJS
AJPLEVOnKF7Nyt0VC/WrEd2+iJ1E9SL/bW/LqCMf2eer0gppXxe/zDgYGlQA
kWHSp1a6PvraD4nzhoYw69O9+DsfGRhttPM8+oiL+RObTP3KaH+OC5ST+gfx
tirl05dkBkc7zp/XkX2JrlaOYWUq7e/D78aupxWi5ptvajbV9xb+sUVTG5vh
O2BoEB1H82X1tj2T84Vod03TVKd5Wmw/x67aMQVZy6O+P6P6IG7egztkOtF1
9ISQw6bnt+r2/itQAL5RVDyni8AzkisOFgigpHCOZ9xPsGDpMu/+7y1Y2DK7
XuYWwf8Bwx/VEg==
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k8VG8bRopWoiT0t6dIJKSFSyVLhPaoLCnKVkqWaCEtpCJLioSiUUJI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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81dkbxy0tarSZSTF+0oyQijRJ+uFDGVosl2wZSxlutlAMohGhLI0t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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs8lOkbxiW7iCQ0pFml2EypUDJUrqiYnIqUQ1qnRqKPdFDRwVS7sULK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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 105->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4lGkbV1oUq9E6RVm1KtvJMau0/WwOlVSUnGuQdehDvrKZxm5o02VV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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k8lG0XpqJSCqkkRWRrkQpJuChbqUgKhextRJKlJNkqSZYWSpIkZKdk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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs01Vkfxg+hYlBuU25hXI5YJZWRNA9K46W8iKIhUiTVITJpUokkl1Ah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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk41ekbxs9EJpUspcTJMmXfI1M0vxuZQiQ72c4YhiyFVEQlKZGlXR1N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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 106->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekbPpTGHl0mS2SZQqWYUlTq1qqFxq9pI2UJ0UK2GMooEiKSPak0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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VG8bxu1FylIkbUqkEhItli6VLGkVpcVOJEoqqZCUKVGEbMmWbD/J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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk81dkfxvVDpZH8JO7NWJqyZAxGi608NSGTspRukq7KvmQJZU8yQ1Iq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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns8VOkfx62Eipp6WZcoly6bGmKTyuKji01SqNC6hErRSsomEevShbXu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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 107->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lfkex4/INdFQGZqKNpdJsqQaxHyoSMM9GdMioewyFcKZaCE3kcgy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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3cgVQ0bR3rTJJWRlFHeiJKIJD+VMlIRskd2spJKimwio0JLIiorWUVG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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41Vsbla5Kuq4MxVcfB6UydTSQ0Lq6kjRIZShjZkVKknR0JVNIGcul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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk81Okfl1BshEIiV6ImlQ5XS2/kSpTYcqyWIkabzNboUqGlVFasW2R+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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 108->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkfNlKZmEKNfFI0pWUMxUcLcjeVMmUby9j6KmuSOeo4mYoKQ+RL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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VP8XximhshQJkSiVCmlXqQeR8k1KJPuSkCVClpJEtkrJUgolJCkh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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk4ldsbPY3kRsoJuVxjhGtW5GIZSoYk0kXKVCpEqBBFoek2ITJFwtVN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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk4VfkfxzGFjEJuuGVN0UJiVCZ+vU0lITLIT5JsZR8q+3KTmVJZQkY1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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 109->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8ldkb10JKSSZjnUiFTGVJTanp21hSKUkaLX6F7m1UGltJETeMNMoV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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VI/3loQ2EWmTpaylDZVKvdqkEIoUwoeypIVQWZIs0UKSIqGS7Mq+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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41NsbV6Gb3EgLkaUokgp1pZIP2iSUba5Euoq0ocjNaFEJIUshhUKy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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4lekbxynJXsQoUbZRtMiuwhcpmUzFzEi2pESW4SeVokZCJ0ukmkZJ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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 110->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4VekXVko0EinpSqX50WSSMCblTRoplw6DJJUSSRlq5LjLIAYJYXIJ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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VI0bxSetlpAKFZUSJWvkVakjyVJeS6RIIq2irJGIlCQllZBUSFEk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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81PkfxxXVEiUdRqstkbVNi027qVUvyWod9etiO1wRyVmOlHVOGleE
SouWyZWVXCu50jhiHGXG5BjHGDOfkS1hK0lJ+/398X18H58/vt/v+3i+n++v
hpPPYZeFMjIyKdT1/7vtw2cBd9824VhLRnuEC8Fc7Py9t8wu7A1nMaKqJejQ
KorV8S2Ggop1kOlGgr7FXosOynLRNusW6rSI4INWpUnc3S6otjN5qQwJ7COv
BQx6lUK73DDm6GkCx16GDI1ThjAb98t9/gQ5vIHp1Y+7oFyUaiGYlsCWdfgf
d6V6qD8c2fWrH4FWA/ft0NUmvFRctOaEBkGPVM3dsV6AiOxM1Rn7EXS1dzJW
dPBhP5qhqqRNsPvxgZ0nL/bAMen4JcGAGINR9feULnYif+F03WYlKX6okncu
seaho6JX98VZgs/7Nm6/EtyK1F6r/fHFEjBM7kyrruhGG9s/yewCQXigj2g6
ohW6saJwpyqC9/xD42qrh/Aq4amRYu0wKqqCvQ3+aAO/8JCV62opTKyzshOX
94E2WkYztJTgRO7nj0F5bai+tincfiGByUu7Ed3SHtx1d+AX3RdDMS6qdGzq
CSycj/QzBATsNFb0k9/jcZVm3Jh/kjov/9Tu9JaDNznsTTtXUvVjRHsou9Si
pnRqvNaEwNbUoF/Xuxc7vPhfHM9LIHPn3vASTwFiazatH7USQXnXBL94ogy7
TwdargoiKDEMS/R73oQao7j5ICcC44JC+5eR8cifaOYesSfg6uheXtrARp65
eL1kUoIAB+fwTgM+VIruPwlMEcPXwvNA3WUB2l8r5xlfkmJNQX5FsVITVGlx
+Z3ZBF0213gTWl14EJOTM7pfivLDKckpnCd4r63x7Mohgo990XpxaiVA9eZM
RQcCs5COtV4GfbDx7hCxKsQYGwyp9a3sQ0Ss6XX6GQm0nH/77rd6DtaMi0Kt
qH6xJ1KOpi7lYG7/uLCX4i/v59DS7/x7EDRc1M7PEqNvzeNKnkcfItVTLa4X
SBCsOsuU/NCK9oKoB9f7CZgqzx1n/uXig1HjjusGBEGPrDOD3vFxzHnxN3Vq
BKLcQMaFjy7Q3hiv6ULFx/xw4MwpjS4oePE8KsvFENH7Pa3kSrBFfoGtPMVz
Yl2OWYhfBVa+0JRRd6fOxzImu+m1+HyctsDbkmCn4Ol8ZFU3Ft+2cZZhiDE9
u+z6u1vFiBYqbfl5J8GLIxU4ltCChHmF1iRXCeY7ROuGmgqR3J0y5WlOsIxG
LGpsnuPOM8tXmZul2NC89/rk3mewcvNJyF9FwNmtmn7LoQbvjWnHA4OpfkZ9
ITc14kCYl6pyTxBEWQxO7F/Qg/KtD/5gx41AP+/iVZX0cuhk/p7kbkFwtvd0
P7OqBfEZ5xcfkCXQf5LsfvloKlyLGpLeUM+HmHXd7rHpRM5No7eC5RIYGjo1
/x1Rh7V+u96WyRGMxSBaEvIEyeEBv9LVpHD81i57W+Rd+KyquKV6kGD4X876
j0MCOJ03H91GzeuU7hHlak4NCiJyYtYVUvOVLbIUuvnjaLHvkkdUvcNNZ+SW
FLvBNdyL/p7icXVDv6Lb/h4IU6b+aosgWBRwi33BsQ7cPfpF4yAQDv8W4NbU
gWWh0yx/b4LgpXLmeu4cHH6W+uIiVa9vQu7ZTq5/gK8XRm+h21C+WbfkW+9y
DhKcRfWqtwnUN70cu/FvE8hPfr6Ba6l4++RYrgM9yHI7wWDaiOF43MfOeq4Z
+rwb3iepfhhyVXQv6NWhRKVNY62QgBZZFftOXAVWj0LXw+UUP7ULwrSic3BJ
ZO7/gMrnQ2udzZodPLyKKLgSTOWjEW39KuasACm8VXss60fQVO5nyNvAxjmd
WyfTTlH97tWcaekWQH9D4p9esxKwf45LV2LdQeMFCzGb8oFt89a0yfAszL6m
n8m1Jdj8wbsqmD0Ik9ycG3RdMT6Zs6Pn9XswHCAKoA9KMLbcatnWmD5kKhcE
DFSM4tCM2ssKDx64Cj5VY99JofNjRNgj4wF4NV9c2vzjCEyDHH6/UdaFanXV
507aUpSk8xM7557C8ISv/w6KL3bVoZuPq6vhSvrtlK9S/v/77iPb1w3wzd3Q
cDGJ4rFVVvWHuAb0n8wW1uhLcfBcYKarUSP2+X/zUPg1ASv03p/rJkvAtG/W
X+tB+SaVld34iYPa0Hu7PzdRfrf7XzdtSQOYtue+bjUlkBxKK99JqwCXxvjC
p3gffXPbzzOxEgmJhbdUqPftcxV7X0kYwLYl3Lb+zcOo+yP9+5SsbihmrTNb
Lx6BenrE/W5NAXQKQw7Y7JHAyvNKerOgE6em114qpEshN7liel9XI85NM3fP
7ZNCtLJ6dXYBD7OHN7xY6CHFDVrGL7qe/fieEXW/OXEE3O/95LePdkI9dka0
z0QCtyqDh/5z9WBeM/pRMY7al6LPG1fr12KhVbxTEuWTItHxYpYVFw7juxwy
qPg1dtG3p61rxJHDrx7PUvMzZeeoZvMpH0HG3kpObgQdHOkxzeFBpJwrkn1t
PIzKBUpp28VXwEqpsfWjeIqUS+vI+aUei346n3w2geI56dmqzk2N6DM7+Wio
UQJj39omvm0vho16Na3cJKhTMLQsUuNi9J0gt7SNqvfxOHppWBdSVgrFbA8x
8lzkR2de8yCuOrMqnsrnzj/dLQ+qW6HT+46vzJWgp1lWU0+9D3+lbzRtsZFC
PyyBpc27CyMFt+lGan+XVNOcIym/y/MMiIBJIDPqsXU5zxURswZ+lRTvprv7
dVf4tsGxOmyl801qP00IYtOFQ/hLHLrMTlYIe7UtvLzuFghU9IZk5gjGudHn
TxsO4enipzVTYUKQhvza1IYy7Ay3WXqQ8itndEOy+Vd1GPA4c1lKfd8/zM9s
wqId2q+c12+KInCxTpPfs+M5sv0qP5/5SgJWRdsbNZKP+wHnbBdQ/xMKUfZb
6j24iEnXqwvpINg6r7gn3qkbWWJmQ7SLFG6/XC3U2tuIHOcj5Fctgvzx0OKo
7VzolQjpDD7BAf/RhL6QbjiZhQqskin/6cswbpd341qHrN37lxKIHq0RbXbK
QGHp9v4Saj9s8ykVOvDLQE45j4XRCf4DTjfM+Q==
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs4lOkbtghJOYQUOYaylXGW0k2hw9JhqJzXKSNJq2yr3XLoaAulItU4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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 111->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8Vfkbx41kfiGVsVVGUrYsyWiU5MO0yzqV+EUkyTJqcBlESI3QwpSy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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VP0bxgctlIq0L7ZSkrzK+kbdKhUSQipE2SL1RiXakKxFqciaPVRC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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lekbxo9GZZgsZadBQpYMUlTqohOyjGiQqZREMUqWMSGVKYVEtNgK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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs41FkYxyexW7sUFSEklya3pMVWbN9BuZQ2KSW5VS6RikQUpZJQwobc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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 112->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns4Vdkfxk+liDIkpX6UGkp0IZdxa95UiImkGCEOudUclzAq01ANxZDL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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3kglGsbxhGKJFsiWyglS45KiC7kSKJEluy0SRSlhRCRSElIIkRyVCJO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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lekbxqVJ2YaEUIOErC22sdVlyxINaUGEbENCDFIzhFHRlGgmSray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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81GsbxrXzWk8rU0lRpEKlSLgsdXRQ4W3hKFmG9yRpIkvSCYcOSatQ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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 113->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lWkbPqMyQ4oihJAkIyR9WrRcMibztUxFTaZtrJEtS5xOprRQmCHF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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VG0bxyWJED0kUU8qS4uylUL5SbIUhVR2JUUhkopSIbImSngqylaK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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk41Wkbxy0NmkRmWmbEZAuFNjSU+hodb40UWcfaIYoUMkjJKJQlxSBk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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81dkfxnWT22DMjQgtlmIMNyE1GHlkKssgFc1kS5StUFK2Bi22RlNN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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 114->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8ldkbv5hp5YesKUvLDMlMNI1pkr6aKJUKU300UhGSELJPTGghEpIl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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VO8fxaXFVhIqZakoUpJKSHSElq+INkmyJVuRJSktVFKJEi0oS4kk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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41dkfxynZ0iJbhn4Yki1NygxFb5VuxhSRZFBJdoUJlZrKWErmWkIT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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns81GkbxhVaFVLYrSWlty0d1mEdkp1col5EpaJ1bqYt6bCVIltRJBqH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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 115->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4ldkflwapDBLppkJpkTBMqUk+FYmUGCYJyTomoiYhiSwxirrST0WW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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHc4lf8bNiqUilBmJfGzUlZUdEslKhoykiKFhkpSSGRntZRISSSbZMvM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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81VkfliZpGlvDULaWISRkCSmPLUnIuHbC2CpERQpNQxmi3izJFka2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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk8lVkDvmGkopHK+EqLcfmIYrhE5T5otWRUJutoEmMtsmSJEioJWcIo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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 116->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk81VkflkHEi4wmRZEtyyivvGnjESpTRlKKxk4ThmxZymRJltcIUVkS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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHk8VF8fRshPVEobKtqTLSFtHpSizZIWFZEliVRKkyRLWQsVUUqipJA9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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81Vkf1mCYxEhIGFKWmBYpCuVBMYWGUChxVa+MKZq00ExSZCtLKbRY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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk4lVsbxhGiU6aIEEJInBKJkjtzKYpCIvNQfUdppDLzkYNCpjpUIlNs
GUJF2Bm3aZNhm3nf9+Qk4ipJ56jzvd8f61p/rGutdd/P89y/rR4Xbb15uLi4
0uj1/71JPiTleSMLVJbH9w1/EihdlySmfaICTD/xOGNvCh7OMdNH7VsQeFJf
uVSDAtvIqTcnpxmzfE5pb11JKP8GZ55vg/iSnSdYF0uAJ7ty3qGSiXEXZkOj
DYW/xFIMVWMz0JD4r1K+EwW7HeuPCqxtQqV7nIhVGYVV2x+McO4OWLauHalf
T2L57JVvTX/3Qls9rttZmEKxYWrqZcFOMMnUfB4rEskNwWyuM30w1a+flPac
RlTnmTQBoy5cXeLu2r1MQM435riwTyP8J/NlzJpJMAU0V16J1iMt5la5iQqF
x1lys6msfBSbldr4alPg2rW4cbHgBghXxcMrLvR5st7F7DEOVgNNqO21U5iz
erSX8MuGBvOvkjY3CrYXZ4a3HufAf3iTSvJ+Emdkhr6Hh7xDZmpEYHv6NB57
Lz4ILC1B0C7ireRVWv/ZmI8VRiO4nX7uUPVuEiFZaTe+szrR9rTIylyCwqVO
nfwPA80QGHdU3PSFxON+oT/OD/TChKtWUuwfAhLB4xui1XtgzUhca5tOQfSw
45G6sRIIbPusNeZM4fafBdAPqcLvWfaLHEMKxp/KWAZ6vWgUYrjHFhIQG1FT
rPzRgoZaZkeBJ4VXj7bMRaYMg/rR58hsmcKdXkaSZNYkoo6IMh+JTYIj2XqA
4TwEAz6tcCtLElJx+kOepjnYem07M8GOQsXEd/MC7reYDTZ9FWBF+6sua8sN
HYS4ZOyi5QyJlQ3r0y1rKkEwUi9JKFLIGfQb0ZhkI57fI01qOz0Pn3/Kc1Gd
KOF4Be4dJLCqTbpvmi9HWkjMggztR2rz0rTGrkFEfU3gtQun+3Mi+GHY3A1k
jMtvs3SlECTW7fGArgfBT4j+OkBC9muLsEDAS6zm2mtq0vXUiPisFWJSAevG
1M5BAwqWdtviDfiHMDJ9MdLv3jRqNaIfLuQ0IcMw1iyMm8LiEYMvLtdZqD35
prv2BwH1u99ucr1gI1Lbv87iGQn2aZ0XqqFsSDkuH9qzh4SXWWR5tw4LEsVO
goPnCAQq1JvMc7oR7PD39GUBEhG6LYb7SgYRxhFy8iGmcGC274rM9gFUxb8x
qaP76X+Edb2mqxUn0kJneY5SmDYZbhNlDCOC88eNnbT+mcY91pO2vdhkrag0
w0v//0Nl32jHKELaGQ3rByYhULFFvz2Ohef5NhsD6DxIbTn/LW28BVM9h2IT
50kM62o9ZO7j4GTIrLPmdhL8SZm+8d4jiHcMIV5ITUNa7UarXfFzjDUFFxRa
0v6Hq21Mi2i9rgfejN6eQlhNoqhOYx1EfBXSgz+RMPVvZe0634spmd/Gfh4m
sC7wQo9BPgeaTdr3/yM9BX8T5ZniHV24JX5Fmt1CQlw2esfCmX64vAvUZGwl
cOHtwbBTnUws3/OP1wwlUZnV0uOS2IsgtUmhwRckWEGSl2SZ/SgWLliVm5zC
xvLdpdzzvWB8dLZJ7SJx00so8JeQLhTk8NnHsSmI7O9/HHmpDNIu1eF+FhT8
r/nVtWQWwfRWmNA6mldux+xy77CHcXDenU9i7xR+bvn5oLu6F0P78vk0VUl8
bW7pU61pRVh0eeIGOp8GPLlmhvJ9YCwd26ckRGKzvLFtcugAeLMSrfs2kzDP
G3gSvfUVlNr2zHXT79e8qpU1W23DKffAA0GLNP+CXi1IfuhF/Da53yNpHtZE
+EbzpI6gqGtJi1d9Eo+NAi4qHH+JXR+cBSW+kQhXb33y/kQnfhO1MJ0Oo5Dh
Nn2YeaEMdwQ/3VY6T0FA4MTYZHMZ+KyeZZZ40f74+RwWsnqx4CC6sNuLRJNo
kWJ23jt42AQtuvaQcIv+Rb0/Ohk9Ij5RP2l+KXttP+ed3w2ZuGVZF2kS12cj
ro1Hc5BiYurqxksgiO1zcKPmKC5pDc/evUz/93RltN6+Dq9fr/hPLZEQaeBT
eMJOgS5rs1HsGQqcL9UTvtosVBEJJanvCRzXSXrz/mYNRJ4O2yQJURDjzrSs
GHyL5/9mrpfpIKHndEOOnduAqr6fVmvHSGyi9AJ2Gg0iNiHknnDSFCZ67jA7
3LsxVy/tb75CYM3oGj6dvFGsvlE4b0HzdP2MopeqcguiVFW4zOl5Sg/TMzt1
qxwqw0qNxH4KRaX3XSOutqPQh1vI8CyJQOHASHHRCigerapUofMu4n51vvB+
LowH/HZPu1M4I/g940FUP9qzJPLM1UlsyHr6TW6RBR+3cuXiYAouDk/Ocgm+
A7dngSf/lSlY9j07Fs3bBF6tz/mMPLrfMRWv63OqcPz1FgmDaApLIS8uf8zo
xqM/r6+skSXR5tlc0uDXgQRT/b3VASRWr0R+tFszgA8md9Vm9tJ58ElT2Xi3
H5dbbQM2kbSeLIlPukb9eOhzcK7xIwU1nnB9dusQrvO5KJSfI5F5smXFdYiN
94Vh6UcdCZwy7vjg87IPs25JD1eqCUz9e1nfqTYFBaPZFi8dKTwpvicelToM
Rm3ec6OySXj5FCkJy3OgqHc88eWvExBYIvUdT7+BIrlcc+0vEi5PRU4EhLGh
U/DH7J7QacSLz9nPFJbhrkj7WnhQEJJ/XxZ9aghLDzT1vHQItH1285hobYa/
kbHtzjoSP5NmbpZ792CdxvzkXmU6v2kWR5IfMuEz8WmdAz0vKVL+vf9l90NM
5p+DYgfo+uzQNhp6wIbFMe5BhhoJ6+8tI4cYbfg9WSxLx5jOa7aUWfxOFiYe
6+i2H6J5F7u6P0NoGAr6lR3CW+h5rYnTkx1ug5iyrndCLImghcD7MdFD4NHR
rdM3JLDfQcTbtmEIp1sr/lE1oO/ra2VNfHmBgGe8mXfFKIRufX7PtuIdEnSV
1a6MkJj72qbCfZuFR4Ps+8Q0SfPrumdYzFMwrkbYn6bz0118qW18Iwe+Kxdk
itMJcNprdfbtKERxTp/t/XMUErMCOaXmJdic8a62geanaW4pP/vHEA6nhJSx
mqfALtsgLOdRjJTltVVnrSn8D06irt0=
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 117->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8lWkbx7UNRaihlxZLCwZRyCDjJ2WpV8uIKW8NJXuaSIiIJEvWImNI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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2kglGsbJi2kok0l2aKkcmSrLF0SpY5IWdJGkmRLJ0XlSBRZI2tZE5Il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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8Vukbxl9C00oh1UQmQ4Ux1VCJXGQtihQpeyGTkX0ptNgiJRoVBjGa
oTBkXyLLG7K+tl6vsb7nsYRf4SdLY5kzf5zP+eM8n/Pc93Vd3+d+vrvsYmzP
y2AwntLPf2/G1XbN1dFAqIlNSk/YEkytrakr7a7DI7vi8gAmBd5rG+ajf2aj
OuCFRHEuhW5et21nypkwu/t1l00Mwc1h0/1rurpxoUTk5KexIRg27H1gldsH
y93sX0eyB9H0ban2ZUEWjLeXhPu4EBz41qYQTBbc2NNCciUEppwLEjO7u+HN
5muRLuXiUkfnn+vM4qFgeCpjvxUBa1modvv2aojwvpsMYFNIN70yK29SA7az
l9HSmWHIlkaGHKvvxfo4pRmdUwSKMWbuz9QL0JrqaX9YjoBRY3TO+VA4+PSu
OybZEMhskzVjf89GqPSJn/oTKKwMdFV7x3WieEfD7ew1BH4S0m+EE3rwo2OU
4ewwF66JMw9KHhQiqlq1ISeaoNj0u3fZ51vwMiei6J/zFMYTsvij8vvAefxD
hJEzvd+tx2tVnXIh8tv4Wo43wcUbusHaYix809+VZtDORVT6iqqlWCc+flqO
fadFkFkdmyu3pRVTfzZfXBAlGNty9ufojW9hV7FLJjKd4NPKr3WDa9k41PrX
JtuHI6ifUBjQ42/E+6HM1XqVYeSV/sDjFMTG/xXdE9arUVCfG3q1HB2FHbsE
A2Is6f8NZu4R7GJD/EJq2xUdLqaCbjFWZtLAPDfLsThPsH2nWIOUeAMi85wW
VpIpnF3V1nh+uhGOj1KOB+8kSBY95bW2ugv2sZbjpbpc9A+4+HjNtcFA06XA
7W+CGFH1slD+Dtybe36M78gw/h4vbOXv6YXuP/4/p57sh1Aax5mk9GCIlRw9
DIIoKf9PTy9XYtx766hJHIFW8x2vNt5GGDk7DCflEiSuDw7lSPZAseV12vTh
QRBfiZmdN9qhLiZ2TekagaTPufC8oWQwqq7L+dH1Myb7nvqpnkGCdvyojDVB
y2rr1zLvalQIN3t2bqL7j2JIOnwsQ0z1MqfHj2DfPd/NkWaVmFFOlq6i8/h1
t9bq2ZYmqKff3UflU/BSCqm/FsHGATcPHg0pLh6OizWH17cjbloorFyGC9uu
8aGtxk3ozusqktpGwUpNv1VYlIXufdoyxmp0fwHyXo848VivJCsse4lAaMeD
P32oHIzbVr6JdSNoV7Z2CYnswMPlRdfRCxSOiop69dzrQb1OwK1kCwKDracj
xFnlcJI2dLc0JxC8UbAx+ko7flxxa1aN4kKo4p6/7vss7Hmy5DmrT1DZ4vv1
f+pJOOopbFlP+12/L+XIBoUcCPH5ZDXT+uTrF7NiXjERd1V4YYbOk7yL7S0h
RjvcuppUWkYoGC1+Ou4kUoJ0Mc+ZTfR6UQ+G1HJCLxRlDf0zrw9i+8rx1HMC
/Wj4zYSPO0Hz/3L09S/vGmG+d29ITzaB/8Sj8qi9b/F1cbEryYnA15zZq3ji
JQTq7qgGGdN+8L3Yz89i45tk3fTAQTqf67kcVXYasgu1l2ppvid1C0RK1f6G
AKNUc2KSglqnP8eH6kRzhnHJH6nDsH/YMNYnmw/+AtVlMzMCD85ulwUVDrxf
pXxpovUvDt/7OlSyFqxAo6DpzxRsTgoM359Oxh77+nnx63Q+lG3WmZdnYN+N
S/Y92nTer7ZI1hixIFuSs2aW5s/gZkavx+cmzJm5MpmjBIdiPlRt9GFBwSci
3TuLgr8fz+RgMBNq2yJ1VscIIvduNLynXYDnuk511rT+x+JXdGzKmLhcru0/
Fkug7rOvIfAICxqmJxDXQqF34InI2ts1sEuvkM/yIHjiI7hNT70SY+FNk87z
FCSkOw6GPq2BRtwH2Xha/4/zwaF9VW2IT9ObteGnwGCu83kc8xfsZldDg64S
DIYK1ICvBfGxY2NT6RT2ZEefOxDYA16VzywbVQp6t1o+9y7WgLefp90kisA7
4NqxP2zrkHg0P+wo3Q9Lg/+7v8hrKP7e8+w0rSdRtfa0Pt8JLjvBO1qCgm9T
6me7qHKkK8lY8OkRfDjBd3H8PAePTLKipTVHICT/JtLOoRqZYUt+WvYEnqzu
mckRDroFSmyk9SlIzcptPFDYBmfSXXbIkQtF8wNFX9Pa4XFh9OWzVAqk4Hb7
kbl6yG2JcDtuRFAxf+qxUmAntrz2qNhUw4XkCwvfOKU8WPE1hPufJsg5tnm/
gnEO1NzKIwXcaT+PdAaE2Rfg/Y0o+cx1BN9/uX/a/Fkb7pqUKXs9GYajolAK
+20NpOrCFpYKCcJq2pJ/epOP/EKDEG8DgtpE3+mDOzj4ZaNfM4wHscDonpem
z+f6rb4myvcpdAoLyk11tyLtHy3rvMxhBCepmH851Ihoo57A7ACaN+cTuz0U
c9EfKP54jQPBwozXtPrFIjg5dIpM0fXqZCsvdrzpwsfDNrNitQSuPAYStyw7
8ZKHaSTlPoRi98TVna9eI3ZJ3NiJ5tvGYSFq5GQmWuVco61pfvjWffGQF+tF
8eCOBMlGun7n3KqwOxX4ncXKMH3yX56vDOz2LMfHY8Ln5vtp/hKzIoucm+E6
Uql3sIiC54jw3E33Fqh4PNjm8oqeV2538vYE1aOUrWO6uYug39Wk98jdd/A+
vKrsFULzsubX+Wf6KZjzysqsO0tQ2nGmvLKkC+4yaVNVA0OQtRAX9LPsgVRs
hvOYwyC0UhKtOoK60VjNKek9OILKnPPLjcM9eKDmoq0vzoWOgL9WVfp7cMXF
2HN/UHjTrJb8NvoDGJfiT9T6U8j0u8grVdcAY8rYYjmQ1s/bJITr0ow8G4as
JT0f7ujtMWReYkMlb8NDozq6PkXqlzqNTnzPk6J6OYng6Ced2Yw7+XB0lP6i
eZ/236pxk4xOJQ6s1xawvk374z+h+a13Ivqs5N3jTAkizHdVz1qwEHr8pKaC
P/090Fhc1bQGL5orBnme0bwW2G1ejmPihycaQ7UK9LwbMGel6RcheYXcPBxM
5y/JdrFvSxoq4lYnKunzRKuo76WUGX0fMk1a2jQ+DKPnJRs2+5XhXtJ+vrYg
giZ+N4ddM42Y/2CfLEnn418vMcJu
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lekbxsuYkagwpBgcNenIlpRSwyVLmSylqTQSEcJEp6iU7VimJNSg
k2mnxRLZIg5x5Njp2I85x/q+L5WRJIZmqN/7++P5PH88230/9/e+Lk2PU/u9
JBYtWsShx//nyeL0GpPIYtSfDLxZbE4hVkvJNCpJjItWjCah0zCsxnZXJ6Q2
Iyad0a0gR2L6XSH7JqcVMqFFLnPxJFKjlnVFFDSiLnCY4/eAQOng/TEim4eb
KTmLecspHDPyn+mdrUZXissTzWASTWqX076e6kK13WZ2oTuJ7mvfri+3a0P8
DwFxsT4k2FHRZhYeQgx0e1nPnyPQMO9YXXO1Ck9+bCnIU6BgZXCw8L1BA4ZT
Lf/8s4dEQytpHzsthAL/UOBJ52HEJdlHbDdpw3i2olpgJIFjK1S3frZ+BYUV
L4r2kCTGcnV7RGNiLH3zj/rW5STmbhaWMJvFkJhO/Oe9vBhnLNpsXxgKQYyd
eZybP4zCGzDMT+3A5N7Yp5HbKKz8eCn0tYoIVg+4++UTh8D5LWeGN9sL/yWf
5CZ3DGNiteJS/1QRpiUsEiPo/fGf+/8O+NQOzxZtoXIHAVNucnSWVh/8cqOz
RK4U7oh/Kp65VwqLDevDHthReCszpevmngGmfJZl4QkKSSqatQPPBtD8tf32
yzgxUn8QVAqSmxDqZ1EmXkUiQkFNKzVVjC3lIc8DmkgYZ5TPp9X1gbrQHio5
N4DuQO/3I8n9SGOW5Y3pEeC0HnmtrMPHIzfRhEUihSU8rqhfvgTJL6xrtRZT
2Fj0pugjNwvBIT4IN6PQYpxnOp3bhYfPxnWTVElcEbY6btjQjQOTlidOq5PY
eDBzW/FoFuZDDEttdSmwrY4p+Ub8hQrJ4zlDXUNQ0BhjiQPa4Rp17VrCGxJt
6k3u/XqNkEpwOhdvQEG1Zi7t3MoWLNvrFXyqnoS1hmbCaEEHDt+9kWJbQuBq
bBOz1q4T6y5PNSq2kNCXdsizTWhHl6bV42pvEpKyaczk+lc4o6Tn++8T+n2G
+IZRcgZk+kwtpUCh4YMqw6+rDplhbcabZgn0GRrYrw4phv9L/RFE0fu9Foz7
6zvBPmRz3qlkGEy1hY+uXlmoK3bufOVNoTSjs8Ejkg91l/GQXjq+jjqdg7Jj
fTigkRFhPUpBpD/xG6u2AeEdCSWLb1Cw11a/feSBAK/tKteu2UJB9gxrI0+9
BlpJz/SLfqGwaGp8YoVvKbyjg4NuEXS+ZWGZGzgdSCxQd+b9MQyP9MaUaf9e
5G1rXs2h47U5LeVQ4Z6NrhbHeFn6fEXsNYEptxubjaLFa+8RuMPc5876lYfM
osbkvbvpfLAE/nvSMfc5p3zCgYIP/8C7EdkuKHvn8qfmCEQciAmSzBDhrwtB
1yW+Epid8jVkrG1GtlTgh2w9CuMaW8elRvjwYH32GnIisYrL0FzYnA/mRo7V
6vP0esRDbWXnToRWuh5MVqLAyB7tLmC0gvNu4PRcNgH28q6kkL5LMJ2p1LOi
+Y40VBn7yVsIVbek9qLcITwtnH3uWSBGZbvfWmmlIcQo/lx1ki+AcKn+ZgUW
zZNc5NndRnXouBGubFxLYuBtGbfw23ZIa1zIu6RCgmF34nl+WA5yOEojlxwp
pJja56TuqkZJSepep3wSPQ6+Bm6rezCxZNQ3IGkYz+PKqyQUBbCwOqUsT68f
vrF6I8e9BQHhhj0RxQREvOlPB+racO6zs1DxLQHJ+7f4xXwhXDouD7bYDIH9
JGn2/X66f5aJ3uyi4+Wb2HAVL7Qiu0qgb07z3l8rnv72uhCiuzpqdiyan+AU
A4vocpQwp+ezaL73RY6ejCnkwvOxn9Y6Wr9ODF6x2XG5GafzzXs9L1LIut5h
qV+TB5P69MoVRynIjQWsNz7Fg+dKu7oGaQr5vW+4SvJ8DC7fEWC+jNa/0Tbh
I+nXmLDiiqJXEvARu0yuEtaDUPJBai8JapPG+J6yXrTVvigqfELCeYnMMxvu
U7jeOy+bSfPj6fOO1+1XC9U+KuF3JgWbVdbKC/EtkKy9cucb+n9Yl3/Z6WT5
EMPrzBDqRuHBLrHvVGc7BI9F7EMXCIz8Xiq1Y7sYrz7srF9zhYBnW6Fh6bFq
/GFEntVZIJGfHLQ9po6HMVnxYCCD5iXtlm/TnyJwNk0vfFkzjP2MvJlMWg/i
FzcbNC2lwEsoS4i7GA+fHo/Qqx50fkHhVVeTO7HLyuz7WEsC5t7fdxZvTYCP
r/m1Kjqelf6Ba8y6BPC29vX8VUDiRxtn2wmWGGtLND/tm+lDhbZ78NKbDZg9
yj3qaEL7yQKZ5iqVDN5/tnJxxymYlK/yzZKvRZ+JfXzlDgqZOuGBFbnN+CLp
nuDMo/n9RODxvdvY84376fw9FDaHFHynFjwAM1uFwOMj/WA58koPRNzBvGVX
4rIjtF8yHBKj3Gl/iIvT/U+aRJCDnsH6rb146TZy2CecgnH6VKB1Qil2RXqw
rr0nETfb+nfZmb+QknbvQ+6lIUT90rhDwagdWvqsyzOldL+rCDbkOpTivlfO
y69fSfzE4Q9lVzQgNkusWkXXZxHvklbhdyJ4uSbx8PcghoyP2+sY1yA94Men
y2k9Yd8Ot44OFCBTxS/y7S4Sox1GH0c21sPc+cPO7XR92KTsH0FTtfhn0a93
QxoJpE9J1Xkf60CuzpYZ1SUkVLQbbpqa9cCFOqK77TyBmEcpE2/z2hHLex7E
tCfANx//ofHQAL6LOxP2emoIFcYtKk2723D/IC+Kc4tA7Kb1Rbk6NWDeN2VP
sun/Oasp6STTBtuKn/WvbCMRb1aV/OjfZnxSezKWqUMiUfa/3s37G6CrGj5u
QvsN84HERbWJRmwpE8YJaH2/uC44OTjmFXbHn/ZN06YwkOXYGKjdgXI9zcV6
cvT9n/eT6nUiqNZ9kRLRPATf198q59SIw1Zx/X1ZJPZuC5P4zbwNUz3zCwV2
JPxYYd090nx8CVBnyAzS/l94PCmK3YQpan3NFSUS5i5H1FheAsxreRElfBKK
tV6vXj9sw8//Ku2M2UliUv1oboSwFdMLxvqHiwiotAzZlV/thdsGDcPjvRRu
ZZQ3bOH3QSam7Ky/aAj/A1fMyYQ=
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 118->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns4VWkbxiXUUNrTVLaajyI1GecwTRO3mqIwjVNSGUKkyKlIQkrJISLn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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lG0bxlWUpChK5UtICKGyRTllqUSbhBbylp0UJZJsKRRZkiSJQrYi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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk41dkfxzEtRn6KsZYsJSRTSmOJeqtxxaQRLbZUlqxFdTOGNKGyFmUb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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVms8lGkftqwoOWRLUmnS1maoJWIrdYVWlBxCUZTD1HZEkdepaepNW7ui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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 119->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns8lOkXn4qiSEVFJGyh39qwP5XS9kXWttIil0QKKdpNdNsVlpQ2k1LE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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VO8bxodUshRJCZUklS+lRIq6kUhKStmSZG+TZEuIUlFSiZQla0hl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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk4lekbxynKqMlkVKIRMmGiJJIW36hhilQGQ5Y4JDTZkrKEJmXPTAmV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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk41WkbtiR0TTEzCGksI2vbJKJp3EiUCp/UZAktJMQhjC2MHKUwkSVb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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 120->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lXkbxr1nTMlLSaVG2ZpGKtlqJEOX9CIpISJSkihbTmIqQkIMIi3j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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHkgVH8bxSdJC1kKLYhQIZWlqMixJaVIVCp7ZOkXkTUlWpCEIlRIJZQW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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81dkbVpYkRGVIRpYWKSbbpKRHURm5QgjFGFtCKJqRqSxjmGlUKBKy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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4lWsXxk1JJ6ck0rBzhCKhsp0S6lZRppShZCjDh6hERMYM6Sjz0HDS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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 121->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk41VkYx1XUlEhZUsMQjaYZoqRum2+pSUpFRAuVXYVKskYkS0yJbJWJ
SFSyXHdkhOIiW1zXdl1r5vyEoQZlnTRn/vg9v+d9znnOed/v+znfd5X1hSN2
c0VERGLp9///6E9EdIdNJiaFnOQea4LUFylkwK8R42ePf77KEDzZLa2S4tsA
+66vByxKCP628xoqCWmFmXaVjPMCBuFK3d981/OwtvmLnSZd32kg0/bUjwPe
pn0Tig4EWknO393T5iIs/WxxtDeBlKGudsfVZgz07vm9ZoAgu8X25nrRZ5Bv
uDQ1aUUweN0wMLOoCeKXpStDPxKUOsq+1NflQz5TK9H+Od0v3PXKRrIVT6/6
xP2mxqCw92W/T3M2ODzGw8+WYF/He37TFAeLlO+4mtnT+6K0fG6YtiIr3+Wc
+xTBJbHG2a28GugEmWyqfEDQs+Od3aB2GZ4NGMTlBRM4BafGmbDLUe3tWrIo
kEDZ2uMX865X+DHipn/6WYLk/X/GPrRsxmO2X9xMK8HmsP2LP3MKUR7nu6rs
PEE0wj6WbizAoiHFXwtp7M+t6lA8xcXXv09q+roQGAV0/jxPJAcS/xTp3qX5
+oudMRaMCFBS4DntNp+BiOXaEZmcXFTXjS0WcSRYfLyr55lVJZbJpC4P8SOQ
32tZEbW6Bi0OehbrEwnirwmvFRpVQzD150l+BEHHRGrO27Js1D23yNWg5x/L
M7MS8OpR8iXAQyKLgHN2W1r8JgFmB7pivI4wqLrU27yDXYXAn7+LXRlCUHnE
ZVVWewuWuv6QkGDFIEkht8L2l2wYBmybO2tD4LIuUkxsLQ/PJ61MVevofXuz
YlLdXmKP06TXTpqv9U3TOXe3NoGJkltj9IrgzsH7EdxleWiUdXl5gq6zRErz
x0pqIDpx4KzuNbqu4H5o8VAGDv81xr9N+UsT1Wsam3kFKa9zLapOBKEp4x+4
OVS/KFlkX6J8fYk9kSLdCJeTGgbhswQX8uaolF1sgq7z+s9SfTS/p2uXXXrc
AH0x3nRxBYHOC791ivbl+Dig6218g6Bgyuan4u4GTD/MeSRgE4zXDEWcXyhE
s8OBZJY5A88VEWdSJupxW+bbwJw4gnPu0wv7jFtwsZljHP2B8uzdwLZ/nYDY
w+riM6cJInsuKF2vboP8zs2qdkcZlC09lT7YWIvO7XW1Y08ITMV9OgwqmtBj
tKP2mTSDudrGt+YU88C6am1Z/Ybgxs/qWttTubBtMguM8CXQ2CanpJnZiRj5
pGt2rQyC06+POo1XQGJ3R4hnFIFoYNHEGzkBvq54ZFXkTfvDVSmP1i9DaKGr
VII77a9xUHckh40w/f22jB3B9r/ya1bNrYd5aP/eF5kESa92XxoJeI2w6I7c
4xfpe6m4EjFzIgOsO3k2D6n+d+bbisrl5cJ3V6LJTcrPYJBKkuZwKdZqyK9+
40+w19To05zaRnypVTRRHCIQ+So+XsJwsTFRPhgBBJ7LD8qrJrbCUF2xk6PE
4L6LwRUNowqwAxUmHaIJqiX14CzehhPuLrfn/E3QUp81ccinDV8cMxr2OzEw
dHjBDdpaCn0fN5ssN/o+21w3/9TdhmvGw73l9gykTi+Rkvy3BfdaCsUU11C9
Fzfl/zD8BmzX5SzFC7S//xwOqJ1ox4N3NSNhrgzS0+Q2lKWVQy/Cj+9H+T6n
1fTE3L8Fhk8kjrhtZeAq9/7+6kXV2CBObh0NJ1B9VnHT3aYVR9d0njl2gkHm
VKLzlrZG5Njq7SwTEtRcubzDLKsSFru0DX1CqV98WjobsIMLD48MuQ76PkVn
FC+nZlZCY2aDm00QwYj/iw77fC4ea2s8lKX81Y17KKy5I8BIl2K462EGytLd
DSq8VAy1nUnaTf3P+cFgQm9wO2Zs0nke9xic6d3NHPP3gNN+uYwtlDe1uNzR
fqMabIrUdBpIJrBY7Wjm5VeHTIO7ezVprCtp1/dgQSusyqNbLX9loKe5r97v
lhCh7KyI38uofr0XeTc+x+BGu0CNQ88T+d7cc0rKDMT74bAWjbNVFurFZLVC
453cZA2LAfu3qm96nS1I3TAsH7+cQd33Y/Efg5qx9zRhVa6kfH5Qbnyt8hoa
H4ojvKn+/gU/pmmOv8C6Po5WJ+Vpk21hhg6/HcdOr+g6lMJgX07fezarGIXl
g/luztRfudbZl9NqQUZvbFlB/UIgrZBdfr4NydsN5863pPVX2OqolD/F5K2t
3YTqY3v7YtHCxgaM5vF7ansJFLI9OQqsejDzhl97vKT+bJXnlb+gEV4XbLV1
igm67m3dVJ3dhHTTJP3kCYJC5cn0975t6AiPH94iRfU4L6NgsS0SctvnxwXR
+ifNrazFp9kYNurvM6T8i2wLlv9mloFDqiYau2k9jm5/HH10sh55rKJJ53yC
D/POpdiUCRFRvkDhUQKD/Key21nG9TigUyCp+Yj613vFlL6zTRjky6X3zWWg
Jahzv3qFA7V2d5dUOh+zs75loPkPaHsrpctQfwydnp++UbINv4VykuJNGBwz
NT7v5VGAjI6VT+ado/Oj+K7aXUEUuizEbkbTfGW3SKR9PNYJF+SUD8zrQ3XQ
kd/X9fMw4SvROcCl/chp143NeIMVXv6ZI54E9/erP7w+2Ixe/TwVTV0G7blO
Mwn7+Hj+5cq3CT7dL24en/ooD7djOiLjaT5S2VL3J/bkwUKydFScxqeWvouJ
/LMGM8OBn/bEErC11Ysk37/B5CfZu1LUnyuXWOc81qxGGa+o+3ECQfjlBMO+
T3zMuglzYv/3zxB1/vKoFgjeHTzo30Pg9mRpoknVOySnWikdpP0rKbFIV17U
DsPwt0u87BisS5+Vrg5phoaOxCnhagasaOMj4W4FKGp5Wx5C50PyAfZtnrAZ
jjphGwuoHxRU8IxrSnmIYR20Vikk2Lju1/kDMwJcGxYG222m/B1mwjtd6iHz
WlXJmM5/yYI9/9r08LHho+tJYzrPTvHOeC1zqEdG/9iildS/pzPXqPUO8ZF1
3MB//B+qj6GH1fp7TXAULjF1pvyUKetddLBshMlf6rdeviXoHK2a7I8UInNg
VKh2n8F/KSrWNA==
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VH0fxtHeo5KQLKVFSXgsLRTdPEkpeyUVhShUspOEUKmUSFnSokSS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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81dkfxqWMUrZGl6FJNWok0UKaqIdLZcgu/WSJirIbUcYaFWlUV1Ky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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4lXkbxlChKfuSJYZQWoSR5dNtRFGdBmGQXTRoIkXGIDLRIktkZBtL
U9GhkuogOcTg2I5955zzvpXBR2RrMb73++N3/a7nj+e+rud+7ue+Vb2D7HwF
+Pj4Mqj3/z9H+4cCg/RhqFtb7aQpcOB02NpEnjaAK5F2UW5zHKhck0+urXiO
qi7TZSk1EjMM5ofIeTaa7Zy1LFUJJDK6i7UC2nGY73XdSWMCTilRk46LT7AW
+L7BR4PE4+trmrv4mrBU6HrXiEZC37nS845mM5qzuk8K6JD4Dy3VUiakB8b7
owXCCQ54QyEifkUsCM6rv1ndTWLTUOZWo/QO3PFOiv49lsCiSia9g14L5f7E
RsYsATMxaQ+dtD9RFrG0cdCBRG6Gj37ZqwZUB9FXFj6S8Oz8c9WvkA5B+13v
3siRCLvXfOC44gA2i0w3/qTGhef+O6U7IgZgusXgm1R5Ht4dyWpoa2eD08re
LnOfwL3ba7GiNl0IlFm6v67HQ/bEQpS9Yg/idreVPhMi8YdM0+I/xQMIYd0p
fqHPQ9/w4YD8wRGM6kckSFQQYHEPNfz31QAuredocCl8Zp5PtMSecOgEpYXq
eZKQvn13smawD6VjQ6Ea7TzwDY4eb17oQsEEzaPQnAu5b6yXHGT7wBURsGvk
cGG2WBeWYJECQ4fE/fvdKH4cvC50XmhANNvgjo08Cc3KTfNXb4wg65D+7FgC
F8zgK1HLYTmw9zo2/Z03iWTWkb3S9FH4XPwN9/4h8dpDWFPQtAcdhpKXGyII
5G9PEBOYTYNrJ2vhFIXPvLfy9ohzEXL2aRjrUP2ZW4xGosu6cGI9vdhsJw9H
a3tc40d74DmZfqnoAAnfyeaArIhhPBj2LLUaJ5HeUVwi5VkFp/Vt7u7UvGqL
n8Td+Aeg0aZ/giNIoICdKRYU2Avz89b0rS48pNT4N9HKOyGx6XtdH2qehyra
UQFx3SgTmW6NLeGBHTjlrz3+Ejuz01SLfyDRu2r2VMu7HUnBLSm+0zzYRFXZ
up1sQMluyYv5HwgoMbztpzLZUEfbR+ftJPzQUCS+tQWyDxpnn1F6fJgZuxJ6
vgt75+h8Z75wIfKvjyYteRSNOu8cab9yEeJA3xER/wpVJQFCX11JXO9YOnC5
tAf8VZGW2SIkzDsZy70e46g6/3Vq4i2JyTCDwyO111HTrVXR40HCipvp7VLK
RL2C1y1FfhJzQXMV6mm9ePWh1tnlIg/5n55le2/PhklljKkopd8Pg2VCt5v6
YHA62uanBxwE71gsz3zEws3S8UkZYQJay457JZh9sNSWXqp4xcFFpXBR31sD
ONgmepu/mIv0XYIZwYJMiHvKCowdJJHY/tfM0IsBLEf7HQxW50LFcO2W4YZU
6CSe2zTkRYLM/9e7Tb8D9sZJHafmCewOydnjPdWCbf/ZH5NHUPdV8VWNbpqA
12/ipCLcSWj1roq9P9oNHdH3FslXudCQmlEedOhBQ2x0jbA/F3yHc39aYkSj
u2n4rBa17xhtSKY0FeFvR4eAnRTf748pdHYk90PsVfTHgAIeGCL8IgaynVg1
kpkOXSDwIjV9e9jaCErC//iF3DeKW+UVq3BqxM/01KP3qf5J0qvxqu0A/PzX
3D58GUewcrZIoy4LOhsOXFLRIyHInlTSVKrD6d+r2eKvSRz6zvTMgkkbvCPC
AoucKf5O7Pwq2cHCydhLG+Io/xATFXif19MMWktgbaEECb7c4IOWQ5UwPqzE
WvyehIvKlaOzGW24fDE4cBkkOG5Rgz6Ph6GRfWku1YPA8tRInK1VP244M/Za
B3FAF5MJWVJshozJ5gi93QTOjrv5r2gN42Pc9/nKQwSKZEOWHjU1gpV7rfAh
5W/0a4eMY+rZiPHvqvwSwoPcb3QJYbEaJKbcsPzlBImp9X9+UzjTjWZ7/UT7
TAJRutHTj237kTMsLUuroPxEVH7yYUYcHAXYwg6U3jy97BXrbg4j6diKxHW7
cYS3pIRf1BnG7FNbISnKX+WGjeyOsBsxExb8aILatxxHbquL5yDofpKVCTc5
8G5Y2RA0PwDBijHXxXoedAR0Ih2yepHItjinR+WB8tTyrg0l/Th3dtfa0kku
1ELd9VhOvWh4MxFOSyUh1uT+tUbqEV4+dj9WQPkFs+Km8ojFIEQLCEYeOQ6D
LU0xzaoDGIy/ZeD4IxdJJeJld+KHYRh/xqPAi4PCT9pv735bhUVa3ru/KbzN
22kkY6ENN9ZGVX4OoPJl41vN8QAmnhcz1hVGCHR1MC1iZurRWyHaVGdOwkHs
buZnSzaMjLrkp2opfu8FJwrr1cG2mn+zvwnFT+shVgo3BVon/5bTcyahtHfG
N9mvFWUKI9ZN4SSOKq3f131Wh28Yp1XlKH20FiRxi1L6cXTdX3BzEJV3T6oe
pHWyMXHqjcO2Fh5Wp0trprRfY5IlcGtjOwHHBbPGI/Zs6Ia+MSxZ5sFM8nMX
Gf875S+5wt7Ufph28wlm37Kwx15m0vAIgZnv+K5ZiLFQLasi429A6W8lI3NO
2w/iY1a6a9S9cbJ6FFnkr/jR3ffKOaq+e6b9xlPKb6cmlBeFnAjknZVcFtVp
RMe++hNP1giULam1npLrR6O3v2vLVh40prk3nER6sS98N82WQWA20mgMsz1Q
l65fMK2h8iXpdPkOzafoXZh630rdq75QaIjC5R6w650+e/fz0P9X5ayYyXOc
Vj82YxVIYjVy1Rj6zWBeS+d7SOV/pkD8hbM1Zfg33qhF34aE8eXxQbGBXuQ/
2cLMPM/Dl+MzNqMxg+D8KXRfZSMBZnWKImtzDG6fTi/7RPHBduu4rV+Th5Xu
Qo08R2rezwzXOfG7oC+rtvlT9aiBdPHLGSaMqke1N1H3sjjbk2qw1AX1Pcur
HbY8SCHxLKnYCo1ypzCjdAJ85ySizJpd4CLXXiZP4e+ff5ST5sJGX6r5i+gx
Aqsbxf+KV2egPCY3lN+XRGTaH29Hvu2HuYpbr+xzLmJUX25bPD6EDN5VWRNf
LnSNX4bZXOgFX6j61+tjXFxTtUmWM2TDSq28z5rKY6kfqn28LIYgcmIsK3Zs
Auq5DPMrUUNgp5BWgjQO/geYzLV3
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 122->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs8lGkfxofo7SB5EdJRZG2Rdrd1KFyxqYRZJCVlHJpaVMzqRJJ2LYVQ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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lOsfxpEWQh1Hi0LKmiPZU5xulYpCKpW0WKIkS0lZKkmlooRUyF6n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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81OseHpQkhRaHOESSrRI3yRw93ajTImeEspPllKXDiFIkjdKnuKWI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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4lekbPgltKlNClCyRLIMotN0YNbRIOWXJHsYoQpslDWkOc6UkhsTI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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 123->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekbPsikZWaUUSFrMpbGT2k11V1+MjOYIjFk7diS0qHMZAbJSJHq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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHkglPsXxnFbJEVlKUu2SEWhunVtT6mQJZIlFcm1h0oSKgmXElJJkmQr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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx5EyiFBpWux+JUuyTKmMj+xRWSJCZVRCSIlkSpQtxTXKEqoZ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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4lXkbpqGMpZKobyJNRlR2H9OCW5FlLEmFRjjDSSGKscyQLFMhGUVZ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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 124->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8VekbJ5oWpJ/Kkq1oFCVZRrtv0RQmuklly3JTyV50LUmIuklZE6KE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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8Vf8fx5USFVkpW7KahKT5QjLSsJL6KpIUIUlIQqVIVplNKzvZKiHZ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81dkbx2kRSUrCoJEl2RKlUuGjUmiUFhKukHXSQjUSooWUkDuqsSUZ
e01UKiLLtV1XuLnXvt/v9xIjbsg05srv+/vjvM5f5/U55zzv5/2onr5wzGuR
iIjII2r9f7cTZEdWdNTgoFJEtMReEnWBH2xEX9cjwWNi5cQggUuLTqdqTjXi
xOTUX1mbCKTryrp1/NuIZh36An8TieKNf5/cLdUJOQ1T7yU3CVhxCibf8Ysw
c2deyPEl4TbwJCB2aQuiffjW7AIC3cVHttMaK3GCvqDuY0qdjyhpp5nlw/mQ
5PRmNxKfx+n2w7UsMEq6E2/9SiDyffbZbSbteJlgkFklHMJspmOXyXs2lk7O
n7YvIeAV0RIentMOmwndk+dMCRw4fqnTS8hFVO158YA7fOTK2s9f63qLdua6
d5+ukLjFndYcsexG5thlG3ViEJ+lu3RL3tYirdrqkiGPuv/m6V2/rC2FicOs
hOdhEnnR5sqFTAacQ5vmvkmQiJ5wX7a1sQKffX4sY1cRUNgqc7VqZzPEB85G
u4bwsX5Ff1iTbzRcVh46ouJIQimKUbcluh0B5zXfzr3j4brsWN5u6zbcUzPS
PvSCB6vRLR1ahhkwTb4nl0EjsbzM7/Hi4B5gRVdYmjIJmxfcpzfUOrDne967
O40kWiwcC6oKmcir/G/xrVoCUv99eWqW34DUU4vtakgCmU7Ps1pje6AU1jCd
8p4AM3pjZddyFvYaKYXotBEYUnHYIc3sgfXZN1vtlIfAjVxkJ3+FBSV3I67m
NAmFOd7SnZcr8Uu94KngFAnBhLXo4vIGCJe9+demhgA3+nPqmRscHGuZdnn6
ksDJ7gdmjDQOjONdHUHl2Z3x/t0uqxR6RmcDLQ+SCF59+BlnqBkFdnscK9/w
EPdgfLC8sBvqmlobXPN4qHR8qB2jzcIBddL70X0+rMYX6W29U4eisyVushRP
ToriMsOcVmjxaO9uyJFINPPwMZ3uRn5uvpZBBIGiW4lOLXpshFWHVYYvJUGz
Fihp3GZg9uWzngt5BAb58s5y41wIl8ql5dFJxMe8tbEVa0Idzc82xYyPyj4Z
2uT5WnTzqvYMMEiw+DsSZUY74BF5s9SzjwffasFqHd5HiKgEW54TI6G3WT7R
6FUnOrV7/zjhMwzhQEjX6/R8HMmtqFi9jcRprddJSgQbfge6Te5SPKuXx7wR
DWZhcC5Rsp76H9/g8WhJpSY0yEX5SPIoXsqSiC8yf0InV7XRmPpvrYW+30SP
lcNDbF5yN8Wbu+zO5O8vSuFmHxLr/I1AL4vd7bqhA8M5q67IPedBL7Too3p4
KwrpGgGBa4ax6vqlDeyickR2b/Zs20MifV6P1jmUAeXXNgqnLpIYy9k35zff
jmcChZ3vH/LQ3KdV95XRji3CXYqcjiEUsM/M/7q+CjOq/aw0fap/kzumbotW
o2bwL8VjIwQuqgTEDwV1oTguNLPXexAmJeIef2xshIVpePFKqn+Kf25eaVbG
hII2a7RUhY+p33LXWexOB9Pxi7ipC8W3e9DRKwVt+F476tkbQ0BkXeZOE9/H
MLctay13IGFhFsQwWMrGPUP7V8+S+GA8Uh2TP9aLbGcD/ytVAxgMWFLeHJCD
QwovZoyDSFzMDY1V168Cb1uPBneGQKVDlrx2HRMmhinXsyn/FL/tXBm/+AFy
10fcGKXyi/cfu65TXwVv/dmRu3YkRL7/HTSv6oF1rq9cNrqSeKNoWevi3IXl
mxPYLfWDKBZhzBpW9eDGn0tO8Rr7MaibQtc3aIXEj3tZPl08pBvnsaLPVKM1
9EPGMxkSJ616n3xLZELRZixEZj+J2w9XqEq1VyMsVlIqkvLPYG3Z+cPdD1A3
MFLdQ/HBYfB29Ex0YsXr1dolwkEYeB5dq/igHavddr+SovpRVU1hjYM7Bz8i
9fOIJB4EnyTpCbbdkH6ptz1mnkS+WX90A42D7TJd/8gf56Mv+KeNFhlsuBzX
Mnek/CSTwkmMDGUhYED6s+TvJPy9+hRHo5IgVhZO16beG9dit08brVCSL602
6+DBc6EpcrvSSxi7d7uEUf47+eNS8nJjLrp1IyxW6vHRbMm6e38vG4429vsb
KB+NzQ9F+mgUI+3rOkPBTyS8i6+tq2Ky8WhtsHecPYkLHyrqHj6uwnxRJ4Nr
TOL7vAHN9MsHCBwKiwxMSJCbGhvU1VpQF6wnzHtC+cer39r2OQcTKBvfJzGM
1KlrV+nGdCgnMy+IUfXLZHOEob+/wOFeh+EFWxJHjs4d6rdqx4GIo0YvKf9r
SejWiGaXwe5jp9xJDaq+nWfN2f51aGZ0FjjtIjFSHjXTJtWI8wbiwq2UP8u+
aZ1TzizG8+OnU8qPktDIVLm47E4NZJIM1dZsJrF+dq/4D7EG7Kq4v49L5dfQ
w4ZnUQsxm4MJhctJHEiyVAvQZSO/yflhOMUjb0Ikz1aZiXNx46ycn0n41g9c
zTnUAck9La9jx0gEmsdcnJTth45s5/JbrAHE1wS2+YbnI+fXYSl/dxL6n94K
6UM1MLbsWtjBJ3DbaE+U271eDHm5Xea+GoRN7NMgYW8LklWs1/u/ITGTkuBX
cLANgR/V46UkCBRe/7qlmHMTURx6+gaqvkZM5RjRBAbOuySzs7xIPNpxudwq
5hMkUjMCU25T83yLtvSVr7FouGPC/upEYm+jdvMyGS7UMgTl26YJmMs93+Ra
lQr/iVr9emo+sWb0roW5dlC+ulsfcJCHXD7r1JA8E2IDGb7n1vCxKrlP8mFv
LdLdJsbOFZCY2qT01Cy8DFmXdYJZTQQEUto1FtmZKHZ0U1tN8WDuFB5nJn4f
q6IIlUuU/9YG6FQnafTib4G85qQ+1c9K+3+U6eZjjLk2bS6MhNXRJ42SIY0w
m9SjqWjyYfDIeeSqkI3FtFdGglTKnyPzplGuRUjj0y6OhVDzcyJ1VUx/M5TL
d6et0SaQKp3uXnqXjW0GW0zHlvDBzK4/8zi2AnSn0H++xpGQ224YwAjrwnXa
Do9keR78n+yfSt5bifZsz59GqXwRv5n4u+Jd+Cae4LfAHULQP1+cFthdOKEh
raP+hUDuzRcRjnEcJG6IUV5bS+J/rXXCCQ==
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk81VkfRqpRdywVorypSNEihFI9mEyRkIiiLFnKeEuUkEoivBrMlKQM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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 125->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs0lVkfx10S0xSRVzrMUMqSlCmXCvm6hV6ppgy6yZRcDyMhKZckFSX3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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lG0bxqe00GZJKJI2L16EVHrDqUUbFVpI9kpIpGxRslUqlaRCKiTZ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41Wkbx7WOSJRlGiFU70hZamQf38ZIzKAminRCkhOKQyY7x1ZZ0ojO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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs0VfkbxlVqVOiYyTUUZboMZQyFUY9xqxzhIAyikkJyqVwyKpeSxiVF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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 126->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwdlXk81dkbx43R6s4kUk1UlkgqSzLRND5RQ1OaonVK9iVmXCqSpVy7hIiQ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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2kglG8bxRVK9iRJkkpKsqSUbEdSSYWkQhJSSSrZlZBSFFooJFqtSQg1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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlWk81ekbxk+WaJtJ1iQRiRGpEcZ2yZDItMkWskQioYiISUkiS6TJIGMZ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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk41fkblbSoCNGQVGpSllQqjXFzJNcSypRKyFLUVUKWiMoSWozSYg2T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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 127->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs4VWkbxvVFyhiUGJ8ODp00JKdPatNdhFLJFCUkbXIIkRShUDRNY5BT
WyMkZyk5RM5KJG22je0cjXelkSQ1ocj3zh/rWtd7Xe+61nPfz++5HyW218GT
/xESEkqgz7/vMYN4bvI9AY4VXhTRFWGg4hXzpO9sC9JTFrGv5hK43g3L1pns
ht+4RgzLm8F62YWX5RKfIbH1950xVwginr6+93auBqMKSSlOfgSpifrrE39+
BKdMdeXbrgQFmr1/bOPXo3s8+ulgGIFN8sXJPYfacHhmi9xwC8G6K59TKpJ4
UPXSjz3eQCCcbMt56iMAZ7nN1wXzBJFJKq88NvIwZLpjKZdLoHKpkCOz8jZs
rxXLyjkQ1N50ddJ1vwvb/gPpAnrWaCvoUU1uwuTEzWNu0QSfqi3YHyLbwUw4
SuR+IpByiOVoKL6Cdt/R4qn1b6DXufjWTrM2DDbIW2zMJqjMdxtcHtGFgvKg
wXfSDGor5bdIxFYj2nvq7kZvgpbf/S1nx/pR8VJpr309g7L1qZut9zxE8rKK
1QlOBH9utREca+fj1rC2WP8sgZl3vn0buwHyL8NlnlP9t26fXXDcjgcLo9aa
mRICPueQctbtB+hvsv7L0ZFge/YDH/PuLnC2//NRYMtALrRBWESpDd/F6mx9
6ggkNnz5797Wesg6d3q0BhB0rdjjuGylAPekOEpfFRhwUrf/gSupKLb8YY0V
9SNJNS8s9bwA9pl2GdNCVI/UTVa2YweuaInaS/ZTP7axtPVFexGdVDu85SSD
5quYWhLSBZXElMJoKwb/WMVeM7nAR4z4pL3SOwK7xSGrdBketI63SBskE3TU
jrl85NWir+ixvPQ5gmBWvuv+sCYM3sm/+iaN9s862+/n5e3IGJhoKG4kyH4Z
mFXgVY3RQO+38CGwdrl/qEi+HGEBZicOeBBYnApwP/w1GMmGeXdxnPLTrPbx
vFoxlqyq2trsQuAtxxbTCGpFt1m8JO82wSKRHRlnYp6hYVpGgQQR+Bs3Kbvt
6oBshccF3wUM9pu8/7ZqDQ8XxeK+FVYRXJadOqBn1YaZk7+o23cQWGpafxHS
b8O0/gv3VSO0viojl7+zWsBo2+Y1VhBUqeS62EwIoPLc9t55FQY75j4KKn6t
xHbDuFgZWr8ca9MbzmQ9snsade2jCOrfeCl2vejE/bT4crshAr+hMuvhmHZY
qga9OEN5nlDg5XuWlcCZG6l5lOq5rq+eOO5eh/SHOhagfLm9S+F3PmxBz1hu
7g81BPaFPRULV1KeBnuzNjURaEeVuC1rbIDW2lvCnpSn6x9epwc6tcHP2PWx
QgbBgGTSWJ1bL37JSd8348lAf5GBjIodF/0nV5aee0SgLHrnS02DAAF7/HRG
qR4HmXf6zw414/oThwT9iwTXFNfLsTS42M8evTRD50d8dv6gj2EzpnfkqgVl
Eejeqz/cI9YDJZ3VHqLLGGy1mH3WeYWPMuPP1/37CNY+eK+oOdYC37Vmu4eS
aH/yN4vssitAMlfu9UI6H0ISy7VF2P4wNMpX2Eb7m2v8U/GTBj5e5d4wDKP+
sNXVQi9Ht8N56VnVy7UEQd4//VZBepEknLHn71oGspaJSzIN+qAcG/rrSWcG
ayVve7rIcxGwT1vuLK0vyWhjeWtCIzY8u/ijOIcgc2mCh15tG1xXaPw5wqP5
cPRM7t6qdHy9OTH1nc6HUW9Q+talLfCx+Gt2ZRnBuaHz5tLNFTinopfp5k55
WlplaFT4HDXWUaUTlwjCt/ZEr2D1oTluSCztCYNiXTGywLMeo2sSNXVCCIY2
Dykvl++GU9/+4RJ9BhZzVs0u3Ad4ry77wInO91aDE4psHT461D+yPg3SesRt
7paY1yOl3ndageaph61wme/9GuzVrPWbP0vA63d/J5vzEGeirHTrqH/9Zo2G
aeOleBffHmVwimB8sfSsrikfghslemY0H4dsMxaNPsxDplt1/HE21SfELuia
GYB/pExetf4bzIb1vA270w3lrrnfXpxjcIMoseYFfJwW2+bZ0077/98LPxqU
pmKX+abPDtSfr6l33xqp9EBcePucgwmD5cOshQ+ulqEyQuXUCvp/S5+n298e
bkOgXtPigAGCL0aqVk+ud4OdEhc5bcaA23m1ll3Sj+G59lDtIQbWJ6AWnFsH
AevCjn/zNHXgY9ydf5rwV76x5Ubar/tWm7z3cDogfPj79y10fiNs0yZEvzfD
/71okALlccwm4O9e6WLs25ezPsqZ5kcJ675VfhHqFvnZNp0kaFeIC5qX6kDI
rHLvETkGZOTg5vLwZii/fD7mSvPqdObZUd2bnXiyJeooazWD8ZzlUkstWlHy
OPSIWD7dJzK8gGbve4jgqu1Lpv75ZqR9XjDUjsT7EuV2hCDgsGl+DoePFaUS
5jIfKB/qR6RMSyuR5/DI4wDNg+svtFLLPjQjtUvJMDyO4JGrm/MjynOyIKds
/jVBdZhoD09NAPbj9vkN4gxeuJ+X9xzvwIh+lp9JL50vrVD9rPPPYacU6v7t
KkHIseczI1o9WObJBCfRfaDnKjuoE8/HHHxRRfNJxP5ynE5iN37UWmPns45B
vZvwV/ljXCxp5DosuUeg56SIp3v5MJwv+4lMUj5qZU+tjoyBmMahLbF0/kLO
xRmfnixChK+Nfy71s9JLiu3xew8WiBjGWSxhcHrD/+x2NnXAOOGxc/Mr6odG
ucwKbR5mR4J+VSqkea0ywJ3Iy4fYF87mYupXQWLl+FvzVkjkbvIOrqR5t9jF
dJP4U0g+SRZOCybgSKaHb1HkocXkVrh2Md0fm1+J7/7cip+5mhH9lP/M4As1
nwMG4Ji62qoolcE1yYpDcoFtSHdK3hVJ94/DlaB1gUeT4HutOk2M8jm0X3Pm
k9ZTGK3jj5n407Nf9fltp+NQPmbTlEn1zUqblEa0CpAsNRWeT3mqH6nP9jtR
hCL/vhxVqlfK/Pqd1bOXEWC/gWVK71/6MLS7XLMPrjLzyhvYNO9/OVJ5LaQP
lumBUkf/ZJDgm7o7aBkP1458n3al+mxmhHLOOIYgfmxKdCf93lnNS+bgNwFu
BH+/SUwZ/B9coLnj
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VG0fli1KaA/tJUv2JUJu5JVKEpEWFSFahFSKt9BCKaRkSVmikLco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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlWs41Vkbxnc5RtlSQomZVEMYBqFJ3ZQ0qRyKHOe1y6EcKhQSphwmoiQ2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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVWs4lWkbpXJIplQITWMrojIxIQ2yEJJDGrPJsajdRBmHwSb5JCMZpEjI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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 128->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk81WkflWwV0mJaVMg0ZYpKwqvGoUyvqegmWpSIyhpDkfG2TKiMVJgs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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8Vf8fFhpKQ2V9W0ZRspVU8qBlFYlSVIhSViQzkSYVUoqMKCsZF2WP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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVWk4lVsbpiJFCI1HEhGiHAkJt1Q+QySaODYZtowZjtRXGgiR6ISQobap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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk01ekfx2+2JktjGRnXZG2RpE0i8m5TRBqUEMpWDRGVZYxtpCIxOUKL
jGRL1ixzG8lVuLqu/bp2rvv9WjISWWuMft/fH895zuec5znn+byf9/v1UXO9
Yu0hRKPRkqn1//31U/+Lzlp/wdbTaybpFAnH0iKp+5x2TK5fTB2bIjBd3saf
P1ODtYXT/fYnSYh7fVvMGujEutJfFYVWBBCh7Tfqe8TF5rTxKYXzw+ClWUjx
4rh49EF/nxebj3S6Z3jz9k6Mb9FqO3OagKby+i12yn/D+cLEf5pZJJZjZ8QH
33FxKubFcOq2YaT6zvtomDAxYK7us3GGgKRmpbsFj4dF7syYRy0BaaMyk5p7
nbBQFEuyvTAMMlVFWKeQiePeU86DBQQK9Z1jMhebUbuPfo8XRCIvk798a3UZ
OIp+Cr9fJKG8+3cV+hIXdi203hCmALRAl7sLJtfwo8P0F4nz1PlrWyuOM97D
odvzSJgyifjeLXrTPw1ilhH3ZOPkAL4GeId5sesh+dFa7/QcAd1CySCf/ndI
mLt9pozqL0UipsrlFQs02pUqaRkSfCdrtU+sF1Bo29DLMiChmtelE5+cgfuB
pvo1lJ62F3poWwVcfCdsc87UToBo5r+Ctes64BYZdjmfHAY3dWZw4mED7vDf
H96pTd1vJLLUt0bikJztjXEnEunf/xIUhEQ0H+9Xq6bqp3Hu7QcquuD6Vm7N
wZFhGN3QmjoWUYdnL+t91tqR8H0s6szpeo177/iHEvRIfNEPbZsaLYG9aOyF
TAcSS1qfdmv//B5T/S5b/9MgKN16wgcMOxAcXDpQaTAMTRfnOL9P1bAWY0rQ
vUmMO6jQ66s4YJ6wfs1MIuBb93SsQus9okale4oyCNBMOpXE3W7gkZ6P49g5
Egd6wzJOeSSg8JapzTaqjlhSl1j1sBOMfNaSkycfzNfyy6e0OBDpeJjoLUpi
k17XizSrN8hfZdwzkUKi+0tA76g5E2UvL1eypgkEzXEneRszIaC1OBi7kjgy
e3s+yLEJ9sExt3doEui7WDCXVt0PXqOd1dGTAmhp6yk6KDfDyqVPPqaKxHUX
3wDR0F5w7npOu84NQTpE6blC8p8QN/ksfvUECZOx4JH1Qu342jIrn0MfAWPj
4hjfrwJnFpVHFNaToFVIyQbWeeLSaa8EYaofbdE7ns2LPAwGtV2RXs+HvoeV
zcqbRkhvDzUb9Sdg7Xh6s6QiB5E8gz+KbxLYkxvHTbHkoeC2xmgI9T/86uLZ
P0xbQDLcvR38BUi1K9PlV9fBc+j1zTtfCfyUkr8zc6YLsjdFvi2ODuOIVp5/
WzcHfIfE+ebDJHa5FM37SrUj0yNBprxPgB0KbkIGRe9QHkNfSGZTec6MOHbd
LRfObzP/rXQnUXFMv4t+i8qz7G+SShiGNm/ppP6av6CtrBx5L5DqL0g/l375
AdTHPzizKX/51LE44VLZkJ+cCIn2IVFurPbqrG0XBvlhObMHCDiPiRZnCFch
1l7Uq+YACct1nhYqTt3Qax9hlVYQeMR68uE36VZoFYu8qKeRKF6T1sZ+3A3f
+C/Lh+oJpPrz3l7RaMXm+t5jD6wEUK0POr3nYwpG7xgUjDmTKHEaYDzuaQfj
nFKotjkBK9GQ3Y4N7SjNDpdJ+pXy444ztlPXe1Fa2m7R5DuCV5zPnUqNJbgf
Tg9QdiER8+NBR/ZQJfa63zbPTaJ4l388QXVXHdq12StOjiSkWR5+k/I5CPv3
hpllBInY8WVLsx3dGPfbEEXPJrAUN3R2PLUFutIxdULqBOyajH3F6hggD55f
EvlI4EA0M6equhjlDmsapdaSiNRs/lr+azHoN9KfrrlJYro9oEd3cwusF0r/
YRwi0DDzoeuuGhO+/UPcrCEqLxMrGg/Ip3D/PjqSZksiij4om0ErwRENw2G/
yyREzrYaFSS+A7OTNVlnTsJCJ67PtJSN0Md1vKizFF/3rh7JLeDCtdZe5hdd
ATiZZ5bKssphbTgd7UfxKGJCN+dhciZUX5V2sNxI0CM1oiVsWpF79Gv5qDiB
F9G5Wf2KPOz8Zpxc/UCAOXuvXfPrWbh8tbP201sBvruV1ldj04DnnOjhWSES
E6HZUgbyTWhRjI95Hk8gTm3pmoZZP3QSVsms1R1G5lB8axC9g/KdVrvWEwIL
NyuE5d/XI15O7XGuOgkmq6bmc0kt8vLDjntT78/e5rJxl1U3VCMczPbupfRw
zyphbO+BoeKfYuFFAli6LuQcpvx9LOWLfkaxAMsRREm5ARsbtsnRLqkRcD22
83DgkzbkPdo/x2sh0NpqPr42vxwJbe6eRkcp/dsWzMQcKR6Gh84/K6L8VsL9
pMPqgMm+JUHpbgJvgnyOq3b1Q14gNZL+cACdK5v2jggqkHZX1KnKkkRIv/OJ
PLMm/C25UN3fLAB/omTTSsMdbIps/GxI+aeMcyTsnNZLfEyseCG4T0L3wbNP
DrJsFGl6798lTYBpfLVS904SljvWTb+keHF7VqXGRrIV/6w7H+yrS+LE845u
vWo2PiuPzIiVkBCjbzKQaejAEo8dX5AhwM/pktOB3p1wjOzDRd4wwhzTHEb0
G5B86ds1R2qejCvullbdX4aV6hWre9EkMugzo5cPVmNOoHS+cDUJFePxU8se
AxARZ9d9pyJAzs490osUXy7QdfvZipQ/qgY+GDa+wS5ruwmzHgL6Wd82EAH1
mNSIWvkiTvlZri/g0KVGRDGUFLdSvPnhlw45+9FGuKgMiev8QfGkXeZiOIML
j54GxpNwAUxj//ObMWHBLzjY52QsAdV7xewDm5vw44zwJg41L3+WcAuLLePB
+euYb6UhH7QEg6M9Rf54pvDPidWUPm+mkvIU9nXDdpusf1K2ALpyfQ9X2jjI
3nFyTy6V//bWrvnfRjsQXZtoubBCQPTjtdLApLe42jA75gUSuZfM6UE+Rdje
Uxy5meIdIzAvLE69HumFKtffU/NFR8WC9QO3E5Uh5QdrpQSQElIh8pxrkCjb
ne+mRSLQq8voaHovhowOiUWkCOB5/YSr9MlG5DsPFkrbEDC4vlP35sV2ZP0p
bGrHJiHxxC3naDcXTW1b6HujCPwPsC/DHQ==
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 129->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lekbx6kYGdXQaVFCIUm/ytqk9DVSiGyjISmhpLFWtjAle0VjLGUy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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VG0bx7UJbVosqSilFNmlpH6SEpXssoSUJyRSeVCSrSxJhZDoUalU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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41Wkbx5EhJSGFUklpDC1EE6KvvKVSvNomHUsKEYpElCVCIpmJEqKy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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lWkfxlVMNDTRkN5k6cVUFCYJ4ZIsJ9mTZQgplESkiBbClCxFaZSJ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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 130->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8VekbV/lNQpNBlmrKqCwx8ZNMKX2bqLRRRAZZo2tfkigVpphEZLnW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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHk8VG0bFiIR6tUmWXorFKWyRLhsJVHhJSKUyFqWKKRIJQqlqEiiLGXL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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk41ekXRxhbaBNGkWgkRLY0+GizZAk1kmxZkqiUopCshbKELBUJFVJI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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk81HkfnyIsLVYSqu1wdMmdcr6VDgqJVSLMKJsr16bIljNnRdGmknLX
U851pgfjHPdgXJNjZn4/sUrZithaPb/nj+/r++/78z63uPnZuq+k0Wh/UO//
/2h4xDebji4sbhvq7n5KYNThQKLcEhvrRoKXDvkQSJS0GCvfycaY5XLZsCkB
47z7r8f1ekH/u9nhUQ2B2vTQX5TDuaBl+qz53sEHy2Hb9LhWM4RTvk7ofiEg
Yx/COvmuF5c9Hy2fSyeg/j6ppC5vGKpr9JxTYniw/uVdgfubZ9isZl8U5k2C
HvDK/saaOojVvm+V+4UETas47TO9DrqZDNmemyQuGs9NbPHsBPex+4fjxwm4
7TfVzOYOw0le0P1pgoCZqqtGaWEPrrjxanO+CpAzOfCD1uZ+DBdkSjkpCMB0
/j1cc4SNwlnxypULJGwb5JXHRHvwzcrVqNeYRPKFSX3/+xXYuWumAFokTlfS
zBmvONhXyzFcoAngmz10iiHbhXQjPbuHJwkwa+rnGV9HcXGtx6y4Iw/Jw43S
W/S6EXSmLVTHgICH8OPGhawK+OrQP6jMEkh9toKzR6gD7ZPC0iN8AmU/GVbV
TDGRPL42MXyeQP3te5pHbuWAFUPuEDpOgtO250leWwsKH0ha6W+g+DBbHvXp
DobJ2WuO+11JvCLl3JJNWvDROmC98SiBnQ9ZfymEjsLUUJFEyzjCzxz0P7Wc
hdQDfQ87T5L4wzSyF5ZNcNHeOq9eS0I6+hODvqUcPukChwBbEjmNSl5H2Bwk
DAhHDqyh/FCkvb1zig3iLwkRiYMEXL75WWztqEOENuN6nR0Jow9ir61T+vBm
bFUUS5jABDsC6nNchCQmtTdICVBM97uyIDOKbcM9jzqCeJDTcZwRUilGdPv5
lMEIEuy02qX7x4phs3ddZLkBiUUMqf7uU4o9Gw/fbvEkMXzvxcLLB51I71sh
kmMrgGlKwNvNzS1QiFZi18YQSGgy2x+bP4x91upKNcp8VIlrP/qzphuSqido
BZsIRO948Lp0agxxcc0zVVd5yJkLChRlDyFeycla5boAHPqhEo3Iegx++aZr
WU+gpK+roTegDsn5PQMREiT+iuu1KEhoRQZb93bSjkmYvDlomyU3CI81FXer
jfjwuSOZ6zvWCvUn0vL2GwgoQoQlbNeOfQfeWioYkXhCX+saElgOEZGoakVV
EvWvv78uyO2BrFsng68ogJdniXqeTD88tJUqDGwIaCrfbTp4gokXsSapYXqU
PmohF3SlmlFlXhjsfJbA5lf0Sq5xFK4UEbKKlP7S9bqkRG0jYivDrD7lUHqB
rXwnjgvHF/s7NDz5oB2eUOGvLEfe7ruGixokPO78OPubPBurquZs3CKp/HaL
ihg8H0CptdEOtUYCj5OWtXfFtaBJ5927PVdJiKhG6DFLBpDQIaanUMnDre8L
oXXGfTAVO7nVVW8S00RFtFUAB83Xd4W8WE3AsDFY2yq3Dr+9bIqY+kAgb+yf
qRXX++GlGBaoUkDl18Vhb306E3v1TkQ9TiEw/dmFpyc6iOUrBjwxDwL0Y7X7
1SO4SL3Fgb8tAd6sl8vswnMkB871B1D3+pJm4q42fchME37o3U7lUfMcg184
Aqa67vxpCh9tU9GO1fP1iFp9PnRmC4l96rMR1eM1cM69Yyh8hISl29dAYc8B
VI+0JEn/KkDD6g01vP4RLN7kvtd7ykd94Jf/bJRIh3+i7vw4g4Sxxklv1R8a
kelw4ZDCWRLmP5XQdtuV4vCPZVdDDpBIfdU2LaM9hJ7zrXL5EgSkSz7Fj3Tn
ot+Z6V90jspviRQttiMTLMvE9cwTJLxif48tdODgcsTwdrV1fPRGmzHdnfux
QiiQnfSWj+LZvIH7FwewWOqm0OtPQL4i6J1vdQlkWsS9tx4lcfjmn2HqvmyY
JuoXF3UIwFL5of65WScui63TCUkWYLBM41h5SR/srH68m+cggDtreonR3gb7
igne50sU/3UZbrpHmciZqBH1TiXAEjkl0hA6gril7RGKxgL0dZ1VsfhvExhF
H0k1yr+jJtcmlgM52On3SdSymQ/NB1qnqybicT9LU8eP0iN0pmin7gAb7kFT
xYHUHtwQ0zLLHuBi7atzWS/DxzFXN+O9tzUHS0/zr66i8L/cuEvo38R+qodL
K2mJBMTUNuZle/Xh15GLN+v0CSy+YIvcGRzC1kQpG2FzAn2aIfes7Ptgf+DG
Kn1nAaJDmrZzfq5E4ci0FV2c6qv7sfTKSyyk75bylaMTCF8hn1tYFAzf/tPP
OlxIbN/DPawV1Ya4xHTtDVIEfEXjJ1q2ceA+JHNt1ozKh6SXn0VWDGx8DWeP
nCFhfddC3pHJQW7NrbXrnxHISXStv1zCgthcXVt6PgmH5XtH6QeaMHdujtc6
QMA8IW/x+5FqBF5ftEml+nNxQjJtZw7l9+I1e4858iF/lNtazamA0ks/owxL
EpcybQ2CP7ChEZP2xMmCQIO03Xpb/T7cmomQk24TgHd6dJVFdg80b+59/+tl
AWhV+cwz7kawHrq0qEXxfSOiYOarxADOyV6Q9HrMR9OUeMj8bg6ePw0pmtfm
wzpqlWO39CAyPCyKe5IEKA2T25DCGMGjeFlGjYCPhD+f7kt5OYhr/zx3ts3m
4R9Bfn4htx//Ojs3G8tRfnwhHyk0x4Txt8aungUCah+V0wtfN+AG+aRsHYva
/1EtW6c3nfjomvvpwmfKPy4mVwWKGfi7V//WWwpfevSdEMmLT8A5ply70ooE
ryRNZuXmXhyJUSu2LBegU9quQ0aCi6vFY0OWVC+/mdbYQjp0QdogbUKlg8DW
kK5NGSUNOG+blLF7kkC8Q8uprms1kLweyG+/Te3BGW+ns2dZEDYsTB6+S+2p
WWHOhxQuWpT4PkwK/0yhxYXumHKsdpw89Mif2se5tBNZUV2QNbWYuUf1i8eX
7G0V+u3Y7CcjP7aRhMz2SCeT3gHUeORO1jIofEFBpkEpTCybOt1UfUcgeei5
eVFCITJye8sSzEmE2+l7Ll0shsjcGy+aPYlgT3lzW50GBE4mlv2sTEIZm+LP
hDWjU829dYMQgf8BwQK00Q==
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 131->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk4ld0axrcGKRWdBjRQpnSi5OijgVsynooGKg2mkFB2ho2UlOFLioqE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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VG8bJipLWUtERWVNQiXi55ZshQhJpaIkbSgRWSJLiEiFJJU2y1iS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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81Okfn6wOFfEj2daQIkJSJKm8E7WOyJXuWFFK6ypExEpytFR2NYiV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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lekbxpUWU0YhhTFlisb8KmSZpOEiKmSroY4tS6ppmLFEKUokCZUw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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 132->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8ldkfFkYkSZTq0tStMTUoGUskj0r0QcsvpEIaSSptQ6iMENpJlqTB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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3cglW0flkL0GglRiCIzO2lwSSorSUiUvF4ZRRpCSkaRFKmMiLSMVELK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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81Vkfx2+7CnkKyaArTbaENFkqn9QkKkuRJEIJZekWxvBMJEu2MfYk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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk81PkfniIpR0o3RRpXohDbhn10bGJdoRIlKUQ5GxaVpRRli5RNKNHk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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 133->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lVkfR5K2UZEaU2lhFEVlsr99GyJtaCFpYWRudqKQneS+omIIqddk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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lHsbxy2VJS1KUklKZUlZTjv5KrK02MIplV0JlUPJTlLoqEQhWcqR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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81OkXx/GTVCplo3Kp3FuWakvS8rEuEbFWg0JGlJlFJJRKUoskSVKu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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4lWkfPpVKGBnZSslMm++YUKRRcpMKkyxNE206GXtJxWCydELKkqij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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 134->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns8VFkAxyfVJo+NzZa1sii2VhNborx+GmrLJtJmSy/aKYkkDS15hCST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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8Vf/XxVW+lShDhSSSzIoiya9aKkVIQikVUqRIA5VIJGXMUEIisySi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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81ekbFSkhIcqoRpFG/EKDaDGHFCWy1JQKyZJlCJOMSMnPVpEaMU0i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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lWkfxokWS5YwZJlUiiilIWrKxdiGxkwhL0ZZEy/JTDLGJEspJSFr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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 135->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs8VekextUxh0qZ3CIMMpQoiW7Eo8YMTZpKRSEhOSQp7QyiXHYmJySl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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VP8XxkmLFtmlrFmKSLKF4pFUCEmKEmmnkGSrkEp9VchSiiRbESpb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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81GsbxiWhg7ZDibJUEr0HJ7RQXSEZaRFKjkKdI0JMC0papZA6tmzJ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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs01WkXPsq9lFRyG5L0IQxFRHlichlKGCK6nEEliYqYspLo4h5Gkwmd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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 136->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwdlnk8lWkfxg2aiqyjHEoKNaaaNzUV2S7RomE0SVGZksYyyUSy5czEkO2V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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VH0fxkcr2hRZyq602iql0C0UIdlTKBL1VLYeopQsKWVJeipJhago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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs4lNkfH1SqbZVcsi4RbTb35FJYn0wbUW1CLYtsmEpIWUVShBiXlEu0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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4lWkbJ0UL8kUZGUkb0yrKpEy/w2gZIVlq4owolaRCKdt3rFlKZWRk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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 137->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lmkXVvjGpKZFxRTFpLK88fqaUrarlBJpmiwhxhYaCSkiCklGtjRk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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8Vv0fxoUGCmUkqaRCpVRKS11FyuMRyioyHiFKKKWBcpdkJSoSCRmJ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVWk8lWkfPpStYjAq2xRCmhaKCpXrKJUtYooWo4O8YxuhkWXkbQYtEkYd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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs8lGkUnoSEJNlVWZdcKmQrZCProVBrNymSS+6UsKUL5VLaSigJISuJ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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 138->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lWkbtp5pLKeQTA2TyvZN9ZWlheSSpaFo1KhkhJAiSyQJqYwiW4qU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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8le8bx09pkaaUJCNCNqUpHxUNohAhWSnzK0WRZEVJGZWEJGRlRCjZ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41dkbt9XkJiRky1LGEvnNSKU0PtJQYycMCr+0TIttJJMREUmUPUlI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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk4lVsbxgl9xVHJcMhMg3AaTAl1C5kjQxSiooxp0El1QlHIkRNCJMc5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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 139->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4VWsbxpHpRIM0ExWlVDgqc+7iEEVJSmWe6csYJdJR30nlkDgZOmkQ
pXxJhvoStiEzsdkbeyN2eheOZK7oUOc9f6xrXetaz1rv8z73ff/eda7+1h4i
QkJCSfT69x5geu2PL5GPIRd8YNDHheBTp3TjN10etvpe6r9lzeDAYImn1J9c
5L3/mPuJRyD/fO+TyXtcYOHXmVIRBpWdmmzZWBY+Xr4yVudPoJa2PvX8HTZU
f7Bsfi6l9a5RnAGnQtgvUldX9yMQ6v5yJlx7H5YO+d3WcCKwE3iH8ZVboeDS
2BzPJdAQmXN0vvEEeoZ5Uhzaj4JYoMh7GzbE3WolllcSDA6MJ/4Iv4+F57S3
BDkT/CIsllSt14UQLdsIe1UGR+eNmoqJ5EMksiX4vx4ET9NiSlvcutBU6Wti
5cPgWH2uwEY/H/bCCl9XetJ+1vyVEB7Agry2gOwIJNittkRlfngGxMJczxnT
9Z29P/O2a/Rg9tRzxUvDDDKW6JFvkw2oK7W9fzGW4LHM++qM/3fA2TS3psaX
wUIr/w/6CTxY1DZ4tBsyeFEhEnGB24CMjnp7xQQCG2NH3TCvLjyxlrjJv8sg
dH/wEUEzD6u3iEXH6zLYKrRoUCWxGZq+uor9bwiez+8xf2HdhvV97FkjOm95
n8QfKwS1WDgY+0wznuAVZHu2uNfjhmhl3Ot0gtqBsisH/cuwUfade2sAAXt6
w7BsZyt+7zBMev6OYGrmW5hsaw0exZ2U3HWdoMl29f6DDzj4LbRCJ7WaQMKg
dipOlY/Nwj+t4J5hIJrWo1zY1YG+e/1vzA4y8Ih+qp6Tx0XSz0WM3jDBTsPi
m/kqrdBqfhJ0fJKgvVjB/YxLAwIcRFua7hJE35O051yuQDPXcyYghKD1sJ1l
J78dBk6Rt+VWMFifmef2+50q+M0sCn18ieDusKShwaMOeMtmnvTRYsC6NROu
HNqOhNMTwpZCDAxcrka9Pt4O9q7NpmQLg+cuZTP85rfoTkn/PplJMH2LbZRc
/wLVnDSZbKqvYIHnE/9lKXjN216YR/2WoKZg47K2C+JT1/QexTAYC131qzM/
Gy93K53tciWITGT1WYacRaOF2xpdWv/KKMRWubcKCnsk/idzlUDS78rIF+cy
nPmWOpRN/a5sIRrjOZ2Pkzm+x6bpeoXWg/czP7BRnHplbqyCIKa+D4+3VcGT
f4OfeI3AyoetNzNVgui6QMcJX6rvZ4tNxk71sAz3zXO/R/AsXqnCU6QXCbwg
O8MOBt5OS/aLUP/PLXafSCsiGBJLtjrQ2gr226spfnT+Fdt0Tlvcr4LVSE6F
SSSB67qfpptGOzBpHiKfYsVA8Wt23/yCdsis4rS0KDOYrpo8VObPQXzr8JFy
FgEJv86tC67A4zZVVs05ggu/bRuaN/YWYZ26dxay6Tx0xhyPr87C1IZr3z/T
PBjqPDAuZ3XhRPVBr+xRBq5xWgbCFjzYL84Z0TrMYOrm339xt1VCwJc2KqH/
261zuPfIw1jICRtqnqTzrF0Z1Gcy1YJA75F83l80z2MKMgnJfHA83N+tO8Rg
Yux1Q3x7J7ZkiLZGuzF41TDTaedfiokhTSVfyo/Q17w7r04VQTyGmZ2kz9bR
uUa1xp1At32PqDvNh7raZd9lrWjakKJYUkzrY+SWN+m8wfKIvePmYZRP8bZB
vatb0ZbvmKBBeXY7zrH8RWgzZB5ZXhnKpftXchMyyG5B7MX1nnoTBOP7Nxsf
Ga2D6lzI7plk2u9DVkHfibeYtJRNCn5O0P256rpB/0uEndV+6OJNYG/b/0y8
rRzS7Xz7XylP4u2XGJ0e6ER+XUw/7w8GAVHXzpZer4KazqufmIuUP0JjAw/O
7YBMcW7wvzwMXabl0HyxAKyc8YX6XvS9asgJNalySN3SNYg4TVAs5Hfba4SN
Ss5pyYXtlCcp+6L3qLZCPyj2fSblp2v8oQWOSm24oXNeJHqM1kvv1ItK4cBm
XU5B5heqp+DAJa53FSK9luZeiCBI2aNtVzSvDiM/XsYqUT4dq7l8seNbLaTP
b3Cce0Bg0Okyz+lqPdi3jwWMpxKULeJb86SaUPTHUskB6sd0brlBmUQTJj6m
rbhwk6BIW5eY3GlDUYtWlvdGBlzOJuU73Vw0FJe/lKB8OBYVz/LaWouMy8vt
7GIIvOUVY+PqylDCWjaXFUzQU/TjkkQlD35RR6OrzBhs/F6ZcycmDaGF/vpx
lPc35MYKHnEbcfd9nmlbIuXFV8ONOv+pg09KjeZi2r8gW8Xkm1oWUgu5Tyxp
noVf+jWaXOZAxM7sEHcB5UV57qFIm3rUf7cs0aLfL9JIYcz28vHRXLK7woVB
3qvsM76NbJx6k9JYX0dQMGi00l/vHUbqQwsU4xgk/OJ1vngxG1GRZbOjtdQP
Alv3MJE83O3nRsi40/Oid0NQqDwf9UJDB7fbM/BTvftmjxIbrtfFMhwz6H5P
KO/a8CgfPnpW3wLo+STgMfwPD1nQ/vhAUzOI+tnBxUkvpwRDQfv4ItQ/nfqB
KsamnbjUaifWVcBgn1LJ0cKL5eAUbF3USed1dc/EgtLq17j3t4alwIfy3kHj
gnvEAyj6z175k85Lfdx3p0J3DRp6YpdnUr892774dKNQC+pdHPZJCQgWx4+a
Cs7XIMpMVFWe6nefO3DP82EWWoJF/Qdp3lWi80hWfzukn4mYmE4THJfNXOmS
XIFN7eaGSaEEqRaBC3Qt0vEsOYo1S9d7LvX0+BoNqudwwPwU2n9fYHrLjj95
+PJ3hPgnOQaO/HK/NUs5MPPcpVDeSXBuXL7lyVw7BuY9a/jdg8Gg8peZuFkO
zHWML5jQ/LHNk2aJeAVWyK1d9fA89Wu8uneLdTnipBUdPtE87Ex+uiJ4dQeO
zlhbN1FekLnYun63p2D5CJ/aQfXf++hwqmRDB+Tvazi8U2SQMzKqFx3OQbXo
TbPYbsqnZaGC9NIXsF7rJ9pL9dCIXHVq3cZiDFd71P56iuZvvkrmpoYSBH/d
fG435b2435KzWz7woJn+MZM/n/JJ3ytrsqUO95wTxXrp+TDY51SQrNiEUs67
tSaUJ/8A+xvNUQ==
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VH0bxj2UyhZCJKUoiiQqQl1aCEkIIYRUkqXV0yIJyRbSQkSixRIx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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41WkbFg2iJFu2hCZLskQ0tm7fULJkClOibNmZSCtfTKJSUjRCQiUj
QpRMmWydENmP7SByzu89topT2TXT9/v+eK/neq/nva73uZfrflS8Qx19+fn4
+FLp8/+amSAbKPBHJ+YrZQKZ7RQ80ydHffcXIMSEJdXvSJCfGKzMYT9DGMNq
jBtBoM9QCKwPb4eScU09R4iL86tj4xXyivHU/+MR+WgCjWtNa9PD+7CdK5kW
bsaGma6Rnt86JmyzQpwqz1HQUzarcBEfRs6BMeewZTaYLq7RAw590Dm4PLBR
gQthj/V5HB0WGgws/OXUOPhkZxC5itmNb59VGcVcDs7FmlmFWvSi9oV36Ydc
CrJWHp6s//SgZMyN36WLQFl8RVt7RA6WAo/sk/Il+NXigwrFboHVjFe09hiF
uI/HJa8avoJ+IaWseYkg6Zjr2cTgx+CbqJSWpvH6MEbjbiV1wj3rwS6D9xR4
f7/Wdkx5BRm5ylTPGwQLZjxj99EKpE1omevR75frI6KStw5g6EoDO6+cwq2I
kkjqeDdWKoaaePA4KOqxP/BzaBXyLPxf2roRyGrd2j7b3wH93JWxk14UxmdP
tPnsHsIej7TEKv1hpMhUZ2yTKodNkKvVfTGCnXMdvBqHetxM1KWcOykQVZb3
/uvdeHB/j5ZPPEHIoZrNn9cMQaRXr3Vk4j0WtrgeNxkYhABX5eFMNQeea1U4
2rJ50J98fTn8vwThuZKBdzRrEK9fuqbNiGBEesNo1mwJZn5/Px3kQuB5VfVt
EOcenjlM2RnQd4sGKUHdngvwsRr6ouhB86Xw8JhNeQEeeT//6GZN8I4l3JF8
sBHngvNvDrpwYWUYUlj9rA1tmxWFzNII7A0tomVN23HCYqvejje0v4wHtbS+
Z6NF+5NQZyDd1/PN2lTZDJnmrmTzLxT40jcslCw3g3/5qqWhAY3vlvuRjda0
3seEhmo7KOQkebudlu/EnMOpQWMa/7xmzqmfGX14dbKNE3aToOp68ZEG3X6I
qS2WPHVjQ3brYoyoSynKJad+DNlHkHvcQyNqZSPOrLr1ZoMSwT5BtXnhK014
dNX9gnMVgWmC4ZVZsV6kV0x/kVfh4vAu1RuaYg8h2rRvZ7oXQbyc/uPTgmVo
+jfJoOg0zde8ajl/3DMcFuIVDIcRVK88VsZo7cHi4trh33gEt9+0ZGKZiRun
cmw0dGm9nY8NGu3LwEBAjUbWAQLbaHNBuy8NIBM73LbvJzDc3VpXsP4t1ln/
arm8gWD23tlT3QIsPM2+u2tEnsDjeozehRPtsMloypvWoVAZIp414f0a6R7n
ihwPEzwcd5X7Sb8fuw8e/Oy4iYMRSio0f38tQn6YOzmXTpB558ITVmwHtils
T1WUpPEk2mhoV7IQ9EjkvdY3Dpquy+muqm+DpIj5Ze+PHIyLToatvdWEDOHh
qK9tNF8+5o6ZQQVo0S9e40z72UfcKOXxEwbqFr0M4zoIujWXliR+YqKYIRgT
pUzrF9H5VDZ4GOmhDj4pSmPwY5vWZHu1IllHYv5cNAcugbHOJe8bUVmf8+fM
ToI69fvf1g12oigubtfqeQ5yx/4qlh98hdp14/znd9P/nxnmvVQtx+iVaxMB
kQTHJiiBlKV2RFepvdC3pDCSMP+LXhsTerzyVZP36fkfRzo4Of0N3tiUszTt
F/EHj1+t0agCiZPU22VCEPBV0/7p63J4fZrbYEXjO/+H7bd60o8Ks23+kgKj
WJ2qRKQya7HkN8X8+pVC8EuHNVOu/WgIuJ4fv4WN8YGFHKWlUsTF/zG9bEqw
/fOTTXG2PUhL8Qo+ySbo8Put0038L/TKRKzQLqXzNN6srK6xFox27kMRNYJa
Ka2ltPw3iF+9slpXmAtZayNBxuZ2usbYWrykYCbKN5UYPgDeIjQjV3Fw+uep
7MKoYYQlLMQtv2BD6EqX0mH3fny28dimsInCpZRZC1uRXkioIHrkCMFa/+AV
Z7y7UMGWUDBisHGpvG3oxg4WZMqNfJw92fi4LnJem/ThflTZvxevcCAsHDzN
P1wFibKC6cVaAvfvC6bRK7oxvGkogOlEzx/ldOCBeRO6x6QTTA5xUSl8t1BW
tAXPM9aKS1wkIC2lNxU72qG8xLexkiIwuK13YliFiQjs7Uy9yIFZR5jCpF0K
wsMD5XfQ/q/g3/tB/WQd4sN69rMWKehY1TTkpr+D/KiqbornMFwmSy0DYxho
iN1XY6VK8wUJtZKAGlD20uZizRScReb/vPStD/lljep+LWykPzMJEYishnOX
YIWoBEFyG2OsX+cdkkPNuE6Sw9iTom/dklCN3QvvPMR4FOI3rlYvLutCrvHv
h45kcsFLvPuPx9FU1B6izii4ErBU//3llG0v1J/8aDcvxMHTWOGWjPlWFNmZ
puSdpXBTI79QSoOB8LJyx6EAGu9PYZbG/H0oSN5qLxfPwb2Ydzy50ReYsjOR
1LInEAu03hB9/AUOP1d8+/dBAr0gdW7ChyLUkDpeSRSBUkp1nufRMsxeFZ4v
A8GzHRJjSUHvICZP1VwiFM7Phf6Q39+ApKgtz6aNCca/qZ/2MW1E4d2irPQ+
Clte+e4N/tSAFFZOLOVCoeHM+cSt7EFs+fXp7FYmGwHuF3/5rZsF27eNz7NO
ULgnLRrVWp2NBC7vL5G9BDHvYz7G6nWhRCTOI06QQohObcKOplpUTAUKp+XT
+XX0z9o6RSaCImZ4ynxc3HNlM67NxsB25prTP/R+cFl8c3Z1fjPORhw62zxK
oJvWvFih2QfFamZEdhIHfM9ZNTn+j5F2dLO6NZ2XATqXe9tkWlGYGnvYVZjA
OeLlHaFz/chPf/MpctcIlN2yWrvTS+Cgqra+9RC9L3wsN86odCPxskuKTg+F
qjs/7Ox5xMJOA0aM38QIZkyF/XMEaf+v37O99Dsb3glBvhMxr9G06mGMdzeF
zAhbm2ud/fC5cJu5XpWCb4advHc8E5E6c0bt4xzkx1Rwt2R3YlogeXRlCwWJ
NXu17Gc7YDnUoODRR8Dndz78qtdFRE8XNP/uSXBJ126y2/UJDDvUjbfR+7B2
+ptqcdJtuPDXS6TSfPwP5tmyhg==
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lfkexylRFCoZW2TKklHTpqYJH0kMpWRLcm0t3NFim8mWRENMdkkk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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 140->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lVkDNsO0cLNl7CZJZW2yJIM8pZRJjMrUYEiKIRHDSMrSF0KyZU2k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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2kgVG8fFRXtCCFJ4h+lLG0qHGSrLFmSLYlERIlkL5FSiuxaJKIsIVsl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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41lkfxiXRmLxTRL3qbWxJtkalVHIbS2GkCKk3EoVmLGXJ1mDsxBCy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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns01Okfx6dcklzayD1JHZeSaKVIvYktW6pZKnJXspS0LllFTLbaFW0u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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 141->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns4Vdkfxo1UTCV+jAqpZIxMF6mmQvOqMDGEiEiR+7iEEn4ohxq5k+qk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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4lQ0bpyiklJAXZSSVbNUr66clIatCGSEhRVaKtCShEpKIhKx6JSF7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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk41XkbxknEJDUSCjEibdSrQjHuOtkqSkgpkYycIZMcIcboSJS9srXw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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk41dkfxy1lSWnaMFRSsiVNVIPwblCJFNk1GXNJhlESJtRYRlGWskey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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 142->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk81VkfllBTaYw1E2FqEBqSJgmPxpooIxOVLL12QumNQlnKTiYikWTJ
FsO4KUZKuJZruZbrXtlizk9q2qQ9Ne95/zif88c5n3Oe5/k+3+erciTI3lNY
SEgoi67/7wofeh6dS+ag4JOStHkawXjRUcWi7f1gLXNcqdxAUFPeFbo4Pgm3
KoM959fOQogpmj060w8diVdZkX0EcZZ6ryfmW1Bz9ui2jyEECZ36taGFrWhZ
lCGPYwkcjDcfzhBuxof0nYbjQQSP/iotf+5RAwtfjttGDwIr5aywx4o8zGku
9YmWY1BYxt48mDaMQVGtgadfCaR/e97yu6AMwzUrn3keISBPgmXXVfbhyB6P
fJtCAuWHjNBJwx6sK7CQUS0huBzMZJiWsXDG6EBXmyfBHYZ7Q3iKizyTitXi
LIKZ2k1xd4R52L922llJlEHeLxuX/ZPMxbuXGt6Vg/R+1fUmvR4egr2+dtRp
Mng1a5MarNwPwbV9RcZ3COwYNyvW/UqcjznQcZbisUnktX+/rxFN7wxs1gQS
ZH3/tTfCiIeGa6Mu22QZ3De19h2wYcM+WKhWLZJgJLwm/PxoF84kB3vWFVP+
1ZExEqvL8W29WmSNO8Hr/aKytg0P0XO+xy87g4FzxeG3cp96UVyYp5JG+d33
e/nHT/yLyKjwup/hSvCNpKjTRHMX+s1id+0oIEBlx8H5jn4Exkz/9+M9Ap3Z
GyV+P3ZDQXJVTH05gdRTWeORaAEezMcnqGxjwHJxa99ozMF375c6tFYQ3JSb
WNeh3oEWZWP1CFo/O1ezqbH9UWC3OjSY0P/0TCtEricPoHnR+bvENgLNUJ8u
+49cJFV6dlbPE6SnP+0yGSvDzoC4gEzKJyv488FSDR5SPONrGzdQPizZf9PK
bmPSb2i5li+B+omae+LcHNQftF7g0/dTrrMl1aO6IfwgrS41h8BLl12ZsZaH
iriF5y4MwYfDc59Ys10491jfNO4iwbPA5hem3D7ESA9xFovoOVc3229XO9LN
ix1Z4QQxDUn5P3t0QjAjL8fOoH4eimlqf8pDmbKszO4FgqgvDkMzBv2wmefY
19DzqGQu75YnF8bZQia7cyl/Zd+MpV8rkLTjktVDysfVWjt6aPkoqnb1xXeG
M2AvNdcKsBvEkmjSWEX9pRMyEIoLTThcJdKsHUDQHJvh7tA1ABPbjyfetRMI
pT4sOlR+HRpzRbWhbgQFe50On5JqhmQhrLypf9J/WzRY+qMAX9WsVCMtGOjq
Tp47HsWHfMiBvyIDGUhctqoKELmFZuutkhxvgtb5RAuxkmFoXF7VG7mCAXck
KOe6bDsUPMs3FVL+Cgc0X24Nm0Tyz5YJgm4G6sKsHeJFnbDY7tHtk0kQnN1X
IYJWRH4bIMENJthtlL/SaX0Hig/7XjC8QPFtW59pIzuOwG0cR79RBhpeKTvN
L7RCNMK1f4q+fyg1RUJ+0zC8wrPq55czcAvK3OPcewUXxTnrRmk9TaT+UrVJ
uIUjPox/HsVb98ny6ZpXTfguX7FP/yiB2IM5Tbuvw9j8rTV37XuC4citA7MX
R+ByrDLsvQgDf7W7ev/osqGeZKmv+DtBsZ+k3zXDMcgr9aYr8RhYR++9KFHd
jx/Ks6VEmglOxN82SLa6DZ8QdiZD/1ue4dGiyvSjP9PxSSr1t3pl9S/183dR
pr3GTJjmVZTpwJayspO4yevetJ3iLWazfpIw5UDhTLOPXhnB9sIiKedf+Zis
YNtk0355xNs2briBg1LPM/ZGtH8z3at/nYsfB+tNfMWZdgZ6p7+MGCW1wM7+
zef6U1S/hZWfbz4YREL+tbOSAoL89fLH7BMHIex/r/rQY4KyHdrvstbVw9v+
lCqheIU0lkQkhmaD3Ws53UjxmBXc2PRfl4dYcj7PMnkLg5STf78KEm9D6+Vl
Vjk0TwwySi/2uU4g31xe9o8RBgW5Xmpar/mY5g7Nq/gxeJobtUxrfykivHpy
nKh/y549eJvj1wq1xkD3OYpPQWXMN9mWDzUP6bvnVBkkuly6csGKj/HqeyJD
6gyM/NLUzs3wcdzK99+FXQx6Yrj+2gP9qA6o1emk+bIo/fGO9J4ONBgO/mc+
muoZ+CXylDkXY6/NxsXvE3za5xvhH82HdblAy1mMwTmpn3M5S9j480OU/mIU
zTPHVP8N73IRG5aXuIL2Q8S9/BdVR8ZwwnEuMyWRQVOkuFP4i0Hs3TwfVNNJ
9VFZUWmU4gartsdpm6k+AnG5W7HqdVA89mjLPJ0nOtPFf78U9ENDe/H0bzeo
/9peav/5QzlcSi1Ydyn/1DHFFr79GPgfvZtIEYOydXa8iMJbeDeUK99L9Y9z
fSTZdHUAIY2x/u5vCNpk3+soi7Vj9fLS1OenCeSW6CZ/KRpBdOGoqpQNg/TV
3+xzujQAZXfW22tzBPHPDRTMKtuh6+7yRRBDEGbbaa8kw8NY6BXR4Ck6H1+E
a8kf7MeJ5eVylrUEIvprZHgHuhFk42TKuUr1vKptIuvGxWCKQNW/hWCvd2uS
ttgQRCa2/rjhCc3bThebgjvj+KbooKMQn8EK2d4Z6bVdmHaQPytM8+9s30DJ
6OsRTKWI/PBenMFcdhqLO8rBjJ5M/YZUWp8Hxkdei7aiydezfiiCYFW2oWy+
xSiq7br0dtH7mb3HEuJ28zHxS16JFc0fC51qseiHAlxuMLy9YMsgrODSvETJ
IHa+XbNngUPA/uK5379xCMltmDAmBLZvDvXxFIdQF7usLeIFwUne5H7ziBHU
nvSQEN3OQBAYJl0UMYyqHlslHp3vizfyvC+lsMHyvKrslE7z7/P7ja1vr8Hb
M0lFm/rByix1heBqDbSmdLeq0vp2NjQVhQTewqPPGUvkfQi6nfVDkpqHcTdq
pndqkUD3/BZXRyk+DP8WOZ6izeD0zbQZs2k+Lrg5cbUD6DzfmF6qt34EGl1R
hcdWM4gqd5fRyxnBWu0yUqrHIEGlPnyZQz9+d43Y8ySfYOLKs7QRpV7odz6b
Kqbzc6ZEU8bygACCrJdtmrPUv8P/JOSu6sJk3fHRDckEAcEh2t3KQzAR0zn+
J83D/wEnwsFc
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8Ve/bxU1JlJQhSRISZSqSipakDCGRJkL9VP4pIkRUoqKSqWRIJQkV
mceQeZ6dYybO2eccQyGRIfHs59X+3K/2vfd1re9aa+tFJ7NLHGxsbNbsbGz/
/5SdsBIt8OwCrL+ZjFcMYfitcsmhtlqclYmQjFKgQaVvrdO93GwM/NbZULeJ
gF2G2auQ5Wbkijy7XpVHQGNim1HjiwZwb2G3pobSoCC1zp/zTw0eBLZNLYcN
oSaJ/XxuIQXjC8E2KQIsTB3YuXmTaBtGoo7sfniVgaRfyTm35itxtrfZV2mC
wOKB2VNL0w14N7TeTX8rA+cup6t2b2yDtbhs4HguA9aa88775bqxZKP3e06D
hdiPdl7ii8kQyDxqv2majphB6XttpQkojptf7a1FwJZN1ebYfDPC5yqnf+1i
omqfi9X/9FohMMidkqVLgGItfShSpwVjxzy3Uzjp0GbcrtUX7oeMvayDXC8N
bGp6wR6B5qh7kZm30oYAG19WJaXSF0mpl91T7QisnqPu/e9VK8xP9DCcPgxi
NPOYzyfzdkg22GwNC6PDIVU+xudcJ/pcuG6+Eh6ELbdz+tnTbRC4P/LnzywD
AV4Vp7S0C2H3gSuptJAO7+HE6hXr2tE3tUWMPZcFHuE8hZKlPrCH1j1tPDAG
/Tf31P33tONg26tVkl7DCJi3btl7qxOgrb+rwTuIL5elLiS87oTu+xyD06F9
yLuiZy9cUAGryzcFeMvJedW/PRL/j4JPTtYRuUQ/THf+Xj5X8wEObJ7LdWcJ
DBpmTXlc7IRpzUsXk9phaH/lu7A1sgAhPCs789MIVLhfLpYPasKOgI/XIxvp
4DV7ui03qQV9MV7rPy0x4fObY63Q5lSIBhE2RjsJ9PwcdAnZVQnPBc90szIa
rpavComda8FBAXq26xkCHPpMVb5buSjUuD+S20zeT3pnqPmpaiwelZ9fl0PA
Wc12zimlA8n3hqqS6gkwDu1w3/W6EoPTHhF97xgo/HVkTdlMCwrdtSMFGvsx
7iIbeGXpK+YUKjZ/HySQXCBJ1KVVolt7935fLga05bdHNuol4O63nlvtVwho
TynOXfSggq33xrcvqSz8WzUr8OxMNZYE84QoGQTyjJ9zNETn4Q+n79ctJgQS
KlSZ3yx7UGZOe/k6kwmNDaE83vQazJVEzhGCBLr0Y4c3XK7Gx22e71oMaJB8
JBJDVWyD6kLW3onnNPy4tLPKZ1UJbus8Nb/gTUfy5YzAmtB8XK32ENpvxoDt
bnnn8vFsDCvP5r/SITA37GFfUPgZErdm90weISB3ISDuuW4OeAVbDH5X0iFf
tTLmyY8WbFOv3F0TQKCl7X4kv2QuRsoPft34mDwnarwRSSpGlr7He4OTBHTW
pwp07WtDiVSseM8lBiQtdwaLLT2HiIMDr/Z5AqZO1Sv+FnZDTrktdliRgehx
vdF+2w+gJC+HDTgTEPBx+3LO+DkstC/F/7pIQIjdbktARh4effswo0zqjS0u
67jz+SDkHfnIKiH14Zu8OqTQshXtXf4Nvv00iPFU9Wo/z8V+Ob+JqycIRPZe
k320NhtBLeZz04t07LJ0yXKz64CQ1J0HLwkGntTGdej11UMrYM5nyylyXmfd
3k/b+CPshpKx92UCohuc5/pFv4FurPBGNouOY3UhHNMBFPjW9rtejmLCo1f6
peyxfHgLaIsKk7wSKhkNK9nTiOUTczHHmEwc/EM47opvhehu5091JB+GxWJf
1xfVwVEzXaZyDYG0cq702d5+9Oge3aUrTkUA2z4f9YBmCPIse0da0uE6W31e
0LEbTBsVvuMsJrJabrrYlWYiI9bj8J/dBHyshPzG0/KhMnbLsfk8A671341d
z/WAJ8/IrfXxKMbD3R772HYhPsDZfeUMCz1ztp8v63Vg/JKtmkgPAxlWcrc6
A7rANqFiYUvul0kUnb3SsBKTba1c1bUEqhozLV+YUrEsvJj9bIyB4cr1OlIa
lZBzcd+qSvKKW1L4biUbFVxfU2qc0gdRqWyuUKTYDsdcEUZbOwuSbe9fOB6v
w9I6hdnYbQycPCzsuzUlHUcZpyj8ygRKNO/tor0Og3hd9L4Ucp4+P0QqrvXm
43DdA9aKtQTy7VQjNxuVYEfDiMh3Vzpu8G/kY+6rhfqT7o3rlJgQ/SE0G2Ra
CaOVk6GbHQlsuMyeGLuzGzvSHKv7e2jQyFnzbdbwHu7X35tRPEfgVN5EC9W3
Ddfc0o++iBpC/PGXB2YLypB5ey2nL42GG6vfJr3WrsdiJw1GJA/Yzvb/SrX5
BE25pn8HrAhwDvZru3bkoOUlZ1e8JQNqDpGnWn92QT+Ikd/2jIEQH3X/W2Il
aDKRhi0HAc+8DlFHi35YBJUXZsuOoOBfzIzNg1pYVq/dVmZBIBYiRjOsZFyN
vT6jakSAiypxdok1gGJNMx+Z4wTYpw+dNg/sRL1nrbK8xBA8NKpWXDHOQVaA
kPihrQSMutdo055WwY6SZ6z/loa82t2Rlg0J0OD4suA9T0dO4zetEzM96L5h
o/xLmgba90dbTfj7ceNvUXp82Qge7A3PUBuIg21uXVa6AQFeuwOi+Q55uKhx
UpuX1Ft12dzNt5d64cnI0xw9MwTRjMXzStHRYEwdDucg9eEsN2F40KocxLTi
8dOXCLCSfqr4mrSBqyaaovtxEO4BY6fHv7TCbEupjQDzO/wfjEXui2lHvyWl
u8OGDgV5TeKmXCMCV7cOuRXRIcIuvtlyWyPYbLq/yVoS8DAz5zUi9yvAuKf1
EIuO2NNNutZFNTA/bnWfLYqOxwmd9HXBZdh9d4/KjgQ6Ju2mLPscyhC+V+e9
pDADGoPcq/jvdMCVv8E6zuU7eKq1prZ1FuC9U89vPCQgqcd/4n+XQpD546Ky
JMkbniD2rx27qGicN57du30IJgW6qdpRHag4rUaIGJB8HxPxyk6PhqOb/4S5
Kcm/L05vn3dmIneHJM8pFwLTI/O7VztWYJOZmfuBYDLP5O2XZ3vWhIsGvo8t
lVlw8d6fEpdMwc8nbtt78gfxhrf6H1t4BVJc4z2tb5J6+Hs44+s9KsTi9iqI
X2VBzG1k/3apTlz5/cUoLnSE/H6dqq9fe2Hr+6rI+joTlKu8FXZSVCSb8vPH
C7LQOPZjfjCqGcISLYZGd5n445C36Uk8BQN8wtv2mtMRzuGj+EmkCVHzbWWD
pF9Grtrho2RCxfAawyNSUTTovNkj4VnbASbzjfGeSywQAiv8hq51woTlGc9j
R0fImr0nlmOp+OxD/HTkHYKE1n/rCh374Wr2Py5l0g92xOitr2AbQIejyz82
zzGYfNOc3aOWjdi8lU4LpL+nnVOYixqngMeCZchhPogWqanTW9dWQTdwvugq
HwP2EYl2XPFV+HNFXXNiFx0yxut/f9rZhCeZwle1FOnI/FgWq5NcgbuHbJO0
/Eg/z+dYSPjYA2aokozgJPm/izjUgjNi4bGN40mTLYH4LcvB0p8rkHymSf6P
CRNW/81Ml6Z34Qv7hrk9cqPY6G0cXSvRDtfaSS/CjwGroAFKNekP2k+vn7Pm
oOOkygGf2bgyqH8t1ovKIfm1/delykkyD1Cznuk7kH6q/Io94Z0fpAN63neT
/NJ0Evm9JqYKgeU5E7nFpL6nOP008+oRuV/5grM/yRO/N2tVtG5i7t6q5mCS
n/afzZozbXNBq5ETFg2mo6HOPslcLx1pzq1CSfYEkvRvPLbpqEbsLaklgSoG
jOJi9KQfNsHpOm+dUwQdiyc5GGzeTYhOL7/5apyA7KaZLjVrChZMOBIdjZmI
fBB3VPX+V3ydf25tZkbgx/bDbg7bumGQR+nZa80C9x6tWtfKfnyUHUlcf4AJ
s9HlnhfdrdAx5ns6cZAOH69jUhuVYzHJXX7TjvRv7S96eglz7gi0je+kWZP7
ylfMUk2nwMQnMLyeRXJl70mL9JQUTMrL9uuQ73ut9Hmf4aZucPwYW3Z63o9a
ab6s7U/b8XeTYJHFUi9ulLx01Q//iOXyP68USb4eMPuec5SzC30HFls2kXk5
TeZS5r9XpUifsHuSK05gsvTz41CXWvB99E+lGNFBcw8yk2vPhu53qm6XNoGA
sTXTPJkFeBuzMfyKPJk3H/7Y6n3+AzwGojKmyHzD3yrh33uxHbmaz37wnmUh
ydcztXQpH75nlqquRxEI2WN51SAxGhI2LzSvkPoO8u3dfp7agXynGT4ZMg+N
VTUn3T/TicwH76w+lQzg767t2hf2l0FlRZWDZB0NNbPTEuqh7XikfyTVYj0d
b7LPG3Y5loDqGCKkV02HaP3UnfX8GUjmfdXOTeYdKVpqofdcK16sE1njTbAQ
0JR2K2k9FYZ/TxsWNZP9RbEq2TG9FqdeJ3M/dGZARHzASC+nCw8VLobdP8XE
oNKO60/VSrF1Iegn/wdyvv1JomEHe6FQot8sdIUBDxnFMc4Hhch7+ffPIxYN
Mi2utNXhFJwQnVzKOkKHAYcRXWtdK5JO/Fs3FEbqQ8/6aYROH6SEx9aMCRHw
Nr1ENRqiYFR7TLOd5E9ySaBP/tEyxCZWycc5MSDX3LZQ41UED/XGYVV+Ms/y
Jx74JpqF76POA1+kybx31pCz+G0afG8K7Co7RODkZMwfVbUOxDzOqhrxYeHa
apNrcmTesVe9c62pjwHxTebzDU/aUNkt6WdVRfohV7mCS3g6fPfZsKWS/WGy
NqIp8kE+lKw+bU4wJiDvU+b572A6liJDXykeI2C1N/9XzslXeGn2gLvVnNSb
1z7ZhRkn9JRIBiuS+xpAC9patpqKxwv/MhXJ3JU3f4/fILAYAqu7Ut+Q+xW4
RuvEZScqHEp7royksMBfdtPPvrQVyol/ORSnhxC2MqnV7Vo3aHbqiixSP7Hv
Bb0UPvdCqOuvc2U4E8ShCD5Xnmq07uZV3h9DR8XuPbKs6QKIi9w5ySXKQI/i
m2sHJ5sgk9M2s3IHA4uJW34/uUCF0UWZoYYQ0h/eb1mILMiBhJKmK5sXgW4L
rz5ZxU6Euq8W+8dNoE/hnZRDfR8uLifI9z4m/UDmx6CqYipqcoNF+cl88y2Z
3rnwuxUUwU+bJz4y8YRaKehvXoXRy9Z1J90IZDUOarB1NEAhJu+2pwsDfYfF
oqJdyb5kOvF3bxgDVUFrVRVzO1C8z/BxeCkDg943Uin9zbBdMX2xzpSODP3K
z4+CKUho9OXOt2RBp63G/EJ4F7zlyu4YSvVj9HRBoZxPN+rS/WRkq1kQ2MZe
dsMiGwaJXgzhv2R+6wj33/26G6/rC2n9iwRuP7ogODPSg0te9MVC6XYc62Mp
m3L24vBGfrfPD8j9Fntnc0CwBVH3Wu9vF2TCuFhRKty/C/7Zp5R+bhiGPf/v
0ePxOXDryLhpRPqBvtJi5P2kLrR0TLCsTQaxISvaJTquBTkXVeLt/OjoYhO5
YCVeiAKvokotMl9+Xt8kratWjMpxdzUq+X8ao10+HF/RAYHTR5dftRF4J2bw
rEEwHbbH3lEqyH52oDp5fcnhPghwd7hzHhmAYsC3xJE9ldhtnGMgQPbRo+pc
jnJhRYjNqEi7k0Lq55jhKI1SDgHD+pUfNtGxvj3g9kOXRuwLFxAS8GHC0cKX
Z4NeNxbDArICdg6gj1mBT6r5GFf3ibxN9tcWkedm6S+68NZTJXpUdRDPub02
27+rgNe7n49OeTMg6sWoaejrxZM5h6Ez+j0IyebZpnzlA7g+BByR30X2l4yV
K/9bzIF6WVD+RjJPhniYOiRUJmPyXL5ogBwBhS/BRzLZyL62oTjaley7qw9G
6DpR+2D9NtYs5j/SP0Rppns2lkD1sEjQodUEbixL2G+5Woz7mz1pqaR/1a1t
kOFR70VkqNbRk2TfLwu8Vsd434aQx499FkiezonRveY7G5BDXRfVQuYhd7kt
0iaDlXjRO+5/QoJAwaLVR87YdtyzX6umRvJmqVnR3kS2HOKZZy12/iZw90Sy
vVUDFXfvGNNbjAfguirH9uWKSjh3XhU8eYz0w8T1pvs0umCY4btftIYOgVmL
z9Lvv0GJL6DvqyKBhVFaZ4lYB57f2+z8OXAIXbeU4q5pdSOytPfECZV2TPPX
U5U6W2DzZupO1Zph6Mi0Ok7+rx3HTyU+TUlkwemA61mR4nZknHd5ySD71rVz
/4u7V9hC9lUpGbErdCRF5eeuOZYFR+bAy2CSH7Hs2qtS333F+eZ/bgYskofU
CJGzOV+hfT5ulEHuZ7c2N4doYx8mel+u/PFvDLFRo6XPHz/A1cbZvZpknh5f
1kwVekj23ZDrHlYbCchososlHM2BRun38YjtDDR8jnXysmhB+EHHrjxSj1Mz
4XL6ij2gfDK6kW0zAqM3BuYf2KtwzHAFMTVLgzi7klw0ybML9WPe5o1MXJux
1w3yo4CiPqBxW4CGgbmTMY4vmtCrzrJ6w0mD7eW4WJ2UQshZb510+EXH2T5P
x96BLtwV4NiwpnAY3Jym5wunOvBDNbLSb6YX964Ke4QxO8H7rCNS588Q5LLE
uPzs09CgO2535j9yf1Nuyu5bJP1td1V8jRELN8K0Wvq2lULCuXVuazXZ98Sq
Eif4G7FjR/26gXjy/H1NW3B1E3hUrn77Xk5HwP5rce5/I3DC73LLIMnzG/of
d37IT4Aob6h4OnlWS7db+7OfCo8FiaaCnGH8KuzOtntZjuaSBeltZJ6TPJlH
fDKLwdG0l4P+F8g80Cg1INUdgcdSl07vJPPVZARX4efUNEQIJShrs5M8sr3+
T9mdAoc3ab/TNjFR5VHb5UT26enTfFsCng5jQ3dGvE1ONUbvGmgPlZL3qaYe
lMvLQvz8iV8WngRcWXFmF8Nz0GMoV58KAuIldyxCJd+BEiChe4jsp8MVp71D
ViagaPu1CW7SzwKl145q/KuFTHL18EQxA4U8jnveneqDTVX3Q8aFQXQF/9bZ
4V2O6/NRr7jb6JDaKiYQFNSN1YL818/tG4WKb6bDlZ+dkHqbqmUTR/rBxcgf
AvWJoD38YjC6n+wj3q5870S7YKQ3hDYDJv7OfDlzUoOCU67lKQ6HaYjjElV5
e6UIZ5rXPvMj+adf/H18sagdAm+eCzkWESiq51GhllcDpT08ES00CN7Zn/WA
aEEpl6l7dgQN/wdHVATb
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81tkbNVoohNSQSUgZSxmjkinjJEIqRMSQ5Q3ZskyTSlFRkhiVkl32
ZSKMsmb3IvsupLf3e1+RvQwS9fv+/rif+8/9nHuec87zPNIMD2MHbi4urgj6
/P/md4jY9wejDbIy1IArRaAmLG9WqN+DI/63p6RlRpDy/m+NdxtrYR2o5bop
i2C7bo1Z9vpecAcWKe9Rp8AclVfkCmuD/mCVlEgRhTs+Voa67m/xc4WIvOsK
C6v9Lq/99hcTAexbn9gZBHJynwKDnYowf9DWqsmGwH56YlvejS6oidXcL8gn
WMxjXmTs6oCWQ6pt1AKBkq2Zx2uZZixHpm9vsyBof+AePN+ZiombP4tscCMo
kD590f8RE+UN5HZ6FgWpkM3qW3zzEeFZ9H1QlyCjIbT7aVIXauMcziWsJZiw
aRsLUC1EUKBP02UGgSnDOpvXoxF3E+5uTLlFwShswWTa6SKiD6UpNNP87odz
Gq9vuwOVnA+Hd9sRcEmKJkja50LgUG7f9mu0XnU2PGqChdjyRWup5QDBcVnx
YWmhVhxPZQz2riEwK4hR2fJjKr6Vi372pf9LeWUh5svzBsGO87vjtdiYOyRQ
YtzRj5rIRCXtjxR49fUzlw0qEd/pYVRsRcDq5Tf1TSiFoFdBqcs0gZ82xdcb
Uoti5zz+8FACoeCzXZef3ccRxc78aRqfN21NvUNzFx74DX8R8ieordXpds9u
xQiz2yJrP8Gu0cdCdeGt0J9Mdu77StBacNk006UbPNaCXZ6faDzH1ZJOxX1w
C6lp3OI0AithRuiB7w2wPPhbUvASwfITzcrCXVUYbxJ2s6fxZuYeL3gF5KDc
n/t6xBm63hNaAbL8iYg0vNHaQvvFsOiZnw1oR/WBPRJRXyjYVvnJi7eVQM+0
T+pXI4LkrohS57he3PqnMEf+PIHUkg2n7UQPnG6XKn78j0LzyvRXrZRuaH/Y
YWxnR0F5ucAsv7IIcunnf776C8GhtRrjrwxawVx2/KH5Dl1v/mLz/LVCMJh1
7xjWBM114ts4D4ag8T6AeuZNwF9i49Ku1g6+nhsm4u8IdHTWzbVv7oezis3f
/7myoaA5Np4RNoTqnKQ7Ets/IELDUiH0bB4yd8X92u9IULxu2kcyph9/3VwV
UZ/Ixg1rMZ7Tt1pwuDqSvcaS1vdE4XC4YQPm5GpyuzdzoL2BFZfi0Qx/O64e
hSMU1MYCct+5lSEk5tKEszuBkZ3K9lGXN/iWdPzFBT6CIfaJZupUFjYcjRbm
GNB6PFabkgysRaJCdpWXGEFMZlpWe3krMlfv36NvQCFTV3VixbwSxm+yZnJm
aL1+1N2k69OJoJnYPXnlbKzX9On7KNSPW09XzqzsptB6LHZp/9xbuC0+/amx
h0Dse2+UoW8rih5dFkg5SedbbVE+Ua4fxsc78hQG2GizrdC4lViLqbW/h+T0
0PjX7oW93dmA1iups7XKNF99RYmRrgqoUmPcAxwK18y8BAWihyAocuX6kjQL
Uufl7PRUapFjL+i5ypAg1871xRDViY5wd5OVn+j6jiY6TaUPwWZjeualWTbi
B3Z2q37oQMNUdsm3NRyMrs8fafLNg/3cU58CJ7q/FiUfrg/vRKyar96DBgJb
H/JM53wvvvlFl7Fs2dAefJxre78J92M8o5OECUjTlR8cVkpglS9dPGlL5+Oq
Is+p2noMiu6JSqojsOLKHM0qy8PU6neGaXR+jSbL7R/NtKBcTWd5VQcF1s1V
V0qnupGdk2UeeoWNl3EmHb/bDCJvSKDHNJlCloCRgERZDTbKlO5KiqVQeeBh
slbIY1T2hogk0vmfqFcRtcvow1RJ0WmxOApPFZSLdGz6sSlcS7lcdAR9b03u
GEw/h3C1Kr85rafUOSkzwxO0/7PM+H89aD80jxmvM4tGu6PwOhGaP8lJLW7o
a8Gk1iWZgSUOcvTC2EyPDjzK/HSYkcVGVXe8mvqxF/jId/1BtzSB3hjHwlK1
B2XFM0OR9H8Gxskf/43owfVu8fklXZrP2b0ONvuiYOga9KPgOYJ+JTXN5IZB
PD7rNN/eNoI5kzjm2vJ+KBs1PvB+yQFn9Yxp6d4+jGvImgTFUFhhSMhOxw5i
5kKOD5/jezgpnZtR0azHjoIyVgGd5+NxB19f+dQJqUk9eZkONpSdgt6MJHdg
b+nWwfAECrlOOeyv452IZDAcdS1GoGdt36Z3vw6rnfOPXmUS7EuVWCOwUoHD
dixPdU2CJMME/aXcfhw5dH4h/SwbPgyT4v7pXujppTlc1+Zg/UJR0ZGTXdh3
4Htp+iBBjjN3mmZnD5QjLcjbYjbEV77vy6zsxXGhAz7ywQSb6sPuJp5sg9Pu
8ybqFIU/r7lvqXkxAP/Xmbsdt7LgFDggI1fRic+Tjvd2biMoGp5OeXgpFrHp
qsxZcwLz98rPJhJSYHxhZKGT9of3h2FnnqRKdK0aX06i+WoPF8ypZJXCe4N7
0go9r8rKNThnu19iMLrl373iBB91n/+VHtQJF6FmW5FmCjsiU/ivmrXAyi6V
a9GUwFu/P0OdXQ7rVw5HzZXofKjHz1zblYGX+vE+DnReuXYbq0aIZoHpzGpa
Rb9nWb+xYz/NwazX8rZGmo9Xm3MJh7sD3jVbR90uUigQdXMREWjGfEjBSck+
CmYKfsItS1UwstohduZPet895NUc8x0Gb2Xh1renOQjqUDz33L8BJyIkDv+m
QfC3ZuWOyOx2SHzeOhFCz2PWgJ83970KXNCWPmhOz6v9DmdGksYHsMHvGE+d
Dwv9UQ2Ll5hRIBWWWwLpfeZ5dSFWSSILp/iqngTT+Y6w32NUW9aH12YXZO8N
cjChXSB3+8kgDJJCn9s9J6gsCxVVLq6GDd+XwCBngrD31ms+17+Bwezddade
0fvEaFLRcDIVrZb/rGj/QTB/7hVrdroG36VYmyxnKYwuWcdEetfh5UNr3idj
FEr0qDrt7mrEGg0b5C1RUGrc7HzGqwZSv/4W4vqVglUpiWb+U41enzltudt0
f3ves+rV6YG4S1rksYb3eHTVsyWim8bvm7P77EXPj4OnfpH7oxP6sQsDQzs5
yKi4w5Q99RJs5chYJ3o//g+skdCx
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns8lOkfHXbb2qVyjy6oFKHcitalk1RWbBfRijCuu2UrRLSR3FatxKKY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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 143->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lVkYxxFpZaKalAmjUhG3VKPIL1OKUhNuUcoo2ZeyRZZCsmeukm2y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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4lf0bp9TbHshIpERC8hbR0AcpI2VlJSsjKbJSQkmRRGVUFCLrVETI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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs41VkbNRW5hZRy6QujiVLGyEHCikEm11SjDFK5flQ0I5ehGJcQpSgS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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41Wkbx8XblCwhkaXSlKIkhUL0RRmyNZahGTJkiyJKE2oQyZIIJUZJ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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 144->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk81dkbx29lJkl7MTUtaqQQSmpaJh/8pM1wa0gZZCxjSbaICVkqDArV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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lf0fxumREe1SSZRIqWRFZVySItIiFYqGkaysh0hmFDKSlZCMlhFC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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81VkbR6hIKEODUTeyjYzJkpAv2mw1qCZNluxaBlmiSEqytFqSoYwa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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk81Vkfx02W7hRZCq0TpUi25tGG8bFVKpXsyVzakK1LWSpT0qBk7GtG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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 145->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lWkbPl86kmVSEqEo31SjKEujQlfS6JgWS6LFRJYc+mT5+tFIjZQs
FaIpu0yi+UiKoqzHfixxzrF1SDqe9zhtqKaipnzP/PH+3j/e536v+77u67qe
ZZ6BTj6zWCzWVfr8804y3RK/PKIb3Hsjaik3CDzWrvHd51qJ7uCi/xkEEsTE
udW/6erCp5Cxs/uaCWbLzHl30A7Hv6wVtmQRdDTce3g0tA0n1ym6bk4gIJqd
/nkeQoRWmObrSAgkuYbsFVMliNhQzCbeBN4qZQZzD9RBFqYja/ovAV/wvP6A
VTc42qOsqxkEGuntUVF9T7AnMiGvV5vByHi1f4C1CE0ZHNPnTwlqiER1/HQD
mtXY716FE6R6VbhuKSmH5e6DIc1cguMlc6L4Vzpwv03Rqv1PAj0bpSAEtOLU
vptFGpcIzKw9X1015MFEo16LTeuH340t+0t+AC1rS+r8FjKIjGtcMSjkoTD5
nbF6EMEJDf16udZHyJ93ZOpXf3q+zLlsvL4Dytmvtdf+QSAT7n1v1T+IK047
r3rZMBD6vLEzCxfgJCtxmXolQdf0H9eCF/TA/7piSBLlY3Tzz0NOQUIMfTYv
ucAnqHOzb7VZVIr9X4u3FhwhGEkIfiWsKUfwaZfDNyhepC139c2P/wVZEf6j
uTvBACuZy71dAfaTAvzkR/FVgs1O6tai2K/LwjyYYIvcsIOkqgOZfY3Vu64Q
tDrUD7oUJWHYUikhgtZ7x9ulm9WKwY7vctTxZrDoo26u7mQ3jI9cPCvmEbCe
u7Xlaxdjs+8y61gvgh5ZS+FfM3w4R+YYjOYR7JyQ687lN0O8uYvlcp7251zB
699/HUNl63WdPSi/pjEjJsVPcbD+hbZHPuXzF3PHJS+TULp0yPcExd82W+3o
esMKTHmesj1P53vlejIoYLoW5LKCkyPlWxaR/E5pHg9FL2tqQ04RJDlYaXmN
CeGWr+cWJ6X7qFTrWqr2Jx5OjU3/y5PAZOa2OPSrEDWftje8eE7QvVbOS2MW
Dwc8nD9G/ErQd+ZV6rkbQrSxpjvLZzOo8RpZeeaQGDv56rNU0hgMffqmOV+J
B8VTDw5WhRAUqwRttDErRfu1Ts4vVK+xF2DcUFsNV/1LSqIAup9tiwpqbB/C
9Fe5Sg7tP4gzenunaivmjG8qy02k38smonp2VyPbZuaoOf2fsibPfW9rEyYt
y682hVF/KLZYvhkQYatpe8na95Svs3tqNN/wwIo5/mWG9jtyXlp0tLAON0qL
Vv7jj2OVH68lZAigcEQxbX8H5e9lpeBZTjM0vn7ReXCc6nsGN+95FmNsRi/1
CeVD9Zf8nug5TxCb6m04Sf2SPbG/SbDuPtRaYvyyqb6O+LlkbeWLIAhr6+WI
6PmaDONehWbc+s6vwTGagLuRpbTHqANZd1Xc1bIJKvQTL8W7tSMl7eAVt2oC
I/PCVWcXCJCi/nWX6m2C/HZT/u5eHoIv8968pfpbEpnpOd+zC9Gb3lttryeY
SlTgSu1KIVV6NtpB8Rf661rpGXfhTrnIPZr+P9ZjebiM1wGFkxv1PpVSfTpF
HeS4COD+H7fqoi6CddMXDT0Ol0Jyx0Hdi9ZfXyCvPPg+B76RtRvXUL0lcRNN
trK78AeZWBaRSef5W8NIrNsP3hsDvX0GDDaUtA9Yvu5Et27t0wXU/1Kf3350
Zotg5Jg9nN1NIC7//tZDdR4Of4jI8qL72Zl34Z7YXATpzYgcq2GCf+/SZ+cc
4WPr4aK/L6TQfhqetZSWlWLPzclqDV+CMhUj9/ApPiJjYlb6XKbzqW3Zb75L
gJcfSqY33CFwEO2U01leA3lWW9g5yo8kdN7vrSdE6LfYVGM9SlD1pcR1t0Ib
mjQvKpyg9RyloSW6Pl0wKL9VGEb5mLAPS10tqYZBxSObRKqnkVDm2vnuDgyw
Pzedov5W1TPaHjAuxBxWdgBkVI9pGXNXPc6Fv833g9GUn3Dx57m3k0SQXJP2
1VM8zmuXeYuc+Tg+ULR8VjrBponIyTCaR+3nptNH2+n8UmFW7ASdd/6UApvu
R0HRMOKbuB6Bq8fUz52k+GqXrf3za3Haxj0+jfbzQ4IOURV2olaT55RcRPNn
jvs68f5CXFl//4e3VI8b7BazdXyGYfu5blyjisFxjdmB34cPovWi4oxFHAPV
RXVPN/IHENR23nIkkgF39uuxjBg+vnhJ7qwoIHCrlPplz+/H8V2clCpjBnUG
LcmLN0ZCS89DZE3zZNXkNvlnNmKwumN/r+UxiBWm90e59oHLDv1pzTeal4Gq
8QpOj7F0qbywKI2g5Lnh66Xluai5aOncSPlpfN8bv8S2F58XfLi/14RBwPaV
OUmSbowr5XJsHxPs8a26HtgvwIH6rL0dLwkKnF1eJpuWQVqQPMZQPbKEt/du
j2yFrezGYm3qnwq/lYGGdbVIypt0CKD+3SI6Nz7xKZPqYJuLGsWbuisxSCxt
wPglucTsUNpP3XWjJfn9KF44V0fZnsF3xEem7NOH7L1LR4flGDxQU+/X+SqA
xbyFFrJyWn/IrWGHRw9ksodus7UYHPqkLC7hDMPBq7VRksqAFeXNP2N9F5KU
t9yHNL+TDp3xWt1RjEOPuTrjdB8rXPQK+dFCpG469r6tj+q3xadOQ9oGk7fa
kne59L54ESdYpXcXi1sCq3pp/k3zdvB9bg4i8YPyhZ4o6if3nKfS9Fa8uKs5
o0X9dH0Hv/locCkejWbFmfoQ/L3YKPzWQDOGKkyOWpyh8xcFJth9zkNEqvyz
4MP0fKOPMMS+Dwuib/B/28BgeUB+7O7LT9Ba2xwhzWNw716cmcoTATQ9Zp0Y
eUSwcixA3LNWgJBZr4obOwmejyuLTmu1YJ3Y/q4cvX843pxvbZwO1PsqhXPp
fhF+7OzlNX1wZCTfzWczGBBqlE381oX8nvCyEcpfVYVt547MPgTvNi6w02dg
YVcrsTfuQ96LQRl3DYOtbf6r5ab6Ya//M8m0YjCZ/EV6LqMfP1gu8jCcT/Xa
n6l1Nf0BDu/rlfxI798hX51NZtwa9PWv0lekeZwt33xJPWUAD47Zrk87xOD/
4WTF5g==
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk4VO0fxklFklTqVSmytSmSslW3JC32JbSQfWtBIUWWqLwtlGSJVJIs
JbJPyDIhBjPWMfaZM2NJKll6Uf3O769zPdc1y3Oec9/393OfTQ6eZs4L+Pj4
bPn5+P5/pYZeC10VRMP47Rlh4ykC8a9jwk5cZODQpwtiDg0cfPtwrezV2xbE
uwnf/TnBRkKG/JRWQAcELPLe5fhzIbrFZU2qRSdCfTlx4xFszBXczjwuS4dd
JONX3yo2+DzyrFe/bIXew/ErdXt4qNg5aZsgVYnOuAYvw9tseMVoPURcHZ4V
Kh63V+fi4dJHrTGUctzZI+uvG8iFuL2u2jYmE6MWcvWRPkNQDg7iafg2QWbW
Rys7gYOIWdv5+Ak6RJSa7yqd5eGAWpsi5VAlMtcRT1zqCPC5tDnGuGtBmZXE
r3GWwJazGwS7Q9ux/rKplVHvIPwD9wlEbs7GrayN9hfyCaiH0C6xKSzEL/Be
pNNEYF+0wGS4+XvIbFe21KJwkKlVcenfI53Y6eQXX2FI3l8HlVK09QQkr/12
/mtLQHFRlY3H6AfE7ud/OrKYC/Wyi+06qfk4/O3YgYVfyP3c73NJKndC8UOt
YBb5ebln8p5M7zb8N2u+ebUBD5yEK4Zbl2SDprP7WPR9Aq51KW/EpjpRsuf7
G5+HHLRZB+sryXahTY3xZXsZF1PKLh8NZ9vQdR2diVQungcdcL33tgkv4FB/
3IQLa8UbjSItTFyUe767QmoE0nGfJ8vCb8DklFuYGPn/FrdjB8N9apEmuTbq
byyBPxVeTXdPMqDX8HP7cV1yv7PmvTvychE2WGxGDyYg+bFnW/imTljMxerV
3uIiLZ6WX2LMwOK2/+6vfMzGpLlr7C6CgQM2LWorewdgUp5YJjL0HL7f7EoF
TQkItTuEb1/RCm2Fnndu+zgYw2GrQw87cU9s35i5NQ8DG87/imh8gVhB7SOq
fgS6Yt6Fbp7vxsHRmnfMyD68FPK9v3aeBVf62TNvyjkIsTCp8BNvwqZDF313
mPFAG3IKV97VhnOX7DyV+QkMzZilr93LwNtGP+lLfwZxxmBtSeZuFl59c2h7
vnUAIec6jYqmqlE4JzpapErARPBS2FKNRqRuLmImXOBgYLtUjFxwHErndY0u
XyLg9SvDg11RgnU+IWVpqQSU05ZRrMzoOGu4cUR/FQ/09A2thevzYPiCEOFW
EXD6u5vfiluPzxKq9zTFOZhpdakZ12FCYqvFmolPBAjfbZUTg10I2rCRHRM4
graaC2v8GioRFiUkQxPhwixENakmuRv05OyyA8E94IsgEuBIR6lUnW0kl4C/
/D3V6cdUVG54+uRjExcx2oep28+8wegVCW7EZvL5SSjqdwnl46fN0SsuTRxc
9KgWYhrUYmV49ktz0s9bInqn8K4RWR4Ckd0PeTg9OXjcJqAF/ju0YBJI6m1e
dbOfRSFiZC0Le5wJRKhdUe9wz8ea3+LvC5MJPO/2Txoyeo0+t7O3rh8kz+Oq
jnxF1FsI/ZmlOIWSfqMJ279zyseXZqt1h84RqDgZGbp6Xy4UQ7tDEivItTsn
N5WvE+mFi1O6KKT+5r0vfIxuQMidCbvXlwYR8lly496TbbhHBHHT/xA4Hy3W
rXq5HuO1g6c28gjEDF0491HmA7oFsiskSH+1pPul/rRLQenCzE/nAsn9ai++
Hl9SBsnV9/X0JbmQJGQzuBEN0Db8YKxqzwHfDjvDSKnH8LlysmPuPIHWsa2O
Uu5tpF6nf+/6OYo3ST4Hru9vRGDAVJXzBQJH9x1UL9ViQbvZUbafzkVLV1uf
+CE6Fu63lbN7Q+q5Kcy6ZSUD5+vHdtyU5eIaH9tp1wkWrJ9+G9igz4NCZ3qG
aEI9AtwJ5jdxLnxshh26OTSM1k1W6ufz4F1cy/xb1QXmn+Io9ocRcPJSTSKX
toF/y7LfSYsISB+wd4kIToZLe629AOmP/FOBr+anuzG66voIQ2kIhQFtflYR
laB4lDgGKHIhrbDm2rmefPBKE1ofeBPwVCj48yCOhvrpn0KOZRyYxNLHQ0zz
IH7R9N+tJQS4Cw6MnpmtBGEUlfzwNAfiiVuH4t/XQUcxsnfsPhvaNuJL1yV1
QgN/77j0jCDe9MaFV9NvoHlke172EwKd7gd3K3iR+VmzZV852FirLXvu2Z5+
fA1JfKe8vhfldz/EWdFbEa2yRGFumNTrypIYCfUaHBihaG1jERjL23djJrIO
Ct5PhU1ecBGqYNXU9bUarXnxyk4bSb355HuGzrTginiguKEUmRcOTKKQy4Se
UN6zfCUCLzwvj38u7ESksXe1CI2LEPqlJcatxWjyS7JwV+FCU6M/fD63FQ5i
0bIjfmReuS26+mdlF4pNxT/t8hxE/HX3yPp4Bh5tPR2TWcjBeDR/rsvjVtAu
91roqPHwXOrE/KBMFgwK1FoszQjMyj3VSFYrR9y1xL0sdQLm+mG9tz8zsEjt
yL3fSVxQv5fe8i1nwe/6b85O9RGkgzrubPsBi5Ryb7mT+a7zIlpYwKcal4z/
07yvyUOSmF3A3O4KWAnMHvEtI7AM7/9MPWmHT+R/C5NDuNgldvlaH0FDqWR0
nGcWOa+XVWjFMBmYlFItX/FoEAOrC9RNjz/BLEPsh40hgTUpKrtmytqR3+f/
+sJyHgLHMv5Z0s7A8iVFT2QiuDAp0FBv35iL51fS3G99JXDCVV790LEOuL3q
YfES2VCWNLURfduIKqpzxkJRAnXXlH+FrynCn1ynTYWkvw2W3N+UsJgK6onq
nB5XNqivtjputm1Ax2GjeQE7Nl63r1+TeZKOOEnD3Vv2EVgemns6ZWstFh7S
N1Z7wcFOP9cBM0Ytivv3yF1WIefhvwJ7LNaQ+mculrGX5+CfiYkvKZUNSDFY
sf95KRfDtxMf2tQ1grva79ipuzzknD72cjalGGIMeYmpFwRoWfnTgyOfUOB7
YDgygAtVkQ6ZpS+pmOvdev84uf87GSFxfQ2t6G80rakL/QIx28uitwOrEJnj
KBwoS8Cwgcec6P8Er7GwdEFVkk/Cvhgmlj7H1/o13lHuBKhLVbZfyuxB07+1
qfNBXyEtfPfPmeJq/DxGYUU6cOE6dvkwrbwF5p99DI3iOFDwX3KQwytFoXxL
RIgdgVSHWSkDzUIMNDrOBXuQ5xl+5dQJ9VycEqNSA4wJ3MuRlbo7VQnhlrzf
vj5kflee9L42H4TNsV1nukl+uduzvemcZxtEXq3vuKs0AHq361rnAhYCv41Q
rpD51Sk1Pv7kQS2Gd3v92GlBoOPg9XX6Pq3oqxe0LPAfQH2M43KvbjrmJ9KE
bogMgrbtHiVrcyOCIoZZ7UpsSB89vCSsJwu3NncM7XAg4KaqJPIz6xMEecyF
suT8DzZM8L9xrBOU5T9WFLuQ+Rmub8EI+hcPvovS/U8RUDB7tmLFciYiqhdd
1InjQfvTg9b2vC789cyOq2vnok51MdXlKg0CUYHWMxfYoEcbXi0k533R1+gE
82MErL2nBfuvMsD2NTz6SngIioyJHxHCTBgFHso1Te7DmUi7P72kX5LKA36t
W0vAb+jfFn7nPoTsizVg65D+NF0sqLWxFO2J+p8NbxO4HlStULiiEtIyiQ9U
lAmsyzYYU+BvhIn0SnlDPw6svgZ6HefkglCx19TeT+ZLU1HU7X/cEX92u/l6
8rwNslqqS1PpmF1gHHvMkguKIK2tZIgJesJhHV3yanE6qjtoMx3nRjSya84Q
oJfYjaUkpOL6+EvXIV9yvnmcy+03oKItSUHw+ywH9Y2P5FcOtOKZPWVp9f95
0Mtnfta2Bccjjs/R+wbQXrrXbVtNJySWWOmLRRDQKw8YDmAxYKtGmXh9mvSH
uLK18r1KxBWFm2eT+dCnuCyitpeFdQbGj29GMdH1+nWinHcBTPiEdUfmOXA4
P5qx410r0u28jFaR+W1HNyvjjJG8du+px9YpHopzb129r5IC549aD9NDCAwM
+XVmHmWAOXjvR1zRICLc9bb4DDNgUf27r0l7CBl6SWYH2nogcNK4+cYpkh+k
3jY1vKLC7Xr1IcUaAm/m+2f4qloxHNHbYpfIRYIUU7fYuAulb8QpfBVsCBv1
qRz+0Y3C7OzQ0rBB6LaaaC9Y3owq3a622DOk/vR+ssJrn2D9jEw5YUTg+zO/
fUsF3sOoRF+DQt6/9BPDQ5SP77Gz4nCpOPl8JCVuKXl40SAdX2UZeYaDg37U
bA31TvxRDX8fuGcYlKvUV6zFnxE7Hr/gDNlXrCmW04YjdZD8LFT0w5FA/a+9
jleKWmG9P/30CPn978POVnaL6rD3jqasbz0Xylmqrcf7cmBCTFayXhP4+zjt
jl53C7KLGJrr7gxCeW186uCjDoS259k53GUjf2UxYbO3HaVGrRqGsjwknH6w
M7CuFSbnP5vmkPxIs94qNZXWhCfjRjLLWwlIWRskCIY1oYKyKMlblwOzGaHv
AkIMELJrbrsWkPzSpxsbk1mHAQo/taKXjRDv9Wsmbeuhes4264gegavLNoZU
bOjAnJ3xzq6eQXTMaMrujKNjU1Pio31kPwmxTFHqnfVDSPSV3hJ7Aj2VRSd3
2NSCecpOUuE6yY8OSytyF72HzlPJJD0NAgLld12rZVnY8rQuNEN+FF4X126S
My5D8s+3+gEkr6rcmeK7W1WNLwWdJQ0rCNyYtbiYcbALG27lstoNucgzGI/b
JFSHFcfU9nwl+5d/tax2RDYFeYWX/hlfRWDEhG/VNls6+tOe371K5lVm6PSX
9AV0CK7fs/DD7SGwuTrUv/wMPDjddGlLBQfqv4JelTILUPp4k9MXYQLDf48u
pU3koT5WRT5lB9nPxG4nL8tuhZ+Bn8ASWw6czN3qP6hVIcJ55EZEJQdvlEUs
bkoy0S2r6WtoM4jG74+LEzqb0SbIt7iJ7LfDlMYlBZ6pGPkZ9uT//SQ1+Enz
Ny0GnrIGPDnfSd4Ja9id+uQ+JFK2r+iyJO9X3iTix/sefF8s/lM0fQy/biml
B//DgvtAf0veaDd+mQVq65h+wMjnxMV+XeTvB1LbFMIq8PiE4DPfQwTaLh+J
Sip/B1H+PU5PSH86ed+slS2sRNtZ+4Ou1zg4Uzs2GW3Zh31jb6tmbbvRyrKo
516pxd6/RZes59lwOvExomE2F04WkY+ebiPzxVzZ44ZHB5QpRjlPSZ47eifx
0Yn5HBiVhc9MPCQwuazFRKKJilNml6W/cEhedhhpScutQHbkseCmJ6TeLbfV
R+0vh6vC5Sj6OAc+lrVHLSyYULR0dVMX4mEyQsoh52ADMoJUNrzfy0O94vjL
Vo9KZFgx7kUnsEExYP+gK9NB0zr9u5LknQeFFSv4DLpxRFKjzj54FIVfOWWh
aEL35C+tO/Y8xFSebf/8uRE+AvV5UgzyfKt0l8120CADKdHhYQ6UNnp9M/Hp
gZH6571ckp9TvR/oc+MaQFuY1RhD+n+h0sENRrnlKO5Rvb1gioM0CYMcy6c0
mH2iqRRuIvt7s/RCqekK8AmUe7LCCIQsMpWt4cag/B+h2uduBLRH+yYfTFBQ
mmobrPeLA7FPy/RCaijgcCsKNUg9fveoHDzdUwI3iw0NJfxcfFCkdQyqdeNs
zlLxvmRy7nuIDv6gdCCWUZ9bwWGjcK1cmmVyO2RkpOTEzg/g1zeJrNUJRbAR
/iETPUruh984MKCzBBKJ8jXj5Pn/eRC4qOvfdsy+WO+eIjeMO+eWnxe+/B6Z
cdOcc17kfqszfq+UTMCEV1j0arKfK3srWr2ZaMSdxJc5/Ht4ONlSQPNObkPk
zIOr85uHoPrrUO1IeBvGzuqfiK7iYuBdhXzitiooTCf+dhnkYMsjxrP3zs0Y
UB2oKg9igy/s+o7+wmwc8Dqm8PgvOb9zeI7zzZoI/0AblyPzNHNk367EACoW
aGy32/OWi3sdnhaiw3RYPPQLOuo6hC2FqxRXDZDzL+8EQ1mKQIqhTGbm61oE
Vmnz9a/hgcpZJvv9YB36iEzBty0kr2Wxky+SfXvMRErPatcI9v74fdVoAw0V
A1Rl4+XkfHAwmKmt74bmn6vhKalc+N9cZ1dfUo5Rd6lfxmNkH4ntt4/7Gw1F
TeMVe/7/vsJaLMmV5JeUvBd/v1/g4cGJNEEX13ZwZ596WtF4ZK80O7fTpAOW
/acNr45yEf83dsjoLAW5ojfuXCb72cHj5TP78ypBr1mpS9MlIHGJ/jLhn1pI
ys6p6ZJ9Wy9omW+PUCdYJe/iTy1lgrt1zveeZTtElAqnQn2GoR1caqVy8w0o
ctfEj6sSMP6PX933wgccO/Z14UIBss87fbnK1ayDQ3zgl7OkPu3cpyVHTj3H
LQchtQsk3zG7Pd2PNLyHyOwL3R0kL4VMuG39J/o51hUaupV5kmtz0U3vPN9C
1aXcN4bkrYuiQ5/HtbpQ9TytXuIRgcJh6S9eEiyklbAYzNZBCK2VPTLXXIpT
1Y4hj8wJmFjEna6MqIPfxFvBHFMeRExrRcUfNeLgvtpbMR5D6DHc8jpjmon5
ZGeZyZu9eC1L107Q68L9Xc4UhzAm5DJGpB0/sUD7sFnfVHQImmvnD6UNt2Cf
2zOVZpLHepL5q2+WlaPDTeeOKpXAaI9jtHFZJ35rPtx0JXMIg1rlfweFmHB+
H52VfpuDa/ZzUafnWXD7XnlIVJgNxfgaiQumTMi2OE0Miw1hp9B+W3/fNiiK
GBWLVAxjUMp0z4vqDuQ7x3lL/TeMcpOxwTTfVvj3FhG3NAmkZ2dkrW+mg7o9
oLiezKMzO+v6K2xrYT32MGEH6Q/J5PauoJBq9Cj5vBXpJPW90XpG5F4wDkdW
2do6kXzWqV38WLkAbxwmq8V/ECjrfVx+9wULKfMc7UVfB7DwzN3ZtDkqHhrw
/1DdTPaHo7/oOdV0eMk0nyw3GoKTgjr/UHslRp3cBYSbOfAKWWHC6mciZ879
7fgNNs5P5xcxvlAhbjD44CvZR187HZAwEGhFDbVu+2txNi7K2/zRme4EX+vU
ahUNkncurf6puCAB9DD/LdonSR7ktWxyvhgFmxAfaen/rz3aFkYdP49C83fa
PqQ/mQ6KHhf06OD//l9WozcbJzbINDPzq5F93MZi42Eu5NasOgrLRhS8OLbz
DtnH/geeCiYs
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81VkYxsVMpJuYaVFRsiuRUiTTo1IjmghTEipLGQklVKgsg0p9MlEN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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk41dkfx1FRaNMyKiMik9JkptSthreLZJCliSGVvSlzRTU/ZV9qUEzJ
OjGSaKxFlqyjGxqyXhfXdtW93++XrFkGt3Sr37c/znOe83zO85z355zP+/U5
qi5ex92lJCQkEunxZb5oP1h64NdOfHIMLxk6QkFlt+w/4VFsPEopSI9XpeD2
x2N89B4Aw/plUeKK18g3ve7tE1QO37iDzQFMCtOc8cUktULs21B50SGQgl1V
er2V8zNo6HGPpQ2SGLylGvxZh425bMZD3+8pvNskitbzaUW41bkK8wQC0cbj
PzBL+Bgbz80/vodAJGujXYBrMzYXUllv40mctfYdX0524m2mtcjvAgEl/hWt
Cx7dOHh+hLicKITUXhu2uKwTXv6E0BcUOKbJFwOZTTB1nYb7Egoh9h2Ldyae
Q6Q6Z/h5mETP7HQJ/2Y7uBFtPzMTSbTI8hJ813Mgmx4Q+ViOxH1X3bOytW0w
S6Pm92QQ2KFiqzC/6iEevnF8OOFOQUypt1h4NGFf1ks7UQgJ7epXadmzHTDR
UiAf1Aih0fjfqxvMXpxM682960kg7Hzkt/rOHHTYMIZ27B3CroVtRjnzHMz3
mDew+ATmiqpemBxrwKxRWNBaCwoKE5Lb8LgWLyq+sxHvoWDSq2F0VdyBTQ1+
b7ZJk0i20ZqcCe9FVfNXC5IrCcQX811YvA4UMfW5pYcJGH50nWw8UwHzX1KF
PuoUXNoVVGPAwcIOrwrP2yRMLA/JsyOf4Wqr8Z7w3RTkRY1jMcsa4G4Qt1uh
nsQl++CciEEejn1VpRuTLYDOYecapn0zlFeppW7UpcAwUh88XVUHRm2OkSCX
gsxYxhLrOB5aLgZYuH1NQGL0VlbbbBLO6qcd+saRgnru2OUE3z68FOnM5FkL
8E4tOnlLbA4U7x1t6KTjMbf1ku/k14KyVggboPWp1F5xiHJ4hMj36Qxpewpa
w1MXJBv+hlv7NMvMlsI+RcWqDwM9YA+dnGtmkmDb/PWbYNk96OWOJhTT+4uN
d0qbhnVg0N8pVPMsiVOhGxs+WTbASQMfIltIvPo1U8D6joMTUU2Lgf0UzJm3
U1jiegQ26DGmpeh6nkvhOt8tgGKe80y3JgVDv/7nqyv78LhXZrnNBgGWfN8V
yrvOw/683PE7VkJY9Q+6xS/LQliK47qPdrTeNaultna1oaayI7feg8Kl7Q/n
GVubwJGM2p3TTiJGJqIgraQJI+s+76sMJKEY19YeZNqO+hl/5TPNBCoc/9EO
8uJgOE++KfQ5Aca/9dovMv9GpGipHfRpfcu6ShoPd8Gef2RkzIPECctWGYUb
jzCnFDVR7U+hJf3ehqj8VkTI6wau+3K/xN+JuSsykWRqMn3XmgJ7rLHF/SYP
l7utb4eGCSEe3poi2MvD77k7+l6EEGgMq3DYN9UEBrFgIfWIhBPjgKZfWyv0
NyXvLX5GYkeayr9ul6uhXn8tpnctherJ9tCwkAZMP+1YZ1JI4qqXwLsonQeu
/8q4IW8C2VNmsUtO1kBUqarZcZWC0plaps3zZ/h5Ln1rwSoKEhyIXYz5iF01
2itivQY7uFDdp7IaLceG5JREJDJn7QyqyguRvctDPiiEgr7qDPf98QzsN6xe
dHCm/Z1r7n/s1iXEqOQ9eUDn2/t1t6nct//iFuvhhgdltL+DlJ9GG7VivXmp
lcEBEhcuWBlOtbZB9ormR4VpAmZ+HocEhxsx+zYvMfEN7Y8ZzfkXSh04HzoQ
7WZJ4rfCO6HzXvdx9EcLjXn6vPXE0VNudjwM6GjHGs0JYTOyhtl7jANLQ6cM
vixdvzortUV3LmON9NoVBl/0TFf6sBz4sJ3SHtav4UPfd8WwOv8aijKNJ9zp
uKhV+MTMvxM+R8I79UwpFMaGuEQv8NH1/uTa8rIBJG1kpf+vYABLnRNKht1e
YyRJGB1j0wH3IObS/4JJJK7PcXfJ7EPyfFv/JmshnH4an9jvGovAKm5F8hn6
/Znv9PUSuPhhA7i31hM4JzlZXr4yC5fibVnSX/IRuOQucluQE3/fs1CKRGRW
7VNPVgXqEPwfw4bmtbhMqpSbj943PeetPClMeg/YK23pQUEa9eZdNu2//gzH
VLUsVESEymyn+bjE6/r9viuNiOk4vEk9g+bjx3Jnm9hGfLJl1tt8JiC24Pw0
5t+OLT0pRlOrSUwvtjtl+DUic8Q2yDWJgmLmNnbsrmKwtt2o9NOg1wI/zdb+
TiwsXbgeVyhEya1TuiWjHNyTvykj60IgYGrWwrWWi8DZ9euyJAiMWipJJKp2
oGw8I5XZRWGCYSjXH1OJ0aj01LN0fzD62ewKSmqR6PpPVEY0CeOg9AwXh6dw
/tW1XkD7101QsHbYm49MNnH+yQM+QtYZbB/WiYRmXqJuuxOFP6t2rZ468QTn
Ni8O7o+gcL77nduidzNu3u+W5bApBGQObzDY24SDH4o2Hn1NotQqYiDneSPa
5WpX2NN8U0412Bym3AC9Kd3vYs0p1CePhcyeboRV2fuce0kk+s8kR6y8wUe+
pHqzvpEAtZVOR5bu78Y2FVklTzuarwVVBtaruBg4J86PEAgRUvR1ZvWjCMxf
M2fGn/7Crw+Tsqpl8FdNuWSyk/b7p7w9WtEN2Fsq1cWsJJCfLHSbmX6B+W7n
pLEuAk5yn+L2ieugE26YuUSLwgMJnps2qx9vNZB0VUGAndLZdnUanaifSDj7
YyOBFsFolDVZjICDwjyzXyicOLQoPmXfjw/JdXKlxa+hH6LcLFeYgQkLPZ3n
lvR/wtibn2jYim8Yh6Kd5wgw3Xpdpd+1QLNdzVHtTwoWqX9MpBv14CdVHLxt
LgT1oKDkkWc/sk/t/PTDhAB/HuSlTu7vgdWKG3oWYwIElw32KYgbMPbj7cNj
inQ/Os5ZfVe+D6xV6i5aa+j+QrzsrZGog9QHtQKFIRIhbAvp7Ht12KgicWfq
CYlzzn8tFxt3QqZnk4zkUhLqLFkWa64Z5Xwe924BzedCR5VI5WKM8GyDY2je
mv5uOFWUz4b/ALXScoKEvlftN18deILw3pqPa3xo/hSemQ726EN1kKboNEsI
7+yEmxq/sRG+OfLVli4S/wdD8dLK
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 146->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVWk8lWkfliJOZWqQJYnSiYoiRU1vVztJXhlRGFuIimSyhEqJscbEUShj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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VO8fxSU7lRAlW6IoW1JK6SAtdkm2VIoiSyW02FNKJW2SIqmkQrZk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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk41GsfxoeT5SBapKKy1cEb5eCUjLpJorQIZWkQGkcopo6otBwOLUp0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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41dkfxy0zo5QsLZYSNYqydM1QxtJbUmMpZOwRkZ1IQsuIFvk1hVEZ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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 147->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs0lekal9smhWYkKoWo5HShNJrkp9IUORgmkUQiEhU5llTjOqFSMqLk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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lf8bxmW1rUTJDEXJykjR1RQiktDSkFHZo1SKr4iMhpKUSlbTKKOM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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk8lGsbnnaKZEgpJSJSspQS1aUPHcophpNdNJEUWq1fURxCISJL2VJ2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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs81Gkbxkdaimz0InKsHErW6SVt4aImh6IsRS1ZNY7JqYRSEkqUEpoV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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 148->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk81dkbxy83GjTSJu1ESWkUTVT0yShpaBnlhrEvkSQ/kzWJtKksxUhK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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2cgVY0bp4QiUaneSkOyU+ovJH6RGRWykxVpqJAGSRKlQogykhJZ2bIy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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVns81NkbZlq3JLdySawkRG1KWf3E41JSuSxdXFaSdEGytElyrQxlk0pC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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41dkfx2+o24gWk1KDLJVlmgmRmHgzk3UqS0byy64myogouzuISaRF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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 149->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lWkbVlPjlCRlmRotlomRkbSZlAsj2YZIXyKSkIpkUnYJCWEkaw4O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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k8VG0bVtFGkSRKpUJaZN42W7mkksheWUJIklLqRVG28hZSSQoRRYuK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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81PkfxxHlzFkoGyrnjtCq1Na+KGG3IuXOFkKiMlEiyRGZJCGxHUon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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns8lOkbxlFRW6kUsUjaVoeRHHJI1sVSIacsEol1WNVatKRkd6lIVNY6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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 150->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk81ekXvpkSbZaIaUVlSXGRaiQPWvj4kZCikCxDJkWpRCLrCJHBtFCK
kcpYioapuMTlcm0Xl4us7xdtYtpD/d7++H6+f7znnM/znPOc5yi7Hbf1FGOx
WGn0+/Hnvzo9Y+VcgcsF76OX+BF0OY+Vd7HLIcspXep3jEDccMvEh6x2lH90
MZ/5jyDpLu+/P7Lzkffpdu0HN4LiPJZMaEgD1McffjsbQTAwq8DLG10Q0z+4
28aMgXGzdL9RaRdckpQNKlYwyL1qxtZ1aUKV22lnuVyC60qdi8ZiWjFyJ94k
UkjgwVX9eN69HuHR5xN0EwmULEIHZYq74aRWeMBGg0FS65CvmXkbCh/e47m+
Jbiht3TUlNODjA11RVJnGXjzEyVPfqpAoKnCvoqTBCVsC1n1Le1Yf+WkYGSM
gMUV9683TUTDobZ8/0MEE31vV/td68Kjusfryo0Z+HW7rJTRbgFHM7wjr5WA
M7qWlfwtG6WtgxqTrjTf0E/fx343fvqqe59N81uElvIpki34ejlYxf8BwXy3
Vcqi30RIdK3p1I1mINacE0VS27AmzpHLnyJ4EvaHjFxCLTwCbnz5GEtwx1Q9
z1WqFbquBjV9z2g/f86a0rWqg9PATN//4mi8vYlqjF0TnutmXy8vIPDu+67X
EfsQP6na24k8CSy84p9uYvXh73RjbvMog6oYMfEKlU6Yr4i4ekCHAcemKLQ6
PA3vNUI6Cihew8h9G565VGGRhXaK5xmCA+oB95MjuzDbXDbqphztb+wvMg06
mRjIaExXp3w5M18UpDqiER6zxMTmB98LEfmWp2tg9LvOR5MYgkd5pcs4tXXI
f8WWmTxH9ZHjXmmSmYEMf4uRpTQ/sLFCLKiuGtI3Vj0dpu850XuZQW4bHqb4
OjsOEMxM53ZGa3TjSa1VoPkfDFa6VzJZue2oEG0+veQ1xev88dqRoBZMXHz+
xv8uQd7yZQln3gkw5SYmST7R+V3nF1t9asaJSyZeAS0EW++kl+b4t+KlptXN
vx4TZDY8/+1j+z3c29h4V0T1OhGRKSFuIsBf/JUunE6C7FXev2S95uHyvOSl
SVcIxnnrd7/hVqJR3GjTjiCClYvWxbWu6oa6ltV39i0GqpvYk7UTnXjQk/kk
U4XqWX8yOaajHPcUFlqk0v2pN56eFykuwov5Y8WbrBkcXjD+PO1gJdgWk3vf
HSc4py3QC18uwiZNNZvMNQxKjcuLEw6WYq21Al/gTfnpjyn78p/hAavAd24w
gUnpogWOMSKE6bxL1trGwPVb7NeFs5PgF2SWHkznoeUVla8awUHi4PRVxp+g
/JCex8uxy0g7sHYwjr6bC4i9PN0/74qs2cSegUGR4EBabxWelh0yyAkhKPK1
jIxI5EJ28Lq7zEWCQWQ2zbzrxN7VZny5tQxYzZck1DTPoezP+aJttJ6Sr71w
Ij8b+lPn+YTOV0xYmR7a2gYj9vetLwhBdX5QScB2PnbENTWcKCWQ+M/N4qRb
IUKmJoXwIFi8offvNeKtqOrXNfr8D8F07C0sVClGQNGK6dBfqX6uXcrdF9sJ
9/1GoysPMBC/qbaVZyZEfZbHSKIhA5dT31Mv3KjHbtMvWu+uESxNHFN0L22H
QGpDislCBtWaRttU5zRju/w8n7N0H5etbvfnDzYhwa6z42ghwcjwVJVddB2G
FC33RiURKMqGV8dey4d3dkRZNdXHgM9hJeWtHMyzvqUhovtRK9fAWuzTgW9l
KpH/KjIIjJ7ylbjQjy8HJbu7to6g2Gm7u6u8EI1vuzye7mLQ+2pYVUW7D87O
rPm5qiOobrvi7Z0ugo+/pWJeOvXDV/25nLs9mDMcn+pRwUCJ82/g/sBsPJKs
3ddM+4nEl2UOS1qx6x/tyM9U7+MGKU0D8wR4abOAR2oIernJ3mF7OiFp98aj
XZLOxylsqKXmEcQG7DzPUv0sD97i8jZRiHOPgyxdd1I8lam3VaTrUccblY3J
IrAsV1PJHu2F8LGSxrAbg/S4R3OLFHswuTrjZBvFE5U2cnQ0sxuTEhV1ipUM
9IN6tMJedlFfZmm/oXrub6pLCJJ4DvWB4l0P+hmEITZKySUfbq7r+m+4E2xR
7peTvt4MvRmr7qh2AoeCvZYRjo2IX3Np1YM/CeTuis8tGqvEk42j6amnqb/1
yg+9D+hAx1Yza2VNBrdD7gy9fstDzm9e3Ml4giXTH0w9tXph5LWA10L1q6jl
ELVMqhDHPrsaJ1A9FV2b+22nrQimrkv0mVAGVjMD/CTrLvRuP7VieA+DPYzX
sVhRK2aad23+q57gfbP0qTl9zRg/7FitXEawR1jh+Gy6C8fidpibzlA/VG5K
63YXotO/LEl+gkDIKxuY/NCArOIuXtNlAtVb9p8c7guQXHrGUUFAkLszrPdr
hwiP4sYW83QZJK/fkR7j1wZjif3prDn0nkjbvbhyvgDXw29a76H9uXK1v0dP
rBE6Av6nvGLqn298nrsxAlQXWR1X41N9XuUOf+a0wYodX7qN4j0qQ/ay9LoR
qLYnLm8Dg/hZxRfs7LugccdzroMPA6mWBbyMgm7cP8EtPPk7gzs7NtdHvBRi
ZucJGzF1ui/57BVfNtag0Ifj0BxI8FA/apNhcxOyZTXfiudTP5Y17R9YLMR6
JlUDtgzY2bwXv/DT0WdpNkeX6nHXZoWAjQq1kHfqPJNL71WY9hYpyeAKHNNx
mvrhd/HGTkcdb7ZDhXux8f4sBhuNt2w71shDXWKPRnsGgd8J2d2zfFrQNHei
cZzykxsq2uYn14KAkuIjjkV0fw1sz9v+XI+fbi8v0KLxBqGGOuN/tuBMtl6I
QwmBjfYKldiZNuC1ffCiDlovZnbdzzXPINjoue49vSeukxP7jteV43bc4Vhb
6q+FJvFVHtJVYOlbDw5R/2aZi52aY8zCyLIe3x/32vhuhraDwU1wM9mluyi/
fZavVrJdeOCG58x6QP2PVVUSciTBFqFrvLg/4n9lWauxSzgYSbU6lUf5przr
TPd80wgzc5OxFIrP2PqixaXRLPSaFZGvtN57Q9kdwVOteLKwxE6b3qP/A6wL
xN4=
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2kgVA0XxylKUSlLJUVFScqaNvpnKZGiHknITipL1oQ2ochOUXkiyRYi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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk4VfkfxymPbcygQdRkTIMxyNK0mGjeKpRUSOqWGXv1oC6RbIVKWcqS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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk81Pkfx2crraMUUSNqHeVqW52OqFdp0zWErCKVI/1mWzasxlXIulIS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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 151->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lekbPsSYmqOMiUxMWcsMZUnSoFsLZRiZBoWRLWUsIUumBWGUbKfI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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k4VG8fRkhlS9ImJEoiUslWd1pU/zZJQpJ2ImSrUJZISZKtkiSRJUT2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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81VkYxm8oKklNU8pVlrIkjZSGyKNGRZmrmlJhbKkoS0mWJDL2EI1Q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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk4lekbJqJsiRCVtWUSOq4UJW4mhJAUbaOyNNkqMxRajLVB6TeDZF8S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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 152->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXlYjekbTtPQzAg/GhOpTiJZCmkh6S5r09CmfZMWklRDizYl2lSMUSkt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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k8VA0bRZJEIcRbIluIqFSUnJRKwpslyVbJ/maJbFEmKkuSJVIoJZWt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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lWkbx+1DvEIabWPfU2mqScivsaaOBlNIoRBGmyxDykihTZPRRiJL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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns4lOkbHjqQQw7ppMkKoZRDibal25ZQUtLJKSKhAyFFq50Qaqm2iJCK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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 153->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lWkbPlOjRWWylRMRsmSJdiWuFpMoUjGRSLJVpEUoCkVRQlkrCsUg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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3cg1e8fxRWJklRGkVlGm4zQOMgqlCKpyOxbaZCUkUqShGS1kJmyt5It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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk8ldkbv0qyZcvIEsWoSGIkyfY1iDJqLCnLLWsqQo29ITf1kygpW4rS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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns81NkfxmkliUiybuWSW3Z2N5Rtkx5Jyi4Ssi2lSSXZ6bKhNC+kXyqK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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 154->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4ldkX1mVm6GcodYZQLjFjdFPSKOrVjRJFqaQRHSSVSK6VQVLUISpE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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VO0fxifZSZQoeVHJUsqSeiW6JUW0oF5LL1FZi4pKKRJRKVlKIilF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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lWkfxsnSW6lMb5QaWxlLK5IkdVnKNkSyVfZUlmzFUCJlK8n+njFi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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns41GkbnpBazVohk1TrkByzorUSboRqY7NhnOWwnZV8H5JSEjkTmwg5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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 155->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8Vekfdo1pKEkZKSS0b2JCfpaeq/yQNspIElJJJUKWFMO9KUUqGqQ0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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VP8bhlWyhyxZUrZ2a1R8C492KUQRJSKkbCkprbaiLKGisqQVbdaQ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk0lVsfx89V5kOKupVZ45VcQ8XV0detK+NNplI411zEcjQSCQ2mMhSi
MjeoWxpMIZKcY+Y4hoMQ52xDrjQheXPf93n/eNZez1p77f3d+/f5fba6R6Cd
twiNRkujvv+PB9wjfhhE9cOv/fSGtkIh1jgtC7bk9UK55eD1cj0BJDItj8Gv
En704ALpQwQ55YlRT2JywFDIcdseQPB0g80EPfsFJjWPm5qdJEjy3WF1z64P
izNLx/7hENR9IZvzwtg4U+N9Z0ufEEmzDMsDAx2YXTVXvaeKINhFNKYttQ4c
zfdFDCuCbpVkxaqMEpSdOuALfYLJ7jeJo5xaMIWnffnU+vv9Wvd8+KkbtEKP
/TpzBA5z3Xc7+19jd2Vdv+gTIRjHDkpIL3bDPmG2VlRDiLx9ZjSthQ5Mz9ty
o1WFGF7BkUt35eLtzYyDs+cIDCslfFRiSsAN55cpUPuz8jvZN9x5EJRcWtI5
RtBrJeG4s6oEryfrImsVCQ4ttm1j1fKx4U9xkX+2C7C2sies41MdfG32d9wa
FWK/xUUjg98bYRDv0bxEncAt0ixESuQ1Ygt3bcjbTlCY/kDN/XEX1lqrCQd3
C6GW11LAzOqE3pfp5S9YBB7S784u5vIQKKlwszZeCKWw4yx7nefYwjqz5+pR
ar2SmDFZXhIm8zkXvrkQNN4yTzYLrkTcSqmWF+4E5vIVRy+MluIfpweMsj0E
wsnK/rTHPDSXbX3woV6AyGYZk8PL+2GRNX1p8dIIGHqCIxftOzFnnMpLbyDQ
oPX0TciyYVmXq+hXJ8TTvtr0d8wqtJw4GbTRlbovt2oTyXweDo2HrxWjC6Ao
c+VSyup2VAVl5ruGCmGrIDlVTu/DRmdVgePOERT8+53WnlmENtnb66PjCCRZ
E/fK3bvh7CDP99opwB3OyETmKy4M1/xyt12fqt9Sj28qZ7JRk3mL7uxM8EOJ
dVIyrgvqKadaLTIIrs/l2Ei95WKliwI39BmBiaFxaYfWZTDPaVW+oubXhOSr
N9gVIvRHatJrqr41UVqPOuyK4dQ9MXAohSBiy+mX8d+SQRyD57qZBEYaD1SX
venDSc/E+64zo3hUriC+uWoI2zzWXRZYCOFwhLf4tbgP5bFuvc5LCSZenM9N
ucpDy1HzY94XCG7qjlfTmnjgfGbLmiSMYrPKt875oQH8VW4R2OkkxI6BZ6+f
Px7ClkRzZ7HCQdASvz9amM3GWea6QX9bAqngSoknZwaR2X2ZPs4goNlY65tu
6IRaiLecoyzFq5PKqr9XVCPZoyY6WZNgLKY38OVpPqYSDmtc8xFiX1tApK5V
H6on/Z3m/UaQ7r8j96ygFSFfMrQz6AQpFfHkMfMNnNdb6NxwI1g0S/AXlWxE
wd7/ynyTJHgzOZ17Y5YP/yaxznMWAkSYsg8069ViKeO3VscIAsfwxY9B9H6w
Ep8dvn5DgAYxXsh4JxvVpSue3XUkkNhsOxGsV48Zi1D7AHmCBfeXmTKb+KiZ
WmNR0TYGk9RUkeWSxci1kmUWUPx+ajjhly37Fgz2eyvTRAH2uv+c1RzLg4Fc
blVCiQCFX1IfrvXuwtHGe1p0fwLbJdygVz/eImtv402tfwVQs1uRrMsowQDb
Slbbi+JDdSG5M78NOv2jHwXpBKVKEWHXjDrQtDzpHIMIMN+62Sf/5iskORjF
OU8RXLOuYCnL87BxU7u4HXMUA2sDYk78pxEKOO86VE/wYrBpeLt3Gorux6rU
U3zMhEcbPooswsPatLh6Ks+UeXL2c08eNN+Zig5GCXGYGfRfzfkBeF+r7T23
UoDpxOuB8txyXOE1bps3J9hkIj1Fl+mFpeS2/SZXR9Art7WpXPsNplerhin9
QvlSPEe3gFuKLSJK2ucpXnck6PZ0Sz7DbU8vlRXWVL+xP3kxaU+gVpkwLK1L
MGBuuW79wx5Ifb/7a6i/ELRgupv6+nJcSh72d6F41NxNTzU056LMMM76bIAQ
R1/5uFjKNeDIbm13jhgB3SaQ+/vHesRmJTkoaBE8UtJtfjnWDv7qx4Ncyu9q
auKb+Sb1iF/aZCFzjfKtqYTxXoN7aPlz7JadE8Vf+ZKWg61tKFB7z4qi/OOx
Ss5xnWQr3Ji2a5IoX9DyP1fpVcVC9q7v4gzlIyMVxXy3bR0oSlfr/Zvy8cw6
aTlno2ZM3WQXB5qPYqiHKR19g48+r8aQ9aYCCIZ/Mzzc3wvemYCPxi+o/N8P
/fuXTSUkpEZt3hkRNJQtIHxZM7p05MUUD1L+r8gLUj7djV/1Gzy/UffH0Eo+
GTVSj/HqJdbWMlQ9pThP9wx0Qce6dDbXV4jSlQZlr6tzEa8U4/3JnqAgSn+P
ZEA3An/+8dXlDeULiaWhTYVsPG+d0TmqR/1P01Z5MNj445ctGDlFUJx60dFI
rB367xx3TpYKMVn28euHKT5sQoNqwjkjMDQLVNWTbYAvr0NSJovqZ1O96dLh
C2hzyt0aQfE0NaofPUrlSwmtUtfWJvC8k7lR9wcXFX7V11XoQphi0x85Wg3I
Ky1RPOkpRE6Bl6ryeg6UpqK/PI+n+lG3yDjCqxf3tBbuNLcJkN7eFNV86g4O
nN4dxqTycSZz8hLSekB7l64dcJHKL2cb+pVbg6fLlJFYQdBk8ZPbZysONA0+
DGlQ742CqCvj7/sN0FrdGbjrCOULmvE95YZ6cNR7pud4QtQc/y0n174QE8fO
lnlQ/fsj530VTgwgbID9Utg/iAVHF9WKdj5SFfxa4SzEeIumjc+uZvx1QCPs
2DEC661NkU/cG+HgNRzCCifov14z9ymlF5EHWfd1gkYw66N0xE+2EZqx2eEm
9tR5H8weFhl+iDujhvwxP4LYisaHTXodqHY5L3a+juJxV2veZ7tOhM6U+65b
I0RuX1WZq/JbXPaZu0zvGsLtLhvWjVc80CIUsxWDqPOH78s0VGvFSjPxNHkJ
qt4XxmN2a/TD2qEgnbWTYF8VXdD9lI/5mjSr4rsE6Tv9DW7HFYG2gRVaSL0n
q1cyr2wSa4Tz/eMXxCl/6HHNPTMMOTBnz3z6KE7gdZWe8dCwFCIhyP7jBMWb
8a+7zoq24UpWsdNIM8H/AEuorEs=
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlmk81ekbxrXJiFKULUJSpMhEIi6EMbZDw1gyhUkmEUm2bB0VadE/Ii0o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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 156->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4lOkbRkSbalYTsiOVsqHDsp1QbpWSjT3oZGOdKscabBsqiZCUlUOY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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3cglf0bxikkRTIioaIiSsOs6JKoNJARCXmzehuiIRWlSVaK8KJSJDTI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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8Vfkbxy8ho5IrS2EaS0rS2Ic2H7RYRpNdNbKXSGoKU0woNAqNdtmy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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk41Wkbx71lkDmFhkx2KhpDRNL+VYYSqUzqqGPsOiFJlhZkeE22kWQZ
6uW0aGwhZKuRLNnlHMc+cs7v96ukpDS2g8zv/eO5nuu57ut+nvv63vf9uR9N
13N2HsvExMRS6fX/nXXFc62othght9T9vX0o3B/3krO704bFNWdWcm1JsFy2
Vqs3N2B0/Q+avCkSYl/uDcuJhyOsVOa6uyMFgYW7/GwrB7t0zheb7qdQkhis
+6qnHzOz4uTQagKyGns9s2ZK0drBqxo1o9CO+T6jkSfYx/B5kLeBQvLrG9U5
b9oQLakV4sIn8WnmKk97XSIquw+FnXeiEG1jf2SbWxQ+POPJ5tLvxXvJfx+X
XguTkxo2q/8mEe1VxW9e0QEWg221tZEASzgZydcagGPzf/aM/iZEu9F66bM9
PbAOHDpZvoXArnwfczLyDgoN1dXXuFNgPEqybLrejdR+Kx0zaSGc1Y5XNjv2
IFuUEv3NUwJsuQjOj8/K0afQGVuxhdZnmcd6bQYfBQdvnnxaQGCbZ9nw7GAv
Nj5XvJ0tEqKQ731Nc7ITTp3WpqG0nrqJf/y8/20/VCKlT19dRev3mntFczQL
JQa5ezaeoVAbncnijBTCK9X4nFMwhUSmSuOWLi6cDbuTZOaFGHXwaJVo4CA1
U1elik0hSOjiPW9SDGZQ8SpJcwrM3Yuhz07m4qbMjvFrQRRkTXMDD/2vAg0W
yfEdTApizQVGe2+cRXLhO78btJ4M3tXOv6S6oPCF3XeshYSSgp/E1EIX2LWZ
Lvn36HwF2Kv4dtWirchqn3wA7f/N659eFB6C62bZYm3aXzDlm+FfUI/f606w
rtiR8H8vI00ocHHr5NXdgqMkildstx1IeQlXBcfkKAEBKfnLrg4DxZid+LxH
FErBfzyMHfOFhxwPntuuQAIcSbnDy60fYcheIsDsGIUAPw3VyIUy2EWNfeCb
UGDv9Mq0vNuG1Pvbxu4tkHgfahshmOUhX01peDuLgO6Uw6nrLc/x90MNPeEh
CtsHD+ypyWoGJ9s76UM0rceSSuuv47VY0E/ll5WTqFQNjM8UH8DR6Lqmv74K
Ifag+sd0t2pk/kHNqUySCA9LTRA/2gLbdyXO60JJCPapDX24UwbZwHe6D70p
6G3SdRmeq0P/L7McOx0KDv53mT/xedCL9Zhxl6CwacTG569T5XAft/5HwYHC
vuH10663KzEUUytz5gqF7+K4IdO1XKzrXek6Qd8XrbslXnGiDq4vDotWi0j0
e1Ro7Ts8guH2E+/ueQxBYiKWLWPUi7zrIY+3MwmM6sx/+Mm1GCrLuwdMj9L5
lxTNaQtb0MsxrbzMIcFU1fLa3PoEkxEduxfpfLEuRIaeFgxiuVi1JTeMQEJI
tKBsYxeMTeL9THZQqOP5dofl90LDgMVmdQgRuEJjRs9/GF3HnDfNSwnQnqnv
eFO/CQ9jHQ+OqFLQODjnxjD6E3P/vDLwO01h2iNiOSHTiRj1tluzp0kkiuUZ
xpjfQ41fpkywHQXOgaoQt8YO+GyJSYthkahe9sCEaGjAb/Wu01ONJGK1w3if
s3nI7NkYYUvS+XB+Lrst5xRS5y5t30vHr283EVxsmQR5jQFTZbr/OXKD7Ru+
+KPq67GeKNoupiHmJWIp4v6f006G9NnSS11y5A4XGS4zDZ4kAQbb7piyRAWS
JF3WFKlRCFfOOD3twMNSwafPr9tJbDzQ8XR4JxfTfGXNK7cIZNwtnTSrLsXH
+pQoko6/TKSk8DlkADss6k+YfydA7BarBKezXdijPcVvCKN5VZTeRFoWIfy3
cKsxGwqGyXEaMgmdYKRnpN3kEtg0rrd5jSIP13qMIkv6CRhKRS7EzD5CtJDZ
zd5OYVta5S35kk60pSStU7ImEK6pd37EogsVbNsJ30ISaxzezuQtlaI8wkpn
iK5vpmqvVWVwPX4xONcRokfBnfU3SjoeIvjr3YEICwrPNlR8jPi+BZSoZWc+
zTcmv9Mp4WI7Pk+Nese0kvhnbW5euMcg2i2MXy16v0JsyvLJbwu7kebj4ujv
RqA/uFpHUaUKWu5ucX4MCvkv+etKvusGNzZtPKucgu9tUcDc4DP8uaR8X+Ma
hZ/tDS+Zaw7gZfaFjio9AVLWrHoxRfMlTV/6gdE1En0R9t1W6/jY9WOrzbcG
BA55Po1hyvaicqhBcEGS5mdLkdxXcR5q1tqlTg6RWDZv8CXd5SWaffYnGbuR
mM1x3MridUHipvgeK2MCV9bam81H9MPza4pz0u8kmtNYl6J0SnD7XqhtOa0H
v7e38cDFPnx0LIrzXSGAew71Qt60DEzCxHRwHz1/PrFKkw2eQuLocyfFJFp/
mWMpiY/uYs5RR9qf7kdFQ2V+gG8XvC6E2v0wSMLQ3dvvsUM/RPuLfKzEaR6P
q7zZVVCCOueRIBlXmt/SNpe1StOR/K26ejpdn5qL1u4Jb7twQleh0Sacgt9i
Q8GNlf3QFY+PlDkkBGfzxVXNl3nQYVedSWQIUVv2SS2L/QTOWtRq3gSJ+8Nl
Aw6SjSg7tcOnlZ43n2QM2/OZPKgWx9o9MRNiwbqyObu7Df994dT4wp7mVZWF
9Lz9EAKrDouhhubvS/cgufNNyNixiuT/QeIhJaiZseiD5vx61a/7SZRNe31j
/LgS+xWD4gwlKTgGpsxFFeRAibFzYCXN38CqO5d9dblIFXkk7c0j0ZtuJrmU
3QqpmwN7VzXRvKppfX3k7GNoSCxtu6tCYbPkkY6gDj60xcc2M9KFkH6fZb/7
5x7M9RtL6F8ncDxPt25Gsxtdri/f8lKEYDfNKEGhDacUz3Nkj5OQbVUTbVXm
0nNirnzDIoGywuZdNSN83A9Inrl+nkDFuFtbpGUtlELfq1A7KVAF9QYpWZ2g
bpOyOoq0/Ymh3DnXQYzt/Lik70nzI2+i/rM7PZ/PduVKtQtwINXQvfhEHYyk
n/ol0/8NRpZuCXM3F+wc4zi3ZgLdQ59+GGQM4ALxsd5rjATj4AG7DOsBtIqU
FyL1hQiXsrq1UfkRlD0OX0w4QsHrzcwbpzE+HkfaR10yJWBmLtuzknoMH434
48Jf6X7jmKuJm/dh0D/tjUMugX8BmKSzQA==
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 157->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lWkblmJkssQkI5WKqSRL9TXV0NUoKkJjfJISypZdmVIMIusnqZDG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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VO0bxpUWeZW1hSQl8RZF2ZJcekkqsrRQyRJZIioqSaWSPRSpRNFG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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81VkYxm81SRMliats0RQVGYkW5klZWmQfJYrI2CWyZFK2GtMyRPYs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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4ltkbRhSJScnSGGWPTGOym1/dFIZqZCdRsqRkiRgMKflqypgsCRlU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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 158->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkbV0OolESlbGVtUUoNk+XnI1IpKoUce8JBmDRUhoNMlijmqzGN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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c81fsfx4UkaZBEVEIqIyqVhJdKGSEtK6NBaFhJMoqyc0tGJIpCUley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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8VPsfxicJtwW3uKks5ZYlXbqFVPTYrjWlZInIpXUoW4tsqSSh+REh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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4lVkDt5QtwhTGOlIkS9aK0M9SlqL6zIQsZewaWyGyxCjKkiTja7OG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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 159->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs8lXccxzG0qCSSooW1htpcUq1lfcgmZMhIzXCSynSUcimKUnIJJdFh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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2kgVA0XlijKTio7Za2IUoo8XhFJWlAqW0SWkkRUSEV2JRWplFASGqNU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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8lWkbx6UMWVJNtsk2LfY4k0lK48e06ShbipGlolKR7PXmpYZGllfq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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk41OsbxlWiRYU6KpGOkS0VR6ks3ZLsR5aQhEKWFlosOaEp0yGFjoSk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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 160->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwdVnk41dkftrRKmzEUk1R3JEWRJNIrUVqUlt8kjAohVwiF7C2kLplI0Shl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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8Vf8fRrLKiiQVoqSS6Gs0PaRIKCupKClSCWVVZBRtQiFbQoi69mjY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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx5FRSSXZShmllG2YSoziYwkpkZKtSAgNgwaln2KiaaRCpCHZ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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk81PkbH5aStnVUdJAjOlA/lVRW3otcoYOpiIiMVc7IsZRjaStJl9q2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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 161->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkbPzP5pLEbMmTJklD2aUZSv/Kl7UMIUZFsUUeEaOyh0CYl+WQp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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8lWsXxqmTJFQi6pSxlAoNjgyHy0ylQgpRhohCKY4UChEimQrRoEEq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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk4ldkfl6GkBZWlKGZ+FIZRMeOS6YPIboiRaKxZUmPvZuxqpsVWkbok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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk8lekbxo1RCdPY2iyDoYVKxpSGcB1MyBKlorJNyFqdUMNIKiohSdbS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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 162->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lukbpWQpSraRllGpSQwlSvJzGhqprIWJ6ovQEMVnihpCJVmyZi9L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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VPsfx0VXuYlSlkjWUqKNK1u9EWGSKGkhlShaCEVJXVmKIkKFK1c3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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlWk8lWsXxlVS6SRDRFIypsEQRaJLRYhkqPOWpJJE5mifDBlCSYPK1iGb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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81O0axlWUpZAk4Y3ozRJ6kxZLrpK1RRhrIaRI0liSSiVyqCjJSB2J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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 163->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkb10R2UcOoiNTM+ChLCo3qhzYzpFTSyBRCilGIIpcOZYuyJMkS
Z1KJRDFt1uNYOnY6OLac8ryijUEqW9/TH+/1Xvf1bPd9/5Z7hfOJPa4/iIiI
JNHv+591fgEXMo+Qea5PVfcowUkFeaecki7ww87+nGXPQMQpwGP8XwE6Lmv8
lbyAQUVgkmu1ah3SDWtU3NkE3JyJnMXu1Vg09bNA6jyBxhyz6vB5AWLmpTa+
VWfgeNrR8uOuPIj873HGoDNBw2jAaMGxFsjMcBR9awiapYajDTRaIT8be3B+
JcHVh/oezDsBtn46rpwcyOAbf1Fg01AHDhbNKq1XYKBzRyeo530LCneF7dG9
Q5D4gT3avK0DFq+ViwvnMdi94nnviTdcVE7vCFsaRKCsNci221KI27EGXX5u
BEq/Gj5o0uODax9qPDFMUHAsaCzxrzoYioeG7s8gcJSsAFukHkGV8RZieQTV
z6Iqdr6sxSGxrRJXowhEVFIC5fa2Yu23PuukToLRZIOa1Xu4mNzVx+H40/4N
hm5kmVeifYf0gjBvAqGn0havkYsotKorcTpMIGg8lrck4DkeKU6+zI8jeKzg
tVl+SSlMDbuF5V4Exi7Nlr4GXIjKSf9ud4ZAbqHHyMiHCizpbpVdR+8/t1p2
Ws6oEwOuUx+MjRgkJjUKmdJm+I/nCJsfELBGz/udHMpA8CH7ol8cCUSDK5Nn
drZgX/2kivI9uh4Qge1hPGRxLo9PsGj8c0WdNCsUJ7+KLtxB81s9PjZb68rD
cWu2uHMqQVG8UM5OvxnObkUGmvcJXMyEai+fFuNq2HvvkL8JLPUvqf8mrMfH
cJeMNUUEDzdOmiWMtiDeqldlMotA8/L+vNNPa5Gmu9+4IIwgKUNmvsvHXqRW
37tpXcQgTmNH2Y/qAqgErOxcT+tx9yyyPD2Wib7IyKHzNH/hPU6twalyCEvX
FKjTfk4mpQh0HuZBw2RcK5HyqcXtz4X95vlIKJZcYu1CoOajPN+BVwyJu2eO
6ZwgCAy11TV41gP5S6wLE3cYLGiaPpqr0I02loXKnnMMHEyzvVptqmCuHCC1
KYBAwm7ezDapLghuWXh/9Kf8LymTU38ahN/UVFs30f788cuzH8OSWjGq7mH2
nPJHxG6DqaVaPOSnRWZD6Lr6l6U2pdOn8W+upt5vNE4Uc/qyNrUW919bn2qm
/Ak1/MzL9eyApPqyWvzE4Gms4lXR630IiG2+/pXH4NrOMuE3JS7mvhgs4gUT
LN29NvHN3+2QfXRhWVwbgWezuFXehk7w/9Mpe/2NoC5+6gprkA/3kCdfpvsI
LocMsNbxu/DZOvBdtwmDJ55ZdxOrm/BPz491/EKCmdTjEjkN9bgx9NY2k8am
3PBD7dM+WDV6NNiQ5pusctYnSqoPuw1yN3DzKT4kbkm8VQvcIufG2eW03t3h
XwKSQiAhoSC7ne5XlkvZt+6PuzCqW33jkxPF/+YPvvduduGHZUe3KLkx8FGw
0jtrUIMXOSJ/Pab1sLZFpSr/cguaPQIHR7q/3ODiyYbsaiyFXuHvlI9RbOOs
RaJ12KE6ct+D6lHmdZyY7UALPP0OWHJvEBy4m5abpsXDRXnPndOUnxbDN9ZH
zxWj5Wv1jD/Fu8ooyuZuUQ0is/9oeP+d333ObdOHvKBa3eO4juYrlLBuiBTn
o3fXJZbdGEHMjBsnWqYPR6JusmfPMPB2a0kpO96FpB0hdg9cGbwXr2vPGypD
xjGH4bf0/ozx8uwrvnwckpA54CDB4Pmt4TJoF8DZfCY67ggB34HbaDLRA/7c
drOSegZBrjqSyRndYPfPV0vbykAwckDNwCUHFRar9KUpf6vYYktyx9qQrG0S
vXqCIGGbxannft0Yso+QalnJgCWvoH1Z2h/BXrrhxt/z3+i0yEeyCnr56ZtN
z1K9no98tLGuFQre/orDLyge6UZKGHuJsi1RJx5R/BK5FhJfVzYg4W70lFoK
gYr11tLJP7tRsszp3zCKj5T1grBIhTYEbzZ3/qeXoCTXYWmsLQfGMS/SP/kQ
1Hj5TfH38iDIapbKTCCwYq94197cg5HdNtqXEhgIX+3p7DVugHZ9fu6vVO/P
e8T93NIewrE3+0GFK9V728NY3c4OTNmcqjM3Y2DaYh4+wi6H+2G2CYf6XXx/
58dbnC48fqHzp0QE1duBpvvRp3yhGeN95DsfVRps9yv6PcEr8zb7Euo3rZW3
9ZdrFKJEw4yJpPdPBfJzgvY0gslMvf3mJkFFii+LFV6H0W88wZsrBOaJ+Dig
3wa/ob5u9SoC+UW+rzqOl2Iu8FW9H33/demnGy7pfBjsClynuJDB+soANXWp
ZuSn2Bo33CbI/sZz76d+PxamL5+QTvWTV7s8bKgPwinvKkZ6EB4rLD6vSe1E
96y6YpU1g5LEw6vKNDlwENtnyvOj82Ch0hmF2VwIjfa1lVC84ywaV4y/eQGB
z634gRnqDx569Wt/rcbtzwMNlyhflx/M+6mgqwWicW+LnxTTfspqaQvucPAk
4l26A8VD2Sh4WbteEUSPzlam0Pojlyu6X4h8gNEqrfh/qP9VqNllHFx8CUq8
2oYj3+fNhcVeC9qeQcu6mzNM6x1NK/Agm4rQxJM1iaHnNUNO92u+eIZ995OU
5Typv4tdu+6hXomLbrr9n6jf3mNPSJavrMVX+cx5XyII5is4vfkkaIVy4IOV
z6gfzZi5ZltEtyLBqXtyfTXV26QWrLy4OBd+tks2kODwtN6VtLx6nNKN321z
jfpDx9n8c/oChCx3vFKzhkGOoaa1zoYOlFaK9zC0HyeTcsL7/yuDumBevB/V
22Zmo7Z9fTu2boigo4igPzNJurmlCfYR+1fJUHxc+sILro/VY7Bk6bbtlN9W
ZlmSmTZ1GMra5f+J8lH+aKMvV4SHrar2nJgkOu+3dPQFqXSC88Et1WqS+lna
rHVpRiDs1LJqTWi/9Lwd+abeudCK3zv7meJVsCLYTGT0KSJjplP2Uv6lbbJd
q+nRAe+2GpfsJoKhr2b82IELmJOZfG9Jzw8eO3g67nE3GharikXfYPB/X2TI
Jw==
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VG8bnpAUSSL0QyVJkTbtcouUFpIkIVkKSaEoJCRbGyoJRZKy75Ls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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVmk81WkYvVkiYSyVFkkqIZRGZUqOGQ130IyQJRHGHoaGMlFIFDKFkkyy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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk4lekbtpU0MpYaWxsaMRHZj8pdQiqjg2xnJkJFStYOadVmSZSJyJST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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 164->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs4ldkXx91HSkm5TQhFNUmFSsJXZSQZuaT7oOMkSiKSTEWjIt04IbdB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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lf0fxlVGg5JNVoUkJMmIXGRLWiIVpUQ86pGGIqWyKmQ0pEFkz+y9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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lOsbxh1K2uRkyhJlz0mp5FQcXJVCGyWRaLF1RIpSlpOSyDaWkC1l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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk8lfkXNiFp0k+MSGpIIyF7SYznWgqFIiSKW5YxUcpIKDFMjF0qjH3C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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 165->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8llkfxlFhGKQREhIlTU9aJEujS5SlkbGMFpKlNEymlEi9tpFRGUS2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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3cglP8fN0oaorKpkPYwUkbqJdGQQsqXokRDkoQKmdkNK0mKbIrsmZHt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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41Wkfxo+l0IKRFDNZqlOKtMzIkrpVyNaJGea1ZVeWFkOzpDkSMoqM
JcubIYSIUGQnwnHKznE4sp3z+x2ZsYwxkqX0/t4/nuu5nut6ruv+Pt/789xf
Nfer33qJ0mi0JGr9f/eMuNF/QqEf0WlhjOSXArQvHJfRC2/AeprILa84EtN/
dFlvmeXgY7yUGfemEHaRQTPRLyogF7j9SokOiUiaR92Jza3wm/uCffgpiTxR
ac35IRbmfOUlk81JhChdU2/e0wU1jU91VbtJTHTcdNx1sgFH+NVj3VYk2BH/
tSy5Vw7/WbuPzS4ktAIeFEjs5sErM2Ry3QgBWu2ubzRkb+HKGo46OpMoaZV2
KFHMhjfOen7nT6LwKPftX5tb8PTrSzd1DpM4pJN5KOp1BWRTPryfcCex08zJ
L7K0D3d5JgOZCwRELyht/LyDg6D4doeFDhI/hOyKZ99oxpTk7p++UiSh2Zsy
wrbqw5UBRsPoZwGSMgRupxPG4C23hb5bexg798oOv9k+hORm2/aTOXyYKpe/
eWrUCYaRQTGdQcLq6MLl9YfZiHOJm1ZqIsEZKtX16+/EV6psc51ZAuxDsyJW
TzjQlM7ZPx0mwBt3e73bQwMQbDOziD9GoJvvmdRf0oKHxdyR2zwSbm7pk3LK
g+iuikp3sebjt6hQG6JgED/l0kScIvl48I2oRF5wD14x1PTyHUkwDy+xT70Y
hOVq7JacAj708+9sP7OvD4r2Fcxy+gQkQ/M2mX9mYeFWvfJZAxI26+OCZa71
onRdRZXoPIHOczIC8+R+KPkEMOZ9SLRbtMkzpnpQNHGX5SwvgMnefzvtvRqA
x9//8o5Gwj9D+y03sg7igQs71KIov4vzL4dtCEO2tgT7AuVnYZbOofNhbfix
tGRdWg0B2cb7dcStSqxeDwyv3Uf582XZqaClt7DJUlV+f56Pc7H6/xw04cBG
cbToeDABUy2xfbJqdaj+kBPvKyDRINsk/zqkCYuTx5l1lF+jzE+6g229MLk4
57VBnUCVovVWhyO9WPEPb6w4ReDQ6ibzY6HPwDD93UjRm8TwiSl5kt6Gdvz9
ImSChKxTZcs4ewiNJsffn/lE8Rah9Nt0DxeedJWzDzcSMFy1KR8MfwYfG32O
SBDFR7rtlVB6Ky7X+dDT40kMHkyMvMguxob0A4qx1Pt/1KzVKVcewQ5b8Z/3
b+ZD8O+M75NRNja4zg8Qx0no0izO2UaOwCNfPHNFTQinqKCCgistWPnjV1Hm
DMWvJ2Hnu68JUq6va8Ypfh9wz8909PcjJC31sWkzibXorDExvyaIpKq7aj8g
Qeu0Wn7ucAH71HjSXlS/rb5mKeutPkKWWGipmiWJyu8lRzP3NyHj2CG88yMx
yeidnfHgolfKX997VYDKFcHbL53KcS1RYWO1IQmDd2LzReVNGBQq76qwIDF+
RsOnNqkdmkEeIeYBVH/KaS/Xf4zBLL/4iasbiVt6d8oivFuQ/dFQyleFQOWR
xY1PJdgQzYo80BNE3Zc5vsm4sBwVgT4iodR/l7U+7Xd1Kwvn7XM2f88hsPJZ
/YXDOS6cVYYtZ/ZQ9f/qfkpv+jFqv80ZiKX0XSOYD7/bFgaDr3O8np8nkdGd
1pru3IU9DWcas4UCuLL61sISGjB3NahTKYuEnfHNcduyPlQkmlUE/i6Ea5C5
tYfWGxTVVz9SqaPyI1QQY1bJww1F3tKKiADjjY+1Gtb1giYlfclwGwmVWfbW
g51VMCvgalovEYjjNklN1fQjp2i5MSeVwHh9VxetJQOlAnGzajOK/4l7hndq
0iAtOEfXsCch94vUl2tJHUhQNS3j6xFI8frzkxevEjqmeTzHBhJLdjWiijPt
+Mqq/OdwJok99EfPx4s5MN2f8bTSToA8rSKrcKUiFFaULp3xpPJ3MvfG1ZMD
YLQoJ0dR+RdycFqnPyYAkdplNJI6m8jN03sqexBhqHD1MJMAy1N/j9hkCyzj
nB1d66l6f7F+f/8oC47HfljnG0GC6zkcG8Hjgr9djZGmQyAj6t64cVouygSz
19nGJGLV7j9+FceBwhcvr09OU3piWc98OB5oKIrOPkHxleFHRt15+BLzY+dU
apxIXCi1LeSJ9mLovnHo0LQAlwIXtTsauejc12mhReWRVk9NSUlSN059SAhL
eE2g/QJL5OFyBzwVJ7ZE9JFISWR+HN4xDFtL/VOPEgm8ilWQ5ts0IMte99HF
W1S/VqQ/HxWrQNJYbr8LxS/TDNtSo3g4MB862fjPOByET9a3XWvC0wyOhbEr
ibCR2wG9rAGITP8tPmwigP+U6IFovwasfhtaLnuReo+2N97VtmJszvR04UYS
z1wUtsrrDkKlIJnOHxqH4e4jBlztdlSYthTw3hLIY4u4dPJYWPzk7nAplZp3
Wh/ZBmpVuGaSvXaX+p/Zvv8kdcW9BsM2MrXTUgi5Puad1rlGfLhhcZpO+RO4
Y2tVRsAwNXfyZVuHKF5fTTkdCKyFlkuk++6TJAwnR31SDWNR3Z89Ju9AzU+Z
v6J97aowPR5h707xURYTlJqw3AzHZfH91Y1UPybE2hPfdcMmbs6opJjS/65u
Q0B8N4w0bpfFexCQj0lpWajnQW586NGeEAKD9GBrso2FQIc/B4rqKT2JZXum
9gM43Y+ckqX8URf2vBKT4KAhciLltgaBnfQXN5lvu2DRm9944Z0AussVPyar
t0G2/0/5YyQBfdXqlX+P9eBOwX+W6m4IYerCK1B06UKeZXn6c28C3tMBW+5N
d2Nd/HLw7RghPi1vu6T2uR+bopQnpbr5SOEYSHAV2mBpnO78dy6Vp5uDw93W
XmDII9D2+jWqvlkyKfNoDKYWn5QUepDwNpIdeVPOQoKmqkWCjBA0G7u7AT9k
wd9v0UGa4q+2NVeyTXUAeQEnLczMhRhUtbdiNb/C+7PB6YteVJ6ExaTksK/D
NL8szpLig3YgU+bBdn+EMbIFuZQ/tcbNGl2pbDBjdnIYuyj9xzNBvnLNMHLr
EP4aTeVty1SvFQbwjYO6jSVPiC262u+TWKOQ3+AsmVEzDsmHxomTefUQd8s8
mbeX4mPNfVYlog1BsTcvn5ES4n+Dv7id
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4ltkblopQCBNJZcuIlGWyxdxiLIUi+/YpRSoVrRSRJZSUpY/Gmoxq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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 166->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk81dkbxw2lKSUtlmjQlML0a1BRUh8hpcaShAxZSiFCZVpJwtyQFktK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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VH0bxoUULVRCllBEhUgkpUvSQjxR1hZJCNEibaIHeSRpkSxJRAgJ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81VkbV/ZlprwmY8kSwkiolKX4kq2EiWhEkZB9aUGlQqWNhJGylKVL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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk01WsXRq57kluIuKVDkSu6ppApjylKkojMV33cVMZUhlREoZRoVp+I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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 167->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lWkfxk2nUNOUnRlLRpsOWWcSxVVGBkVNb6PJRLaUsmdNSEJ0krIU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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VP/bRoqkQkgqS5ulSCUp6rYlImQpvkmSItkSpVAqSiVZS5Lop82W
Lfs69n3sjG3MnJmRVIqEpPe8f53rXOe6zuec+7mfe5F18DA/z8PFxWXHzcX1
/1ctnua1hHkQEsUtb3ieJyDz0Wjq3/w9JBRki6fYE/Ad/DWq8V8DDHy0Zb9Z
EqiQTJXdTTRCNIXBVHFjQvA9n+ja1H7krU4sVs4fg1T7x3Ux/6rxn79y7/Bz
JpzNrGtXr6DAbOSI2nseFioE74umUoMwi2Ntn84SoKTXVtW0DAJ6enMsVwKh
b1WVGdZtEJfp6O31JFCwwiMyOzcf/nImWYekCHCF7rBcrXQLNgVBA322BOih
G6XoZ0sQVra4xKGZQMjoz0oj30ZstBLma5dkYvbgIZEj9AHIqh3ZfeX5Z8ze
r2cMXs8Af9xJ4ZF1BNj+XNs3xBTjjqGOdlAU+f9LVjyr+NWGb+bvnKS1magP
N73rJZ+Jt13ClMJoEg+hdXnx79sRcr5OpjKbDns+71eZP2pwUz//ZEswgcTj
m1q5tzfhnrbTQog0gXs8pow9x7pws1T0ZLciAwm2gR9q+OoRTV8mMJ/DgPHj
WOUrMn2I+12fITPCgaielyXlUiWmXW37n/IQsPZc33Xzczie/Yk5lexM4D2X
xh+bHR2gmGfkG15jQChz5rcvoxWLbF3LZBcmghbqS//pdCJUcZ2low0b1MCd
jPu7ShG+vkRTd4FAn2N+wxRfO4qTCh+fmGPAvMajPvrsAFz0mfGVUyyoqi4O
5Mx14sSy4LCviyQeJ+t9rxnlYtWJDKNQXQJ3o8X8Y9168O3sYkx8PAcOtK0f
qkbbIWHrN8E6wYHWHeGTjctboOU6QamVZyHRuWFlS34W0iwG+O8pEhAZdTzO
/tcBhC+oC9cTEPoRdPrP+USISXO6RM0JiHfmr983247vqprx6X3D2Ea7PXlZ
mgqHpfE+jXsZMDvZNqhgnA6v7JnvzvsI3EgQuVkWX4MysWUXqiYI7By9Le22
pB0UxRaPVwZjWFixOma3by5EW6s568j5SPTJbRBezISg5qTVtVAC0q5fnplw
GjH5OuzLl2EGwi6m5/4vpA7i9pnbCvYysff7hsQ7t3ohFm0t0ODNRKDRV9dh
vgKoV8cvG9lO8pf5/uCnzH6k5HWphFcQKNoVRRM3z0GP7ciDBwUkX3n+Hirf
3ouTexSX33vJgVmqTkXTz1QEuM9ZDR8n0P2utPVIfweeRhZeElrBQOZKrfFK
iQ78vEvLVhpjINqEa5OXbREuHJia3kOeF16u/YnG3YHKhckXrxsYiK9vy08J
rYXx6Xer9H4wkag3ccG+sAODMdLxTsNM1Ch7bPDcQYGLXl6R2z4WJv/E5ps2
pcBBg5Z94yrJp1NrG3m5WmFn1t+6guTHq6fnVqzb3oGvzjxhYkKjyIidParq
14pMzYXzqXV0zAqUH0/0aEBCffGMcTELvO+zDNy/DiKTxrftxZJxyAeoHOSm
9aGiMsXgO4mH2TteU72QHIyLx0ndliEgR4k2s1jaj/mOBxd573yGSJn4GoW7
5fjconH81G8Cq5Y793LZZsJ7wOn+pocEgvqbpwMTQsFjrRoWSeqRY61jLfNU
NwrnC/YHRLJAxVjQnroKrL/tOZrGy8Qg8fwCv2AbRFa13t/aQSCzlVFbuqcV
olEX9pl9JDAW/E/lr1ElBFYtFfWaYyLzsg5rZfgwDDqGYcj/FUdHJCwde6vB
Z5FHr2xi42b6v6q42G4w275lSr8cBTVUSGeetw5XG/ls7vqR/F7YH3NWsBMf
fBq29h8l+aPxb5nrTRrGqc6eWWlD0JS8O8QWakF2jdMhsyryedjpzEbyvNSu
q7J/yziov3iz7HIlFb3f/Iuj/rAhIb5beK9wPSRaphN6ye9LPsbUbsgaRPvy
w4tGNUMwu67hs76oD5SG9AbhdhYCQ9waBc90g6+VTjR+oEOmTezTCqE3+LZr
gF+O3CctTc8sp3YKjEIM241vE3D9IXHfO6YLH678u9DSwoB94RmhsuYImDin
DCY6EZgtHfRIukTFtfBt4aXJo5AXatgq0lSH+TntZPd+JjZ0shjrdlPARREL
mr5L6lP8pZLlrVTYbGzXsCb3cyaz8aeHVzWWf3MZ3nWGnJ/H0X3ri3rhg/hd
URFjmI2VfWZu0ofa3HovjfvjkFSfypivacTt+gvWeV6kHu9Y+iygvBvUGz8L
u7+OwJfi8UdRLguvDtDmbHwJqE1duvVnqg5+UdK1rHQCzl9nORusC/EsPrRF
f5YJiS1WPA2P8uGwqWj8+2MCkYdNAih7aCh+ayPjkUlHilzydR1KHVQdIhw6
uAnoJM+6HizvAmGve2Qik40ojRGFaIluPLBxz7icwwbv7ksC535mItzf9ILb
NQJibwtXN60dROLyoJerS4cQ9NBrery1FVJHvVnDEaRfLJ28yjP4ETN/20oa
tAnwSNv/UM3uhXZo02H9oVEk7LzoYzNMRWGiu2e8JAu5a0qPmH2ohV5QYOih
eAKC6qITrZE1EPgiWuJty8TzBq4O4cNN2LyxM0lnLxvGimWlVKsafJ/PG31B
+mvzNutLh3krcKL7U8QvEo/D71W2aq2mIi3+ouZDKw6mOYHqGwP7kCDjYBfy
mPSDKf6mnW4dUDWp8FgyzUHX39bVdPK8MOZUiWU/qT96Rs8MFnpInZ7vrt/I
BhG7pmbubxcebVNoXvRhQOaxItV8MgG+SmdK9p8iYEf8/vz0SBnknXb9tFAg
IK/AH252vQXJ0/PpJ1kEvA21rsnntWPk/eLvLmsW8nYqnHdf2ooPghFisYFs
qJx9dO+QYzlKXt3V4BkisKcj2GX/aC96epfVPB0n98v3uIL60mHkPhFu1Vs7
DM31hnytEu1Q2XlCV0uDxC89s7NsQxMEnELkhdhMUNeL99cfKkFfxHbqnUkm
Koo/mdvQshF6NWD9zxMERA/dF1YsbIJ+gXwn5wIThnx2e132dWLka5V68ysy
Pzhv06AP9cDAzm1Q04mJ2qtzSsYmzTDQKBeVaiPzT/Alq+cCUWAdH792h8wn
qac7haw1O2FkpBaWI8SGTNp9bmWLElRzigr5TQjwUj7bnZZqhuA7Va4kCTZo
CbIO1TEdSImRPPrsJ6kvIr+3+J2sxRbGsStayaQ+0VJ1k0YosFA735ldx4Lv
dKXM+ns9UDyisF03cACWTVfyMyzasDerv03Xhnwe+creceotDikLZMyvJfE/
N7mHayAX4rKbVp6zIhD4j+uEpEYYpFaWE/JkvlqMLXMVsKEie3ZyVXwmE1J8
DCZXGA0Coxk0qWUjCL0uOnGqmwLluGm5kSAWQnW2bLCTbYGtlIBO+lICk5IB
FnvD69DY0UExJ/fnqoWXXQpPCZkDiSXHTxJIVhH4V/uqEl37N3HdvEdgy/ap
29pJtfBRNt/kXULmO+GtutO13Wi0sjCacSHxrhTUNayrwoWyLaLbisl5PYo2
cf6vGuMyW7gDLFlIWBSNkl2shFCVGNuN1DuzsS6ZSvlOyGqH+gT/GEVg1fYm
OztPzBjJxZ6zI88Ppx1aKd6FleEnzMXSWWhU8re2Dh5AhMXJG0wRNjQ1ryrx
ciowoRt7MciRAGz2HjsjScXa24yfSclMjLkVPP6t3wXh33rigz5MVP/p/Mb6
QcErolA5g/RH4/8m9+64RoNX19TmtPlhqLo/Lou/2oDwV2kXfIII8CsShUev
vwfd25LZQf6fWUGo7fVzLciY6dthdouNeenKnWFllVAzLEtXcGIh9vOA87Kh
IthqCLLpvkxwzSpSxxKoWPW7RUhPkLz/ot4mNVGOVrmDE5RtLNTecZObMGsH
T+Li6p9kHh8fvaOa+7ofoxfGVOSCP8P8eOyVbVvacWFJWDefORu2Wc37fYZ7
IPBrqalMwRi4tdxuDq7sw4M1DVPuY0xMZL1UfKpYj0hJXrny3Swkm5xxMc+t
B0Ppg1cDh0Bzs/fyJscBVGmf/ncwl4HALcafMsr9Ub2hPMmPxDspZLzxtXIl
skV3SP1sZcIxqUxD3LcG1Y80ZqlDTNzysRSlKjRg8MVh2a5QFvTOj91ybiC/
383P3X4j6V/8rZ83ZHzCAfqe16fcyLykoyY7rJMHEb11+tGk39BsQzVrblWS
/cN/j6k9EwuHmnPaVmfhbVtZ8KZMMp/GjphsOpWKh2GyLyPIPjEv9FfUsrcX
ESG2NJrzOFz5dpd4DlWidafkPa0yAnEsXW2+rfWoOH53BX2CCS0dP8nu9lLo
2T0/EXuI1LMuqSSvsA5w48zioDADBrpM7qymDgjktR9b6UFHV/65dw389bBt
Pd5x7i2L3POhVn0qFeoBDIs9pmwE/qq0VZrLxpwN7cb+NiYOiEXKeil1otA1
1j6xkQneu5/25wf14cNX8VmH4lFMLsr59u+JQKipadwxawJnJandK3LfYqZw
fD6O7Buxqp+Lwt3zwLvv9/alZB+Q6lDn9m8swLTKlpTO+0zceR2tZEqpIefi
qLj/EInnTpOnPo1v8cd1A21dHNlXUqz0T8yQemz3QljAfgxCu+dufNhYBNk2
scYEMQJuYpxlgu8GQZ3LNvAZ/oIbNxQE4d2Jul1XH1N+MDBKvS8WrP8AJcNi
l5JJvY/dJ2yX6daNdJsxxH3k4Arf5PQTzR4E/v0pEtXCgox5Th03px9Ei8MT
/bRR+EZbeT7/1QeB+6VfTY3I+azhP3U3YgAB53b8pBd8RrOh//y+8Dbo3/DJ
Nyf1Kk61Q33tkR4kPKkcri/6guRLGbGrqIUQ8Nxs2kPiofWM/ktmXz1KkgNv
NXYxyfkkpPZcqwfT7VSGaR8TYbXc64q4G2HpEia/dprk6/4D65jlj7EqQT/u
GcnX/wQuOUauo8FhtuiZB4OD2NL+098CYxGndi6XIPHn4p71FJeKQl/WZ0Yh
2bfULpo0LJlsQGTH9T5xKRY6C+f3f9foxhWBOdEA3UG8tYihXZDoh1xxd/d1
fQYEU01jEmZq8US9Kk9lkMynK5w2q+q0gH0rQ+nmbjak4jeIXjLswET10/95
zzDheiP/teuTWtRSTFz+qhC4xcOntW9LN8ISB+abrnEwI785OmOmC3aisjcT
FZhQX+CtG6LXozKt5V8ZuT8VMxnqmpUPERAy/6OR9BvPY+ya/EMV2Pa0+XbR
/0j/OR/ocbGN1JsvjxlNY2T/0hV/aMzbjtkfbj+4IzgIWbrxgdvXdhx9ep3H
mOwnqkm7dbToNHzafXRubvkX6MVlM/6xqTgwEBN84OhnKCJwIcqa9EeXTTa2
ykzscJNIy9zWB3rEFnUqHwNp51dpbXpEgZBI/qYboUwIuW+aL71WA5W0HBXj
NQTeik/aJwzREOIvX0Y/OQ5NUY9h2b5uFOj8kUpaTsMs71611fKJWCLY/HAz
2U8M3lPu+k2Vw/zGkf1Rgix4j2/VF3tZC6+qP2MPWCTf9LvFdA3ew0E2R3CC
5CfF027X/Xe9yJ0cCYh4MAbehpIeu2tUZB7Y2DgzTgf3sImHfW47XL6azbS+
58A/xqXMw6MQBer6GxXI/EA/IWm5ZkUD/IZeKl2qZiFta+qL54ld2JuTRuM6
SPIhNVIimLsOQk2XKqv8SX03yp05yqmGlcXpY8FkXrijOtUaxduPU6OhmTJv
6BBR3Kqt594Nx3K61p44DnxbVibsXkvFwXH+4xfTRzGuJtL/dWM+yhztaq8c
IFDCvaXEdKIBAU7NUVfMmfhYn2qwn8wfB8qyzE5vJfv7FPflMLkRbLbQz8gR
74NK8JxMqmI6dGbX1RytITCXcrD605IWPM5XvHwzjw6pkvbKMa4KuOf8OfmR
7FcBV87slP5QDc+UCJ3iPwQSjyW5s1+n4N5B/gxlNQIbdr3mfaKUhfEsay6n
MHLf+WeXx3KK8DZsequHGAsld7VjTwf0wdtYob0nfBBa7YGGR6bPw1i7qCWZ
3K9B13PPWjb3wkbpXt7eY2R+TPe4ei2R5PvVszvqjo7im3vp5rE3rUibZ0xy
tpJ6JNnzUfVdEvrzU+Zbyb6gFujuLXyqD7Q9FrbUt8PoG/d+IzGdjDbl0s12
ZJ6W0dl6JGCxGXkBFJ/Zvyw0F79Za7OhGM7KA/IHyXw+acx1+d7RfrwwfK3G
v40OobtFKPGLxk6tF2sHzxHwOs7cUBbRCfld1ikF69jIW5z3AJn3QzOu9NuZ
MeBstm1C63421p4U+Kd7mHzf3JTfl0fpaLsr8ZSmSuanwmJJk5e9WHZZnrUy
m46iU0q9S171Ytfub0ONI0xMPnSaHT9TBTsZI243OgscaXsezftdCLG10FQ5
ycDsB/fobt5anH/oV2KbTcBf+pfCLno7pPm2uy6IstGt3XfFn9kOg1iJ+vRW
BuTZjksaVfpR4loZfCKEA617j9/uXVKJ0H3aOY/zCEz986NF+fei4pCIVdub
QThONfj9F5SJO0/+0o+QfdvSQaYp6UknYmTXLH2RwYbBrns77uxrgsH5hZpI
cr6D1LLNgiXdCKc+/bi9kw7r8zyysqIFiBT2HBV6Q/YrbycZK/t6+PPfeKg0
ycA0//9G6l53wDxDkiZI9hmtV/HiNXfKUV/xxmlpBAvOWcsTLnvl4LVh0NKF
Sibe0xOVPpP9oSbsS5eU1RiGIkOCDd0rEHtas1AmlgBV6EaxrAEFV74x2o7s
YoEi4eBs+70Dw+9ztoRuZiNuVkLvdVQPEsu7uVVdmAh8qta+UOWNzUFJ484k
3yyjHd7o7WuB9jUtl4bLdNyRs3ufKlKNtIqhpAfkvGIfCrYeuVkBDeHEyyJk
Xve0sztTKV4IZeNvyWukCbRd3mrxaEUfar5Hw0O/D2nLmtZrGcTCtbf7aNd5
ApmUpIa+oTJ4/NWpdib9XO1N79dd8j1Qe+T38ZonB5oNs8uCXtbjW92JiMPk
vB81DD2P3DsAA1RXPTYchYFgmpj3sTpYbOGs5u9k4Gm+zIvlDwZRtkJxoPbm
EFTWR+csEfkEPjtVq1YyL5kFpc6EPalDzDKNtQkP2VA9/IV1L6gfabPhyjx9
bLik6vh9eESFscily/a+pL9c5vzvysZOqNhsvMWjxoLUS1OdPT+7Ec9rI/so
eAz/B9v4AS0=
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs01Okfx61kpxCLXKJyi5KEttqK3rYo0ZYiIZVULpVGyqZJqeRWloiS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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk4lWkbPxktZJQYMfaomZEpElNSPwrJviVSwsnoKz5apJAlWSqjkrEU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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 168->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVn04lNkbVpSSpJQka8dXIrFKrdpy02/7oFYRv0pKiIRFlKKUlgqRj4Sl
KGpC0RRNRAz5GkamMY0hsemMVvkMKyJ79o/3eq9zve91nufc9/3c99Fw8bV1
myklJZVEn//ewnvjls43KrHC1azh7UkCbYMx680WzYg+VbYwpYvA0TOycGVX
PjiiUqP5rgSHR5MOTWx6A/0u/3j5CYJLW1pKV6lx0afQVP4+huAIx22a01eC
gQoVh0Avuj47usfu1CkEKdTm/exEcCM6NkQsqIXpoDrL9zJB9otb3jccU1Hg
Ptr5ln6P27bbaHtfAbZrJ2qtcSN4Zly5If59JbwfXOV6BRGcnGFVwTzehKoi
Q43kUgLTpVNhb6Rb4BSQGn9tpQR6G3xsi7R4kJ9U2ZedRFClkKsyw6cacZnv
41f/QeDJqV/3YB4fhhlt9zJqCcJiZx2p1HiLNta8vOEECcJX67ieLmuBOzvJ
bUxTgqrJ5LqxvQJoeYXvjKohED/zdRtmcRA3qeizNIDg4qfbsjp+IvD5GS6V
eyUI9ZAN0dQuhkL4xq1pxwnqP+aUZDoKkMSd9/Ilj8Akx/94aehrCLuMNU/V
Exxlek8U6XLh07Zn/vB1gl27C9mG1hwU5tfwBb4E7X7BR0NuV4EkdbpFXCR4
NfkwryShCQ3BAgP7FwQpjJGiSudmFBnJDzT+RaAjZ9//MEkMn34285O3BPlX
uBP+kVyI5n5Rzk0lOKtV7OLiwsP/3KW1ezIIvuoXcpMcmuHIDt/WXUIg/6Oq
0sbkOnQNRxxoTCYQqTo51x8Qwy7aQ2I2h57PvmdadiQTx+y32kceofxZB6WO
1bbAjCliHFgqwaBIub8+VAxBt1L84zGCb7utniwPbMI1m91fFlC+wusvrZDz
qsLNWk/G35RPsW1ZUMiTYvBOc/orKV7aKy/IhvnX4fD9gf7QKAK+4KFr4JJG
5LDtIvZmExSNLLQ4IfcUUpu25AdSfWR3vnsyrsoGL1Pm6zYPgrLokQ8P1QQ4
rZJ7de4o1dO7oYHEVY9hdGz/J8ujFP9v6/SG17Tg63anqtZfJUj5w2qXWt0D
HJkjs0OG6pufdutOoOUbsCw91fNmSRDBdzSr0chGmlz6slFnuv8Ue/38C5TP
vvbU1e8JpGTTFfVORCFqNG3cjep3x9+F5lF2YkRxZp/9YibBObNHieOZrTin
O+U9l9b76/qhEvmwIrwQXmY10/OaGP+Zoq3WgrVLiuxK7Wm9ixM7Ampe48W6
SsfkDoL/B3L0bU06kW9cb1ET1A3TlIsKu1Seon2ovvqvY3S+2PppgmP3MOym
NrmZ9hdXuHV++YkmmOz3tc2nfN++vKNM+xoLx/L7tixz/W99xmRfegICHcdk
Emm/S04pV6raC1GQM1duRED7MZHpVjR4jlfCFftqqP5SPYs4vW2ttP60c/ou
CZgZ363ctPhQ+qg4ZsEmKP3nh70uQzVg3Ly2KTmSgHHG85aDTScit6Zw8/qp
Xpip6ln3o9HGtHjrSutl2vTG5tD5iyph63jSeTB0/eSS3sDHzJ6u+x/uEvgM
6JZPDQmh5+9cdugd5UNVXW3wQjWOlsdoNtD9Te+G+Uv3laO3or37vD+B39sA
2+Xy15FhHHEsge6/InFhmt5kLbzvGx1UpOf3kP6p1rGAC+nuyGcbEwjq1t4O
lHN8Bosh3sQ76k/brELqTi6uwtZ/escbLxAkzmldoyDPg3fOZx6D6i021+xm
jsYbaI6JP7XISSDs58kWaLbCP2vzoBLla9du1sDEHiGYMZyoW1MEGx8EJBjo
tiJab5ORgroEpisW+AUrCzF6JMVFd54ECqt0AvRRB+b1JGjdJDCviv1duT4G
J/3cFnnR/q3VddeOz22FsueHmho7Ws/9SvhwezMEzhaMhnGCQblFHaL3ArDb
C8N06fx//+OX33pj+LitxTP8+TH1s2jBMqmMCjCi+3bmnKb+qRH+7VwaH8dj
bBI0Kb+TLWq+071CLNOtY1VQ/zZ4ylYv4XeA6/9TrdO6boRlHHIJONUCu8CL
dj3WEiSFXFHzj3mN4FjTfbkfaL/VPJ3nLS9hmLJoIDSQQLjSxmjrUx7iVPXW
lufQ+ufLY7kqQshMFaT1qEngs6PHoPhAGxiTXcFsQwmmNLezbWJEmORoO/2i
IsHRqvQ77fVNuKS0oUjpGkHO9yuWq7w4yFdXND3jTbA2ybt42xwRllebzKqg
+O/IOArysgZR5mxZ33CCEesFOZWTNbh8blZs5zkCu9ppB3l2BU46et1jU3+u
U/rqnmgjRqj48EzhJ8pvw5GPO7824ef1twe9WAQchyyYf7+KNR3hSs4U/5rH
jbMZs17DtTTcanUTgeKKjp558Uzsae7w86HzxVFtUmwtvICfPmfWW9D/s7U+
61XfKUfKzokkLR+q/4HNX+P+rEPWm+mD2lRvoYMjg70VFTjf9DCFS/PV3Fbd
a6PGHaTfItbu1D/z9ycvHqN4ifqCGMubCfbo/e61/sIjmPt1mlrSeV15buf6
08Im7HoV5/bsKUF615DLn408PD8olTlE8/buGR6vzLQEgqHjz4M9CX5tWqTo
Of0KXYbinLZqgpuqv9R19L4GL8uf+VsnzXOdK12Ky8WYUaE/1bxAgsi8+Kzq
0mr8tt4jT+0sQfQDB5HHLRE6irt/iNgtQVjQnLL9+hWwWXX1UOUJApY4NWGR
6n18y/rH7m+KR+mdF+pEzMPHtGipPcUELuGjlgODzVAM7Dbro/67f58707qw
GhbbnJcGx9HzO2RfNGiMgKOkzvAgxY+9ZKwyeNlbnL8xb+F7vgSzlY3PO/Me
Q61XeNKZ+rtdX1b74018eFWN63fTPE8peCI9Y50ACvWscTd6P+GM+++U7uJg
AWvKaTHNE8Upxq8ZWq/w8IsVc38K5T9uCd9+ZhNMI35kLS6g9wdfFtPDLAfO
GZcaYmn/V5eJh2S4Qjjkmse9oPjze3Rk8k2ewjrtsPFSmicd6onnP18TgZHg
0CcyluDO9UdTLa3NeHYzYnj2R5rfuZJq/b18RH5zjG3PpfmU79P5QxoXdoMb
toTQ/PwX6bHZOQ==
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lO8XxiflW9EiJbTYIlGpJEV0C5W1QkVlF0kpSZtdIUpCm2wpCZF9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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs4lOkbx8ckKUQpwtJINQqFVML6OqRVpBObnLIqtqKVopYQteWQwiiV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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4lVsbxknpkMiYHIpIKkV8hoTbQUSKMuSQ0CFJRUSmBslwRNKATmgw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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 169->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekbNtGk0DpSUkapVGihaaFulK1SlmPX0MmeZKpBSAgnKiKhkhRJ
6icdU2PJvovj4BzbUebH+8kxU6qpyFLz9sd3fdd3Xe/zPs/93PdzP58K+4Sl
2wwJCYlk+nx/z3dJ0DOJrYLJumepz4MIEi3EwlO9PBRsGJBxbCGQNjlX3KpY
j6M8OQ1RNEHYanNPCdUiXEtzuq3lQ5Akxy5XbWqEvEJIwRIOQV1133FjdGBs
53jghtcEeh/W31s+cQZZvW8kdZwJNI3Nn1d864XevDCpxFMMslQUSnNiWtEa
Gmy86TGBwzf+LWkFPozGplfEpxL8Er1hK9unCori625KwTRfUurC6cKnSC65
7bbMk8A82VdKENIGP5Ws6eUVBIUlYWcLqwqwZXqBaYkrzX9x5ozfo7swnDqz
6s+tDPaY2SaGbH8CnwWnZlseJbAZXhu98Y4Qmg+Wyf0pySA16VOHq2YGjCpr
Nu13Ifi5Kt7pMP8hgvR/aHZjE3j31+vCsg1i1fEtcnUEVq6v7NvrqjHD8PaF
lDBa3+pKFjePB1afD0+xiPYjz6aK/YSPf8U/Vc1rIEifyIq1eN2OG+UipYFc
ghyFhm62ZB3Ujy1cWk/xbdrlVZ/M5aIn+VbBHjeCkMrQdIGoE3xFjvkGcwZL
Ou5ohH8thaz8XhJzksDunApLMLsCbJv8fcoBBFXyS+73pLUhN6FsVIHyF7KE
r/H+dgvqLAarTbII9opv3HP7wgc710vFq4niV76savKoHVw/T3vjVwRxN0c9
otivMDd6X1tnGQNZr+MKH9X7MLX128mco/Tbe8sijdU16E8vOYwQgtjdh0qS
bUWIk5SZuJ5O65vGhWs/CWEnz8vx2slArfzAWqJfh06/4ZbIUAKphTKhvi9r
kYQKy7IoAgn/Wa6r+L7Ib0r8VZvqQ/GwqLCxoA05inN0O/i0H2malo5najFn
h8iw9RzBhanA3hUaXPz86O34JOX3ZeruV4p+nVAfLZtKWskgNMXfw/mgEKxk
7tiBFQy9vyVFVNyOSf9ng2IRwdSaIUOtWhEstC6I93syEI1cfq470otE/cwd
S9MYjCeoH9xc2IfPNv9M3FMagl1AgJl3Dhe7d+pkOlE+rBx0dtZX9CC1WDXg
LycG+WsUPyTc4uFr55fCkHKCnzSkzkSWtmHlYZW+7De0nylzejXaG5D9WtPv
wkWC/GZzjnsMH9Ca3BZSTZBRPEN7RUw5nB5Iuf5znOptjbNZ3mQKVqTHN9fT
flzRivst31IAOZcyBaNuAv6qdKmXoe3wHVAfzE8jNE7NoKm7DdGLht2DX1C9
79kWFCt9EQmxMnZHaHwqJysgetcfeL5weZSpB4GsibvtG60eXI271MEbI9gx
t33urHl89CcPHz5bQCDmZproG3VjKtK9+OMhBiPnKk9/GW/Fft/1AqaQ4q/6
1mCt3QK1H73Nlt4kOGEf1J6X1YaBnbuKy4WUH91j44VGT7Dx/RXVSsoPt3/A
8dmcTuz2ipL+h+ZbP3pEnTNPAPZud3FkH8G7ZF/Dfbueodw/qrHUnSB7x/VH
I/IicO/+kO1mweDD3/VVrUI+stz1829RfOEvm8UfecWYk9aQ5HyMznvQ3Q+n
erpQsEpm64/eDHxfjKx2Pl8P0xPnul8kEng+3a/t+5cQDjrzu6ZnM3iX6eNm
v6YEDVXWErFeBPeVTyzv/7sDc51MF75XZOCYatA9/msz8lLkC+IzaX3nrwUt
jeSjtfUQgu8TCD5b/Rnb2gNNjntRnj0DH5mzuXccehHR0ve79hMGverZ6zeM
tMA0hv3pIz0/7CfhusC0GR8X3PJ0on7WnHd6ydNGIfz6tKuV6PyluuRPvR16
imX1HldfUz/Lv64VXPDuPlj5mzhNRwhyhX568lvrEd6byzej/ivbIr/Nw6AV
gvZLwZK1VA9tSWoRCTmwKzF484Ket2+bUFh7kQ9P1dqhTOqHV0KbXffevIiv
lX5BrlQPeuKiI1NDtWgLt/e6FEPACU6TCa7hwaji8dH9TwkOzibZRYv5CNu3
MNuK9s9ls6yS/vogPL4seLeTxi9W/ffRHsM+rJxy5Y9kMNCYuLT635QeDByx
m2fpzqDh//L+1qk9yOGl5Yw5MyiLbU2ZqupEj227WvNiBnaPDQNn7O3AyVeO
zrfHCdqVCkf2LGjH3G+bhAwh+KtrIlvJ9A/4Tby3+PpdP+JE2+mvvRhyiH+b
+zv1l+542TH2Y6j7bJHOpv5ds8r7o65tJ7j/08n1W8Og205ZTVWlE7EJUWur
9zIICv8slTrajgr/gQwWQ+8fVQzinQ2CzRj/5fd9dHWjjmwcpwfGUleuFXkx
OPgyQj/fSIRtuuMRSwNpvf43tUriBfgcnrmuej7Fo2JyuuxTB1zClrN3fSaQ
H/BwPCfg4Znm5MDMRwT+2/b8NouTj9z7rQ7f62OlRY57bH8Bu7fTPsZXKb/c
urg/ujpx3nqdJ3+IIPB8pqXSswro7WaZtFH/rmgUTt3zj8NosoHtcVrf9oQZ
N7bIVeO9xUrzhnACdkDr+40cIZRmvjucO00wf/iE9AOzCrC6e33ZJwi6pT6E
aubysOPBE2PbuwRtE4PHYu92oej4FTOrAwwesUJtVU5WIrOatb/+NPXfrVJF
d5TjsSzH5a4XzZfhNdNBcLwGJ5WX1p8OpPxXfhFl/FyDzCSZs3p0vwkE2wfl
FVpgHmTiv/kO7efRpoZDiy7hisvRUW8a39c1ucKGU4742ytXcU4RqFnnOhio
l8I9RU3d+Dc6r3IlzbUKJYiMLJPfQP8fzIcGp1jveqDrVyrFtWUwIFn9fL2C
EOU/Hoiupvj6hRfuDskKwSt9o2ItxcBkUfgNmVt8PIwKfL2gjOKfjIpIM+DD
5uHffruo/57Z/nDt1+ZufPIxn6/8K53PX4bONAblY+rY4nUbqZ6krSIO3hcV
oqukcXCmN92H7qvFkrxqWDc5GF6m+zeGUxTwjfpZw1Mxaabzw5o7uEO6ogYt
iYb96RG0X9yDTVbXHDBxZt6azd/xWhXo1HnUIVpZ28uR8hOmbxU1S7sGhx5H
+mTQ8/8BfEbJKw==
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VH0bxvGUqEiUhGyVKFG0KOoiW4u0PEIUKm0Usj2UUGk1IipLQiVa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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41dkfxy2FhhmSbSIMKiNJpaYMve1kkIQWS0Q/iklDUlPJXohsEWNC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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4lekbx20xk6WNCMXRlLVJljDUt5oII7QhIlmTFkRJRMjMRKESMjmU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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 170->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4ltkblmw1mkxmDKNsYxpbKpSt3BRDxC+hqQl9pDIiTDLJ/jUqoZQl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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k0VW0bxjXLW2QIrzmEpEiSIpfKUEppQqgkDWYyVeZC6kWRZEgpswoh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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx6VCQ6NQU5JEdJNUpiyl+RBZsoSyDFHRYr1SdmXfkmgllBoq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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs8lOkbxuVMIp1YpWQr61ArlA7ay6kDYamUbHJIG21t6bQOySEkh0JO
SdjYKVJsxKytnyEmg8bMNMZhaGbe9005zLY5pKy2fX9/PJ/nc/9zf+7nur7P
da8MOrXnqKKCgkIuff5/D50Rm2Sn94NY5VWyV1OK6rqTvM+VXIw8ic/sayJg
EbNLq9CNhZaOLew2Lomj2aWaIVc6YWFjqLRe7TVif9Fxuze3Go+mdR7Vfkfh
ieKcF7o9YqyPud+UWidDsPePZhzNLniXrr6+kE/AbWe5flEhBz7sI5kpYyTu
Ff3LfOPBBG/WPf5NIYW/tfm2ybEMnFnis4dwoRArfyft0HmBB3sLDVMqSawZ
rBv45MKF4bcvFd7eIaGgHRzmZnAF4fc5G0L9KBRn7KrSeFiHLLE6j3GQwqJG
/bP1VZ34YEdebeGTmK3fG02ks5BQXJM7S9cMT6M0K7EYm7vJ+zd6pfAp+FpP
5XkHnM5/5kwNknj7Ovbx+5h6rODeuPLZkILCiqsHz/Uex+ny2ZQQfwqW+9Pe
HLbqxnrG8rZPFQTGolMHLvzZDOvrt13KW0jw/vlOfvpDEza+7DGdGicRzMqQ
F9vx4eQkikckiXG1r3aUfvMUa6wVD4f9RMHNv/kgV96Eh7LWndXZJOzn1ZW8
Y7GQWbvZtjifRPJql+BYCwGcw9WcPgRSkBo8/Nkv4g5UeVnOmXTNjX9/ePQD
H6XOzLghiQwK6seP+R0KgNyRnWhNz9srXVc4612F9x6+DfHeFDjvg8dJ60EM
RcWVfFagwHwr/Tu24xU2OZq+ffNJDJYWlfd4Mh/CiMVDc49QsA/5ViR2zIGP
f+rUUlpfK45N4wdNHq4VTrjebyFgT2iOPinnwif1rOHzJSTSZLrTWzeIsOZ0
0vl/7kjRcYBjsiR2EAKhpb/UmQA1eKPXLp+PeaZx9hkyGezX+sUHeHbg4yGO
tyiHxDm1QxnGM32I0Sra1vtIBqPhE+ZGJkIkNLb+YWlE80HUO5uFtUK5ebJl
lR6F8N9Vhf1UH/7VXrt2xkoCp30TJsXWL1DSFcae0qUwmyf6utZBiIDiNY33
MglcDnkfopHXhLqnbgte51Mo+W7i8UVJI263mTIyNtH9VafLt/GYMM6+WhBt
QME575yb2vF+KGl1qJddpLD/s2f92sUccIdif9F9TOL8bt7rsSYe1plNC8M8
CHxsKX0oO1GLJQ3a8zzpeU+bJ00avarBpTs/+WV4UCjNDrG6PCpCorbr6okF
9PuCDM5HqD2DfP+acY1tFNQtVl/Z9TQTs1FzDdto/168bCgbVuzAjEatzd0T
FKL172nPXfc7nCv0QpI9KYQ1zhuyU3+Ac5aLSrYfpRCgkjWxx6MS84NFx7iu
tP9blscoTbIwpqL6vT3NI8v3ZnRMVhesQtoM9HwJpMhVlQUTQjzNYsR2qxAI
P6miMzv9HA/lcfdvCUh8IeUS3xoeBsMNnhYZv0bklhm2uVkXWDW3dpUzSCwq
lSUHEGJsCGItd2mUIduYcXfHug7seFXvHjVA+02ZtMl/qMXQqeMbNxlT6Iy7
3dtwrAWsYKZQ7EXCubh7cZqtCJqh8eHzUqSYn6USIVUowc6bc0KtaF7V1dzP
JJtfwTrPoFuhtB5rWcXum5U6sCD6+67rtL8/Jl8MCnTvgatLmTyhXYbx4NNa
Y1p88OKSQrfbErARtPNOsnvQFGOxWiB8BWHKzZhDzb/jp6n0P4MdKZwZ9Sd3
d9L/s/E5E1tJLJllhCpvY0LXKXV1oR2FZHPF2GbXerB1So27VGlenByX3VVt
gEiW96tXOAVKacQkRbUbBmLzS3vGpejfOcGwq+yHAuPk1pkaKWovXLcY2s6C
l/IpJ78JEmahOxheV5vhaD7saniAgs/5iJkpBSbme9VGztB+JVw7uj2mpw76
3bWhWpE03xuKl1nuYYPsDwgvGCDRS6Ubh6dz8FdOwKdLSymMHA6ZsqkahP6m
jT/y+QNQVvUOl9wSYsRnY09XHQGjxRwl1esXsL9atphJ66c1/sOMY1Q5HLay
3F0DKJT1lTZ4LGqF0FliNcMkEdQ447VvSz+i9634eTRcBgfz37Yb6vJR8MfG
BgcVEgn1o9LAVc3YUemtEaBD4Zvos9ZUKhOB0ninLFovs0vHgrcvrYCgICrK
bT+Fitm7S7tUBIim+lN2BtG8fZnuOfKsAfNZkVdJW5qHnEhpcjYPte03h3jv
CKyyt196wUOAB7n79POTSCxM6H2SYNmDkUmHiE0SAvOlvrUHM69jKEeD/YCe
v23TmY8uyi3I6kv0m6H3gaVhkUe7fzvs7/3Vlr+Mzv+QDdQsrxtDpQZF11pl
SHmT4LeKywdDrjdqEUbATh78PLeiD+FTD5tMNKRIsInXSaT40NufLazsofX2
cCgXXOaj0m/nyrEaAtVeHpIvVx7AmSc0FdB8Mh3+SCpLb4V1wvrhgRLaX3jo
WDZ3w68p7tRAvgzKc4S28cNt+Lmo6ngFne+5idUFrdcEuPu/CHf9jTSfj+re
t6uKoNgmyf8lRwZ9Y33d1uEOUIbsj0UcEq55cSNrvu/HsjRCr+WsFIK9vmdX
iAegOt9xwHSVBEa7WQv147JRERiY2OdL+1kSesBjgo2qlzrP8yZJVJjfSr5s
IMK+b+x98qLofRVl++jdES7Ufd8uMRYROHxypbpGXD16NuuNdAZR+JU9fNgs
rQqVAQW5pom0vjFl1NS1FkSOdfp3alO0Xg285Qu4+Eg5nSijCASrp1XkpvNQ
dODZnOh0ArFutp35OdnIGouws6T9KZCkTt7RFoObGZikspBAss2//iunqiE+
1nfu11S6n6P3rkZ+E5QqO4112ih4Pq6cDTFiQ1F30ejeW3ReTUec0KXnX7fC
dJv1MXq/nWBoWolFGNs9+qzhHwm01yZWkTwWZMXazxZ4UXSeLT6ll8GDbstg
6d/lJFKecBJY/Ht4dMG3FPQ+u5R1u6dxsBu/GSlZ1XxFIoN87fnlgRCbeZd/
Y7ylYLylcsjgBgcXj7Q7/UDzm7Ti+KXzp3rQUGhfsfmQDLzWMY69Txck2eEf
E2g9t+oVfus8KEbBiwWP00Kl+A9Ihsc+
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 171->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8lVkYx2+ytCGRSGOmrqJGiKlE9RNtM9MgpHCbabGnLKOSrTSJlCkl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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHk4VG0bHyr1pkWFJK1UikSIIj9JkhAtSPYthSShelUSsiUhqYQW+541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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk41dkfxy3l1i9ijFCpwWAshSwNJt7NUIlGjcrSoiQyxpIZS0oGWcqU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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk0ldsfxpGkQSGipEgkVzcpU9MjSkgyZM48pEEdGkkZGohSVJyULoVf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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 172->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4ldkfvyMyFU1UUlFIWZvQKCl9bEm0GFGSLSOEqNGUO5aoX5YyBiGV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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2kgVG0bRokKSURSyNLyKnshddmSpFfKa22RCG1EsqRNoUWWLBVCoaSy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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41dkfx42iZhQKkxBTSSUZaZmK8VYSERVJ5CYUKrJVpPTYI8SMtVAY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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs41Nkfx4l2hWS1S+XRShaVkFVJ5a3Idcjaco0QueYS/WiFYiMxwkpC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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 173->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns8VPkbx4WVJZd0G5dalZRLG9GmyEdsG0KtVJRQqaZy10VJLrkUipKS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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3dcjf8bxpNEStKkNJSMtMyoL5cShZAiaVMotKiEJhmpNFApNIQSDSpp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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk41dkfxy8TUSrpR5RQGq5InqKk8iaRrLOUZSyJspStGN1Kkl9ZMslM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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4lWkYxiVJltJmJIMkRZSMhHTuaJkIISJqsrWolLJkmbJUx05ka+Kk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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 174->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lVkcxnUpyh6qUZZKpVGDkjHUPPZUym5sI0SkUGqaGlkqEZEURqIs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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VO8fxSUKydoiIdS3hGxJSM4klSRESkRKRKmEpEiRbBFKJSSVohKy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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlns81NkfxqWSSohKhV0tISKlNCk9dnOr6KdMQmiNEl0kWSkqWhERhZL6
uV8qYyLX3MY1DINxycSGmTkjkrastiT6fX9/nNd5nX8+53Oe8zzvc9Yxzh06
ISkhIXGPGv+f1epMCnRP8KHvUeUk9UyI5gyH9napBiQ7Go7VmRGob5ENklvc
DI2Psplq0yJc3TNuMFE4gK01MtdzfwgRVObL0pnPwS6npMCxBoKytRHGpKIO
OscTD3m/IHANtTSX3tYJ+8N9IzvixShWYRWOFbAhpWMheTVahFiF3y6PfsiH
FbN5jXA/QeL74AHj34uRFLs9J9CXwOyOhHFMThtiYnO8ek+IULPDrta/JwB3
g9wNha4ET89pjewN6AP3aUc+r1oI6xbVpG/gQDal8k/tOwTHc+KtQ/9lgz3e
nN9pQfD7U82AB7sakZNrKzibRkAz54ToDreCpeP2avN6MT4HKmh+q2+E7HLf
P09S+zFqlIInOK/QMHvUYtM+IWo+C95ZXq3H0kz9xVe+Uud1CfmlMvQ15gnO
WK10EuCjlKO8tXs/Gv5ZIPNudATHphiMjuccrCUzh754ivD2ks6Yn7gDdb7L
Y0tfijAqWYHXJRWwvFj7cvNagsqNeeujvQdQ3XBMvTaDwOCIfeUS3yb4qbVH
brtNEKsdQfMzZ4O/J79D9TrB1ycXPSIEt3FzWv1ZljNB/Yie6L+CUuhdXubD
jyP4QdtU2SF+ibBWeeX0ryL4P2j+VDLVDVsbM3OZTWJcapl2bOT1Qzmk4Tij
bxj/Mhf2qs3wkB3cesd3pQjDKVunvj97hOZyr51STgSZDya1NsXn45Rh3Fz9
fwje/fNx2a0UDqoNtyaEDYhg8NvJOUsHFuRJXTA9iGBrsJdBSXgXCqv1PN/y
CVKD8w9lj3Mhf7/yjms5pecQc6/O9pfQ/mla/4EKpf8Zk1x6Sw28leMqJnYR
RDZf3vapsREvZE9diYsnWJ3vICplvUKQ9WiCWYMQTekXYs8P87BhqM08hS5C
/9DPsbM53TgSKCI8bSE8L8YU3kssg/AXDRWJYIK1Hj6ThrRecAObvL5R/W40
sjXJP8vH0fy7NYMWAiSayh4mzc9Bf5rhdDiCgG59tnbIvh/0n+USYUxgEXXw
yfuLHNjTp6v530VQMxT7vh5oAMn8Q85Sj2DKXnEwjtaKXSF3c0RiAuti2Mks
asPbXA8lj2WUH+VDeY2uTYiJ4oyZpxIEsCvnZmYqIM3am/7mKXW/yYfcbpq+
wlLtvqH290JIR+tV6g/Vg75gXhYjhICpd8voI2cAsyHnbew+UHkoGSiWbo1F
ADOe1eJOoFGVqlYU04tyOau72RkCWEXK7j38owNRyz9tscsmCA4Ld1reeh1N
ClkZHBeCdnWO2q2yfuTTdKFO6fF157GXOQmdSNybvJS/QAy6+mrf8x0lcHIJ
DRP4EJCAdUstH7+Gwm79PaVJAgS7lr7pnc/G402LPOL8CU75SNPsXfpxPaQ7
7XMnlV+drAElVhdSbC74z9MXY1jRS61hYx0G14wvmjEkkNfZHaraw8IY9+up
U/sIpG0a9i8LrIKNS8hODQXK/+XhFqoJXJRlNCo+P0HwWC9pXuIRLh6mrrK8
2CpCwg3Tm012VP0VdQ8bN1D6XNBe/FGhE6u6bx/b7SLG4xIDWZ+mZpTasC03
8Cl+Sb31XzGRC06JZxf/GKUHa53qQWc2uj+rMfR3E1TbTTVtWDcIj/QFqza+
G4TvGuOd6V96IHDf3tUSJwQzMiU6n1pPea/hO1I8XC1d+xFpXMSKpJwLBwj6
X+cHVWnwYMI9/4ERJ4K8m3qT2ZlWmEbRDH7dJ0Ymn+tV3celfDs0oPwrlYf9
uR200jRcGGWHbaF4VvQH48/H+jysqQtgd7iJIV95UCs3JRvNf005p5tQ57M1
Xr1g+BX0/eacfY+IESB1LW3Cjw8f4Rf9J/tFMDM1WHVurh0P37uFzKP4+egX
D/uqPC6q52SfMLgU/64efJE82YueKOs2w0diJDJfnGxXbgPtXb9LjbQYrGsO
934fqYLyznF3sRbl99SEBJkDfCyblbt0bHQYZmVy6fP9GkGLrP/Jp4Tg+63i
R/InOWhV6/GZriUo2aOlaRLdgMwIsVv4EgKr0wZX6TNc3NZhR5criFEjl+xt
cbAXh5I4k5rPKL50kpsu9T34wozNy1YUoyqBtzE0shOtQw6PtlB5ktR86xXk
XIcDj1+MO86JMKdbzpLw78Ob083xv60UonOpu3H7DzY2FlV0fm0iCKuuciq6
wYPnw/GCimwhIj9LzpJaHt56yl5mjwkRbMI53RnehwjJNKcPlF8Es53ZE5t7
4RTyLepaqghFY38vr3Tuh+XIuZ/uU/xJ7VDXiXyYh0+/0rLcKb6uXxLVduBD
F47Yy+2tui/C4TbPRKbtAJgmYUcXaw3B33cHyyCZD6e8oaKobUI4T25OljBq
hf/zi01Od0WQiN1Rb/+Vh2UfvNPuzQlBFyr1VwV0gKYpb/KcysPxmLPjL8za
IF9ww279ARGC5s9KBS56A4W8hQ5GkmIwR1yZV46Ww7nszEQs1Y90QctShxuF
oGXNeRRbEdhGCrK3x/XDT/VMzcIDYqz1HG5WWc6DT5fxcfo9AokhrZKTN0rw
MkPxr7xAgmFX5VWajEQoRfqq0Kl64Wvrg2iXeFDKjIj3OioCrchr9VgBF9sc
irkMSzH0k61ljuoO4kmSgsQf5whMAwsupS7uhtzWq7p1mQLQfWTWO5oOYjI9
2mz2mhgttElbZ7VOeE9nqTRR/4XJdtVwxvxS2FVm+gemE5QqGU10vq9Fmmz6
PDNpApVu4+FB2R7YPOfGfBNQ76HujOFqDQ4KM/6+m0v5q13AWMEa7gVtz3em
kRTFh4WNi/h/V8DEs/ZyNMX3xN7IKzLOxfBWLM7rv0/lSeDb3t78CikyN8a8
NoiRZOQm2p/bhaTEXS2HmSIsYIgLw03/guZoTqS54zBUZz7fNpFrwaTW6RX+
RIR/9y3J2xfORs8ZMWMHxVcLs2jdp219KLRyDSmaFkDbY3RlxacKaMg7K44V
ETQHmIfplfXh5/1yZ1tOiPE/lt/GHw==
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk8lHsbxh1NHFJUzoRUZOkYLWPPSS5bUXRSlkS2VEKy5BUpSymcKMWR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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 175->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lXkbZkYkXyohLTiO0nwx6Ms2VLeiZWqSmiKVyDaULSOpaLW3kA51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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k81P3Xxid+2UopSgslEQrJFqLLraIktzZaUImoJFpQN0WWihKSkIQk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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81dkbx1VSFCKpUJEsrZM9pI9KTbQIUSGMDKYULUgLojCyZokQlcwk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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lekbxkUqUTGWyKRFDZkszZBILmPPmGwtKJKxNkYY2iwpDQaDhImR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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 176->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lekfxjmFikkTI0qWKNpmlKY0+N1kTWoiqaRGshyNZJtQlhIqSfYW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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VG8bViHZUkr8kiRKWdOCkltSSSURlZCk7IlCISmlQomIsqdFtmTJ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lWkfxm3RiLGHhjdlbEljLVQuRaQsNZbkVJRIeaUZEqZUY0loOmGk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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk4lekbRlLKMiGX5WQQCRlGtkrdhoNja4RSkgwtKoOhskSpJEaLzMiS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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 177->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk0VfsfrV4rFZ4oUREeKRXuI1Hx20oZFiVRytAgiZ6pXhF6kZBeNBlC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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4lf/7V4iKkqIiQgNFZgPlpaIyKqtCVtKOyKiPlRX6KPkoI1mRGRJl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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk8lWkbPg4tI30hnyyRSk2K+SrLlOgyZN9zUkqSLCNZkqS+fElkKZMW
WzLUhER2koQOssY5zrHl2M77noPIlEzWyffOH8/v+eP5Pfdz39d9Xdf9bHbz
P+xBp9FoidT6Z096Fv9qh1IjaKXnZiXOkwgYCIgQqsYiIF/66YUTJFzL7qVN
cfLxsWeXh4wjCbHzxltl/Vlwq4lpz+KTUHX12Fz8kgOd0a1X52P4+MO10m1g
/XtM7oycnh7gIyPONqHNpgLRc1Hzhj+TmJwyrTBZ7oel1lMbnsEoeksHGOlB
PDjMpkhcKBaCvot9reXbB9i+sNktlkzgiGqo8irtDqhphfOutRMwudjwuPlF
Jy626y194vHhHVqoHe3CwbacJfZ/z/IhLeLzzI1673ZuynsJBRJhy4zQYfMe
tFcY6d9hCFBbRHe7bB2F4IgV6dtcSBTGsBSuPmmCS1Vl8vqHJHhbj2swFFvw
aM/1Yy0O1P21OVmbJbtx5zxrPGe7AOH9DSGGGSw0igWEHZwgEC/c7CxONkKZ
lmjEoOpbepJdfc+HicCTmdKEO4naBkVCLigXvOjNjsMUfjTR0HuBVu9h9rCV
98lNAMklV1F6ChM+P2mo258joXxspPxRRx+2rDp4al2BADGLKoPD/l2IajWW
zN3Hx1wj8/n/SlhgKK1U3NBDICA06+q143l42ewSqr+dit82wdmWMICCTI9V
+Vp8BNxX+xxV2gFnyd2yZ40FKNVfGKy0aAZDdAv/63sCrNSzJj4K5ehjWdsz
XEkMugQrSsWzcb3TfN+ROhKp+62T9dLYEO3X3JxRR8XLKLbUkq/Dg+D6R+PW
JD44VX7FYw6K7zQTP+4iEVLtqvp8vAzestEGH6jzDO30uFEyHlck31UtOJNo
yv1l7+qCAmilWiXRKXxoE0lBEWQMdE2vzw5S/XjaajbmkdAJnQb2MS8nAVjM
YvbOrF4Qaak2HpoCyPk4IUh8AIV2nt1iqnxwVcJcZ/3qIO4wMhq1m+qfl77M
nmf1aGu8FJHtQyKP5XTm+Pg7NBVLJnKo8ya+5kr6XAM2NoTe/aIigFae5pYX
9U3IjzlxxtJCgJYpl2RlnVYwMn9OTx4gkBVLxP/+Ews32zsGBUYk+O7pt6oX
unFE/VEKlyAQ8si8JI2dh17RoU7mKar/4Wfjnf3LoSAflNQvQ+LqxNhHsR4u
JBPiN8TV8zGVV7nO5hQXU2tWXru9ho/e4fDMz/frMPJlpa/7AInStX87VS52
IJZUal+qJVFRdOWcgW8v/jBcfqh0msA3686S4ecvsbXCpngVhVd8myJuyxfC
xzbQyT6ZxAp6buLknn7olurp8XUpvlhUvW2xbkLVptFmOpPiSxKtK8ilABOn
7K/Cm8SxDd6+R0U42HBkXmW6isSX2pN5o14saHnmOIutJxCdIvhuudiDQ997
vu9nEXgU4aCVpNSL5p8sy275C8Co3kcj9Tmo2StyKGwbiV99kx1LVuSCdeCE
9C5jEr9nea0RF+mE6/1+c49MAezEX1Z7Gpag/m1s/qYQEtGheXHyTlwoPgxT
diwTorh818aQa704edMqkAcCwxeXHMO5TMhOrqbby5Jw6ZWYLK7pw4UbVwy+
0wSosOms68oqhukTxroBim+BgRo32o06oR2nMc+7SKDabqjyTX4f9hoPn9Bp
5sNlxsTqzOEuyMv23U0vH8FG3ZhxZb0eiG7PPhmZIkDqd3f5O9kDcBgTVR+6
O4Tg3XcVb4jxkCqY3WdylEDtLHN7s0YjfhNZVvvhPQlGcUDlK+82eBqd0Ry1
JGEXnjR5mVEHhQzzuG+UX+3XNpBLOciGU8JT0vcmH/pBL+mSgT3oqWi/rkTj
Y3J2Z9rFpiZIb//mJ2RT/pY/9GplGg/nrcdmljkEQi1prwtbuZh8OyIxeZlA
QVB+WUIVG56j+S6HvxCoeOEkNjBWCzUR7dYRJolz77dMJwob4bI1Yc1pGxIf
VUw6zNdTfD+QZ/pNg8SouC43I4SNmiPemqORFN/sZ4//Sfmd35cmcyNTSq/C
aQePS5X4vCn2+MwTEre79Cc9vTrx4kbjaY1/9KI6mZruxQQ/4dnXqFTK/1Nc
RNjub6FHWMEvnsTYuVMef4U24JB2P8csXoA8dT/TiXkuJKRzKl2dCOQ7Cx0K
TzXC0ISllAkSLYKOorWx3ZBMt4ouDyUxR0sMwKd32LFDx37mKZVP2gqmKvcV
Dijf+6/uDxRfpSJjR4eZMDGsONlWTPlr/ESwFMmF8Ca79iqlvz30+amGOyz8
lRZe/eYNCZEiG7u/ZVh4bJE7Y7qKwIwP3Vv5XQm4HSobkyl+RgRILrceLEaT
rEd0AIXP3P2zLSkWTZA6Gil3+IgAO6f+MFPR6cfgwPrM7h8JmD1+vbH75Tso
m6kp7JCj+Lv3P1Gv9bpRUlPz43QCiQeRBVVGln04/TVHst5WiHUHdBR3GveA
3jFMTxvmQz1v5Ve5Ay1QHtqrzmVT+q229b0tfIXImByOQJ3yP4dKC8cPtbCf
+55ucJrEb699tWpFeIjoClj2CaP0l+fjYfixAzZD8v8qpPTPVV+dOa3xDDI7
HJhq9iRYDeFzImsLscx1GC/0pOrp1VJgFb7Fwtls3+dlJG7u/2oQ7sXB4QfD
cifsSJT5+MQsBlN+oR77JmhwGI41f7mpeVTBsznDeOcYgVJ1KTOFf3cjaYWf
ieYcgapPy90DUY04yltsqz5K5VvwYH9wERuRVbpFhVR8/6Bki4pfqH7ISAj7
jo/g03z6ZytlDipDFrOF4gLcenxpZP+uJmxjRW/TpvC7sr7UVjW3C7eif8m2
pea3rkl33JvXbNSH+WWcFydQeCLSduYVB6bjmfnm1H+CdYAzN3WrFyGXLgQU
2Ahx6MWfT4ou1sDdM2HNahGqfo+uX50TyiF1d9BC05/EQ47XtYyNXLRfNgn+
IW8ES/REM8aHLpgk2m1RmSYwt6ZvQX+BieqWPx1lqfnMaNwiFTTRh4Vj14ks
tVFw3xFveHMlcE9O3i2k/D8wwmBTmAQbcRaKvy7eIjEs7awsVteGnAlFmkwa
AfLvyaCAxDpUbQgkpQUE/g+NrMk3
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk4lGsfRum0oJIthjYiOaKyHdU952uT/VAqtCGFHJJIC7K0yFYkHdGU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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 178->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs4ldkXx09Il6GSUOaXmsoMXSTlMmr6qjCHRkhMI2OkQyMaalAuY9wa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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VH0bxke0oZAoFZESwpMU8vBcQiUJRZZCJSQUqUSptFrSRknIHpKQ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk41lkbNm0oyRBJUzHK+MJM2ZLKLUtDg0yKdySkLIkSlZgmEiIqSray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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs4lOkblnJoR21OJRQlFhttZSVbbsksyfmQVidGZEOUyCU5TAezndNG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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 179->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVmk8lVkYR4kWQooWEw1RkaHlltTflEER0tiaFnJVQpIl60QkQ8nQSumO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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VG8bxomoqJR9/akQSkhFpS6hUqFIe0SSQtFiSRKFEFKRrKmQbFnK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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlWk81ekbxo+TLamxZpkwNURZImUSucrIKJQ0DUKKREgKJUsh+hOVJiHZ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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk01ekfx62hjFHRlFIqaSM0kdL0tnUqP6HcqZtJighZs99RZCsi+snS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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 180->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8VekfxzHJJCpZujVaUNJm1MhPDX0kZIgkeRHapGxZJiI/e5ZIuIpu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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VO8bxkepJG2SUlIkUSokJNxJi9Q3FFmStJItpAhJkiRri1Ck7JRQ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk81dkbxw1lMmVpRkg1hGTJUA0Z5CMtthpzkSVL9lFR8sOvSK8KISZr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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVWk4lWkDlmVQQqnQIkoRKSRJk9tI9krIaKI40aIGTVJJqFDq1BgUooiS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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 181->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lekbx89UlrIkhXapjDMx0igjla+UJdPMVYaEZD0lIstIMSYNv0K0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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8Vf8fx6VCUqloSFJUZDSEUnrJKElIoiFJFA0JWfW1Z0mKkJBZIpIy
s6699712uPfc65plFEn6nd9f55/zeJzPeX9e4/nebnZP34KTg4PDZAkHx/+f
4vtv7dW1T8YlKfGzAXcIWP5Zl0qTrwRPYDenvTMdhvkyt2+c6sQ7j7JTyqv6
MVZwLLrnaikoJT/Yf5wIpBd/zBn71Iva0MgXD8yHYUqZFN/KjITA0zJbq2sE
/G9zijQQtXCLcnC6mEog2S6jUPFbEzZ0HpwbURvAvlfs4B2h6VDftvOWsBkB
Jz2p9gr5TsTfLzBMDGZB/KEHZekGChJ+Lb+brswEx65RvRUumSjzvn+mUpHA
wBaDBOOAOEgU/Wytuk8garPkj4ElVLC/jjyqiGYjimWgvOxMFbZ9ETVpv03g
quVs7OypDkydEnVWcGRA1Hv+NofFJ0g6nM1eZUcg01K8zUiVgu1lo5IbxxjI
qA4Y3ruWAs+60yvaognEcpoFXXNrhuFYWRRHHRN63Ae4hnKbsTxW4J6MMxNz
tbN904pUxA1de1YZPoTgoAyjlKZWKKzgnq8imHixjF2/5mQLdqX77MjhZWJg
JTE3tqEA+fdPnSvJJ+f5Y7W14P06HNs5kad/gQlRWfMeEd1wFGsub91Jnt+G
f5feI7WPqO1Q/in6hgBcZpOoT7/Bccve34pifZAuqOoas22F4brKiJh7TPjm
mcYYOrXBQbheypc1gE0qillX/dpx63fP4s4ech4749IautohKrDl3g0vOmST
3c9zfOpAiaB45MkldPA/t4034E0AR9th96yzBPYVF/qGVWdiz5jhsNY0AxG6
OVNDPM0w+S/fU/UdA+zPeiFCZQl4558trkHeZ2dSTf+OG+3Y+K1I/U0FE42r
uxj6U1TkU7cqSCWyMLO2qOPAgSTkF5x1LiD1wrtqZ/+LDVQY6uzfL5HGhOqc
1la5K33gVquRo+kT+Dd91Orp53YoM4+t+u07hIGIGvUk+S84t5lzZKs2qQdT
14Izw8mgrfWyS7UhsKyUc8n7ujZ0r85R4tVmwaYtJqSAWo0LFyUPbeAk9TI3
8kr7Thw2xsSHdSgT0FR0WhCYroFOr6WrnBodBboFmskn0mFsLB3AcY4AB7eY
3THJFGB/7jlJIfJ7X7O2XdJqR84HI4f0FWzYeA8v2+tOxduY7yL5OUMwPTuT
8mCsFKdTqoKPOhJQsFEXdIjvwPLppm41FgsnFFSl5Nt7sLBxj1vW4Bi0E9Zc
9rHthHSOzPGwYALC6gPqAl+b0RDpJdirPIQMD/MniXfasftWXvK2JBZ+TFiK
b7GnQKHEhk/Ol/SbhJrqTI0Nao9w6n02JXCOW1G0bTd5HsnCwDitIbhr093l
Km2x4niJ6DcTApXj1XEHVnVD9DLb4cyDAXy8cHZsW34bOHnXOzomDsG4jELh
NKHh0rlsRd1vfRgQWL11kScPlSUGsnvKCejxuLos/ZyDXbR9WjvNCdyxEqh6
9LMJYRPy7R2adPwY9wwsYheijWJdaRFBQOXoZc0DozRMbC/Sjwoj/aG5WuGS
ZSssLh14Rayhg89/7uXhhkrckRkPytlMnk+T+rsnpArp0k4f6iTpSLZMOVtn
W4nTTtzZLwQIbFW0svG/UY/jdnsP9XIOoX7JPY7fMrHw9YbdxHkCm/6mjTE9
uxAxf8lz7y0mmj8WvtMxqcQypefWNskM7HlYM+GnXIvlNVojBu2DeHeyMSyp
tBP2z3VuasUzsXjkz6GLKu2Y1N785oILA6e7U9W/CNCQfltkek0eG+4PvoqE
ieWj0a9C8SyTzJMSmYXpuS/4ZvHENkCUwEelkCYnu1aIGr0u+r2+FzGjZqHl
ts0IVdp4SWyABVnf4WB6Jw0iMbwvdh8iIErsOuLzLBKRMkZPInUIiO0Z49+j
QQXKKM4SkwxccfR123S5B2HhtmkPpMn515axFU6VYtFXY++sOoHQ35mFOoo0
2HofSuvewMaIRuHKm7EVKHVovjJcMAiViOsen57VwX5xpPz+FiYIz79syVfd
4HGqMBqMHgKPyeSvCx69sNkKaRU3Us+xGaExHDQ0HnXi6bBiglVsV/YurBWJ
arEz4zcJ8P8w49NQSMALxqYznB4EEmX+8Wq79OFDiuvnWTo5/+IEP94/9QiV
Nfrk6DsAkTl72tJKKhYjrvck2vSBM4ylb/2rDfuqdq1NNR2Cwei1EuSUQj+a
zr3+HwOtgTZbsvfS0Psr9tnfETY4jg2GpW5xxKbLrFBnUr8Zlts/cqe/hZM0
PSGL7COeuz27nYRLkRgTFKTuwISLweEjDc0taKp9KP+TIJD7uF9WXroa6kYZ
nDVcBH6MrDO8R+ZzYNYZjzFlFlwe/zq4JLgXphUbbxvVDYMtlhiieTYHj1NY
pjt0ST1+55H8Mt8LTmzSmVFlQXtMa5nX2lY0Xg+/lfKeiYKLcuvVpChoHlwi
wBFFIDhM/3GIbwYi5x5xa5HfC1bxXtAoKsdYRdvj9E0sxD5baem92huWJ/Bk
9iqBQaFZQRvrLqz2umXvu2YAuXnZ+VI3ImB43aCEm8xHzV3Nz0cD2vG39e+a
kAwyny4b3xDsoCKTtnE6uItAgYOpk4Z3I/i4z4v8+cqAse/jwvwdHdBXe5nk
rTqEkv3LQwSoHdBmP1869ovAIR7JWeNwKhbG2zc8Lx2ApeyWJY6NNFR911xz
+eQAIj4+8uVxzkVI6lMxFVcCSbpz9f2xNNicTk42Hx9F7KTx/eSiYkzaHi9u
PEDmle6ZRhcjMu+Um7ydjJng3PE7aCiOhjRiddxAVR+ZT4L5vDOt0DA+XFjp
R0f0mOfaulPtKFB3N2mrJfPhsaeBvS2pN4Mdge/lhtDubikU31UDIT624b3X
DLgne8xHzjfAO8Mn6bkb2bcarm3a0qUoso55XilLoIjb/PjLLS1YQRlxDr/M
hNOrFTfzTrTiUdCThpzzdJx7JPdf440OmMhMvM3NHQEtSCZWv6IEZfMW2UcT
yfvVfcfJWEFFt2W308XvDJj27DB9HVkLGy+HRw8SyfxRPc1g/2xHy2nzh//5
k/n9d1vLqbJmBOYlHf78kA6zE1fciY8UcN13sRX8Q+ahqdOZ5JxqiNLrdN7I
MhEjlNypV1YOIVPhAHtvAqXPVONpqm1IqdaLOUjyV2LKeUjP9sC8Yj1baYbk
IS/fL8o/8kCLSeStIXkndrDRbVY2HmfPRXdLGBAwyLIqUP/XjsTz9Yfl+1nw
/bSfK+wMFQcyEzgNAgchlR70p1iiBb8F6k4fI3kidtEnQDsjGeLbJJTKyLzJ
Npz80DxOw7ydzxvFgSEc4UyYzfftxE97LU+fORaSTC4EMjeVwU03+5rKd1K/
8+PntUxawPbXrvrsyoIERe+/7rxOHC3hcDiax0QcbbTrZkwpQjNlvpqBic63
nV1Gx3uQ+eWvhQV1GIcOfkybyszC6Mze6oBPBFr9l9caXGtDGXePdF8R2QcX
zptvt3fEgpGDwQ2SH44+fSWZ39wN7csjbnhB9rdXyPU/wjQwLfmnF/iYOLla
Kum8YS9+TGWXqzePQetOba2cby2OilIoZv5MTPFGhJq21OL9d13h+WcETI+w
9iRnlUHo7y6viTQCJaVNWz8EdiBFZjo3XXQQois2vKJk5YPXdX72zTiD5MQD
r2HYgm+9AQZcwXQYZ283CX/ZAfmzYie3DA6A4/uU81OrZzANeZ1dTfZNyaZz
mm9Gm2D6stbsXBkLwucPso5n0bC7XPuuZi+pvxd7dQ7+qwLfqteRE4cGUXJ+
8UNpWjVUBnm3Pu1jIlthd6lrQyve9qmO+jvRsSfy8R2HjFbUeChXHzMg+6V7
1LXItx2qgtGvdvQzIBxXf6VsZwnqej56hpoxUM1dec0k/ivkPxlPGJDzvWls
8CK1oh4f34aIDS4l+eDgQtDvO0nY3K9QwK1EIOLWhMGbA/UYcf7wzmo1HaIK
XJNBSrUQ9/zD8fUSAe2AJdNWzwsRJ1h+PeMxgcfXHF10UsvR2lPZIDlL4OCC
jYFoSSk0IrhucpF5FxMr/eHfPhpSxyKsvU0GcGfw4HqKx3s8aRh5dJXkt2ZP
n/mQG2T/uo55ByUxQMxkfnTd3IodPzY+KChkQiV34qPShmKIrnZPm8whoDwt
H7SkrwyZEWvh1M9EokaZ36BSL6RSZKILHQaxMNRS7qzegLTn13+93z8IzSrr
QInkaugqVDQ8otFR3t+pm2lXC9lXuWsqy8n+X92R7CSejqrXy71255J9Ebf1
p97OBrScqU+jeTIxxlce8U0qG8vkXhic5SDgzrf2wYDla7h+SU98aki+v3h8
HZdIHa4njIn95qQjQzKQ8TyqBkXMfzm8pP9UVq2/neKQADu1c4rHSN77oPzm
6ZbWRPza3aCzV42AscrB1UseUCA2PF6c7kfg2KoYk7SrVPSayN9+foaBgKXm
C/1VVPy1StUqjyF5e1LjSpBaDkrHLF95k/qK9/+lOaNHgVm02e3j5PmjMmlh
4kwq5qM495fm9iNY7HfH/JEqROyeCb+XTsfOpkavJ5O1ONG5KeHzS3K/uybY
UiX0CSapTVPPSH7jHuq/UefRBqnUtl6NzWw4cR48fyy8Br6ygt8D5hkInXqS
u3WiHN6a0lq2pXQIZ4p7HrFogoIPtXvdVjr8u2Ut1Gj52FE26p/USM7L06BQ
RKQdtkXb+G02MrCPntwrdD8Np3XzlIkyAhKC/32vX9qFdN0gzXPk/42VVn6J
lm0A269m/pw7He42/pUvGTSs1Oq7oFE7gF6bNJnwviZMaM7FcDixEWMobn9Q
pwayWmORfUoMSEgf4T4b2Ymeqi/8rjoMHDKOnSq/l4W3sqcWS8m+FB5dsuzE
py6sO+waUcJJ+mf5uHXE/o+4Jluw/eE20g+PCqibrrbA4oB2tIIiE+bX2tKU
JtrRbjJyv6lgCLJ5IzT9nT0wPkJ3vy9D9k/GI71xAStUbx6T/Uvyh7i4XbD+
tzZM+zu+HXVlgu+u9DNacR18w73mD3GxkJFN15MbSsauSZNmk4vk/mB99ajd
/vcQKrPT3kfmUad+idOhuCLwpOwbEnMj71eguVonkIaix3IRArpsrD1MSWo6
3Yr8aecOzvMs8Okd9rrwk4qZlhhp7mJy/1z52D5QtxVT8yLM0TI6OgI83GYs
m+E9pMny/TuIAjMHNr9lKYQe+w7zy5A8Vlio+UGJCgf5bO6+lWQemscd4yP9
U/hMKfI5ySO6X9aPp1aXorQ9ecEunYFOyN3vKcsm74vPz+0kgQtlPSUz/qRf
jQrv6GsOoHtL39T5IzVYlifiKCDKxMLcH/vNUS2oCF/vdOwu2c8PG0adhYoR
8El1dwfJh99t5I8dOVoN/xMJTFsyX0vYLvNL9J9APzC+cNcVsl+aIg33balB
YrDkMd31BCbiO17IPKiAEter28vJed0Q8amQ2kP2ZTh16rnNN4zs5XD9Q+/B
zYKiK7HjXWDLuV52GeiBfzvLQ2WADRUbk/IzvJ/RO+1wqZfc7zj0kppl+epQ
f0c0rr2RgeS4qkX7g7nwUp7ce47s/9qW/jRLeyrYS+/RXsqy0FMhSpGRrAbf
xenhe4IELIhf1J/SVNCPJJ0xSaZjTsw5uUCbhgPsdDrHPxaeXtrCxd/WgQsi
Nms41/Wh1i9PwWewDcJPSgRTVYZh+D1bLZxoRkHXPrfHwyzwp7+86/evCUp6
Mn8FJgeRdF9Sc7Saigl7XS5+6wFIGw9zbQpqRMtKqfhcUj+htsXqFVXN2HxH
2zo6mAke75SV79ZWYK2Lr2g6L6nvzBPTl8SroeWtLHezmsybkCiZlXVd4Plp
zHYjeVCfMvRTiOwjqrL/02ZrUv9q+3+t7WmE7ft3Cc82DOHQqbD2T3rN2BMv
Wpy7vR8Zas8tOldSsOG+wBzxHxNlKadPa9/7DL1dLlN65H5qtPmZmMKpFmiq
5YSdvTgICb3dIkIW3ciSl7wc95X081+jUFVGO6y9LwW9FWHDf8mh+V93CuC/
6Rq/gB7J48zPDy6klKPKgvlngtQPTU8vx27jF7RvlO9mPiX59KG5wrbaalwV
SuETEGZhoD7FozW9AQklh2yshkl9SP9q3ruiEvLx+Pebh4GnVknK4uT8x4v9
JBpWMrDDT+sdZaYDrtYL5rJX6HB47bKdc1sdwhJmBQfnyD4puGQx9qEE6qcU
q+9kM/Fl7iarYVcLFrV2nAiaHkLneMjOA02lKK8ZcdagkH6hrH90s7YUfzzl
Yg/X0rEruPjSzFQP7EQVdp9aMYzQUzdeiTDroWKtEtnkOIQBiySdNuty6L3O
V+gpIvsjw+PK6O5mcMr/jA8ieVYkO+Fd1p8WnHzwvaXdh4mB2PcB0e8bkeTW
d0xObRA3rFJT4si+l7rLqLSSpoMj1DWHf3sU7IuP8gRakPuP1nupqr9vcTPF
emqR9E92f6J+X2IblqePOeUSZB5mrvrvrUoC9OpVnQ6ReVi+y7FMebEHnkEh
DieNWPj+Vl3VBCQvrsrzMu1ioZXqSJt06YFEVouZe+wgnMpS04cHST+Hdpr/
NqODvWrqskpbFp5GRpdv+ULun1cf3OozSoPFVN1IuCoBr6KjTc+utiF2Z61I
1DoG5q3ePes5XI2Ilf08MCJwQj6wyMuhG+Zn4gOG75P3ebNC2OlDKegL6U8s
/hJYFJ3y6uHpwezkz/w3NmS/2L4RnhBuxr74G7d6fViIeplRKpxVDNcUv4yk
HyRvma1R/bXQBAnOdZxcGwiYJ0QNLckheSt/58OvUXT4iOrdkl7ZgbeKsVpJ
I6SeTJszM/SqcTFPfLr13BB+HJG7F1USh0CdBwfDST/MqT2lV/pVo9P1ym4O
J7K//CihR5m5cN+qLK1qQ86PWyWUP5fMR/55tye9DLxTWnPgw5tOrDRwLng0
xMRDZS7ecD4akge9dg3IEyA2Ldd39u9CTfC+/l5pFoKqasXe76DiqMw78xEr
Ntx7ObkoOwrB5/O6Y1yBwDzD/Ofoqhasvn36uOA2OiSIu1Pr9QshejKp8EY3
gWSjjoebpjIgrjh89iSbAf6g4l/2i5/xX7gHo02a1MO9U9szbD8jmtKffUKD
if8ByfQgQg==
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk4lVkctlylsSRRKpUtSe4kGUvUq6QFoUUqauxki8oSStZMY40MEyOF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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs8lWkXPWWiwjflUswQKsmlUBkyxiLllsott9xCTWIQOSoqJiFMBoVQ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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 182->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk4Vukfxt9EpMbaKFmGphUZLWha3GqSTGRpGQ2pyFLJFj/0miyNnaSx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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VH8bxpU2lBQV2pCiTUhF4UZESIulkkokKglFKmVJthCSrRJZf0gT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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVmk8lWkflnpTxiClhKTGHmUrKrpMTJZBSoulKFGSUBHjLccYS0ykMqmx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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs4lGkfRohSmf2QDYlVKhN9RFPZblFJtZSGSGE7LPGVSUjjlEjKoZNT
0WYdIqdIyplQhhETM4zTmJn31UabUm1kpe/dP57ruZ7r+j2/4/27b72jfo4n
5GRkZFKo8+/t+PCBwaWvfMTxbJPVZyTYqmuq2tUtxIWTVzSmBFKQX5xc8x4P
QzPjzvOZ4RHk3PzfXw7B7Xh6jRPH+p3A3hweJ5vDx2rXoc48hhTVyT/WWPbx
sNrILN1zjMAHZSkzYcEz/KDuPiU6TsDKcja+alkcvBl2I66eJCxdbk3QWQJs
XGVzPymLAEO/9SEjvANffMPUo9YQUGLUB7Yd4yByYUDm5AUSPj9Pbr9azkEc
0+UX06cEFI+l0g+GCvD4pnisblYMhryceWlJFeoXx39+aUlCJsfTZzkvF9WW
unnrHEiwQl0v/1PUgeDymCnbVAKeO40at+gWQS+H22RP5cOSPZsw+zQPNavf
uFY6Uv8jjeVUlldB50/ykSn1rpR70daytArDJ3ZbZWSTsOJ4aIWXsXD4/ct1
UncSCUb3f5hr4OLqjYwGp3gSO5PGbtjc60Oz9fcIe30pgnf1HM+SbcGCxXq3
Ki4R2JpYlb3liBAWZz5l7IuUwN9YJJrewENW5lCTcrEU3mSKO1HPh6hyUQgt
UYJd/sGuEqchZP/eE1CoJ0amvt8q/7RelIdPxVu/FYO1+VZQdW0Jwv03sVXW
kvA+1Mwx+rUKbKutbatNSWjGPhNe1iyHd3qITyVIxLV7heo7dcOlaHe0+icC
S70un+WpC1HPZYmZ4QTy/It/1P2xG6kRc6URciRMP39baVPdh5+/nHPcXy7G
o0UtHTfmuqEiq3VgF51EQG3cpYW1AlyUeMgqh0lgcNukw3eqH0d2kC6g8pH5
Ghf+gt2Dj/6H3pjMStBbp1q4KoODGPuwlMJhAqFPm8ve15fjlpqJkvZBEh00
qQah04knc2Hut28R0GRf65xktMG97cDO9wNSTK/4Xqs1UIW1MiaD71aR6OrI
0InUFiCLrPCjOZFI1Ex4eyhlGM6vKg82nSRQ0n3aP4YnQITCaqa+hxS1+/hq
6afLwS3QjppRJ2GwKPyUuKodv8WuWK5WRUA1IytpjvUKT/JFdvJ7pIi1mO/T
ZzmIAKeU9NPtIjTpR7fZJ7ZDk6vimaRFIH46ejx/63OcGVYR7u+i8Ntj9iC5
tRrzZ8ZV3vlS+TyqEx625MD12i97XHUI1NotszUY6ka1bR1NO49A9Ltsgc2H
RtxUfaJgbE0i9hdF56nEJoisNjbdqCfw5s5w/x+buVDM+XK98QGBUodHvr8a
9qNnZN6hsY4RJN0p0D8+wcWzsaHHDbUEEnXvqKuG9MJguyLN7bsULbYJKeu1
m8ELHh1sO0/11+2x7R2dLljwP6kmzBL4vC2qgTDngrnv+eXWWBKPLkTd5g9S
83NwTVlkJsGJk+vNx72GYLC/Vcy0E6HzFa9QPrQDc+kKRfPqpZhlBm1UDuRi
vt0CyzJqf2V1F64cO9OL7LM29DhqXgbrhN1+HoOYfT19SytUAraO8bfsim7E
HD72hwJTigsav/nSMu8iyKzeKOMwifVFKn1bFnJAH8p9/dcpAtdTBK+QTPHV
BbvtTgIxSrcFGveWlIJ5vilozRYS6R+Cp6ZNm0HsuJq8gdp3NXe2UO9oEwxz
I7+EvSaQ5fdixU1hC5YdIHn0IhIqLGMxP7kVHw1Ouf2dSOC/qrnHFCvqcNHU
YKIxlERmBRm/a6YL9OC6sUEq/kO60Jln2Y+V1oaHY3ij0G6fN6EWVY+gF1Gm
dhdJ8Ko/izxEFWBPO9yfp0XxQ8JPuyPFbPTOmhU4e5DI+IflPDDQiVNTGeca
rah+aHjZGDpzkF+Xaj1N+VdRs44v3tCIdtoB2URFEjleT+8dZDbCsbZR5wVB
wFvVPEQmtgKq2huVzm8ise/MLnlGwSDEE3SbE3vFyF/iPOCu0Q0nN6WSpFoJ
7t69q0j0PMfuLvsYoT9lTw/T2Ls/E9fHnT3LjpHYmjukF1Tah5lzAZulJRIY
9/l+TnYfgCfb5rUmhZf16k9LTprXI6Xf71peA4HMmCyHGtNWGNFO6O3qpPjf
5yea//1nSFhi15DSS6BI39tEK70fqXK5g1F+YlR67aD9HdyMO2seJrENqPgv
53115nCRE5E/8acSiVL1Swu/d9Vgb5RPnSKFt4hwm8olU924/L+xgTdLCLCc
0yN+Vu/FOa4VJ/erGPRifxOnmGYoR5gaJFL8GZypkavk3gXG8+3ZWv/i423c
g85lWchXyPzJjEnpiyP9Tap8JSa7r0e+v0tCeYsl12xFNTSvDHn436D4cCn/
gaygH5t9rzUW35NgZ71lQ+dcB0oVGXL3pJT+WevH2O6swKL9jd5TVL+rdY/1
sPT5iDKN37DyHYmDc242zj2dEMWolH0sIJBm4VdQ2MKHjG7PS5W1BAwO3Dxy
wUOASeNAw5ilBITjqR/6I4cw1TqWJOqXonTQnBkT8BwaHyPl0+ypeq5tKiZG
ayA/bhRafYpEsAmn/rjiCJbf9nftmpGCM/qBtSaiB5/8lEe0dkggXtfPiwip
RVNHHuOUK4lZkzCxW/sA7JXKeC4fpZD5FjxnVuUJqUPXP3sp/M3JRlQY+gpQ
vI02U64ghUuspwfDk4+rNioRbV4STM8rzA2RCMDe4hR+t5GKl3Zx9NXxXhyU
uI1OTophteez01WXSPxwdkX4PcpfiaPy+T1jryBiTXwJNKbmFeWbFqTJQYFc
mYU5h+K/EHbeoB4fhO2l4/tWkqjxW9wyf8EgAoXD2zxfS6EU3zC3J7sBq06P
b3p0mkDuf6xCVRf2grs8zz3oDwn+rN24WP3XPmy3L65JpOrLL9257AylNynn
LtpWDZCIeXC75/r8MhiPbjw/aUPi6vI0J47ZCHbXrauhvRRB6JcYqO3ZhL9m
h5deofTeojXLYslJPtys9mSuv0Lp0ZUeW2PDdES3rQjwofTi+t+/FWbQe3HU
t237EZoEPt9GXHe/follZ3KZ3tEUX6fdeMs724LS8vy1+WokAg2PjhsWtGJs
MO7JW2qfom2XlizaUI9VbMY7BW8S/wdHsLPh
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 183->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lekbxknKRI3UyCBFY0mMlpGaymWnMmWd0akpYznZ0mYdzTCpplRE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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3lYTP0bxltElCSRXmkRERUtr1C5K0miRQvZKyWStKC0F/FSkhYKJW3S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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlns81NkfxodySZLEppTUyj3lstpl61FZt4iipIvsGNJlk1xCoabIliTJ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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk8lekfRSgzIlpoSlrsU8lWSE6hCd2QvUT2QgaVSaFVKCoKTaSiQqhf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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 184->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4ldkfv5XIVqFFaijThEncbKU0H9OoafWzJKZBsmVQuAiRuUmLGPta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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k0VA8bJrKWVEiUpFRaJCFJnpSEhFIIoUJCKilrslUqIrRYQphCEkr2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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8lWkfxlEiO9NYUkLbUMlkS+TSkSU1lgkl2Rq7VlH0GiQaLUrWprzI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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns4lGsXxp2y07Z9lUJFCqFMmLZj2t2knUPIIW1bhCJNxFCSSEcVqW2r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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 185->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lXkbNrJECG2mUWGYS4XskeVusZR82SZlWlDZ6mSZFsqEZBRZChkj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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VO/7xylbKomSssVHZa8UofKW4msthBQVEhWVKDtFilAUFVJZIoXK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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81dkbxykJYwlNSZFSoSLzi5tIH0wjRcjYJiVLFArJGoWYSGWkwpRk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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk8lWkYtTYYyYwlFWVU4tbcLA2yHSRJu2LKFpcwZVIkhIxSZuwxDFKW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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 186->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8lWkbx0+2zitjSTUjMqKR1BQqGaZ+mDJeNRWJUSqvoWSnLIWT0SIx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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k4VP8bxiUkIUnZEi20ixKSuiWlEkoqZMtSlErZlx9CSQkJyU5IthCS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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk4Vfkfx4nRtbT+ZJTsmWooioYib1tGUtm37NKvLialJi3WtEjDRBou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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk4lekbxyUj0+Yw2RpLVGNLiH5zrF+hMpXKkaKYymVky5aQGUJGlCQt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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 187->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8VWkYVpGrRtnrRoulJtuMTMsN9UhUJC1ESbKNdCOyRabImqVJSIut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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8VW0XxlGEJI+IkJISpUGGqLikTMmQoYQkRZJHSKIkDUoZUhSKSGXo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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41Vkfl9GQFhQyYUK2bkiSJPrwtoxl7MQtWxMyKkuklEp6NaMQFSoq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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVns41dka3kqREo6SRIakSWlcyyW9NChJ4zIjUy4pzaiY4riGULlNCEmF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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 188->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4lekXlctkpJMxjahBVPSbkFFyb2nIrQZJU8TQQYwTcolTjEujQk2O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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3cgVf8fxkWyJW1RRIMUSsh6KolCKFSkZGU2VFIhERUiu5CWMhIqe6+Q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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk4lekbPoVSZJemZUgYJCJLJjO3nVQGySGRGpXSZsaSNiQToiyHNjvV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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk8lekbxiUjiiSiMTWUpUiWrJnDpUgahBgUg8iSTmkdS4pKUk2iKaNC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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 189->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lWkfxk1JkhxMpULJlikjIkxjulRMTYtSSaQsqRxZjmmSrVJhCjNl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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VW8XxW9l+kmIRgqJiggpIVmRqUKGBiQklUipJFOSKA2kSSWZSaaQ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8ltkbxm0VZRtGSkiWMtKUGUQmlyjZs0QqlYSSYhRGKiRLGhoJIdmy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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4lekbPjioCGPSNKiYQkhEIS23mEEYRD9Zs8SEENNUkrKXyhpiFJWI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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 190->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs81NkfxmdH0U4uuyjR1S01UULSzZNWU7upaHRhSxEqKipdrEuy0qiI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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8lG8bxZGkkpKlkqRItjapZDtEsqdFVEKytwmpkDKVIkLZQhSyhlGS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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlnk8VfkfxlVEESZCqEhkuIwlk5bxqAYR0bUloyxlqcZS1nZrUgnZUnKn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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk4lekfxvGToWVooTIlTYliEI2QutE0Q9lmrCkxEiWNFH4VkzoJCTGy
TDFCwkHJUvadYyvncM7BsZ3zvm+NkSQkEc07fzzX88fzXM/1Xe7v5362uvv+
ckpCTEwskV7/7duX8ZelPeqBHTkruzaHRKxwxDv0ehvqcz0yStoJXPs7sLk7
jQdDtxGmXgSF052LnzQZtbBLGb2p5EXCUXH1+rXP+9D58zu/UT8hPNqZfvZS
LMx4Ra6x8iPhE7ooOZvGhnVI2inpuwTWJXoaTl3kYJxfn9jPJbBH6rfKqOtV
0HU3UlSeI9HpXeExE9cOizExh4+ZBOriuiNcjCrBWNIRKzGiIJZjUl7oz8b1
FRJzmcspWH+8Ed7EfQFG3Wit3wkK4wci31Uzu1AhWi+bRZI4ZLUpSLeOA8uN
H2MZUiTmyi/dHOgpxI3D0o8NTCg8+TQ06qXOglv15oKRDAoKYVd6PIbacO2S
NIY1KKRIzZ536eLC1ZPx+57bBISnolY+qWGB/PHD+oz3JHIqOE/V5dsR12+j
csGEhFP6IxV9jWY4jQSuNHGksG24LHqR0Qdr3Z92yRhQqNItbBol+firr3mf
+4wIgqdau/e7cnHUlzWd+U6ElQrNjRGeHegtjT0ZokFCenTf7bOfCtHZfiGM
4UrBbVtZWUpWNtblq7qnWND5x0accE/lwKbRX3mxm0Tmnoi7R8/14NvOhsHB
nRQkfX32aU5ysY+VpJ4/L4LC4J0NsxVc+DjYmBh1kHisOvbKxqoflr+7RvLE
hLApq7WPJsphU7qxq2AbnX+J55fXzzvwxXcva3kGrYdQjcNFFu1Yc/mR49U3
BNRKTYfEg3rxIFPX95g23f9Yg0+bOL1IcfQJ4p6l+60dJjQY5MOtkPhGPpiA
nPk9iUH7XPyMEkLjFAVj7mt9hWom2DGzCVstKWivupHZbFgCN0tbGTkzCl97
XQ5TzexGieCQnOl1AkO3K5OiYrqh/OcN8UQuifAHAo3ldoMwT5B93zNI4YG7
R6TchQZ8edA/VjxI4nyx0XDbmhoYRoz3BCrS+umVtJ3S70DrVdW3lV0E9LlG
agKlYuT49oQtmdP1VVNWutUSjQT91B0mdL3LuqQMDPW4+DZL1SjQj47fouXg
gCYT9rkF20ydKTitmxd65/IQ18RjWtrR553mammqPfDCF9KIL8L2h8n3ss1b
wTPtdc70ohAjVeDxT9EA7ONm5oLThzHxssYtKbsfqzpaZVqukbhE5u91TyxE
my25OZ7WZ6ykdn/teDE6K6L9q36hEMYv0CtI6EfJ/Q1hOZtFkHHROuH6mY3C
wchWTbr/502nrCPUU3E22H46xYnCGheroYq8JnzPHHYWP0hB3+1cguurfqgF
cNQ8jUSwVzlzWk1RAOMsyaZcBSHeq3DtSflGGPMZe6KZJGYCxHXLdrRgm33w
29JYEj/OX20Xl+vB9gD13smnBKJ0mEd4W+oQnJ01r0XrRbG/WKUysQWpY/uT
JZTpefJPTy3l94FjLPeQ4UBg8PerO4/n9KLkYKuE6nsCS8+E975yzcPMW3fX
iXMU7OpZ7kWLfCz/sam5fGwEQWJG+lRHAxIvlqtGnKTgkad55M5DDhQaV4Ty
wwl4JVwU1ZhwEbJRL/RzAgWNHVNVLSwWfovmFXw/SkIs/E1I/24BPqQ8Sf4q
cARuihfMNPXLUdH14nz3ZxLCmoMLObP3INGrmOXsQmGYaBlJoufp5bKd6dIX
SJxOeKtwcoKPweORzBcuIsTsD99mZtKEXa4eWpI0j2IPs9jxTTVQuvjQyVOH
wpxT0g1O+XM4Pp59pSRPz4/RFXLq7wYwDLgOOE1iUCLD8uk3XTC7PZASYkNg
PLnL6aN4ExSaP09rraQwGn3FJupaKSTL1RdWL5CgnpfnOzHZuMktXP3sGIX5
8U0Ox5L6YCbxg3zTiBA5hoKkgKetGFg2dOdlLQkGo7L1CYMPY2vv8MAiAvm/
Tjif2cvG/eypWltpEqPDQ5ePNuRB4bNL4RpbCj6/7u4MOtWMioItMW3qFN7o
6f7QfocNS3Nex3MPms8HFnbJ8OvwQWGyd93fJPo8nLKbL/fgWLyCf7AJzYNb
U78IN7MwPOur9HSYRMhrKmZvpgB9gnheWh0B77/Gp2wOd4HPdUhVpfWzgf22
sGaxDiV6C/2hAjre6fcfoqx7cD/NNiOzkL5vUXZv7m43ijXlA/lMCuy4c41l
B7iw1qp2mUwWYT5z/vbGn3n4g/eipfgQgb0Fh+Q0zvCg4+uJhqsi7LmvveIP
FTb6ti99CHUjYJy6cGnXgUaEEynqsrRf1I5PVJeu5mL0wJegxlcEUl7GOoZs
egm1/jaNRZq3rZDdrdzPxCq1zpAJK9rvHN/du8mpwdGXH2U/0Lw8fOTxwnQ0
Bzcfto6F/kRhpujdCnEmF+/sHwhK+oQQbpGeNDZNh8xdMa4/zf/j+Uv6AxvY
MJ3VLC+fJDF+TjbBe6wUmgIVpZorFMzWmiCP5g93JMuuYzsFnQyV8Nyv2VDZ
J/7azYfAJNMh6cinehSEjWXFnqcgpbzUeH1yAKHZ36mRjwiIHZBpW4wIQc3a
r4uVaV6dbpi4K0+UYpT1cc5Ii+bX4vSz4CoOqvoMZLYM0X6sHLBfO70dQq2l
sZ5lJI4fH610qWbBJkiPchCj0O1Y9STXagjGp+pOeETResfEsEAkQJ3zOOn4
nx/t2fldUfwLJEZkOier0f+FVJ+9Vtr1tI8Zz637g4KFbZOf8WAWbkW6/rVk
R4HpGElSLB6qRy0UfvpnBJeajWOfVBXh/C1zRuv/KNjM5qUPx1dA+3p1vrcf
7Y8b7q46ptMIj+8HjCejKUTobbmp2sjBpJzbQdVxETbFEJwa5W5oj+uw4uJF
8NI/UQq2ADvMvMK7L5PYnhx5JtuAA6HMM4cRngjdW4UOkjZs6Jx8ZJDeQevV
65Vj1plsGObmHNP3pOBeaH3I6mw9ggPObHphSuEzL+9SSls3HK767HM+SL8X
VdAdO1YPC62A/+fRethxeNrfmN2LN1eiAoviSIy1FEjE+/GxvjDWwaVViGvM
xFLd4jqoRYqkiv8k8S9VDt3o
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 191->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs8lVkbPQjxUUppapSUJEoi97Tciowaim9qktukC+UampoKuSRU0qdD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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lG0bxidaiPpQihY7IUlRaHGqUOQtpJRkKYSsIVtJKKIsJcneniUh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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs4lHkfxtVah0JCqk2WyLZaYmsd2uUebTlFJLJyyGlFXGUdSgjVrkQr
erGx6LCJxMay8RbWeQbDjGHMYGjM/EY5r1hJ8r7P/vFcz/X8833u674/3/ur
7X/e5fv1UlJSOdTz71vuSJLWP/KdmGBnHd9iQEA7M+D7IaMDKYTt511DsCHR
dKgnggdD+jPAToTLvrrcmr1tSNT54WJ5vhhaT/fLWq4V4ukTw7NFvgTsiLn1
xjoMdKxMh9i/JAhvKs9s6BwBv+D9paldY0jLPalmdZIDgckrUvZEhO8YcZHt
jQL8opgUwdEcR5i8z5y4n4/NrovfVHwvwmLieoHu1U4s+dydL5CToL2ow1PD
7B7s+dNdp10IlvlHhG5PWHDcuYlr0UuQwWLdDBbywFvWddnCFiHMW7jZt7Uf
07vCWmd4IjjwTYZMPlShc8p0ZS6UgP+Zhn3LbBWMhYYxhdcIDJiKihU6bEjT
t46I9Alu6hScU3Djon/+bfyrCyLILq0ZOFhzwcxfu61rOA5h1NEEul8tnCvW
L/fdIVBSn5qNUOEitu6OzsCSBFIu5W2qH07B6lLcae3TBFdz6g2mRBy0p2g/
uhEnwfIS4xepZxxczWjTk1OQoNvyeHHnNBNqMe/M7D8RI3ydXBc/ZQCWwf4/
5nxLoFJWfn4koR3et4WBNrViSMWYx8XQHyP8lNZH86cIhPffLIfYZeNgckrb
lUCCRttdRR6zJVDz+2XnwHcEjE+Z5VM3+1Avfal2g+M4xjVkdqv/PADD7m1v
ra+LEF61aS97XQle2NQGRAQTpHN/S5IpaYNg04+cXX4E91LTKnOWMhDrf7L9
uic170FQsTq/Ha+nnVRWt0nAfuW879B0A5ztniVHfkYgvdfFh672JyzPtocM
Un4aGW4qcLhUjaCI+eEgihcj+Q6LLg4bNbdG6NweSm8417fA5iEUjpsc16MR
BIX53yhms3GPadSbqypBkn5sfsrAdWQ0elg/8iaQU/WwmsxkY7wqbJM5xYfW
QyN/+3I+4rMCFadnxjFzbKi0S30IA3MFTjn7JKjYDqOIQ6XYX36UV+1MoMxi
hs65lyEhNtDrS8o/NSnjg2c1magdmov2TyGocLi8xl7ioK7CWhJdSGCbq9IW
58fABv0Ru7tDYsjfir8VfrUVJ+JXI1s+ofyfSJ68ssjC2EnT5CwnAo287KIX
79uRZSuKVWgTY/yiYPeW9aMQlNBestwp/2aStvrr9yF/xUJ+eX4Mf+/rX6yU
y4Ob8eZ5bUdqH0OZNP+oKyCxsrKDFD9NoUJ2XlQlFL2YAcN2BOMB30XaCbgw
37V8ocxIhKDoMsb+MQEWa6JCjs1L8PrJi9BgIx5idKedg6h5/e92rPhk9SIw
YqU2NEkM5yy5+4trTKSEj4vtKX5Hh7e+Vt7NgD378N18GzGy8i/Tv0juhq5r
6UynCkFralLO+Mt+fOmesNr2XIzNXxO92ydq0Op2JbGHystseeem9Pm/MHH5
rPXcLMHshJwyTdIL3kBty7lBCUJSR71yuzlYyjlmGnBAjAenLb72juKiOVPe
bqsZwflrZz4v9OGClxj3UQjVN4J3pZPdTwQojZXeKrVKkOBUn6ZA46Dan3eG
5SgGW6F5swwZgbPOeHahsxAZhwp1Tgc246DSNr7lihgHanDi4xYOhpRueChT
fRBlPfaFvFEv7ldLnPRXqLwrvr9BG+5GwVxAwIzBv3k7+qS29MBVc/SP47oE
f1yXmc3TG8Y+pe0xPIkIJQ6Oaka6mYgaSJefovJwzTyQ0cXkgDHpuvt5OMFp
exV7mzf9WGSFFelpilEb3FaZj6fInV1NdzhDoBV7xkrCoES9f54USH1HqWGd
fX075Da4WORTeirNUtNoDX0ok7NOY5AxNDSl1bZfb4Xj/fxqpiZBYJOJx0Nr
FsKOfh7TUSGGQtqnrx4VsKAx/sLqwX8J3rT1bvf6lg1N86wyBtW/N73cL34j
04WeRBbHSELxmTn9WrqjH5yE8/LrKH5Wu/fWsCLYWLVZqBNT/L+2MktvoLdh
cnNczp4qMVpV1zUY9dTA3OlXep4rwdlFi6Pby3shFCZ/oxcjRr250kbrUTpC
+/5p+ewvSs/GE4eNbTlwYL3HILUv2RYTLFfuIE789lZ1eAc1b6ltJXPLPRy7
xhM/9ieQOvewWTWZj79Fhew/9SXIiU1PLQgahJNGfuiapwgxgp+3Sb2sxKgl
2z2E8ncX/WnnTkseDit6PHr0UgI5/VKN4VUGUsN3PKui+qTC1aPjf/wiTLzV
cZ+k9NICtCNHXuXC6PCUXRrVf7N3fmco/90H42Fb+5RhApf4jUuZen0QXfX2
zIum8nC54x2qQQctzNL9qSpBYfEnsgsxzdjnWeERXkzx9Cnnq54hFpjBV/OM
aWIoSx2pi+jqhZLw7VqTKcVTvP7hhlk66gQit7VBgrLFPje3oGZEFBWu5i6K
4WiV0y1/nwNb2UN/VFeJED0XlJFoMQDNFzt9jR+KkaEx6Ok2eQ4jI0PcJR+C
hRuGa92m/ZDZU+9wO1wE3+ZLOuuFjfDfn17408fUPq5l0Pa8fA7H7v8o/UP1
bVJxY49x2Q34TVYySyk/0otPqgxF8qF7xPukngLVd3o1Iau8VrgO3bR6SvV3
y/Y/WcKFEpxy2x0tBeqeKsko1f7OxA97XmTvyybw/fCctpfZhF/ph5US66h7
n21iHXG7FwPBBVJHuiXI0HqzrrevE2ZWmGWrUX5cGFUk/iVoTf+oa8GL6oMQ
xbj81vvwic+T1ab44mT9ZbDziz5keTwz9h+m7v9NDn/jRS46hEdno7zG0fIV
1K/xf4Or34aWg7YEg3YG4Xflh0Brs3mXYiqE8u+yvczATtBS62bi1STIjJxo
7dZlwzJKR4+tT/ln/PYx69QD1LIXrqufJcg6UN10sbURCXW3VJYvEFTbLfRc
vlsP5f7SA5d/ou5TwuwR7S2UHya5zUxpgk7GuTTzTjaeLcXJramLMS8022Ne
KoB9T9rge88xKJjm3XlH/f82Q13Og0Mgku5JLrQcQvT0lzvubRMj5rGW4mta
Ixp+frcqySH4Pz8izeU=
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs4VPkfx0lJDNpqkdtSQjfVFol4C8lSRMhtN5F2VWSrrbBb1rplZYmi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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 192->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lXkfxo+aspQY0shWo2yNka3tpXOHslUyTUQhGlvRgmG0CWkYGinR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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8FW8bxkVJi/JLKJUoSVIUIalLhUpIKoQsWSIKZSslSSFUttImKUuS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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81dkbtiVZRxRNiUxZsmYJbU/ZRmmZkS5jj5KJkjKWUIRqUvZCliRb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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlns4lVkbxgk1OzVE0ZitJKecRk5JuEvqk8NEDokyMojoIMLXJyGTplHK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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 193->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8ldkfx2+2JMskcimNVDRKi6SSfIwkjcbWaiYSLRKplLSpCGnIFS4q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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmGk4lP8bxS2VUqTQpiyplIiElHIkSUJCiyWVpZBUSkmRyJJs2WVJKUsh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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk4lWkbl2RphCLSRJLkRJwUYcrPKFFRkoykj4REskSylCXJJyEHqSgJ
MYwWZcvuWLIv5xzHDOG870ExhiSNpb73++O5nuu5rue67/v5bc8WJy8rF0EB
AYEUav1/13hx+p35jX6UO51R7S/lQ1Y5vKJBsBseJzrnC9QIDK5leWTOchG1
eFeQNTIMS505c9/fuUC2w/3e3QTcBpWbwrzKEPNNwUwoicT40MEVJaYtKHSo
7RpKINCmLK9qPtMH3dDFcCH7UZiPhs6kz7fgxMX5v2Tj+BA49keJ6Z638Pvn
uLTHURK+a8q24QkHdmq0xAN7SFxrFU75jykH0sX7Gvl6fCh19BewXQdx07n+
7Pq9I1AqrH5Y+L4Jti/l5G/PERC/vjbc6Cc2pkbW6J7yJPG7eqbsrsI+WPA2
WP4tzEeNIn1e6OkTCI4pKsifJ2G0LdJRh2TAeA9XJuEsCUeaz3kHSSbOPbhn
KHOBhHlTk7tFTSfskqymogwJLG1u07BNbUdfY2FtWCkBo2Xd+UPVt8G8/11V
ypGERO86t5vPe6GQmygb30JC6bb9yWvpPXj7PeVHcjofVdlYMWfbhqXgZ8Pr
cgiMXMutfjzOgkHcm4EvZQRK71vIaU83Qvmi1hmxZBLe6/FeuKgTornhhyes
SSQ4n8rYdeshJDZ/e2RNzb/IPVNwMoWDwzaq78yKR1Ae78JwDu6GcWwDz4fi
R2rLRhH/q9mQiQwN6ztBoob9bMg2/xkyhC8/HaHqbXo5d3QFvQ7XSjTaZdfz
oTc1y7Ta+Qq+VbFzx4NIcDm9nQtfX8Az8ylN5jQJ0bmOpfiPbGje8THlBPKg
FiU3YuHBhZj7aOL7RAIxBp+tmb+ywc/aG1sSSkD7UNGDo1ZN2HpqJLS5h4DM
qwjZyMAeLHUpJucEjOLX5/oiV461Y538SdFWBoFhF8FLBvUsJIkXeHLE+AgJ
bjQX/diHkKoTChrGI+Dy2Z0Z8lU42m/7oLKNwLTNV0fng2+RLUHjMyk8YmkH
7qtu5uLys/Pz016jsDx/PSlKowc1Ivf66YIU3+HKf6enVoC+Vv2RnBgJgVaL
ibs7s5Ek0SEyaEsiY6KiOFAkDu0veN7ZlB6Eg4Z5m2a4oHXEumvH8dDDfaRB
394L0ZumC801JKJaldRCaGykzur1RbbzIBUYILHKohXvmur0hDYQsKuzd406
04dPOv82H7cagcCyA28hKB1hU4r+76n6anmK+Z1GzyFVMhHd6UXCTs5FgRXT
hbYPRQZ+x/kwuifp7yaQjj9tZjNoziRsc1Iqx4lKXPAafp4cTM07vAFmP+dj
RjdTP/8UxVcG/4d2ZRnsq4YqlmMpP+bE7OjRfY4cieqaQjsSaQbfVop96ENW
6G/dTHcCj5urk+00O6HQecA47hyJiKA05r47LAwtqs/tX8FH5tXtFtmd9ega
ZKZLWJFIdUo9q+TWCpb/uP7eBRLTDS2x8XtrsCNgeE9ZAKVXxZyxCdRD866x
HEeYwneUCF+rHAXlcFZmjROJZk2tNXoiXFgGl8rsiiPRkufaFUsbQJuSwqK0
KA/eEep5wg5sNEpFmExtJ1Ha/qUo50gdxFdGdzrok/jXM3lwU84HhEQPqY2J
j2J61+0qE9t6+Flq6TjbkPDr/ykv3LUdnq4+3k2TBDSLrnjtzO7CutIs6W4K
nwXZx1sFF99jpeQ+aH8hYd+xeu1vUxyo95vYNwUSSJumC39OrQUZlpa1ej+J
h3f1xVU5bKwU4Xl6MEiMPpPu+MTgwjVE5c/gywRsD0239FtkwXJxLk/Um0Tr
+nG6XsoHqLwpWYyXH0bXtZTy8LkCkN+DD6lQ/jMjPnl7jufBTauhSJ7Ku6Ct
d051GXTB0TDvhu49EgVvVIycPrOxRjMvRSea8tedI0TI7j5cSNO1+qjNw5GE
i7UDe3qgIWC50cGARPuUdI8BUQdvlaXTckdIbNzZ8vVqLRPWLqlRdCblp+1O
d07z2rFP/djQLaq/keTeY2ZfXkL82CPH/RSfWboCPK3wDgQpJ9U2TxDY1KpQ
bG3Pxrlt7afrDhJg7DMt0PRgwkh2+Pc5Bep+GcGw2MrEkse0XaUJifSnzX8L
21LvFbI6cCWUh7TblasuspqhmLRRRVmHD4OGJBVBhQHQcqrvpQ/w4Jd06dJS
NaUnvxjbxgxK724xJYlRfbjl9EtaDoMHActJnf2JKmBKejTtcqDwDhQqytNj
4dDZw+4MgkA9LYzldqsb7puLop7I8lCgcv1udG430r4uy6v4Eohmff/hl/0a
bO9zkZ8vk7isa6Hx6M8+mKmGhJXHjUKqeXmHpXcDIl59ji/3IeAo9ubz10wG
eCIT7jQq78nqIXdR6140DFl6iSRQfvZk0q5ksWH2UIM9E8GD46r2W/P/fQ3b
OOMmCzUSxy2Sc3Y85WBoQmrGchMf4o6LI/lCz1DmT7d0o/Lyy5WtWrn1TMjq
FDfuESVRvFvA7d97XFhx5G+ozo7A+OqYArPyHXytL9FNVpMY2D+jX/RjEG2v
96sklPKQWJ2VYL7ci291Tetu2PBRwThWzrXnIFP78YObLQQOPqXzp1xr4btB
tr0qgeKHMbmuy+g1Jk8LLf3sSp0VPN58vMiC0pZlWoAOgZffaia16oqR9y7/
QdUBEjJNqayE7S0Q63we9hdIHCwVXDNp3Ajxj3bXyu5T/jjFk28b7MMYr9R1
0yrqP25rSPSZKMEKl1TTFWYk9JRS738aY8GjpnmhU4iAYe7qOE//QURUVqq/
ChjGLybznoeL2IhpMTxsIk1AQHLvCfM/CvEqYoBf5UMiWtKfqc+oQ/H12L4z
VF4JvEh+/I9IOyTyBi7TfxAY94vHyrMl2Miaurj1OtXPJ8LGaFU3hNNqV92l
9PAyNm02qZeD7F67mNFiAhoyLrOwaYTBchDDuZ7E8FjPULDwW9Q2f3MjKP2H
aZzJNTvugwsOztZulL4srQ016Fr1ONJq6HVrhkDk+a53nr51uDpZIZZJ5euX
SwN569/342NKwO7IKQIJ8mULJL0QM3YpXeGhJITKX+cHLreiedaCYxxF5VW3
N3fW+wHOkxXbTKm8+x/SVLcp
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk4lekfxm3TNM0hSwuhDinKxLEUabn9yhAZ26WsP4xBkSV1BknGNqdI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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 194->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lWkU1m3FEDGKibKNNJGEIvWoqdDCVMpUQpKKEGOPmBhqkrF3G7Jl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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VO8fxadCUqKVJEtJCS0SkjpIWggtsiSEbMnXGpKyVFS2iqhU9gpl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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs8VFscxScKPTxLD0mTUkpcJVJNLRVClEJKmG6EuL3ETVKJXlQSCYWU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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41ekbxhExWVIo2yRblKksWVLciMmeoihTYVJCKEKIRpoUbQijBU0L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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 195->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns8VPkbpmLstqXtilapVitdtCWpxcOG0IVc2t0fiRqxYSoVuVSyiawl
XaxGmVRuEck9RIPBuDYYMUj5nomSFbO5bPT79sf5nM/7+Z5z3vd9nud93rPi
0DFbtxlycnKx9Ppy/84wnq3SKUbQ6+OhlxQZLBSzrP5TFGNlhEbfRxlBwMpR
D/a+cqgVOGcNnSBYrhEr/3GED1WXqa4P/gRBuqk7Ao3F6G0eH2xawsB+bKv3
st56hP12wTG9hMA49tSpVaxKvJv2e23rR1C4KILfriyABe9MT0YwQbB6xbEl
WsmYZ5N6NcyVQGblzNbIqkPhRj2vG0kENb2i5FpWIwwy3RymUgh6BWXTEwoi
TMe+/FXUT2BvWsDj6gvQqGZYU/QXfV5z0mz5myqMqAn6TENpPhOzpQZDQmTW
mRUW3CI4s2eltbliIywLb+6JTyewu63pUuRaAQNF8xqvUwTL7nB6d6SK4QhL
2ZO9DCwCLcd6duXB6WCoLNed4O23NwyDNdqR7Sc41mzNQPvnIN6co2LM6by4
oOEHBjZpDSlxHs8h/B83TD6NIFo5JCU9rgKJW/5gqwYQ6PdNSVc8rMRonWPi
5/ME/Mgfl3KyC/GiSpmvepTAYu2oyWWtv2EQXadRdJDA5ensjZM3smBg5qHo
f5jg4uVRiYZOJ7qWFD/q3c3gk1enj/mCDuT9a36g5xoDrV3d8c/URZg3NBL3
7TDNdyuEd9YuB8u3171UP0IQcRbeLkUi2LXmvYor/4Kv++z92i24mn3GiOkg
UHGSG6tWroBzi+S3LIrHlYFfVLZuegy1wcktDWx6PmTV1ji3Grd8BdZuFwji
BC3b12wUgmMT9DoijsDqmvb7mbYC6G9cml8WTjCPL+s0Cn4K+U2nDLu8CNrq
VfOM34nw9srztbsFtD/eoNYavSfYvmp9f4wnzeff11DKaYdxysNec3sGvZq6
8smul2G7OsvXieLBadlmpRgsxoaB87G6EwTTe8ov/y4T42ntNy/9JLS/Nr2q
eNc83PMtykp0o3pRDtTfwu7GgDQ1Qf0DgxcJI8KzKTl4Ntgo95meh59r4KK0
A1OO3Hi3GAacO61x/EV8GG9dOCOE6lt7mb9weFCMqxqNMixjsNM5+JdohW7I
vRkR6TAMPIwLmvdsLkX1VP78JXQ+vu9SWl/4oRmO/sZu6yi+4Xa+eoKkYvTb
bnbdyKH1vN8Qv/qKCJdmOwTcrSe46yrddUStC4qbkw0OjlP+Eh+0ZXIa4KR8
O97/IeU7ZYG6rkclZpx8ot8RQfApfXaNsEmE62mSIve3X+LIRouGLhhNTKs4
djD41dLx4fjZPKhw/Fl+lG+niaYfU7SFKFFqLXkVS9CsxE1ivcjDd6zyXo3f
aT1Vn5MLjWIR83XMu3KKb0nbwrDTQhGEcRn+OpUE6Ye8FtWNPYeWj2+cTTuB
t2vkEV5hJwydE59m32XwSKY0luhXiN0Nnw56U/3KOmI4aniGqSuVhWkUv/Dc
+XszggQwteP5v6Wx2eO1h7k8ETgnE3ZMFxKUv3zVurOyBB5eKBX5UL95O8vd
cHMLWDrVf2q+J7D5wS/M55smrPxn9NBLOv/8EcHhR0d7kLZBb13EKIPV0dHV
C29KwK0qlLKsaD2u9/k6vT3Q7vT1qwpgEL5R0smSZaJ+2iiikM5P+HmH3zL8
JTAdku4bamJwhD2/O+UvPpS0znT8TvXOyT5zXyDNw06pu9cmip+H/ru++3Ml
aC/ghe1lM1gas4FTH90NLV8/3zJNKQY1bKraHPi4wzfQaaTzXZPvbLZ/UIg2
c9WAvgTan4vcvxlDUbDQC27wpvgGD7FMhCI/LLBo/bSNxrnW9X8zuk2wfWM/
lnObwHeWT1F4TjNEnTIXSSKBV5rPeIG4E/xM5cW3V1F/PnaAsyajAR9nP9Me
e0D9Qj9AqpSZgpVdkRUN1D8vKpy7l2tWj61zLG523yMY/PrC9l0BYvj+7PSi
R4nqy5D3+hS3GJ80cr73ofO297xqVamZEEbcIIOoKwSHgntKZgw0I6Qk74QC
zW9jzAs5jDZsvXNiVRTV//BPadWWrFaYr0jST6b+8trp6bZrqm3o106KNRyg
+i+PVZDtFGCD8k8RFWEE4wMhc5WbSyBdtCUh2JtAqWq3x71rLYh8p6Ci1Ef1
lf6W5eLRgq8O/JMfqMLg+L8nt9k4teJ0zcz+M68oPvbqelrmTegPNdqpUEqQ
EZKsxj/ZBduo1Nm2POrPnLXmxw8UYyv3kLIJ7Uduwk5rmawAgXNbPDxpfCrX
PnrYUYL5k4EslZsM4t44mP1qyYecpZ+irS+BLX/gdEKoCHNvk1njbyg/Dkmh
Ju1CRGjevWgdRbD5h1a9/lIJns6PeFCTwYDtMGvxnsWxMPkmZEUa5Y+0J9px
52SDHGRdEFB/fBTjaTxxth0lruv3St0ZzE3MfmDJ7UC47GuNKurPrfmTuSN/
ivEyUT8p4yCDcRVN6TGjYvi/3yQuoPNjoN7O5u1pxQ0PrR0n6D4WPju9+Ms+
iQxdWFzfTfWx/sn9GEkOiKtd4y6aL+xjrHrdH2JcGAiqnz7AQEX1VkouEWOc
O7X940oG81nd6TZrajG8zjSg7G+C/kF2gta6XHClNwvs6PsJ+709upbnIOt5
gOF+GpeYaOzjr5bAwVO9Vu0Ig5af+5o/7GuBy9U5ut8qM6iX9s486tSOQYnq
3YhNFA+tQHmT7xvRa/PKtKyK7vsPuv4zGqswb3lLQBnln81scdnn2YnnAR/3
XrvHQD+L5M88XY6AWiu7ejrvlWVrPUevlqBVd4FsPd0P9sOZ1obiWrCjHgk6
efR7bLfq4ttieG37KkbZhcFgRcOKVMsaDE+EdIREEuQrVP0kTm5DyJ9Poh3k
GWRYX60ty2iEQHFydTT9f5jUOWfqtvQ6CpSju65Tvq4r6nm3WtajwmXGh/yb
BHOnxc8yoiow+Hl69MQ5glV3/rMWx9TCOSr1u65LdB9Fpyxinj/GinePtxTR
faEnjM2MtK2Bs+/xEPcY6keXN5Q3K7Ug6MjZ7TbUrzbJL/R8QeowK8S5+z6t
//9pZtRg
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmGk8lH0fxSVuSUWyV0hR4kaS0h3HllJIWUOESGmxtSFEi5KyJ5EtsiXZ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41VkcxhUmg2nkYbRoUJIoS2Sk5bW10CXr7RYh0YhSKWFUTI+lqUQY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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk8lWkfxg9lEN4Y5oNJTaRokgzTjCznQt4oWl5LJSH7W4RQKNTYRQ1Z
QlkqQ7Zwkkr2LRxOx3HswjnPkxeTJVGy1PvMH/fn/uf+4/f73Nf3eyk6eVu4
CtJotFTq/HP7aEd9y03rw+Ge5lz1qzy8pjnb67i0Q8rhkYrXOgGXPL+WiME2
eCpP9pdLkTALsWXI7WtGs+xB8foFAsYt15XSyvqwqZdbYKXPRxlrRXj+Ywuy
oq45CL4jEO/9i+2/NvVjd3KgurAUAV+1zVaj0yNQ3ygauvzuLdpfrwf4tLXj
aYpJscxdEkRO3pGf9Vm4rHeTIZdPIlfqSeOkORcDMbWWGW08TMqfqcqxb4Pb
ctjHqnskNBSmKq+V5qP+vd4d7/MkGJetajJ6OFhIKKozvsFDwsLzL479bSj2
eS2+eJDAiZ1PunakPse3wKWIaCUSZc6RgoWJ9ZCeGHzgcZ2Ey+RtgYzVEYht
KP0jV2YYOclBYkhJhLaMpNBlF+r9sF/fYMszXHrnyNy9RMC0Jd3V9kgrVIwl
lFWuEejNzmstvM9GoJPRSDZBIHB9gAmRGuybIWvGz5BYbK7eYC5UAAPPWT8t
T2r+GktC5jATo/vvqp3rITCarTJyfPdbhFtbF88Z8KAxfCVux0wxvovmDr9y
JfEj/T2Daz8AhrVP5zljHtoe1q6ZVbZC1l1hgqT2KWBpZ37u4WI9Y4SlGETA
KyIpJll/CPUXZpyUisahZ8DuXWjtRWOwPGNdlw8R89h5G81mbArwUco6SSK6
ouiCzVQ7VB7Ka4o8IbEt+xSvI2kEtlc2T7p18KGQmTO0utyNDjlfS6MpPpR8
fd/UtrBRs9lTbLqZj0AzTvS8QjdOfdRni2kQiDDUSXVS7kWor4JSYBMfkoy+
Zv6HakRpvlQO+0Kg+XNXshKDhR+WBD75x/Nh5dpbcIvWChiYxYs7kTAot0jz
2/4IFhPWVRxqvnqBCzP/kW3HGyws7xAgUbTJoveVRDf+3iM9kTFHIEO/XNt/
axuYZvU5N6j/orXYHNvDboDFx8rNx0oI+Nukb/kwwMZydPo7ZzoBBR1D9wE/
LnLykt2CBfkISiqqidvWg3cOGtHm2gRUaB2ZZ/c1gb7YSG44TGL+Sl9XWtkT
lIXdvyBzjkRsvXC5tT4HMTc+qNl5EzhXebz4uS4T2qLnD+k+44OrT08Mf9aH
yp1j67HU/jEX9WomlTowGxu1WD/GR5vUY6fdQfWYz7lS+/sklaf5cQtaRzf6
VRzYnhf5yFm8PvZSqxsp3FnZdXMCnyLvbTw58hZ0xTLPgLFhbBefDp1SysJV
r2c1JSdIsIeqU03X+hAZdFvCVo0P49FPFmlijZiNsfUQSyOwca9ec0p5P/60
OZ3qH0agzWjIJ9GuAzZrEUuifxKwn+LEh3f3oOyImN0dV4rfa/cJptAr8Bt+
Zwpb/5N/51sVEXVQmZFJcRwnEKxtxrnXyMKa3EpfMcWXnI7LmdtuA9CcNNI9
Jz+OQJdVj3STNrCwSZ2+lcSWo3vbpH/vwZdKWuJGLQK00DAPfcMuSBY4huXZ
EtD7NjpbujQEiRliTUmVjxd1HaEJd0bQZsi10tDmIXtn0s9GnEH493y1mDhN
QJVzZku0/yBmi+xWTm3jgd0gWHrh1iPEE+6sPDcSK5w/1UxVuHi71sda/YuH
hYO73QvmehF7a2vWZBqJcdOKbPHQJnjuxVVJdRJaDObX71e6Idou+khehUDH
un9J/oYecDQbWo6NEbgh+l9P/atcRPgaMF00qP88dHu79wsOvr5n3JsUJWBw
c6c5N6kLEkXFmnUeJKpCDk5Xr3FRKaBzenWNjxsRj4euNFvBSdrc9N8OlA/i
LTMXg7rh6Tf7qiGUQAzj5lLkHBfjkToWN7R4mFG99aCzl42H+Ue7fNwJ3K8R
0q1LZuHTibinKt/4EO96clhG9ynF+YJD4SES5+rSm3xqGxCWabkotkqgVXqX
6mPaG3hW2JX7Ub72ifigo8XnwLw4oHw4gQ8B5ZI0O/c++LC35KbO8XBTX5T9
94EGDPcwDbZakahw5FUOK3bit+gE7pggAfEhPT35R2mYtI+praL4NFayyveJ
TIG6a5xJqyOJ8PRLJ/afHAQnMkBGuoUEaJklRcONiOw1zb49RcDZrbPYLnMQ
35ksWk99JXC2dHU+zuI1FEW+nvB9SKCsS8LEy6oUwSm8H0VDSIhcD3fu8+Wg
M8WkMXMDAY1l/0Qlx374bxm6NCfPR3LcCwn5oB5sf0GXDSvkoe/Op18EkzhI
/fLAOM6FD/LsN8MHs0ycLopyVqH89djrdL/t7UEc/6vwgIYDH4Z7kku1PN6i
zED1TursOE5EyY8crekBTWUbt+Qrxd8Pd0MK/27H/gK3UYtTJE6n1eiYXgwH
3UMzaA/Fv3d41Pvg44MQPPvwt/wCEubHCQtJBgc8o34hVVmqD10U7I1OPkCA
kDItmPK/Z31nZf/9AfjGZEysp/Oh8Ul5lHOxAz0Xvc5PGJBIja2TCE9rgvn9
bVLXdUnItEb1HxIYQG6qNDPJbAy/tgfvaPy1CSZebPImxXvuFGHt1DEK1nOd
av7Vd5A5ynofdLkLIUmiwnepPHGeO47vHW5BhONBWR0+gQn/AxsZ9U+xU9RZ
wucPKi+skL8Mp5NQMXG9WsGehPI+yXWOIpPq2f2xxyjfitvXTj35yIB/1QaZ
LUdIxLyJXhZZ4UJy69qM5iMetOMj03Z5sSAc1LFDSpMPr5Ls9sJGNpR/2f81
0JPq3727Nr/48gA3HTimk7YkOucS1L1PtWLkp8TYEMoH9EvCc7Grw7CR+zlr
5NY41JbcE1budqMiMyp91xkCbJEDn9m5bAjRW0tUOXxUqSvQX//IxLTnjCX9
VxLvr4S8nDg1DKEpp0MuWuNY1rA0UXMdwMtdja5WE6OI+fhTTkNrIzZ6Rdia
lVJ+bu383Dk+BIZi0fZeaR6SD0znzEg0IiC1N/PiWwIiYv97EUKvRvXyinxc
J9U3186v22iykFsvnO/nQsA9cVgyb1M3sqwKbKWUCayfrFs3f9yLqO9/6JGj
89DBGmjKWuagi/HheYAfgf8DGMTR+w==
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 196->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lWkbPiktNChMKhktxjIxMU2T9UKS+kIlhEZSdmFSaYzGviRyrGmG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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8Ve8fv2WUUkkKpaQoCclIIW80jMpOSGbJaKgoKpFEyUpIg5Akqm/I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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lWkbx5HCSJ0aU16VImnG2AepiZ91piGFsi/ZJrLXSBQp2RpM1rIv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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVnk81dkbRipSNzHpUoosZakkaRQe3ExqKI1lkKJsiZBsTSqTtRprJaWx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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 197->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4VVkclTLpIldUZqY8e5FCZihmWiKvkopeSoooI67IGAmjlDA9iCkV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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k8VH0blpTCU8haFCopikqlUpckiRZUqFQqJEkihTxZKjyyJVtR2UKI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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk8lWkbNipR9s8oLShNgwopjTaX0ihL1pI0IVIU0SLLSFJKtiRkX84Y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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81dkfxm+qq6aF0AymGkrKDDGkNOKhGEuT3CwpFVkqka3GWEYhU0pZ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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 198->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8lWkfxk8SJVqkRpIUvai8llFD0kVRR7ImTTQjJPTqkDhEC6a3RaF0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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3kglO/bxUdFKUJZStbSZsmWUsmhCCWhkihEhFKiRb4thPIrVLI1SZJS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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVnk81Okfl1BDk7PIbuXomEqSa7f0641NRTbkWDmKRVRsk18S2WJXsinZ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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs4lFkDpxLRjYRVKtESckklm/zSSCrrnsuSNHLJKi1ScomStC612qS+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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 199->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4ldkfv8oSxqASMag0bTeSvWn00aL6JbfSJoykwhSTJCIlaxRJlsQU
lSShsv3MzZLsRHexXPsdnVdUWpSyDM2ZP97nPOc5z3nP97N8P9+Fzidsjs5g
sViJ9Ptvdc/7tHW/cTFUSi6vkXIjMGseLTsbUw0JltVRxp8gM0LH2P/AE7zs
FeSUHiF4PNmRVK91F9Frk1LynQgG5NhZtct4UE/hqXwsJRBlf/c8n8FHp3DP
nA4hgW/Yh4D8NzzUaEjZa9URiHlc5svyq/g4KpMQeJDg2TELjz86/ZD9fVhv
Ld1Pxyt/Ol3YijS9ngvTOgyefzTY1fOwDfPlS/mXjRgsfK79TudkN16UiYTD
VxjkCXNm5bu2QT9/tZSnGYNkR9v1uQkl8PfSKjl9nMBvs2XuX5GNqBzODyq6
R/Hslfil8lYTMnab3qtMJRiSVVMN3irE599yN2kWEMQPK5a4N7SgyF8uWjRF
6w0a65nqSMVI78r5SyleoxMz3zkO98CfmLI2Sgygwm3Hn/meIri9/StcYy2D
WbIVd78Gt2JZ++6BtCUMrgZ+Tdi8OgesjeGLtA4T7Kmf0ZAZIUC6X9rl4QEC
kjLx+PhzEdyHOZbTZxlYOG4PDi5LxWLnk4E76XsKy+Va+ZZ8OBYnpKxpIzh/
4ptuQncLnGzfW1nNZLCyP+NMZno9PkclGSbEELAyVRuuBmfAY+oVCTtEYCH3
z45FFim4/ufc7H8ov1s9tfN+bC+C5uwzLX6uFM8C1s+HxuvhxZkbEhVPkPf1
2viOrE44m+vKs4MZ2HUfDpD24mFGeJ7qzSyq19jhQR0vIQQ5D7Tu0vcFh/gR
olX03FPfdm0PwYT3V7X9kUXwrnpZ5Ur9pGTDdowGFwbzWhdtp/uthRfXcK15
4K55fScsm/J7ap5ilmQCeGeDCm7T+p6vT4iZfNaGaiWneXb2DI6eOiOx6GYH
VmQxBzIOMeBJfiiw3iDAxDFDO49GgnB4Oocad8CoR/6ObzwD2VMSgUt/5+GO
HRwycgj014QuuqNcg8Oj+zbYXyFY8tSWbZ4pBOmM1VX8m8A2+oHqFs9aVEQo
u0QlELxJTpxTfqAXpTq3FvO8GYQ/vC/dekkA0papzntJ8AU/FNTp1mMn30FF
LYVgLMuiy+NLIZJSw33dXAj0Gq2W3+eKMJTEu9i/kYHT8c/j0VJPMXdydh7v
GIGkzFk3W6cGGHd4rJu8ThDmLBs9EvgCUY59joFpBCofJNh5MtXoJgZvPgcT
ODH2L3q2PcQSvQViY2eCjapRboMjNZCusjcbo3qXVScvPWhTi9E5sskrkggO
Pzo90JHcgWM7Z5Yan2Swaf8Z76RtDeiSj5vWpufO82IaZsm04cRk/kHxXgYX
BkZrPc19UPzo2+9mlP+dDe7KQdfLIOmgbxriRTASWK7kr9SOkSeFenbtBBGS
mSbhfoVQY0VESFC8xYsEjc2TjxD/a4HNFK3Pza9JZSz9CRx8zh+7eJRghe29
LxsLefCK+iATR/mOeq3pomItgHhveJ/lK4LNFeJNkVJ8+O9u4LjWEGxv+33/
lfzH6K15bdJN80ZspDrF4zRBrudtht0zAu6nOmFnXSsUI9PVppQY3BfPFvQ7
t2DeI+srjaMEaVYV8v3qt2Hwobf0JO2fzHV3N0y1V2HpgL+PdAjB4uNGt3bp
9qKoWcHn3CCD7Pmna/tu1kNKIe3F+C2CukFu2Eh3E74lflawukawoGPbrXNF
D2GgcEOzi+KTbL04qt3LRQpbruuVB9XboGboSyoP8dOhz8uo386IOGzlTVVw
WxO18Pp5yufCrnO39bg4/re8WxPNo62KARobOAV4qmr17mfaf8XrpFl94eVw
9dUyavAmSHKOVba7VIn8LK880PuMwUmrVssWGOm2f0uawSCA66rP927FHXvW
kdJpynfgOtWYX59j71sNDVOa1w47B1In5BoxsHxYC5kE7tGag3dd6mDEKgpj
X6b5Or/jJ752LToVev3aIylfUTHndG6UIEml/P9id5pHvue9ZvQ30bxku46n
0zwxrLSqvBoKN67RyDbqD/cHP+1aZSuAFE/zH5cW2t/J65vSVzYixGfmq8T/
+PLi3JMxF2Bhaua11jGC0CfqQ7sq+Bjcpd+9spzOh2ah8nrbAgSp9NtbUn0d
Z9YGPootw/vfmg2fUT6zuYlFq0tz4Sxp+U6D5uXE4o2y5Rw+zJeNhHzuImix
M9kn4ZqOFB3ZCobq+3hZeP50SC2YEvmn+n4EBZEBqTP31CHijGtyehSBIIJM
RLzlQ1Mm9rhgkGBl3ZS7nkcdao3mBHReov11LNtiR28iRMvH1f6i+CYCb0pD
XYRtJT+pW2kwkAn/I0O6txunCsUcjW8MDLPiQvZ6tyB25Xhx3XeCwbd6mx0r
WpHf/vTxil6Cqn1Xcv/nx4NDqBNney1Bv4qGiasdHwcTuZ8OUH/b3Iv55HBJ
CDNLRdMjlB/Wm1UVf+jYwyTokO5q+n5V2JYhi/VVEMSEFm+/QP3TGN/RIt2A
gypzJV8n030WtF/63oZY5vqKSIpfMmP6vsq+dmgp3L/a7ELnh+3spR9+6MTa
BL/bJZIM+qsFo1/HhdjQ77KZkWOg5NkokeT6Ar426pd33ybIcPgaqD7Bx4L2
uCVNlQSTXToWDuZd2GfLar1M5yvPoq9v+4/lyLV5J7Sk/hjjs/XNrB/DcIvE
L9FUn7FBqW7r6JcQjA01bOMT7DuQY/yJ1YLgwYwhfUV636HUfJVhOexC2rfY
nKL+Zrg8jqgKE5whXXfqV/sCId/iYTW8m5mre8Jov7/P6qqmeo1o+x+Qbab8
fXt140JBN/pYw6l7YxiIL8XKvpEUYJaZmji3nvrt+643U+Js2HwZ8viB1pPq
MxQk0urEtS52btEOBj4z4uLmqQvx3u1i7UfKxxHr2LFNE1WoMbJYZhFE/XZl
uUl9KR+FSxMzDWn9ATkHJUoTq6G0k31deJbqW+KXZjKbh3eCZW03uHQ+OmRy
434RYdKHc49FaP8dNT1h6kf9FGvMLqb/W5DgcslA5QGcI54Iuuj8/RfZeMne

                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VG8bHlIpUglJRJZCloRs5ZaEUpKtsYSiopCflCXKlqWkqLSQUlFU
iiR79n0ZY19j5swglRJlre98f811ruvMe573ee7t2XzinPlJTgqF4sBBofz/
N2JPUlZRfy2Ir5qdwV+ZKOk+dI6WRYco987cygE2kvTPdawUKofAdueHfFFM
2E4+5i67Tkf/0vz4H1osNO8o38kr1AsiW9fzuw6BoRg8O+OVDEPFycaWvQTG
NU1fsblaELrumtrdFwQCt3b96djeiL+yliG7lJj4gZAM4ZxPeGL+4v3NYAKe
ehkXB8e7sWaZda70ewacEs2d1zO6wLunSyhB/QvmdN2dba1K0TN7evj2CyaG
zj0TzlxGh9/ewRwYMeD6u7943KwPm169EJpVYOPH0AcTPbMGlD8qZh58y4Sa
5ANKYH49zKSUF0ITmTC2O7+65XAxpnguWvkHErA/Gxd8IKAF3N4LcVppBCTa
P/n8k2wFb5ls5sR3Fio/dnrVpjXhzLJMHmovgZk7dGEmQcc/+0DGRi4GaD/U
+R9WF0DtSIf3Ol8mvrP5vH7uJut3TBRfuX4El1hrtyfcaMXmw9Lh4W+GYPzV
zNg4qAopzJ1NUwfI+qYvS7fF1MKyx86Xk5OFFzOcF/kby9DreqMt/DWBau+r
fVSdbvj68MofTB2Bk1H+hUTLItiMTYdqTDPB7axgsMwqBz472d7mvUycOR8c
v0Q8BwfytxxOqWXCUkSPGWTVAjVlX5sBsv662H+frQpL0RAR361NzqvvVFre
z3IaMkX1Ls3R2JjJsvD4rP8BwTfeHfDJJLA9uiljzuEJdJMZ0eusCFAcdFxU
h+vh6vdJvUeQQNSbCKPS5BrQVPkvV5HzCZ8M0WA+KEDre40oIbAwE+Ppuijb
BXvdCKfKcQIFK8IaP8fRoe1Up5NN1ls541RhKNeMZms9ik0+C5GXP/Zw9HSC
KDl8PaZgGIRFucLRpG7sYwhuso0fw3Pdl8rrZAeQnr6VGLIcANXjtjG3az7Z
X9dmxfdkP55m+x+5lIPQseyO4Q8EynLv/tI92wEVOYPBsVIWdAPy9X1XVON7
y/3hS/EEutRdvvdVV8OuhpdvqzyBL3HT531O1eLai7XLXKPZJL7kDQZedkF5
g3MP1xYWbLlGTaMiWqFisf4n/1IWeEtZ+7TD2+FpWvdgQZ+AQHWmkPBgA+QM
m0u8ypmgqbmLNLx6hjXNU9ZsGQLUbVc3DTxpgvQLHtp5RyacxM9GHVkfh2sH
i68qeBBIW6HSyvG0A5yfFnZSeUYQoxE65GxdiblumuQ2JhNh2+83WXbQUVW8
I+9xKIGDk6I/q3bUg1DnNGnIYqKC4RDGJdWJv9zvTAxTmXh30PhzXNEjvNko
/cnYmpzn5ObnDPNcfDhRFVGUS0Dq9Owusb/NoEoTr+rI+wUzuVvS1oTB/hU9
jteBwEgx/1a/5V3w6mU865kZxVPRSP6ipnx4352JlV/BAjavUfTVqQe90ttW
8BwbGRc1Br9f6MZq0Q9V43MEdMdyvIe96BCROX5PPoSFfoEgLtrFMhSu+GH5
j6wv+NNQ16VnuTDWFrOgku+X6tLnrnOkwC+7wUnnPAEnra0eH6Y/4voSqs2R
owQWHCx35I10I8B6tqPThIn7G/YqvrvjBa8RK/ZfRwIcZkmhGSodGHXY8K6M
PohLYgrMD18rsLOtb++5ZgbeecWKaVY1YFDBqbLSnwWJo99W3qm/jf5zZaIJ
TiS+a0QnV2bnw5KywrU8gIXSm+KUK6Kl8DOaNJB+Q0Dvn7ReGyUFDudk/z48
TD5nPo7VaOjG787REa7v3aBoS6RInc1EfPVaL4uDBJ74LgR8E2jCiWZkaN9m
wKGs7e26fzXod+mUFf3BxtbqPYRSRjtex7pvkzrLhpnLJ9Ge0y/B2aRDpe4n
4OIwr3lCrwM5ZbSv7a/G4bX7w5Hv6U8RXmNXq0kl0KhpY+n4uRrFV54emikg
UDQ1Pb5o/hkHz7pd15IegvR7JQO//GY4XfSYPC3ARoJy5N6j7T0IFRWL2tPB
gETjqYnFqDIUqbvUu3QSME6K6hD5rxfcufY6/5V1QoB6fYU0Lw3bs0bX7zs2
inAoilxdaIJ62pXWI8IsnGlMVNon3QX96KLaWZFhbDb/HUJ0VMO7Xp+ddo+c
p7jQo0dn4iFZlnh98ynSL75f9pxY2Qqda4Jab/IJJO6bd/ld3o68iWOW74YY
CK5eZkAv9QVzWUHLseOkvuwWuCc504P5P5W231gDWBcty/xm1o1lV1NWjbsM
406w51xlFvn9CX6P3eMDOPFcSNr/Qids/zxuDHEcRlKFF804tRTiyW5X1vmR
/L6umtHN342C5Q67qU0sjD253yIV2obtW20W3I0JPKudrrbXoOGBT7TDLhMW
ak/qJEjt74NE193kbWnD8FahvjiyhgZOlwLXsd9MWD/dskQttRVx+0uKv70n
+fRR0qgstReOi2eXUicGodimfiXYjAbNvmKBQi0GfolTdF5rD0B98ISn9p1O
qAX4DdheqsZkb2CJrCnJn7V88Vb/PsLw83L/H2R/KvmE927IbULlftURLRKf
uV/WrumJpINy2fVeYxIDAbP7mrGxBok5KvU5QgyILd/gm3qhCy0tqaK39QhU
DH7oFTf/CGulx/+GVQh0Wrz7wvzdh5M/FXU9rhCIufnT6Mk0HYvPt/+qqyRg
Ob917Xneblw2fiLYQfZH8axAvbJ6I0IzEy44c5D5oHBvynhbFCYl4nl8yflo
7pB7e2I+AwVubv6xSgS4NH5InJBthqDghWHXEtKvN/aEypnkg67Z80xrPwt/
mUPioVV0hJz+0i93hvTr2uriDwKhaKaIulD/f95it/7iuRzc1ejLjnUl8aJj
7/hyWRGiVNaK8EYQkI1YlHQz+oRT+a4b22JIv46Zj1ztmYsl7yfE2tYTUOC+
te7csio8ao6UcdnDBOVdW8NwQSeMUjTLJZsYqN2Q1fK0vwQqqlYx2p8IhCq/
WGXfN4DDDtvb9MTZCA4hMl0+nIdkckI37RiBh6yX5n0S5YhXpOm7iRCojVLx
MPDsQreHQ3D+BAN5vib7HjSn4v66wRcVZD2/76xKbRzsAcOaY+hh3AgkXUyL
hNnteHZUIll2FRs6QiPyQn9qIcppqSJuysIXZZt8nz46dnyVrpOqG4ZexU+f
l4XRGDrxmptO9kN0fEmq+P4urHxMXNg/OA7q7hyzgLhmpK6aeX54jIGX9o7Z
Bz3awBumPrvwpR+Ex4jUIZFOBPMeCepb3g8zO/nkhYb74KQmfxp0J/VtQfYK
YXIbXLELX4+QfAx/xHiqH90MTX8T3Vw2A9VWH/PEBGoQbKluf/8tA8ojafUy
zHq465+plTw7DO78RkOuN23I/E358DiQiZkHsT9tpmsxoeyofFOZhR9n3/Z+
Mw6FUNetmKuO/8eX6IzMwz78Davb1WsyjMz8Xib37k4YU/9Y+JL+7FfeG1su
QvpDhkv71ggWGDupwzYprTC9sbHabIT0h+ogia4PN/Hxn/2RJXYE1IxuvuVu
zMXQ23SRkyTfbD33jzkXt0NnaIPf2bf9YJ9K1XDka8Md0ZKK9Eg2vm5q9t+j
QcdFiv+xX6dYWBkqf+i4cCZK7wkWCZL5dVN5m6BcVgee0RQzL5J6HjFd85O3
tQ7JqtZqYRUs3KK3wn2xALf4DB66RpB4YvBo8c/G4oKhCL8Z6Y9ev6tuNN+q
xHNFHs3XomzEvM1xiXnaAO0SFaGKADbeTA9bWun1Y8i4V/FSBxt+vcPr7gVX
4c2q5WInyLxknrDEsSG4DNqfCqX841h4Z2Z/yXDmNeSeOELcgEByutkHG40e
JGcJeRxX/IIpMSUuriddOESTTvnIP4BGF6MdnDKV+Lbi4hJl0s9SQvXnQpS6
sVlcKN5W7QvWrFeYWKh7Ai+9u40dpL6FL6+y+eFWhZs2JqdzDZlQ+GKq6ONG
R1Kmh8TGswSEVXWM9zUNQO4mj4p/1hhu1Tm6KDi/x/PUC2liYQR8xo+/1rGu
x5sdel4PS0YgQBLkpWYNzvgnRyT7Erj42cvPtr8S7cm6hfIrCJjpbIj2/tsB
/qQFrzRNBmwVdx7N62vHqGDcJ/QO4Ou1Temp12qxoeqZoMNdFv5oBrWyDvTh
1aF93i8VhmBIDZ60WtUGjXK7TkrzEMoHp/gcmbnolisU2W9PIO/EnvwnnXl4
J+JPiVUj8LfZN+NmeBUkZrf/2XSZ1O+FFter0TR0Vi61WLKXhdw6jtuETzs2
CG9c6zNO+qM6IyyH9OdGXiPevRls8GsV3Tnm2orHYv2YSCXgSvdLM1Nqxalx
jnmDHvLZ9vjzrQGtODRrqp34kcwHlMHjc8EkH1XDZXtJ/bjlmbR8UjsWXLOe
X8xIvf4V6+4kYxOH0O89+6xI/CqNbqMNh1TipcGSEHUyD8X5yeyS+NoEOv/f
GZNCcn6WLbzPL5Th0JR38uguFqzbvb8oNJeif5loaQapF5R0+//Wc56B9LbW
/wxJfrmm5GTaSOTj4W0u9uoZJkTvRqo3yPWh4tqa38fJfSgvUS2KsrcK3elz
4VclCKw9s3RL/a0mqEW0zA6dI/2+p8ThcGYzSuYO6bndIfNiJOc0Z1AWVM6n
CzaT+VhgheKfm7MZkFV0sAsg+eF1qGn9U806NK+qxd0/JH7VfGOFzdsQe85P
3/M2G6Of762W3U5HvZ1unvMQqdeJaocpgc8RMy2SH0t+r/qAi5Axfw940/Vt
Bji+wHV94U+fezTE5yokrOdj4tby54+Nc3IwmtkxFahF6ik/nHnJeXCOm++v
XBjBnc2XxtpKO/H46Yv4ANMxrLh19+XeiS7cMywI1loYg1l2zMMfQm3YNRLp
FERlQ7Ur4PeJixWY11nxaGCCAB9ROaE0TwNvEL3ouzkLgSvO+5sPkO87P8s9
qcBE0IuOZcKdrWgLUhU59nkEtzaePj5zMA+7j8npW+WSfma+UZpLOwaOb5VP
7zlB+oFeeNLvkgasfpTEUdPCgrCP3atH3flw12wVeFDPxMsEQ61QWje2DBsu
ZZH3D56J9OF2LMVfY9fepyQeqLviX3XxVaBekaIpReb7UZ3TupJf8pDgGchh
tos8fzCkTO12JSTvUTeJ8DOx6PAgsCWiFkpv/1DZHSwYnN86XafegO//Mgwr
JEm+hT+9NZWVhSCqW6S8EYHRJuMFLstqXPa6YHdZipxvasBh7xv9KN85nm+c
w8Iyh5TrrLV0xK6MP9lH5n/qc5O16jsqMDpqHPI6msCOhZT/rqZ0Yv5+B3/p
GBMu/uv9jOxzYWSwQJkm7+cuLRJ5ra0c3y24PVsMSH1882PeYksXlLYpGPEU
9CHvbt3eK3Z1EI6x87Um+00xupyQE5WJiOAjl7XlSP1fbbVddWkTZGLTb23Q
ZmEXTyF71rEIxPsggQ7ST3Org94bLy8FtfCaQWMN+X+v2E5XSSrO5URc/kvq
r67w5gPvauuhZ0q1KFtH+luYaPa2YxXwYGhMfe0m951dmWmfW8qwK05iJl6Y
7H/GoS4FkzJIL94P7FYm89Cqfjf/vBYoSNxYLXaN1PvWMyv4HxZjRKb+jxSZ
Dy6q2xyYeFCEF2+n4kdWE7j56EZa2ioyj5rsX6ZzlI1MHnVevfhu9H+f2yUc
xobk2O2rV2QK8UZ6H3W1DAuNu06elw8qxZ20+eU9SwnkFH3sz3KowcAJgmL8
jtSvRz/UOL7Vo4x7h2tnOAP/fRWB/5M2JFbOXqkWGgFnzoxHcXYZuOL2NvYX
k/uhVqakn24rrrmtdCwfI+s1yF+0vlaKAluLRSd5Ju4E7mTcpDdBpKMzLS+J
3Ic/Rx+fWj+I+hR+kYvOY7DkUd7073MRkiLDU4LZJP9fDshmPWnAVP6/krAj
bPCVDiRme7diS+Xt6S1a5HkSiXYzeXXoV9qSIL9lBNJle+P/RFegYF/rpUon
Fmhp991v3G5G7+CmY/wxTOj1DD+97JwDLZEylQgLAu7WFE37kF48WDTVpAWy
sOmEkvz5+R5ENn7eYto+iJlVYdsjH+Xivsp5gw4+kg+2GgO//PJAs/F0Y1LI
/eCX1enAng6ENW207godRVRyvf5cPLlM2Z6aU80m85/4ZcOd2rmQcyvzVj1A
6mHQkXDq7HvsUH1Xb29J4Ku+RYUPVy10CQtrJjmPndNXb0g19EGMWjfs+m0E
T3avYU3feYU4n5Yjz0k8hb2WXrh2n9wfmIUfrVxGIHF7cFF4qgncT8+9fx08
DJv/npvJBfZif++HvZKvCIgx7sfeyO7HyLI1Un1Zw/hxXG+dqUwNsum9EvKZ
pF5w+Sel3mwG78q8/sWXTEhIFDzesaQNqz8WcQySelrNsH41I12JCBkDo4sk
voJpwzd2t+Qi7Up1Ug6J51NLfq1P0W2Dj2ek9O8KAq9tHp9vEeqG/J2vVVNW
LKypc3a4J5cNqaKeDVNkPs0T/eK5W6UO7G02b9eJkvvpNf6V/+6+QfpUtdIk
qQ+TqQ6hOUk18G8RXzVE5nWKzDaJv78DsH0j7xt90q9o9n+dLp1uwKkQt0zB
RSa+WvLcs/Opx4ufbhestZlIINLT70V3QTjFnd5wcgSfKwWjH3eVgMUl+XuP
NAvBw5krD549Bfd7zDAv0p+C1//l2DxbD/OTO15zfGRiIfaObuGvDly0VWmT
orFh2m31if8ZHQ7vaS9ca0bAdo7dsuQGHTYJp9cV/GMi4Mql3bYbqzHRtTC4
VpKFXkmLbavca5EbXnNdMZnAgtSmPp89LdCybu/bR857/vZBzseWHci7Z//S
qJaNTybjntZNNDAG7Y6aRo2AMlJ4ap1qMqLrx/9EkXl4IVfdpVKVBgP3Jr6Q
CwzEJ7e00dTJ/eKXB2UFg8DzirgHzPZ2aLZoyCcKkPs21fV7wp8+tF/jeaRD
5h/Jc9l3nRLbkH2VT2xnwBAofkX22+zo0Bxt57ngysZCwj//yeVN+NtRfEmn
YQQlkwq++ak0sH0N3HbxscF9eU3xZoVX6J+T9hAl/aGGMt8T5EnHvt6rOa4G
DNzylXkQH1WNDrMG+fk9bChUyB/kGW6AVcvJQ+lzTAj3S2fE8zXDhW95qIsg
E/8D6kz31g==
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlns4lOkfxlWUqBxWJ0SEkOTUroruIUkHSiJWSRmt7SDaSLFIjtWuQymJ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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4lWkbR5nRTpmyFZmTDLKUGIkfkiSETplG2YqyjEiWb76SkJQ1Gbuo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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 200->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8ldkbpx9Z0nJFZipLUWkzlaZk+1omUjK3KQwjjMlSsoUWqYyIREgx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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2kglG8bxf2RFEUikoRokUIJpToouzKVtSypCCmKQkWWFhVKEYpShFSI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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk4lWkYxoWkhjKWomQpKqWmkrms3ZYcZVRSRJRIqBA5SoxINLZIJJMs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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlnk4lekfxmUpCZGuwrQQskUY2Sq3LBOlsv2ytdpJg0mNtbGUpkKSQbZj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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}]}, 
                Dynamic[$CellContext`i3$$],
                Alignment->Automatic,
                ImageSize->All],
               Identity,
               Editable->True,
               Selectable->True],
              ImageMargins->10],
             Deployed->False,
             StripOnInput->False,
             ScriptLevel->0,
             GraphicsBoxOptions->{PreserveImageOptions->True},
             Graphics3DBoxOptions->{PreserveImageOptions->True}],
            Identity,
            Editable->False,
            Selectable->False],
           Alignment->{Left, Center},
           Background->GrayLevel[1],
           Frame->1,
           FrameStyle->GrayLevel[0, 0.2],
           ItemSize->Automatic,
           StripOnInput->False]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Top}}, 
          "RowsIndexed" -> {}},
        GridBoxDividers->{
         "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
          "RowsIndexed" -> {}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.7], {
             Offset[0.5599999999999999]}, 
            Offset[0.7]}, "ColumnsIndexed" -> {}, "Rows" -> {
            Offset[0.4], {
             Offset[0.8]}, 
            Offset[0.4]}, "RowsIndexed" -> {}}], If[
        CurrentValue["SelectionOver"], 
        Manipulate`Dump`ReadControllerState[
         Map[Manipulate`Dump`updateOneVar[#, 
           CurrentValue["PreviousFormatTime"], 
           CurrentValue["CurrentFormatTime"]]& , {
           
           Manipulate`Dump`controllerLink[{$CellContext`i3$$, \
$CellContext`i3$1097$$}, "X1", 
            If["DefaultAbsolute", True, "JB1"], False, {1, 200, 1}, 200, 
            1.]}], 
         CurrentValue[{
          "ControllerData", {
           "Gamepad", "Joystick", "Multi-Axis Controller"}}], {}]],
       ImageSizeCache->{391., {195.75, 200.75}}],
      DefaultBaseStyle->{},
      FrameMargins->{{5, 5}, {5, 5}}],
     BaselinePosition->Automatic,
     ImageMargins->0],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "ListAnimate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.5457560896994476`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListAnimate", "[", "circlecloud", "]"}]], "Input",
 CellChangeTimes->{{3.54575618447394*^9, 3.5457561853019857`*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`i4$$ = 111, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {
    "\"min\"" :> {$CellContext`i4$$ = 1}, 
     "\"max\"" :> {$CellContext`i4$$ = 200}}, Typeset`bookmarkMode$$ = "Menu",
     Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`i4$$], 1, ""}, 1, 200, 1}}, Typeset`size$$ = 
    Automatic, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`i4$1923$$ = 0}, 
    PaneBox[
     PanelBox[
      DynamicWrapperBox[GridBox[{
         {
          ItemBox[
           ItemBox[
            StyleBox[GridBox[{
               {
                TagBox["\<\"\"\>",
                 HoldForm], 
                AnimatorBox[Dynamic[$CellContext`i4$$], {1, 200, 1},
                 AnimationRate->Automatic,
                 
                 AppearanceElements->{
                  "ProgressSlider", "PlayPauseButton", "FasterSlowerButtons", 
                   "DirectionButton"},
                 AutoAction->False,
                 DisplayAllSteps->True,
                 PausedTime->8.015840530395508]}
              },
              AutoDelete->False,
              
              GridBoxAlignment->{
               "Columns" -> {Right, {Left}}, "ColumnsIndexed" -> {}, 
                "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
              
              GridBoxItemSize->{
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
             "ListAnimateLabel",
             StripOnInput->False],
            Alignment->{Automatic, Inherited},
            StripOnInput->False],
           Background->None,
           StripOnInput->False]},
         {
          ItemBox[
           TagBox[
            StyleBox[
             PaneBox[
              TagBox[
               PaneSelectorBox[{1->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4ldsaVzlyuy7lKE3GCmmbdzTxc5TSLiUiCW2KlDF1OhpESZQplMxH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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lGsYxlWytZAiibLGEUdSiZZbllIhSSiJHAkVolRIypI2WRKJskRI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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs8lIkax932xEaEyi2ki2tlmbQ5Oj8REpXV1a2sEx/LbKxLRa1UiIrs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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVHk41IsCnVARUupmSUUJJVkut8XUQV5NlIoWqSRLm1eKLJFeJCRahKKE
4lIuGlmmREOmZgwaMzJDQ2b5zQzX1Yqe9Xl/nO/8db7vnO875xj5BrkHKJFI
pIhp/J+rapQ8FZ87MabWlzhmJkJFntrL/X/wsXDTHL65qRgO9B3rLFQrMcro
nUwxVWBeaV+iVSEbxp6MPJ4bgQNPck0bNDhAueZR+9ME8n7GhM8o5GO5ZLTk
Wsa0/qEh690BNrg33qoYRBLYbk7aHHybh3RdN6+WEAlsHjUk9Lu0o3nTJM00
VopA88seRecEIA6+lTVlibG2QjtMo4eDXtWIOTpdBF6TK71DdKogqPE8mb5Y
AavQU2IzyxrMcAhW3pEqh8+D8DcmdQ34GnL97+RBGVRvPuoP/czFuYVsr/96
SBBhuDqKvfojNJPWVYZGiRFlM+WjK6jAa0bt4yptBSruGH8c8G3GPwdCkjZf
kcE3sFd2PbUFni9C9S3jCLxhnam+pMXBhVrHuye9ZKDoel1dc5KNcStinEMm
cL/zDjl1FgdxUrXw3cZSKJiuB9Ujb+O2/p5Uqy8KkDP792d2MZGYtTW84JsM
H7y62zSHmrC1Y+r4cDQB41wqbVaPAFKDjVXrX4jQmzK01m1JJxQhPrbm0/6L
LqoTdekc2DNNmk13SOHfJ7cr6GTi7JI/BlcXEqAfIQ8FZDAgtzKms8UyxBvp
qhTvb8Na4aPNOx4ToJS8kcy6wMezlm8ju8tF6PNa983mP0LoBmablI5JwKHO
Pupq347+Fbs2zC+XYnFR/0dKVwdCvg/Hj60X4/uNB/2zM18iNtu5J0hZAYct
jQnL7G/AhjzMdpxQgHJC6Ztf7XvEj++MpWnIkEuNWkWTsJCaJszSMpDBQJJB
q3nbjC5DVs8aHgF1mxH32n91QOO3TMqTM2KM79GTpbFa0LR8YY5DtRSHrSXX
il+1IuOvia8LjGXonfigYnUtH26NahZhfyrw64eB6T8vWjE/NzvgrCuBav+O
tKREPo56U9WKgyXonf1u7MXWj4gOb21zrBPj7uOekrOL6DiR15jn5yYHyWpu
efC2OzjMM/gt4KcCu3VNMvINWsHt9myX1Ehh6/z9YoKgHObncwqSt0/nGyZz
1kTw4ZCZ2NM4KYJnvWPAxtp61M3UEASGySF0/KqTVdoE/17HpV2+0/lLtnm4
59DQqFfapsORQ4VXv57aUA/vYh8+K0mO9gv3/Bef4mKhkWbO+CMJBHROYY/3
W5RxS1yatOUwXhY2HjrWgcxX2oyrXSIYmj2wzjWioyIr6tNzgRyccvJSFRcO
Bql81RcUGUb4fa5Sdw5OTO57Gtgnxcq/tvATeQKUm++2H6yTgL6dlfTvX+2Y
z58ffWxEjGQ16qr3czmglMUdi3GSwjm2W1NA5mKvQcCByk0EimpXNKr/bESy
666s/c0ynMcnvbC57QjiuHEP7SHg+vpvn+OGbVhYSZ/HZEvx3F7rZvYQDapl
E356j+VooOaUlWzhY2MS7ZCTshTvdcovt0Y2w6m6LINqToA2q9syn8PDmRzG
fW8LCUhtBWzDS/eRbHd3E61VgbR8n9FCRgfoanlbvFKm/2luuJl+zAcI350+
OxEvRYpx86qT4SwsffWTRTktQ/G9ixZUSy72aKduUBqVwGzQqNQsvg0hz3Qr
aS5SkFjh0+O8gZ8rfkRFjStwWGuUrC7n48k9g7EjqSK4NSQ0pQg5oLM+FI6c
l6J97HNE8E0GSAe3hj2qkUFQtMD5ims7okPzOqqNpPDWGXAV+XMg0jnEVF8i
wxXnmPRFpTw86V6r10SW4KFHzlKVWzwsLXUv09lLID/NznfZKB0u+y4TVT0y
3K4Xpple5IFmvUp9+DKBiOHh19kxPahzmVKqCJLAwSxtu5dyIrJC9Yd2zuhD
cstLv4wvPKRFVv/YYC2FRs/vc6LD63H+FPXWTls55hmmOnnNqYNyws12/yA5
zq1ObmRKhFjxnqw66/deVIh3rd/lzUd+p7Eg8YIEu2VdEeT0HIRYc9rVaxSQ
CN9Rroa3YCzB0ybYiYDGhkjfSVYXPjRtN9mb3guVlCDu504WTFCvZ+JCgPnp
i59TDhVTE2KLr84K2PppLLrm1IbYX6263AYJkuzY6g9WtiBw3VQfc6YM5JHh
mdoOfPgvuzFBGhNhWM3sztM+DooPLFi34YcUVjb+2fG5VRB2FVrdl8tBiT0n
9B/kw/JIf0tpkggDnZGOBd/4GHD1mGHBE4He4BAXakCFoPB9wehZBZjML6vs
djERf+zmJOOSDPvcgg+ds+6G3ek/3cVpYtgmfz8W/bETNte5WlqaIpj5qSu9
/MXCvQCneXFUGTgktv6SoudYw9gWk+SvwJUnA6U7NDLx0NhV7vFJgYH+tFtT
B6l4aXE/UP/g9J9PxP36bFuH5cdHLRufybHSYrQrmtGCoW0al0/bT/dFi0SR
1BYj8XEI6WmiAj6lcV+uBdehmdSqHNoox/8AA5zX4A==
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 2->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lOsblkuRUh2dQmXpONmidTrE4c7Rnqw1aVGWMiW7ysQplSXJmmOi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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHc8lW0fl4giFZJVhLaRSEp8Fcl4KkXTSBGykqchJSNPZQsZkZGRJFsa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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs81IkXxdhSbWKTlLz7VUravJMcSumHPEpKemD1EKKMqJYGeYSkIbSV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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81Isaxm25HdTRaaPcMaQS7r1ZT1l66FBI2myV5FgyKGuYCAdtsoVD
pZuI1BCJk1xXimowI2PGDIMUM79ZyDBt5+om3bl/vJ/37+fzfp/vaxAUfTBU
RUlJiaqY/28t12lt158HEcfR5jbfFWGTnr6dpx4L5zLvlXqYieA5MZo6cHUc
T6rpa3US3iJ315mm7XajOJ+goe3mMoGFlAcpEgYLAY05h+26CciduzTrNlfC
MCWx4XaNFF1BtUNsVx4EBd5F0SYiOEbZnl1404w1P3Tax3+TIMtP98BXVTZM
U1uG2m0IDHgX+NH076Nan/aP6BApjOjRFwKODaLRy4WutV2IqEp9Vee6MRyO
dV5rdk8AuX/Se3f9Ptz2lbdFPCVAGt0QPz3BR+7s3J4Jm0lkeuo+/R7EQX4V
qaRogYD6fA3NxvoF5i/6jUzeE4NHDq5RLunCD/9ZekzLX4LAuKhqkrwRfXt9
djKNpaiWx3peqBvETKRsW4C+EEuZprfme56jfrrAt4sqBnd58evY0zx4mT7u
TDQSoTWg+FPLNzaaPs9+qBYKcSIytNDKeBw1qauiP5wRQmmkt7XVqB6ntz/b
dzNZioityLTP4GBz89d8cq0QRL/BEfuSHlh8a6NYnBRD+bZR95qlb+H+trLs
UogAR66rLNngOYSsw6SGuBYB+hpLlvx5cghm92ZlOYUC5Key3sqMuuB41La/
jy8BOar8tpUqDwV3/zletkwE14I9jCT2SwTwA1KySGJQg9P8j375A6XTU23n
rKVICSCNqR8fA41yvuBRnhBmiaebDer4yEq9xPxoNwklk4y1rx0j8KMpM+OO
zhR01GKtM2dqYSHPXfLv81JM0NINeSQaupdR1j+Nk4Iy3+HazGxDy/o1tMIm
CQYiHI4kdzZAQtK4ZLxPigG15UNi726Ualj6PeSIEVjQNltu3QueyG3juJoE
o5T7NUWr+fBS/lSXunMSv0cHT2WHP8emL8xj5llixDS9bsywZGC098Tl3DYx
mmOSD6Uo7rHDWOuG4UcBcnUW9Lt8BpAf+JAtMxHDaIWVE+WPGjDWF2Y1l0vx
rPss9QF7ED5f7R/6Q4QrMs5c8acuWJy5rl/RIoaN43T9Y84AaIbxZWqEECqt
Jduaz3Lw2+E2l7fuBPzWkz75BT3BogfTtLZEArlm6HcHfx706BZ5r1UEKAtm
dUc2D2FboblT3aIQ7ZZOgb2sISR7eJ86NUqAkhm/6HKqGAOSaNcqsRTaFwV8
7q3z0Ho8/M5ZbQrkj02V+T92IE37fjatQILc0TMyvehBdOheMKK+EiC4khnM
WuDg8sxmYf8FIT6/D08j6L0odjsxo2srhq8m6yy1moXHz8f4KuoiUHPOPc3m
94M82PpC0iuCR9yJht3FY8gtNU6yMZuA6tHVf0rPsxG0dWvhxBoR6ORanmc2
G1ZeUt/2EAL6Ed0RcvlL+Hd9eVC5IAZB5dIpamwIlgRV2dGEKLrBihmrYGPW
2tfnlyACMQXTWc5+jWh3HVv93UaK+33O/qm/9yAu0luPPStCSFyPwUgCC8fS
GIMJmmKYbfrrncWrL0HWcN2X3SFG9V5WUfkWPtKsetKPRE5iPqKfm2DIhFb6
q7DeX0WYsDDUKPOsA5EUlpcTpuCNfJkIc2iGh9rVxBELKSpUbgSSD3LRJPE8
8JEngIf3YqXPtm5UHapv9FXwFuCx7F5U4F0MkS4a/SVPCq5VpFNsRSfqk7+o
ZijyOT5/wVSVM2C50l5V6iuC3Hyv1t2bfJyhfo1PKp2EuLuHXvWBjphwjrtV
ghjPPOuDTWJ6ce29wRQ7X9G3Syv3O1WPwWfLG7J6kRBXApdv9HzdiXHfGqZy
kAQ946L/zjmy0RBYu9bcWAwlrkN7ivJOlJnb/pxInoJASAtbN8LGSCMh0jMm
sPy795MdTnSY7NYOntWSgHtKyfhiGxcdqifn+JUCUJp+TX63axgb21x2vtxP
QM2No9LU9wgv3ockFWtJ4RLCd9lirPB7zoyBo6nCV6ZeX9aZNOAOWy2nKFYK
sv/fY5oeM7DC4rNeR6oIXqV6PSb0HqibCn7JN5Vg60+vDr7Z0IEd/yI773GW
4FLCVPj4ijbUrVd9lDgigX940U2ncA4OfXqk0X5AiN8i+YtuL6oQt3ulMu+B
FPzqh1t+SugDcbqSW0oSQZZ+bt3CBBtXbYNWlnAJBVdGR5qEwygPpVbNMibR
Qi/2nyd1Y+boGt19xWJk8m0PqQ+P4sqbVccORU2AbF2z+1krD3HcXHaqkRD8
xRlaceYwQsYWxgYMCVzPk92eZozgXMUcW358EpTcJe9u/a0GejrXDw43SOGn
gnS/rE6khe5fu0vh/x7v3munFD6hyJ/M1scrfDDM9MqWdcG13Nmt30YCC8tb
O7avZEPG0FRKtCNQfXZuV4U3CxGHZTq2VmK4Z+BpaQIH1FaPIe37in9x7fho
TMo4HOIYSiGRQmg1XF7+/dUIAtRWpXwzm8T/AGdtzgY=
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 3->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk41N8bVSklSRFCSCVtyBItOopKo6QMaSEVspaKTFIoxTdLsiVUylJo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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lf8bxpHKSCHZWfWNSiU7yiWrQlGElnxTikQDqYiWJElDQyqlgWQl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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs0lXkXxx3lkpE0KhYqUjJqUqS00LfIhFcXkUuuifNKSkmRTMMyruOW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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41AsXx6mriyal3PHSZisUkoTQ/Qrdp03Z3t6uLaV1cjOUDJEtJYpo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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 4->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk81Pkfx6csOzuVUhLWVY5FkphVTfJK5AqV0qGcSUu6FjVZJCqKXJUr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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2cgVn0bl1FGZDSoRB5PtkRF8vSTlTZllE1akrQklEJIKkUqW0lWIlnZ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlWk41IsXx9WN+NNeKOraUorClSzpO9J9Spab6kYRlZItiupas4RUtmhU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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs01IkDxSkqLbEqaVq/RFGSx1CpNDcTU7/y2j1WVB4xqNSQMyFqEXkM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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 5->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lWkbxyUlJVvT5C2MvdNizdSJ8jMq0RiV155KsidRpmjBpFCRSihR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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2cglW8bl+yRsoqEyGxpUtQPRUQlSUIlSUOIKIVIRaESpUKUZP0blFnI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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81AkXxilC666U3pSkIqQsttA+KhvZtqSbxDYKIYpa0kQXl0lRSS1l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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs8lIkax2ULySm6WGHlsmIrt1A49JsWKbVat0LUVEIXl0Qhm4kuHFMp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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 6->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs01Pkbx6eiRTSuv5BQ5NJaypZWybuVipJKtpVChiS3VWkYIZdK2RZJ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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VG8bliIq0qZEEkJFIkXid1MS2pRkSYSkBVGSaBFSoVJkSaEoa0K2
JFv2fWbse8icMyMJpVXf+/0117muOe/znue5n3tZY3fukAMvDw+P9Swenv//
XokXMr9v1AzXe+ZxIbsojLcFz7pi1QAGpy/VpJzC0mXqLBu5UjzlDUqEO40J
fbu+3JhKiOxhduss5kDrt/i3pMEuiLcKZqwKY0NjpIubL8FAd1T0j9Wn2VDj
t3nhJ9MKq2RvzfB1bPx2XdhXkdaBgl0d/fFsLkTsNaf8P7RB/9EGp58CbBgc
SLYUvlmNj477jW25FBSapNsNH1Zg5a1VeVsyaIz4DY6obmPhodc1ye7ZNJoo
9Z+qa6uQIDxwy7yAwpNPXfWJUzGw5p0xUtpI44NQuMR8VRb6Bu2FPofR+BFg
GjcW24LBxi0rNIY42H/q8VTGSxZSZbP2SXpQ0Lksy876LxJqQgIad8RpeMpq
u47/9wGh9oxnAhdovJ5O9hByZEKP+v53tgYXUp4j2+oTn+HwUAXriCQNXl6v
+0w7Fky9xyw+xVMwphcarZ15ixNN2l2PD9AYTauRdX7XAFG72/cLtnGwWDvd
wKO9D9f7Y5kFSSMYLmS2Hhpph4iUmovuJxoCPw3EHszrx8S/yq8LdIdw/JtM
4OEFNSgvtfdUzaHgmjnjv9EpD4vaj7DzZWgMWLJyz/Y2Q0tJ77HefRpBrVP9
3e87cWqh7WyBKhqb41M0NrtXYZFFgnenFAf1B7vk1gvnYN5/Am9dltEouXe5
TM+pAxK0d3LcKgryywr2u/uzEKadqZK+kYuwLuWig+sa0BPWJbvkJoXnsQEM
neQCWA27DSWsp7FFfLXecp9OcLV6Ot/KU7i9QdZb6Vo5xLNDfC9/oWAa6y2d
5dKOV6tf3t1tysaCJv0FJaE1OL93a4b3e/K92afcdfl7sTT/jN9djIAVsiVK
/hEDSSarJ2yjOUh4N5miIFWCgHUrW+s1aUjVHnio8iEL+ixNsURVGgkeyuk5
pgwEHF8b/GYNBwqGyV+emuXhxJ/NLdv0aVxZxHbfcLMFWQGt4+785HsPMMPn
8sZDZ+tO2z8KNM54LYiLnqrEfybMQ6laNAofFSqblbbAtfrMxBdfGpWv9M0k
1aoxY92fk36CxnF8k070jkd+pX1zrxgNrVMPpgLv1yFDpbJpE0XhaLzIjc6y
Lnyv3ClrosWBVVyjQuqWUrT45TnJ7KTh87ci8/r8pxhoc9kUvYXGlNEL+51j
leAL8Ptzibw/86D2YvHzYkhlr3sRdJWGbO7djFKFfvh8TnNLduRAT2dmx62l
bYiKDS2Sm/mEwgjTW1VeLVAfmQr+uZSDZV/eHzcwYqFTYNre9TEX/SZyTU4z
5Yj4nIVwZ1J/RUa5g0M+3u2b9IkfIfNRCt7uadWHWLENjZTJCHY8on8qBGSi
KDLAeHMjhY491fIbSjvQmK9xY4qcfyeQebw7sAPmBwKSeH0oUJWDC33tq5FG
xVYPLqShNhawRLssF+WS76o/EXyI3CwWSa8tRUhB+OQObxrLTFIHTDcU4lmg
//7oC2TfB0bpFX3tGPby4k3eQ8Hbo0AkdUM32rKVtr3NY2O94kbeWU5Z8Lmo
wbuNnMejabY2Quk0eB9ayUpIEzxE9CpsmGyH5lXKYgm5jzuj3NXIgOBVVuf4
YB0Ny9K5VcKOnRAddxHLuE74yt8i7KZqMdqSLmf+vUsjXuTjz5U2H7DeXp3h
0Unhz7ZjZxSjGhFgJVEz5yyFIAWt6K99LATJ1pQWDdOQOKO5y7yjAxwVg0rh
ZDbaXr+XkLnHhPClVH6rNlLPj7zwtx2sVUMKZ/tobI9RKfs6woKVtvI9BTEK
XWklk/NUmuF/5ZqycwkHGYtyCpfOq8cXj8nlVhvJ/iQPME+mtMLQ8r89Z6Mo
RIrFbTT82ozYUxcSS5kc7At4MBmi2I6RxFctEco0xo79qojsKcDD/tvSDlY0
FO6n7MsLrYdaTY1NBeGf/x6K73mWV4cTLCW3OQ84SFHa7lQw1Qmd2outz+6w
ETe9PUXsTyJ69ybsK5pF47tu2oGnknUYlBayC7UkfGrp220mWIsxNx1l158U
eKij1wRPR+CQy8GNuoQvNzneyzaYG4J/0et+dqylMa7+rq1/aSgGmLEbYlaR
+Uyp3oiY04nrEdpDnxs4+Dx6Rl/sURWe1xfrrxSnoFGoOft9awF0BtJNj56j
kZXrFzHyuxmlir0f+XrZ+G+fhYYE0QPbWzfnpZB92LeZub2psRPxn8fkV9Vy
sOLk+5o8Rg00hNxO0+o0omozHc4y2uEXOTnP0I5CSpVwyspPpTjEWeiWN4eD
iU0DajsM2+C6P/izrRwXO17tEb8YUoHCA0uGMy0phP3VmXvArBEZp614lgXT
SD/0+a3d1jYMCaGpLpADHd8fPQKPMjF6mjfdQo7wy9Nt/JtTm/BDdd+6+r8E
fxs1F9LiH3DyyUMXzXUED+F/dQRfM3CXKf9vXTsFM+su84O3muGWbcJ+F8OB
xo4HKcs6shG87IZd2x8KG5//bg7TZOEO//GhGVEKx/emG+dGFGNejGMKxaQQ
yOZP+G9HJ2TVW/uHDoxiPOTwt1iFt4jr+B6zz45GaHk6O2AnC5E/RnR/fxyB
rFfl388TLBz+IZpYFkOhpdNXVvloBxJcQ7LWE/7lWbZd9qXABYj+9cuj19Co
XVByqyC7Gxm0c7V+MwcOtwtnn7tRhax8l63ziR4rUJRyteUbCJ7kvdBAvlcx
xiigpZmBwqsXv+SQfnfoCe/5mZoDRc9xV2Ny34XLcgbtuEx0hQ4HbW+kMfxZ
wTL/SBuuSt2R9itgI7jKKF94cTOaLSNttm7gYKB9dk50y2uUNVkHafASvpBO
PGOQwkCP3+VozyOEb3MvKVb2MlB0UF3n3hw2RJgnhjUnU7CFOW2Wq0T45p75
Yb3cUszJ9HN4nk/Bi7V0z6GSDrQ8uK916BwbG/uZ48blTdBR+N4hwcdBdexx
6/OsDlwZDX+TlMlFTJTdJtu7LTB8NF5x3oJGy87fUdNBH9B+59KE13MaQiMX
+ulDLJRcDX4ea8pB2h27zdkviD9y2DRLYxYHca38kdeKnkHS+bZzsRSNnNl5
zD+lnWB9ErztcJrCxGv7MZ1bVchoV9Wvvk/BZ2dt3abNLCiamz19c5QDIR8l
1/2vO5DP3O6yeiXxR6tMF6R+z4Xo0fo2px8UnNbfjpHxKoWEeaSq6i0aC3L1
BqlEoo+h+ZZsok8nxAOT7mS3g894UVnvNxrUvYBFDsS/NJtrm7qpEX3k+8JW
Fa9D9aeB9VGbKVjOknNZ+Y4BDf6Cnz7rKAx4dnmsyWjAkyDFu/lZRH+04uzy
1ZpxIttp4upuDqJFd8T2dzIRNKdiWeMeGtXKMWnnFjzDhaCwT0/VaFi9tjAY
EGzBRNAvtbd7yP1FE02Xn2rF2J/CU1DmIlh/X6VEUiEUPE1No1bT6OD/Zp4T
2oUn0lLfqkOHoMPIC8g1TkLTehtfZYLHJ/+SVfheMVG82NbwBsGra2CnrerT
bFx84X249CwNfgGezvDsMtwoi9ISIPuVl2P5sF6YgQUa3z6PVlHwzzGKb5zf
ifIVAh+Xf+Lg5cTE/rduLAiUvjwX/4+NeScW5CsVVaPgzBW1Z6Vs5B+WmyXw
9C1UX1vNF3Egeu+iwm50j8C7qT1j3fKE70Ziirf9aYW1AXf1b4LvNo5ktr1r
D3xM7FNenSH+yjT8+OJqwm/m177u3Urm6yOwkmNWgQGXhAQ+wseeEYlzzc5V
Y8q9/tUi4tf0ihYuHwjuweJ517bwW3Hh6n9h7uldpdhrFBHo5kQTHSuXzwrq
xF4LwZtvgrmwEczyFshmoCBFpUf/KeGfFYYHd8l1QMPmpzslRPhsB+8c9Zgu
HMrhiroTflKNs1qlpNyGJzIGMRacEWzrtnVPed6Citj/RNqfcFCyPPty8Y3H
aJC6I8Ml/sfriefqn2X5SLPxUfllRqM+jM9tthEDkXvyC9T8uXDhSbyU7cNA
YP5ktqY7BzwPJ18ajNlBcP7EaDGZl46gd7yc6XmcyLhrHUSeDUZwMKwlHqK1
O59EEz48niPVOP2vDK+jTi2/kUP4Nbrto9J0JYaN/buiyyg0N64tuJBWgSeT
qq4zIjTmd/CnfHdjwk/mQ42dOAcizrU7KpiJGDq67oEkOc9Vvy/jtGkTHqtc
st1F8OdoPaBSYViFYY+47oMxRH+2Rz2oP8XEh5Rb2/WvE3y6bV3b7E7qcY98
dA0nftArRrOXG4L4zJN6B4ifd3AYuhgl3ok24fVv2yy5MD569m5bYSYCK0b9
f7eR/Vj3r6x+sgJ7+dxNiuvYEJr2aH/Ay0C5guHhP4SfsjolFhmWtGKj7but
CUM0bufYe+/OacTqWMV7RpFstMJYXHl/B6wejk69IfoVGb8w49zyN9hplXfr
LLn/icmxg0HnSpHt5pIiRvz7ph+yr1ZdqYdYvPbNxydpHDa5GKzVWYW6UvNr
ioo0wkMLSk9EstBiHtL6leSfU54+kjcYrVA7cPDYCTOC95uD4sdOtsD9ROi5
9v0c+Eht95kRbodUZsyuO8Tfpv7jVry9X4+CsV/MPOLf1DM9ZtUKt+D66pki
M3sa7pTzPg2JFrwpeuny25/0/8Lf+fKc53hBCFJOh9TzPW9vmF6FuScWtX0k
fmXA2uDLr/an+OsdtGIxySc847JzFRI/YOutJu0k0r/ylmSvPO1WTAlWpl1N
58I3OlBjZB4TmkcjhWYkCf8va/ZZU/MIKWNFxnbET6gtEl7r+pSB9aMa947x
kX6adtTqlxfByELycymbwqivtXnE7rew8PdI8txN+C4kZPpmYAZGCln7uYYk
v2bIGEjOZaDe6piBUSHhM45cg3z6MwjkNTzWJvN2/66upFvGwD2x84e9Bcm+
Xv4oXmtehubnZnaOL2iEGD46pNzzFua3+i7tGiV5Ueur25qbxaj1E/30zoOG
/m7nCPPz9TBX3nI0g/RzfJpeK/O6Fr6M2dc8ST1uX93vw9tqcWzcbUxXluC5
MMt7UXId5hS3rxo9w4a0jP37hqt1WHBV0bmU+KvhX25HdftaICdffDJtDQVf
iQ5fXV8WhsdZzpeJvksppT7gXGmA68QpryuEXyxe6iycxyqEo0BumZER0b/V
mxwk92RBNTPQ+Ys1jeaM69tunMrAoOWmX1LbacjYSHZKdLZi+L7VcLUMFx26
J6aFrtTivazNw/AeCvMedXdNCxfCacNKJf9NNJ5Pa/Q56rSieu4Xhwv2FOKE
FbSntMsR07CpyCmP7PvCq3Ps6ACMG+/WV5SgwVmZ+TzsSCr+/Dja30r6L1Lo
kTnpkYtclcma2YdpxIWe43fTjMKStlfNQStoRJb5zS/73oTUpI+1LfUcBL/f
KVisUg61P4FLQsh9LJ3Dq21uVyF8fnvdHm829oV2BZ7VLsXKVJGGiVhynn9J
b+adN3g/6ZM9dJHM847dkVfFjUiaz+srqMVGxg7+p2MVLBSoVLf9In5LK/KI
j+CsLkRWaqvNJNHQPP7sp6FZIdGfS6PRp0k+klxOm3Lz4R6mqZvdQvSjN7jd
urYEu/eGGUxmEr7ZWXO29U4xeFw5KkPEH261/Vnf7tyOzR26thfPkv2quPF3
1OEmTGX2yiUQfautnFk417AXx9+vylVewEX89Wsfkra3oq5+fpsG6efA8i/B
mcsD0JYrtcaG6Iu/5nUv5ex6NK1+IfSc5JOEMw6iNox6fPebOvmQxUbTmpqc
35tasbX9y9eMVjZCfnyz25/Ggqtt4qCoE9Fb9VmO2Vm5SOue+bKL7MOA2nr5
StTBbdZxT93zHMjxyevM4+nBV816NwWS7zlL3wlJfK6CzyK/d31dNDJqOD2/
QpLR+HS9/SOiB5c7Dm1v/1UP10v9xqsf0bBu9P577EcjooLmPJvVS8FYT0pv
86ZqvAzR7n+fTPLR24vMaIEP6LpoY56tSfBru2bR3V0MzPx2/ZKRT/J+RsA4
T1c+Iteo/rgxROHhzEmhlG0MrDAJT3ck+TY57mWdiPoHRC6bsXarJHnI08hS
068ZvyTyxtYTPmV9/voq5UAJ/mW+mOlbRO57RIR/Pu8bDIoVBgfOJXhv33Cm
4vULOGsnZtEkn1erxl453VWLe0t092oZ0zCPcV7B/7oCy/dED58m85Q/yn/K
d4aBh3X+xZK/RjB8XS3i18VG+B7bYeVB/GPzqpx3O71J/q+SlhZOZ6Ou2+f+
s+BW9OZEDUoTfPZYSnMaCH6Zhj3C38s4sJk9c7VnVSdGcu8xWI9HMDTjO3hb
sQ38i87faFxCoeQ7X3nj3VDsPBfVcJn4VVeBYwIPFSrwRmVjknU4BbG121l1
jvWY+hficpdLwWSxpHSAExO64wPf87dwcUFCIFJ2pBV73ywuLpnmoO/ZYWv7
LU147stZem0/mT/ftMsndRayt1kl9P1gg9G9Mnz2ox6sbC4pjnxC/MTgmjBH
nUpwmALSTXNJ/rCUjrFnvALTa84nMeJX+Q7KXZpY1YBfLbd7W7cSf6X2qp+f
+PtIY5ZkSvsISvgCpx3dm3D+teVsPQsKDT41W8b3VoPn9pa/qSwKGZe0EhxO
xuCIjKd11lIaLw789VhZ3QH1HaM75+Zx8cNn2ZXZbjnIDL2fLUH2f2CXnrPo
lxRw5E2UfEk9n6x7vqJ6qagV65x5p0DD4kgUc0CmHU9nsizSPhI9a5DWn9dc
hvoenXXSJH+MylU2xMo1oeXsAWYnKLw855/BbWWi96jLqe5LpB/Vc+niFV2w
6Mko3DTChXvOjatFIQm4Zhy7+RY/yWeV/66y1xchr2fL6jPbCD701oS2TGUh
LuqIgTzh+yumWrv0z7VgidD0vXSS/9l8ARVjC1gQZUWZCFwlepBrJlLRXA1d
M06kJfm/8RuDscGUh/julO6UKU3jz9fhddpd2ehQz+ZGFFCQO8s281hVh6VT
37UoLxq6F31sy7kdyLD8e+DI10/4Y5Lolm/WhVArlldjGoUHinNb/R1bcO3X
+8kwmovBdceW6cdV4NS1S39mM2ko5un3f9vdCYc84R17yfz+ByhaKAA=
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHk81Ikblghdi1QSsXJGJW0Hq542ku1AlMSu2pwpZ6WIT6jVZeWeksKk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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwdlHs01AkfxuXyJm1JhC0yuURuuUVk96HQZZNLii4iJN2Q1LJ7elklJe9K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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 7->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk81NsfxqciuiXJaHELY4moqCxRPCktCm0KSUW02rpuylyFSpaLGGMp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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VW8XRcpQhpCxhERJSSmlsiRDihJCKpK5hFRoICqSQuJXKlMhEiUa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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41AsXxyckKVqkRbxZIlt1s6XbvX25cVtkvSHeqTS5Ra9b0yZtlopL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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs41Ikeh4eWOnKsUIgKTaXIoaUnbZ3PdMGk8khuW5LtLDkqJWoprG1U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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 8->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lOsbxodKkj6RFkXRSCF7KtXkUo5OOTqlRZiKY5mQMiRRFOpYS5G9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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VW0XxqVIkiSikpSSSggNb8mNjCVJkkoqkUIUZSivoYlSJENeSZTM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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41IsXxhEpS1GkLJXSLkZF6qoXpVDZCl0UikIYlaSJ4t4uk5BkqYnf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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGs8lAkbxqehJYUpqbcDsUnRCUlILmfekmNSCVG2g0Q6aTcZSnKo6KBa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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 9->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs8lVkbVWPKuBRKESm5VSoccqtpuU0hkTLSjHKrSGp0nHL5okg6IyOl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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8le8fximzrFQSkk2SioZSLjRERvoWkiSRUSFRkpW0taRJwwgJqYwG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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41IkfnkJrPdqsbCappSRyROSqvKu2smWZ7doRJaIT5ZhYJFpnpUPK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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwV1Gk81IkfB3C1GeeiQ6RayllIyVXJh0TCqm0RodoSkURJjhwhIqwiHZtC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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 10->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs8lFkcxl02uZSEotGNXWmT+yWp9TCUS9qkSGsQa6Ry7SLS7kRWqNQS
5bLVUkLZyLS0sTEY5NJMrjMx6SanFGWjRPb0x/t5P+/nc857fr/v73meox0Q
7s6WkZKSyqTP1/eSP+1t3/3Ew0Lz871cEFyILgwNPN4Lr47Fl8QRBMEsnZHZ
+u2oEnEisI/gGFe3MfzZQXiFyM1o6RBsd3GR556WwCXM7+PJUoJzmfWhlexG
ZJad6uYwCSxXneveqdSGg/LTokp3uj9O83SgximovOgZvEn3m2dpC27P50HX
3zsqYw1BnBGziWnyGLq1C0N+KiCYYsfeGb7UAGUxp/ywI4G87L50U5dmcM+e
zM+m9Q6x2OUlqxqhoTE+VW5PUDxuufK9QSP+S3tYV0y/bQ2fRKfKlOLcPBxO
XEXQ5PbH1S8Tt7HfsYyvZUBQamuSr6SWD+sA75y/dAmWit2St13ggaeb6rr8
6/4hn9AfBrqgdXmekdQlAocDCatUHRrgFjYa9vX/8RLjrcdeiiFjHsY820Qw
cIado9mRBcefIyN9viVw4nGDXAvvYzLwc0KIN8Gzb4+693cI0f8k5Wz6XoJT
z4I9b35pxMCW6cSJrQSbDpvHFMkKYVqhUi29g4CvpDypKCvG5PzkLGkOwcHE
Xbt1q5phZMupcPMieCra8UzppgCRnp75U2GU19LVJibP7+PpcInr0s0E31gG
nUmw4UM72pA7toXOS1B759OcDjjfW1waH0sQotod+cmyFZqp71d+70ywq9Ij
wN/lb9SPH87cbkx5FfUt7MrsgOl3qXLGZwhWShrURWM9cJd54pGSTzDMn2/u
XMxDXERJQPUGAhcz5nXtKCHi53bXmh0ksMm1i1ObbMB4vPwWMyeCG6MN9/wr
RTg6/5fp4UqCwNf8GmdOO+JdWXKaQQSdSf9lzdYSInYk3qn0AEFBdqL0b8kd
iPi7yJubSHmG6Zp2mtTDZaS44Do9r2ZhQuO1nmSkLHu+opbqScV6teiEbwXq
2wu9XE0J5h3OZ1QJOrCCFRjyM+V9Xc9EKGXeAabvhN8RXwLjifiGOm4LVP5Q
DPL1I/hH5Vn9C/1u/F4w9vp6FkHv4amUqoA6GHXx/XXoeVI35MMMGMm4uuKh
1lF6Hl+0JaT8aQdWaY7em5VAUPU446/vB8rgsmziWcVqAh215hL7+5Wok7fe
xzSkPFKGFE0SH6K3N3K1QTCBF6P81yTjajQmtiyeoPUaPijfRUb/hL3Mx+4D
39F+jatFWgl9eO/hNlNOecuX2fWp+bXjr5Gbl3bQ+evkKcVVrxHigtbcafVQ
gtTHfiNdj5pxoer1+uptBJ/vhsTlF/TAKnpWbO1Jgr0hkzt6m7qwNXdDUMEx
yu/qB7HM/gPo1zyvuIT2c0V3I9foYh+SbmxfrJpMwNmu+txqTx1EN/dl+NgQ
XNZQeKMmqES9RKj7hfa3Ps3dWeF6NxZ+aIvknSMIMLFSc6jtxINbMarMSAKW
YOQDM+sOojeXSEroevHLRcO2kk6w8srS9KmeC4/GLFcwkcBzIOntr+O03xfI
GfDnwTdvcHzGnGDUe0EZY18d1jidV1Wg+XBRWS3qkE0dXKtTH1+l9XQE5loL
uDw4xH3j/Yry81IcHHggbsVikfxsJU+aN7ulw7n5SbjSnvhjI+0v5UDpmjsK
Qjior321PZpgkcX+5SZv7yFBfyg2me5fv63Q52lwA4K2TFzVd6V8xkS+2/gt
cDvk5NTtT3m+zVFi322CVkmf/R803wQqbPmS9NsoeON7fgnNE6fKzfEH5rRj
RaiA8d3P1C88Ye4H0zJIOlX9avQJzmqLOFcW1CNtdvTUW1uC1Z7rVRbs74I4
162/P5PqS6OB3f9PPfbctS6I+Zp3ZvcZDLceVNVnP7xG80edVVU2qFqH/rtF
UvPW0fPz2JFXGWJIOLOLjeJpnshI+R/b0oqDLwILZtH5R0uK7G4Y3kD35ZFN
6XoE7/Q4+e3cetznTratoPXLv+vQyjLnoskxcmksrX/OSan3T+y7sIuvua4m
g+bpG+mcYA/6rT32Nvl3goRXgwEONr0IHdj9YR6tR8bGPX/ktx4cFDVYFJcQ
aBo5ClzvtEDNvMt9hEX5B24wcDWNx0j3IiVnyl9gGl7IKrmFFZI93gbfE2Sn
/VuTISvALbme2UdpvTX7Z20wY51A66wps610fadPxLENnb1Qza4evZ9G9Wdg
vPLi6y7ksX8ZXE3zKFqbE7FAToglOvx1u3YSmPnMcrdMF+Idk1F5zY0gyZW5
xvATDzlWl2LCqV5+D16SIxtfg0bJdEzIDzSvT4TXdgdfQ83r3Ewdmv+RL9NX
mrn3wqlp0c1y2p/VlQgp2wutcMw719NK53/OzV2/xZTyaDNaduM09XvRdPr7
tmZ0WEb1KlI/ygTMddZYLkSysDSG7UHzJD3JL82sE9GMKvXlVO9NnFzR4kPt
ODuRcDKYTdBa6lE287kPDLXCMa1HlI/T05Yzyy9jrqpPVgX1P8O0b6mVWTeC
PrHFFSEEfsfeBDCF/8Jj3DH85Fr6vyPTXcY5D8G3rqpX/IXm99rOVVG3KqDK
N9Dj0fwOYDoOBG8UwyF3KiOS5uecFD3/yxlCzLxQjCql97v5m/e6VjadkD+u
s2kn9buDhYU6g1uLhEDbdbKWBDO7LfSn7Lpwqm9Pom8SgZyKskKJJ/Xr2I/m
vOeU/4Bh+u6iv3HbwiKPRfUztKmthpX/EB5ifRYoryDJx339nzvRd1d54ynq
N0GaZWox5w6Cjnxpf2lGcMh7z5TyzjYUSjvtyKN+0RlWkEurykOYXnX2EJ1H
zedho3GpZqjPfbzek95fwUExAsarB/hUf0/8hPIojRVLL+o/j1NeR1/N0PuW
m6cuo1PYgDmns2SZVtSPmYMee+2EyIsMPLGR9tt7JHii5/gDaOQWhjRTvRVm
PB77UdyEElehMp/6YeWS4ahs+2bE2tlZz/2J3lfFA2+0/uzHUMt6k5rXVH9p
G6/tyuhEu/b+b/Wo/irPno4KbRZB2mvZqNM/BCN7AqY+DIlgPLn5kfpFgv8B
xyelew==
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Vf3bxREypcyFlJIhMkWpsCSVBtVDqSgVGgh5IiJJktSPzFIpwyOi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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs81Pkax5GwViQlsXY15RKiNCqST6kUdSIUNrGlXFK6yKWbu45LqWyk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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs41IkXxieJogvtbLcloqRSI0xJw9uGKKk2LdLFZSN6Qq1ri5JKJVJJ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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 11->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXlYjNsfH3G7cVusiUhIi5S0adF8UlRKiYiiFP0sibQRklQSUTS/Vgmt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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k41O/7xUWLJJQsRaK0SyqKFkcliZRKPpKyJEqFJKlspRCyk+wl0bco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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk81IsaxoWcScUUR1TKVgrdMx9tQj1aKJUTZS2EUzhJpyPdooybcizF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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVH001IkClSZJr6TV5qOEUaLShJSoq56h1IZ8Ljb6YCO91sjnlqyEmjpk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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 12->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVmk81WkbPmMqLbaMURRDjCyJQmksl1Ba1BgpKp2MHCRGllAhNaJSh0S2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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c81P8fpyRKoiQyEpJkVb4NqSeSBt9+lFFWRVRSFG27JSuVVUkiycye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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHs8lAkbFdbiy+aupC3RJuV+TeWQXLJlRUrZbm7lkihSrFuXSZclXbXG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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlX04lIkaxidbUhKV2iMJGZRKmj6stHtHnIqUSaSsaql8lVSKOoqdCjmy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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 13->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk41Gsbx1UqR+icVuT0Rsp6MZYKg683nTZyaJhsEZE6QpYkco60HHQU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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHk8VF8fliRKQpIQkmyhVIrIo6goSmiTJGkhpSQVJUSyZvtZW4YoWoQs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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs41AkXx6VcmtyyEV0QidxL0mXqq15KtoRVyzZttpVLPLFi0s0lmmiF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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81AkDxl1Fot5qYkiuJFE5klXokViWt3KTiqJj28pQKlFEvYwwaJ3R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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 14->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk81Vkfxkwpr7SZolfKOtfela264zEpsoRsI6WIKBExlXoVouyGEmps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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3cgll0fVrSQVQop403JSEZCXpekUBQiWshKUikvmaUIJZFKRUNGSjKy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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs01Akbx13iyJttareUS64V2i72lbyUr6JQtmanpdymMO2FrbAZTbVR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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVWs4lIsWJt1IUqmQtlEUuuhyiDi9bpERddxOMZWUHZWhGbWLyr3YndAu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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 15->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns41Okbxqdy2lRIS23anJI21uEnOeXWytKQZEMOiSJbaVkUIiRUWsWE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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3dcje8bbhFKm1IaqKSMiEJyhUpW0iCkkqykKZJRkQZJhZZQJIk0nXba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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk4lOsfxoeTQ6lElFOcn0KN5aQSIWfuEsqpScnSQsjSOiVpIUlI5UiL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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81AkfxxGlVZJVeTY8rlA6JD0R+VA2NpqsJ3JmlCtHTXSzkdglRMvG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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 16->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4lGkbZ0nUSitsSscllJDG6qB+VCuHHGMTQnKKGZWQDqjNotaSc6mv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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c4lu8bxqW3QipKaCEjIxmlQji1RKmMkuxEyS4aSlLfQpJZRiRRUmZG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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41Wkbxw8l5VUaJMtliSwHlSxpFN+TREoqwwzeiYrWkdeUN06llIRk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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVGs41AkftROF3NkloSslVNIiydEmt8rQTrFlIyRCVFLJxNNF0SYpY9Aq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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 17->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lWkY1TTTFJIWMnVRWZKytKFBx1yVpaKxlEIj40paiCQl+0iShCQp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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VWsfxU0prgwlpIlGV8KVJg2LRGkwlOSqkAq5XEOkkAwlTUIkQ8iU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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHtUzPkbx8clRKitsG39DBK621JttO9SMZIuw6iIymWXdF+taZGhUhFZ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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41AsXx8cSJZWIqFspl0oia6R8K7pCyZbordAit0WWG6OQ6h2VUhK5
JEnd8mSJkeWKUhjKGDPITMY6y29+wlCiEnrn/eM857/znOd7vp/vWXn4jMcx
eQqFQpXV//vu7gWS/rIuWCiM+tof6kW2i+NmqRwTUz2r39F2EigIuTv8fdF7
xB6Tj1+QQkDbvd7XPpeF8XvMYHMTAjzPTxLvZfEI6WZddVMcQO4LXsXorUdI
9NbyD6wgsWu70eDTX1wkTK5zn+vZj9l6ObE7V5QhVRK13GJMgqOVA1k6j59A
qYRhszabREIVz62ivhWzHYh1eyxFYEvVw/zYTEynPvQO7hCDwizpt0h/BGZt
j8CsisSSYz4Hb0vbEaTmZ3bxtgDtlwhXYm8NRpupfvuNJNC9umFVC7MDR5Ku
0Ux1BJixyTvgXtKM8yVOBSsCxOC3JrNUvLl4XOQ86NTXD/bZEunh4WaEL/ej
JZaL8dlqmH+WwYHUM2LPeJ4YW6WUjdm86zC4oqQqP0mi6MCezUOjlyE9XdJ7
bdYAkvTNrDmGrRBu0hH6hYvBO2PTf+tbGbx0dKP/UiURzbgyXzxNx1/ahl9m
25M46SL8Z0qRAbM1Ab8N8gkks/39ltR8QEGXxZ5nsQLc2OvxMLSdifNMuzhp
qhiq+VbyPpuqkFw1NvKtXoLc/sXXn+pxwKu7iB8TQujSzQ4n5XEwsdip4uUS
mX5LorWtLYtxpTy9fLsFCX9Lgzn023eguCzAt2SAhFrkVN6Raga0xkqnKuUI
hPzsyupns+ChMnFQpUWMPvZ4qJbGO7xqVL3Jixdjwxtdx4/6dFS6KNb/dCER
t6zwOX05H92+7fU21X04kOl7qiGpGQqpQzmdoQR0N/4+L8y/Hg4/TdNbyggk
6EryaiPZ6LMNGw6gieBut2vkoT8PXJHqsRvrRLjqKG+S8YuBJ7wx916Z34rb
fO4w0tvB/nL671UiESy0n+49NM4CNau5pvmxCGofT2lZDeYjx/n4RGssiSGe
mWYlhQH6iURJ2RiBawbq39u2dsDINzgyQCpA4/SonI4CE39cfFLbe1MMZ6qR
a8sUG7YuSg3njopw+MJ+JI414GLWpYWMagLe1/eZfTvCxTKcd9aiCJBwyul9
4otmODzYX+PbQeBO8NiAj7QNXzvrDRqShcjtO6huLLtPX/E9Fc8/JSiqHorF
1yL0PHjWfmgniVHz3CaP6/8iKyO5KUMsQWBhfNpSDgfPyorLzWaEWK3e3B7/
swtnj6SEaqb1Qr5K+OJoAhu5ZSNetVvFoMp19Ux7FuPri3La3rUkaB9D9Jze
vUJcqIbOywsSaNs3qF3xboEWv1o7r0IEenY86/f9XIiylfwrTAQI5+z2c6Ww
Ydop+cM6RozZCqa+7+JKkXs+JEqTL4Giza6gOtd3MI2xNIz8IIaLz74Y2lMu
7g6GR2kMyfSz2nzv0+s6kKxK5x0SAtGdqyx77fjIuJSpU7ShD42ux384feZA
LjBNbXKWCIpzxtL17F9i2xyaXbYSiRzpyk0BnzvAPxvOfQsB4lwXq+9OSIOH
qstrfS6JxeKpB6mO3XBQWqnc39aH1m8M7mhxJdxaW3r1U2U8r457MJLExsLM
iOKhTBG+t/kE23aXoOeD8aeXiiTq7kwZ/lbOhut48KcT9iIkG3m3/3LnwsXh
l0aEvwB3V33x5mmW4sLMuRXmMh5M3qe9kfqxoPxPGSVhthjN5jaLqfdboT+3
6/h52f7yptq1ljMZIE++9hOySGSuPDPc8Gcn9N2cXf27BChSmhFFm9yHVdPd
9bcbSVB3tPEob9tQqWFOWx0lxA93kj7/LR+LVkilagkCeHVnXLMN+YBAg5E4
poIYRkGO3tTKehhPZ2YOHyJgSDVdGzHEQ0FwtH69jGfFuSerb7m3YoliV+jG
z2LsvHDJQ8X6PeySji3K9ydABFk3Pfu3EYuu9P0sqidwNWye8UzBK0QEBi9L
kfmrXy41bDywGcKcHQUFNDFI941ki85LHHhrzdc/IQEl6KycITUKjH21k1lq
A1BX3pQ5a5KDJPH6Z1tOC8HcsE1bL78UOTYptinGJLLbb9KL8nm41qRhY7u0
Hztrlx70F7bAeXJEH3EiuNX5ri8dLEJsUI3Pf2xl+TLmHBGr9BA+j3om7MpJ
bNgTrly49hUyEps/un2QYJQwX+dFSUD0gSnW/SnZfM4ahbf0HFy2GqxUzSfx
61HbuTVcFro2K3ICj8ryyGR+ehW3EdbPf2y/IMtDkadGRORFBtRigsv3VhAw
fjDZr0xvwyxukjRGX4wFnIjvZSltCDUbL+2+L8LMRKTecGQdXtGaXMILCKiH
hS2dlrJRQzhfPhMlgj8tciyP2o73Npc824KF4EfFLvdw4OC/XoWft0WLYFY9
Oet5eSvOpLWXPKeLkKpyMJdFZULTXlPBK5DA13k3PDZ3FoPuZbhFeJhE1Zw3
BnbuLMQUxrdwBLL/sWXh366qHXC82lKY4SHA/wCRdtkw
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 18->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4ldsbVZluyZUkGSqZK1QyVpYrCUlIKYRryJTSQCmdekxFlK7Mw1Xp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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHc8Ve8f154okTSMorSEkKLeoiKjVKIkyWhSSkQUKiPJiKaZvZIVkmTL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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs41GkbxycdXqdEVNO4chVaSbTtbinFt9ahIjWmsi2KdGKipFKSQydR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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlWk4lAsbx5GklETJkaRTUVlCKkX+2tQ5FZKyFGfOUGlRWplUyP5eJem8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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 19->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs41FkYJtYuSVspElsqkktLZqmhXnRRCFmGFSLWpai2laRoXFJKuVXk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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k8lF8bpiKJSFGprIWUXWhzIakkSRSSpEhCEkLLn7KVErIVCqlESWTN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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs01AkUx0etLUVhR4U8o7aXlSQk3yVLRVFZa6M88mhLmh5bGk5RqKNI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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVWs81IkCNdzdTKnU9Wxtra1UyyqiuD2OR2lSSsmrtUwTtW0eoaRYrbR5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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 20->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4lFkcnohpVchlyVqXkK67XeS21cuIokiKlEsXt5J0sVQWq0WppRFi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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VesbPZcyRaaSNElIFJJM0XKLklSGSJo0ioarJGlARSRJqQw/RS4l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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk81Isaxkd1HOupI+Qi2XLVHZS0SfeZjjpNqBCVEqcGZyTlRIs2W2ls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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHlczAkAxYckjbZCkhzFYh2pJrJkttelxY5t0EHFRsd22JSSSCFUdCcU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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 21->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns8lHkbxof1IkmErTdWJcnKqYOy1bqQJKeQDHLepXbjZXUSUkTJKcnO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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2lcjH8bxUOIUlHSJlEpochWiVMk2dIikkSkTbTYkqQISdqRNoUW7ZYW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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHk41AsXHi2i+kqiKKMUke2iTaVeTXQtbbppketpoSy5plvZbkS2kr5S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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVWk4lAsbdilLllK0KU4h4ujISUJyp+Wrr8ZBdEInRJYkUjK2LCmKSNbo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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 22->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8VukbxjFlKWsSfsnSQlnqtWbCXLKFUpYWNShKtNp6y5qlKEUR2WXJ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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk4Ve8XxVEJTVJ9UyElpZIhGVJZmpAoJIkGSYUoUxlSmYcoQyokCSEi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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwV1Xs41GkbB/AhIURvZy3JvpGERDmU9tsR5TCaVLJzUXNpt1TS4bIOk2gj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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXlYzAsbTYmULorU0Nee0I2iq2s7qVzpo/VpJEsq+fosNWVc0yIRLS7S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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 23->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns8lOkbxtGBdlPUrFOinH8TknPT4UJySmyDGpklZB2zEWWXhlbRTwjN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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k8VO3fHuWRooXKI4WkrGlBpLwuqZSlLEVaSEkqQiUqlCWlooiQSlki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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlGs81IkaxxEOEZ1OSpIoYiXNBzlWWz9SGUJtSihMKqZDllOn6GInWTql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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk8lIsaVigUkdKVdCppVRFKksflStxxQ/bklGMqkuSoS5SRrUN17MlM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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 24->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk41WkUvjXMIBkqaoSxJaEkaeyvLHVD1iGlpE0SSpMMNVlStoSyX1lK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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4ldv7xkVKCKUkp8GcJBxTkdxSSlJIycmcBlQi0uibpJJEg6SOIkWi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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs8lNkfx6eSIpfChqlfEb9Ykhpd9Io+hZBSattVupimoqwY7ZSRaSRd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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs4lAkbxidaoRwuKkXbIjSJdSolh1uopSIklbDO2o4K1UYqSlQrKiop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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 25->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk81F0bxqdo9D4klUpZMiJRliRSuCqS8EjSJtFDkqUiSyLpfVIhya6U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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4ld8XxQmpqMgYKslcRElIllLRQKJSkWQokUJI9c1UNKCMJRUSQpnH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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs81IkWRxETbeklIaKokAwbim8ktCRbrRabNB5RqNy4KYuLVN5JVOSR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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGs81IkexqdJ6pT7raV26Ry3aJ2Koqwe5FItJWaVkimhNjZKzZaUS1ST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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 26->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk4lOsfxqVC4RxLtEgpQpSk0xDqJku2CklaREpIi7RJ1jZaqI5CJR1C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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4le8blyiSooikzBCFjIroo9KifImiSCIVUdoqpSIyKquSlEghMkr2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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVWlczAsXHtl620mWcG+JZLtGLgp50qVQlBZNcSMlFS0UskZ7dFs0UdEe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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk4lQkDxW+mUlFIsjyUbUIpFXpMfB0hjFQmlSUZTMkyIZlISWi5RSpE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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 27->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs8lGkfxtF20EqzDq0tSzmWwzBCltmuEm0hJU1JYURWUlTaV15kkdYu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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4le8fVomMomwhFVFGVonKLSuVVUmUZDSsSqXia1RkREPLaFFRVhlZ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk41ekbxqmTpe0XhUrpKEs7bWi9LUWUdYQiWQ4ijTIlSYsoFYmyhCwp
jhaTfSKOg0g5ceg4nCylJnwXFYYxaJrv74/3eq/3n+d67/u574+6R4Cd1zQp
Kalg5vz/5k+E752XdgLb+M/s5q0jIDqQkSQb1gTCv99PLCRh7ucb6niuCz4e
JZEXY2i4WHm/ODirGUZmfhly+yhIiwTf160Robc5keeZSWH/3NfExNzXWJTT
eZGlQiF/Se3N0A9VmOjnHoi0JcHbXR145x4fEWfStkyak1CURKuUSdoRZLYh
oWYNjYHCb9JDm8SIV508V82hMfxJZVRpQw1yuGRW3i0SUq1Fg8ebkpAodeV8
1hEC5Uo+68d+6cQWAx0RYToI4TeNWdt1xVimam4lDKXBCjm9OFLYgtZL+hGF
i2hsUtIZWyXPw3e1HYHiX0mw6xUV/1GtRCntN8bbQqJY3Vzu1Egj2OpaAQFO
FLIeFB/bFtOBXYcTDF/spCEtVbLAbnkP4i86k8pRNPZKuHY+5e8Q8tmCNdlL
4aYF20u0shUrTliYlUrTmJd27Jb/z3IEcf+967CDROjNB9buCi1oGU3fr+VC
4d6Q3vQ9wmzMKN0itSmSwMCCI7aq/7ZD0W40tsqUxrWH/+ivmpcPxfK3QVI8
Anu90+d4Dj9HiAb3bfoEgdzURsl4VyUabnk94ViToJ/Ijk/XrcOe01FxORdI
9PbKGCpq1kOv4OVuv3ckVmZTq1lab8A6Okpp76Jg2Dhl1dcsQLbYVcxdQkE3
bI1B6V0x2FGfJuWm0yC8Dni5hYrR1xR3cp4jjesD3ZazErsR3M27aPOCxq4S
RVZu7nNcti62DpMhceLLpN+nahHo/VtnB5nT0D2X9iVppggaPcc12n1pbDSN
cvKkBJjkdGhe+0aCk2vrWSZdi+s5b/InfEks51v2pOu3QE+n9GF+N4XAw4c4
Gc0SPPO8GssV0zhq7sD5uPkxOFfnCOIyCPB/JvmmhojA9z2/jM38N3ZKqUNz
XACe29oLCfcpuDlrLy0PSoaGbKY9x4fAzgVtwZ7KHYg+JTqW95ECbWyyL8a5
FZdHIhf8Pp+G2hzx2K1BEZKGd81JOk8jf2Cq6M7bdkTYR8tIF9PMvMHUnvMS
NC4cKbVcMohM95YSP+8ccObPSt+TSmD38ih5q8I/YPjn7WrHIQLx1t1V2lU1
SPGJN1wUQ4IfxGL/9I+Fl3gBb5UlAXGw8LCnWTXiR0uif/uNxKUHd0I6U8oQ
P7BHsHEpCVP9b882/NWGjtjOH4l5NFa3fPjf1FYx7j/grb4fQMP98lQN71Qd
Oioq8ciZRD6l5n7nVT3em++9cp3Zp0pfqpSBsAFO4a8+HOpm8qcZn8d/0oZG
7s4Uw2IKwdvNUttHRDAeeZjYnUdhh5eCZdjjWmw94/ji7F0SM/VO69rKCWFU
sXN6Hpvxa63q1u5XT+H9ozbi+WMC48OqqY7pbxB+6eRieT8KXydlBRbT2uCf
pTWQa09jnCKWsCq64KR+aBfffxA3op4OP1N+j9hjxeN9/kzfB03mq1k1IrR5
VVilKYXcq+BpKVTjmjJxpYfp5/c414XvYoWwS8iyexZOob7iUqLm0gpYfm6p
PTuLxF8rmkJcD0sQda0uXnGMxsc3QxGLMk6icZmDw22GZ2wzpdz4vNsoihq8
8MWK6Y9aCytB9R20Yy+HlE2jcaBfkJxi0AlHXhM7Wo9GaFzfnJV1bdAoOLUs
IpF5B5uk1lcJMO1EhoWnNoWIMPkPkTsrcYOoqeAfYfxOvMHeJynC+tsKHhVf
CAQ/Vzf+20aIX39km525TMHfVKYq4qMIRfqaVmUxFI4f5BZsVelCj0MuV9aG
Rlerht6Xu/Vw91xbqDxEYmHX+7QcsxoIe5255udI+L+MuTHxlQ/j2pRHKzgk
NDPcusIHYvGt/I8dzfuYvB3kvNh2sB3yfqzGdWE05q5WCe6tq0GtjVWCzFXG
v4A/0zZPtqB/YL19mAeFgdALIwYPX6Ewt/tG5AwKLDsT05GF72GBkbbXjN7t
cbOlfW6145BezusnJIWAxn6bHZPvoKegY9LcSkGPP/uh8ZZYbMzyHsiyIKCx
zuzOoadiXNTiu5nVMDzU/1yvqPQISgk5Y0aFTD5GPVTfmzQjc0o9t/0chUzp
IveCr0IsDZ8Y65xB47mvWt/f0yXw5tCLWzfR0Mxrnn39pRBLVsgVb8yiMLO9
obmkSYKbQ45vk1/T6FOQrZhf2oCCQBe15cMknpZLGhTXNCBwik7hhTN6C9zd
dMeq8IN7vsiV4R8rNHMbnVAO4ezrbFtdEspHPxdnujZAy0Uuu0nC8ColWe7e
zDoIoCMz1EPitkObdb+zCIcLhEM3JRQKx/Tm9me0YPTKseVGIgrlH4l8cwch
nIwCjZKjGV5KzsrZlwnA2R+ts9qYgsfXzRPTDGpxQNvdhc34f89iW15tfDFO
u0xeDX/J8MBpbf0ZUoAx3QdpqXIU/gPdytOZ
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk41IsaxydH0bFkqxlFiVFEZDt1yfOVFg7dCmVXsnSn6BDti5ZjipSl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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 28->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns8lGkbHm0nbUIOHWkVtqSkKEkuSUg5DW22fCoh8cmp+iQm7Na2EkI6
KA0hGwkRSWOMQwzDYBomk0NHz4Zy2hC1z/fH+3t/zx/vc9/XdV/Xdb8a7v5M
zxkMBiOZPv9/m8a9/HlfLB9eSnPfxFoSBFixV2jachHpkvag1oQgFrs2uuu1
ommHacL+UILl09UhWqclsA5/tGpxGIHR0FDMoP0L1JwQRkpSCJjmFvqb5LpQ
fnpuk1kPwczMxitCeR7UjyX1TxsSLNZbpDrzqgCvv34vD7QlsFhyX3cYlRhf
KTHsNqXfn4+5ZniuDd4a7KQfThEsjfTVHW0uhqumooGGHsHdtheeftoteDFP
earHgeDkTteZJuovYZLc36/FJ+jS7/ZmicRQhscj3i2CoYUnkswzuejMaTTR
NSbIY/UEaDvXwc1NVcSn389uyM9R21mCyV/ljTJ0CaT/bXs4Ui3GDS/ZboU0
gvjLyaYlZVL4ulcVPhURFNTclVh9b8MvCalDVUcJLrp4C1Icn8MmzaxZexfB
4fUd1zVyalA2dmfAfTcBI2L40zrbJIxfkNNav4qgw6X1SbYMD7NLhvctNSfQ
SSjI2+LZhj6e3R55LwKfjR8czF4I8Tj89J+J/yFQgOe5BZuEmN9+MCzcl8Ar
NzTH2FeCqnfnFUPiKZ/job5yYQ9x85b2JEOHwDL1bKD2hBQzstz8PpUTOOz9
4rMjvB5nGMEDbFqva8MrzoJFAgzeeQMHO4KfDFdwFYteYmZW4530RgJu3Neh
TWfPI+ORn9bhlfTcH/lbekcAqrZM+KrRs/FQ5rPaXi4CzIhdpgHBQnlVweQ5
Caai8zKqTxN4/1mOvLPlmHRZEL1Un4CXmTiisE8Ea0X3J8upXsaNDz7kB9Yg
akXj51LKz2Ru8r1bwc+RMLc1cRM9e2SHKl/d3gzruobsN/tp/0GWqRsHy8E4
e/x2Cb2vvKwki/VAisTIK8KRToLHS5ysfdX5iJ4eCzCkemIKJvvG9MRout/f
U0j16FJT2pdtWo+OoLp0OYpfeaBf9o5MB9Yw2dyGIgJhabVUcagc7Q+uG5Vu
pXqKepIZ8KkNmwPclKKPEcQs2HalMrgSWdt6V+6lfpCP3lXwObATtSNhv/Zd
pfhvyH3eWPwUeUpPVD9QPu4frdz+3bQF158UX8vdR1BX/e7goKwYPRfKtlYH
0f7DzdV9A0UwSTK8WBBHsN1gQ+w3/SpYzJoT2kf94fpYdxVzjwDKasHiPHuC
vtakXpM3bKw4+0HUqUnrNbNb1npw8EucTmE/5YM1kN9HuO3w5r6XyKQTBIW8
3lXp0AAOn1SH0vouJUHs3AevkCuwlQl+QRCRrWy/9cxzXJu/v/fyTgK1c6uO
+n5sgWaP86Z0Op+Qi/U2mxP4uNjuqS12ofXen/w95lIZ7S8wy4/2F/Hoyrdl
IYUIGpmdIreOIFTzoRI7sxOCAo+ezNt03qMsGfsFEnQe/YeRkkz9EOb1Saic
Ag+xpNme6p89o5m1SHwL/xv2O3iR4lmuandodygfaVPbahzp/A3S9myrredi
1Kb/r+CNBNaPhOuvFYnBFmiv96f35Z4WCUK12sGeNm9SyiZ421ealGzOx846
hlrUAeqnutH8ZTw+MlyXDxe7Epgs5MfNft4C5iWDuykhVL8tE/4THWxo7ri5
z5PWH59759APuYmwNO2utqH9lRorLLE4VoWAfV8ZO6mfjUtPS2/89hLL3HKV
79VQfZenDp6IbUF1TrOORzjBLV5NzGhdC96ni0Q+fgRTHTNPlQ7xYDrBWmxh
RFAWpday++dOyN3+YrWjmkD3+E8/XmcLkapwh+94hOaD5asYszEnvH5Y+4ZB
/VVV6njvuEoH/Kf6+q7SedR0RqpsbexE4rGzoWk0zy6Yzlviy3gG3se/FRXX
U/97mCgknKjHBo9v437WFL9TeM4RzivI3C9bvYH6I7vNoVLWOgeXOPF5XG2a
X1djFu1/1I55hLVGn+pX77vn5dVd7eiK93J+F0nQI6s1X14/Ba6OgbVzKD+r
b9a3+unWICQ5aJeBFc2LmIJCpfOVWLhDwllC/TBVEpbyTrsV0rbO6AOUX3/P
AP8jFSKIHx/V90kkePpguCIzQ4oBoaWleQWBWa/8oFPyRVwq3Nt7iOJNEC8d
Mj8ggrKxmoof9ds8g6FaGauX6Dcqn+fMofsleLnqn5ub8HlRc0WhO91POt1b
1jIEuPv5Dw0vRwLZ/o/cvEIptE0tFmvEUr06sqZMxurxtEc99hrlgzspY1Tx
oghMFbHHBcqX81SEj+pkGxZGaxtxLhOY3/b21/rMx995w8wC6rfShsqYIptn
iP/0OrJiM9Wv7cxYDNyE9/ys6W1UH7WpmU1h9yvhMDLLNIz6/XG04rpTtSK4
yf2WEvo71TM7u2F0UIyCkTmSMTq/utQgdXOdBljULvvqt5fgH1Edy81eiMi4
pyIurRevnC/dncCB2ftt+IPqfZz3vL03vhU+PgePP6b5v/duw+XK6kZoZhTP
0aL8BFi6ul/ubsCwfcpNeYqf0zh2JWpJFtwj17mf1KLzKQo1ajTi4MsX2dHj
1K/SiNXZY4ntsDJ7/72Y5uHx8xPVnT9Kwd8QLXfvL4LizvknZ5yRYm1T9O0O
6l/ur9uji64J4Z0spzfDiWCB7Vv18f4qpK2ZONVE/w86Vk7e7JZy4LT4Xcs9
uk8jBBWNAoMaLBz+cOQD1UNMT7rVfPV6OHQ9S3nCpPpsOINs6qeTVjEeYpq/
rhayEpXAQjia22mNr6X3lbKOYDcH5dPID6f4f3feG/fVqB1vbZaPrmMTuL8K
N11jUYWIjrXkBs2rjV1mOt0WQmx2FUfx6T7c81HPZsy+ErdHBpoDqN++ZXk4
8VjNmNHt26JC+RHaf7qqMqsVrWuHld5SfU+qr8mZu5gHuyjuOi4IduzJiND9
/hKts+2aDt8gyLc91Vo1KYH4WZ6Gcj7B150Rzn3MBrz3PLCJaUHzyPLbISaL
h/GMyXf1WyhfpPtc8ak0nDB8oylL+Wc2Ts/18K3FgzIFnUs0P/4Fc+TH0Q==

                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Ve33xqWJikoqUVIZGiRKRHSr8EaKzEmoFGXIlKTeKCrJ+zVlyBQy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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81PkaxxEHRVFRVDSISsW6pCSfblsjtYkIaUNRLqvYklxqTunQ7skI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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs81IkCxYcil4TKM7bc3sU1pjxSHLrD0tY2vVNambCbkqKQ2l2PtqyQ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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 29->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4lOkblq100YZCUrshPyIiJBVu2iHrrIPapHLqiJqy5RI1LElIaKJs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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VW0bxRElQ0TKG0lIkkQq1StLigxp0qBSyZSENHnRpJJEiSIyZcqY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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81IkbFvJrVwf9dttVm3SQol1FbQoPKUelRJION2VDioRyVCuR1eQI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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk4lAsbxsd20mQ/keX0JS2kJKVIcqskpEjZsiQqFKVIyhLlcohWkWQy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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 30->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk0lWkcRqncUk0pXLIkWySiIcs8inSto9IoS0UmbRhNRa6a0iCytEgY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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VP8Xxok2SRSVomSJb1qIKC2PJC2KLJGSlERa0IIWRYtEKimECpEl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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs41WkXNW5JhSnky1EuUSgxpENlUYqvlEtNeYTKZDRSTY9GJk5F6IIi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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk3s0lAkDxgdt81EiiziL1RYhK+NSSvUUm+wONWxXlWXQZmOUbpI6Uy4p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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 31->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwdlXk8lekbxhkxSUhJ2qbGlihKthFdUZEUR0SFMLI0HSqpiUwSEamoNEK2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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4le8fltEQmZUZEUqlTSrdKSUNCZWWSgNJXyt7hUooQlZSZFVEw0iy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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwdlGs41HkfxtFGiSRE5dkcSoe1kV0ti+em7UAnil2UqKnssNIkuykRhUiJ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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs41Akbhicmm+2wdkWLfC5lYwtpk5DtEfow21UkEiEVM0UOySGbsJ9E
q9iKQYMpJYUah6gcIpNmCDPGYchhxpx+ilLphPjsH+/1/nlf1/O8761/OHRv
gBKJRIpZmH/3p1BifaWvAEHfXl2rfSzBndKlVN9jHcj25dKoB2Ro7GVlLB25
jkO5XVuLaghkzn0fvyGwFy8+2p/KtxpFaY9PbMplHpZfN5qeGpThsHXPurbE
Rxi+Lna3ea0AiZW6qFPnNgpcV+dX5xFoyBM2JZZ1Iew2+Yo2X4aEGUZhkcFj
eNBzmEs0COg17f/TOLwHFuwJL3qeFAmJDl8vBDMw0jHOe9RJgGl7bALZbXD9
5qo5u0kG7Ym+o5r3mqGyxZB01lABR1fj/e9SBtAud10xoi6GuZW3d0k0G5tr
WpsvhcghnNH9w6SDC6uBYcrOdhlo9cJM/1gOQu7tOLZvQobSF8ORL57VQT81
dWVJvwIdBUad1td50NqwyHw6UYp+GtUntrwXV+tFBc8kYiQMkRiERiTW6Llt
n1AfwyFaW6LufTaWFjIT3A/IYbq48pry6x44LrasaXoqQdBN6htetgB/zZzN
lAZLUWqzc0d8fj/a2Nzyb3vEqO0697+IT4NYH5+8rcFMhGWn3z6gzrIRMvRR
zJ6R4+ib4KSJ8T4Mm57xL1EaReRD18n6ll70xBiljseMgki2s3hbwcTYOh8r
ZzYBhpu7S7bSS/C6uelkLwlYmUt05nZVwE7FnoNNC3n2JxuJTz2BhdeZL5fj
FRC5ea0oowwhyNn22uYPIowPZuQF2rUg4Zn1KscPMpCmS0Zi5/uQf0fx/paH
GMV+8290eMNQ25lSM106CpEFI52oasB4rTI3OEWBao+llBHyC7SL3OJNahfu
iZZfn7KmBRPertVuW+UwSN6fy1F/ioOf16ubxSlgaVmUbjQmADtGrYu/TAKV
OEvMt/YhxT9M++89UtiHNF5sl/EQw7c1HN0tRYD/gNavJD7WVa2JLJiSIbjO
NOb+OiGi9bOcjhhLoXnpVa22fjeO/x55KZIYhRPV6bMzeNgdLXsk6pThy8nA
kgtO9fDXifyv0j0FjBM3xZidGsClpi7mRLAERcqzU9Lkl7DlpB9iU0Qg/ROx
M8euH1nZLWZlkyKw+Ltn4lyeo9fJXtXNRA5Lz+Wfb6TW4JxSxR5lFQJdHZyV
4ZojIM/QMlSzhuDSuL+qIaAFV6lNjatG5Dh0cbOmaDUXAQ6/WTxbK0dxpW6o
eg0X83frmhkJciSEpbucJXfB9/B4w/lJKTR+ky9iVLchMK57n9YCzzfz+aI0
r0Esoek8+MFeBLUclR+njg7CIuJA5lZChI4b3Y7hgy/hpsianeJI4MAkN6sa
8kFjuhinBslwlEr/yFLmgnvFnyYQyKDj8zUgsLwR7tuPSDTMFCje2BHt6daA
uZM2dd1FCpwsctQdM+6Ha6CdJmWbGGaM+V33XbrgaF2UM+kugy1exhros8GK
677tp6NA2PNRa+piHg7O8lbXNEhBYlZeo+tTcDVdtfOJ3hjUPBka9XvZMNu2
tFtLLMcXdzXnHyNa4HeLnOS3XQ41ju7DzNeDsE2heykND6PK3+DKFlUhVKKY
0YNWYjCT2zKDIqpx8Sr3Tp0+gV097PFV7S0L3NoLVAc5tM1z0/aeE8A6kHNk
5UkJ/kKrfsgnHmzdfjH1WyzDw1/Hpg9T2vHqmItJ+AkZVD9RtTwN+mBOpX/I
ix2FcZZHTdZQM0Lj6O/318rhVHKIFW0vgNXbXZNRlRLc1Kzlep3j4YxG254H
/1nwFe/ReTapAkne1T5Wuwk4fk0TL1tbCZW89VZJuwgkNbEKc6/xYGG9Y08B
W4qosyPpkXefQqfcfH7fu4W+nxdOiPLoIE7fJae8JJCWWFh6vPgFaPlqV58n
y+GYs0ZQk9uN0p8SKcLTEgiZYYaMjSyMzUk7/1z4Z6MMwZuTpqXwrFImdEMJ
WHp/l5y7ZQA/vRf61j2VovFO2Ov67mp4vCWFH9hJ4HFsxass5UF08o/PGDqL
MV7pkl01xQHFTEWiHSVHWKI/q+zcDfRf8QzzfkhAtOJzkB6vFg6FeoUbJhWw
Fdwjb3DnY1vuvRWrTKT4I8a06MCkEKzvxCfOX5ZCyNEOnW0WIoUiK2O7SlH3
S3/8pkv9oHhNnDlYKIL5+uUnilWbQU+1VvX+R47WnOJxgy8CcPpP2CTWj2Ku
y+SdgV0fkpcncbZ2ieF30CRr7QAfxzWi/jZslYCXNsS2J7GwsipQz2YjAZsh
siKtSgBHjzGPIS0Jtlcc8S2y78PpjZUq5pkSxOx7U+6iyYXTage3gpsy0J1G
zcpDeyEPXeJANljw5xI/ow8+FTglfJ9a9gOB07esIu62DSPuiXpLyb4hsKbT
dtMu8BH0hBtG+SpBwGFOUFlIA87s4O/9QFdAyrjeGv6ODccWSolNiRxRv9ff
Up7rhIeRib3LgwX/cVcoNJ9l4OfPeJr3lsD/AQLJ0qY=
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 32->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8VWkDx+2ZdildRhShZElqEvKLSobiJlkiUiqpKGV5LUXhFSluTV1Z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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHk4VG0bR6VdFIWEIkulJB+S/FRIKmlRqDStJCWFQkmKtJAtSSVJtmzZ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs8lOkbxu1WyCmxJKkkpZCmktocLr9fJctIyJRjckpJ6FMW22EcKiEJ
WdFBlORMoxhCcsyQ4yCqyQ71vu+I5rPJ5tC++8fzuf94/rjv+7mu6/us8Qy0
9/lZQkIilD7/1WIT30cTgXxUnIqvH/xKwfyr1oT14n64jZoZ/5EkwuTx+P3S
DgNIYR/zkMylIBHWzk4+cRNTu94uH3EhsNM2SsMw8yHEv60b0UgjcNr/6NJY
Dh+nZn654kVQ0L34ieXhOYD5rS/Phe8Qgb2fpTA7+CcqgusFFa4EJBRVbizz
uIM5g0y7v44T0NzZbH92YzvU5ZwfLQ6lEG/3rUpo04EaqVtPD5ylkDWx/YBp
ahdsv6/dZztGwbXisKGtRxfqa3esj3tE4fDyPEZfUg7KDQ1X2iQSMFFYUGO0
rRYnbjz1TTYmoS1t2nlkohcy4h16OQEiSGTaf3wSa47Pvs7Vh9YSqLgW7OZx
9iUiHTd7j5wnIaF+T027goOmfWrqryYJBFXLKwZf6MYZdeb4EzsKQfNuBzOU
O2BgI/axsqDAlkzclf05Cp6jHwMfmxAQP1/VMNTWiwPcvf98qqCQxvJO9R3u
A6ME7rVCCiPTP2Rn1vOxwMRK/h8xhbuh+bJRgd0oSi+cP9hKwS/uqtQbJh/6
l2VmNOYoCL6TW+d14iG0dCTD9hJQ2DbGcknkg62sVN7tK0KJWdP9xHel2Gjm
p8ceJqAk3715ZEsPIqwyogu/UBguVXm1VG0YrtyyO+2scchI+fX1JDxDjS9z
XPiDQFnjJc6QUS9Esnp9s0oiVGYfGqtV6MGYgzX/cjq9n4bFcsbUAORT/JQ3
ckWoM/COebM8E4EPEioCgwg0DHOq9qsOIPaMK3t7MX0vzH4lM3kdBY+seUlW
BEKFbX+aMVowttPAobqdRFkdKll6jfD28M2tfE7igd0SY3ZYEUrC1od9ekhg
X6Zsu6ncEJQORaap03qFrnr/wV+bi9M+hqwDtJ5+VXcUjbL4aDnAcynfK8Lz
QwRzHWsAC+O1zDQeiiCuD5lOzGjFq/fBhyNWUVCcULA6uSIbp3RPVS+II8BR
v2+gat2BDxcuStizaH2GlFnpKR3Iywk5WLWGQs5NmSWLfTvhv+m6bEgeBeHz
wLQJ515YNihzFWg/K64t775+Nw4N9eKzAlqPzqaz0a33GnCXI7Unj95voSti
9zs0IWDJfYdlHBJ7NC/rZfD4qGZNNm/+SEE/3Ph+ymQfOOv8I4dW0n50WsJz
Z4bgzKdYnSQGAb9sl6jkWw3waF9a9hPtRxVbz02Cha/gLGfxUGBG4QyDbSOp
1Aob4tyWo84UQkkZnnlNDaqryo+puJAQqhbWNus0Yf1uqVL3HhIZ3n85vbzd
j9Xye0Z9dtH9bKX+kLUPQ3xB0vUHW+j83ZbLFXrxUJS7TOBnQOFG8N2ZkPQu
mHFGjX8UUqgPJj+E+vMg/Sy6vHiQRF5p64S+fB9iBOciVQUUNHcrnlr48CWc
f8paHXCHBDvEyl8qPROa0V/nwkMJhKceztAu6oFPsdP78BYKBo3ZMousXqA8
rvKSeQAJYyObtxevvUErnz+X7SMCU4d0iBLV4SrIsjVHSWi0Fa4ct+9BS4jm
sptxFH5+96J5nHiLWXLyxVydCPKvberGdOj8DFxJtqujkCosWlRg1ADrXfnL
OFEk3L4cOTY93gWPWC/dp9MUNiwhE25WtqHXTc5yXIqeX/IoMZKSjNHG2Rup
tgS0rUYu/j+AB4Mex3obNQrTpp9T23fXYcot/YxjMAnGouJ4Bp+Ly6fVNT1X
kNhalLt+xrQTtwtcPEdeU1hROqnz97cuFCRVW3bYUHAWjK4uIVqw+z0vP41+
P7+OkCyufwf2c2NmNgfR/FrlHZEgaMTU/9omI8Qkcj9oSpau7McO7avHTd+K
IG1eksDX7UfykUo99yci3D56NW2ooR/z+Ua9h0JFYJAxa07nPEfjmtbI37aQ
sEzflpFW0A4lrV/ErecpfHJ6zP/q1YhLIXYr9maRKJG7WXi1rR/qgh1KzBQR
xiYFcmquXajJ3DySeI3m27tbRZecyiBdyb+2bpTmzeS9xPecTij+Otjs7EFh
qZZx/rxXFTZtOKliQfd7x5BJP8h8gccD5i69bBJj4f5Jtxz74WRxvFpFWgSN
XA0ZH7dODE7kZxTT/Dss+bvXLaMybEjZZ8R8TSDGcKdYcPo1Lsj8rdzqTuHL
sZYtSsM9iG3SXeXRS2FGoVh8UZeDg8d1IlTpebgWTi/ZUt2QSCguOE/zP8tr
1ne1Vh9SMiL0vndTSLz9cWplRynUBrmcpmb6v3nb1sp5xIOEdutTE30K2idV
qxuZtchK6M75yqTz+e7Nj/St/dhzYiooaIqCVjMz8aR1A57qaiSYdJMw6kh6
1pL2BnOb9KMlh0Sw/hYZE8CpQ9rMeUtHfRLTLMlzV7p4mC1bzs2LobD9xO8e
ulcGMe0Q7b42WQTzdF3hpaxOfPfrjmS8oPAvLrrKKg==
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk41IsexhlOOVqMrkKrSihpOVGK02spWyXJETq3qKgkS1JCQuoqky1E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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 33->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk4lfkbxlFkL1qotAhFUeiELN2mVH7TQqJSiRFnbI02REj2UooQQv1s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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk4VP0bxi1FWSu8lSxpsYQiKlvdklSSVNrtpOXVhpAipRTJLiR+kUol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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41Gkbxx16VU5RElaSSDqZ2laEvnTUJFmNdWh1QE6pJN43ZaU2kXZH
OUdbIlHadmJyCMnIoZoZh3EYxE4kfodKasTy6v29fzzXfT3Xc9/X9b3u7/P5
LvU94XZESUFB4TRz/l93KdjWj7CFWL7a62i6LwXDqwdXBgufwSjPPaYsiISM
dWPLtVEJvK9bKD0bp5Db5X3P41otuNH0mwPLSdzf4ig5PtWCweSpZRFnKRy/
EHnDU7MFuRyNNNV1FIIM+2fvGxfjtNLIvV0rKbAGdjd5CSWoyfAy4WjSYHn0
VyzXb8WDOvbjzV0UnGd+sNySK4Lqwbf/qKlRUNjmbvlNdAIBXJHjldUEtOKO
r9mtXAjpB+OdrNsEwvosxIcTH8HGnz9o1EiA7z90d31lN9jK3+9Y0U7DuMaH
XsN6hUlxjuI8FwpXL1Qbzs/ggWNt2jcqJtDtkSbv3ViH6d7cEvVgEm/Lh0S2
h1tAxM+aL/uDQvxWnvX27DZYhWvZi3gUrP9+2sP2EKBt19YA4zQSdpb7wtbK
K6GzZncox4KZ97MbNn/6FKV7jDzrnEhs9jjVXM1rR4geSxAeSGO6seC7AmUJ
VBwKph6KKEhyeI5DIX1QWmVbFHHiPe4HLwBP9xVCagoGBp+QuCFPFftpC+Bq
fTCYtYEE61vvNHbWQaqaPeP5gASxjlPqPlmPlbOLd6hkknDe9mGwqfcFNF8e
iwxh3u0kN1vDvYTYJD6TtEmZwk9vr6xYZ9uKK+azfHzsKThcUSk0d23A7ZZM
2wwxCe2YxXM413pwS9fJT8OTxurMp6vOlT0BP8dgwkqdRF9+VujL+lpUZpdK
8qNIGJnIKLfIFggPbCtha1Io/Jqe6c7rwduLlc/tTd5DR99FYPu1HyYfx2rO
/vIe6mGTdx+bCfGr9cdk83gKwbTMZzWnGwvP/D74oocGT3G2ZFBFBE+5kXdn
EIXwxZOu5fIyNKhqmXycJnBGcaGkNb4NMcGBV+c1Mn6e3l8eNHEHqumnt8Zd
IDBWmJxsJ29HcrFXwAEXGkf2BcbSyWLMLopyvMH4F1RxvvTu/E6oe7q7rkii
MUfq1HjLnA+Fz3QM+x2BwaqhicppKS52/jbOSqFhYn+v83VND/aKXpYW7WD6
S53MfY3akQA9P1VTGk2L1n5xi5fAOnjsTyc1Gp3Lij4nhkoxmi2tJaJoxCZl
mpZ15eOTs4bfIKMvxkJeUWrcgYjbD/26nlIwOBtVGe0vRZyagvQyo8dAhcvJ
4krA193z0weGt6D/hvw9HliHFJY/+8VDErHjNoPFYx1ok3sWVX+jsLJ3RnF+
YjV6XQSfdOaTeBTu1JYhkCJw/1Rn3Dtmfqfe9p5zrzBwbGbY5wcK54d1uy2s
uyF7kzpwcjvDX9Pb8hUpOfBlN7o5nSIwOnzIqJzfAYHm6aPqoFE/aedT9aYV
3LFQja5oCnP4+mLruBqE5Rx2P3aM0XOVNCwfP4d3PezJHVYEMr+UbYtGHG46
DMzNsyVw8mDC2W232/BKVZ45nEvh8b8sS5tutoGnonjJP5HC/bKKu/JPEhwY
WvmLcAMNYd+64QTddtTOnKiQsGhseNlgZnZECLH0wwfnGRIDl8BevKwdxaH2
edrrabxU6ssQN/dDzyFh6amz75F7yGvZ7UtNMDbYvjW+nMS737nnl0R24Xzs
tYlVp2hw6ouzRp93wGU0/urYGIWWgI2Kgd48pMpkJ72eE4jN/aR3zuM3mEZp
x/C3E1AYzfTJSvAF185Z9smcQBX7L/smjTakb4oeq+UzPF2+Wa6v+wgHb+i8
L24mYM2K9KzM5eNZZEaaBk3A0CxIuny5GErp9oJFVgxv3KHXHI4I5AWDAnoH
c1/vmO0cdgepswRLJ7gETOeFVbC125H9uWb/9/tp2JwbKXl+qxePNo6cpKdo
jBab1uctkiLrYn/obn0aObKBAV+HZFRZ9RQV/khgdYtLZItDG/yPrrXhMP63
GEYdCWc/Q7yaTL+ByYfycaNmrTkdSB6535y3hobW5vg96388haPVJvolawnM
6hbYf5ckRGwDl1u9k8Kh7k0ZmWbdULCZ+Mhi/oundVIJu7UKk4V7PeZ6krCZ
3Bd/dHM7vmin8L70U9DiOF42S29HM3ndypXJN9fry3r+E3wXmlNZOmmpBKaX
ypQeCjrQvulny0W3aCT0Jl/0fV2LBLGN8vRFEmE26kXTOSLk6nYI82Mp/LtA
Y8GTV2UwVh4r2TdMwO7YIfkF3zvIOrIIS5h9jcS0BiS63URdh8XcgBME9Nhn
LhXxRSgsMd/cY0CBWznrkFlcJ6p/njSv+YdCql5a4hIXEZqbFhC/RlBInNB5
7Z3QgDibRu0/Kpi83bBXTdOyAXlx3JT8LhIhUTK/d1ZtcPFPzTMwY3g+6Vhk
ZVmGr96PPivPJVHo7xbKU66Ce9KLwBI2iYi66ojD4hKo1ZjaGL4mEN1keDn9
QCf8D2clwIBG4daJ0pToYlxi5S980EXgf6gZznE=
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs01IsaJXnVHFERbuHIK8ml3DxKWyrk6iV6ODreRXVMDkWRdxQlJLpx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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 34->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk81VkfVqFSI5WlTbpvl2uJSiglzx1U05QZyYTIem9NFMVNQpIw2RUj
W9YGI1krS8sre93IxV2sqUx10PJKlEa9pz9+n9/n9zm/c87zfZ7n+5zDcPO2
5s6WkpJKps/3t7NouqbOn4+I61Fy2j8S/M43aQkyuAdV1mYNyWYCu/VXWaNB
FTBis8rO6xDUSuZhzco+KHfcalfiEygvO7/KJLUXk9rkyt1EAhet6607l7TB
y8rdrINLIFU9I7ZSz8OwSh+/gknQNjvt4GlnIWaCGI53QgmKC3qK9j7pxrpR
y2Pllwgy+9OlRlY041gVK3EhCO72+IYkn27H5ILdpbuOEDx+fUDuNxkhgsLv
CGRSCGoE8nlMcQ9GA42qVl0mCOrYlvfit0bIqr1rXreVYE3u5qSXtv3oT0l9
3CYm2DJ05fhMlQiJFtoX9a8RzMsajzBsbUGK/NJd6fsIylyfiGas8vF7wHSg
kjr9fqV5Vv5tIzQethtlmRDo635Jdr/XCO6fA5c6dhJ4BLSU3V3fjtfaemd1
9hJE+Fh/1WX1gRfRXRxXQKCmlflF0bgKbk9Npt5vJHD2Eqq0/dOFX7brlIc7
EoyyGE/0q7oR8zXj0pIkAl7Q5EbLsDJkZL9aeVqLYNG+OWre8ny0XFp0VpdN
sCHPbPnBwBvoWaEsa0XHeb0hlZZXO6Gxf9bDxnME/5ZFps7WFEF3lUv67QAC
7cMx6UeNWkHGGMtUTQner45LsC7gYw1D3VndmSD7YPjiLKnH4L31mMz8leCE
UNqkh1ULv2D/0F0GBHGTyyeYYXwoPt3uPkT5SSpVUEx+1YnCnbEdUXT9tSrL
7k9EVmE1x1a9gNY3z3vNZq5fM9Jmtlp/s6T6v1S2sbFiw2KHbN2/DIL0xSsz
3SS94DQpTVwrJxibw5AMTHYh4unYndjDBPbaxuUJ00L4e+z35FA/MLv3Z+3j
NuEEb67ybepHjkDRwb6gAbXTjDUCc4KYv6WX2c5pw6yrJS2bqD8qYgqDTizt
QSCjpORMBvVj7yeHbuNbiE4bGVmxgWDBm/DTP8jWwWutqqqbPoF8QTDz/LN7
eO0/YLOLrq+b+KYpsKsDhWU5h+3cCarH48tbXrbjT6eie6G0fpMGyV9PTdqR
PVT01M6J8ltzlFcl140HgYq6hocIZAtOPjR71g6X+cJcZw7BRGk8M7LhLvQ+
D44dXU+wcN9Xo+Mvr2E6tsqLQf11I6cvf9qzAz4pD5f0Uz3cdOKbWiT18Cs3
2sOkenEiI+p/HO5EfuSQpTCE8mlYt/mZdj5krCM/p2sQaP7jGMKm/aG86aNk
hz3BTzy7VwpzayB39t2553Q/hUotednpYlQPVf36QZMg5MuhmnOiNjT4rY1O
p3hthp46KmX2wHDq9uqA+wTs0zN/nKgUoDXec9EQxd/95laWRogQQ0GGO0TJ
dL7hyeaZynJ8wh4MUv8pljR6R87pgj/LoH0WxV9XX2L17n9/48FYjzCf1ifZ
I7XJpqYaG1xmmd9fR7C3lqvsvluM7bNef6vII6jPX2CiJyPAIN9pJtOX1ico
3V8iqsHFJL/zgboEYcGGI8WtbXhbqrNj8icCaQfv97HiBoQlZUTxvvf3SW6Q
TI4Q0gvZ3jpn6Xxv7kndbDHiY4+avC+j+hWX3OHWdeJnhxvic3R9BVfdZXbq
Pdj3jadyu5TAqmG15nZRF4yzflIZP0PzY+KXw0nuEtg5TprL1hA4bHnVrMUd
xDv79wqO+bR+H9ODybt58GIsT2T9h+BlBsMitViCLQrPXwQWUT0KLLNe5LYg
yqfQNZPmacrUAPO69E2kHRAsSdKj/jEXq+qFdmEi4flhLcrvIx+p5Ov3OzDy
aal6iA3lT0N37seKYiSlTmUvp/wW/iMt78fqgH7FB6bNUQKvkkNOZgfEcK+F
6cwVmp/BqmmrNMWYSqnwW3iDIN9941+Zzk2w4SUyr9O88pnq3LPDtBXSvcyr
tpbf87av9JKnAJJG9Rvtv9H+Vw97LGubA1fZA8+aaD7XtTvX59j0oYbZFKN0
mwATORbP1ZtRq2Z+RI7mW/cz73WcxF7cCr/qJmykeSCslvO43IPLeu0Lr9UR
XFM9BLdTfKrDi2hFV4LW1FMJ2y7UwaSl3fcRxZOgpfGDzEATdqbFjEhTPH5F
RaFh1W0wOiPZHk39OHxW/Yy+oxhxAVsaeLkEm9hnOPVNtRiHfvYf1M8sva8h
mp0ihKXVtyj9Qft92M1Bd54AEds79U55Uf+LpOdyZ/owHL5+hCmgeakZK5IN
7Eauy71rSd4E829yo3RsG6Hro+xua0Fgfj0mIOpDK/a+xJO4HZSvC5xpDtXD
YnTs5/JjtB8qZ6INttVAgV1vzqV+LOMcEchqVKNizrzKQZofMVeMjb2EHfCb
L93zjubBo/WP4is1u6Bp1zs1SPOxLDuGbfZnCSRE8OWgNoH1xwr341eFMK9+
ESHjT/0brbB7d9k9jJ5683bxFqpvIt/JzOoB/E5ONo7Q/O1Y7JfzLTkD/peL
XfrXEkSF8r1Ore5E+OX1Tb4u9P9naeWNbBEK2ennTGn9+QZL5rIGOnGTJ+Js
ukDP81mMEDO5BoyoZTuH0PokEs8vJy404rGVq3rqNnq+c1cWjL95DAP+DTuL
n+n4qSiXzl/KIdUvYsXTvJDLtVSq5Yvh+dltglNJYGCU/DFW2I3oto0IjiDo
HUxbwJQSw5R9aZh5niBga5+pWvojaB0efX5xD/Xb0M4zvl8fYJ39idkjdL/h
xJ2bXIO6wFcaK9gTRtebaM7z8BDjmGR+Qhbt18LGon0m7x8h7NNg6N90futk
7wWjm2VYunjRrnqKxyWAKxlxysVfK82CPKhfV9kof7Dm16I2yfhCBfXHf9NV
Qg+yuyFpetI/Qu8DP6y2XuU6IELIwzztojiaH5wa4+qEPngNBUviSijelM5x
p+4W8KLCZ8bofcMqQO2I51AaLpPZ/Q6Ub+ViGZUVGWJIP/Cx9Q0iuPhpdPqu
rwSjtxWdm2nebPh83Mw+Jx1bxxdUraB4fp+yj3lj1I/ALd+CI+l96P87I63t

                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VG8bRlFpjxApSdJCRZQfubWIZE+2UEQkSwkpKlQqImXJliWFFoWI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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk81IkfxscxZBwRW8Ta3ZxJSOfqeLalg4rZhok1dtWvciUdUrEiR7Fb
jraUpBylMnRQSqGRNYwcM+Max0hR+h5TjpL6lf3N74/P6/Pv83me9+f5YUfE
1l2qDAbjiHL+v711n7aWNZaDMUBkst8TOCIXvCzOr0ZQx+gU14hEZHhsssEy
KSqKly1L0qTBfnlzmzbrAWKqWRsSWCQGGq/+3TByG9ypWbb37xOIvybny7/y
EbJkt7jvAYF9xrHDr/PbkWpct3zlWhp35LWjrjtKUbtitExyh8Cesd8GShRV
SLHyw42lJATDQidXi/Og00LdTgcQCJ7xC20yKcKlx6/HE2tJfM+uOXLA5Rkm
3Za4/ncdhctZHXnGhl2Yfju8N0CVBu/prFXCyFqo+2gbliWTYDiF5aQ/8Ybe
dOJbrhWBy3Pt51wb7Yfhy5LWsT9pMF4sWpOiJ8KCdXGnXcZJzPilOTxQ8BBv
SwL+IDVJDOss3n5JTQB1114O8QcJh/IDAfOpNjho6KnxjlP4R8v6nmFcD86q
Dd6KECvv2/pB30MuhjD5UfcjA6W+w1t+e67WBPfo8KmiLhJDY2E7HtqL8Vf1
jg4bewrFzkHLlhhLkP5KNjnvDQXGGrcGjn4pXOuy0oPzCJSy3X/P58rws+Pn
HF4RjT3bRP/Jt22A9S1rTuU5EjedGhc2zuwClztCrrlFIfKAt0+S5yNYFxqU
9WiRWHnSLC6I0460aPbOGmMa81gHK9iv28HtiHFzbKFwPUr+KmWhBAYOo6Wa
gRT8Myys3/Txwbqo3+WjzPPnmHHFCR0xEno3lDLrKBzKylmpai/Ec13XENU2
EmXvfb30O6QocKovnp1JofmdcNJxcyNOuVsacAQkRqzOZJrNlWD5EZs46SkK
gxuiOubbXob2lF/kwxACWzmnNxlXyBBf9lm/VUZjwDHv1+c2PRgp2r/eKJDG
14BzCp6wAeZaMRbdahR8vZZqFg48w86jdmy1ARKr9ryrrim+iZi9m1+NXyBg
/ZH0zrGRorT8U1sUi0a256OaQ/NrQemH7XffTKJ/zrF1ETUS2N28I95+hUKe
Wcj7lf4PMPHmQ77ft0peMpYu+ndfKew9TtVdekyAthwwAd0N3X0/1XHKKVyq
CynYKe7F0x1Gsa5aCgS3uBX2MBvgEnpLdL6ERLAomn2+qRreyXd4tkwSv0pa
HhwVSGC/9YFipowCR5xrVS2VYvOYldC0mUJ8waG18RdbwXU8UAWlno4hR4GV
SIIPCW5h6/kU+k/6ycZSO1B1fSbvEZPG5E+8TPe1PdAT7//mTiqN4L6Yu7od
5UjkRH5KHyIQWJKb2eRTiF13hXbd0QT2zvwwNZlUofRFdYvoHYH6TufifOc2
pKg+Cc9bQ0HQFnO0Xl+KqChzXw0d5T9UW8ZrjbdD3Jham1BAYfb4kIJFdcHc
WydspIrC9ILDlcud2qFyfN43uctpZNyf4XdeeBct33/K0esj8D57d0Wmlghe
8U1XmaspaKaOe3bz+xC4L9auMpnGn0YH07YnSUGFWHHNGim8yS5726bZDi1/
/gpDCYWiLJXt3AllPsJ7wZ+vUuBZvuIr1BsR3D8amc2k0OLq3qa42ohZlSf5
bBYFJ/upshA9PmrrNl1YfYXAYEHuHlH5BSy794IbHkgg2vaWBouQ4Tt/+3S/
SBr2eQcYG8w7MeXs33BNjYa+F4/vUMbH+kKjLs5tZX9RQ+mi2w0YFNtruJpQ
uLHtsI96cw88Z+3ymK2gIcibqBpzToOHrs8C3Y0EttxU1XbjdsPL1GR29DZl
Hu4TTadn1KNUzNswMkqiNrU/bDpPBmdF+KZWPg1vfw+VRLtOmGdfH1Q/TGPY
0MWzf3sXdou+OOmp0Fgc4Wvq1NsFU1YEs7hQye/GVVNLK/9Bj3bIU60UErn7
Y4PObpYjt7tqzlg2DWp1jCzNtBkSfxOt+XISXfk2huoOEqhSGz9qxyr5Jl0m
XrQUIarh8ZOhFALSoNDOq25iWBhYck66UdDjaH3sOScD48ecyNPXKVjuT+qb
QQ8gy2P9t2ZnFDixuCLLIqMbtIwhW1dCgb3oy5y5eQJcep17mxNDouoeM0Gj
tA8OTkSGjoYCDDONxZm1gQhr4hwNsCFwtnOpKfNZDV5z/vK86Ehiuv7uwo98
GTKYVczeeBoVzll+inEZ1LMHF6QpefIlnFdqrurDZ7OE9EY9BXqPDw5WdEsg
KzrnWaXk/8Zg0Ptdx+pQefDhV/1EEsd6/eOEz2Q4szWxZe8AjaTUFl+7+lq8
tAzImaX0K8+2/KGJVxrexN0ldTwIuPgOu37d9gxl6SyVzu8oFKwomh5OkyB3
znDru1wKLyaOvJX3SJFp7rjLJZlCb4dlUb9FD4wnQpyrTRQwNtX5dLyvDieu
tIyHBpP4EkgIFkqacebHvZ//ZlOQvugU7vkoRujqkOLDSv9DP/E6D8lbYNTU
/1y+k4Iqrfp8MqIdyIi6YKns6/8BvW7Nhw==
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlPk/1IkDxociMSFH2QiFtk0hR6GpB6u2VTk7djuEkA41MkQkSUWXLrWl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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 35->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4VOsfR0Ql2W7WSkLTjRuuFlsfqVuSblq0cUuoO7qkoaiUiEgpspat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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Ve8XxSVEUZo1UciQvoYUUlklTaZQSWUoJEmGSoRKipQilUJliFBm
yRQyR6Zrnm7IdM+55jGV9Ht/f93nPPc577PPu9f+rLU3mdsbnOfk4OAwncfB
8f/f3Vkr70cJV6PjafK74r0U2H42urfEPqFy4L/qzkM00ixbLK08GiGtY/Yn
bj0bXb/E2q31wzCSNicntZqGh+kKN9VmSyyaMXqoLEpjSv/BrnvzWvBbuPPy
lB2NoobLB49Zt6L09E5H7RMsGJWFLrxPV2FBuN7BXgk2PO+O820pL0dygrMb
93sK95oPSkv9LIBh54NHSi8oyGfcTniytgm3I7l0n8+ykP54cr/co3a8+GcT
vYubgkTNIo8XJ5owWnfv6PlxNpJvvZYMY5RBJW+o53k8jbPKMX4lDg1I400X
/hLFxoHjWo7dNZ/gF629T24Pqd9VILmpMANsU8mJuj4KqpKSlzMXtmLro7Mt
X4v7obf+3OnJpwzEqz2wPRzHxpPoD3OlRxOhq//w0MvtNHijJUQ23P4GzTPK
JY4L2WBIH9ila5UH4Z61i8PdacRtqkLqUDUO8KTqak3QsNRzitNu/o7VQhGH
r9vQaGmfv05jNh6nXoe4JiZSUMmvHxJgtICTlglViGWjdvfcBhmhCvBOHtn8
XI0GNcCUMLKuhmzJpu3BO9lIFbjDn1fDROyrAK0/Sf3or/nttz39K9hFw2av
5Glc//DGfFKOgYSHARm9rTR8ZhVXrBJqQ0yGef2LaRZWaOeaVF9sgclL/fi8
ITYEA7x/XA8Jx0q7jlvrxWjMJPk+eF2YgBvK/T/0WBR8nnWa3mwtgdftJBW9
dRTMy7Q1Jqli3KnsdnUqpLFTavKbi+onvElOZctcoiGReZE6otMAF/5RvrkA
CstSlNwsOduxXGz7tgspNGKRHFuhVga1Uwo8B5Jp6DnpuwxZN0E0Sr5kXTGN
bFGHm7xc5QgTO2Z89g2Nu0phoT9nytBQcr7bbxn5no7Toba/ayF2d9V00QIa
x296KoU8q8FCEdfjZgFsUP+MUsxDymBhHLr120ca4sVHBBYP5uCag6pnQB2F
lqmcE+4NeTj44KtEYDkN69Dz/ac18/D58KIZ6iSNiPwN2YtetEPwrMW5gBw2
5Fu93Z3EkpCS4nRjqQYNh22d1k6NJajjMP9vsQILl+yZpfK6ebhmrC9pton0
tyTB6vtuJiID5Cxdv7Fhrb5jre+hRjT12JrdliT9dE2Q/MqsgaZn1ukCDjae
2hrmKGfVwXBRTpI9qV9PLWfY+Vg2uH+IPREdpBDbtKBmZGsmZLr7Ej130Jhb
m/Z6ieJ3CI4WhdP3KbzmLUyKiy+BwdDzwfvhFJ68UnS5Js7AsukH7lIyLPTo
Dh09I1OL7V1m8iFEv7Hzrwl8Us9AkD2njIcWjcTJgfZVG0tRWPiTabCEjfw7
1kcW5afCRzq36os2DUGHQ47tNuWYk4wP2udJwVJUs8i+uwx5mc/foYiCuOMd
p87gepRaylmPLqdRWbXtTt/yHEQ7WjysCKHAsdZf/I+ECVKDNk6tIryoC36i
8PlpI/bbCdy7BzbKcp68L5VOwZ/5npdbJGioXpG06BdqhdtJ46xtNwh/Gg4P
tP1KQs7Y2K8aNgXjS4/aInZ2wNjQLcAoqA+zPuHObcod0Ot7d852ey/CbZ2l
o8uiwNOTeqhFkOhRn9IPdm2BdHzhs2whNty8ppfsSv6IbfFF97+aE32Mhcqf
M/mGjrstoloOFLbvjt5qcLAUrxzXPtYUoaD3yI2KoOMQPq88U1Ka6G+jE9fP
Jx9g6q9V47SOhnHxbyVFrlrs3uj6ct9kP8KXx0TKy8YhyGhQZpjo87noX32t
wHRIyH8USNtA9H72PSFOC6LjWy9J7xjA2QizmA8Or5Cn1LDmx0oao1+vXsm1
KIb5kJ/fT3023nz4/aNfvxrOZ+4+ChEg8+pcOrWgPA+pul/+VhM9XMoYHbu2
PQtLP/96WPz/86/lfm5h5eDW3MuZf4QftsGZm68a1oJf52Bg1GU2ojoF+7cc
ycd6IVU5+600hNLX9Fzu/IqYY8e+uGTQ0HXpFG8srsMmfTUmr2M/umZ2jRy+
lozqrID2qfU0DKNVuhIrs3Cctds4n9Rr++uUyKnFLdBPWH6a6cbGrKJ9HZOz
Bb2ZjmLHCY9Hr1ZFvugNw6SAhKrWUvJctq9EeG8UEu1tek8okPn7ude5KImB
yvGlVO8/Fux+Gx8671UEoambyTI1FJKnKn6VjmVBOLTcb8FVGi4WqckH4xlg
nPHM8eGisSP+Q/CfmTqoPX2r2SZCw51Ttp/7VAG+DUzwDpP+l1noskw4m8hc
Tm2cEmSB40jioZGh18jfzj1mSPwsPK7DoXEsHIJblu8xIvfRcH+LN18Y0dPo
QXWPPhqPGtdLmM22Q/e2clVhE+nnTFr/gcU18Eh18J0lfvR3XlVr+e0mrJil
Hip9ZMNRrPP3Ko9ivPi5VCPsA43tFy1cs7TqUR543k6T9IMjfKL+Ic9dDGoe
fGNO5sGIv1qWyq3GxMmXqSkyxA8f9hkGbatAjsYpTZEqFlbNk9DvE2/EzFHd
t/zJFHgjBnvdNjEwp38jycaKBn+ets+Sg/GQnXocPARyXommukl+CqL2MMQ3
zVHYe6TwzZzhN/jIHzqYtIUNlxNKVt+lS5Bix5RyCSa8nV2lJH+dgelfeXp/
SvsxZxkoUG7XCgeH19vDBgZwiWeXP4daG9j1Nw2vdNII0vZN9eItxb8x3wuV
BTS6ZFUZaZX1CPqSn7D11v/PfzO4TycXwYtGf344Q0PesWCN5K9GiC7Ptfs1
S/j4Kewdx+YKhDXzR1Z50WAeuDCSO1KC9SvOmjcQnvgci7apX56H11oezYJb
SP++f5kWOFYBb54erxIOGvoOgxtYkSnI4wg0tVakMXy/4YJXWgsmezpnPImf
dIU94XM4Gwjtp9y7Esn78pvqS9x4C6BlXnW4JJtCrZB1xhuvZly+1jFpozyI
vUUHbvxd5A7hu05RxYTfOpetFX7kMLCmb8U2uz4W6itMB53PEp6LDrz985kF
9T4exs3qVty7UBEUrspCV9K+MQ2RHFB//Vcu5aRx1GHG75QjA/xbWy6uzWXD
r1H22MjXNkwwM/ZMhrCxfsfGte138mEpo7O5lNx/V4Oy6Cf/ALgyn2p+Inrw
CN917tzmb8gs57qi5kqR3KJ1V4JuwLf34pz/DAl/IjU1PzIaMe/h2rjYSQqX
hEwCQ96U43Esp+/neRTGanjkx5bXYpmwmoUa4b9uwW3enKWNyMkz+HJnxQCu
mw4JxBytB1d/rYEeySdCIgMlKecK0CDpkz2P+K3QOa/1Or4tEGqZvFjXRvz1
0quamZkSXPrrqy93m0bxaPWyt6+bkbrQVe77r36cVpDZUGLZjI6NohYbZnpx
9vaeS/reRK8T7sVJOTSejihFBB2pg9HjnlHxwn6My+ap6PLXY3TpvaIyct4j
L9wWXl+HZXf85UxraHCZHymcdKsHW1QgNiiGDQ91pgpLIAxMKqRbg/DWW5AS
S49j4l+p3AGutn68XWl7oiWuHj5m3KnTawlflqtNDWfl4EqCsHbaXwpWt07H
35hh4my2jsFuhR4oS0tq7l9cjunMCiveKBrp3AN9D6hmcA1JVk6NsvFBcb78
HtdiuNOOFv+JsaHiu+qwh3IRmBkF7vfsaXCf9z7lWViPeysE+527iP/vfchV
+qYEzL6V8raknwtaRert++rwfvHfdNFXNHz3PqswudSO9L+z9TbnaUh9G489
cesTvGsMCoQ9iF/T+5aPbyuEk4mw0QvCH0uFCw1z2bVQWzhs8+kR0b+o4SZH
xxQU6R1h8hC+S3UvLumZSsZ3YxheJ7zTnlHOHHNpwXr1vukrORQaBD8tloxq
xrXmB0vHWeT+RvZ/0o38hsa1/Py6JP86LNPzORAXiYZjkdEMYXL+0QK7IK1y
dGhlzF8fSvjZbi8tV1mHuBh2Mx/Rk5ScSNvLts8ojhNkqtvSYLRbzT5fV454
qc3R3/UIb147meePfsY11Xxrznk0XvNVThRvrADnnjW2PBU04rMCD6e8r8PT
rss7fFazsGzfPr5IuTrY3j/67iapd/Q1t5HRkXgc8Iz0cSP563ehd+9WLQZc
T1ZMvSB+J88de0HatQGJ5xj81ocpDPZZXf+CRiRv2N/2J7gPDt2Vx6ztcmDX
aPRaZILCYu5reSqh0eD877vLC9J/h3mJWt/t83F80TD/amcarltv7xQMrIWc
BhibFClsVbouEry5FDHhItkGJD87COaOe44VwMDnyMGj60geiovyCCnKgFD7
aVHZaBpRcSFSAXZV6Hcr0z/iS/Kd2D7nSq4ysBMe/9HzIX6WZSVbIpIO/Vdf
tFTGKERNJtRbiVRAPZi1pS2SRoiwoKlEcT34Gp2njDMGIK6R6mthUA6j5Fpl
x2wW9rptmv378SkufBXqSyU8sAl4FOvaW4cf3zJk8sVYkLraURqjXgmewfZC
aVUa+bof7Qt2RyH+bnrEylU0uldfEbhD5m0LMyRrsISNIFZoiohSBqZ1bY8b
uNLYe43Nl5WZiS+Wx085DRG9VA0r90sl48WC7BEv0s+RlZXdDz80QlAu7cvO
EJKPHnL27rMrg+bwUY3NP0keUlBjNLQ/x3HpsLZWcXJfiaaKO+ULMO6jyt/c
S8HCv/6pvzATQRPC35flkn2iZhFHQ8B7yNmZ1l4geTK80yWqNLAJNpFxzZGn
WRiRXapuKNuG/Z9dK0IEBmBU9Gxecmo+NOY9kLhLvifnY66cmW0ZmsoSB2Iv
U7j+R8nz/fdm+Pk6+xleHsDG0G8a6MuBRI7NxfKFNHjWm3lMcDTDnfuelNor
CjoyUY8Ej9VibI2oLv2F7GvuvvdMtuUiuphK0HhC9LwsIqndKR9GAykRUsSP
PLwNvbUs8lF9PExPm/zfLWoJR4VGDFScVFCwZ8M//4pfytpW2IRS0x0k/7fM
v5ooeyINpVkrDXc60VD8p+PNXFKLa/18V66Sedhi8CWEg+s9dj8QLl5P5jdW
50Pi/uIGDPxntMeug+RHC+UZK7EWPA87IrPUlo2ZRkfh47kleBtZLv5bgPR3
jEtYy9wVUV4qKYMbaaz9cfKRzngthLX5fGv4aKw6+0Qu0r4JwaJjZ6Ir+jG9
qZo3/lYz1izPVshpI3n2jgkccpvgIS8Z4eU5AD3RdGbJaBwCnk4WPWug8E1+
Tmu/SztK1dq3qg4PQL+mtntoUzmSMg/8cfvFgovR/rYCiwhICt39tIXkNxs+
+TiJ1mrMl9TUsThBeLRA5t/XuDwI6WpYd9ygoJ1RyDsi8RUbbA5YTMVQ8OBp
j7ofY46MN1k/DhF/3T31xWckkIGOG26n3UTYeHT3maKUWyXyvR40zSrRuDAb
1Xn0QiPkGE5qv47SSNrvv8F/ARPpby/uuDFKwds4bOjDzu8I9+5d8zGYhXCt
cVbqYSbJ2YeenbGjkbFQ6I+XejsGa5wP70lkQcjEJXnV6Vx0Kdlx+xN/Ti7x
UC+3L4d7RfpkiAuNV1tnIv7b8RWcc0t+65B+j4rkrvZpTkabC8eej9uIHgq/
rQ7nvod1F+/IFxG9d01bVXRNv0FZpIXUZ9LPeO34mxrz67FZ0EzbtJeNS18D
Bw2Um7FJ01PTnvBNPqr4Xk9ZEUzvDaZUBpB+3+8dXX6/GjF+XuKtx1iI8tF9
dTWxHuMPcs3/erFQajT4yle9CLn2V22GH9IwyXnbVa/SilGDuce9qhS4xJdK
HTqTj/CRwU5pso+kcZ6ucBCph0jikt7PmmyIRy5KWMnbBOOI9PNdH9g4y/la
Y59DJYL6JnS42sn8Xow4aHmnCY0L+NwvOxK/Fb3o/aSpDJSZ09YUoheOm4GM
EZloLKxJpUIJfwR5pP42CFVArqjqROEDkr+9VLaNt2XhjfTWAyZ5FNSeh/95
6M8A7fJpROg54Wnid9ddhQxQt5pCzt8l+0oNT7+/TTTyNvyLTib6nVFNubmk
pQwXr9aY/z9PhPPcMn/o4Q+dzYlXXoqR5/asWTG3VswbvnCF24bGxlespujH
AWBUBCYJEv302w1u3fW3Hfm8O2QqVrNh++SSZ1pJEUKidOf2LyHzxVE6Wbfm
E7zkPyzYK0fuRzhkyTKHenhl/jlpUU3hkbEgf+D2CsR4x3beXsRG8hulvgt/
Y9FtturFLbKvcfQMby9/4AOJOP7BhaSeUPWdOTH1DNyxa525SfSSnO7Qbnky
DEY3+drnEf99khiiIcMVD9Njd3tUiB48NkpVpXVk4pxJ2HwNcp/dy0fklqhm
IqTh1WXB3xR++s9mxa0pwgvmvjNfjtBQYdb6KpwvRfTsXredTBqHZ4Z8FHrK
8EEnlL51jvjzy0vuVSrhqEzwaphH+Jucc1COzklAUuFwj68yDWHXpL3sCpIH
LWTL9hC+xWiUzwWfacCduRtVg48pTEsV+zVadkDp8fiWQ2T/pd57/FYOKYTt
SDnNukz4sqVIos4tGJPej0TekfqPiq8VqxSrhOHuaKtlhGez29gLRA+3QtVi
YrAubACz3/dW+03UQSfyvX+xDql/C6+ZKU8TjGRk3Xdlk/MWm65zCMnC853S
5l7k+zbS5s5PNxegb8SmtvApjdT7/dqrLpSh+MLYAqXVFH6clFb4saQFUcav
ck5pscC1pzZj+88q2AyanRv1J/uL3ylWruM7DJ9Pn164i0aEYsiuxOMM2Kpf
GmDnsuD7aUJeKrgCJ7I7uG9vprCiRXjNr7NlsLp/eVQiieSR254xEVwM1Co+
DuIzI/3tXioXH5iKZr3ozI1kHxvhVFF0XlQHdpYrPzOLBeGD6wrU3rVhUcPm
fAEZNp6nPj0k4Z+GxyZvOD52Ef64HL06ntWMHHeu0hZ2P2y2nfLmtW6CsFNW
hd8PFmaYyuyVXkmINdRanU36E6Uo0e27tB6RUrK/jcv7cdfKNyJXhYG0X5SA
2DuSD5JKpbrHy+B5tVQkSpnM65bJrJu9OXiyqOTxVDkFcweNnekpzVDLNlc0
TqNQnTDRFfi+HNsN7Q0Mj9G4tp87ZqVgPd4Kuz8pj2fjf8f2HXI=
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk81XkXxxGlyBalSYpoVLYpZXLVJ0qjGUqKEpNSlFTKE4/CjCWJIksS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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVHk4lAsfVX2KrpQirVKpyFLdq49LHKRCKYRoQW5pIxKFiOTeZJnQKGkT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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 36->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns8lFkYNhZtWm0hSWLdShJRTVrlSWstEWV1sUoouYQmUYgSyiVbk3bR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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4lF0flrJHkkgbIoUSWd4SbhWFVEKSLa9KWsRLQkJ7KZWllIq0kC3J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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81IkbHjkiNptcxSoqVPrpIkd6bDokV9g2RMqRLUnJMulOByqyZTum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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41IsexpWEZIlocpJREi14OoWJvJZyNaESlYqLy7lJZY9I5lLSQpkm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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 37->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lekbPpEkpDQt0zRGltJCG6UZdSPTJHWQsmXfxhIlSw0aa1JKKI02
y0G2NNEp1DmcLCfbOY6lYzlkL2/bT41KSfN754/v+q7v+p73fd77fu77fle6
HT3gKcVgMK7Q5783Y2zdX2dn1+ER83du7s8EFu9sky/Nk+DOcdXDnukE8mvj
ffIm7sFmlkLEB22CA7/77J29sRvdd98rxd0lOBmxdt+Ss13I3e/btKiMwPD4
Dg9eSy4sgoJsjTQIVK5HCWJXCZHYz3JQ8iTY7LdQsFhHgpdl2dWn8glYQdZ1
X4pqwWRa6lfqE5gExp9lv8rHn+GJ9pxVBBmXk9t9D/Eg9cf3ohFdgj7+IcPH
BmI8WP/MNPMKgULWsq5VaZ1gWvW+KEghuBvNO/3baBbu8UrZ/9D+7OcmqiZV
rWjfH8z9+SDFt3rSvnCNBDPepvJBNQRZ9k6c2kcpSL1nZG2sTqA2wuoNqxTi
SZbzhsEAAmFn04tU53aYn0rwbA4mUB1MeafqKsQyq49m0uYEl70utF+1F6Hp
oYf+BVr/YO3SE5ZfBNgr0ku6YEb7v3b9oW4BHy+Mv41tNSKYff+u+5HtPSh/
7NX6rorgfHOMuaqDCGo1ix2v0vVKtS2EmdCK4AXT/cV0/6wyr/VrA/pw5Jns
SrunBDH+KX65knLUpXC99lE+9KY/2wbyxPi8x2m8mkUw+PJM7WUNFrqKVDYL
Kf7Z0ZPrtO60YbpBIDh5gmD09XBOCLMHf3HPb/+Z9t+4gaXI54rR8ibbbn4g
gfKmbdKMhiYUjKqf+cYkYN6/P9Vs0YmihKWNHu4E4qFdvvkVYpzf51E8N4pA
UNP8MO7pIwRNxTH/pfr4KS2Jf7StHxmpvz70TyQ4qJbodjO9AmMdLMXgzQQ7
RqbXa51qh8Uhpg3nGMHc0iHmjXmVyBKlJG/RIQjdFOPu1imC4y2zvBIHgsZG
x69TS5+gulzDRm03wevng24d+SKEPnPuNqDrB3c2izfJccBL+V+cG+Xj5bjb
/KIUMSZr5VfO3CRI+JGxxE6Wg+HQ3Rd8NxLoHss22F3ZhMz028PP7Ckf9pnK
7/lt2CLhNwUdJwgw/Gji84YHt2H/tu+oHhMG5COsGcUINtPxKdGk8x4sXXiQ
Xw7WsOKKaIrXJfCw7fVP1djzKsA1mvY3PPLhQb/R3+BDUPSdFoH+Yd7lG9p5
MIrIs2il6z/Jjb/tbm/Dop4tf03FEiwZmHNqO0+EPj8XxWwr6ocS+ysf6iXg
+gX7SkQEYfUldfU7+ODL+E/sMCZIn35Q0ZFUCY5iqvJZyldcCzvnxNIuVM0R
+lrmEkwYUprfSMBiKvCHsul3+c78rcXlsAiNYftS/hnf5EvmR3Fgq20n57SB
4pHa9e/fNa1QZrUa3qJ8NFSdcCnPqYe0g+EeVVMC416XIF1rEY6osZK+0fON
kcOLn8W3YXy/bc5hN4Jl/velZQJFqOg86i3vQ2CrpvROEH4PnVpO+8VrCDq+
vle8GN0Oo1/VI7d6EeiEuOy6tVIMrRAH2YFUWn+uPpa9sgPM2S4p3qcJrI+v
mG5Z/RjdMg/nJhsQRN2sKDRMP4vlZItmvBpBsovNEl/xXTTd2D7ZuY5gvnaY
0fYrhdjdK6W9azXFJ33Qiiesg+pwlmKhIYGPaWaU+fJ2XE+e+URCCHrd7TbI
9XSAYVJayE4m4KSOq6T1NkAq9KLo4A46z9uu3Yv8eZjvFSrk0nkmOOZdU7ar
QYPdCs1Eup/LxXnH5L48Qp1mann9NoIpgVasW/01KDeblRlQv+lcKe6RvdWF
rVZj5omU/7h1pyScwEZUnB5xu7yPINGsTfUTuxv2Pwg/vignqJtVkJmU1oX1
zpY1/2QQFDk+fj5ysQcxBZFr1tN8/DgtH8EceoxZT21XWevR/Em8WlTjm4v3
pR+SWqieJsteqfBb6rAkKJ+hsJcgniuMYM3qgvodpy+6cQQaX4wuHfu9CsWJ
/pvZVP89et3leklCRJnu9JT1oHgavBMH3a5D5xczRizNP0sjg+IBTzGCZ88V
OVD/2DL71U4mdSGJUe5ifYfqz9yyp7GPhy++BtHhlB/dwlXn2KG3YHV230df
mtdxI0l73hsJsXNkYu4MzXuFVZpLKys7EPYm51AP7ccw1i4zPZOOLa0ZFR9p
P4Nx/cWv40QIXihuOk3zda5j0MT35tV4O3ls9UO6/9tLHi89N/diMv6zTCzl
a2xgjuyAfzcq2TLZ0dQ/y2R1f3GseorwIT/R6PH/9JiTn1xRiQ25Sp6nqD+V
Fc91pN6j98mbXtnvqD7O3Y6MW7/gKYLnhbfdSKPnfxXysu9cK/riwsZs/Khf
F6xz3Bf8BM8iQ66GUf07JnJLRxd3wtnpfacrzTPD4RKR8/IGbJyJ+K3wAL1P
+EOGnQvuIy52Ik6G8svQdZWYzdyBcKlOmsZayn92nv3q4E480MtUKg0l6H7k
oPlnWg9+qH+x3J1H9X1Rnd33UzjCFAsaf6P6Xpau7L3BswzOAyftZai/XXaP
/1KbyYFNTtf8Yao3rdF7flIhHNzqStFj0f93VeqP7koXI0Mqfsg9jGD33jap
cH0eXP89/+MNWp/lv3/k7afbCIjeam1L8bNva0q/UHqK6G3HnsxcI7hjdFSQ
wuAjK6DZzWo71XNqeOIQqwvWe9Yo15QQmJdI5H17OqHxXEbnJvX7lEKbj5OT
AMYJJgnSdL6c2gvpY0fF2OnTf4afSf0rbeld3S9CkpypuQ7lxyGl/uHU4g6k
Ozj+eCaawJubqqieIULb9Sezmul9d+TSee3i8A6sIFwDmwt0Pg2RptdqqhA/
yF3RTPOJUzAnK/v5YyhsecT/DJqXllE5T7wk0F8Y8DWzhepTZo7A6ysXDUHe
agW0vtvj15dCNQmG3VerNFE/fd2zckHMyVoY88tfj9E8MeXa9k86C2DyWX1n
ggvNgx0lJyzs2sAsnHntSvOhaWPkN+xtw/KYarfIPwlEPsoTgXvLsCTSWkWD
6smxKOPtpvQuHGxMy/uD+kEg9+BbY10zRg9d9PzejvpXfZvcpK4YV2wjeRLq
n/8DDiC4zA==
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c81e8bxqUSGlIJlTKjoiSVhCsjq4hkFFrUV0NRIjNCMhIlK2lIZlbK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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41AsXx0fRMqISupSia7xpxJC6lqavNlR0JSnpUcry3q63cMkSlaSL
yqgkidJCE5UiGcKYkskkTA1jvWmb+i2UpcX2zDv3j/Ocv845z/P9fp/PMdl7
0DNwEoPBiFbVv92uooU36iFHdHxMwB4mja9vz5Y68rJQ4iKKa/Ij0Ob4KZ1d
+hx192ItuT9JRPX98DhgJgejMi7mRgKNIydCBN1mryEai9eKrKWw0H94xa7u
TnDm3PzCktKIjxZG6UWWYojzbaxHSkA4HnImNkmGR0vHd02dS8OV1VJWkXgH
ZZ33XvYXEjix5AB1xFMEg4oKo5RAEozmN1094gwM6I8VYweBGdmCAMcNEjgv
ebxq0WwKnWnG3/TXtiHrWvDghqs0QiSmjbmacjgxJblMBo1Zd3tpraRuvBTF
5FQH90Gec7o52EOKmzN6vxT3UTD2cdn2ZGUdcs8HXR3jkTDuO8fJdJDj3pHr
WrFhNBp/Wv6Tc7QZIf1Gop+hFHq3Bc9RL34KdVsTdQ8JieQ3+fK1aALzUhDt
nEZh3RSf8FMz25HMbQuvBI3jTtLG226tSJ3w3J5QqJp/p/DdYpeDMx0Dpb5B
BFp83Ga6GQuxIt+r6vBuEoKwuvCtPiLMfKCu672fhKvS3OqPPhncutQUPC8a
l0WzAzqmtmLGifH2hucUWqxauJxjOWA6++SZBhDouVl/4nCZCO+2uUSL/Ujc
0Pkt0mR3OxyH508pq6XBWdN7/0TTfZgNjUTGVBNIlvj7P1U0waJJ8W4Xn4L5
dubTNT96MJBeUqn3iMau8/M8Kv9oQ3K2gc7ejxQuKuPqHzSKccP+0+JvdSR2
si87rj8oh/3fRIiDgsKv4WSyUUUHZnVtUvNzpZEetd8hkSuAdhjDl5og4JYr
DjLf0ATbF2+uv7CmkOfZn7moU4DB3QMM8VQSt1MV0SFFMvy66t1EAknhWFbQ
h9U1FRhZpJUVOomE4q/2gs/SFkRFFFhrBlJo1K5V4zNfw8h+jfyDFo3BBTuH
ObWNqtxkxBXpq/SZMCiNXlmD7zt22lttJ2H3RGR8aqgWiqEFpcv4JDptrJ8Z
GFYiTtmgaT9GwJhj5jBplRSR87YdPCSg8NrSRocZVgad0Uhx8wiBqtjkjfr9
z1CYMOP4qJhE7aUVenvUniJnTPr4fCaJ9becbw4el6DVQXqu5i2JNHVX2ckP
beCYrnI8LKfQ4D6t2Jkvx5STE5Pn6NLwSzMLrnr7ClVHo9jyHArtcXmZf3XV
oEcgzt+3gkRhvgbVNP8VrixRtw5vpaDucmvh8v4XSL2d/t01jEKG0GTgaGYb
UrRkS90FNKZtPczMGazDztaM7ZZlJOosrUPYK5/BnZH0W245iZOdOYKIABkk
5VemeEpV+vPlPHsPCQJTq/mrL5BoOmniqsbthHftgsuL2X1oH33rZ/z9ATZe
+Na/7jmBueHE6Skpcpyeq3XHRKnSt0iw4eKBGryaGRTIX0PCZ+Hd1ZOfyJGn
+CJrOksjy1o9pdmrCte2HEuJNiMx3zolUs+sHi7r/6POZ1BItsmJ6xh6ANsK
wzyvtwSckns33pkugVDfwbp8MQXDc8vYpc31GDPijvo+JnH/2fJDoUb5SBDa
t4YkqfySLlnBu16P4GHHTTHaFP7hsok7VAvWXNjX+eoMBS7XRttC7zXOz9+j
dmiEgoT3zlq2ow3/VUx/eHkTjVC3LXr/21wN3x1+lgcdVHlIPMNq+kXFr2uL
b3uso8Fgsa66KJNRUnbNXbmWwCRmfZxooQyHEoS6Fj0UZmnvScCVcng94cYn
TSdhWk7sF9wS4+IWb+XdChUfbDWuKnpeIv28r9ojFR+8DOd06X2sh7a0uP7q
PRJVFjPdi1T+m5qeM2HtpaCleUGtMVuG8feRXcY0BYuxJz8MY+rwwqgiQzOV
hBMvuS5CVIXlNjzl7ywVH12XXYvlbETAWWG+uSmB6H3xM1q+v8DI2U1VlUmq
e3KD725KMTTT09IbJlGwnSzdbDW9B9qt3Xv+jKJx6H2066kNbXgWlriwUIdG
XKmWRva2DugPfprgVdIIYG5OvM2Swal66FKHPw2br3+/TI94DVnI8MGv0RQ8
LDRWDhjfgpXnTZJ1hoD6UES20K4Ke4sit7BsSOizFUVkqAzZisiUmgIKjLTy
LN/qePTHT3PkLSdwPVU66hf+CiVLxTznoxRcilP5VkXtMA/+3S4znsbP4LTE
kq0yeIc23u3OUPHa4uNn3YTLaDn7p59dsOof7Nt6o8FOiuO+LI2EMgqlBeNK
YZ4Uw7NL8rT8KfwSOW9OZmw3hF8L3gu9+1C0qtdwvWMzTkVo0EFWqn3ebNEd
Fc8+oa2mgUXBSPfwU/NCMQSaQYY/H5FoSS144HS6HWoG6d7+mn3I87WdPJcf
BZ3MyZpyjip/3E1siW4FuiW3jN4zSXwWLTac/7AVvdbV7aPuNBw65x5RKvkI
NFB+uZFBgJP7qC+d/RCKrA/jI58J/B/qcMfv
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81IsaxrWdtHBCSrrdi2jDcbSgxNN1urQgbZJUJNFJWcoaUqRSMiGy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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 38->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns8lNkbl6UiJKWbFllJyEpIyHdUSpYspVgyWDZSySUUCQkrlVzKipqu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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4lf8bVlEqSSUKFbIrvolSxi1ZbVSSEZUGKUJpkZKRMkqFIskeSaLI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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk41AsXxyct2riWNipSGupKKSHSlxa9JN6GFsWtNISiG9VQIkK4JJEi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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs81AkbxS3RdBFRcr9sueS15DJtCac2S22RsCW1LpkKUZK2GEkN2iJU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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 39->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekbliZhSrbfJIlzOLIktIiy3BFZUqFTSZhKpyT7TjWdg2RomVKo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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lG0bxiXFaykiWqQIpVSUpCynKKK3SJF6KyokRWSpZGmhkL3IFtJm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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHk8lIsa1rRYyzQhMukkLUTZbhktTyldJKeFwVHJvZHKlmjEnLiTSpbC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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVWs81IkannKtnZxYNdYlFWUqpVJbCo/kGuGwWcltVUoX2bCspHFJSaJy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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 40->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk41Gkcl2hpJ1G2TcnWboNSEoUc86GYRYejkiuJRVJSzmnl2GXJVaTc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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2lYTV0bTm9poKIyhWZJZSwNqLsBRbO3REpJKhVCvKFRAxIaEElKgyRJ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlX001AkXx4lNpWflZast60iRqU0aL2VUX1GhJu95qGkoMpSWyJY9rVBL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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs41IkexqfcVkRKSSRKUaQ46xr7btlyXVHZ1dK91CqaIowi1Nl0c5dy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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 41->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8ldsXxoWu6ZgKCRkadJSkQorjMWeqRKScQjKUIiXErSiaZKxIXHQM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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VO0btiXKriRJCO0rSZJb8hWlhQ+VLUVIElGpVEI+RZItSyRJVJZs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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41AkXx1WbrFuKNltGNcJuym1bseHrCdUqXaYkSaRsVEo3XYwal5U3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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk3k81AkDxktJrQ60H3Q5UrlCQoQ8yBv6aF8r695SjHUXS0qSXEmHCVlH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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 42->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4VWkYv5UmlS1LaSxpLKlQ3EtEfjIqlIgYNUnZhkZjC1MU2TISGiUq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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8VW0XxhWhKB5EJEOigRDJkKeLFJJkShkKzUmSypSQVEp5NCGJoqQi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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81YkaxhlHSEooWaYbJbKeT1T2x40wkQ6uZUJFaBVRjSsVkVTkZBtr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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk3s4lAkbxksiqkGUkk9C2pXjJCGfGzluwlc60WdRoUaHpSLbtohKq1BW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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 43->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs8lGkbVivKl5CkNknjLIkModZVaUVNu3JK1IatVianCvkUioSk0bbO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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2lcjG0bxnsSKkn2CmkliSg8ljhsRZuiRQsptFjKUnqSKCFtFBItohWV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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lWkfxiNL3k62iF7ijOGN0qSSTNF1tKhESQt520aTmmNrRFT2sUwy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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwV1Hs41AkXB/BBlDe0Lsmbu3obt6R0Qepbcq3elDfEKrZUVi6lpMQmuYVt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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 44->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVmk4lWsbRfFp4BNKqhOpUDJmJoscQ5s6UpEoQ9GkSBFyMm2klOFkKlNJ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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4ld3X1iTJmAYJIS8SJUkSbmny9qoQGfJDqag0kFTmpFBEc6lkSsp0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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk41AsXx13Zr9srlxJFi+m6pLeLROirCF1M0aboDRFeLYob7drrSRT3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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVHs41AsadimGctLqlKSLbGV1MSsqYl6lRJTIQZapJkQ6KRERISQNK5XI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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 45->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns4lOkfxgejZEttW8vSCjlmlEKylXskZURqWOVUYSu/itJiVQ4lm2M6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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4lX8fRmVHqaSSJElRaalUbitRiVRISKVQVkiZkaRhtZCUjGRUyN4r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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHs41PkXDmVrlVWxUo+emRqX1LaFhGpfWrnEptYUuRQTIgklqY1cfglb
IVJtinrUpNxCdkbu5J5bzGhcUinm8/1aKreV2O/vj/Ocv85z3nPeC5vn97uH
7Lx584KZ+n8PG3lx5qhrJrxnHGYPCqSQtFrz+7LbQVI8LeWVaczT23ktOrge
FxYJw4MKCPzVzyXwSl/iGsdmtdkEQRjHxTDWPQSSsy5P3+pL8Ws9d1cj/zlM
4rWWJKkSjI5FjgdF8KFbeTEoI1EKk6/r3TyE5ehXj3VWsyBIuaM6M7CtG9Wn
jE4np9KQSbmnviSwDVblyf28WAqcG93KvaclMOYLRw9vG4bA86vLWGExLo9m
eQpYBNkBiZlFJtkwezqV+yJPilHBH+Mqq17jsVe1/7PFw7C0i9m8MLEG02pH
171XpGDBMzpratQNgaNPzYe1NOzl+NGnLRvhb23UsaCLYGGZ/Rdyoh6+QWX8
xI0ULpc9KZ0ergSXO/dDYAZBZnf9PmW5boRyz3rhCg0DD6UztoZt+ONQjptH
M4XfjrD9Go+L8d5jpVOfIQ3zrUpTTaUdiDjvlnPgPoWHYduu9riKYRGpqhJ5
lcbCltg7idkXkZ0SV6ECKZRGzvWurMrBAVUNPxOhFOG6VPjc1h4Id/y66E4o
DaV/7oq1VFKRbJiQvN9XijTZoeAcVi3kHH57cb6CIMh1De/I4Es0bd0V9Smc
guB4fCLPrRapbA27oFsEZsNhvTbWtXhJ25XGRBEsHrpZyXpWDbUtEqshhk//
QlP1hEXZqHBKb1paKsVuzQSeho8Iyja7Mi59pRCo7m3ULNcOuoGr1zdNQUfe
QuX5sASmaj0R3jdpxIpmmx6vbMeFX8pnauIocPdUyq/K7cQmjTkP8WYaVib5
F0aDGxB159vTCjEBHZW8IHxtGe4JajtuBxAUnxz6RQZN+OvbFYfdWyk4nXPI
HVHPR957q07uBykqgzP2DTH7y1+FUYcVadTQe248ed8E7uwTg/5Wgn/XOZ2x
C6zDjwoSTeMlFAr6AzcOcOswdckp6+k0wVXFm59yjDqxcW5DSOlqGo8UJ7zq
J4pgm/xY5ok2wf++VCftflePbLko20F75r6/5W6ka1XDMyE7/noxwaZqkfvI
tfu462g1nx8hhXvqd8vnFFvA0fJztfxMsEYHMU7aIrxLsJ0XSCjQnNSAsFuN
IHJTk87OFGSVk3+3ya9GWEGhXKo3wbK4AY37OQ3YKmrmbWwgcLxMOimFLhiY
GX+3cAONzn6dtIOFndDU3JFfVkVhTDaB41bXgO93Krg/Y/Tpry8cYd3vQbls
75UBPo29gz6ljWMP8fj1/I/P4xh8n1q3WD4Swzwk+c2ifBrBSZvGnVorwdu3
7N50DKOXweU66O/AY+Ly0GqSgujUN//Ur+1wfKt77CKjV50HBR0lNt24GmGu
/MGSxkmLqE1Vbm3InH9lvxvzn+3HLAO2VDTjrowKOyWRwoXEvzrWVIiQnb7p
YI0+jbGmBysuZ+VBvqooYVAkhc6RdO/kuTL4S4SyOXYEwe4pnjGCdmROjM6u
bqPwSsbzhAKnE76hbP1mZt4s9tRdUUMNfs7c0zTTQ+BQGRLwk/0zLJzQ+VPQ
J0XurmK/WlUx9B767HbPpLA3zS3YXPIaomdGi2XUaZCB8cmTp3vRGmRyQNl/
GN/r2IbqFPWAUzshE5fF+Mn0+PE41gsQD/YyYQlB9IPUZdFZQvTvr9DOUyGY
7M7vrFHtRlLwrLL+fhpJgZsNeXvq4CopuV6oRKHr0NSjhvIuhPLyn6vNUgj9
7Jpkf6gTbCXO8ooVNLSHb7NWezfCWVwWUjRDUHXgqo0sW4L75qViZ+beXLX8
lu3mEphVr4svmaHxUe5YzFLdXpiY9Zo72w6jSYt97tb6Oqjm/xQib0DhMNs3
TzeNycecyn+8aeb/tnWfTBvKwcm3WfqvL5PHVYHXXFJvYWdHrmX1USmO+3oq
Re9OxwYv2+sdMVKw9KpaTmkWw9jXNq1Hg4CVschLw5SPkEHNkbW3mPycrzA1
oMmH3+niH84nSfFo+/iOj30l6DkVuZ7tSdA3HlB2JvIp6KCysAVtUoydOSi7
p+Q5tBUsV/TqEgT0xXUKDwhxqTHTJfpHghvhn5d8+bOR0WOXo89HAu05BcPI
rnaYpd3edsKaBnfBUeEDHRHivY/5vWP8yGXJ1KTpV2Gl3evqV0UE5lzjXTGO
bZCx3efxNp5C3qS9R9xgCwpnG7MiUiiwFA2iPDkpKAtZkK7kJUVYUFaSZOgF
juglh6gy+WKitNxYMHMD5y2UMyxcpOh6sz3iS5AY6lXrJGtBY2qiJdehpAP6
goNLFRg8EX7OYwotElxbrmkdxxpGf3xhT+ybVhS0/73xYznDVz0vtGC6FLGN
8vaRRwj2Gk1qbViVg2KOI1/2iRQhzRFfqqxE2JA9Ub7KgIbiNEdXPNYBctda
w6eLwg6H7tVuD+tgscRQT/MOwX9Otc0J
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk3s01IsexXFympw4TB7dSpludWVKTCSSLSTFidAp7/IoqptHpXTcUl5d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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 46->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4VekXZn5oRhhUSEQUoSnX4oiXLhIqSYVyGSEVuRQiIkqTSiVEVOjC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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VW8XxQ39hExNqAxFipSIUMqKJEQUSpIpSSqVSoqKVGQopKSEVBJC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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81Ikbx4fU5sgObYUiKrUqUWvJsX1UchQSliVehQ5RxpaEpURZSWIl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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGs81IkaxxVtbZsuuog2t5Tcok4JxW8oi1YUVjZFmEplDjm2JBVdRKlE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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 47->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk0lV0bxlFJhTJUUolSIYlCFC5KpAGJSJIozUR9QkKKOqbXFJkqJUMK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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k8VG8bJipRKBVJKEuWQtoUdVEhSotky99SKqVSSKgskSSJolAhZU1C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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs4lIkXnoqibKuLUk2WLrK5lFaS0ot6Go1CiVy2SNOmkksXKclUElZC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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVknk41IkDxqdDbKXUGFpRlH6FQiWxy75ixnbI2pIjlCa1tR3CVo5INinK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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 48->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkfPglzMlrQJ0maatCCNmup25pKWc754iPZiowOqWTQYsioCAkp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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k8lF0bRokkqShRshWJkiSVukRFUlFIyla2hCiVlle9JSEkSkIhFJEk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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk81AsbxSfpNg1Z2nBzQyIVbguRqw6l9NqT0kaI7KUoWbIloWQtJPEa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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk41IsbxadJSkm3umoKlSWUQkyS7ai08dMvkitNEY1Ubk0RKtojlKJI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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 49->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk41dkbF9K+SItKC5WSmpBihM+NwlTKNrdmlG0IKVsqJbljSzFCkT20
b7IlhK71XlzXXewiW3HQil+Yljm/P77Peb7Pec77vO9nexUdPCycJCUkJOLo
9/+TxXbbccigAD+fdkn5bibIGAl4MeuOGMoWNuP1kQQX+8pFK07U49pZVZ9A
Z4J8Xru+S0QHTtRJJIQ/IWDVBIR5lHrBLKUKC5UIruxVL4r1b0VYrEH4qSSC
rNoH7+1SnmLnhZ7f99P6LwaGa9P6hJh36PYTM2+CkYea+/NM2TBpiWxd+SvB
gXNj8obyWXhpETbDSYUgpzjoRXa2EM3yFux+X4KKGQWd95PbIHPsqnVwBEHy
E4aOSk0dXvc8f+txlIDZkKO/zK0NfhvcaxBIYOS2Mt/SRohUOf62+ScJ0pYV
fR8Yy8fwydHPTA2C8sDDtZreQphPJh73OUwQtbFvympaIXpXiQTH1QgmxiVN
Uwfv4tL9ZSFflel8S8weznEVIkOvjn3iAu3Xv9VVNp4DlsjEhnuQYJ+7R0p5
eAtm/jXYUh1F0Lp0vUzmOh68kxW7ljJp/SDGncgbjZB2/lAYRe8vsjIddb3L
kd7hl+TDIOCJhbF6pm24e3t+8jUvghJb3s59Ss/RYz6il6lKYMByLYheL8TO
tFuqE7Rfs2unFl2+/hRl6h980ilei9YrstOlm5AbV6fMuUawqb/GJqQ9D4xj
4ztqthG8Pc2dNGQ1I1SKZJWmEvx73rcz0FeIiR8b5q/wIPgl8KKyiVcTapWT
FjGiCRQ85QosfVow5V/cUEL5Tgt7M6fL9Bly+leOuW4iOHlvVbeXMR8ZrtKy
9/cTjL16FiJRWIMHHR+0T9N5i4z99C+bNyObMblkkOqBfTJjb6lVJKI3VuoR
qpfF7ITVCgIu4ro1Lkv+TvH2TjLvqWSDEzVQHa1OkMjtXLPnWDtYjnxvmSKC
h7ndh/JHO5CrG/2PfhrB8PqnVfEuXOQ1DNv/a0YQd7Uhd1l+Mxrcg+/MPUcw
/y43ekurEMML9gUu8iTQro68YpJXDo3uAdt3VG8svSP9Ga18rMtfVqVhSuB7
T/B+2zQeHpiP9AZQPtkBDkofpFsgkTIt6Esm1av3lsXul6rAjzdU8TMgiBgX
n9x6QIjdecoVGtYEl/KGlhh8Y+PqQ1OneTsI1i7+bvC4KwkXTN2bjq4nWJg6
yj1Wdw8OH03arKmedu+qDM/kFOGSUoDKjV8I5G97FP+YyIFhoeTSMsrne5ac
dMVJMZjiggdXHAn+WLtOUOYphEL0zI3tpwkY9hPslkMcxLvlZDjQfq2CQ52C
l79G70hpWgCP6i9rs0zvP2Vo/cmofQeC59beVRJ7G2EQ5vHqLfWzdM1gY2BC
JUr3XdVWo/OUT4wPM/uFcAkerd5E63se+azTcCwWLcYVtkrrCNQ692XYutQg
Thic5GlB/eeW/RIfBUiu8jnhSPH1HCxMiXSsRXowS7yZ8q/qqRQT90GAa/+c
cX1lTvEZl58c/V8Tyi+vvvnzBEFkkFj+S0cr5v1RIT35lGDpVmaUI2kBsZrZ
fyOP6m0Wf+nxLzX48VHDey7Ft3Fv1e1QtQZEHjg9p/YQwbtpY0bsPh6sjEom
++h/4G6Yael3ICttBVEspv5azXAbNBEh3LLiHduP1ju89mjJ3OsIs5XXtqfz
VA58iTnbVQlZl6qziroE2/pnVR2QbYPTi16jiGSCvC9vxEvONKCjPtQ61JXy
Z8HdWsa8hYJ2brY/fV/KFAx9/JSPfP9XTc+oPy/o7dI54N4CLtLPSdykeM0u
0Hi0g4M+55c5FfoEg6PqPi+rBTi6hj+kYUlQ8MB9oJdTh99ClHrVbQjmxU0X
JmfVImu5rVzIXoLXRV9zY2fXokBwizNE8WakqAryLCtQHiMlIaVNsCW+dCPH
uAkmsmu/PU4g0Ire05Xx5jWWxOYt/pxIoPvw5+7vh8vRc7gtz8OQQIK5Tbcz
0Qozo1TKfigStM/++4lFQjPsuZXG7hkEXKnlr75/eY7zkgNT6XSeoSCp0G6a
j24KciWraP6Knty30xQ0Q3u5jE23G/WH4Nno7euP0NmpM6OD5sFm2cLGDStF
WKnz53Kvi1Qf3Qbbp4QiSGunOvvS98qrZ0Qp2jVh6qDLmUx3yk928o8+czbO
nTkyFEP9/sRYv5ynJUDan3nfY6me1mXP+Wg//znevHHmW9J+0j6/V1/xKREL
rJsGrlI/mRZc8X8q2QInhWdeZrcoPjbqIa8UxDje+ustLYrnnq12j186c6Dq
19WTSfFX85O1GKwuwoqYnHViTcov50iA5QIR7sVYBZXQebjj3u7mWxqxj880
3mRHcNA6O8fQSAw1pViv2MvUL+E6zQ66IvwV4TzxKZigl/ls6vwwDxGaA7IH
KT/vxlQLzV52YPW3m3tsaL5rdj+q6D1TjTv2DpYDewgc1ZO2y81uw1hLxFeD
eAK/YY6gk9+EyYwqlgTN+2bR/amQ/a2YNexQ7JNP9VwY8VBjez1U1l/cobab
IKlSOPB5Ph+B8yzVU2jesQRbj56IyIJJ6uf6zo0EHx6JL+yXrEPYgp+adXSf
zNzwd4CTWAwt3cWNN+k8WTLmniNJNVAIDqw6Re+LfwvSW6nSCZvMogJ/ip9d
zoXtYc0F0Nc3ksum+y/MMiOsKpEDUbHamqbfCExO/auTlVkHnhBzfWneSOzt
tTVzsUfmpdH70jTPGdmWz1NX3ULWvRelOhsoX9MuSi2vaMaKoV94hnTfFJUY
8hOLOnFVa9eIXSyBjmtQfiujCRGeg9zEGIKvjfbnvO++xpZ2/zkhVL/S02PK
Z9gUwira+O4l2o/A6E/+2UfxSAiKSsyl/otXzNedbdICnzDjca/HdL9KTSwc
6amEakCOzEIT2k+9dOH57HDoyN91T6f9qW31+6N/xm1s9vsmP53mr+doxWTC
/mo80EydVreL+pGpVZbqJwJD4UjmbH/q14pc6eu8OjAVj3za/RfBjX6Tt/lG
DdhgFNq5hvId5t+uzNJpxIFtlv18mpfxs8LrFc+LwDtmMDrvOMF/72XKaA==

                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk4VO8bxodWssbXVlFSISGijW5JWsgaUkIqbUjKkqJFSZZSKERJlkSF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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41AkXx1WMV5tK2VKvUnKN1aa2Nhvfrrq723LZIZbRbaZVbxfJPaxU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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs8E4oflUoU5dJj0WPWLZHH6solcopeQl7p9SMlal4pxfUrXEq1kIgo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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 50->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk81Osb9UN1tQhtEmFKya5boujIlpRyu+6QpboVTbbkyloUhSK5LVQ3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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8le0fFhUNvRqKBqKBKDulXHaKEqmUhFRGiUSlIikrDfVSRGUlQq8V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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs8lPsaxdFF7ZKUozkqhWxCQnE6RUu6iFxio9xSSOXa2VIRNlOJwtkp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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs0lIsaxl1qbwcVcpncolBpuspBF88kqVQukyglLSEkwijbnsql2ns7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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 51->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs41OkbxrsqohxSWqcNiVLOh0qUWzmn4jdFzVZio8YhOUTKYZUcc4hO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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VWsbxpFEyhCp0ECSqKSkCbdwShMSkpBENJLUJ2VMUinCIbMM0WCI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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlGk81Isax6eoELccEk4LISpTkqak7k91ZKsUipshha6Q6lTniNRwqsNk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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk3k4lAsDxdEoSllyFUpEKG6FipAzla8USUil5eJqX1B8luZmrSRNpZDI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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 52->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8lekbxjUpzaQyLSMV2Tpji4YK/eiylD1JTKUY4hzioJR1smQZQiWN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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lV0bxVUiepuFzBolIXpJYqUkGUJkKJk6JJlDIlEiSiWVJKV6S8gc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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41XkUxlHhDkZC2uyRGjJFi8zMe6dkUCmFRpmSNDVSYWxFlqIpkuzL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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs4lAkbxoeNUA5rKRWRjZLQ4ROVulFJJbssMbFCFIXUqgaVpfnSptXo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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 53->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lWkbx3SaGhK+aWMShiFKhOx+JylLRUIbIksSERmylYyRjCxZkizh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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Vd8bxUkhNEmSOUqDTNGgYqmkUgqJokGaEElCUhooiqRIKgqljBmS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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs81AkXxkcpUqrVLiqJraSSpstKUY/cck2kTG5re92ryXbZlGjeQptb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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs41IkanpRdtthELovCkYawLrESXglNJ2TTzSWFVCpHikw3nGqxajNs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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 54->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4lOkbFhZJUUraaomyKjqQbX7IvYYcskVWOkg5TSPllJHEqrWFXQkp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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VO/fRpKKsmRX+VaEJO0qdUsI9StbkUraCC3KmogipE1CkspWSUhE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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs41PkXx2dRTNnCtlJNRSZFSy2Sbt4uu2nHNauo3Y3YqAhFpYnSZRFp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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs81IkCxUds2ViUNpI89hZutaimIptDWZXKnWgZWy037aYtjEdIm5mk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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 55->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4VGsfnRyq0+krobuECKnhjC+F0XJLoY8IdTq5Ri5JNxkPnShJykgo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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8lW8fRopKw2qRiCRUkt0vV9kqslPRUkIltJSMRCiUqChSSCVkJ9nZ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHlYjAsbxjuVSaLttAzpVEcn2boqUoi7j4RUHyk6akJpQbbSCEmEnCQt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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs01IsWxz2KSel5CqUHpURRZKiFb4eKRNEDRSUSyZWj8igV8hhSDUqa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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 56->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8lWkbx6VdKHrfY0mEwigpg4xMv6wptFpOyFjClD29RZIWVGSpkJQy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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k4VV0bRlRIyRSSkAplSPKmvN3eoiikgZSiJIQMRWkgJRSSVERIkiEK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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk41AsXx2mxVJaoCJkoS6QIheSromXKcmWpxlZpuwm3FLrKtChKCEld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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGs81IkXxodYJfmXrcmnVnchKtHGip7uF93IbjvRtlSWioxSCWFLmwrR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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 57->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lF0bl0+JEr1ljUIL7VlD+DFRkihpVYMhpGRJpYhqCKGFiJKGKLJU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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lWsXxklpQKJEKlNCKdEgleOWpE6kQuUUkkxlzphwCpUm1FcUilQq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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs41IsWRe84InJ9OZKMzlHq0AMJawhFNV+m0txC3UFCV1IpetBJKk1R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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk01IsbxmlPC6nINkVS2n5uVNYedJM1TNxKLspFF9kuJVtDCNEvLj9q
UsKJokhjiYgMhSFkGUOW+c7y7UYhSpbc+f3xnveP95znnOfznOe8yud9qW5L
xMTEgkXz/+2SI2GlseIubifIDi40kVB1cSRS9N7AV1JuZUy/ALkXgr/oqrXi
IS9q/y1dAbRSfUf2mPXC8iMZ+F6NB6OrNycLmX0oGu+NXu85gvKts5mfV7Hh
RD9PuKtwscWk7dFcaClqnn6kjC4IYfLUOCf/7VuMMWQenprlo7yq9CF7lo3Y
3QZfXNbzoaF7dMJDrBkBPoOV19IEeHxk2dMBFhu/rpk9kntrBLFnhRVhGp1I
pQxlRKvxYUc/vTrXrQqm5bkXbb4KYTjX8ukitQc+rWYtfWME7hoEL2wMY4Jp
5Fk4vVUIm5tU9aPVXWhyrzgs3cGFX0GyC5wLUGFsmGXjS+KaG63f8GMnIn/M
yU2V8eAI138Ykx1Qi06Ro9znYwblZ/MV2pC63FXi6DwPIS9qwk81c/DcWJVb
QnARGaHX52xeDH+PqMVpcxKGTPXGPnoF7NoyTx1KF6Lt4tnmdf6NeGix8VDe
WgFqX7RRWCU3UBLvcyJgkQRvRdGy+9R6vJ5YMJNdJcSk3MvjUo4MvPKfj7b8
D4llu3O3vBrshLbgPjvxEQHLbCfmxnw27OnLNrh0jCDjaXn65a9MqL7pLl5o
ECBaPGi9q2MzYs13Zu5V4mNc6vilPzZ/gOQHi6Dv54bAmjg2Su1oQdvqiO7w
P/l442Wr7yjowSYL6cB2Ty6UJ+TFujzZWBp96g5rBwF53W2KO02HcEtBUVMh
6AOimY7eUVbVILZ4hbU1CKGd/0lyxdgLhJENjCuzQkjNaY2xVlZCU+HOlcOf
hIiz/CyfWdKO7eHuYb+Z8/CElXZIzu8tHm+01rQ2EGCGHlIZe7cOcRHZX8Q8
RHo9ISb3N9bjZWJAuI+BELVFc+Le+zogtzlnSTiPQL7JjdAYkyxoLVW0b64h
kSNfaU0vqkLcrozzyjlC2Ola6TebsNHJ9B2ig0BWjlNGn3QnEhWn764eJOBf
6y3+4M8WOMu8sghzESBuu696a2AX8l0fXV8nwwc3bH2ZbuI7tKgHnbXUEN2z
bC3llzHw5S+LH5NbRHklaV63ihDxir2m3zs5Ap8zv1L1ijqRE0GVnzXmwzXY
7Pev9h9wLSVptdZWAuP3/jm342Y7BmJC2PFMPorn18Yy/uhDiZmrs2M3F13Z
7Y/K+vphH/mz33DTMGxcR/yneCyw8quSD7zgwUFXdu8enQ5k+Q8Xc7r48GYV
TplX12IDIy1ZQuTX5YN0iC2tEV3h4jvMNwkw1ZhGNAU+Azm6fKrBlsQnhhE3
VaEb6XGf7S/IETDN723LTniHyqpqPi+FB0r4isCfSzjIOJBQE/N+GJSOp3VN
mrVoOvjtF/MpAYqt/xd+V+Mt/HTtysJFPJQMWrpp6l1Qe5dqebKKi5n9Aw94
RmVIkv405jwoRPFmXbpV1mtkF0ypTHgJseqmrZKdpKjf6ziOl5P42Ka6UnYv
UYYKzzZPrCehGMkZjT5XB5qTQ6CdtshPY1J9llErJqxWC/qHefA9WLnTQWUI
QSVlUT7PuDi066omXaYXR/ZwyoZVuWDvy1976/c3qJ2/rY0zAuyitLRLyVbA
5vByHcklJDhaSqcPhbSjc9vcok4oD2LEPe3ha4NIfyBRF39qEON7n5jxV9bg
+uJjamK8EFlMel+xQikOUMcp39RIuM2c2R5EaUepn9uT51EC7KTXCwLonWAU
pOk89ibw2sNm+ZpIJlR8vqkKrYVQ7c8hNFcVIk2/zuIclcTAsJLVUOsb3Nnn
dII7LYCxhDk9NP0FDsxo9Lo/F+K7t8m2pUH9iI2kR+QucnF0Ui+6yeI91BIm
gi9H8WBnHn77pMR7nF1ss91vSiBu+O87htOl4Bw0Nc2WIEW8JlS9WKUYOG0o
PqdMojMzab/M1T6YTsdsUn9CwNDXpf2kQQu4ir3v5p35kPrcvM6poBGZ+ekJ
jwcEiPlcl5zmkodVbh2XgvJIZMUFV9Mci5AojM8gjpHoYG+OvFzdCEOyeyXF
SACZgFAd95EeOKh4yibv4WEXSyfEZu8rBPx8rTzjK0R2IkPLa7IdHqEsVYtR
Ardg28Aw6EHlkcKQUGsuFufzbt9QE/UttTJRfxeBMJW5lwMbStHpV83OmxeC
1ph3s/l7G7x+i2NZX+KDWePQqUC+w9/rTA2tt/GxXVb1F54PB69tM6w2VBAo
XGNNw+Uu9IkrqPTYEAiWa3AYkn4OKofac1GJhFR7SsK9wfegfS94oO1OwPHC
lp166X2wP0/5q3poGJXSu0fqjesRtzBKI/SF8DvzX/emH71orj1eVy4t+heu
Oq1f657B6MqR3YknSFQ8SpEaqy7AhQLx2XEvUb4eyZOOlAEco8XxtTS5UIy/
ZK8nzYGyW0vT0vMEaOLXB02T+qGVopZn8JzAvwvQy6U=
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 58->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkbl1KWNG0iGbJNcoSUFuGHKQxaSFqQvSRrmRJaNcRUKpyoM4Yj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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8Ve3bxYUylKJEUgmFMmQmyRJ6CAmlRD9KSD1SaaCBVCqVilJ5DJEy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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk4lQkbxmVyQlSETCvZypKTkBrm1udURk0RmZMm0eKiRCpKoywposUS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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs81Ikaxq1UyLWL3C/pYksUIkWPg53KQSJCSoVQqaXkdnJUkkUR2ViF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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 59->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4VesX1mnSNTRJGS5RIVFKmYoXDdwMSeM1dFFcojL166TTYChKIjdE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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4Vd3blpCIN0IRojLUmwwpMt0SQprUW5Ikc0UkpVDmIRRJpVLJlAyV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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs41AkXx6WU3dXFbdOFZN1CRVH0pi9yySUZl+zIrutGkxSVdHlb2ZIi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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk4FAobxUf3apS9Ltmu4kabNHWlK3RMJSIlVCpREiVEEfr4yL6FQmgh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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 60->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lWkbNynZkkrqkyRtMxHSoQg/pdOiVIzIUnQUKWMryyBbaoyS0xQT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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8le8fxkVJkWgnIrIVKWWUC0mUVUoqIlkpZBW+hYao7FSU7JWVFSor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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs01AsXnTzioqu8Elblpq7yuhXyqLYVkZIYvZaMV5IlQtNDEspKEhFx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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs4lIsWxknJ7vREdJVrLoV2F6FB9YpyohtDIkQyUilKTqJ2N5EukiKp
JIVxSSTJbUxq7HEZhmGM+5iZb75PV53sDtHuzP5jPeuvtZ71rPV732UYFE5n
TFNSUopWxD95tR21OyWOhxm6mZKgzzI4MkK2HTcTwmejeqmFEoGiGaJnR/Xb
wbeTz8qzIJDuXfwwKKAdShfj5mjoy/D1j7UekRNv8d9DtAnWmByOqxmiMJV2
CPVvWMxkEZi64YH0fD6Y3pKWWctlGLwUruIc9BZun218P1TLUWUjSUnZ14nQ
6t2tftdl0GOfsGTP7cZNFZszi1qGwR1wizQL4MHjD9F3z/1yiLb35Jct4ULk
arq0sIWAUjj7Hv3YFTRFJ5XunaRQY/N80HCJEDGLdVReMSU4YMI9eNS8B6OM
36rsPaQQfsib86akExdoswabAmTg3zAstOurxWKtwAM5NBL2Rb6qP4wFoDtc
9VpQLMVYeY1rkYoIPgfVc7f6D+PknS/u0WnVYD0ueNyRRILrzG12yfwTbVuy
Zq0cJUBvNR568fAt/OKXaRisJZE1L0dPdScHhac1XrjQ5DBuf98d/rQZ1TFX
vSxCCZTo3wqlbBuQLJoTltopx+t4r/vfP1Uj94db+tQREtGrTAwNd3GwXmOD
jaFIDq7u6PXnH9+gXyvnhMlCErNPZG/UHurE3rtPd/X2SJA0pj1qO8SDQ4/h
4fBAAsFr5P3SoBqk9SfH9p0goTaWkH/jWzYmJa4F/8ui8O/03ct28XpQY7Tn
uMo/9eXLJg9vFMIj6u3+7GQJHKSMB72tLxCbvDCjdDsF+jn2gLzuJWgbfO7+
Nk5CvCBgouHKczhXSSbeb6NAbmYcG6ruxn3Dl9/c5Yp+J+OXjo3yQdU7xdss
lCGmUPAoY7wXu3u5pKWJGCmLydRiex7mXUsOqdqmuKdkmYPW5Zt4uSqqh/cX
BWaus6U0QoifQsbTb2oSnFZfeb3eJQcrn6bZ0J5QsOma7eJ5uhHzu203z2cS
4LZPWFm9acTQ+VRzSbyCF+WKfft8noETlhx2kE4hQvnI38/JfOS+6xLQr1FY
XTjB/njoDVpdVYeq5pLwZh19d55RCs+sEIcNRhQcH2gbL0jnQ2+Nauf4RQLb
tYsLghJacCzV9cTlxQTusPyjMve3gNUvb5wal6GlqU3rxhU26qNKi/YtIaH0
IHxXwNcA9IaUOZXojEDmf902UK0JAcHW/2riE+DTj90L+r0OnxiJB2YnkHAw
Xl89IzITIddEXZEcCrTDe1Q8HwtQIoiJDM6ToaHiSmLd63boJkVUx2vL0eoY
WtZQ2YE96stMa+5IEai/JaPzbB2ye33OhV0lsfrLnbgRszJEL2dkT19E4T8F
ThstrLugWvbiO0tTBo3LzN2EcxaK481sG7kUPHeynuZrVKEso0KkySbhcu5n
XttWPnzub65L0CSw/EXffjt1EQL1Zu/ocpOAH1ukk/cwD3zlOkH7Iwq1kenU
+2f9yLRTi6ltGIZo580ZorZ8tAytif94l0Jjd826AwmdeBUau878qAzGxlNR
QUQfPIturw0IFqPf6OtB3pMOrPVnrCvhSKFRK6T7e+bAaQZn2KCMwqncfO9T
XQJYf0sq/ZkhhdKvi7H0JQ9wMdWBMOdT0DAa9IjYw4PB8JSFkVwGA9o8U7VN
LeixIv3TKgk8PDlya8ClA9pbVG7puhMIVIuT+D2qws60AHIqmgTztM7rDWcr
YHmJExLVouDBzP2zdTsHSZU9PcbBJM5vifWttY1BOTcmIUt9BGK7/o7JCS6Y
BZE581fJkb1L9534ghBx6zO+BinmiwjXHPli1Ypxv7ljSTvkYAW+TOFs4iPJ
kuUx4iLDTcEKsyu/BODGfNhUry6FldqTxAeujTC0NTKd8CXwTtXpVqppJY6f
nvr4Ol3hB02fC5nrhPhROim7bi0Bu8BdX7yiDeo7lFda18vA/NYXa7NChNHf
38F9kQTJOya1qgNfoV+ZiFzVScLvwlCC9p5OmN+PdxnXlUJtuq69e3QHAk0P
euUvIZDbXWM6eqkVfUmOTB+ODE4eh1aQxd0oV9OL4fhKwFI55RtdMoAIt7fR
vLBhiH+t/cT3r8T0VxF7byn45c8yd9zBLUHfKvGHh6BgkKB8v86zADp6bIN1
JxV6e5/iNc+gEfZEzqWENAJXTSIN7I8040x2xcxUczlGOcHicM97kBWuCBf0
UsgIzND0Zf2JmbVXpy9W7G/1m0RvZhoTFdP+kDVdpvChp3KrnokItEraGZ6X
DEKtvpfN2h3oon+x1GyWQdmrO9xtYS3ONg8oD9eTSMvz+rHelY3MMd7y29NI
GFdUJzIG29BYtOAvHQWPTX/X5zi+b0Pm99C4218U/0Emzp66EIl5wvJYqdYI
EtVO1bg878InFdMGHwMp+ruVzT4ONsN7wCq0tF3h5yY29GmfX0NjdKlnu4BE
bTn7F025Bxkb+urPvVLoU5xzLIvpjIKTBX4aBiP4P8nkzyU=
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 61->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk81Okfl5UslUprETXYIostknG+/XIVmwrrTn4jWttUWEpCihylVpFZ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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Vd8bxYWkFFIyZKqkSUVRKrVMUSrJlCgkUVIoIZkqJE2KSkWGiKTM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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41GkfxtU7jhFJKryF2FpvRXbJVroJu3a3KB1Xqs1ZmJR6KyqHhpU2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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs01IsexSWVQWWh6aWFGxNSR3KkmtqnUqYXPURTnVIp6eFVUqEkXO/I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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 62->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lekfvRTtkigVkl1ljSimQyZJ6BbTgmypEBMVoqhkKdnK2iZr1qyR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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHk4VG8bFkKFIiWqH6lkqyQtVG7aSAiV0IJIElKibCVlCRVKtkihJC2y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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs4lAkbxtlaLSGnQmUrq0KKbSkmdU+bU4xKKOUYskokKZJcRaGooXwO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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs81IkCxZVHcodIIkI20XqUmIS0ZyrW8255JEWJPEoRvUhkQuQZlaK2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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 63->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lWkfxmnilSTjUIqmFCEkayq58NornWQvJSWRiGRkyZJ0apBTUkmR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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3cg1W8bxk9ClEQDJe0im6Z5pUippEFFoTSULYmXhCREGSXJz0oZIXtn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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41Ikax8llpctGyiU1JWlLLm2DOPJVayKzsaEolXtRp4tiDtKKk+hi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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81IsCxeVKeo2hUCq80Yqu3etOXjnetUylNEoSaREVCU+SpCypJsvD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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 64->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk81ekXNiaayVJZIimUpRpjnVDUU7Ykykg3S0m6JYUkGltRdmGkxVKJ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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHc8le0fxymhVEZSVpSnohSPtBQfoyFKVkSS0RSiVDwlkVEpSUTIloZK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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlGs41IsWxjUpRaSIUi6F9oxyShG1yzud7JIkx60eiSeXTcrEVoZ2kQop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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwV1Hk01QkbB3ChIaVsWarJDSHTIqPd9OUlRaWmcCwxKuQiJCJxbU1htKhM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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 65->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lekbRpImSiohEkqULDMqWeZOyVJKI4pSI8leI0ujUnFVyPKbQhIR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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lH8bxVWU7EKLPUUoNYhK6khlK3tKi5KIihZR/SSpiJDSIoRkSSRF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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk4lIsXx7UQrkqSylJIRZsK3dLyzZJwJWVJcRPJNolKbrLkV4TiomtL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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGk8lQkDxY2spdS8DUOMyhJRXGL0oqNeW8iQ6rYYe1knphTRFKJMC0pK
tizJkq1GqKio6yLLxb1usoy7PM99KIWQKct4P5zf+Xa+nP85G7xD9h4VFxMT
i1jS/12s62pd/B5PmK1jeASrjODW5c/+0m9aYfAhGNoJJM5dsZAOye+BeG80
fdKewOWsC3XXxXqx5uaX/uYxPpIv9CkcWewBTTp8rfc/fMT5/5aoYslEfKHC
RDVFojL5m6NvZxmiXhF2P++lkDNZoO6ozIL7Eftgve0EXqu1yE059mIkgJqU
bOXBUnKm7cu1ZoSs03MLe00gWsrnGM/mCobC3Pq9pim8/MOJ0Hx7C5/j5oIm
OBRqLzbFllT2orzmjY3cIx6oTJ9dp95Uo5xPz/D9KILMvGyKyOkpLGYaj9ML
RYh4kgu9tG6slThYWTIugJhf0gbThAD0SOrbOCiN4EOnwQPJ3a1Qn1cN1I0h
obKYbrJXi4VHU9bOWZeFuF9vljXt0ocKGabZNXkeSD2Cm+3ZisiwNQXFh0ms
vWnE8aI9h4Yjfev5PBHcigo+Xhtmw8jc3El+BQHLE9Vqrka5ON2TdHailkLi
mkMNCdcqsTBdo8U3puB9yCv4Gu0J2AHZ+6IGRdDgRR/zaHqGosN9f59aFCH6
EWOvfF0X3ORsVJm7hUiP0ZNN9mNh1GJYY/8ZAgbzgcvTaB0Ic/VM8OoSotJ+
BVdDux4fXJ/cpceIoL1SvcIwgwH2dQkXMTUSAS77xtJz2VD+LrxFliOA3CXa
ELWiEYYZNMY3cxGsnKKPpUl1IfHLgB9Xi0CzXbnrC/MqPBpo0q4BhbCW1KLH
Mc04qaNrrfyKhH7G+1laTzdcnmnnm74VwqbUbXFk8i2UqydH6dsEcNRprI6Q
ZmFFj01OOkngp+c98rw7HFTLujx0ESMw1bLAllR4juTS0GoJjgihBfq0U3fi
UbVxcLRy2QiSlymXkb4PISzv0DdUpPBsG2vLt1EWXssRmDMRgjV+4Giuaj6k
3F8mLj5d4m1Q2Xp1zk0kFzL6mkQU7BfPbRYz68ZKzY3HXbkC/JgYNl7Y3wWp
G1f8/kwXoGomI8Eqpg1TR1TX+nQIsW2g7GLD4QYYioIExn+TkLu4T+9Gaj0C
LQxjlZ4u8SV4GbtSkQHnpH6Dq+0kPHM/i4bFW2B/JcO9vYPAVasdgf3nu5Ch
5qaTMiRAlJHxVhlpLuLC470NQvgoMs3caKdRC5oy961srQi/hGlt2nqChanF
/aZaMQTYQSEFX+71Y/bwpQYlDz60JPRoWZY9CFimQCvZJUDRovIZh/kOzIYv
DAmzhEhx3h7DdenE6s2iwHkPAoLAVlkLOxb+K/dyYP17AuVKxVOKGl2QTt2w
f/6DAGaWN0xtDzJxKNhE89YjEs1FEwZVfzagutPRsmCQBDs+csZ1lIPAzgO2
Ktl8lIyOdw06tyKisDa125bEqv9UhNcpDYFfI3AIrB+C1QTN/wSTg7Wfg33u
F/OhEqvNZI+xkFMtdcxomxDrK/g6xv+7jvK5+V3hnyg0dtil2PzehCpFxbRz
IhJ50aYpJs/78SQuabpfYRjmmiYv8pRbkJ5pPUp9JGC1eUekjnQX5B7e0+IG
EKBco6qUWl5ilLE4Y76w1M89D8mUmg5knq3zvrPUX1joq0TbSgYs+pYnPcgh
MVCm8caE14BtYVO2T6JEMKdtiNTNOY2vNxzuHv9+BJkF8n1PGUv5pY5lfsuW
9l97Xoyf2A4qMNBvqEkIk5l3qo/XM3D91zjeMn8SPx7N+WFrzSukjLkWM/5a
+rt6AzfzA+14x50rzWsXwisrpiG7mAV2plqft70QIbppW9pyOYhYoD9zaRTi
U7OxDuc7LoZl6cayr4Tw33dgTWlAE5zV1N/vnSWwfoo9LE++xqoTlnGmm5f+
ZPd8SbsbE/Wi1B1WZSQO/mA0/exLD+rvpnMlygW4PVhpaxnLQn+o/nTKcSF8
2T8d1M16i0++HA+ZLTxoLhfltXzgIlV/pU/2AwHs1P54OHG0DZfKFVxMG0gM
P07avUe1EeL3dp7RF5LIPFoR35xfiIBDm9zGLlC4qClbv6p2EEZtnVeyvYag
vJGXllLRDVLc7uzFX4XQNpT1Ld7KwdVBKq+Gy8f939Z5jeSzERR744xDtxCR
9k7/9LW/xkmp+fDpKRJU61PVsdRGrBafgtImEVRL5A4W/czAuZ8u+CTQSey7
7hfg69AF7zp590RZIZwt/MVKfy9DSoTuC/UgCrvCDQqz2nowJHd75DNNiLry
NCX10maEnjq0PNaFhH/H18i/1rUgTi1/8+lzBHbuMY53NuvBe9NeZvxOAtrm
nvcpp9uI3CjjOcmmIDMb5b6F3oBQ7zVn5WdJNBw/8LDm+wGMmzJHymyGwdJa
kXZ1rgnMd89t3oWTYH09yZpp6IZ7bxCtM5kAT8K6ZYzFxO5ua5XyxSU+q+bG
0xaawa5SDC3NJuD5S0bj9qIMVF24505vpfAv0QfODQ==
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 66->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkfRiqDNvmGiJAla0iWpDuh0ZcSSUMRhsJEJVmylyVTTNKYHBGq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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHlcjO0bxYcWRWlfKSQt2kmWtzpJZHsjEiIVSrRYopBXGyJR0h6tIpSS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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs8lAkXxwcRFeKtrIqlrFQiklvys+liK80mzYoucilFaT9U1Btl1U6l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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk3k4lIsCxqdpc5SjbLnl6KjDnYOOOZZouV5LSqWypSmTdG+Lji3STdFi
aSppQtluEZ1IKkmKUsRgMIYZRowZMcs381FJu6TjzP3jfd5/3+d9fj+zf0f6
7qVSKJRYTf7f9n46ZbWVYrxe4Oh7302GNXkBCWLrHnCUAWsy3ZU4aLiSJ2ot
RFV9ghZxlwR/W2eybQ0fwbTXG0NrlRgVJEfRM9tRm+u0hR9G4LBb/P2TO6th
Pd8yLnEmCZdXRScLduWDt5Vw8qkiMelkZZ6jzcMMF+urZTtVuNOaq2Us5mJb
9RGj42ICzPBXl9lzhBAEXlHbzFci51urxzGJCPfDLXXsx+QYv5NVnJ/di5W8
++UmahmcDG/XuG7hw3KV/Z3m+QTCbPXcbRhHQctYVTRPdxhLXM9+XfGoC0/v
LbRVcBWYKBxc4hz3GNhK96oYU2NqqNCkLl2MCtoWNxlDgWOzzQ+y/EUopQSQ
D40UuD6trOCfPRI8q4udkREnA6noKnvcWA5FxLjFSiaJYEruRrVFG1KNr9p4
39HsJ1JOp473IaGwaP+IZAgJzIANi4UVWBHRLX3nTILlmpf07cNzyL8EkI66
akSRM0qqTpaCWugca3yaRD6xLL3xghBvimxMf+IrsUTtab5uFwdGBaxnDtpq
fLTxKRfNFsLT6u32PWZKnHa3u/aI34wyB7Ey7LUK3Peeg3OrpPDxYo0GhMjg
vTPC/UBVA/ZtDHpp0KkC29FUIY3qgv+H2VpphgSqVuqRF5+LMHIqp2jLESXG
rTrfzf3ER4p+0/6RdSrQ/5JRrI8JsDDGzUKyWolT/9rhNlUUjuKA/kuKBcMo
6T9QJpC2oILl+8CVReDQ0cZNh40koHCUSUZJchRMrjxBN3iC8Rfbjx9OViMm
5crYpmYpOP6Xop9PDSKE4zJhVSeAHbv35etsJfoZfh5crhAf25Ym7JylROpa
AT6f58M0mRVpofkjcCkEh1ZJEC1FmKpJgcgwATWr9wX43Mlsx6dypF02fuXY
zUOOUDawzJHA2IazhMOVLKRTWyp1JSSOEF0qlq0Iuy7nh7LXaXih/zc6ybgP
LkFnPjCdFBA0/GhvJC5BFjnMk7JI+HUv4M6c6oauh9bMexNyeL7/4nj8Qisi
osde8T8SID03R43EN6BdK7aJ1q/CCQuDhxGTHJTkKbYnnVHhPK+eHjK3Dzes
gksSh+WgbZaXSSarkPGVRv3huxpUr2nqY+G9MAkmH1H3aHjXjXVJdGxDmaGV
2ebzKgwxEtvkmZUYTWfl2awi0b7oB/2aUSlMLpYu7U0fxIIVpabNpzsQ8nn7
BHtECePAPWfLvG5hwjamfncOiRs37TxG/vMMztTc9QPuahTsHf49fPE1jIbq
2MXUkDCsF83r8evDrRORbsVblfB21vU5QyZCudzd58zMYWzgeUotxQI0LnJy
nmuqwrGKLcsfLpGi5eHu8tsaX+gjjzxK45qQz7AJn+OgBuVJ7Y2OGgFqmlyr
iysJ6PoydN619WGslYuoPTIUXF/veDr1KoLi3IMP9JLwdjr3a2r9E1jzrNi3
GWpYZ64zPLCYgzfLaTtXx6jhqfzT79xCDpzZXIelN1XYFN+9z9+sC9ybvkc+
n9DwWrF+MHLgCR7Mb2fPClQjv5f6cSRCALqvySqJC4Hvd6NKolvECEod3tVM
ylHNDiSnEiuwZN9PrVeXkejYUxwfuug5WrWo2q+L1fDerzU9yKYFrxKjr99m
qkAJPjn7H1WLMN97YG252TDu8uThxt+E6FtN1ef/QWCimIy5sluMwZLQN2m7
FaAtTHl33rYBaXZvXoTtVWMHwW9jjnZh0LShRHKewHXFjH2LVEKEhAx4zKpR
oMIw4CKrVYTsfm+3zQ1yGORGqlu82sHcXdwXmqAC88bbywlDHGi7xO81eafC
28nKQx2X+mAZRS+y+CSDUrt+mtfPz5AgTHhv/VKNxYdSshKKNXyXpvnUavym
GL35tfW4P35sObLunOkwKKeeDpQvfwhG5woDyS8kZt6Af8PvffAvbAwxTJKB
ltbJJ0oyYP748FenMRLzhOJtn9feRoPTrQsr4kiku9xpMme34lCK7aW6DhVK
j/6Wee1wD36TLdP/azEBHWf+VLKZGJbh08MzXZSwvvj9F4eb9ejcq2Vz1UoN
p5D7huzxXhyM6WGM6irh6WBvoFfNRcz0jHJXbRV+Ts6PMMrNgu7l6wvvKUik
+VfaPW7kgFE0p1+vToW5ZlhqXyyE+Qvvz08qFfDW3sD38OvGYH/J9PZ7CnjR
adfyHreA+nJWR5hQBS0pS3mCqEeqyDuri6lGs13g2oI6IbZtantJ20GgNpad
wTjeB53xTuEtfQUm4+cpP4z04M9PXzi8HxUo8JO59tP/B9G1rqHwNhLMjvcp
z2MfIe8Pv48Wthq/Ai7e1QqRoN426wHLegiiNfmWfvwW2OkFCUMzVaiuqJtH
sjrRdVSvW8EjcCpHP3s0OwNMc5liSvPv3ybo0IE=
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 67->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk41ekbxmlMe9qkmGps2VKmEdlvkWXsIUoqmnCSvdLQyVgqjaQsFTFZ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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4le0fp22EVyRkRCTKqOzyyYikIZRCSKQkoTS0UFSyEqXISwMlQlaH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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHk81AkfliO8pdBhVSK8WPdatWTrKb3pcjVS1s5utqW1sWgTOapxW+Ql
5bWlHJWGqEhEkozbMMMczJgiRX7HJKHd1VY77x/fz/fP5/OcG46EM4KUlZSU
Tinu/78497hWgk8KEiyMJ85vIZDhM1ya81AI9sQPsgIGDdPT404dZ/ow5Ve6
fI0NhVOMevt+hgy6xHiQ2FIONDGVOXQ/tkSuLw10oTA87+t+RLMXdKwdK0aH
QrvqL9W2eiN4raw8OnCPBj9kQ6q5gwBqpr7sqEkK5xqShUK9Liz7r5/Un0+i
4/G952w1EX6Ntarn/UmhK/DdzLUVwwicZuYVVdFgNheVnFknhIPJWElQMI3+
IJ+EaHsJPHzyG163U1Dlmci/a6mF9kqpwQ8TBI6tu5e+4DCMe1m6ukuv0uCS
Muf4HQL0mBh6LK2kEKxzxXn6rgAMS/Pf3g5SiCj3Nyh1qcEOTlXZ9XYCNUf5
ArMPLSj7ev/y1jAS/NI23QWZGNZMTc7jOzSEj4K8nmj1wkgsahS7UphOe6lu
2jyIuFfaj4wfUUhzCvs4/YcUdu89vlhymIaT/1lKXbUDBz4kGuT3knjmmXtN
nTEK3/kiI1N3Gsm2FezX8/exLrJGNPWRgPGXOTpFma14voZfzTpK4ryhf+OC
tAvBPmrpakMkTs34SHsV+EtDH7TH76WgbVjZNHawFBn+V1KVUggERn9ayFvU
B7mXeq/gGIU54X9ie9MFGE4W96Zq0Ri81bZacFkA0w9xxvqfKLht42SnxFQj
xLFTJOom0NSecuF0bT/GrGd3Dl+gYG8esnVaqw1sN5Xwyn4Sd+cLk0iVDqyO
Hw/lD5DQGI1rryh/gIiCyvR8MxIXjrrZv5oTYKb/8s5wgkL9riNlqnwxMniz
q3u2KvTwW5uRzagFd9VHM4aCrwPn33cDdMXYrXd4z4+uNO5q9S2EBrQjw6Mi
2lmBZ7+nn/EiuBvflIfGT2+gwLJruuQ9+AB1KqGbJRokskpM8vwhwXbPkg6z
JXLY5xoeab5/G7ffefaw2xR8rF1rHU8IcV+PjB1fSYNlu3tPYGUv3t25GiA/
TsFyFW8y/oAE2dlD001XaCjlbyo3YD2Fn37MK6coGvYvzq05dbUPK4oNCkIU
fp+UeQfH5EqhW14blrafxvmvC8YLn42g6613cjhJw9bEZJermRinjeL4CQcV
eI0RA5Y2nejSv2nyUkJCj+/pNjLcjkHWPoasgsSx2Ypf0xNzUFz2Vdj8XgKq
h70yK9Yo8vaeafm7lAKT+0RnKEGG0k1RgXEGcqwZKKmsM78J3o+T7OcXCYwh
vcTVoAwW3/8WW5JJoONl/ZimmQCaNotjmh1oTJVZaT5tGcTWy7o8Cw0av8sd
CJInwfrZkWyVGBqLT7T6Od/nQDvaIzS2nETcTOueLXdFqGu8bbaqh0LLktHE
Opsb0Fi/bPV0DgHll7vN9Zo7kBl/9ZBnIQnH/fKDLlIhKsIf0UNyCkYWi6Zi
H+ZjaaDRacNvCRSfyjSTatUgavTSbJKAQMuhUOar6mZUCRdbcUJILBXV672w
5mHY2DJNW5Gns/86Y2S4VozG5WmdvxTQ2Kmz3Tq98D40aku4f08TKHhzbu78
ZCsKtmV01lSRYF1quUpPJuF7xxu+g5sJyIZ26EnZ7VBOF33b/ZREXyb2pHQP
IKpo66JLXhSS+/RvRRb34PF45cViS0WeYkZPipPOwlGr7fjKTQR6jHnJ728I
sHg/6/hfXApOxdlWXZ96oeQ35K+ymcK2rBTbv7/joHUkr/ZSLAnuksyG/9ly
4Rm27A9nDwqujfFOGz1EcLf9xNB6SMFb31hy/FMn9sV6X9ysR2Hyp2xJ+OUh
pGlPmu7lKPZVzOyqiStB9EzAc/8oAsF2Jzo/OyKBcm3mrY45Gi18UnvGIxJt
ByfUGuwIvPHJttqYXA37GOPaTBEB1rWsm9a+3fD01euZ+JJCJFP2YnxVF5xd
kuQB3SQiPvLevyAfI/XNodSfN5HQ7fz5wrHqIcjuaeZOpdHI8tqaEmFdB068
7WcNWiTw+iv2ljNSKNc5hyUq+pIc4qOiU9ONsV17r71ToZB4xe7ZX3UyWKy9
rjTvJAfLtV457E0+1hEhc3lMAn9WeI0Id3QjqOAA6wmDguwWV75oywiabf4I
LPxGjpov0kYS1g1jhevuOHchjWoN9WYW3YXTH7xadnJIeNvMHDK6Uok0TVGO
eg2BZru6yYDIATjmeDPc+BSmWl0kY5oVUJlwz1UuV+jRuMvc34oLo0fn3RoW
SDyPSzy7fsUQXHyOipOW05hjHd0bpDEC2U244Zmi31oRpZ9/ngpVruVi920E
PtYzD92kefBvKlKbv67w947NsipxIQ5LOyQPfyLwNkPfZ+MZPqR5xQMGijwc
4Fs8sOuWQFqw3b5zWrFX7Kkq3X1dSI5ht3gr9ImPfmM0V8RHsnzWZtdJCln5
xtxIp2ewnbEId26h8Q/qutVK
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHtYzIkexhsqbGiUiujCpqPVslq1ieOd2lK6UPIQORk5lDDUJjXoxhKK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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 68->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk4lekfxk00uZSUVJrBpChSmCRmLDcVWdLIXgojTkV2YhSpjK0OqsPI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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8Ve8fR2iQtqzMCqGsaPFGKqmUkRTZyipFJKkolUSkKCOVyigiZG8R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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlWs81Ikax5FOpCyOppUiUo4G2crIbus3WWFIF2sdyrpt2Sgqd9WJnC0r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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41IsexifjdihuipTtNHU6LZRDISZ5J0tESiZaRXErXdGJulK2NtVN
iqTVcmS0MIzsMyUMjRgMM2OJjFl/Za17r3JIZ+4f3+f71/d9n+d9P8/zXXo4
wvcfGiQSKVo9/9+Hq9aTOUZC2Cez13lPSTGcnjKco2rEqSStv+sPKuATF0en
iZ6hduZup9sxAg82pyS4DYuwJCrdPW5yEF+GHM0DvJox8R+Z3Y16BY5f+fCO
Zd6JvkeH2ie8ZDgzFHHAZF0X2p0063zCZSjVbY4+4tGAw8SPrdbTSrw7aH3L
pb8ehtoHw7NsVPCZIyH7hVchreza7Jo0FRJK0h5diz0JDxfu2jmLPkKLeT1G
1FyBCc3B8TUNKhRn3U7NZr6E/zrxggAqAV5jzPs3w03gTUbaTGYqQST8qI5q
qUH2yUwDJ7YK0eFzo43FQrRm9pNmbVKAUXnbJ3ReB1ypm/N8tBUw7b2RErmM
C+ste8NvByhxrI5CrRR3wXz+HNq0tRzGjm6BNY3tiPQgUeeZKOBxLuROTq8Q
M1X0S2dTZIghFdd6N4mw/Jt+eSFbjqiADI+Mjkbc11k0GcFSgvfEztetsg3j
TCdjIlAOCh9PH3u/QHwf3tAuEODSaTtd6Fn4tvnBfZ8OAva+DY68sj7oO7sc
Sbopg9Y6p58nf6nHlIb/kQCxEuGUgzqpz+rhE7bWaAlTiYHM7W8XFgohOlSt
z8qQ4YPiuVabnQCuVvm+hJ8cPiN9TfwUMTQ4qYa6jlLo8uND+RbteBnkHS2n
K1HeNHb519U9qCUvNFpjKEe4VpxGxZouhC7wXpGkJ0epRfX9Ou1aNJuHZuQN
KNF6lFalfPseJo4WpmYMKU769wSTjYsQPrKlodKPQJv/7W2BozXo9v8cMRmv
QvdXh8ntdS9xPtQq5OMvBEb32fEZ7u/wKT3xg/URJUi/udiI9R6iZoVG0ZMu
AhyN2gMWaVyID1psKLJXoWDPyCz/iTZQJ5O374pXgLAcDfYo44D/+HFn/gsV
HNt4loZWraCXbXWt3aUEZfj3z1nm/dj9e+NxqbcEBdWLeMdyW7Brtpukf0qO
uxdOjSeShVh5WmAiLZDjhsAqmrmyGWEJttyAswrcu/lq6vtQOb7MF19fqEMg
05X1/kRyJxZVfzef6JEjqP+3IiPzXAhyecaRDwm0lDKCh9i9oMx+cb02RgIb
SwtqzsMekHbbbYsVSDAWnv+Hu0EnaNmm3c5KOdoJ3djz6S/gqxDuSIwnQGw6
dMxQqwMHChkO1CwFzvi7smLOiVFgU2B5IE6GVY2Jpattq0H30smo+qHCp5qZ
xEeH1H0eNdR690CO7FpWbop1NoyHmJlJPAKSqqrRn4v4mKgy3fdKzWOf5pJ5
o408jK5yMruwWAm9b02lR9blQXP1nk9fUgj8edeU/OWeAGnSLLOkYwrQDB56
sU6n4050vsG+TwR6ToqqFo+J4GItqugLluNO5H+X8506EdHjHObQLYfBSb0n
G1Nr4bPRZEWZkQqUIGfajh0CVF5exv3XTgV4+VXLbjKqsZ78zzstsSpYbUvK
I79uw87WWxtSEuUoSTBmlP2tA3szt85YNMtAmkpdYZ1biatzbo3RGCokC195
zsurQNA2SeHoGgLtYWXLvbtz4Gk4/fwai8Cb/fX/7rxajtbQJD++RO2v0n58
dLQEf/CJKfJaAgnRyVbnlrJB39LzzeyWCgyr5XqbGjqxZa4nJ0SdL2dDGj1z
cR1sGMpN386pkLupONt4pBdNwSXTF/UGcX6g/7PnaRY8mLYZ4ZEE+o6fbv4u
EePOPFutBmcpKPfCin0134LicLTHhaTEeO8XbnJsNmYbLDB9ou5jlencqHSe
EOn67rt12qTQYdW72S8WwXIstj7vtRxr90fYmoXdwniwsVAyQoDxkmrbYs/F
nFwv5qMxJfYICwvZPvX4czTQ8vl6FZ7e2F4RpxDhnmrv6RgLKe6+uu8k1O7E
glA7drJQjqccnRNli7tQ6vbT/HOnpLCotG+2YpeidWN9tVO/On/djAbGi0o8
Kib6c9rVPIUMDcazO2DM6fbgRKnvx3Y1rqBWYiCOKVj6QIUZ7zyayatKbP+1
5ZTnVxXa1xvtP9reiF0UJ728u0psK5Ikta3vQNDHjJmsfTIEKdnTRZ5MXAps
6BF4Exj/Ljg8nZKLUtJ3/eZ0AsOUi/4hz5tQoGHjOWtEgUtcmzBXz15cae7+
GtoihaHfzGdvg14sn6w6ENkkwVPnCm16DQdnrpbtILxUeLMx/6xQkw8f5cuB
opUKSExSc1eRn2JPzkXDPrX+eFeSA8W9EIN7KV8DYwncSMvbNxAiQpjnT3Ws
Vik4//s54lBPE17XZOQbuylQSnaauCguQ5jDUELwBgIlO/SvlK95C7tn7gs1
uEowP9HO11wW4mrB5N73xTJQF1ym2J5vwU7DIi2B+h+QpLJhR7/7KKGade/s
I9A69kEUr9WOB1uiysUn5BDohmVw+7pAZ39dFBgvxV8U7M3b
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 69->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4lOkbRksKsynS2kqWTg6VU47t3QEVQsoxh3LqZFOxbVGRQglhpX5D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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk4VW0bxcncIEmlUqZCSAhRWEjSICISklSSuUkTOqTyGiJJhJIiKlKZ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81GsbxrUelVeiaZE3Q0nZjy0KV05lqCyRkjjVUC+pkDinslW2ciqv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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk4lAsbxqWNRLZOklAZOXNVHJIibnzKaRuiQmkXOpQ20k5pQsun+WwV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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 70->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk81GsbxmmjhUo6DUn2FopSKS0XUkfIUhgvWVJpeUVCKKR4oxKVFlIO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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k8VG0bVklCe6kkeyKylLcouWyVNgml175GWRNRUVJUUoSEIgotlCX7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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHs4lIkat6VSqRRNKekikiPpyCCTX6Eh9pTjhKQ0uReSGjQbS7qQS+4h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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVWlQk4cWRUWlbFJwBJ6AWKk1CFqbUgoqh8WlVFHEDUUQUCKKCqKyiY4F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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 71->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8ldkfVqQ0irGlRrokmlJUkmh6kJBQ2bONZMlWWt2mSEmFomRncn+D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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8VW0Xxg2RRpJHVE+RUkRSJ8l0FT0IlSRFiDKUjA1mQqZkSCQaJIRE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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlWk41Asbh1HidKxN2SItlDqIkiZLP7IUbUqRIg7q1DGhzKRjK0lFhQon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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs4lAkbxqdySotqOtpWipCIUGlTd4qSaDvKF8VOQjVsSzmW05ZcLdUY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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 72->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lekfxpWKjJZJi0z2FlFG6ITolhokjK2SsqQsjToY2UJDqoOULKkk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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4lF8bti8lW5K9ErKmJInqpkRRtiRpsYRIoQihUhFJkRRtsi9FiUL4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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk81Akfx6UtRTlaukyKx9qiw3pstY79KBmRZzto00ZEuRaNHYMnbQeJ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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81Ikbx6W01FYkhIqOte5Nh9piPpKQ2i41bFTywipnrhWt6KJWKtUi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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 73->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8Vfkbx5HKlEJJKZVQGgk1ki0fhaKhTF1mcH+Wsqa4lnbZUiZLibKM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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8le0ftjIqUUZSRlFUkhUSLkkoIynJyFtGpFdRkraM8kqRVIqEJElF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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs4lAkbxh1KiEhfh++LlkZ2VUKlFZNbhmpquppUvpR1qU1NZtIkX3yy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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlPk/1IsChi0l0YKKLEUlTs60neIYy3lVitOZJNGVi2SNIls10TIXN0vu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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 74->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4lGkbt1aRQ1FKW7SK/aKtTEUh+bGbWFHWtw7ZRBRFydYUlTSmnEZC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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHk8lG0bpVBEUZJCWVpEKpRQX0dUyhYisqSkIhWJSJRCliyJLJXySij7
kjVrZI2xZpmiLPM8o0QieUvf/f41v+c393PPtZzrOueMlK2T8ZkFHBwcJzg5
OP77LGa+ZG/fwsSPqc3SNdljUPnI4f5gXQVUxz5V9AfQ2J/c/Wx6sBy5DWFV
x19RSOh359bf8Qz0NTPbGkka2Usl702FpWJGPUAkYh2NkvSL2nXmNciz3BHS
PUGBf/mqxH1x3agU+LX3/I0vGDeY07vl2gmbTcsz/abYyA5N+luSHoeaFsum
lxtpVD5wdVCPycCP3+vUr3DQyCp1ETodko87E4X/zs5SYEfJWonfrsIfqZic
u0E0PDIXiFGP6vCL/43/UA8N+ahekdHQAnS+vHI+U5C8vzFoxudiF1TyhwWC
tdgYv6z49rYTA5Vuqm02AzQ0dJ5L+vQmIXP30FWzrTTWH67jUWVU4ppXCX/f
PxT8X/z8NS3FQISJUbjZOjbMpZTvDLcUwGUuYXuiCI3MI9a3OfJ6UcTdm1ev
NITGkkv77r7tw/05nj0XXMdgbisxsWxbJ7jffTh4+QIL2Q77c9VXN2C3Ru7T
tPc0DHmj4JH7GsYaKZHXHMizLb1kkVQDKmauFn4cJPU3j6wWXtMBjhTmJ3ol
yT+xx7XtZR+uZ6yWH24ag9tBp0a1pGYkLjx19qwCeZ8xE/G8rwbHyi980fCl
ke995soPlQbY/xV6pdhI6juvc7hf6RqCtbfYlkrRmPvzUEywrxP8/mcyWCco
DD7/GMKTH4VrfHYe+rI0wl72GWZm9GJmmc71hSakXgV3/6o8SQSPRuPgZQka
aZubFie2MvBdxrAhMpoF594sUbMnmSj/32XhxH00nNHyrTCsDUKuoitGbtCQ
lZKbVkrMhbp1pPfUQfL86+NNF6oAwttnKfdeCif7jZ5qKwej+NrYen4Sn3mL
2VJ747eQZ9mleRuyIbL64XevDQwYBFWtms2jILhOtbiqIgX53Eu2CE5T8Pgj
ksIwysVGw/aOrv00tp2aqDDo6MLJa26LvaTZUP8+qL0ppQs9fQIJ3Yps1P9k
tomvz8Ngm3ew/R4at2PlqqS03uLXCjvl/jM0Tl7M28k/W4095yQ2n0ymwcEu
NTYSzUVNeeIH1i5SzxWXnCqq3BH3Ua3al8S7Vm6S/YKzA3rjtlmqF2lwLbnB
ityahG9rzh4d4KUREhF44HLDO7hKWwseMGPD0GCn8h/JLNyXUj28l8yXRkBY
5Kfse+hZ4vd7cAPJvzIzf+BXFDIXZ8ZLiZF6Gri1ago/w9rd5Z6WJF69vIjr
b8x7oVVt4lJ5nYXf/v+2ha9vh6ysGcfcFhr1hdK5Yby50JRqamBr0RBMW2bX
+KYMFsU+nJXONJbUOR1Xji/CwqX1Tls0aYjm/ry4vbIOjX85RC26Kcx3rvwW
t74R+Um6b59PsMCl6LhBc7IEgQpBTp9iyPmn8rpc69oxy1PI70XOX7LqVU05
2gE5Y7VDt7PGMLZhcvT4dDOiB/d5vbhO8OOqhiaRErjZCDYwTEk++s7ep4xT
0XPXefY3P41NTLmu9YntsL3zekzIkoJm73SyykA3fDZYftzPGkXGaOy4+1UG
qGTBcL5CClQEkweGFbClFcxV/8PPRDGPH9WJWCPlGy33aKTqDDU3hr9CyfLT
YopKNKgF05q3MjsxVxTfKDs1ikOPqm9RYS3wuyVSor+MBZOe+cCE4nqYc8Wv
1PkfBYN0uZSeyApYQNlGY55CUZa+auK5RgQ+W+rylcSb2iC0xb2oAuxI7ded
B2gwG0Me/XnyEUkzVkENP9loMXpXdtKvAvt7F4dv/EThGBWa8KikEknr1dV/
XadQf6jpccnmSpSo+f3V2knmYeOVi3ZmleCtMKnZQ/CQW3pQ5dWXHqRf9hIx
rv8CTRVGnfV4C3SWu5VxWpPfW7c+MP7qGyxM+8dEMYnCY8ejy3u8c2E8L7Pe
axuN9L3VtYzpZwgz0bGRJPsqO0NsTLmpARbzMYdGA2n4TP7bNEMH4V7DnQfJ
0jQu7J7jdS55i2QRoyvs1wQv31YbfEkqBe0kFqK2gIaq/emf9q+7MeqvtajZ
axT8fg1j6Qv6sa6USb2bGEXZ5jTeDYpMnN809Tt3hI2lAi8ErF360B/6PZLv
AhtX3LUuuBu1Q8TZbvreHwoPr4RafRKoR8l7xmTyGwqG366e/nwnCi/lV33r
JXi3famzNHxbB47Y/q9+6R2yn4RzxqwMyqC4W2d7aQ7pR87nCivzQqgO7cm/
SvhhVrjLyVuqCRf8K348l2BD1eZnkdBUOeTcV2z7OkThguM1JfZwGXakZmVS
YWS+JzvEhUYCYez97e4M4S+VvHiW7cAbHPytE7zgNKnXqXW9ZS2NWOQX4ZxW
SKMmIUL+xuN6dBdmnDMl/BJl9jct91Uzki2enP8rToEjOnk2PiUAkzuUNVJJ
Pc1TdV1T+SLQylxmk7eeRpHPbxfpa23Q2Rc1cyOb5NsrbyRWUIOe1l2lq7Np
MIo1V/yyTENysFRjB8Fbdi/PlG1XNSYlPysstaPg0x/rej21EjpxyhyLlAn/
WW869EizAumeKVwPCd/qlM6zOY+243Ph14ELZ1nYrq2l4dGWhQLeriNHCR42
uqbw+afWgvGHkyHWRvI33LRMLjIPFsccet+tpWHfUSz3PbEGBe4Zt4ZcaMwu
W3hu+kEO5EWtXlwn87Nf3VQkNL0OzGsMF5WfRA+00Nalqulwk7iqka5NY/hv
pnTkaBqKp/b8UOAmfFQeE7uiKANXvNZz3CX7xd+rMP32x0aEv3Z94fiGhvip
4q92+17gdHN1/n/7bI0jn1q4URN0E9MDp4vIvrzt/Sz0UQdeWuzP2ZRJ49B2
7rPiElUwkKg85niKhqRjWu5BkSJQI5MxS+NoJOgy/ZIz8xF0Oj9hmuzbQamt
Mrq90VAfS/69QpzG743xQfcflkF27693ycI0CgMb6i+lNSJBLq5Ip40FD60t
W3nammD3ed31tz0U+Np7Ih/c68Hn6xa7NpeycCbQtfxHbRmOHRL6y0HwKSq/
qKN19B1+tJl4mpP8syOm7omyUiAyUu0uKENjy8pjWgaW9Zg1XXfJ8H80rh6Q
MHmv0YArxn+qryuRft717RPNr8NwfPQjOUmilzpd+Rds6MPby8/55bhYuOcj
buxfl4y1w3ZT5uQ+xbgUXc6JNhgMNZ9VGGOjz5NdNFXSg+h2f+aFi2zM9hXJ
fFnQibXiN2LTx0ZhuN+v4Kx/G46UNQ5dmmQj6vJYdo43E3H6Vh6mnaNIaV5X
Z3frFR6r5vA66JB9XLKCanVqwZTWcIOvIBvz+o6ea341Q7OCvfdpFQstVXu2
yxX1we0HXWmvQ+ZbMKRj/FktXp7YXPNKhg3/+QClYV0mkgyU6ns6WdjRd3tT
YUczfptyZq/xprB2405B/qddGCg9t1I2h40tMqHZ/4toxcrbyhmpTjQOKFzZ
wavTCumGxQ7Lj7PBM3Bt4PaVNryynD98nuDTZ/ODhS1iDdDJdOe95k5ja9mK
8teLW/D0gf0mRzMKDAnb3aLDMWjxOyvhT+r1mmv/RJlOL9bmvKpsiqNwIJTr
XGRkG2LZ+SMmPhQOhYxsezZejdslco7j1RSUpNYO8N6vwZmjnkyBQRYY9tuM
K9TeI30wYumak2SelFy1VP5WYCDkzDGplzSaD5fzOnc3w0tCpsZBjw2PYRsr
tcQeDK/Wrv8RxQbjy5SMvHM8ZoKsHSTJ/PO/+15jw90KnaIM4d9LCT5m+xZJ
FZeBQy85qEiPxr3R08KPHzOwXJwr/sleCvsyUzzyuLtx9UxNbjvhh5d5Lgpl
3b3wmAsJX+xFoaZbjkv+ZQfmT27YkeZGQ3j1cM23oreIYKRP7SX6xKNP6EKo
aQ/Yja9tODzHwNoStPCOcidosw/RytlsONdWujkcL8GxrRxP7TcTvdIXpmG+
uw47t290bNeniS4NeGyh3QmeHFMF0wSC94m5Ad+wAejlCGjNqI2gkU9YNPgz
A+Gb/Bz6943Bdo2cTp1nJsybSxZZk3gtzO2VA7jaIPh473rfazRWBCXyHZrp
h/af2UJVUXLfv56dodxNuLTzrCZ9j4KkU6L4RGEl6n/nxYYtIfw1M+TIK9GK
E1oO2i8JPsU8D7L7M5gQNNG8f37XGFT3tqkp7WWifjYz70XyGJwlHKz+iXsP
1RGVv1fvEz3/NVrHzK4LHTC82VXIxmdHzpj70w0w0Vob2UP4MmlD0X4h5y5Q
wWd1vj8l+k9961BG1XvI+p6Rr/zGgs8TT1XLMxnwXK3Uo0f8gaG3yTX39bW4
tHHGu5/sQytTJx9/3gbsDYn/qE3O7zcRLxqRa8SJhMXPfG9SML9jZVozmU10
xMBV3eNEPwaWB2oXOIOPc2pyLcGnrI7aKMOiBuIqdU8c6mmMWl66v0C/F34N
zNnIjzRizwv8cHKsgaeBs+c6Mj8aoZH1t+JT8NgwVewY0YdMrw33bTwrsTqP
K9CX8MX02Lui1MkOuHypP5oTSuG1uFXCvrhKUDr1t/TJPs0ejtHj1q3D6N/7
n24SfcHu3XWXP7kNc42tZz5N0vgkskooObEOIgV+7NQAChOfeXXCCb4DPbqy
6kj9Ejo4tISL+tG7e5vT+DuiDxRlGlu+v4fVEZnlRsxRVIZopg0Z+0FNPX/T
IhJfj8KZCwvd6nBjUiZa0pyGw9y5pVs03+ONwG3xFMMRFD6YnVwU0A0+mxPL
Sq6T/fXj1Op24g9NFq3e6kn0wGK+3fORHF049Va1PYbwxdKgLIUFOW24/9js
wKdGCiHsVeO39ZphVvQt2IngZYHGw/vGIkSPWVo++/6C1FdO3CT0aSv4IrnL
xpzYuCokHrPrRiuUemd3Di8n++HeuwG/wQpweO95tUn9P76JHjBIr8azY3Jz
gUwSP0Ohj9utH6KhcZZL2Gzs2VKQ3jJSiKNP+BH3kPBlwJ5/N0dF4olV25cU
4odd/8q+9FtRCS/XXQJPv1JIPREpY2XfDeGuvmapNjYGQ24qBtd2ofBsdIT/
KTbC9Jh/dPk7sE/MPdFOgYXK2q+7bDxdkH7P5N/FRD946f6MUpNsQ/CBoGyB
CBY+RW5jc3F24g+l9OXGLjak5Qsncm3e415l8eJWwkcF2fTCkKQO5Bb55mQe
HUPWg1TpnXMdeG4YVqZE9LTPyd1/U3lj4RF7zOkK8dtaak91h7x7sLt2uOuT
0SjiqlvHDfTeo2ev8M+ULKKvQ1bEKXwpRk1X5aRpFIX1a/Tiyq164B5Qyr0C
Y8iQmDpe8aYXVxsVnLimib8d+pr5ajoNqzKeZ7z5D58fpR92WbXgZIH+vG0T
wcsCu7TgnmdI5hIIdCX+RPBnmlZodTi4Yrbv1CHxSPYOBFciAgdd4qyXrKHh
Zx1rbSHNwM53RyayW9ioFj1u/E91O8IYJWrfpsn9LSI7Xwl9AFNr4MA3C6Kv
qN67wrdS4JN/PyafzOuWCsubBp1dkL6x6or991FkS5h5npcshcDFNY2lBC9W
WaWH5kMakByz5k1DG0XwWVPOutQJ8/7Wwyfc2BCMMbKuOMdAzZ/M5fUeLBTV
PuE9odaHDTvCjx40GoPN7fDlUWv7oUoFTrjGEP7R/JFt4ZOHZXTsoW55gq9q
Dp4757swcyO88ZcV0Yf7lJjrnxbi1fIBdncB4YOw0YUteR2w+Mdk5fL//ODk
Tr55lV5oqmd/DzhEY3wopKR6IQML3u3vldtI+mder8wyLUf6wguel0JoCF0+
VTa2vBvB4dwy3LosTCxbVdv0swd621ysG26yscJhEdPAkwlbXUP7dAUaZaZM
aDZ+xHfOBOfjpWOoeaz1Iqz1A74kfHjuKEz8g1EejOIb4KahZqlJ+rO5s5lX
4G4XXofWcf5+RCHK3vJPsH8VRMWYWaqRhH8TuEaXSJZAjapSfDZC9HhB4ObQ
OKIPNyoqFqxjw4rHl+1wpRVfQo/uWdpK5jHgi1iIbR4YjhGxe0m/LmhHlUr8
eI/yE4LWZ8rY8DkmO7j/YB+8nkUmCBI+fO15XD/qeC82GYoflxFhQbXPenVT
TQuETRyiW8rIPpW9kuTrlIS5rrFoWeJvQmI+Nwy69CO6Ly+s8QMLsqXJDzS/
t8HNttS25iwF8ZenrNOqO0AN1S75QPrx6Qjv/zzz3+O2W7R2EJMC9+xNY06h
EnQtOXU1mvjHTh91C9V97aheNToiQ74XVFdbfGeoBW4q1ppVtRQsv4vtlWd3
o/2fbv9hNRp2X3lnI4UaQSXpn9glR/h8KQ9X3vwr3AnvHDQmfiFn2XbFD1sZ
8Bz98+cj2S+Lg7U35wR3Qs+Q3blDmY2T7760uEf/gz717kJfAcKP+jf58wTa
UOaWXvTVcBRX3T3XBXYRfpG7uCNgH6lXxicPzZgw6BRKv7lJ+GSIZeqzqouJ
i1MFokoqpF+qntEb+/sQZvomWk1vFLH7P8Y+4mtDo/YNwTvqo/jNIc5Tp9AD
jSx/RUXL//7fGebzzb8Lk+FjPknkPo7DMeXyvl3w1LTO/0z4utLbIj7eJQBz
bdfijDfR+CgtwBZ3q4G7qWFFmQvxAy4Vxf2DVdBPyT71uYVCj+5lkR3G3djC
OiLbeHMMujzvL6183wu6TCl3rQ+NkjXy6k7ylTgsLcRlSvqz4QHTbHdRMaQO
6KqfUqExcc/t10mbShQlPxbaSfwOx1tbt2VeNZi7/IG7ZIBGnXNERvHD9+C5
ayDTozSG2IfFzd1Hm7EkJVhSfIrGhq1Je4otP8C7jr8/m+CLzarVSy0pxca/
zyNHiF7P3Lt9JtW4AZ+97zqK8VCI3Xm9jtuvDnYSJqLuRI8eev5vLWNtO7aN
PxtqfsBG85sswa0zbXjywz5sPIjGot2e5Vv7OxGQ19AaFMlG04MPUoEjrdiv
Pz7/aRmFe79VcnlUu1ExuO9heBgbFuFVXvnHapHjK93nW0X8qoK18r7OPDze
uWL7Y4KPKsnINS3DjQjm1JeOYVAY12FGbWmvB6evh3b/Agq1GwP5VEW7cHiy
t4cRQfAWfEJs8c1mbK+bKozRZUMI3gZNaeWY0DuSOZBA4f8ZWw4M
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk81Ikbx6djXRVSIlfSUE1SSbRRHyVif7qkiBKzylSODildbKdKsnak
rNZI2vz42WS2Q2NcQ6mJORozw4itrXwPNTsouuz8/nhezx/P83rO9/NMZyeF
bB/NYDAO6eX/ev7sg95Wdldg30saF+4gEG6VL2wPaAOz9mW9mwWFumCqL2vC
Q8jOcFcWBpG4zfs705/Fx05ijAU5SOC3FEF1V+stROyYLm0tIMALmul0cYMC
QpPdlRE8Cr4vihvGSlrAFgiMsxdSWDe4aeP0VWIojzq5usZTsDDP9fBNkOGN
vHHKzmoK7kY9Yr8aGTjT7HrW6CiIEiv2VjerYaeRmq/j09BUzR17VarG4ePK
kytn0xi/PIfXW6FAxiJucOFCGrc2yi6aHcnDDzWnLMQxBA6N5vMn9yrAZKaY
l26gwahbEntgaitIz5D+okAK4uU+l3wSqjGoGFneaEtC0tAjlaf8iSvRNlW6
XgK+Hjt/knmV48B15ydHHhA4HDJxz7YtjfDb7rls8w4S8d83dBpX1GF0eo+V
SwIJx5x1jF2pSkx47CMeYNEIZXfHnzBpRrWMabv8mT5+XRxLTtaCtcvFvSmY
hInVgjMNLxRwCS+91HuTxo3/DNsr21qQWcBedcWUQugf3BdldyR4GGnt1Z1I
Qc3PGf8i+jGSfMori6dTkOqHxFNWIt0vZuJZBYE9tyTkB50Et9ki7j69//h0
qUnjczWKI22mC4dpCP9K9aldKYIhdcTg3gkSvF1Vty3jm7Dk5fulvB4S2Wnb
qjozKmAzP9RhVgWBlOR7YeuWtEPanMSOKKJh2yYQWp1ux+WtqSVzptHQ/mM8
b2B9IWSnr5XVJhF47+VlRF1oQqrAjRByScy6ZKUtDX6Or3M+ODmrKByfFFVZ
SLVChN/iPPpJnBu+nj26QYwNiZXtZl4UeMyjDzQb27CCrZm0PorC0OmRh9bB
HRjK+l9dF5uGsv12Mv+qCszcjtKQNhosb7sOh7R6CGZc99wcQyJ8WFE+9lkD
5rRGflDvJRHYf3ro2Bs+6srkNpbG+n6zC/465Z2Hft7JquAwAkpoDM+lP4GR
vWLbMhcKvcc+D5gOSXEtNqgbbygE7Bz4Up8sw+CiPEaYE43Ery263aYyKDPe
uXKsafjv924xCOmCYX5OkGssDVUBZwHj/FN8TB+2N1lP4VTJkrLiy82QBavc
GoX6/KO2UxxvFbhPxFV+2TR22MdPuRrXhcOblaryeD2fpo+H19imIzfz/K92
XgRuLDUPrLncjoCpeQZr9LxzHqkNe/itWOg/QySI1der/GZLkzXwDHOzjtpE
QnAt6n5KdCme6OZ5rM0lkJwlNDaO+R2m2i2JyhwCz9t/mXTQWoG1yZNeler5
KA9IUs19q0HRzUidkVEfxgnfRfnbt6P+4/y8ZSY0Vkc905zhKNDuWK4teavf
zxhzkTMlQHr4op+/riDRMVM1zzGwGSefMrpibpHIcNY2s6RPwT6ZX8f7W8/7
j0UHN8dJYXc9XLyunILnwnzq2456jHL4zLzkrbfPTO8926vGqflXF28Z14ds
0u2d2U8FWOH16Xodh0CAW5+7bf6fiOHOEHG+EJjV6P1dn+4BJP4Z+fd9STR9
F7p6a6YcSY8yX9ca0pjyhl2S7NKBOF09cufT0J2r7C4plcE1iB5eNkyh0fCV
kDlDDc+SuSb7o2n0dMemhw504NeuiUWi5zQGEn52WOPYjgWsHzrbjtJYZHbY
JbVHhF9ersxhpenv/X5rlbBADcVRZl34axrqH3XaUgs5ikaIWF89DytW9HK1
PlJkGez5QyyiMHnCndKzw+1YvGlw7MjvFCJOjt2iHSOFdD1PZRlJwfpAVeHT
BAn8SsaJTP9LgTHLyub46ybs/eie8Y1DIqJzlEP93efQ5EWcreii8Il6dnPN
9k6oa5JauJP74Jr3MoxUydFm6rTPbjWNQNX+rilJD8DcN7MqaRyJfD+5ojmg
Gay3n9KKmvX3OFXB7rGoQuTGYxn9NQQ+JP5zNdpbDvOdIXMT+ihkx12c4l4s
hbwmKZZzg0Ka2Xhh4xcJksW2GXl6u2B7ZUWMpQrdrg2SrQr9//USKFs2VOv/
4OnbIgMSHmma/pCtKvisOjQjzJlG35s4Ru9LCQL83VdZSilo934/vpPZgNcK
P43TJRIhWQfH8dbKMFTrHeV8h8IA65uHQVwLPKO6J1oupTBKUF8ctKsLAatM
ci8s7oO2domNfXMZLhy5eyWHT8B8ATGtwFUM3XKH1RuDKASu5S6dHCqEb0Bn
6u5wEnWuhzjywRtIt6EufrhAoK7g4yGDe1cQkxbo2x1LQC5MuDvi+ATspZmE
dScJ0/dlKXuzpMh4VvmqQM//sm8Vh735TeAThp/PZ5AY4izOXW/eCpp5OXD2
RQpGLkZqyVc+MrW3TtS/JWBo4Tgqy6cRms1BlY7RJE6V593k7nkE7uoL0WZm
FPK2tMxi2ElBU3yWXyuFfwFyjdJf
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs4lIsWxp1oUzJpF5VuQy6ljodKQ9ErQkWETeXsXdJOJSFUpLBLGqHk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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 75->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk4lWkYxs9EZgqFTBlR1pHKLltxN4VMkqYoYSypcVpsgyEKqUS5yJYa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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2kglF0bFtlCCaHyFhJKRVIp6kJlp1VJhYpSEalok15KKGUrLSKSN0t2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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs81NsaxhHV0Y1K9xwabEk3l8n9mUQ4aSiS20nbVuTkVlEpFPbOtSSh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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXtczAkXxlNCq9XERFHoXrK6WZTVMxHFKKl4c6ntMkS6UaLpslGiMFJ5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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 76->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVmk8VWkYV6OSDJpI2rex71kK46+UhGxTkhQVkmylhbKV0mKmhbqksaSr
bgxdWdrs2W+47rXeK9mSV6mmbJVl3j6c3/lwznmf5/lvz1l1wN/BY6aIiAiD
Xj/vWp2WYjdmcnA9UebMMgeCk+6b52pOt6NVge8t94Kgpe6G7dF/yqAayNnc
qEtwhc3J6jzeCnb5ybYj2QQWOh8OBHytReoJucGePQSWzZyk80saUWqQMMlw
Ilj0acdtBYNWhCmLDM+7TyCi4MFQbzeDgcGyxIlVBMs3jmiG6HZgYUGi9UAK
gd2eXZtybpXAx8O6Xd2IoOmQVGTdVyH0QoSFNckEhvdFJYeu18LmWuiuYWeC
iQPTiulHU6D9SVa0Zg3BijG95rydT6DwgJWvr0WwVE8sTNSXhSG/sF9MficI
uX7X600UF0dmGHnoehHkeXpdiAMfG3R57ZtCCNZaXF0ukceDHqvxfUMkwfou
1cX+hztQz+n+ZltLEGGcFfshKREOg0f/49F6dl8G31iMtWNrgd5EMn1+Ovz9
VseOepw/26IqTue3+DhyTpNdiy/ybtkqfxJohQReed/2AmJBK7oXahPEh+ec
F895jJGot13J6gQ7It3OTh6owf6RAmYlfd/OseOLrWgOFnTvzTNVI0id9V2f
W9mG6wt6rJqf0PNq3s0yVSrFQGen1h1Dgn8qmkvG418h0oHHVz9IUN4Xejrs
31coWFi6L3E/QZmplL3q12p4m9gV5VsTfB9WbjJeU4bqpQ/lOtYRVI087kx5
xoUzRz3Xl+LbUlDXfk+jAdt8BK5J3nSeOffeCjJa0dV5N+4DkyDX6aaK+9EG
LF/QKx5H9fOf+pZcWyMBnG7MaHG8QSDXYNsncroUcetwv0OPgDGptdHnWyUS
ttRny5sSFMj69Dbp8uEvL7d0iuJvJzvouDD5JZROD7v5byFIeaST5JlVj7Zq
075hWj+qz0dZR1+Iwz+8rnpcpnjxORsuBjRCf3roVNU+qo9Y8eOtclxUahpN
hvoTHAvO8G0taYKa2JJb+X8ReBpqsYYVuJgSja99YU/nUbXdND2dD4ZfZKMs
5eOK7J4ZIi1FMB8PPZ+pT/keYRy2KOJhyq/s/IILBJeOZBcZl5djoUysts42
gmZe3nO2eSvWqgzwJmJp/zw5g3KbMsQuFjML3kQwNSRilezchFB/3XeywRSP
MwcmPWoFuJSVYJ6XSGAlNST9pUyIPdyQIxUUr+o5pfz1jHvIfhbw+RPVa5uU
paSJRTME7ubyXdcITg0meJo/rcFSB4eBcMrfpdvjOj08Lj53ZN5W9CMQGL+5
MdslG9VzjcsSFAnGo5dH6foV46HWuw9COh+3REtuUqYV1vbbM10eUP1Ixl1z
+f05LF3MeBc1CHQTzhXmKDLxMnprM0uB+tciaoy7uQEu1uomLUco3ua73YOO
1WI8KDUvn+qTzZ06uTkyDp3zdWPuUD9E9E8uzvv3IpgRYrtzVxNkrbgiZWvU
CVNl4dpbfQRBcYFrPTfycGH7Jb+iMOqvByJZDxuKsbl0/VAo1S9rX3GGittj
mHx8al+mRPnpezV68h4TXqZDmia0H4Hn1bK3ZhyIr/2RtAUEH68s6U6q5EJi
10j/l+MEJyS7rZ7cL8T3WfvMlei8nTyFNyciX2Nf6rjcmJCA19D3h1+TAG8r
PXuMcwkcfVrv7kprREJyW4Al1XsXS7T9PqcYzAxpzQr6fbBN0q9edeV40RKr
Wkr7+xxs/GcAiw8/vdd6+lR/poUPlaX0OBj9LB+tQvNvnOnYUNpRDJ/X2i7P
qZ8WnVLcIKXWhmfvzhftziLY5nz39tYGHnKVb63UjCCo/2rQYLKfB/v26vA3
1J+VY1ZByc5tcG0OCquieZh2mLFd8moFXm9sc+5bT3B0k11st1IzdL4yelln
CSJvprfssKpB+i/SbLtdBLX9mS1ehqUocdKOWUbxGfUYfFG+qgU3+weY/vS8
9NSDotfXCcCebjtX9JzAz1BqxTxHAQacp5galTQ/Ck4pfJ7ZiZgF4c573xL8
kJkzatPPw2+hO3y5VP+Lnx4KkTFqBmODrKRvFEE+m5GyLk0AhVNL5j68Q/lT
3SA0K8hGSq1pb5AygfRItMlA2DmMS05l6VE9BAjlZeqi8vEoYziUTfV22jbA
dG9SE/jlUYUm1wmerna3XCvehHnKOrmOu6n+F3WxAjNLkSrzLmPnRoKxMU9j
m4oqiGj8ZxJO/esiEjOG+0KE2B5bZ3iR6lvUttHJvBzanL3SI3R+1pGnTtcO
tCBep6Nrdirly0X79abvafhjG7s9iupp5c6J1QbyPKQw67y3UX1LFCvJZS3K
ATt4eeNLmrdirtpuDm0l4McPx8f8zK/v7y/557RDJtryxmrqx+n9kVm5SjUY
vBtyU8OG9t/M7W24VwE1V/7X41aUf9fkksv67Qi0Xp20gealXYhEzJqTVQjK
nGmgbknrx7umZ01wMFf/6Jt3FgQKo7VFoQcbcGzPoMQSuj9kJcIi2Dl8XPTe
tlwhmsC4uClnJLkVWUqqehOP6b51x+UeTT7sNC21Y33pPrmq4cf6VI+gQJtq
NTuCv2fPUFM43I6OEzdPMOj+TJVbOkPCogk9M3d269D+LQ5VzRe/8xJnlhUp
VlF9cf6qU0lc9QoJz7g5YlRPIrVbH3NZJfjYj5QW+lz6x9MFE9ICaC77TTmy
lPp9fo5b8sK/UfLF9wmT8qv2PYKt0kv91DPKj/Wg+RIcd+yj7yt4f077uJnO
47bjsnV4TB48zSrWV6pQfv0W44zGSwQdtOAamdH9PBC++7hqE3atWvxJ+SqB
ZpHz86DqbMiMbnU9RfNg5e1fLxr4MmH/YDRlEc1H8TtPmPZOQsQP9NbZUHzE
x3/4lu0RonDuvG5GPUFgxKPCcUMe+jtWZjw69zNf0jX/MK2Grd2E5YodlA/m
8f2dAhbkdY2H2TQvhX0zLnxLb8TpVPZzS/p/4K5eb6i4NxsGHoe/1dH66bO1
TW8XCXD2cfT7TLrvH6VtL97JFUBVI8Z6OI3iWSvpHU/5Krsr4JdSv/wPaXHB
Cw==
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8lW8ftiorEorISEZCFEJykVmUFKVSRqU6pSSKSFaiYf1ISdKyCiUy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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs01Akbx6eWqUW6Ibe2ofctuZSlhPAtilJvzUZuKZfkdaRUi2Vri5RL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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVHk41IsankoljSKRki6SLJ1Li5S4r9DmkRwhlQctTlkaREQy1FBapBCn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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 77->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4lGkfHiWlE2lVn7QSOa2zaqm4R+QQaUitSoxDSl9lWSySQxJaK0lK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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk41O0bxSVpIREVStZkq4SE1FEkskVRSUJIZektihZLi5Q1JEvZKjtJ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHs41eka3WkfOiWXMzqEhMooUj0uyWVWDarBRGVKqZRBRigMI0Vuwx4M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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwV0ns41IkCxnEilYg0i42URnsUh6IaWbySTaRU5CiXxMjqiKldl4q05FaS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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 78->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns8lGkbFrX6pFo5VFspGjnUJqXC0uXUtg4VYlFSGFbWKU2SNmyf6IBK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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lG0bxsfaJmlHKZKlEHqjz9aJJqmUkvJKSaKIkC0pJVulyFpaqSTZ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHk81YkWv9ainrIWsmZCY+u5Eq/mqyJKqzUlyYRKtFBhjBpUejzRs001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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVHk81IsenfCylIkaLYr2RBcVTxLOJVeiFekW2ZJKvDyp5LlItOuNLKlc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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 79->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs81XcYFjlZGGpZzcbc5pKjDjYleeREOajDypRrSoSypgyNpCmidnaK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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k0le/XxsmYJEqGhEJmGdIoXRJJpVGGSChRyVxKkkT5IkkqzURIQuYf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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHk41IkbZ9JGp/A4trT0K2xajVIq8qGwJVKZWrTl6nJkKxTWasK0EjmS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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk8lIsexicSKkunU7QcW8rS8im0qPQoQqFsFY66klAJLeKgMZY0FS6h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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 80->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lGsUx91WypYtpUWSUrJd1aD8qMm1hBvlJkIlJG03l0iFlKUoshVK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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8lV0bxSVlaCBUpqQSMiWPRIYVmR8iKqFMqTShCU2mIkpSFE8klRAy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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk81Akfx0e0K8s8T0KSowgdylE5Eh8Wmx4NilGeVBOFTmVD55O0HXLk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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk01Asbx+eixRZZrriVZOqN0qIo19XX6SoJQ643I7J043aj0I1GKm1v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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 81->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lWkYvRpt2ktNZUQlkX1r0M2RLXVlT4ayDF2SIlsxXUuWImWdyhJF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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2kgVX0XxUsSESpJSJlLJaVJ1FJPiTTIg0qSJBHFE8qQTKVUMpWUzAqh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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs8lAkXx90qJKY2idB9aCuljReln8rqIpKkUnqlXCptrpOErHdWVKx7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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk41Isax0VhSkWLJXK7dORxypmiopq+usVVVIaOmyWFLEci0mTJJFqm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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 82->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns8lOkbxic698tGshIlCqvk2CaHLlkJSXTYcdqsipzKuXLID7E2VIrI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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lf8bxlFZZWREUoQiqRTJKJdKaWeFFqlUlJIKfZOE0CBZGSmrSEKi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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs01GkYx1G5VzZsU1GKSqXUaCtt+rZJShkkKQpdFBHWPV1W28WEkGYl
m1tNRBgGudZGx72GmcwY3dNl/C4jSrLStLN/POc57x/vOd/n/X7fzzP3QPAO
XzUVFZVoZf3fycq8r++quzBUVns5c5ACm00LVmV0IfqW2dm4PgregqlxHFUp
gg7Zmqb70Vied6L9dmstopeY6xp4kojKnhZ7tfgJ9H7wCPU6Cg9Chq5+OM1D
Ds99WUUVgfD4nIqImhqsSGoQhK0nwRiJF+TcEKArVI6EPRSG2dfGVewl0Obx
z/rcoPHv5lf8gKNSDHpbyWTraOiOmyrmXGjGlSo/6xUSEuOpt44YL++C5NJA
SX8mhVI2wzPBuxejOzlj2SY0DPcz8xq2tSCgMoR2LibB2do/7eZHMfZOGObU
eNHIGS3RFGwsxsrIfemd/xAI7Mg3srnVCU6aTGdWM4Us356PZnwJPP7YQvvV
0zArKGw4f/gGbreGmfJPEhixjrui86kbiXYCs++2NDQnneiOdRFDt2CZL2ML
jdjEOTODNBIxO9lOuMSewGym6xmp1TMoNO5vU2HJkRicKZp28SG6nVp2bekg
Ib7zc0ivnghejUannJgUtvtUhbg9LkLC2D/vV5YTGGxd6+dB3scXL+nmX51I
LK9j3dnq3YQx73VbmrJI6O0lXkWcLgVhk1cXVUPA7uHipDhajAXXCtaZg8Ko
fc+GtzYS6BsbsdpoClcFPXaems/ACtDMy1G+R8yk908mlkvx+flPR3YpKLT+
ffaB9sR2vNG5+buRnMSxnNdnvB71IKxUEnynkkbVmgRX47wWmMW0rzjfQ8In
xL9pnp4Yp32Pfp41TIHPlE55VPICIh6xdaqrHHPb7n8VEB2IYo3bZFtTYMjS
utXG6uAarGW8YCeJwCVaEVxWC6J1J6zS1KCQ8pso4F6NCMYpBdzAbRTES/3S
DWY+wWTLIs2/hyiMGyd79FfXwWNnhv71WSTUUjs3fDPqRp9X5q6ABgovj236
1ZDRhPDFQbZh2SRa9zmfdqnowY49B3UYMhq1/9YJPfulGLCRp16rohFonSeM
kFRilQOT+0aNBN/MInuGWxNOnvvwfeAxidEo89nXCztRz9y2rNCIgnNAd41j
Rz5S+WJNZjoBkxLf3susvyB62Wvlv4cAJ7on7UGkBENrc62YdjTMmSl/BfZ2
wvl4xDfpCQrcb+tzerY3IyYtM8tCqY/r5T78tlmKUK70i/U1GowQbeeWjT3I
WRZ5we0tjaJJrJcH5jagWi1lEeeAct6kC+77zJsxXdXvOPc1iXnNC9W5kb14
IHArm7BJef/53aVFwd3ISzAJ01pNo8Rr559zXIXQ8lcoHIso6Lld/Ko7ox5z
TO5+V/2FxPshG6uJalKsCHpneVn5/4w8F3xRY4txP2LKaLgjDT/9Dvu6tU2o
nh42xmok0S/kbrY17EAS/1WapS0FeV2+5YmYLtRnV27qs6Pg89mB9PJpRMw+
/2rPWGU+LibsL12TjmS+C9ffh8DreJ2A+kkvcORecscxthyjV4TlezwaIUnO
+JZ7noSK6UGTcH45Vt6TaQ2+J3D6yC9+Mr3nGCj+LSbPQg5G/fBmc7IZ0uH4
z+WGFEyijmzlDKfgcOGUS7ztBBrbNG4LwjuwMDM998dUCtdb9gZ+KW3DSKyb
6mWShIFU1na3pgkDQ7ZlpRlKv+uo1fnRIjQxsxz6simclPTf+fSuEktzjRyK
RwhIdMzueToKsHuH+49QB6V/2+NLBzyEKGBbJmnJKfR9fDKpjC2BPfl77lYl
P1Q0jeKPS3wwOXCytdNCAuNJoesdDTLRb9dUKPMnEELeVpBOZVA5xvE9/JSA
NHj08veSBpDaHxjCiyQcKhZEtftIENfofn9UmU+fHV3zUyxFMEmacW5Ot1Kf
PEudX9aBgtFLPVGDJCx0Fo4FScRYbO8yoSOAxicXh1r1lRIkLRIznMOVfFIj
IpxFJaDVeWcNGgkwco/qJXbVQJb1bvL7+STYf8bxTA5nICsn1Zp1iEDXIuvg
WsPbYP9RUJCQoTz7Oii6cwVYN2JHfj1IQY1YfO7Ux0cw7dz3QbpUyXvvwk+S
7Eys1/9kbR5AYI1p5ddQqgGcS6tSW6+Q2C5dfnDKzEfQ8bTe8PN0CrFBPEXR
IA9rGfoafg8IKJw+HtN3eYrul6LMeDW5Uk9jgQHVCrZ62vdIYwrp3u6zphaL
cbf+ZMWOEgoT13vPPflYhPDeh0kJ5co87xJevDFeicVvWus3vlT6VWahbRWq
zOOuUvvdhygcsj9V1kYIwVadoap/k0K+nlfBqnoJmHeGBdnJNKasbhwXt4ux
jbufVfaWAufZyAqN7mZ8qJJVf56n5M1eDYuprg1wURQPzLIhIX3xLjFPyVvF
cpwbryWg27c2ZneMEOtO8J625yv3WelIQIdGO4iFhkcd7SkwbSqe+Gs/xw0N
HiPSR47SwwterZkrhcGZiInzhTT+A/Dt2lU=
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVknk4lIkDxwexSkWSbI1MZJpUjmptOfoWunTpUKlYbCqjEIlKS2pRj40y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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 83->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs41PkblVq7P22a0kWSRFcUm4oKRy4TliglFKFCRCorhAipDbHJpVxj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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k4lG0bpiypNwlv4RVCklSiRZZO0aJQSKIkiaJSkiUlkaVCCBVSSRRl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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHs41AkXllQiSZNqJ0pFiG2sJN28FNFFhEqFbipZIlvr0kzqG5awK5ek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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs41AkXx2exUqHRjSQhZbeyKFoVvrVpFkXILZWKLhQGrVCyI0uyVGTK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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 84->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs4lOkfxpGSpIRliZakpJTDpHaW7g5EqBxL61QitXIosrId1ZJkS1sq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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lt8fxpEGRUKSrCghIZGUXNJQNIRKZVVIyMrXLlrSIKJSUVQayMpK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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlH041GkXx2VNPSkZlcdUZDSS3uRliFW+JXrxmtekbEhMm4gkCVtttaVC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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81Ikbx8dR2c7hlSIqVlklP4qSko8zJLs5VyUJHX4VQ1JjN2m1jEQ2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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 85->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4FOoXnqIi41rrqpBQqKhuaCw5RCUUt8bSgkISWSpbZMlSEl2pRvFz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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lG0bxtEqRKWShErqLSRtlJyFigiVRCIpkra3LAlFlFRSCNkVSpJ9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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lAsXx11rSSlxEclUN90sKbJU+ml534Q2KWZIknJLljbiluwp3ZoW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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHlYzAsXx0f0Std6heJqIS0aRV1p45tKi0S0aiFctNfFpSKKUjIqLSRL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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 86->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs41HkbxicqZFepXqfNS1LRhnKKqDuymy1RYhyKSFJKB+lAKqV6lW0v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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3dcze0fxosQxROKNIyKJ0RRkpIrCSEJRULDyCqSEA0VLZJKU9EQWk+7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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHk01IsflchSSjslpsUSktKjLO8qJUWSlifqKWnQsxQqPZIkJru8ymR5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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk3k81Ikbx0fajlV2RkUNWpKyLWHUph/1aTdXIXJMlJZsihQ1Ua5Cp0Sm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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 87->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4ldkfV4mKEoO0mbpE9nVkmz6SIiFuipSfG8kwqilbRYXsWmhjohIV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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8le0bR5KkQSJJIZVViUjWl0hkpEi9Klmh0kKhVCplpKIor4zMhpE9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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs8lGkbx+elqHdVvKXXpx2HVMNIoqQ35Bc6IEWSVSYrNhG2SG0OeYmK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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGk41AsbxmUJJVSWqYSO1iMhlMTck5pOJAmlLCklCo0UzYlQJ6FyjqXS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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 88->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs8lNkbt7OSlBZFpdINIUKY+mX0dYmkm4TcKrKmJCG7NZQhymIrXW1u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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8VW0bxUVpkFIopUQJUUIqaVhSKUOUzJVkqmgOIURpRCQiJPNUmUKm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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41GsbxyUl9fLW4ZROKlSWQtI4EfVFi2SJUYhy7DSNVlHeplApHIyl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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk41YsWlaGjbjJFplceKipDkkLd5b5HN5LkXjeiwTw0XL1UMpRcqZQo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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 89->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns8lGkbdmg3fYkOm4x8aYukVMLmlL1SQmtMklRSaycmiYjaFFtySCI5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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4Ve0XFVKhkqRJaNSg8kVCw0JIMiVjKElIoSiiyRcJDVT4KFNIMmWe
E6555prKkPmec6kkIUm/9/fXfc5zz3Pe/e691l5rbbR01LvAycHBcWYBB8f/
f8VnfkpfVuiAfn2V9D3XUdywm3o6rctE37iCjkUhC7N9TOP+cAZ2Ru9Rz9ei
kHSNt4Vhk42xs/uNfE7SYK/13Ckr8Akpmu6eKlwsdGr8s+ScWzXmJgXdtUJY
uDN/Ikq3ug4OMdGxx46xkVUqu0geiVBbvbjrxG8K2xzrBy5yNOFS30M/5XQa
nNTE4lrfRiiH/K7VfE4jUDd1C99IGeTVwp3Oe9Poe611d7o+E9HSDvo1R2nE
nrC+/Di4FJaJZtNyL2jsWRXo2XG4GxGTWj9l44egWyoyrWj6BlbzA7vXraWR
zbootfFrF3gy38qc6BiFol6wz0nXBlx5ser8kCGFif1RUiFbCyEw4VfEXERD
UU5u4eDjTri4SeZ5N9JYs5+r+utoFhjjj4+77KfhoPXT35avAFEXJD1SfWls
n39aUZ/SiokVXf7JkmxIrZ1LMNXrxL2im72suREoWnvuHv/yAHbvt44fFqch
0x39avZ0KVR2c6ipz9BY19ZhFMXVhrCVtxRSv7HR0cXeIFHfhtnZ3RndH0Yg
fK8nYeJBB0SObhFi27CR2fpgbY4XE2d5dUai7Cn47P8s4peQiokUv44hAxq6
u1w5X9gyUd6pDsu3NDT1GermF3JwXm9QsnaCguLda3XyXx/i0rWHBuWiNDTc
/IL/nahF/I2XE75RNMZLXeQUnufCWPx8arYAjdSLGvLWe/KgfXeR/vgnCqmB
vpK3jfJwcbFc9NxZGmEMs7o2sUYMDC7lMnei0e6ox2rsbsY6nby58GQyr3/P
XWPMl2Hyx+en1Adyvq44I8OvGHHXK/xMXrMwdmRdvJQ/E0/7dxer8NGomc8e
90zqxNiQ5t+3x2nkrqoa193NRBFfF7+8Hw1tLkmdsiAmkhuuDjsHDaPwomzx
P5JpkDKbfLxLksbMGqVnYw+7Udnu69ykS+pPruzoMK9Fc3CTi+okud8tTdfe
wnJEru9PL6IoeOj9OaBb8RrBp8RFTgrRMOMNvLggpghuypVO+ywo6B/V+N6a
Wo/cep6T8txsWFjyVG6YfgdZF9Xu5CU09iuJD1YOtkFFx5g/ZRkb3RXj26wZ
lYjnlfQ5bk3hbs1EySWLCiguu+d7/TGF2GIed+E17xC1QSLm4yEaSfbsS2NV
zWAW1T8+tomGOFs3ay4lHzlvTf9EP6PR+cYxhzJugLWBcrYlmwJVppdW/7oK
cxlH3GuO0SirS4nwrq7EvKDTqa17CX5/1aW6b6mFfYTr3Jg5mU+6RK10Wy1S
y48kXtjCxpsrFzSWnUiB7cpwyc4DNASn3V87BzAxdGAVH102hKizSqcz+18h
3tDy1809pH9zIco+6q9R8Wb+8JW/FIYKo1dzb2xClY7HptlqNvoSih77V6Ug
8IPbzgdzFMa1NyXxRRRhUizAv7ebQtjB58UZd5kYLz/6sL6AxqNdddrewQyE
frecbHhCQSj0vhSvVzOyr56pTqinUMjVH6vhVILaVa4f5Mm+MB7rW17D34R4
m9Sqw5dpCGgHuPI0PUNFzOQ3SwkaUbong9bRzbggKaKS6EjDZ+0uTmf7N9jD
zXL/tIYGj7u9HZ6Xo9czWOpFKQXx6y2C1TPFeO3Lkq1ZRqNur8CtwwpNsAp7
y6tvQsFBpe5h7O8uuFWHF7k205gzNVUVetSKZVIQthgdweQBdaOH1jWQ9vSp
uc9B7mfjxzcjWwttB8Y+zTcET81cfUuHnJFgpxH5iczzl0v2qj3Tn8Dpr3M3
yICFnXWunuMOzVCvHBrSrWcj9cvjVydqOqBwhcm470Xm/U5oaVJPKRz8A5dv
baJw+5BTkmV6J24NKDCc3EbhMfU7RKqsGi96zBVapWkcePV5gHGViXUOy33H
bNlQ3L0jef03HagvelD5cyMN9ZL8ed3BQtzYk7+R5z8aV5xdNbarl2NkxDAB
zhSUZ4x5C51aITWx6uScCxsqMediUwc78edTexuvDYXrkmftFVybwcs5kxJ/
jszj5O38HZLv8fmm+EH/PxQEXOtkuZakQEQfWXU7aAR/XmvzZbgel2sC+q5l
jWBIPSypZLQFxneUpb+8Y2NyXWBzV24DanjyB3S5Kcgpb0h4ZJuGaYeYFjUN
gtcBLQfT7E6s8bN0EXw5ArPT3oWh0o2o+SIVofabRvEEt8EB61ZIlPUPmWiw
8eTC1qF9Bz9hXWv/U/EJNgJKxbxkuVJB/Zk6ZS1D+BAy8OF5CgO24bHRSoUU
+gzfhl63z0dZWV7EbUEa6dNHno9c/wAvR89H1ndp7Iv6fKw7qB2tL+42qdYP
4wb45o8+L8JeD9kZZyOy79cKPN/MVYBdC25YSHjQ4C1OuDWr3YlfvKPfnDNG
YTVSdva2bhlSi7W7VsQSPXvMe6OxrRWRWw+9E8qkYTUXd5zLMAc71c+qVukT
vhsXR0bThYiaLo3v3kejaT2nHHdIO5Qsf8dn91NwMmGm/Lnbg+6LEcbrSkax
/Upb/7GWDnjJSa4SyWIj9vOr46nx6TBWFtqvk0PBbNBI+bdVMZ5E/N52zJhC
1ArVhI+mHzH7T+NhUR82QvKui7TLt0FN2miJgdoItpfkPHywIAbebrNZWUTf
ZAo1EnIS2tB4yXrCdZrw6Rnv5RihYjSwTyyM4yH9fBa3njXsDa+O//j/jy/J
GZ+AaboC8ZeCtmq+o1GVe6VwnUoNDvs+E/w1wwJ34psBfhYTon0LIu03UkgM
cTCy7a3FLZXZ0P2Eb5+8JWdvWTVjdkjwSJfjCOKGbqgWmnRC8bx2RU4wG07t
2/MazNuQeyY+9Hj6ECiVhx9PSjGxpl9LMGk1Gw5nUt5mLGtCnOCm7/HLKQgv
9FMTmHoP4za7flqERtD3n8KatjXYvklVx5To2czGCXqdViN0LDqiv/2i8eSX
yExsZDZ4ZwMWiivQcFqouPTp4xpEfbzcKE32Y9MCAdHggmroeVSn2hey8Wh1
v+M9iXjsVs2Q3fuFwrmtlIpiSydwn6tzczYFKUujTAFzBnLTL5wXlacRcEXw
5hlSX3dcX5sYYwQWjS9Gnu5Nxai/7Lt2oh9X6hTfPE7Igs8Hr1N5hM9mbpHe
n+VbQA96fk4QHYVxzFdX3rgCuLoly/ltJ3rhxv2l07wMwpuPioaeoqFfbqr+
aUcLbo64MDZ3UCg+tfvYq0F/tCjlH5YgfJQZXCUd96YZM8t/Nhtsp6CwLUzi
JOFXgs3ep4tWUwjgvCWVMFYH51s9m9MjadyQWh6+/lA2Mjs2vFSXpdFtONKd
XtGIqdInO/mYNPyiVff8NO9EXX9K+tXBEUQ1HCmPdM5D9qdrRx8Q/l6Oldn5
gq8Wr3YZBYzUUtANFXG2KGvA3SVKZkLEP0jlbf7zNSQdPM6SyWLkfYETaj9K
+HpwqEnQvnrJKGJUIo+bPGAi3itSOz+L9CfsGGvfko/o9FntyifMhm3ixWTr
gSqE3Ti3ScyFxmIVhk0P8QdC3vOipkT/j8mr829JqMXYtgv5M21Ejwy/ly7K
SEF86ltrLnKfnc3ZB/obGjB/+oquxWoaZ8yrxirZHcj8HjQk1M8CxVBlKCqV
4yujJSmW6EdmoDB38KtUBJ7NXtqVSKHLwUrFaHM2QgyOrbIMI3javbtdRicB
HD4h2z4TfiSt9Gg3ny5BtnFMl641qW/u0uiPA11w8fj0yb5pFIGnWFeyQhgI
Ci5p/KNCweWAFU/23jRssd1H6Rwh/KmPaMhbVgp+X+Xedh8aKYOnZdLsW8H2
vf3kXiWpp0l8qon448vuXcZFpJ+2LQl5ubll4LYZmz8UR0NuV792QG42qn71
mGgRfbuR4DFbYVWO+LlEITNv0n+j/2RwkAGp4Pwfgh+Iv+3+u+uUdzp637+U
PsRP+M4tKs1+UQNb749LHjoQ/GfPZOdWBiGdtbYuheBPUv/CKT3NCrJ31wyW
5hL9LHYYyv/bhfsyHo5jO0k/XqZr9vY1weKBfn6MPwvtbvzWhvbd0LTKjZSm
aQwpcOqPprWhmAeC3++wUdW/1nphcAEGbE873kyg8WbWa1dGcCXURKYSnygR
PVHsEu7iKkV3wkDrlCXxn17yUvfYbZhhLz8Zs4uG8cfmMMOAj9CWngkJyqax
euA/31G7DmwrWnS0R38Ug04211ZcqQSHU9+akl4K38eHKcGLxQiL9dNrJ/6C
6uffnt7dhBfDbvJKomzE9LntOxHcBplamrNqKw0phYrIiogq2Pl1u9kTP7XO
52zLPstmRLSocMuS90VOqnVFEb+ZfdRjZh3xI+KLs1N8Ypk41C4s9zyE6Knm
+7W/i6qxPenyrAPpV/yFlKFETbIPgsrErcj/O7jzBFu7u6GW+IjRpkRhVe8/
YkscOkBdl5Fy5xnFWOOsiVl0O/hNC0bs49gYl+VzvnM9GEkNeQYWZB7hxzQ2
f5HoQGDNYLswyQebnidcZ7WWYOSp8NDef2lEcDDF7Na3Yvn1XbklRA95F0Qs
nYtqxu0Ib/eb3Sx4vNKO37DJExwnn70s2EzDM2n5aw+TZqQUGuzbUE2jlKMo
x3pxMxZPXD/0p49Ck275puklzSg3Mv0rkM7GlbzqoCcfy2HbP5tYSfKDurvr
h6lLhajSdlve1U6BO5ByENFJg5BfFq1Ezpc7kuTtFF6D2MyY2Ydkn0T83JH2
Yh8T+iafdbeTfaa7VYba87EFXF2s4YMiFNbsYNHWHW2wshoy1BNnw+ca+22i
dx44rMO2+ZP5ja3VbAejA77+d5d7nCD+SMvlzmKpQKy+X53LFqPh3iM1nGLR
hCMmTw8P3SP8DF3Rp3OyAdxBLSt8VQg/xk/l5hanQM7TxVxzG9GDPJ8Pz7dU
YK4+vC2I8P/r1Z5ci4kOTBVqTG0zGEUrz9Xb5vIZuNXcsFJxmgLj2ljDfa12
3GllzrnSbBSvb1/RXumPn/cOJr0m/m9iRajbgF83ohPTS0tJvgnP9zUTks6H
rbGWXvn/81jW781fDgTiUavCeQWSD/saSu5f0wpBSnqV+XFhGnp2zImR5CYU
L0s/xogcQUimh+58cSumn4o4TJ8bReeY3Lek5BxswA8RjfUkD5/U8tUs6MBe
o5vOb28SPyW/jpEqlQU5eUmlsS4Kepe/LbUNL8VkSnHxUjMaosx9W4ZvNqGI
W/npgTUUQiL3uHe6lKC3R6znfhzZF3aFTkfj3sHKIPVwvA3hr7vQyZ0OnWCz
+JbnTI2imObSOlThB1mB3tsxBP8cXYVcR/ZnQnKHKy0nR/IDZ7Od3XQWVgYe
Z9ysoNBye1382Hw9+rzsoppJP+KvBMV+iyzEmltmPbeiCL6uLp1aFZCBosTP
qvpEvwvd5xpfT9Qgn3dteGU0DdWk9M+L4ypga3FRfynxU+IFvadfvyxAZ4b3
O3PCb+pgQcQy7feIeDe+7C/RlySrp2vS3IpR487kzCb81RU33c54WQm5yetD
BgQPuob0P3eqa3BjtLdX+xqpX4Jzf1qoF7YLrjQ7RfhAlZdIR55LRdRR6ttK
8hxW+0prWWAV+JUGjV4S/Rnwms+4p9iM8Na0O4KkfpXQ8NL8b40YcdT5x/85
wde2yrKrE+nI+CAiJkTwWrHzXwkHyw84Y9J3MJD4yeyW7VfEq9qg1GtoYPCd
htgQp/D6xG60rOg0d/jNAg/L0XmTcgtWrr1N77vMQq+iSeiX5HrsdBgOyTxK
/Colb/iOrwVSZXarJJ3ZxE8njKgGpJN7FOziIfiqa5R5oPZPFwwlDP8uWTSK
Pm6t4w0Z2Tin/Ou8F9ErD64R3UY1DwTu2Pb3LbkfRwWnsmFAISoT/pPrCaUw
q/zu1tKOAuSPqk16ED0zsdsZyLjNxOIlj5zPpFAQEXDp5igphmGYu1UbybNf
1XL/VP1uhl+3pZbbGTJPz77f1c4VyE1dr1d5j4Lg6rZm4d4mHOqqKpI0pCDv
9zFs04JmlP6bMrcojZy/2Ghm9UAhpNa0xsmMU2Am+FV8lvqEv8s0rFcU0XhW
oc6+mdSCXgEbxf/PP15M1FYmOga1B748vEj482uAq3c+rgsaSqcr7hD96bPx
7rygXQ2vE3KbztZQYD93lxg+wISSxKM/tq7DOMP/y9h2mIngyMC1xu4UvIQO
JD9ZmoND+ZkVhSmknnYbFRvPZChuPr4xjPSTozitoanbBy1uYXcLiP/lf9Ez
kmhahy/qM/HfSD6Nn6l8uG2wAV7bf228Su4j9yMmRyk/EbI5RjFJvDRifZy5
JxWrUSW34anTDQqdg99FjvgXwna5xOK7xG+mmge+Nv9aDJnDtQ+GSf4+H6PQ
qL+hC47dK9pdB9lYZfxH2TusDg/tDSYKuWi0RK4PlbhUjPr98+fCTYlfUJ35
KrEzBXcMc/eWipL6F5k8XfrkJmQ2zgn5kP4IHfG21dvXiUhPF6P7kyyY7Vjg
d+lyLTqTF7tIjdCw+KxbspuzEi1FokvkCJ8y9yyb7PyvCRk36wZkyP7YOysp
7ffhI6quNkddDxrGWAFWe3Y0gZ8taQSS762eVcxTwh8h5Tv1R051FLnmfLFF
gQwIiF6aV7Mj9azRqQygk6AuHblRcSF5Fp3SDt3dgK2aNrkmySx0diolNmWm
oaIx9p0RyWOFcxc0lGJKoN1W+GMb4Y+I9qzfmtUV4Llzxu9ENMlzY01Kiwyr
sV5IJc29keCNdd7RcVsWBs1yuybOkO8XGH1dEq2IWJ3sTXxkH8fbMSfPa2Vg
FdftY7Jk30s+//Fr64ZizGSczaEMiX9NynUw52tCj9IigW4vFvjzqrb2kTxS
MSWjmv1kBGGuqW/EGblQFZtJzOEg/oP5uj3zSQaaRC0PU4tohCxy9Fu/ogq+
Ags934tSOHRnn4XV1lZQm2TF28g+1d+0nvFMqQUpZXE7uIhe3XNRHb1q3AZp
07EHr0jeVU9TjfgmVg/rUf/UCyE0OqWWvW0rrcUWxz2HIcHGjVdvg0yF23Fk
93HW4WSib2Vs6wjeFrwY/+V+jeyj/wGFGzDh
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlX04lIkaxq3kIyVJNSyyQhHa7ZrSEW7UliRJhS1p+iCcaCXSymQ5lcXK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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGk41AsbxgeVIs6oVIM6dVpOpJNE9NbrFoU2HEo5Mc1Qk1ORilIJuWzJ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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 90->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnlcjVkYx1PRMFETYkwqodIiXSM1Lb8sFUkk0aJSkUKLtJC0KUSaSokm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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lG0bxqWQ5S0KpU2WJHuS/e0UicqWFqJFmrIvlSIiO2l5tYhKUmmz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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHlczPkfx9OtpcmKQu1qlRZJIRXlFakmbGWUsKiHyuasRsiRTTp0oXOV
aJCkDaPoNmZKpYyarumY6XTke9SqRHL9vr8/Po/Pf5/X+/18vT4vg70BHD9F
BQWFEOb8/552oH2yQNwMvz8u67SVU9C1dHftvlwDv2rXEIkyhSnVY3n/5bWj
eJYXuyeOBm9ZzLRlfrdhEhf0TSGagJ3w4eAfWRcxcF4zy3YjAZZ/HGFv3469
N6sT4iNprNW5obzVtgWXln3uCr9FIcx8is0lTim4TpkH04xIXI4N7RQJC6A+
Q+JW30vg9zX+y591C/Hr7uCjnh4k2Pw5PSW+d3Dya8gRhXQCGg/nfcxXqcLG
jtvvWoNJFLWIN5sHSJC39UJE5Z8UzgjnGQ+NV2P3YaV1/0pJePiUJ0T1d6J1
zjX67npm/gvZmx138ZHUVuHFKiHgODNufmF6C/a62QWXVTPzveK6fotrgaDo
a8GGRgrPHL56nN1VA25Ox5G8MhLuN79znmsUYSu3iH+ih0DYUJa817kK8u+i
+5tzSfQatL3MkAoQe2a7A83s99winSfawYf6g9QmdyEBrQOrBk8IakFeuW61
YyaFd+u3zB/hiOAYOl4gSyVBXhqznv+tE6KNnPDFT2gUSNV25ke24K3XqC4W
0ph87DLBimyHkn9fPLuNgtaIxXCa4VNUzdlzo30BiRCWvW/4/gJoXra4d6eN
gIJl6e3D9/wx08mwcvViAkHSx8XuYXJ8qbKZlnCZxqjPlLtdflIUeIFXKKQR
1jF3+qQpFxnntS5YLyWgZ11ey/5ejrSBtBiK2WdyNtvJUl+C9a+jjyh+I8E7
qaV5o60Rw4pl/IPeFNRjdP33pQjwhq3iUx1AomJVjM99hmdmRJ08Qp0G1850
avYvLaAC24b39FOo3LZKL/hoEQzqB2IF4wRqNFOSnvZ1IU+BM77PlYb44Nmk
+6tE4E+2/+sUSGKuUdNqS1qCnrTcGu0UCrmc2Q8y9Jqh59xrfLyFQuB2a415
2TeQLJ0atYRL4P4r67ySs3L8tW/7dpbiEDq0Zx1w7i2AdopjKauTQPbJgKHQ
iYcY3+4hldUTeNT0qXEwvwQSuZpBjyKJBmrwS89pCfjTb+65+AuFH0Yzzq1s
fY64+NoI30ISmZ9O6L0NFMBK2BuX70NCNSLGxnGxCLdPiRa7uJDITTV6fy6/
AxOHP4XltNKg132OMJW3QNubMHHKoLCy+5i4slAOaXJqYa7hEPQcsmTmVzpg
6qqxpGeCht10wanXsxpwVcVOn3+Xgu/oznd3ByT4EGf2+pUmjfcD6ZlRIzch
FI1fVz5P4KIxdUp5uAuBL2qvmjB6bmO7fSLNr+AQrZrQ7ENg4sm51Bv1zeja
ma3twKWQrbHmutlUMSydl0R6gvFj17GPgV5SbCv3c1UUMXqv3DuPLyuBskVd
tECBhGGxe1BGYCukKxIcbMyYvEgtRGeMmxA6Y2Z/tBUFYVuT7QKvx9jbGBYT
r0rC7J/GQnHdMwgdDqzOeULCjWevfSSjAvW9rWcTmbzysmojKvYXon5TYsrW
jwTYD/JnC340wWT/u1l9jhRqjJ4UuSe1gncxMNvXgkbS9KBHUY6lOJq9QvCU
8cft+ttx29KbWBLi2XcmkkDfrkXx1n6JaJk3ltq/iYBu/6aDlHc1qHcrp9nU
kJBl6brtYIlhNuwy6TrM6N8xTBd6pKBdEqdW5UEghPPF3lUggdVv2VWeLyn8
fihmyd2yR9g7mLSA+Ewgze7Hb4GLOnB86M2sFxQF70VL//5qXA7JeGXYxXkk
+Nwav80lQqh3qHU5JJKouTqyTLdZjIUC6zD7NRQKf/SPGb5pxCkN+8RQhvdp
/c7uL/JmBOdcUVrK5HnDP0HKWikvkFafsOG0GoXN3bYqZ5Y34+cYWTWXT+Gr
9+S1sNu1kCnYBrz+iUJFRPzDCt8amCcLdwYwfccuU2sYNSiHSU6ovs4iEqyP
3QZ32B0o0M4Q91jReN5eKRD3NqOx6g2hJmX67b9S5T4LCWY6502NLaZw4Ys8
3fzwI8yuS1HbOIVEn8zQ0ml3JnLH7CTOR5g+WcuRv/QOwMYV5fIFJgTERs/q
/zopg44Gt1QhlIaZ7ZMRDjcZuVcravtdCCzPd/lJlSXFBc35u+wHKUy/VZX8
/H0dciZH9Lm9zPvfKp7+eaAeVlG2P3ZvoKC0pq6p27gVvir89nUMXzcn7YYd
DL+Sz9vyiqdQYAddm6iS9aAnM484akrj0JbkfSylejSUqci0+Mz/M3bZtnWL
CKNDA8HscIbHmqgmuq0YtT4Jzet1GX9saK+G2DTYrVelDTwJcL0+8PiCJCz8
EPz2oBsBHVdZ4bGxSqTPfrw2NprE6PE4+5S/m0HyTQ1nhFO4Wi3e4dLRCvUg
w2ihIw2l0pMrb2U+g1Wi1uK2DBL+AXP1c1QfgWdUoShh8qJ+tPiTDqsTyzV5
wTxPGrn3Mlo4rxvwZu2HoYoQCv8DxVLeew==
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk81AkbV0lecqulbKQSRTYk2vK1WUJqM6akZHVMpMOxrsKmRIZsUW9F
rhSvUq6dXCnjPssMMzLOOcxvflRUjo1SO+8fz+f57/k8z/d6Vh/zp9AWysjI
hEvr/73BXG374sHXKErV+mh+XgyahtYVueRq5Cc5/dc4SQLT3D2Uvp4+nHU1
L2McEYEY5drcz2ejJC635eTiEbRtSeVuie1FoorZWFK8EHfXHl4xtyMP645m
dk/kkJDx6D6oykmHTTbf9SCXhO+eLbYSdRaadx8fGdggRtP3R00F+kx8VWpW
eOclgZN8iF3pg27479wT9V1FDOojwvjEsxZQm4OmVzaLUbykMSkxvBunjw9U
WXiLEK0YAW//u/DitFoUD5FgjW4fGMpkYe/DkrqAKjEm5NZbeo03YKfSpf2R
ShK0q6qP1XsMI4WecvggT4hs2n+OvqzIwFe+es4Mi8TZ4rLSH3UGIWLvtsp3
FIJ4k9hSr8/B3PMf+h41itBFclv4Bb1gZst4J1QKoGX6XGHauxv9ir8E1d6U
4hP+YOIVvR7M6iw3bTEBq9LJl/Pb/8YNW+9XCQYkSI+KM18+MJBhd0/Vul8C
t5TYxu+WpSjvefmPiQMJ/v3EmUbLDhwiWh9VJBKI4L/WcakqQ16eiQLtgwR8
dyaVPl8A3UHP1NAkEma5HnJdBl0wueYi/um2CEZC9uPCKR7oWfTggk4BTqq/
7iuz6YbqtqrenBQxSNGpv1TCeAid3ax+9B0fZyJHF69Ra8XWJwUed6bE0Pr5
jLN7WQPuap673mchgWrJbZPorHywovQUHIOk+HJLV/o84MIi/ERwrssIdr2Z
31oaxsEhhbMe/8yJoPveJ5Cm0w2zvoRkHBLhTq4/jsbxILBQHcp7PALbzoN+
eq7t2KZLXceOl+KjTXt7vu01/H7N93mqLwazvHzRrwG3sfN3N2VNAYmva1wj
fbRboHxrYVpmhxi+tuwtw9dZKDM5kvdPwAhu1HoPWKxrhHJxj7tXKoGx0HFD
ilSPz2JqyvWNRbiheZK+0a8WWTeNzUa/EshXah3vcmYg/rbGxVdmJHSCuFW8
/3Fh67Lfd42CEN6cx55Tv1Si31dnod0CEpHUtE9WGu04kZ57aeg0gWDZfrfC
ggaksg3jN5IEzuiG6vlQO5DQuLRmJplAQFyTHutNPVTlRFdVpfzrTFpUyDxm
w9n9j3FrQoTPPuYvftrQBmY+cVV2MwEmdfO3uZk2xKn9EPpWqm/+5a8b1b60
Yld0wt6oZDGcp3btKtzNwfO92avztESoSMsbHhcyIVR19/EcIiCvn0N6LK+H
AXXCY20xgewLCgdKJ7tQ2qDzo7miGNGV3ymra7Lh5JIXsK+EhOPskBU7twWr
tOTjPZoJRA/Imyl+qIbmirPcYYYE4w6OSw5cfQOm1ROtplcCUO3PUhkRg4jM
Nh8ctRzGFfWi++1H6uGblW3F4RHYPmsnOXehE3+plV4Kl95DE0xe11TpgdOF
kCuVriNSvPYVJS1vwIsFlO6WBwRGFG0PKCf0IU7RoDM4VAQmq5ev5FcO3vhT
SW6dBBT+S+/lgjq8SbK0tNsrQUaQpee1oiqEGsl7n5L6JW3u1JK7pp2oTm/i
uSSNwCz9gHbt332gJN4KmaQKEGBUOTcf8AScBL2prmMkBjT01EcDmvGElnw4
YBsB6rR6vf+1HuSOfsyMCZHyrf0l963Dc3wOI9K3y5G4Gbjs1MdnHEx/u7Pq
mHT/eOElWuc1FlZ8PxKvzBFDoaSQzkzl4rzxJ7fTzUKML9EPPunSg7ULrGfX
HhNiJnElcxO9C5511rWx8WLsi35x/tyhbsyw1OLrVEQw3ut8ldhYgc9Xp1U/
syUIy6Tr1ZWVI7mzY8LOQqpHQ9NXkbO9cNA2dIyzE+CKcoi9dhcXYWtSmo5K
8zWqKfZiUEwRxNUxiZMRJGR9P2YcNKlFyqTit5eyEnxQqQnps2PhTyYv1n4R
AcEfq3odsjJw2X5ypr2OxMOi9zVeT/tBWsN6d+owgiN3Fp5p6kHOVnrpn7Mi
LPNf6bRZwMaY6SajPc9EuFDS/tuR6F4YtC57P5cuxNovtLFofj2+OWxLLrKR
QLyIEacRVIfrpxnvEt0lYFAMZm3H+jGhbaqfuoYP+T3vDts8bMaJyaRrJ38n
cPFRv1/Ui2d47DWZumA9iXf3GBGBiRxERhiGUVeJ4MjKUVylW4261PMa/lK+
yRtlJlkddSi08wzSnZXqh022aMty8O1DWdaSISGWavBiwyuZqMgo8KGkSvMq
a/nTqNYyCFUCyxp1SYArd28HowQv5OcrWQdIFDMX1693a8OOhtabi1YQ0JOh
KSSXPkEgzc/JPYZE2idn2x1Sv5n1qxtmSP+TUT/vcqImFwuc+mp67cXIrFLv
drnfg+lbvxkd3jEC2eP2gTaubWAkEPNWStJ5lK2UCHEzlk7RNZ4qENi36c7y
uZ/zcGfwYsdWqf82xOx8m7a/C1Tt4ZtK5SP4Fyp51FE=
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 91->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk81Okft7Y2IlR+jqVzM6GTUnK9xUZpxCJHGSVHpYjsItocUY4tVIaE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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k4VWsbx1WoJKQyRYWSKCHJKfVXcaIyVKJSmkynzFSGFJWidKKEQoQi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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs41AkXx91LmEKxU7PSTVO9qVxzWV/d0bTojWcrbYqQhMqbKaum8npT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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81AkfxyeDEJuorZXsUE+xq9QmuvQRElFEq1LbISrFJtuyDSoUkodJ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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 92->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns41OkXtxK1Yf1a24okly25NWlRunyqh0IRWpfEjxUi1q2i3+oiqayd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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Ve8XxYlKIyKhASXR8CUkSS2kUkmSZqFCSoZKhVAUkUJRyVyZy5CM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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHtYzGkbx6ckoaKYmHUok+gwKlk5lW9jsek8pEirNpRIYYV1zO40ckgh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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk41AsXx90ukTZkaU+0ShqKJHxb3NKt1KUaFcpOmSG8mlSi283+pozb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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 93->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk4lekbx6WUKVsz1GilJEwhyZ5vSoUmyZ6MkKU9nSRCspsWy2GkrMnW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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4lO3bjijRpoRKopBStiQtnCptUilCeYlUWryWyhIlxVu0qsiS0GL7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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHk41PsbnbTccpMkoqi5SvYiirrlyFKSW5EWkUr0JK3q6tqXhIRG1nKT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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs41AkXx0V2pEQlq+zmVtJu7pJ0+VoV1uOVxi26kGtF2iTXSqVs9WZj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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 94->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8ldkbv92pRpOmRoliSmUQRdaxDN8SMrckhIqKum3G77ZYUtFGWZpy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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4le0fp0RvJCFFMkqFVDRkxAchvREJlaRIXpWiRJIkFTJLVkZGySpR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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVk3lczIkbx9UL0yTtlA6lbatNIq1iRak+El2uSheK5bWObl1MKTrEdjFJ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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81Ikbx0cpJrpp5Qgt0ulapRYfFTmjpiWhA2VLLdV2jEg0Wr+VlB9y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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 95->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns41Gkbdlq0msghJWuxPklO6UC+2hvZnDYiSWqMHLaDISutU0lRaVms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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lG0bxi2RSpaXRNYoKYVKUclpT6hUlFTWEkpJsr2KEtErIZSsLXaV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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41AsXx4coa00LauhqU12XG7oicr8uymi7pSmSopKlJFpl3KtEK5Ul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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs4lAkXFz6XFGLrSyRpu3wbiykR5ZehdVlk0YUuyqeSwlbKvcu3Ma2Q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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 96->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8lFscxoVEpUVSKtutpAWhNAqPbEl125AsLSIia7cspSxD2q6yttzU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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lusfx1FGSmYqnCgjDRmpED7oVJJQOlIy6lhHEkIcW0ZahCj7SNkz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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk01AsUxy1F9aKk0iNbIo8YyVJKXxQZL2mhkvKispQ8o/JUkteKFpTK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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81AkDxieVJWrlVUk5qmGsSkTlpfZRKyRF6HiJsNqNQjXOdEiS0BCy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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 97->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lWkblkYqxlJk+U6mskQdOyWpS2E09haRqJMiYSJhkLR8QodEEVJC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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VPsftiVJIiRUVLaEEmVJ95VKlKRI9qQSkSukwrW051KEQqRsqZCE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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41GkfxpFLkoRVWVdKG5ZK0puk6KadiorSCitKyWFLSRqJIsU0Kev0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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk81IkbnmIpbNlqS2jCTo6diEiJPIgix1JqlXRMq4t+6EByhVhHpSgW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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 98->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnlcjGkcn02XKyS2SLRFFxprihx9QwZJupEQW0zUFjsddlOjQzrUSLLC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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8lN0bxkep9CZUWiwVESpKklS4ECUJKS1UJKGSslRCpWRNEioiIRKS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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk81Isaxic3lSXRyZmWaULKNlroUKgHVxsRklNIq3YlpWuJEkpOnaaT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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs41Ikexscl6apyq5WatGrPuOTSSp3WO5TQkVKzGoaSZReHSCVFulCk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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 99->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk0lesb1TE0oltHSRKlXDehkDK0jSXVIZmnpEhlbFAol9A9qVbcchGJ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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lv0fxRUyiidCymhJKskshCMhSaI0RfSohJZsispKyyxJUUZkbwnZ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41AkXx2dTKWWotPVKRVlbyKV6EdmvemlJdNHq8iaXLi7lrsjaTSNs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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs4lAkbxieNQ42WzkVyZpdQzpFuZMqZ0oEtrSgNq1Q+Ce1W8kkhlYjQ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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 100->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns41OkbxqVpKzkUFdlWQg6tCCFRt+OgNkWWLbOzymnskkQOo5ZaUVgq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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k4VX0bxZEyJFSSSMZKhRQpwhKlklTCYwiJhIw9lFQqUpJQJISkiAYZ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk81AkfHqrpoHJlY4W0HSuRPmHl5VFhh4QOpTYs4VW5UioUFkWaWqkc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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41IsexoVuynKHtqmjU4oWKkqLVF6VsrQ4Ua5sxS1NocXRjVKWoymp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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 101->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVms4lOkbn6xDKzZKpaKmHEoHSUglP0lW1tBSk0NFTmkqCo0VFckqp0gJ
6xQ2KbUSOWccSk4xY0yG1CDWUyq22tRS/+f/4b3eD8973c99/073u8zdz95L
isFgJNPn/+81uUkOJ491Y++td5zBEAJH3brhHLnn8JysM10vJMj8MSW3WCLG
aNj0nJM8grmH2+ESLsKrDsvNiWcI2uy9x+aFtuNC/u88rYMEZoJM4dSWZqjq
RZ5W306gpyNdoNrVjo/Lc9yk2ASMxfLrYxhVaDf46LNsLcFxt9Tjb3q70JkW
fXfSjWD94wWZMzz74F+oP2EXRr/X/PeydIsvMvf1fVRYTvBFrVI+MKgFPtum
d8nvJrjxdCpJni9EVt3jyvhDBHl2sU+DzITwMXS+FJBAIIkOeOSjXwjJnrq7
MtoEhewqTcdfnyM+aLn5WB9Bl9jTfFNAHzwPcj9tSibgkcR5zNsdSJkjV3Xk
CIGPVchDb+VKxOcW2QetIbBqvO63VEGA206Hsur3EzQYabpV5wjgyWexzLwJ
tmqLagbkGiDq1ptjtJmAuZ7M8ygpwgj0i/N1CGLVjaRfOHRBrDz4UTaa4Ij0
yiJvhggZX1Ur02MImr2UO0NSBcjyig5hcwmE9xo+jJfW42xGmYfLVoKKN4U3
64834OmL3v1cY1rf5+UWCScTkmvy34I1CbTZZqeqwzvxTZkxGnCMYIcdd7V+
ZxLmKOm1LtcgmPkB6wazbsBRlidbQvEYGhTYcuW6sVbnv79jDlN8nJpjC/xL
ELyrKjmF9uvDaSMq7n14wxzRj6in9+12DROnVMI5vDCmdz3BV7YpmxztxrdY
d+3RQAKb2t+Op0vxsHU0QnbTBoJqVmoJ27MVntO1j9h7KR+m7p9/Hj2PlQV2
C6Mpnw9q7dMqZZowdLIxPoRFcF5cbKy5W4iE1Jq00ktUT34DJmfEtyFxvPj2
Oe034dj91zlDNdDbznk1rUdQYr25odLiPjp6c5U1VhFc+Kj7w8qdtZg4y3dT
MSGYyo0TxMjVYfKu8kCjIUFPZMOVpGA+Ek7HpfGdCPYVni6J76tFwHpmaSit
N3j+/K+hsl2oTjvm9uUAwbXlK/KtZUWw3lCUpx5KMLFRXmWHOR8WI1ZhP1O8
1LRCRPv6eFhy4ffaFCOCtBkHVD9n98Lyx7WK6yi/PoefTqz5IEJPm/KeXMpn
rFVAidrGCnyfejIxrk/xnFpuWr5UDL/dixVNSqgftpzIn9CswbkD7b5dtJ/x
6IFPLutu4abH5B/BdH5Jq5bDtaZsvHINFa/SIvhtxnzGIVcetOfql5vQeZmN
3rxIqW7MLJs9zssgEB1cFKLzQIiIuIr2gxcJ6gy/2NYf6kaoiWjRcBrBw5t+
Q2F37sMngVV8YyWBlFJCa1RtH5a8yb5tfYX614lX4LQvFJMDqvWGlC893YG3
7dW3kGlRspZP+8mzDGebf+uB7X3bW5/9CArMP42SIDFm3c3udrhOsO69TL7F
lWd4WyevPUrzxWa4PkP5Wh+2qe5UN8yk+vl9Nl/x8zPs0dik+/o+wfOiBWpR
rMcw5n7eP2hKYCKpPOj5Uzf6S7+qt2URZOc6p4VcLgJP+lGtItXnxMy+SM7f
Ygz7qc+98YCg2yAwxL9MgCo7lZq5lL+8WMUu6a5OiMz8uI7UD8eDLp9ZzOyG
1J3vqXlxBOms1Ib5e5vhPd3/ZoTmUwauSprvtGJ+PeP0gl8JEntcE3fHtUDI
cjRWsiKYZN9J+jKzB3pDqQeQTxB6TSdkwXeqX+aA0Gsn7VcjVBLOy8Og2mPO
CsqPsdPzNm5sBVaJOYkrKZ9hV6MHMiWNWKbm0fR6B8FR6atvtEgxgnSbHDfT
PHSTe3eT1SvCT1xDGQM6r2nlhKzn+0eYYrB+CaX+b4yy7l+Y34VX8fdWKNC8
HYv7FHAx8wXGJd6GLymeSk5NkXvO5SBtwJyZSu/X7G9aWBzZC3FeTX1bK8XP
sPfQaGMGOIPWrqU0L2wk/mH6PzRiLPkSy8uM4r/3/NKLT1twlATu/EDrqxmy
A87o85F8u2DEhuLpPqFzoShUgNZjBVr7fiO4kpYaZ9ArROAiyw5TT+rX/U6S
I2Y1tI+lcpYGFN9xDzuHnG5oa1i8dTlLwPrZKH7Dqj5wrmflhl0leKHNvVmm
LYACzzHZm+a/87BM/Ir3XQh8NqLwlwfNP36wqlZBEwITdV8OWRB0So1fUklJ
g720Zcts2v+3ka+zqx1E6JhQazlxgiBlhxwrxiUDRlFRbjn03Dji1OTYSDXG
LOfxDGhe2q9WdV0g3498Jc69YLrfnGVu3dMdPYWiNcEFOlTfNvYKWXdE3fBt
D1Den0L5miMzvqyCi8jLSTlMeq5b1cd3udUPqbVeooAc6seNPcpl+/KQ7Pxv
eQvF23vGK8LZ0obiwHTmFaof5vdS/6AtCVA9Je/JoPmbzf1zXoRXBYqsXvyp
RPPRrHpreoKLGKvG/fNqygjKTxhHjrpX4IVfenQn3TeqV3bVWnlkQ6md42ZO
58kx73lf/0AAp/CVC9/7EkRH/KMScrwXi6b2ToP6OTtlOGPw2R0ssfquOUj9
rHm61cKkRoglWoy3S+h+dDSVfiK41An7+F25DFuCjxe/xE+U14Ej+cXXcRsB
MU1jf5Lio9EqgUxR/m9udM41aSmD4OGfTVk07zurxmTbWwqRE/WPSfsKAks4
KN5L6ofaqYjy/wQEga1S5HDVMzz0a3k3M5vgr1DLLqNjQngdGVwSRvfjzo5E
g9U+9TAqj9+uQfPyIVPXrCmmF+d3J9Uo+RP4NiWluyzi465TFaszmGCXo02C
gYwA7kP5n22p3o5M6pmN7G9Ah3ZzIpPqy+/MARX26yoU9ir4KtB60Sdl5v9r
2gDd64k/qVF8vZNmjan+IMQuvmxu8jmCNds37Tg1vxbcaV/7J/R8alRj8QUb
MXy+2l4YrqV+Tl68R4bmf4jW3eCFtF/mUi21ZrlssD3Vh2ZRfoPjrY0vmQhR
qmw3rUjxfFeX6Eq2PcWPj1ryouj/CMPU3trj2x+o5N07e47y/T8NOqrS
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VG8bnkgkUhKSipKspaKI3JKk0KK9kCRJJZVCi6UkStZIhQhRlmyJ
CmPNbuxjKwpzzpiyFS3y+97vr7nmOudc5znvc6/ythcsTvExGAzrGQzG/3+f
3b3ud24FC475GW8YyYNQPJhyLWtJOXJ5yzTQyIGDzW4Re/2P2Kyq3/cojYLz
7cHeMMdmZGhlukw9paC3qnYr+20tqjwH7mIbFwG+fSqhs6vQH17j5zNKo+6X
mGa1eRPO3bhxcH0Zuf9H1GqeSBnyxDZPPDlEwSgwoYFPlg3G8vkN/t840Fwv
PXNarhqKX3ekjn6jMY/b4XfVIA9GVtNPW7Ro/Lqk1SNxnAnnX4afI7xoRD2+
J/JpvBWx7VelN9JcZCTvvurqVIY1Q83zBSdp+Cj+6/vBqYL16ZuiulYUNH02
3dEQYiFw35Zxq2gaAbyuN9eVyzCM6bKcRArZftMStbGdSKirEzaxHYBe527u
+6J0pDpe+BDym8LxlwKcr1UNWPWv/UBMOw3GoUPdW3+9wi/5Z8O3JWjU7Gke
qFD9jBmcYq70Mi6m2yM5OcnNqBkWm+Olw0WoWbHuZg4blhMq+V9SuJjhqez9
eGEXNsfkP3DjG0RCiEVXsUEDzjiLbCk/S4GR/5LRVpGBqMqh72WLaTzx3rbC
6UQNMnaw+XgNNI7w/f1POLwJKlY7BUMv0dD48mg2M6wJKQs7ynP6aNgYr/5X
MJKCCYGciUyQeYvotwmlTjB+/cMyS55G5GaDqzNMWOg9813joi4Xlk8LP76o
qEFL5GGdpM/k/nMmWwRfNmLWnAoWS20IcmJC5vI3s/A9pSrNex05/xVJ80vs
G/Eg8bPo5+hB+D22dK+5zsSV4wpGintpiN81ff1kuBKj7uzFXYZcaH8NW3Dc
PxPCSh9T28k+o0t/Mc7qtWLNo0bzI7oU/NxHleLYb7GMZVr3TJHG6+ml8+xK
2ahfEDO6cicHXm+rmp2Yz/Dr0SXHORrk/V1/xs6bN6JfI3ScWsDFVKveM7m2
BsTwj720rKVhwDQ4mj+7DcO3FbrOZg6i8lj0fzNMWjEWnbMoVoGDnKnERLG4
VljrLT+kunQI615dUW0VbYbakfF2frLfeWHHypyzStEn//hW8DIaSn+L7qWv
egTtBZeW5ajReB5+Z4fZQDve73gfIXhwCKl2T4w3/2NieM4bnx0bKHRmVj5+
M/MjfBunUw7p0DDOtj61IageCvOP3Hdgc6AdIp7x1iIfmocyjCve02D91mjK
7WLi++65p9lXKWhfe369wiwLwtayIeq6NBzmX3t9N6gSE7umK76eo7E0831x
UlgrGoIe1bFTBrExIXhb2NyPCOCfoOgMGhu2CSe23GYhmTGz3aSGA0ZbJeOK
UzgKu0f/JZL95/quu3TepgdjJ8Q/FJ/kwXEidPom1Y3s35v25WV+Aduhwz7V
pgmzHpZOPlnHRYhVbm88Xycuu03YOFZx0Pvk6aZj3CS4qV+fX0TO53DkxNPo
gmzcviNw2m8WjcpJjfNuhg24kGo5bFZI4ST3+S692kY0FW1erdRLQ8i7OaTd
pwSKNn+S6sJoxOqPDDJ55cjY5zxxuZ0Cc6uh+UeNexjz/yC8muAh2HO94cu7
L7BZQJO3k/AtISWQfcU8CR6J/6XHzKVhXnp2LHpVK1Slrr7ba0D4v2OP85dv
tWj65+0evZILA/7sYc23adjquyS1XYGGRNde7brjbXj4WT6n+PIgGK5P0w/q
OiBma69uDzmf2HZF9f3KFVgt+pNfhuDp4DtXl50+7Ri0ftAYFkvDL1Z5T2h1
PKYmC5laa2nUHh8NqJAqhffot+1G5PsTfjC09oY/B3PeNy295TQUe/z8Krs/
YslJ49BBfxrLd7zJGe5h4eBcy6+eklw0uRveE75VC/2TSw0kdtFwkazqu7Ox
AkHOTkrOqhSU3v/4HaNWiBJm7os8PQoq616NBXW1wvRQZOZ/SkOodNx20H0y
GzlGjlEnOygILamvmN7fihZPz6YsPi5GviftffypA8GGVf59ZB86WaJN0R5t
uNSrEl+Tw8Vh5UTG9MF4zE0IUn1K9G5E+ufK8KgG7PzklSVDnme6RDB21KRh
RW6+VbQejd4e+W9J11NxdbcZ5cehsLxn/zUZ+TI4pYTlck1ppF2sWOWg1YTe
482eczMG4eD74Fzx6groBybk847SaPFQWG3U0A7nlnWJkgkU1Cz2utjFM2FZ
JfV2hjKN7YpWciJyjRCXXOArpUAh9M7FHMfqOuyReWl++xPh91TvyazLXYgJ
snulY8+DynC2j7NVC9wuWthZ3uJg7mRBz953H6EiuPDwGRaFuaemYyMs28G9
K7PgVMwQIp79lhxJbsc5jUJ+1zGiX4fTDhUPNEBkdX6kwH4KD/9wjhpK1qH/
56KjylU0LA/NN/Wzfo93nVNciSQKF8QzfFt2VsHn9dVIv3tkPiF1V879VohI
zU0ZaOeASi7df34qF43hC66GEL2cOTimyuLPhbda7YQf0euHarrpY9W1WLa4
u7bRkQOboKfZNhWp6Eyu/7CV4NfPpVAmXL0RlkF/0kzCif4/b0hn6LaBPyos
5V4mjf2jOe8vFZSjLeAn+7ElhQ8nkMA434HUqV8Oage42J7C/uc/2Q63j4cz
Z22lUd+uCaVtJWjZe/irmhwN68iNvhcHWGibdsqL1eJij3NVf2JuIVyUgrZm
Ej5+SLnl7eqchzfn4+uWWJB5B3Sq4t0a8Ssqrjk2k+Br8MzW03sLUHTPx2zj
TOIXlZPhVj+eIDB2dsxmogf91Rf4erd0IY+KOuNRMYiR8A3c1vtsJJlwA/UN
aWhOzRYZ8GpDIWv/YuYADbnTnj+s9bxxwbHfs4TMFyyQOfuyaTzOLBAadRMj
fBrfUzQi0IR7++oPyI1x0L4yo2CK6KuHwLVD7aJEr+3LmNf+xSLdvfCUwgoa
XrsvRJzwOY/vr11SjhL+CfO++57WKYaKVPSSGCNy/acgX8yRHLAue0f8I/cz
5aNvGGZHQYIOcVxM5ne+47+Q8zECTxXYc8zIPCwDxaPmI2yYmnnfUDzAg/Rp
1ZGt8q8Qui1n6WWiz88VFruY5DQikiF84q8DB8lSx867LyxG4tmXIufiib/9
rrA6VlKI0nfr5kxXUoj1e1sUoBCPvhCnK/claZgc9Ai7J/YOZ2PXtygTvMiZ
HLCJM/iAiPTcnnXk/VO/N2OTKgv+k/s9cq0pJFyfLx4ikwnO3xTZLBkaYr4v
LcoUm8ALnOl0sZOc74ztYRKyHXjDlRg86ToI4c4iry+3q7Dz2Iq/0oS/eUz7
O18CWHjuJJpWKUSh4putwrBZMczfbW+2zKZxbk2vN19tGcY6U3JHemiMnX3y
YmVzLWrXFpxOTiL7+Y/hMzmZSfZXZpC5k8aeCRndwDUsTEcvFxtYyoWSb964
5b84qBdJKF8l+eXdpIeuUCib5IBUdd2LRF+3zFg/erIcG7TmCqh+ofAqVasl
r+oDXC5eUHcj/6O0V7bPMmtGk3PiRc3FXLwqHl3zWoyN2muvxz3fDCL2vvWf
OY0VkH4c6v/WmeSdtif8HXGPkBzzOqpGhcaz+4Uq2zjtCM4ZdVxL/MLC3KNc
wr8TpnYBFc7bKCTZl7gmjzMhnqsZmMCl4LM9c+r+9VKc/mt4SoTkl3vfY+T5
mD3waJdSps5y4fxwb/0Rm3cY8hH8stiWhqyZfbh6QQkMbp3bf7ya6BHttUSv
vxbdQi7Gfou4qK8Jct00Wouy1wWLVqnTOJE2X+rZ9U4MLtTZW5TGBbXiQrr3
x2pcqeHX7bGnUdKQO5B/shayT/psuvMoWDYzky3qStB93HzdWCrR/9fG4Q2C
BehvOFWqRPSzojLl5NnWRsRnuJalrSf6wcm4+by/EV9TjThL/pDr+5Zay91t
QqC29uSgDxcftqtnngqrhlcDbFlEX6zdZw3bvCiB3kZ949OPKewxGbe78qAF
2oxoI7YYBxqlzBtxwSxoObxJfDif7HNIlr+xpBVFPkG51b8G4COnOzxWU438
fKXFoikUuiXFdJY6NSPv4fJTBnEUjkp+ZLGoWsRNnDlxPJqCm1OLyo6vzShZ
uGtMgUvDaDJmTUkWE7sCzm1QGaVwRGPjM4kFUUiars3ukKIhIn5Dudi9EbbO
ve8lZbjo9txtZUL8K0u5dHxbPI1N38SfXr/fCIenS1IWjA6ApbUlQuNUPjaJ
psnmkTxQL3yobPvPtwhsGLdXtqbxw3yp3cnD7VBbmp9mMJ/G5BpAUI6FrUJO
kQGEn1SI3PzTxg2QHLh43KKBnP/Q2p/OM8ogVFfz6PN6CvM6ns4s7i+DFsXe
4LeaQkZwlOl9uW7Y5QuKOgxzwbg76aX6pwxB+YcaIk7QkLb6GM+WZMHm9rDg
PgEuvvDnmayvb0SU3tm66kaSP1R1pWztWnDI8ceBR3soBK8Xtu+TCkOk0m5R
BVka67f9u1KR2Qb9ZfYHD+YS/bny9n7g9zf4niyQfG6AgoPBzI41Qa24FPph
k8/fAbS8eDTe0sKGkcMij64iCjv7Za01KqrwwG55R3wg4R/rolzcgxIUui7d
eOMuhQNq8wRUM5tRNjktE/ueQqGTxpfXU9VIKdayaL1N4RTT+eYRbTZeDNfY
ampxMG8f93DXrhy8277pKGuQ+LV829g6fRaWcy7+NG7jot9wZ+0i80rM3JTi
mE/w2+tjyjcz7RW6El6cPUL02Scpqo8pWQOl8uVmUku48AtMuLKgvB4zLnmZ
85F85vz7p0uqtA9KppP5a0j+4gWaO4jTDdjgIecURvhW5t7i8/UuE+EvqzpX
D1H4sV3Ty1SrCk5NfyeNY4hehhj25iILPyYXVK8WoDGiEvhfvh2Zf5qnfiJ0
CF/Criyy31OH378CmTNPEnxNqp4roj9BTrVvtuAiHsxuVgSGL2bih7fDLv0t
xM94a8N5whWYG6TrtXeCg5G5Lfzvhprw/qV6tjzJ39W1awIEjTswnXvngn8M
BzIFK8b8iZ/p2G0rv5w0hADRDY/0NZrhEPvTYvIU8cvnWuEDy7LwqeLpqzsk
jzjx6q0mTn6GgKOnv8fKITxUTXnT7JSFeerh7iX9FCyO64QeeFWLB5lctbsE
H9qet7jy9rlgyO55oHaewo5vDrqh8zoRv+OPK2uSixyBVabWG5tQv28u98YK
kucuNB3l2TTCcIvTgluyBJ/Z+oWM+9lQOfiKeZ3o0Y0074d0aSnW7FZRPk74
8UEYJcf+leP54SNxZ26RPjm67NPpt9VYnBw5IymOA5HlITtUF1WhKCe/PGo7
yY/ud0OeRbXA0NbcV2EjB4obaPc//Sz4XE7nKkSTvOl3+0n6+3QszXvkMIMm
+cR2YvrUcCsSnqX6HCP99WHQ34OCinUwajK6udGP8CVsQVXVi2rcmFb45uBK
Y77kbk6gWTt8t19Zfo1HoTJuQEfXqQ5fz8wyz1j6f31Qu/E1uAH/9L8eqDOi
gN9+Hnql3bBmcoo+LRyC1djRByI/XyH1teuZniU0MgzFti4sLoSs/bfptTUU
2AofqAUXK1H9uL1mlOjJOjHtku47bHzjHQhwJ3re5uv8U1q4A7c81vyt7CZ8
0tbVYLyqQP5mL/UH08T/+CQ2RZVl4ovtqLH6JuIHCXF/WMk5+LZIpY9N+Hsp
Q2jtzZRqfG/miB9RpUGl9WiFabZiTiBXtzaA4D9uXGQTqxPigzI9Fz8Ogdkv
//2lTzB8D3Ae8a2iEcB6wVm1tRWWWWaX5hUMIKG180yubCv+3dVolSb++/BZ
QuujjZ34M52r0ZHIg/+q4gbj7UWQSZ+Z7fqCfN+v+wERih2of+h6s7+Og8rs
gKwrTekISLwavPj/+O6NSWaybyMz7rdpGMlHTLmcDo99L/D9cMGMMJI3bB+0
pxRk1YPx4tsveSkuJiRk0xU4XYisDoy5EMOFsGe1WgTpz/ciMt1aP3OR92FR
Q9bbGhxr6g01uUryadsuDUXPBtjMWvTrHMVB7EbRZtGpOniYmZhEJHCw/1jd
iMa8Sug9nBlkwiD97OpgcOmtGPhZ5UoIkT5l+7LwQd2zHmQsud63PKYfjjln
hrc4sbC6bHxxQhYH7NGcq6Ih5ZiMOnCpaJxGcmVft3pxMdJTtEUl+yjYXBs3
WTub5BV+5dqxdNLfKyNFvpVXw2WhbY7YKOm//6kvC7VowFhYl8WGZAq39rE4
kZFs6GeVyBh/psDYzI7R0bdB4Aa1kY1Ej6SnAs7fimXD9p26LG+kH0rpxyuk
97HhtsVVc5bUV/B6D7+6UdMKhYDET3J3yPNZ8PSgmZgn07o71on0JaW5ry3u
JkLqs/DC1tkEX6cnpFVdulBndXX58uOkL5tZBaQdKYKbESWiRPJ14V6e/Wxe
BqTXuq91U6NxtK36CTPlHeTu7y2oIXzYE2CVqaLjh9ARvTfGK0n+SI1y5XMO
gG3hp3sryD4tpyPjTQXrYb1LYv0LJo3XF4PbFk40QsGPlfz/fvFL5Ob6ZxXJ
WLdry/CINJlntCf8oU4ShN7e8a0jeF7G4xc0Gi3HloddTx7HEn9U76VPr2Rj
2b41+hWCFA6vcU62CK3FQoH0vxJ6pB8qZ1XN3BoLXv3aGYNKNGQCF/tGSuSg
d1+oxRjx92sCd3fvudKA9mD96ZFDFJrib+XInuiAS1iSwPYMDs5p3hgOq2Zi
oIBxpHoL6f87bx75Oq8G/o9bbvaRvs7ICfRVtKiFfbBWeuc9Guwi8YhU00p8
qEu8IOlIwUW745SAWBkMq0oVFEj//FAy02vEtxE9dkqB/CpcsFyPTjWWvcdh
h6OPeCT/G1wScwssqEJNLW1TTfzNzdBIxmtxOapM1/lsdSP8cZAy96mqQ7Xo
+NLQ1UQ/n5rJGTVfhlH3Om9xgofeQrueBw9y8D3g516a9HWhHxni95VewJa3
w7dQnIbHmqTw+eEtmPp5yOToAAc/NsxyHfzcgNucUFbuRi6itiXmT5qWwOtA
mY/sbuJnqsz9K882wNe15xyfORd2KVJz1mg2gLky6I8RyaNCBkMyRy+woHJp
lb9dBwe9eS0THkHFCBG1EWcSP9LmXc++HNcFnRbWjPvfufgflzMkSQ==
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81Pkaxx1KUpvLkmsu1R5nS7RhcolPSUpluyErm0uEsqQbaQnhVEoi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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81Akfx40VtYWJeSRpDWJfytJaEYtPZB8q5Vylc9IhUmTLUYocWzHK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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 102->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns81NkfxkfUSkKk1OZOidJGyiU9bJQkqd2XS8huSXaaRCFaiUJhCLV2
CEm3qWSVLq7rmvswBmOGEK1ybCG01E/6nf6Y17y+r5lzzufzfN7P8z2ah07s
PzKPwWCk0s+373+qqmt6374AKyHLxMiagNklm9MaI8LBJM4PCY8JruVKyypP
duLgK//5eRcJQup+Fs5ItcEmxnNTiR+BktYBd/NdQgiGFIXvkglulRa9Dvdr
QvFkpXnbToLK1wmbPVlC5PSLz8eGEtSccAxi8NpwaEdc+uBPBApW31/uyxMh
8L8DHdXhBAMykpIDh9tx0/N76eFLBOOPR5PVnj7DxAB59Od6Ara0c1bZBiFy
Zyfszt0nmFJoiZ2rbIfPaVtSwCZgpG7sUjmUjORM5ee9WgQpy25bRJqJwdz0
qeROPIH0zpkfh7eKkVjn8veRYgLukrlgkW8TBgcVfYe2E1yx3BRqnNGO+QzR
U1VfgjAJwb8xhXz87Sk+4H2S4N14lNUnt1pw1/9R/R/Vy+4J4975JXw4q9an
nzhOMNH5RbKQK8ACcVLkWW8C417tIUN7MeZsxBl16QTrnJYE1Zm0ILvKeFjn
FwKZwJ6vqo5iTDFZofppBBVf/sjPTymF3sb/Hd29kUCKsZolbSlCfGxjmWII
QQfb55L0r804GW+h+cMOAn6ki9QfCp2QH9M0uOhJIBQa2M6+r8XgR+v0gF0E
I7+Fbove1oPjT4d4gxkEMVEaN83Ge1Dbl7tu9QWCn2WK1EtwF7I3VO3WrKZ6
eK+yMFJtwOcKoRLHloCjyVWv4DSj2kT3qqc71W9urZKvXAdYrVtuMqMIHDap
TN8LbsAKD4cATfr/K7cvZOal9mBchydRGE3nfXPSrOVUN8L2vNVdWUrg463a
GBdahZDs6DOdmwjMGUFHzS+IoeAeVf6mhECNWE1Y64ohMdchqLlB6yt3MTBO
EqFIkKMZXEgwfdnydrjDM1R9rDz4nvLA+lk7T5DThgJFBw3JMwSDcz25h063
YXbFgpeaTKqnodyQ3T+V6Ig+s/+VEdXfjznveGAZrmr/1vTClCA7o9QtR6kX
ia+LjBT7af+lBS9yarvAjFB5VRxM0FjA9Zf/UYSRw4kDy3MJfvGuchup74RS
76DB9RyCbumFPpqf8iHabLRYR4/AN1l+rQq7GmYZp26fsSGw6t28gVV+HKMa
wSHLKY9i34PvS/LrsSLUbu0aO4JW/9KAEo4QGnHje1S5BIf0/KTOMGux7EJG
9ci39cskp8LxN0y91D9cN6Z+sElcYjL8EI2rWqLM1hBk1OoGW6s349/iB9n+
VtR/+gneAU7tWO32waiPzndJ/A7jNp4ILs/rV2lQfpyjKvZejaxFobVqCqg/
o7pW9tfsbYP5w0krjhvBxayZCLGNAGy5Jxd2BhI0cQ2VQ3c8RvaBj5umaH9P
AiVy1c+3oPlXs1W391I+TBb38xaJkMTvD9IKI4jl6XrnOnZCqv/7n8Kof1m6
PWNbRaUwbDC9+7sJgVPxpNo6YQHmpD7/ar2WwJu3S179twp8Fe0+67WZoHCv
2Zp3+S3gaClGSXsReCmEdWxL6oLjx7TMXsqvg9IODy9LIUbkPPiWJ+h+7HnG
AcwyVG5gTUtRnkR3FLWzOkqg96cBu4g+T71OGlBc1AVR+VDM6UcE+oNjfoly
YnBq3zSZlxH4GfDahssa4JzNT1rkTP1odNT61ToBHiU4meXQftTYyQ5/nmlD
fHFc/zjlX7RvPD1mQRFyBabJepS/XJfEfbyWbrRMK7LbUwhmqlaE6JeJwAs4
PnKE7p/Z0FXuJBQhenu6cPQmXb9g8ameh21wkPnwVeoYwTNH8d2ainY8HDUL
+HyK+tf/WUhgVAdcPzkFzYsgSGNtvaz1mI91iW4W9TSPZPOtZVpeV8EpWKL7
m17ORRcGKy92Yb6r9KfXlP/SxNZulYFmbPfJOezoSBB3TSF0a2QzBsXTQQ40
j9K32jxu6BBg9p328C/0uV46YeWtYSH2d7CavOm8P2/TXfKdTgN6vjud9pb6
WXaB0mT4UBX8yyu8bLcQaJTdVJ5zuY7dk+JH0zoEOpYkTdFegI+aWcq+56j/
Z/SM9ueKEDNy0FW/gPL58dyKI0I+dh1L1VSj+vq/7VuQwsxEXPdcxUttmmdV
z+tj+MUYOOh69csGgtpyQaSLhwDjEoG7j1P/eTotbDir2QXFB+raKjQfC/9b
+GDjWDtYbadHL9H5X7KrjXhpcxv6dUfyKnVp/neHyDdw7aAwhaQvmgQvR8My
Hd9VYSlvac5ZWr9KxE7J6fupWHSX83QtPX98wmJn/F/lMN5pZ+tK+YxYf94w
MOgkXuZWv1ejfpWatvLLr2tEpJwlV5rOn+F+I5gjyUGK6kjmZ7r+gLfRbGdv
F77aPbEuoPNkb2sLiRirhKxr4xZ7yt/sHduGeEUhmo+4MP+l9ZtywmoH7wgQ
Fjc5coe+T7f75ntdUxahaj7/siv9PenGCs0n+6vhvOyv+x50vrKjQ3k1q3ph
mMHTfXCNnj/t3+ixPBo16+Rn2LQ+Dd7eLYf0KnE37fcP5vS8GZ99G9LGxDh3
a6FzNfW7NHus/vBYARhZJ/l6VF/G/HOtnXkpCLreauz1rf9/1JYGhFWAG658
8oQlzes90kHPfIuxTK/nfOw3P715cNqU9xzui+89DKP5qfEltW5kqB41cwZv
8mlexFzWKvdQaYf9c4ugEOp3hdblJkx3EbjcpAylWzQPjzlbvXdrQkxPln8O
1c/xWrbUmxABPPQ3ntKj94fdbzLmtNK6kf05O7P8Cr1/MJvO7pfpgywnT2bh
GNXP1s3J07UeyfGyKtWUxz4F+/Vf2H0YjDVWaH5BsFSwsrFO4gmK7ORP7aN+
dErbopYqLkciR4WrY0HznL/oYtIPFWCFz8hN0H5eiay6fBYnIG9CzzeL6jem
/Pu7AkMRMkMY9k70PuHUf+Iezz0HoQqZFRspT7dUpvtNrtF+Y499ZdK8lPqa
4WV/Kws/mnqYV1P++Ue9pw5vLsOVV9GhdXR/1otZ+e82NCLDghsvT+v9PyOX
uJ8=
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3cgle0bViKhpFRKfUYkoqRkhCsRDaRFGxnlIwqVTyo7aYnMFCHJykrI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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81IsaxilUg0qpU046kqxpuzo6WZ6xhJObZJk6cq69k7iH6ia03Y7I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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk3k41Isax0fpdnJLUyQilKylY7puK74lUpoiJ7LkWipLqcaU7E5iqHRb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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 103->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lWkb1/kinWSYJKnJkiapmVRIy/ihZkYmx76kGUqiQqnsSuoUp7Fk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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VV0bxiVTpiRlSoYMDUhImtxCJdKrCZlCUSRlqBRvKUNKRamokBQi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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHtczIkaxrNyVtlx0mXarVac4lBZsy4t+4mHiqlpySUVtnvSycoQg0yX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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVWs01IkbHkIqQhfSqr/7ZUtbEyU5HmslRZed1GLdRZtKnFoVFa2yYmTY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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 104->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs8VWkbpemrPiZqSkzOSAkNZYR0ymVJaJIun6SSSCWXKUkxiORSuSTm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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lf8bxqWIhmQlDVKkSCLSvCRFSUZIw6yMfEOIaAklJVmVkKIoJcko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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41AkbhqdJ22E1TeKjk5rSRnROaUYeRca5KJlCtVJJoYOEHFM+lQ1p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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81IkfxidlETJRlEqJxrFsx2uzzh5lVo4s0VSrQytJjtJhdztUtBQ5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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 105->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns8lFkfR0St6CVspISkSCFE8aUVyqW0RUS5rK4qQ4m0MUtyLytFLrkl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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c81H8cxynJaGiJKCpKUkaSSl5NKyEpSlESJVSISEZSiKJkE5EVhVAo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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41QkUfU8mLRrU06KZQraSR6Wi7SgZpZKtoo0U2pBIsoQUxqChV+jh
E8rSiIpHWbIlS8Lznj0Vwm9RohGS5jd/3O9+959773fOuecq2btaOEiwWCwv
Jv7P3adW9V7dIcJBGzXHYmka444jIrv4xzj5MfFKhpCAXVBsjYVsPUKvr+eZ
X6RQesui5aHDSxgOBA1rsyiYHSt4pifZAg05KfcZ82hMNftN+K5PgrdYOSTW
k4CBmvmKbY5iVJ20/yYhpOBRtdpoJLUZy8plOH8YU7hQJWs9t6kaSZJhz9b2
kLjbT567trUBhZ9GTYYfUHhoOTmb/dsbLFaOpKlREtFDpsdUuAWYqcarc5Ah
oevr1dXCbQJX54KedQaF9yV3+n66VuDpW92Y/OckVOJ3u/BuN2JqyHxONNMv
ycQ9e8aTKKwKeFXsaUZgR0yPQ2hyB95zyy8OfqbR9qaPP+lRgvv+mUWXjEgU
XJk2eNcuRNQi2/stWjQWBpq0fBkWovH0Wvt0Zl6phTOPk9EBg9oeq6pxGoYx
BhbnNVpx1ja3qMGVRlKhPv+7RgVKZPZfl+aTMON+qhg2SwbHtTCq8CoBydmq
O23thej918LJVpvZ//55ITuiFgc01YWRwySCrR6vvXWzDJP5Nq5GR0iEz5BO
ULEToafzq3F3CQVZYmvKyfRkcLenqtUEEwjdVJvgHp8FK7lEu+epBIarvFQJ
YQt0XWI3hzXTUGCpTi8/VINHy9zEtD6Fnvbh6XUfXmI8lp3pl0LCxSlg3S7J
fJz1C3mnOZepY/bNbP7RjJ/7JgOPaNDYppUXvvKwAPNuys4yniKQePk3KsZQ
BBP2A6N79RQUrencHHE6QmzVU3ZmEdBI+Fikm9UIsfhZinYyhcZnGf2CtEJs
6lzCj1MgUcsnDQ9uzMcxXlqYwhCjt/CrL3rd6yGO15tydKKgK+3m/PVoK7Rs
5Z8O9NLoyllQZ2MrRFfthZLBWxRYbaayUVVC7M2rW/JhhEJA7VJ+XlIp0qPJ
5ARLEocqzU1MpcqwPGiGdrY/if2RcxfFNpbizHP/YGuGX+uI24vV/FuRHcVJ
Te6joFwpM79fsxHRqww77AMoZI5GT7f0d+LBi8lTWyyGkENWjy7pFMIx6fRf
RpYUJOK/PjGc1QJJTUF1exqFxT4DUg5Vcci5ExHUe4qA1+It+b3KBRgcq1k0
JUXCbfOcgNjSGkSzOVyrLhIJ1+4ukOBXYPqz3wWvaBIK17dPl1uJ0L/wkXyn
iMLBYwff8G90o61oJHfpzCEEl+uEH3AS4PahPv3VDH6LDFZcFHwpgl5y5e5X
+0ik+/zakN9RCdLzY/zRJhJ39NtvbrzXjpxBdlOJNQ0zyRsLi79lYXn3Wqs9
uQROW3mRXd/yoOSmPv2tj0BAZsHY0hvuaP4RnJDEJcBZXWosmvUU3Ez3Q75v
CSzOux+kKl+INmeb74FcEn9raMrwU8vgS17KSrhDIpNUPlvjKYTLOOm8RkzB
+k1xfsWZV3BXDZcbWcDcnzYV81UqHfZ7yH8kEwm4eK/rHFsjwgOf2L1H9WiY
Vhp2x0a9hINyqAK/kkTiPWHzjvxW7Jatdhu0paGo+H313ORspClr95vkEMi7
9HC6YF0ZLAplpAMYvs9Dfsx1vgi6v6gF79/F9DsyWbEuoh7vVZwdg69ReJHB
iY//mYufxU3n1nwlUO0jf/qGZQOkBLk/eQzfe+duLVL8KEL5Ku9u3+cUwlMO
cxKZfY7vMlLReUXC1PS4ONCtCp+2t88/0UciaSCukaUbjRK7+AtW5gRMG3e7
OpmLYHV7M6ttNg0JL/Nab8Yvjqg1/p4zxuDxTk5mzSYRpBXHRidsaPB+6Bxb
O/wUWwLX/20iIkDHvQ3w/1KLnRUvzxzXocCRjArxeViMa+k2gvETzDxL5ZkS
+skIE7VWxfgQuPFavcM+sBMdh2urcjNoFLmF2xuzX2Ns0s6Ypc74Q8ePhjzb
BujE7Hk04U6BN2/5uVsbGrHfKrF91n0KOda5Axt06lFxWe1E2FYKGpkrnLit
dTj39svdrH0UunwTut1LWrHwi95kawgNmteTEu/xChJzahV0lSjYx75WLllf
gYm7n8ca4hj8Q8NYkSuFOBzlqfIPScFLK9tl4lo5OINlmelhJGS1pt4k/lKO
8VDVLU5BJN6vDC37SxiNyMiQR+cY/DSsPWIEohI86++NHNEhEZBlOa+jzQdX
2FEcF11Gf45lRt4RlRAIbJa0vCQxuFdcMGqcimW/cv496U9gIi3e48Mfb+Fp
qq/GiaShrKV0QLyoAZfkwuiVBygM9lWyZz6sRoTfTsEdMwpH647+GBmswxLH
bJVtKoz/pi0IaNuQhBOtVR6azP8KPjzrye8bm9BmHHN5PJfxm5LRzR/q/4SB
UghvYCeBT+HneXrZ5WBvcraw9SXR/Tiny/1FJ1j7u8zZxkNY7bdKsaGoCwXy
/jmhSsx/lBOry0i0Ic668h7fm8Z/S5nX9Q==
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81IsaxskoIQYlnY4l1G3RlSWpqx5OxXES5aKEmsu0cWRMZUlUIo7O
FZK0cMuSQpkWDRKyb2UYGkvcMfOb+f1yZUt0yhln7h/v5/28fz2fz/N+n2eV
f4j70QUKCgoR8vn/NjCz3Odd0o1099ecoG0E7P2qNhTUsnDeNKdsxfKPOL9a
QcHqGR+OVsoeBUoS0L8H+uscaYXqzkq7+d8kMGXGHVEz/4B+QwhtjIUQ5Wld
b1rUifXFTu+a1aTQvq9qGunahI3XvDZfKJHCvsgJYcMceJhOJyrZUhjm2lR4
u1WjN1u5Y+YkCdrs8RZiWSPMDQTQ0iGR0XePmX/pLay2P1f2EhEo5PSSZ6/w
wNsBY/1ECe7VU6PqPj1oeXSrZihBhOQz1mzL0G6kmgypjxYTaL8caVD8yyBS
xKeMVnwZBjUZz7wVWYmBzPA4zXMkDvq5+A9mNoKZdrPZWEmK9Lrx0ZfaPCiZ
/7c/uIOAy/PE4DynHshKpOsCRCL8LcbmgGp6J2Q2h0Iytkvwa+XeiKfW9bDr
mbyZt5jEhJ6LIG7gAfJ3bIu7k0DhOVWrNfuch40De+yzAiTI7GHJ9uyvgK7q
fbvUHBIe9MqbF9M68SSU+V5ymkA6W6B/KlYAfny402VjApvOE91pOnxoKGaP
jHhLEKH72Tcq7DXW1zMO6buRSPq+50mzPx8LHqeUt5iK8a3o5I68oB4IfRMX
bYgUYV+BW6FFXyO6tcNDbVeT2NT+WnlmZyniURtAW0qhcr/PXctHfHhbXdby
+0hA751roRIzB6Ye8zMdlRTunfGOic7JwTab0srklxQOiH+cJgsF+LsL57to
VoSyAHfKcW81nNl+IbopJKbsuKf6jHqhOZE0Y6Algm17XEqaYwkcE4MI8iQF
mZtbrlJSP/QKb8Q3hwmRWW9m7baqGDHi0QWMAArvyh7Njsx0gR24f2rXfbkf
c4NjZywbEEMNbtX0l4LeOva1JbAGqzJC4xw3kNCrUU1Yt1aAa9/jFfuCxGiU
qD0s394Ps2CVJbn0YZQ9qQ9N6qvBGgvWrlQPEglTjIW66W2I3fmkumi5FLzx
UI/L3HaMOdzPclCXwP5dWalv2O9IEbVf5E9TUFk9+PDe5lKsUcw0HpkkIQtR
zLml3AH3rfkMhpcUE+4JFGvvW0im2mKZNyQQRtV3iq48hqvn1nseWyjwRDGs
QyNpiMtnHBsdo9D5KMTJJaUO631WKhWYklDnpe2aoPHwL51Xl68dl6B45e0V
KyKa0f0DXyHwgRTmRcyXQXk8fI7bXPTTRQIRxnpf8x93wuaCxnOd22K46F9N
Tq7OgUnofLpmCYXpw1PK1aoCpFQbzno5i8Ha00bcUC8Fz+f6g+wJEqV9t3p+
MBfghKClKHGFCCoB5Yp0WwG86ybm/jc3DJ5mtcbV0QHstnCKULAUgx6qFnYl
8iliB6pYozYU2JxOB4fdQ5CstEgKPybC+c3RX2i0FticfvshO06eR+ttt5k+
Fdh2rCBY6EvCmh8ftHsVH+7LppYEh4kxsv9phvTHfuRr+w9d0hgGU9AS3FEg
QFC4+iRL/u8jyq+cinpfwcWqwlOlSc53hoqn8cB79NZxThgKROBw59g7j/LQ
fzp4Y2uXBIGK7JE73nJeyjbo78gVw3X9lBdXrQu+XBMl//+IYS/7fiuUngqR
AJe85f5vch3Ob6wVwLnGM1loLkKJdlmRhVs3HEfOTpVGE7hayy9deEmApVrd
+vHyPKWsXf6HTDEFu7ffpC2ZomCva9y6zugSrhxUL3+z6CPqP/tnsN90QzXn
WNODVyIQ4w7nCn/KRbQJ45emAgpGqZVKZq4fIIo0ST5nJIRscVQr54C8T9fw
euk0AmOR4iUDXnwQWXcMEj4Q+PrJTnphohFJDUarKZkUeZqNGxX1+qAhNO1Y
HCT3izu50S6qB4QBX5qcReBF455Eh6pcSOZMJ13yKFycjHrTnluALWptUWby
e7rQKW7ahg/uOd0/764VY9c7gakhrRv/4GiZhEhESJw+HVtytAqVXmfGXJxJ
+H6hsT/o8nB9q8/PsVflvL1fnpU6XYHsNvZ9lXkSD8t7hhaaN+LXT00CRoEU
c9dzAxsM3yK4etjg2EIpbJ9oHnp7uBmgr7maNSfFXenAYgVnHswyZwmdpQQU
JA3laoIGPHP7+qDKWYotwpNj4opetEgFAzP75Hrc23lXDhfjRfZvQ3VRFP50
yzsSSb6Hplfd9hezw7jIUw62sedi6TjJHO0i0ZxioRGTVo46hujzSTUKnPFv
bIWWQrhX//t6EpNCvX7hfDS/DEOCf36qzSdBL+HNKzPq4HvwIQu/y/OvsIN1
LaADzKm2Q3UNBL7t1f5j8BMfMr9xy2cBBPZxbMtuRA5h7YnXslbuEFj0c5Vd
84XIyKHbRx+X8xT64nG2dRW6GFazi38mUbPh8D5zzxLQPJ/G2PrJ+5O2dVGN
Wj+qRS/Phj8TQuXA+5c1pzux12xi2c5gCf4ClgHPBw==
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 106->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk41Gsbx1WSFielhXhxJEtSSEXJV0lITrZDoogGUSnTJpF6i96SmCTJ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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Ve/XxiWUiJLSoIxFRdSXiugmREgyNCcNhkrEr0GUoZQxNJCKFBIl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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlGk81IsbxSfFRf8kpJtCXWu0y1iiUwgpEVJZuiJ3pGyFFsoWIZUKt0Uo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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81Ikbx2elRMcmtLWxUTZyTDZHJe1nxbZyxC9Kqdyi0j1FNqJDFyWp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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 107->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk0lesXx5UMlaG6tzQRDaZUJFKGL6WiopBkDKmUuShaFfrdFCEUmW7G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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwdmHk81N37xu2KRCkiSiWVFCVZ61KpyBIKFSVJaRMRSlrsVIhQEfJICEmI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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81AkXxrE2XWwkqWxsF1Nt5bZSVsOjcW1zDVuUkLQURbtewqqU62vl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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs81IkCxb2yinF7yM7Kbksvj0gqXKxD763Y7qyWItE20XiGlSRGekpy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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 108->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekbPkQZbZMRmgilkihRSOouTahUHJQ9yZpdMkfZmqKmUJnO1C+S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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k4VV0bRtJsilLKHDKUXhJRt4o0oAhlyBhKGkheJVIkRaZSIZFSVDK8
ppBZphMOxzykxNn7UDSIJH3r+3Wuda2991nPs557knY6Y+bCw8XFZcfNxfX/
36zHdguvDDIw77/X5jM3aYTw7WVaPW5DTFbP103tFAS31i8d9yvD0z8bjNlS
NJKVvp0tqGzGYm+TQNqOg9O1y+bbfmDAUmzd7oatNIwNM+OllMrQGiN5LO8Z
hQeqmc9L77BgdTful/dJGlnJbvO4uStw7Je3p9sAhdCEcr9pvTfQe9vjIqBB
Q8SJv35VWA9mHzSeoJawwdeRJzVk2APr7NKog+Uj6Kpjud6QLMPWB79T9DJp
qLznVnbakw3e77dkS7bQsDSL55KNHIB8p6RYwMuPOGK1KUchohf+tbUWIrwc
yEInPLeAhTVDf2pOnKTAJX/h/oKm02g+kSs5KU2Dp0th4QXNJvgvfcg9aE2j
b31jbvZoDVTF+b+k/8vGnOhKdz7NfDA2rLGt5VC4JFuflCCXh5BYiRcOnjSO
8dslMrTqoZm+yuGhN42O08umBx07wL7UGJtuPIz4iyF9QXYszOaH+Bx6RyFQ
abfasj+x+KT/mWpaQ+OPvO7Hgc5OzCx2FG46zsHWz85d95hMyMlcMxwUo+Cd
bnp8nUEnjJNNMm+N0whOu1w/69GI5vRjDeUVNMKFGqZst9ViH2O1D5c2hS6h
d2nlTmnYrWPKZcNFg6H6cif9tRm3AhTTZ2LZCO0pMozx64N5hePgyCQHEUdf
nnn/pBvRUT+vS70eQWD38+xgvgw49bH21YmT+//6OkdFpA47i4b1G3XIevnX
sE6XWhSrXp0L6qdxv9pklWZvKkS8K2IpbRql4hqmQZ4sLG7jU1fO4MAh2GxW
N6gDfQ919WW4RzHrc6BZYHUPDDyK1RyNKDgsu1Vx6EkFTpZddo0MoLAvzPv6
FudevDOMVuCtHMWZrcs2udKtCMxoD453p/HjLEP4/O83cPJ5dD9pPg07FYOH
2zK6YSn9zLhPnQNr+4Mlo6IMlLu9j2bk0eCaKtJuPtMGhbvfW7ku0dijlpmX
NJ6FcIMiZ6N9NHS1i3ednm5BYc14yeN2GgVf/JujRAfwvT5L2d53BLNP+92S
S1h488WtJ66NDd/4+7VSovWQF/JMkQlkgyWc5pGlk4VRI6GHCwcp5B9aZWpn
1wmrBSVBgWdHoCg49Q9nkIUdLV/332zgQCseXK87BjA1kiA/d+ojfC0644QL
a7D94nyug4HkfPNcFiU6tqPVXqS7U4mGoNOtPaqMxxDs0nawE6DhtN5vaeXv
DhSJX7hf7zOKH9yM3j9cLFQKdS5YE0Njpjl04cHMVjxp5L81v58Do785g5Nd
7aA3adz6AA7STizn/BlrgKvpR5fIERotm3VyfnrWITR8tVKYFNnPjdv9/eJ/
GGpLWvlUmYZUpHZu4UQWjnj/8t5USvCjsURf4MQVaGx76FxJ+OHSzwlrvtOt
KHhcKHcvjI3R49+5PJUqEba/4cAHKxqDd+x5xazSMf0tYIwWpHHkWN7++ZK9
uHT/sZDfLA3bU1oV27VrsPNTmu6uWTIPHdh7Y7YHxxy7x8T8OOiT7NLTet4C
MXsf+5YEMq87+N4H+regNc9f/QS5T7E/QukLQorxSw6Oob8pbPy3Pu7EwBu0
7j/dqqlIY6HGpSnr6BJ8Tn/1Qo2ss97u1jNKegu3+VpVvUkUBrd0G//wbMTd
E8Ms85UceDcF5XuwW9GQoiPDkRnFVu1zGRcPMTHTsdYlxIqDDZKnty73rYf+
Ip5SQV8KU3ZTvooCTJhnnXKvI/O0uznXMlq0BWfmqtoXydDg3zHdYfiIicbg
BcaZ5H2uqIJhneZgXNA+diOT9E/NrIS/9tp/+DD1YSiukkJG7PW62OMsMBWe
TinGjODsa0bRff16OA2PR1osYOPI6L2zDTo9KJx2/RVzfhTUp41RzTOlaBKP
eRO3msxL8VL7gcS3GC3mOp8+SfCyv8v+nx1MKNYfYF41pOEjtidoMrwdG87F
SJquGMN0iYBqvVExzmi5rJ59SUEFAXPqr7Nw5UE18zjhxz2HCyJ3B1bhUe47
TaeHNOpW7yzUmWrD1Rf65zh3ST28na1PsyMh36FWWiJH47RxU9OtvfUoL0w3
jyR44prd+eH7hQxwKd7O2jJD4WLG529s9xYIZu0ZUC4g+0qRa5X6vaDFm+9p
QPpVXikSp3HaE36DySZLyfr+A0O3GIFmCBuV/3nAT+p5uMPCvbsa+sI1P0+B
vJ/YmRIuVY+Z5RmiGlE01kxbS4ubtsPu09jzBc0UfOXc4p1tnuFD0JzlaYKn
XqfnN3t2En7earq0wYKNZq2R+8Jt7VCxHA+YVz4M+Xmpj/9xbMHOo/5bdb04
OOH9UXTNbAuEbRMH6Pcj2FR+5oPL3X6EKuqfeMJD5uvDEi6d5BzM8NVqR5Pz
hgYIXFQ/WI0c3d3vz28n/PxNNcF1PBk+uz5IriTnPxaqpv0utQU38kX9KlQ5
iHJyjb0Qlwsvc+Ml5qSeieYTK5ytChFYpt889YvM5/W/IaGvO+FrY6mTTfAV
v3bmuF1IO4zazIdPnCL9l7CJStR2wIiSkNAUuS+xgNt7FmR14e0l41W73cew
sMp5xt65FRekedurv9Bw5+HJlZ3uQnWJi8LOpRwkL01U5BG8Aonx7ZoD5H2H
hVnSt1uCYf147LXAOoJvTlacZ3g/RA4s+eu8jYZeo46I4ak0bEq4HzsmQvo/
73p5LrMQvDVvDu8h87/UJeqAwY5uyLAj/FacojCm5ugmLv8O3xoC5a/MjSDq
WkrUO91c7N+UWnGYfG9x1yqdKxbtGPbw3+8rTepxUNJqSjEAK4yrmSLn+Sdj
3xKtxnoMlU46pqbSOL5AbtHaf/5DmM3W9E9mBD8CD/pSL/ah6Rm7zf/nKA7a
qzufN06Dz2W5a9O8ZP9rUEJ1czP653gUVDcTff8R3Pg4oBzBleyiQsIfuesM
53VH5OFShL1CpTyp/9wGq7utfbhb3qkz7EBBVsQko1GUBe9ac2RYcPDqILRd
7tfhUcJD2YhsGmmH6z49E2/EnRUrNY4VUGCM31rZsbMNHRzdluYcGlqrTgaG
WtbgVjLvT7+VRD/nPfkjJBuNiVk3r14JGifTFEc0PmcSfxOeM9dDYSH9gSku
1wrbcTMx6/kc6K0Q3ZXz+xmkA50b/qjSOHjykRDLuwy9sjYaF6oIv5omVJw+
FotwXgXLSKLXNwv5tby9sjEwGLJ5roXCway0Jj3zXKisu270kfyfjqhI09+S
AoSEv0nxOk5DMaqDfcKiALxn7ZKcmyhYxX5VMXBmYuho9WrVLDa4ousOjIaf
x8wudev/47GN0e3yUbcN1Fe7UfGLbByPj4kqZFSAXzHKP4F8/9q9mReDRI86
+3jYBwm/T4sEqvTLtILL6v4B3gM0Gu7NNg4mdII1el/iuSO5n5LLooOP2vFi
Sm7l57hRGOpvav2Z2I0P7gevv5FnQ2tIN4Sxvxgl8cFRZS40rC2WH+fxqwYr
/ZGCD5sCj46+S/mRVpiojmRqbxvFCEam/gvrxZi+5gopJw4C97HzTYV8oW+9
P5+fnN9B2qt/2WAR9KWGcnVSyP0bhfgPXX2D4GjvzRbmNJ5K75X0Mu2A6/t+
5SBponcK5tobfiXAffnf7s3LafxbVGylItaGGRcL7cSET8jaIf09wKMEY+Ed
dRbEz+arL1ROujOAI3c03X19OZi9sj0zpaABLOZzl8ZOok/xbgllPbU4wrRb
+5RJYR5b4r3DFSYSXQQ3nl5L5iOipzV9cze+XFA/xhNM9O/a1YLtGu0QzNsi
+W2I9CMoO+WXYzHWjOfOXYqgsdW/dtrUpQWX9FR/WF+loa9QduzOv01Qa08w
cXOj8bF42d/rVt3g66lrtZAfhXVX2poNxL/5XCjXGnpF+l+5nkfQg4HCFfvE
G3cSfO+QyHSK6YSQqPj0gAkN1SKGndlRBvj+fE0aJfjQO53tbTIXAstzLoyP
BJ8/oLt19eJUSCXe1stfSoP3VIp911UmIt4Kp7xgjYAjZKsgG8rE2YIp60IW
G0Z+7LPXJvtQdlFvdsiehvJGjkcXow2eubc3qoeRfCDk9Wp4eRZkLCuzDx0l
83155wzXXBMq60dFjpL5L72+tk5etQtHqOjUe91sXOw/Jtrs+hhqepav/CUJ
/014ef6xqYBTZ9T6oDsUfuYYzgmdaMfqm3wCdckUSsyueJmva4Z8N9+EAfFr
UobpdRf9unBp+Cp3rO0Igg/8pM1GGiG3JK3VpptCi+FivdrNJfgSKFWUQ/ju
h/SBRTWZVQh/qM2YIfjpOqMtOfTjLnLrgw52kX2lrLdxYRKpuLNYzjOX9Cdq
xCvkZHwuCg8MiGeR+06mSjOar5Shb1XeFisL4tfpVNUvu2rgYaMiMWdMwySD
Pnjuv07w/xOsUb2Kgpb6mZu97wvxfL6Aclg+hYnhRcLb+VuwXqKO5UP0fLZs
Jqb6VRcaYHZwfToNjT11y2yJXxDZXn/+og+Fo9pquwQlmfBJmx9XWkPDPnr5
RH/eW6j/4FJNO0RjxCTZd8NyFs5EGp1w2MNBaM4e5YkHL9HETjzUr0745j1e
hF8ugPu7CwPGZN4E3eVK7de/QIp47ZpsXRrFgvNcf63IQbz14bKif4jfadUW
DhcugvvlLrOXzhTK72ybuDqehKAAnThhFdK/oDL9bSntRIdvTww9G4GH3KPE
Yzva8YUlsvmZDhtTBZ/5vXiYUMpT39tgOoKJFz9sX8p04V7KpWy9EQ4GfW/U
7UvPh3bw3N9Ikj8l5oU8CSV4vWFX98DCjPQzPrPbj5GPgZtPFIpIHpl9KTx6
XrEDP24sz/+oRvRuQnDe/qqHUPVXN28jfNVQPd4f4dWOne7BnsYjw1DZPpYq
JFoBD95tv84Q/Q1XODqTvKMWeRS/XM5zCtVUx7Zfnjk4WbP59QThg5fdk6nc
t1qx80K1LHsR8dMTG6sDljyGWPtqcw+CF7nL8/RGBt6hXC3NS8CGwuw2jvIK
v2gocuTYvMT/RbDPnnj7pRdyvF3+N8tGoad5rCF3UzR8ih5wcxP/TRU8yqcS
y8GbvVGIP5/k9YHsNd/+tiGrd3uUYDnJE/bnul61NEI+ffo9N+FjqUNbQ9ar
5oI5rJ/Rf4T4k/bMZ2nllfh4bqqHdxONuSjZ8VufsnGz07lh8CeF6Snvle9/
NuOv9LnUAKKHGm7dVXWaHVCfMQhepjyKpRFSN1s+deDB2cOLVstyUFIgZy3N
04jVjQZH00le+Kg4cfLhy240bCxgjp3k4N8qbs0D5zpg8s5m9ZuzHNh+qb2c
YtYDwejxP88qKDwwbrkcM8HCwv9eRXENE73PDLDUvNMCxe99W5hvCb9P3cl7
JTYA6fffpJYtpHDWXEGgKeclBjstNidZ0giUuq2+sq0KjKNh4zqxhC/Pyu8L
QDSWGH16xSb4r/bbVrLOsxa86oyfOh9opNhk9mzyZqKIe58p3wwbcq91L22b
7ECPZFnukYsUeD9uHNW4UYPRpDCTfNIfk7ulXou2P8Fzxad/Bole6w5dLgl5
V4mZI2pnUl1pyKiOr2fOdmDgs+vfWOJHQoWDvSavV6CQUf/yM8lH3tzGFj4G
vTAWvemqT/RMVSpeLDKpB/kekzO8ORQ4+fY99TdYiBEOaPMTp+A09eO7bF4z
yieF5QqCOPgtWTR37lAVYr/9HDzUSuH4srDzDOc87DaR/NVA9GMi+HKzSj7J
a3GdabYyFBy9FET833WicOvxbZGebPAdrmmKP9sHiwhZ/TSZEaxw0Gi429CF
m579N9/tJflqX+xVkY4OaHQyhH2kR1CyVCvNYl8FTHoWa0eZUBBjuK2/4duG
K2HVEa5MkufK38wXr2RAkBNp83KS+Lmley3bB5ohpp8wf8CbnE+77pyYZxxU
soY9DsuSvCi17Ou+tS9QqTtd9J34wSzOLpnjGzuh5BXt3HB0FBNDEgqfnJjY
tz6ptLWPgtxQ1GMBZgfUuszErI6PEt095WoSfQd1SzLMjv5fD2V3qP/e3ArX
+fdGy0k+9AoovRw714JXdpIppYeJHoXzLVB7UQ/8blQ+tJDkE8eLC1KESlHC
aDWXWkPDN+nc4SGqDuVKYw8kp2gUfvUo3FNZhVdjjfKrHxN8bLDyfv+wCynM
tMAJwh8qDabLDje3IZ/HriZek4N9sGaG7O3G52VPNYTECF5eL/saTPIQX/vk
ptdqBO9y8vnP6A5UWuYbFFwj9dxbektgqAGjUt5JLSkcOPwK1nzKVQU7oStu
4XkUog645Z90KEa+oXvHly4KJlTBghipdmTULTx/NJKGy/hr24hThC8a9HwV
zlI476y3/kxBFQSUmqiRagrX6wqWSh17AxvzXtFSPeLfaowcXRzrsZVpsF+K
1KeS8045dxcL1RstfrjfpqC4csJ/vnwUClnPtmv8v58Cz6tsmMnYcyNZ1pPk
tb6rm0TfhXZCd6d/Fw+p746J8kYJOh3XDM3nrSV58s7pRTF9r5pxau1fzwdl
bCw8HOpa9rkU+TrMlI5bpH9HG2Vr8lmQqf6qp7ab8Ku/8d9wgVAY/Ovz+TTh
NyNvsysXJxl4HvB3YepVNqh8j8/1q4vh75BvJOdA/MeLLa4/1ZvQNDnhkfmG
nK/IQELiQAeuajG8vo8S/8y6kbYovgd1O25XWRF+Te665fIktg0x566UrjJg
w+yzcHqzAwsH75wzrfIgftl6mYzymzaYR8v8kKklefLTEf/GngYI/73fyX+Z
3OekrlxYdS9ifg8O9XJGIeMk7vrBtAm/v1oYsm7SqLRPl0/dWIGYXcVNtiNE
/9duThN4UYwb12IM24if9vIx2PtHvBVjWS4S/xL/wrX95LrE+bb4HFu/U4T4
y5blE5F9IUxQz14HCpC8MRJ8Xev9aDnaQr6NpN0lz9fNsylekgg1fW7RGoKX
wMnvSmn/XsKA7fSu3WSt2fBKdf1wO9KMnSNWnCH58aORg8uCXny9e25qpeVH
dD084/fQrg5vNQMCwp05aPmZz3La/Qz7WbEv+oi+/g9rkgRw
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs41Ikadp+ohhJKCItSpIvctryKEtnUZjXdZKVoKnGi0EopUyY0SheX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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXtUzAkDHYVTWUkqsz0IiZaUVZS2Lj0kO0svpKEmdE4PCqWi7bGVtknh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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 109->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lWkf9klpytiibG1Oja1CKVK5hS9rMtZTspR9y8RkmSmVhMwhpU6y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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8Vu8bliQrq1RktBAaykjCJSUZJQ1FFBKyonxLiraUqFSyFTJKVkhC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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs81IkaxidbIrRY12yMbiZkiWRQj4rI2RSpkJDKdqPO6TYlCRXtEhWy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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHlcjIsax6do0aJNJFEhLZyUSkR+aTvpkkLa7klki6HFvtSZ6KIj3VTM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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 110->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekbpik1ojFpQcqSQRJNKGv3SZYWFUkOKSKJRHNCtIwtkq2FsqQk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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8le8btpJQoSU7mRlJSEOXtJCiEC0qfM1KqJSSJJVQUZFoyB4VOrId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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk81Ikbx7EdKCUh27GNTlu6NktRPpUOllWU2dQmOZpRZHIlJmeHhJiU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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81IkfxifpVI5SWpsa12STjaRDvX6PDkKS2rDbboU1dPx2NmlLWCmS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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 111->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lWkbPjMkbYpMEUVpCg0RIxm6fJLsbcgZ2bJOjTqIComjyVZK9siQ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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3cglm0bxhG9KqFSSShSZmUkJTpKUiIykyhKkopIXiSvVEaDQmYaVoiM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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHs41AkXHhXFWumeTbKiNtmSbLNJXokS2k/CztamqZR2IpLasqFERKw7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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGs41AkbxufyOpTDeqshSRubnLYccghbbluolk2hpVLKJcd6pRRSDpFI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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 112->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8VWsbVU5KVJdKpTJHhIqk+rBcRHW/S1yhMoRDaS4yZSpKRaKkkOFK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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Vd0fxU1JCKWoDBEhlZAp0ZKfJopoQqaSIsqQdCuVyiskIa9IGRtU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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk8lQkXx29abJElyvKqZGlPjdSU+slSkUlJlkKypqy5xdsQY7kjEZMU
V5ay1FSTQrZGtOLicl2ua8mgoXuf57lhLEPEe98/zuf8d87nfM/3nHXugbZe
EjQaLUwc/8+57jdstBd9wCVVFu34GwIVfcnVOtMcSMT/LkmxSVj8+6WCvpmH
lVbyid+1KaTz5XzHapsxMvQ0MXk/CRrPVj6koQjBW07H1tYLkbsiKq6QU4qN
fEbxqgkhtmlYh5bXcNH+o+a6XUsonNaOOrDVqgs5vs01qvMk1j4d+GJ3rhBW
DZcvKWUJ4TqpE8siW5G/9ub1qkYSstLpc/ybPbjSssX0Yh2FLaJ4kZwMCwLf
3kltSxLcloiRHfvfgXmnVMsqh0BrMZ6o2X1E+rNb58ZuEmjne7yeovcgbcyA
vWK1CG6ZajsjAx7jk8JjBc0HQgTtW536jt6Eub+MLezdSZyU+DzDYnTgovXf
lXQWCamDPiKL5Gq8nlkawvwPgS2M5O8b4jhYuLbXzk2CAs1TT8aJ0YXdG30s
c+UoeKbfqmIH9eDI3T//3q4igiDruPrsmT/BUEm69dyMgLpRnKlWfh8ecpft
jbxPIfrxlGyBQiUM5VycrKaF2Hv/xtJdfhyUajkZ+dAorHEwcX9yuQfxu2OO
6DtQ8LLx0Letbkd6tb3N9bcksmefuw2t5iApbcHFj0HCOlnzjINDBzJP+pS/
CCdx/pHi294rdbCbedM0r0jiuUbmufgKFrRc/HfpypLo4/ZaXo3vxqPeJkN9
FgXNT9H5WuV8LE4+2+XqSeF9Djdy06/N4MSeypXVIGGyLXuxnU4rirYtfi2V
ScJceU5WJ/M1rKqmtk5oEIgq1v9NPqAE9eEqDg8bhci3N4/2zuFB0TN650Au
BdM31NGs6zzoGE4FLKhQEKy07xjxqscXPb89ju0ECjkr6WUyH9D6ibnWIEXM
K+3B+qpDbdj0s/Sdzh4SCklL2ckeXGTfsz0Rep+E8YeFtgvLPyJRZPnsyT0C
G9jqHuPXWsEZ+lLyTczHb2Db2lmrdhw6bcI8lkCCnzX3o5ZuBbxlWDb5ywiY
OBYf0jCIw9R04l/EfiGatI/u9p/pw/cO/e6uiyLQtCvLGxsqYbsw67xrHYEU
yWB1VUENjJTOKJYEiX2rm2WHKVUh6r8li8PF9Y4sqTD4WbcN5SJz0939JAxe
Bz8lPhchYIy9L6BViJy36U92ynMxmmJ9qqhTzFN9+AfF83wEDd21r4uk0Fus
r6vW0gRnsnGl2lkSLl1Dm1OCedCiVOTqv5OYn/nJ2lfnLWpXh4bzQgm8ul89
48Hm4FuCode/t0ncFpQs2N3hwPx2wAv1RyQy/P3cnop554QVnNE1oxBV+Orm
3qREFP90rCjukBBusfqaGqFZ+Ofy+TJDuhC+E5fSyraXYry6g65QJUS/ZOjI
wVc1UGjiBh0MJlA6/Kvbo43d2PGuT71gkBLfZUGKirgfr2xrQXAEidq9jAc6
9TzYDo4HKTqL9y3vkLdEvh0Su4/xhqQojI9G3XNpawUrNjxY0obEyqPS9kJe
M/iR+YKAFySmnTIMnMLK4HLcgoihEYhPoI+5p/JAU5SYFwVRkDJqvXtwqgbD
Xcx7DywJ1N7KOdBi0Ia6K1oDrGUUElxfenbs4IJe5Z3K7ybBpAZPdzfUYdBW
g/OKRSDxSu4nD596RDTfW2euTEJzbJqaHqnB1VtmjbGBBIyLtt39549aeEvP
NmZHEpjQWsaIiOmG67N844MJFPqt2XclmV1Qyhd45g+I5x3eYx+37x0G0yOz
e/MJ0PqPvmB4cKAUmdTQOSz2U1ntNx2/OjgzaYHLqgnYXRnoviRowzhddZWz
JoU5x7iiX/LawWB0VIweE/9XUfiausMlOB+SozfNE6Lq29Wn89tb4PhEaqLO
h4T3WWOBS0sryjfHmD38RMJWutsiLaYHgpci/fluCs57jBNlr7+H6qoTkyY8
AoNLZL8G7++BafmFnHgOBeMDo0L/4D6kxGxoDxP7XdoZLe37lY1oyVO/lBmQ
MNVLKjeNaIPxhS1vNjSQqOxgjg4J21A23Mbvl6TQ5hYiOpzaAQuuYKTDhILO
18PPJ8fFPN6k6i3SFGFT33ou36MTQ+YZVxX0KWQ7Kqr0fe7CtFxInLKqCCmU
svKj0YeoDNiR55AhxGMjvSwbZg+cV6RNnrcXIYrclTrjzYLr7wtqTutJqBCW
ByonanEn71LGtAeBaUFcofHLemQGyGRV00jUB0pt142vhMMoXUPPkMABJS9q
00AOCh0+XmOECVFGi0pbfq0R/r0x30+oin0TNG14e6oJkyFLd0wzSajP+S9y
HGkBTd0gzc6LBP3avqCIdA7c5XbG550R/0+LoxFWURVQ1/zwPFOCADtO2bOO
y0X1O3ZnXi2J5a6smSGNAlh6S+lnJwiReOOkTkY6H8uN+k+YzYvv7UZr+9D7
HCjKBLZkBArRl9y7MSmQjzVmTs3tYp/+B6Pl040=
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs81AkXxodXGbdSlFzeUEs3oi2U5GEzyJami0mhbJtctiLZqGyUipRb
UVPZTOnmkjSFvDIY45ISMxgTMxpz+c1UCjVJLd533j/O55y/zvP5nPN8H+u9
0VvDNEkkUoK6/t+DVSHJpXteQmNWHvfzQwIPFrEcb3qVIzTzkeBxvBLk3A2C
on8q8PnLhh/HphTIf3yCY3e5Gmsf2bRan1Wgc/G+ReGuLMQY9x4reafA0Jva
80+zuYgRttn0LZOBZH2EuGQlxFDV31clSRJYed4pW+9bhr2nZ6uk65XQt22l
Vjg2IdqohRW2lIAbtzrHSNWBGX80BEW1yRDMOFXmMyRAw5uhWfqmgyBxpoc0
7u2CyZhzr4O9HK1OMw0dKprgWkDT0UokkNu/e7hzbRdU/fF1rs+l8Fq1fDUx
0g03upjyWr3Pw2Jq4AOvBXGm2yOlUwRqv3zUvRcuxA+Btt+XtYO4Y6KTzHPp
A8VIN8HTXK03O9x83txM6HO1jnK+KSGeeisfX8fF8Wx6Xky9HL7VKxbzuXXw
3ZZD/XWmAuM+ifo+sWxIilPit0gIzJIaZO7bxcY3GtUlU0Zg3pkqURi9BzU7
0qpMnkgw6rfDnmUqQHHt0S8dQil2xDU7Gp7tgXK53a7oExJ4aPqzY2+cx4+f
/S6rJpVIKzYMk5zrwKvhBYO2KwkEFsWl+m+tx63Eu/GL1Pqr/3FaNTGzF33M
ctuagxLQ9Ha3eOtzkLbVI/HwAwLT9bQ77hs1Yjm3rdTRTwHvsLic7OQG7DWt
s79wWAEr7+bsuRZNGDc4kG5jQ8DQgHk1Mr4NuQlEamCGHCrj14vrszqx7oZv
qKBQjjFLvc0Uux5sOlOgXFUvw7MUbvgZxyzoqrIHs1RK+BPi4IqvfFy3PHUl
NlmGUZdfRisZreBHrt9PsSeQrDtZetAlDWntAcJU0jvoLyunnKHywLjvs6Y5
RA4r8xQXnXIOghROThRPBXIfl7ENSprgRi6r0W8gQKfd+BSx6T84s5FMXn1L
AcbkiEhMfoYDF3fvypMpQOYkBBQmt0DTRJV6LorAiNdJg1eKdoTu0RpufS+D
Z5dn+iSrCuHx0bRKbSUuht5a6Z3XjrCVhv0lfgRIt8sYQmktzpXyV/uUK+C6
v2hHRGk3ErPnuXOipYi5YR9BO81EQq6GyZWFStC8f/3s/JGJUH1L5ZwgJey0
7LK8lWw8CH/2b7KW+r7t4iSzwKcYjnyQxFDztMBB16N2UIBVh5lyUskgPpgx
frpS1ISC3L97BF4KPOtrSzH+XoP9bOqe900KxDCGG3LZl3Dc6ObUkEyJP3Xb
fS8n9OJ36rqCsAYJioN1rAOud6HZ3fMhv1eKYh5l/YR7NwJ2mgWRTOUgrhVt
N7vbg/qPsRrrxmVwI1Gz6rxeYoEPO0hsTICy4AjLOOkJXmha6u4nKeGxVPrI
4k4eynyWlNElav/Feuk8NeZgAe2uyGmbArJDwfnm01owELjsm5mIgPNvr9I7
2yuwdVGjdvUKJais25GnsthAWiL3XQ0BK41pAtKcU6gfUX0z030HzlTRi30V
LOhfEy6UcBRgj7lMDIV0gxmy4YlziBR0puiIyqIPs7vOMsxqxXAMnGopMu6G
c3uU64SdFPVam5bwQipRa/mXXTJLgcC5R19/yGkB5cjARutHcsxoHnkYqua1
kjlrm/t9KeLSeqJrCBHSzbJs92RJkX7rbEUf/QV8HbQr89X+rie/bewIvYAD
zBb7a2Pq/5lEPN3Aq8dPn6I7d/6u9ldU4UV2JR3VM2wWFw6o85Hnuezlkw6o
IsyunWyVQ2dfQzBfvxuebScyFXVSWHzKQKdBN/ydHT7/pS1H/jGnrK7Ifswf
Jp8OI4sRQM8YN/3YBLs41+knWQSEoSVGa5a3wX/ObrnNZgLvj2v5N1v042Sh
zcCGT2L8fL/e3K20E1dqLrHj3qjzLOnPqLHiOyj/fOrxoRIlJgIyprOCu6A8
n7Lmpq0UHeohbliozrv1W8S6ElinB1qwglog1ql2jP5G4HsA495dUQue9MW2
LeET4Jxe1euQ0YWNXPO3R6KkuJezk8x35GLX1d9Mn1uo+V+RWhIh5WHhpFH8
0VtykMpf5I3mXAD1usdb0Q8lxqoU+xn+FZj9nPH2oKES44kqzXzHGlCqqDe9
1Hx1vpbsKBR1IyryPnU+TYrYEEHwodQG3NZwKk6IVGCC+/j69y09cP9jJvcZ
T4YyO2G+aVs/ZB9kIzR3KUa2j+Z+zWjFxZsvJhIy1fmgyv6kMVKNh9rZbu7X
1HzJLckFK1Kwq0hzT/G0d7g9qCgjLW7ELw955aaFBBhrLzJeW5fBz0qrvTpO
iYhhnc1ajlV4z1zozZyt/vfxsKzLMi74NJ3wNis5Eox1v5KUfKxJCfzCpEgQ
lSuik5bwEa93uGt1hASteu321h7lSBmY1OOpeWcqs+vShkUwTJ//LzueCDGJ
7kLj/wqw/VxjQe9SKYQh97SqjXmg244afp+U4X/mBcX5
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 113->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8VVsfxjXc6kaSBkNuCckVzSGph6jMY6QyVYZDSBGSVEJIk0oIoQwl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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k4lG0bnqJSKftSKZQt2RJK4pRK5fVGWkibaBGJSqKVVEiJUilCklTK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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81AkXximUopBWSYyKqQhbunwy9Yi36GZZGiUb61VJWSqESpMmzUhS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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk3k81IsaxkVpODmhRXV1k46oKGnkcOKZNIp7teF0xpKESQctKmtoIttH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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 114->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4ldkD1q0kWW4aUpZkvTNXE5Gl1GtLNNNoJhTjkcaWLPWbQYiopAgJ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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4lF8bFkohSSVEVChFiShRNyopEqWolCUiFS2ItFgSoaKkUJZSWUpZ
s0R2yjqDGWtFlvedQVn6kaTvfH/NNdfMnHnO+9zrCjvXAw68PDw8J2bx8Pz/
dUq6zklfuQl/dxz10b81gPI6D5usW7WYG5fmt/04BzaDlHlOVDIO2htu615P
Iz7x6CqK+RSahkWS65bSkFsYo22tE4SXrVGXD8nTaF0qVqXWx8Yp5ZGnHXYc
8Ex+/DpjWAlPT6soT1CY0JdtGJj1FYajKfKjQxzU/TYRj95ThmzpGnehOApb
Xxzf5/+WgZuvFctmuXIgbNtg33+zAQZCMWNTpf2o0IyTUQ1rxK0IHta/XwMw
DdiXdrW3ES+DM6aYaRTU3CVTjl9qANf5iOP0GQ5cL24z3FGdg2uaLv08bArf
0q7HjvbnwuBP6SoTLRqv/3G9WjzuIyOsR2H5ChoSXrLs2j/Z4Bnoc/NaQ+Od
1B0TWZ521E/fMhP0ozG+aeM7ef8mKJzY4SzZRuOsyfiRiDEm3vh/CorjpcB/
+u4+IeNafHZXCw9worEzlPEv50glegtmRX7jpaHFO2P4Qr4dSTWlqskO/fhZ
WizUG1SPBR/SQiQdKVjOe27SbMDE6wn2ztONFCK4nzltkjW41FgvaPaAJr/z
LC43SMT6tGmdHWS+4rChxR3i9zC1QGGetyyN0t79gs8/lCAo7ZnbU3sa1Uov
ldXIe5/yUiXzrWSeAv23Nb5FyDla+2oOmS9+OEbqPJMJ8VUr+6zvUgiyzd+v
rdGAYQn/PjsxGhMBMdVWYc1wHbd8GbWpH4ke2r9yLctxX/OLpNNLGqLbzvBq
17ERe7vc5QU5v+2J+3yP59Wo8HQQpq/RkDee41ujxwZbTP0d7d2HLdtjJoWr
KyDB1v9+fC0Fkeb4VbdWsOB2QE3dLICLykMW62tUO+HSfaFQwoGLQjf/N++k
WFAT1Vj0xowD0Z4XHgGns2EkEOLms4dGlueruAmTJpRaBg9zumnoFDUH1B5s
xrHvu/MaTpN9c03dzDd/xJb1MRfkxGlMNeT6+lWFQWXHmQMJcjSak/IknPdm
QKxq3OyAJI0DySrJDUeLcXTGOpvnC4XBuw0fVvtXIS09dPytGo0ggY0fkng/
4on1x4UBy2jwOOgtuebvCMc1b+o6CH5s+BqGXqtmYUaiSvBvD4WsB7HHMlq7
UPRh/+efiRzcalxZn7uYjTyVyCWxMjSea9pfN5lshcjg8Px4so/HJir1G46z
cWye0UG7PA7M7mkomNa3Y699wJLMC4MIGtQw2lJQg5qVUb1sZxrDAYX2c176
w0Rrs3UXuU/wl77ROL4MzHnoHjdqS+PC2HZ5xcAKGP+XmqV0n8x3uTer9f5N
5AZ+Ez+xkkbKnpIeKv0TcjpsMzhPaYzyzXg1bO/C8CvDDocGGvVjVWuC65ho
1fA31e3koFJmWZgKsxEcufH37ZkcuNSriC/IycLXMD5312Ay/zs+T7XsCqz0
2uUgNo9GuciPyLXVLHw+9jtFhuD1s5BJoh6bgZ5bFrX80hwEFfHv+HekDRlD
EwzJGS7eldqcXC5bhDXbbb0YW2gsj3+apDFThmmpbSptSzkY1Wc6eQ6yMV6c
k7uJ/J5nA+/MZiNLNCo4KZwnz3+v2Ly8GcV6BJ0IdnT3GUB6fWZ1+W7y/2Pf
39Uf4OKXmk/t1/MdqPRd45R0nwuBv8P5VaeacGHSg1Fj2w9D9Wyz+6If8HIw
qPMH4dOWyi7zk+5J+OtQxtFcQsPjztDo3IYmGHTu0921n4apzt1LfV2fIHOG
PXR0Pg1lH7e3/wk3Y0dq7S1DlQHYW09syFnbAs/snWafj1FwYWNLQf47uMyO
Dk/ppzAQPGurc14L0k2HRdKJPg2N2dYO+LGRuEuj8+UUB7o7Vd9ejszA461L
q/LI+aa9/nJH/r5G0CLbR94jFExv1xUWuReBzacabUnO08204145FI/fzvll
RosJPhVSM0fs6lG4azvN2kEht2jJ7nG/TGxOYp25ak5DcNajaaW0Fpz6zjY/
w+Yicd3NEP69dVjYVBuYnEfji1qouO5wM1Z7nxZIjx0AJSnC8g+tRIR0UaDH
CI2IQt2NdWr10Nmot3xeAwUn5p57u1+3Q1tD/6Ufuw+6csrYufAjQhfuMva+
R8O31bpHI5yBIyWSSVeJPpw7wCt4ZYqFzGxtl4txHHRF82ywEauEoNJrK/8e
Gi4nXog/kGiEqdCs+bFaHFwOrfH0nfMVm/IsulZa96JZ3SKVxWxBrtIQw3n1
IO55rWr57V0NA9uFCyW2UlhqGtlmZpcPEalW+cZVhO/JHOOWq/XYIGZgutd8
AMmvjrzNLmMiRX38UboZjevGydH/ybLwKnS5g5oLF7kZpTUjlm1wqeEziLfj
olVxRiMhIAtbVrcLWXZQOJxnvOBaOBvLqbAHCYYUWMEZrFWnm6C5zjf7BsHv
LfM9R13Wd+CK3sr/uvo5CJuw8DbWf44SNUNW8AYasY7KTQI5NXigKv9pmweF
TcsKwvpuMLCMrjNQ+zcAN2uFFydsyiGwRmLJQAINn85Tvapv7LH08XDbKcJf
uafn7u3zLoHzG5++CsI3xZ7f7dVL85AxbuU8TfArvDWyRF6NjZbBNu+LbgNo
DZu3TSulCeDOatAup/Fzx/EXB+elY6+zv0E/0bPW6da/rmsZcGX2CkocJPr+
3IehPN2AVu38qQ1GhM+71q7MS2/G1YCEi5q/aZzwOHnhuikDBvyPz0h4cohO
a8vL1bDxQ/vb3ZK4fvRWri/Q+liL6garS7jDwaVE3i86OR1Iuctr8sSaQrBU
gVOrZSmGS9KEngjQWCFf+5O/ph2WogFRofc5cD687qvgXwbmZqyWEZXigt9E
e/P8K0zMnNQ7t8OUwhM+t0UmQaX4HHzj0KJVHIS21fywYLdC4fBwg/N6Dpa9
VP0QJ/0W8755VB/WI/c99eZU4+o06KkePxisSkP1xt8V4Z8zoHu4tdxxLQ1e
19luBnuqUXezQNOB4L/5d7Sq9SMG9Cv/dUZHU+CJn5PAEE5H/Kt8+xWGNPI/
rf0uu7MCV8RzrzaMU1hsVqy9e8NnCJoPs0vJfuP8kh2kjzCRM/FT5dxLCm6L
zjTe7ipHW/fNYrYPhfyAEkeDBCbExLP0phIoGEuHRR1ULEVI57c7T0BD2sXj
jaQCC91toxNr+4h+x4heP2nzErm7znLYm2hkdJ4T1OppwbGxkSeRJL/Z3D89
u64wHmrjx8a1ib9E+EzzPWd9gsvqzGdf2gYQMZ5o2jevBr28dhef19Cw+sNh
bmSyUHxy1ddjZD+W6U6shyQP6L4SCkoVo/D6efQD3zf1KFopukYgkuSdvUsl
1x8pw6+lpSFFBRTC6hb6hbqRvMbz72PKZhrzrMX+3HTtwJLmu/sryLy6x/Zx
96QzYb7j3gYRAZIvLknn8KewEPz1R06RGBcKKQJcqVYGtEWuyj53JHhi8l5r
62zH4cjwS+OyFCZr1byG5B/idkjVNIv4x+0tkvbLFcuRZVG/6iHxY5vMrZu8
D3+Aue2oxdMYCpTO5A1dkVJ897RKKP5Ao8bimaGVCwvlG9R6nllzIZ/X3sKn
xEBWnpLLYyaNwF/jKoVb2Lh+KF3z/WAfQoxlK3YNNEDRrVdmnykHqrc3i1eu
qIOVpNi6dJI/jPin5cr8O3FXSGS6k0FBtXoCdVfycC3pBvuvNnmeuojZFMuC
xPoNdube/VCtMGhJKS/GugT+Qz3BFGoj7IRKWmowT09rSEuB4E8yoDw6pxUZ
sdsGzhF96K0Ye/XetBLcBXXrks/QsBzzeHdPrhkRFQ/2VlX342HXgvKkgjrY
MQ1Eh+9RkK0eHe4caIPTOV7V14IUks7E7MoUrUOm1jZ7SonME7MmdTIhE4Jp
Tawtg8Qf/GJ7AoPDIC83viiEfD6XilfwPFkKzpQ942kghTedqScSFdno7U7Q
X2/FhfC/uJ7CQ0xc9Zg/2zqR5NMz5z1CJRtR5zETm0j8XjfLYMHM9GcclN5i
rzVM8seUwFYnSwaYdlkOql4UpG+ImWuPFmM0N6PQ+P/76ixckaJVhbX2LodX
T1CoFnNRH3Tpws29aaUmARy0nDd6KqLZia4zj243hJJ847bPL/xSPW7e7zYt
J/5cXPGfZPW8SpwYnOwLziH4/qQcZpHBxLLOUo2nJI9ebZp9oeNvO1pG7h6q
2U3hooy97FbJLswZt9E23kT4YSEVPhzBxuijpm9Z2hyYbvCC37ImxDtnfVES
Id+/UsmSHWqCBxX/h0eJiycliTGTSzrw73u1+2ySPwR7+/ctaWpBCVNEaI8W
F5OcN5PnQvMR+kZj5S2SlxsKxr2+8pZA0e9tr04AhZyWmbh8USaiS4S9HUm+
M23YbNR8Nht+i/RfdwfRiHn8KnBjRDlcHpmq5udT+Fk7/8C1Tw3wyX4es1aH
C/tlZ96LqVWiIHVBM98tGmG+7+/EhaTjfO4b/6/8RM8Udz4WdW7AzmKjO9vz
SZ77sTqDW8CETpwRX6ELB1XHDty9m1wK/ddJ87WJH1Tfj2QsG6vHZ9R3ubtQ
6Ff01fzg04jruj3Or47T+DB7jK9VpwlZmk4bwlcMYMBMrOA9uwVBp++fbMnl
oLr7R203bzmkrqrbX0+iIBFmGJNP/NnnVVySwlUaPWs26vHH1uKL7eU37UTP
H/+SPbRsjIUBhQe2U+9oaPg6vzMPLAS7dtHCVak0cmPkDUe4DBi+kr3wpW8A
18uOzPJsb0BlhJLaQU2Cl6TJU//tjoCItWKUP5lfp/jkqfI4BlLi9UL4tlDY
2z71Pku/DWbdQz0favrxIfB054JdRfCYOmhuUERhuspvcH9jHuRPWVw5Tp6X
RJTY2CT3BT70Xiro0KCRdjkgrWMrAzbuie5TkhR8ziXqR82qRJbwX+MRC6Kv
qmsz+qUaUSlHH24T4WLx5JwbB3aRPGfuwi9K8kr7gvcjtEgzgheWlNYSPC5x
KHPZ9zAfHMttaqvJvmzcjDPUStugqskc3abSj7BK2XOvhDuwhV9ijsdvDpTf
2ovv7yrGlrU/hkH4/KxuwaDP00/4r/7TKlUrwtf0FB1pr1jIxU8EGJP852Um
/rZBqBnLkj6N86cNICOah8dEsw3lkZnn/hA/5U3gc84Ur4TUWysnPhYF73sp
8epFrxFQudlt8SIaK5dp8UxoPMOXCFv1MEEaCZuOjKoeIfnC1imK4iN9MKHb
Y+ZKGm6bWhd+Eyb7OVNrpVGYjfSEw5a3aQp5N+645lbX4ueBwH1vowbwlTF7
3+qxKvBcvqV39DKFeGPJxf2mSZjnI690heStx90hfyL4PuPWHd/Zw8R/Gx01
v/2+0QL+LHedKtLXmm+7PHsoXgLvjElLHYK/3DjhlmdVCbgdeLPVeDmNjxYq
VSsmGlBe87c87zkF0cFPAuW30pH477vRgj8UIlXklxsNVaG8dNvZEJIvFS5c
C/gtzMZzfhVppfA+RFjazjg8IX2z7NOcF+T8+E6ZMUw+xsZHj4Wi5WlMnvjI
CPCqhtzeA39SH9Go+uLFaMhrhZR1dL7eLC4oGY1a29LPyLG8tPtREAePxd6r
eQXWwCLO+6FgOPE/KzHthpJMCN3dQRuIkHx2fPR07q9syJ1frKpjQ8NQa+If
91gBVDzfGWmpk/u/HlZC5Cu07R7aTG+n4Szoqh6ZSvrVfVuro9LEH6/Zac6n
M6HOSwuw8yhsX1t1SLigEdknrq2wy6HgkGU7OjPegU7jex4FT0n/2V5t5KqV
jBfp4lSkNDlPf5p65lGKMJvr6/RaaET9Tf/tqsmEH90Y7/L//npPqWQ8JxNS
f61TfcaIXzz+uF9wrByr+jY9ayN6sDPVyPzq3EeIveN87wbx28EFF9bLVMWj
tFduLnMpeV73vRjfLYtAKVdfeUD067XLtz1aLKKX/9pD3lgTP02MXbhwmoWr
S0Wt4wheTmTZCfg1kTw8FD9eKcdF8WEBqmx+PPYlRKqmkXln+rVSsoxYYGj9
S+BX5qDxxfS1zn8NSPjakZc1h/SvWTfCki+wEBJ3YrpfvR88iu46h3fVgC7J
oYaI3khtyu2uDmQhX1ZqY9sQyWd613v6l59ChLa2+0PSB4vD/USyxbOgH1xu
4l9NYWZhoFQgl/j7xP0V240pFJ9I3p0rG4XiHHqTJel36tnXJHIJv05tXBIR
TPRYRDpxy1hhJ5JUXspIM0j+nBXTqjNB+tkfn40q7zjoNOmpuebTDM/LpwSc
1AZgNZl7cr82E4lmMXfWEb/6lktP+upkIMTx7Laj20gfk1dmOTiUwW7kanrB
buL/wpXCD+UywZbx3W1K+J3UtXqRb2QX1lbUui+dzcUhicZJL5VOdC+LPNQz
lwuX481CFiYEL7aNCySvcrF0SF+kILALI+7/9tgqk/tnVzuPmJ7BnPrsMUnS
D5jKWqr98/Mg8ULx8owO8Uu77v01TQx8/ym0cONjwp+CvSlSy9oxOzy8wlhy
EKLrKudfOJiNizduT3SQPuEkc/Iet4wBmb4/25JJvluU4WvcO5eFHe9HmGmu
XHzufGkcvKIDB7vGhJyNOaAe+aptP0bu+9RMeL8kjU7WtvM3w8rRvldXKOAK
jZtz5C3sXhVDwMJ0URzJoybaTubLFVrAY20RKUT4LaUaHCVh3AiR5ENSueoc
bKpIKdxN/CPyxmxH0REObDJOD+zSiMadQ7TwXYLH5ge907KtbKR8dK3zcORi
3GX4QllSHXRvr7Bw/EWh6uxidpT4J9TcrbNYOU30v5dH5lJsJsqnew94E39x
yk2/yxwrxfXQ27msBxSGw3sGzkqWQk16ZvjmQ8KHcCWTiIlqCO66eTiV9AHR
yeMW5lfKMG9ZWfqeEBqnYhweNzfXI2Uzkr+Rvi23Qu2t0sJ0bK5dlOGuSCPg
yLoDOeJd+PDrmWPkvn4o76q2HS+tgZ2Lh4/IbA7kQncrinVWIfW2+stGkked
1m+ynhooRVCkufDsZBrbJ8JHzsmWYXfQt+ubj5D92YjY3atvhJKFn/BRIdJ3
AqZc7Z2LUPp2RyNbmeQLka5Ux7MlWBu97v5DLxr/AzwACQw=
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk41AsXx1Woaydpk4oWST0tyFT6qtxeSnLpFsN1EeWVohTqCpPJbadB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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs4lIsWxl1OVLpQyiXFdArdtTfb5PZK4+HoJtkp7SnXjorEkaSUM2Ko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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 115->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk81Okf16EQlSMphUiuEq3WEr2npkiRxCJbyZFjspOMHKmwhKxqoqRW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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VV8bxQ2VkKI5+VWmEillKkMrDVLIkNAkylSUIVJSaTZVNEjKkEqG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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHs41AkXZqql2lxSYbS68OWyk5IYQi9f2qZcm0QJIYXaIpdISOSSEhLd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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVWs4lAkbnklTSdkUUpJSJDqpzYW0t5KisMyKElGboliHiqmkqcjwJUlr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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 116->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lekbVppUclTUqImUNZGTtCjctmSpLKETQ5aUojAl/ETkVAhZEsZY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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VO0bptSXFi2kpGz5KloQyae4KUmSbJU1pUSFoiwhQlJIKYWSlEKS
UNYsYxfCzDCWCCVzzqBQWUu/9/fXXOc617znfZ7nfu5F2u6cif0sPj6+o/x8
fP//VUsdra/eV4iUH18u/VKioWXzrERLLAGHnc+E2m+mkfGyU2FOWj6SHIPv
d/+kwVHdLrFooglDVQcnw2gaTodH5XSelkLT4Pmu5jwa2Z/zaZUcJlj+G9p4
xRROhljekXuUA6sEwzs9fyk883FXkJZrh+UHvY9hRyls2nJSYEa5GoNFqh4P
OihMZBwdOn2yDaseX1n2XGQAMZqVNb3SHJzQ5WqYkvulLad2pPZU4MFEuPTy
KAo9zT18nDd3IDCWfP2RNA3KwbbfuaoVli/MJj1yeRDpufHEOTwTZyO+Rf77
g4Lf+fqKcH8m/Nxuy+9KphGTaeTFuhuGTRL8kblSNG7bcue+6EhEhPi9HvZq
GhfdjVbeTKrDxIiQ3+deGs23IobCPRvgHrV8oPAcD/XTf581zW+BTMdA2CRN
zh+m4tYvYuLkoPvkWmEKnlIuMe+C3sPkmE5GiSUNu/8OqMx1YMNNyvjblgwK
/I4Xw/nZ3bhxU/CcbAwXrdS6S34+RTAuKD1kIEfhSkBHmMCxBIz+CbdsWEqj
Kj9Mpag/D8+cn6i8X0vDcONlDce9dXgWM+Nt/YSCG6d67o7RFjwVubjFSoIC
3/bpUnGDFMSFPdrM+UVB4pDntXgLDsqbQnvj8sj7qykZT2+kwK3Ks6XGmMaV
oPDEnI9x8J3tJ/NZjoZpJOX9QjAfYVEpPiuaKVxkl5UbGldi76bTN13daZh5
jz5Nec5BM3S9h6K+Yp4GM1c1KhNODAGpLCMyjxEHpSzhbHgrqYYzrtDIG9k1
Jj6nEqt1jvPZv6Wxmu9rWcM3Nh7oU7sKHb8iZUJj+O9ICxrWWG+G8gBOK9ff
3vYzG8d3nWz2X0aDrT0v6m4oC1J+n5r3nabBOO1gbeuYi/vjRuL1mRSG84RK
BCpaMayiyjbaP4gNY6kb09RykC4v6zEpQUP5S9CPUEEmPC51Xfh1lAcOO3/v
8leduDjyJKbt2CDUvyxw7lrBxsLVau83Ww5AMXmpz0hZBDqEnnJLSb8TQnrn
ROz8hL+6AZcV+3ioyq6e/xOdcJFv7j94oh8GSpJfG4paMDTrU9mrpQO45inQ
2PeCDZ12E9EnogMITJwbFXuuFYfvClybzSb972ZVcM6mouiM39C2+TRkPydO
CG3rBEOwOTebvOc3yx67Gd0IrV53brcbDxfL7DUMClhY0mjx3/3DNIp/GtQu
Jvg7nnXyfLA/Dx/dfsyxOsOC03sLGWlVHlQXN884j2Yg9UXmxk38NCp+Zznc
nlMFwR/WGieSKPQ1L3nV5dgAjTmiucbkPMr6t0/euyL8NctJ666jkDH6x80s
thMqn798G/CgsWj9ipUsYRYWypiPaZv2Q81VyXuOUQrCTr1zvkr4os1ARsP4
TQ20J3qHHz6iwXejTXSnRTJ6QnSHXTeR87vVPqeE5ULv+Ev2y700Cm3VC8Ju
1SEhO2h74U4eNoV4jued74CAIEc29i8P28/kmPraNKP+ZP+Xrt00jEYKNgmL
NsHgdnWBfyeFBPEdKrb7mVj3KzuxpozCzmPnfpjz2NjYsIx9V4DgecPHVY7y
7hBV5L50lqXBMk5ZHKCTCbf5r81dVWnEq1utfxDwCdE6RrIsowE0vZE6VOBf
j+QBu1c7N5J6Pav0Qlc14N+sBeX3RUg9V/a1Xlb8hLz1chdq6UFw+xaX7e6u
x9drNGPnNS58N18OvcNqg5PSZLE24acymVFJvoIWVMTtnk7n9GHDlhOL6Qs1
6OfXU16ymfDXrhVlz8erYfNt76tl/9Jo2n9xUXMpAzndMucY5HnVgWrBV5VN
WFZpJf/rDY0eHZVu5jUfxO2+07hbksb1a3C17qlEW+W+wRg9GtY/N/66vKoJ
XB+6y+AUD/R8j8hQqVwkqKb/9lhJ6te4nrrJmYXRdxaBVkd4uNraSTeufoMF
ny6LmM2jcdgm6473f83wfnGvoc1tAOp1I97B2e14rSGQvFuEgtR9o3yFm1l4
rDA9mEzmeU3Dd5alPBtjS9b2rpzkImG8QtKb4GnZ67pPPmU8rPHs/Xt1Tyc+
/Wms1VcdgGrPpTbmn2ac3XTin34VGvMU9hz7saUVKRIPhdi5NH7PHiiWNMwD
Yw7zJW8nDUWvowvVj0aSc2w+dxN+N1ua8ihvVRusvwd6KF/mYsnUWPjrnEb0
L5zN+s7h4moNLzhPjQWl42kKrGmiN8ZrN5upsNEpNioYr8ZFfcd2u2NdHzA3
WHWgJIAHI8NiG90rbGRMj1qpbCf64z+5bdC5EemSTod9ttLIDdO6JB3ShsEV
AyFKnVwI2QQ9/1b9HgoP03vk31Iw26l0cP6cQhz/7K3s6kTmMaq/IC3yPeLP
Fy29oUOjYV3tcLEZB0WyyrsKnvRDp/HRw2dzmyC6VTk+hY+HzuhtQ+Lb3mHX
UjFpRXkaW4OFTjT5l+JmTnegVBjZpzg/g+tTb9GW2RX44waNLGVz47U17XCJ
rFjQyR5A/TFmrse3WnScWpK91ZYHUUb/1jDlOlQkmLwS3Eb6G9zgym9SjfPf
zYzY+jQCq8z5/0lpQF+SCeujJ+nvn8bsg0X38C5fnl9iA+G30l9+N9QeQ81u
7oUvBO/qfV6x4SuaIL9Df7NJFYWoN5Krq4VbsXnYK29RCQ+M7+WMb07vYRkh
23CaS6HTN0JndkQlCvnMEloPkX542b5XHKpCqldJV8YtwnfPBGfbeaYg4Rzl
0kHm6e+/4niIbAfkItMv791NoamrWFPY7wO29A8L1o3R0A7bbjLVXo+JpLv5
vWoUfE+0LbJML0fD6GbxrlQuptoVhf+cbkdL+OvSEQkufmeEhVVZsrHsSMP4
/EKyr5+CKFMzBwSK608pku85nqam07UyUepVYKNL8JuXq5l4IL8dX5JdH4Ym
DEDSl31H8FoWJm6hbr8wjf5p5lTnp1q0ZZsvdRwhfsFF9VUTAqCVqz37qAyN
jkpW7jyyL9TPqcXCJ3lo22OqOrogH1WtF1MFflJQqvWaOvyUgbklMI9roREh
NyR2ovAj6q1EnqcHk33myaaXmjbBL21q05EkGqVSP/hc2pshM10eu8mG8FHP
UPLeY0lIMCv2bRWncT96mDdgVQibkK2FwUUUFIUOiA5mxsA32rsoiehTrfzc
PxI7WPDj60/9fJ3Gylrh6ECit3y3upbE+9E4P3k3p0/8AYpop/Hn62lkfpZK
j5b+AJV1L2906JH7u8XPWK1lIrTeY9Y4xUOuQVTc8R2Z+NbQq6lMvqfXLR6m
HtuI2OTeiYgUCluOzCpXSmMiPdA2pHGQ7NPRVQ895xZA/7nT7+sEPxX9eoZr
XarAEd4QHTBMI1pEIe+BdAtmQg9VLHvHA98GL9ay0hzMM11/K5Lg5eRusZql
ux5AJsDujL4aDbW6kPYnpe0w93ywICfxCxQDPYNH1xVjqcW5Y2cIfq/oe8hI
ZjTCtCT3375+Cl/DFU+NDTdhH8XOU19AIzT5z6/Eja1YKGVQZZ07AM9LotLj
FkQ/Zj9urhwl+hO/UCE/pQ3eS9OKze1o6Eb3/5bMZ6PZWn7dISXCjxcbOC2S
TAR+5R/2IPNdvoTxJPMWB/KH3nEdQEOq6Pji/PZkLLRwc7Ui+9NWvWeHeHgz
wX3+PWmyv6vYs8sZD1nI+DoeHmxMQfy+g5+0EgsBcjE5Uj2EPxSejFg1MxGu
vHq5iBcNEdnoiYeCH9D7VYKV/YGCrpJcW9KVEmTIOzDuOdDwennkd/DqHAiM
yr6OuERjrbH3tf3uhWCtKqt6wKAg0ikmkSTLRqhjx74dguT/X+YwXB++Q1a/
r5quLuHXgQPuYoLliDuqE156keipwnb+VX/Y2Jmtt6ee+JXDt82KQnLaELGB
+2q46jMYey9cVA+qwQl/5bi8KhpLWiJPX2a/gVlNdqMc0SfGpUrfGToJ1iUl
WgZEX2Pkxz14ZUxYT66uiCjmIUFoW4CjbSu4x4KZdXcIXs6z5JNuVOKc4Lpk
a6I3TWUlmVtmkiA7Iav8UoiG/q518WG1zbh2JtRNieLi6ELnU5fpJvx0Efg5
4kpjAae/5fXXdgRqKnw53kUj9fMBXZVdtTAI0IjNbSR4LxhS/He6FvNynSY1
jpL6htb/9HIuxtygCcndvcRPB+7OsV+YDMOO9F0dZF4/z3SObt7cjjy7Nav8
v1BYmRrNy4mvxXX+5Yr7FhC/5bvOySmlGgaSHWL9s2j4OvIWsOwrYSm5+840
8dv6f/VfnDSsQYZhlJusIY0cez/7Pik2Tkmoy2rc4iH5BDPkwVYmtjtfUdwA
HqIW6XQf214Olzl6xxVFiV5LN0n/SWYgM/Noqw/JB75+F6L3m9Tg15TMJw55
5n8WEcTPTIX3SO1NTUUyv7d/ZikntiLmbu/GGX8aZyZ95zUotIA2LYzkiHNx
bPyFoM2eMoztK2sUHKKQKiQZ+o3LxI3Rxe+0iR9YmJZyit+7ATI1Y7N3rOMh
T8j/6rlPDNSblqzPJvtccbYo57ZFOaRuK2zLsaUR1cx16Cb+dla3Dy+tdAAX
TxW7KI3W4plCgWKwKIUNe0IXlIwlQnG+bcMncr9VZ8X/aXrbilmLfy/0mfsV
MWeFFn/W+AAn50Waqx2J3izdL7tO/TVej5w4Fkny3LqoZOFZnCYURmqfsdTr
R8phsTDR9GZ4+H6v6DnLhezy8GSTsxWYs1Yl5kEB0Y8Mtq1jjwtMik7c8iD8
O7hX22cyvBJ/xAQMVx0h/nKlWEXt6XIkyNd8nikjeHi1h8VMysPNBs3skBkK
jMsJ/BvabmPhtlHBBJL3FN31E9WOEH3N/nl66iDxR01GLLWyJgwvnjeib0Yj
7rr5UDLVgPh3N9Z46PNwvf3F9kcjHbidsW2RzUA/nAJVD3lalCJce/teqXwa
KlqZviI21YhZvuTnOaKXsiHmH7WfchC8SfZQ5n809uqF/9tZWod07/jvRqUU
PiyqD39YzYTuk1RqN8nL1gEDyb/KanGzeKWwWT4Fu5YXJ+2dWHil6rfcq4DG
g8mHd1q3cKBiJvq2neQ19Vli/uMfmzFRYB+S7d4P+/j48wVfmRB5b/wii+Rb
1VjjrW1mbTCfdDL5SPxs27bXLi3rq/FsudKXqgQKWf8pPxKMr8Fgp4JsYAsF
oceR+/bIs9A89PjW0iwKn+4bXli4qwmDVSJTLwe5uJY5f7+wYQc61XMz62pp
/Oo7PNhMt8Pt9f263edoaIUUMR3i3GHOPySgQvR2/a6ZCzMdDCzJt/ovoZPo
XYvMRfnaxzg4tbbh/jrCnyYZ4lKFRbDJehfaRfJOjUVa0KOALESa7GeUkPPO
eFhNb+ZvI36hvTCrph+MQVlBPY/niPpgL2lC+CbBR2XvCV0yv7azpfIEfwZV
QrIPXD+AnWTBd4X4VdWPfenXdtTCDDGa8YQ/56V13LkbUgyzsyZHon+T+uMn
ZaMvsSBhviBzcw4FBS3V2C8H2zGuZxJ2QpiL+1feHJGLZ+DRaE+1HdEX31qy
nZqlxK9dLznoQ6Hj7I/7cQuz8eyn4B0Dol88/yo+5bgqGLE87H+fpOFU4S3x
07gTNYcOHVxP8JPTbrnfOLMRK0v9i/IeUkixqVeLa6jCplu/R2I/kjz/peS/
nvpWXJVbIRb+hYc+cG3bHzKxwXyj67QW4Vc3j7grwa/xMnV6RwPpH+PxLa2N
okloaGdo6xE9D1j38vqWjCbwXgtZqP3iwiOWq2tK8pVYavewySrix9a4hDje
r8NFfQmT7Q/JvsSVN0jE5uHYnMPTT4nemnH0gh21GpHDUWNeeMqDQoSyw3qa
iZej+onF3ygYyd01P2v9AVUyDmdUSb+sftv/0WZ+xPoDyncKiL5X8O4oCeu/
hyHzkru7Cw0hxuRiU5JPewSuJuQ8pxBef32X6eUKSA0s0/NJJX5kznMHcdUs
3CuY0ZwifJhSMWtnzrNyJD58ZhG3hcx333mOu1kdnuXOEZl7hot5GXJUsFgX
doso73gvxoNskETx7PFanLRYG6Faz4VLgYHhvn+ZqKn7ftLGg4KTVjdHzJiF
fF1+jv4zGuaIejKmwQJleGrvIel+oq9BzXK25egf+5u/luiPrI76wGEmC3wp
hyOOtPPAEoh8MuFdhQ+x4zwR4qdnXmhsPRfSirL0na8Su3jQ8stOE5j7FhPc
MZ8lJB9ff7yTuihF6lUvXsDuJf7ixy1+WecPcA9gHeU9pdBm6/Lb/2YppoxM
mcokj82PEE6bvtSFgY/Wk9LxZB/M7RR09t7BgUP6s1aSef2zbY2JZ2wZZs61
yKaPkLyz6dG71JkyjNdbiFh1ELyrt7T+c/sNAgpHgo8TfVOriosYzC1Ep/69
Ph/C/wlyJ/Y730zBGVv2isqlhA/bew261zQg6N7G18ttKazeYznWktuIv0uk
v6bY8CCy+pOpnXUT3PFbfWgxjZGlDC1XZw7mvdDOsrtF492PzT/s7JrB5+mZ
/iF8AMqhe8OnvnNA672ZXK3Jhab2DsYbhzbM2m7xssKUB502gasmYdXw5yuP
ti8neVe2NSuo4jlScn3CKgl++XJUVrx+FAgvM+flcoQvSjyCFFoVKqAov/7W
niAKMadC+C895mCdv82V4vM8qHvcM/8u1wLvPnt7YeLfOoKu6fz61gSVvD71
2wo8rE4+4hVh2QCzt0V9GSSfHH1habkmqhWHXtkskQwl/mI/57xkBAf19pLC
F+wHUOM0Wli9JhusDg7t+p1CnO+98VROM/adj0xV66YxYVnv82pxOyxUudcz
gwh/vhQQzjtSgqfe6jyZbRS0vBInnidWwE/2SqE9RSGDGys+6VKBcWa4dhjR
T5Ng/uPpp9nQlGadSggl+qWm2btoqz84EmblI0S/xAeet/JEu5HKLb8irUXh
vEeitJltA25zrZM3bORhrsDdHTLBbdAdt7V7lckFQ45y9ftYAim3aGXRR2Te
aSvPjlV9wBvRjHkS9YQPYuMsTZ+z4KU4JeI+SeF/BggdoQ==
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81fkax9FqK3VjVOrQSFJkGSoXn5Ol5kqTlEmWCGG6RREllTUmyRYR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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk4lAsbxjW0WU6RIk19aVWRIVHnaO4InSxZ+o5TokU+SXOyVEj6YlqE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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 117->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns8lOkbxqmtFIpaOWw6qLChQmNnc7imkkMhJMWGpZrsJoMVNhRShKVY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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4Ve0XxUeDX5MpiiQhSUhKGqySMjRJpZRGRRnK1EcyliSVlKLILJGx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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41PkXxy26aAuVLOkypNJtG0zIT96idKErSroQVpFKwgrllmtJmhS5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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81Isaxi1Nqnus3SK6yhpRH0dOWeJBKgkdkhRCIbKVooU6LdySI1TX
KWRLJMoWJo0tZHSjYaYxDjHbb+Y3hToiHVt37h/v5/3n/ef5vN/neXSOxniG
yMnIyJyTzv+3vdl0YVlSEWySxwpfNJMwDamgus6wkKQY0GawRoh4/erdrEwW
TBQNdz9a5MOILTJOjehATWabaL5WBG7E9PfTiS9g33TAh1MphsaDl7K/W7fD
/Vg2xbxYBI1D6dUn1jGw+YnxseZQIZj36QMH5YehsjR+19RSLvbMr6Xldw7C
213F13a7APu68/5jmctEs/21uO6dBC67cuP+Lm0CzelDQPthMcz+2rAqlTIC
Q7PeppKQEZAFoRrWVzrxKkASrn9WBJU9ym4ydqUYDzOMHrhI4tftS07uv9+P
yNiMEfVJAlPGwR1yshy49Or9CN3Og3OIjJLxi3dwrprdvp9F4I2mxISnMQzN
8jzzNTajuHxx5JoxWY7FOM9F2xASBWpF56kpXXA3qTzZf0aEGzuz/Pb60bG0
4cOwfh+BMMt/B9aHtSI8yPXslL8YDLXA2fzpBtzqHVqiVCoGV77y6uX4+4iU
a7mbMEgicapBzlx63/a4LLXvpRg1WgFWtMfvkX1o3p9ZI8TRHbEjVpLX4Pml
xT41FyPrm8zCq+t9IKOtuzM+CaBd3WF80HYQgR5fw1fa8bHMWyG4+Z+NWE7d
szvsdzFWeKeWZfWykFuw3CJliQBLyEjPRuFbqDbejo67LsLzSadU3XEW9A/N
orKVj4jjnVeJpyx83HvZq/KxAFWTEw2CyRI8tl1tdOAuicv77sw/yOlGnqy5
Re4Cgaq2K0L/gRY88dC75BIkhkWC/2GyiQlBh/xR4ZQAvbJO/v4vWCD32tiq
3+VDI0T9wqRyI6iRtArTFDFaNUyi5gp74O36UKitRiDyFAde3YO4edzapaSR
i9S6MufcmBaclHuYaPpAjOBrRjMJw/1Ye4FpueO7EM56Hbxe+gD8JpXyetyF
KAivq3/3iYWauZ7Tx70EyPNcV3EvjQldhULfdkcCSepG8Qcth2F0h5lOVeUh
41wRpV65GivHHZZN/CL9ryTk/ERDPq7eNzl1s5WETNZ3ooVVjuF5YlmClKew
39pWrlCkoWbk5N3TH8QQfjw6J/y1Dz+1rVpcYSxExzO/bWL5VjzTMU2o6BTD
XHbcsWFDDzoXKdP36ARuSo5MqP7cg7f5hdcZ2gTOUCM1Tzmw4b3x4ZakHiG+
zD/a+WRNDagyRM3MchKWtGDa0TE2yqPCBgaLhBinbk3Rc2Ej5ke+5j0rPlQy
rW85+HeBbGsPc/tTBI77S58K1RZ80MwMNbgpBn04o3vBnoaBADeOtkSMW9c+
F/zFZWHVt4AU30Q+AhfKT/mWJmPjDV7LjKxEqleiOu+WAsemPZ5W8yReb/QI
LpdlokY9e6JmEwGZ8aITo5UszBYzzlR+4WPijfCEwWc6NNWnj4WIRLDkbB27
sKQWwQrKd2IUSFAovo2OixywzY5QGTkC+IQeMOF9qkaWo3JotiKJGDuVar3l
bCg1NnCmST6Ce1xT9872I+v0YpB1lwCkY7Ltn1638OxA9UG3WRIV1I40G8U2
6H7T1bUSi9C5KzfGQnYUPp2e0xy3DzD4yNBRe98O++zM/W6xIlhtG18X+u09
aIfTWUJXAuuNrxu92lSOIFnKcosgEmfZb1eHqr7G+KKh4Vy91M9Oxez57GLU
M6k7Wv4gEci2T9vkTMNU0AJ36wlp/mwwa07wfgqH2pUtNyJI2HmUDPWODmL2
eFnZ9xyu1Nd5ZafqO6E2Z+qyfYqAxdMI5y3vB+Gn1RrXpSOEK18x0tSMjsEt
RVeYgwTGwkJ4dH430luHdN9fJRBYzJx1yO3Al77ytzILIlR5iiW1WnRUrk0u
2Zcn9ZsP1dzgcy2GVz+l6+qQ0LPyUKi72YNtj9q8HJ8TmFSundH5eQihgdEp
zf5c3J4ZaVSzGURMcgT9rjYP+mXBzmnJdHzZvD9K0kyARp/d1H/gHQxj1/nu
fCDlM5/lER7PgEURJdPCSYSM0z4n877eQb/WsdXTH0lwne3oEmkfHLHbmGY8
L4DZ8Kpz6726YMkNv7VCSQSn84XTjOIhrDCoS4yW5k3o392sH8f7YBAr16/3
DyFktFojKMYPEO3i4MR/RcKmdJad/EsvnqtLnMQlBBoLygnv34YRqaKw7evL
USw903oi/V9MHKwdDd9rToCt87zLem0vMmaGprRSCfTykurjDnNwLerbZncH
HpKsgxlaoiHEDh35Yp0/CqPSKo/EqDrcaeRvDJLyxmnINIktaIVzmJy8EkUM
Ws6uHem5b/H49lrvnBkCpuuOGBkR/0UMix1/qY5A1CMTt2XyDLyJ5yS1nyXQ
PMcRmHEGIKe/WnzlogBjP4yoFwrp0D5Hrar4LEJkI2OOy+9B0fSlpgI/AsLM
NTlKIT0Y2/fR/4+fRFiPXputpSwo3qN0f5Lq+R+rkdUE
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 118->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk81Pkfx/0iRa20qd8mCiFEJJXW8ZoRouTaCYtyV4rJdmxlrcSSEitN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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Ve8XxZFKIpIyppIGQ4ZIEi3KkJIkSlSKRJokokgoJalESUlUKkMk
c1HmeXavyyXU13DPuRSiksTv/f11n/M89zlnv/vd67PWXuF41sqZj4eH5zAv
D8//fwMGr57pv9+OMPtKsyhHGkz1ibI/sVW4tUZROWQ7F1N+bKHk7wys9POL
vniDxnLFDo+uzBTI6dc/c9Gg8edBkKj3t3Ikf1GaGoihYTxlrqXyhYFIQ6Hb
e6S4MNtoMeNiV43Zvpe/PQmkkdyRJ3vUtR3TXLXTvZ6DEInZU1YXWIsy5wta
ErU0eh1ROduvBX7h5xxjjtLYfu6q6wcl8nzZZ37pSvL9A44B78Li0ed0fmaR
Mo2ALtVX86ZYsBuVc1nGGoCv3TsvpnkHJItkdB6ncyG3YW6g5S4WvOvYgva7
+/C1ZJ6Sb0srMkuKXvsOUDhy65nGyJVkhDjHezvp0rjS+2euphsD/DqzoX6F
wrM3aYwbnmyIdZWHpddSmKrK+d5wuRjJLi43pGJpLJm+t299SgsC109Ubz/F
wdGeQBvnU82YWJbZz3pLo2D+/ICB+mYM+XtZrUih8Ubotv7b5Ddoii7vzBaj
4aV2rcbDoQ2Jv5N3Z/yg8NDUyLHjJRM+d6xlgxW4yGle6J8S3ITopEN/BJdR
KKjySZgZLIb7txkV3+80ZG+tDuJ7zkZiiLuUVwKNTRs9H4wuaUTZFmP/K0UU
8kSV06QZHQjotvbliNJIMHDkeaCYBi0XSWO5gzRudT1QHWltxplRxbiRNgrh
lnkb9GxrofDL0/xTPwfRqlGJa13z8V3aPLE4iIZo35z3CkY12Ce7Nf95AQ2V
lfdE1M7WI4pPi025UlAv3Fmp+jQTJ/pe55/lJe9ffkrxJqnffGmBhMZ2Gjyp
EiFRP85D4JygzSF5GpbMuBc14+/gqOCQqsum8PJ78YeDi9mQcJAQWfiGCy/W
cqEQ42Y8CJuXc0GNg3aP0imJO/Vg8v5sptg0bP1MdIVf1oEvy+G1bTiN+NT1
mxilsbBbsy29V5OGWVqw2FthFrZwS3cv/cOFWHmYpIoOA+woq0qp81xy7ytL
3JSrsGWh29WOaQp92ftEDq9uRqnBj5dFioPgEbjxT2xWJzZ3nA2V5R9EwTWb
3wylT9gxeUlVfhWNpp+/7fKTPqLpXFbDi3k0JmPWjTaMdcK1iPVabwWNoHvZ
0vohpRgKbbGyY3DAU+7rluvbjHc/CneaPqKhM9fv33HPKqxL3cOymUP+Hxrp
N8u0HVrL7VxOaVNg15SNiYm1Y8RSk5G2ZADx2sMO0cVZsEg8KhB3jMb9pZFt
H0MbMd4U+tWenF+9d2O64+FyNNk0OQwlUzBCa8GOqmrcL/M6VmRFYUGgre5c
Vi229xQ9Lq6msP/gNimVAAaeW6hd3wkOjugUf81takEd73veTX9oWGuabSmz
a8Sfy3uLbz6hsFTVcseSTQzY7S36d9ODi/AnC05udCf/tx2pyAgcQPjC46Y6
lS24WnI1xYQi86CXQ7lpR2I03+vRdkXCl8+qK6INC2AvvvDvPqJfrd1/dDO0
q+E3tubKLFD40sOy6HVOwbTp6uHToJFneOD2REI7yiitiQuzOOjePGj84Ukh
TAKf/lU+SmH1DrkE/+0s9D3LtfhL+nVk3j7BBG0Wmhx5RgZ7ORDd8CD9z4F6
+G+O3T2XprH2hIT3m7CPaN+6kC1sRsG8Z5mP2aEyRF08dWPdXxoldUfeTfEX
I6I86P1/jwlfDOeumsisRpT9gOCGEzRW29mYKhqWIsdmrMSmnEKAjbDFDDsE
5gNTbAvCJ4Mt/ObqlSHozbJMM5ajcXX/lwT3hFb4KbdYfPYdxPGX3/naQ7sQ
v6ev5l8RjZjhIdaP6CbIes8y+BJNgz/wYGzgsSbkrKqy3+RCw/W+WA+HPwfu
K3QfN7qS76vTu3KuN8BOTcLsDTmPet2Zh2cDStCfLDZ6w56GSbn5sG9MC1Y4
fnzsbsJFfKLryoLBZzh2b0NQMZlXqm/ykFRaC5Q8/btDGwZBsd74n53KgXja
CfFb3RSU63xk/oyW4Ujh8uHjbuT809oxz+OYOBu5QleFbxCBWkzTXb1MtFlc
EOf4kPtMW3XMKq8LUpJ2T4cTBjEeJy4frlcD1eW+624pUYhf+rtNKzIH1zY4
cp6Q+k9tDmO1Clcg0rR/yQ3CnyfOao1HS0rBGlPge7iOxojgSfO9G9KgIDUq
Ukv0oOBvJLKquRjPb71t+E7m5YpN8XGHzHRkNDJzKcIzyVM6dyflSzHiJnu6
4hzpH9upJSydBQvpxkCOHheDe9OE/beW43voOaFmJuHxAc6kwdNaXGS227kt
JvqP7D1Q8f0p7BzyTwrx09BTvbc/52ApkjinghpKKfBXHot82ZSHRMYDfcEx
CrICTnZera3wz1YdyXGgQJ1a7LS2nw1ByZ6lxZ2DaNzA17B6tBXqsj9rz6T2
w2Bs+tZX10RsyXa/M03OV21reDJLvBVv9vpE1R+iUHTjUdtO2QAcPPH7w1cy
L3mnXn5wPtWJnKJ98hFdhDd7Umy7kuqQuiDB80Mc4Z3HshyTqk6w9QX7+Qkf
3W30svMevoFkVtVIiR7ha2V0ao3CS7yKs0hZRPQje+J64u0XdRCvypgeMaPx
xW3F/IqBRqxPVaW9ojlYzh7ov174Dupf/g4VbqKhOF9CJvVgGxx59J9fUOeg
qGC4qCUlCuaTbuuCyPy42y8QFn6ThEtf+tT3kHonRMwfntdg49IL1r+0KuKP
uVObtdrLwNw5KGawl9QjI7Ih9WMhdqpbaUm6Ueg1duDV29yBuGpzc95XhJ92
dtsPWL6CwSpjh0QdMk86E567tBtRlzdl1p/BheDGYAuBVAbmTO2r9iN+Hn1g
fA5faD1uRHjx9a7kYracQsDp063olrF7HL2MxpHmwvK9PyMw0lNv8Zk8G3y0
AaczFQyO96ToDAW+jxOiYQMMLBAI9XFeMwiNvqWH/1Nrg7oqN3G4awBZInzW
vwifC74mLhh3IHnjHTtBaFMU1i797P5FlUZf3cmsM5JMOG+ZdjMkPOudCVin
1NuBsghLVa0fHHwxtNo33vkCATd5Q24SP1FXPH9RSb0Qx6YUWqOSKBy0r9ut
O1mPPQW3+jLGaYg926XVJ9GGJeJ2ZRddudBz6sOd5xkkX/AXFpD7OFjl8mhO
aAOOpViIexDeBRydn26/+ApcH3oIs4l/0qGGu+eINKPx0Ph8QXUKnyNOnk0Y
ZqEy1FXmZQ6Z7y9f1eZvy8Fz3ngJ/7U0HvtbmrgIfMaecK9yp6tEf3eyed0F
q+EtaK9QKUjjDk9n3YX9zQgcvr/8HdEXHRudK3KwAykLP7MWhnPw2UFQQmlb
LcQqzvJEgAvrJ/WK/jVtCNrGOyy+bBABnQlDN9QcEf494Vku8T8Ni18Xm8h9
Oay2u5l1kvAs1v4yN7cAdhX/3eZ/SENo1vFJN+LH3hWJJva+XDQ9uuNyMqYK
F+sW1Y2IUbhgINnOTmNjx3TSsajTZH5/FBvnLC5G+8WSW3kfiV6zvIyNHpYj
gv32myofjaLdsxeUOSfgp/CWRcazaIS0LzdZV1WKz0Zlx7b70pCpVldLDGuD
+bVu04JNA/DYoCFncfg9fLMuyXUTfiiwvcSXBdTBszb45GUPGp5OS6xLL9fD
4zErPT2eg6b+B07hKimQ3/eS12cLmS9NvnfWG2vx3XCaV92W8Fy5R6+huha6
Kte9xLcRPrFDS+alFWATt+fQgnQKiqn7dysaMKE+50DnvUIa6YLSykr3Cd99
Iiu460k+k3m785pCJgzbNijEEf1GmOYE73YqhrSoyWwjFaInnv/y0iRX4cFU
/PAE6a+lhoTffOv3EFc0zREm+nkiqXjzX0UL7p/Y+u+3BIVvtsMHrjcw8Ov3
3aPquzjYsrXb0ZBL8iJnqOLEFOG12CuJ7utM2AqEnF77iuSd3Lsdjw9HQKqy
/XrnUhoCKbzKizyzcYzz10aa8FHcINVmemU2xk/xDMppk/7qmxXvzEnEIve7
RzLJ/KgsETrPY3YRa/69uDSPzGfAy6Ao6Y3ekCyxb/xHnqWoE96TeU2w8Tat
F7pO+GK3WpQVVYHtj1++fdjHgdW1Gi+9xCrwxri5L1nHhcD5a2qT98qwmNqt
Fjmf5ElVvkz3BR340ySX3x3FRWKzj1XRzQYYaJytHG8n3zPaLvRUhgGVQ8L5
ZmS+6hL2ldjyteJloFxKZDwFQdWLLQvHSxFwP024fT0Xtt1yYbqvCsGKVb86
QfYZn/vfrHhj8uDUMf68jPjPgWlpTaWPHVjN5I4M7xqEgrfzl+Mun1EWLL9b
NJ2DrOd9l6y7G+Bf2ZA/bcTBs+Wnm3hONcBshrtf4SEHrqM64nP0W7B8ciza
Npfo9+eKojQ7K/Q/m71nBemH/KZxBGytxj69ZTavk2i4vZsWH6ttRpi3SKtt
9QAChEOw8kE9At/zmfF85cLSMOW3/5dyMP5x7a/8ppBQLG2yI6sFCrrxNjxh
RE9NN9/u9G+FB7svblSVC127aNGlpgzsi3uwY3MUharksYjYrgqMiAQ7Cwly
oRasPRa+nokmnodeOtkU6jKvnqc/1UPn5NCK48pc6FTKSflpVEG3b7nX/jEa
0qeefBilcxB7KOgaM4vCn+vHdwqntiHLwKXNLJyLgLUTXbeXfIL8hLKHxiIy
Lyd0T1wl+k2IL+1KUuciPeuox4oPL/BpQOizvALZ79hCxsZjDTizw232026y
Xyhrqzr5FELrdup1S3Gi9wsiy1gNZegKV9/kI0CjpkhoquJpC+IWLb3/gPh5
9OPji9avzcIXoWVLBZYT/d4VlRULYmHyzIVDS3oovNF+rXCxsgbqpULMN+T9
Q7FaE3o3PmK75qGbi5OJ/0x1inkKfkLRW5uA0WDSv79GP92MK7H6dWDVxGzC
zxGXvXWjpdCKuzwSfJ+Dvn/vEpNDmAhROCaUPUD661Mof6KViY9QiFJ04mK5
TGVj4c0b0MlF9iSpx2z0mZizZAXejHkZbSb3ax4b/pYVmoep5PtUxwTxf/Mj
G5MXMuCn9+BedSkXoSraLc+HWBiTN/Ggyf4cYDOeaWdbhxHjAtfDZ7lYpcbY
6arGgvrxDumcq1wckeFNNZipxNVsly5s5aLo++CACn8z1gx9lP4USvg4lz3J
9OvAlZVO7DatQaxPOqRb87YL41sLOn4YDWFKXlGzN4oJqiV2jts7Gt+H+74m
2H3GrWsxFlMXSf3iVydijpXhgs+4e/Ighe6GaLPG8lo4DrzZ03yGxt9Lck8P
nGxHibbq9WW1XFBdlYFpQk0YdyitoYm/2bpt2ytikocMvT/O42Te/eSbajd+
Y+JkoF/tLVEKJSLC4rHaDHzXnJqbPsTB43xZ38K7rfipcaRfxYqDoDOU1du4
fBQ+vd7zS4nUN35aKFH1M3o3zL+dtv4/SMr8471Y2YjuuYGBj0NI3tnac863
vRWuCWxuteQgzrR7OgQzynDY9/ePSXKetuDImAWPu/BoV03bBIPsG/Y3Eg6s
SMNhw8F/QoRnB2ckwuVY76H5zVHjBumfju68395qDegQTFF19eOi7ns1b+4J
wvsUw8xjZJ9tmqNyb29GPWoG12UtI7y/JiXovPBXNeqmG/nnkfx4VV7r5qEt
XbDWylHNKCB5vN8h2e5sDRb09zw3ncvFtfjhUpWkWhgtO7AnfD/h+YXxsMN2
eWDxZW/jJ/51wXXNz+ZzXWjSfGK16fkQhlyLXZr9WqFbe/f8oT8DGFFcefpg
fRK+mZbNum1CI+v0U0uXhiy88miZGSP+pF4ksu1H2wecrZTSPPyPQvrW+tDe
I9Xw/PjQbt1JCmED2u5xX5tRo2ES0T6Li7XJm6xXLChGHWae39cn/hb7yEo4
OgyiT7O1x0nee3iTUpDey8D8BMlfoYVchMnazatxakeGUbryooNciO9+Zv1Q
vRwqYg279A9S0FuvJaykX4cPOcF5+3dSEJBvrJ5uYqHRUyJPVHkQ8XfyUyVm
ncNgdrGOH9HLuFhHy3+vG8CzXv9fJg+NT3dY1m0PmHhR7Te0xLsPAfpyQUJu
tjg+07Weh8zTBf8x4c3lrdgY3K2tmUnybPW2fP2QMsw/2hq9lPBuQkkmTzr3
Mx7/Skujb1FkLjluPb+zEK5QM/VNiPDeY6j9qH8bTKQ63JOD+9CV8WOu1OsO
yOvsFxAwHISMlRRzlQwT0+mlT8ru9OOHmtCSJOLXhov/c8o3JLzJjoq4G9mJ
2XPn+Kr0D2Ft9usKN70MmEupK3ST+zgebe80X7cam/VKL262pJGi9TX3jfcL
pN9jRDjoknwRM72j6FIrAsc3HFH8S+FM+oXcX+ey8K1i7HodyX8Gv119f6sk
Qdxx+YdpwvvIZU5hgWntkP9qtKXnPNlnPZ9IXinNwI+c8Kl5JB/92s9i8/Uw
wNpzXu690iDSj4YYrnLOxxPrt/tUDpN8Yb72dvXlMkhYhWrKddLYk5vkmcxo
RVbCTVNrcS6ktxT5n61rhlnExbJ7hPeUqnbNKLsWs/U3jMmTepmLL9g7fW3F
rjRh5sgeLhK2irw1Od2JdJHmP92aFF6WboqrbWiDpFfImaBiLn6Vu6n7M5rx
+2jWx/8W0HDQ38wWbGRioO+Z8V0VMg9DPLN+2pfjw3D62vceJC+3aqs8kSyH
1tOfQXeJf+i6PlJT1GiGo5PwrwTiB/7zYy+9s6zEJRj4Vnwi9yuhen5GrRSB
S5/TLZocaC8pktWY6kC3nm38uwYOeJztPY6KBEAuQIV5huznQdyAjKuJzdAx
f2m4+AEHaf8m+L4tZWCgU/6eXzXRn8SEC1MlHY9q7i68RfaHqpL4NsvabOQb
rYxR2kHyV33ZicbUj9jVr349OZyCxxplHW2ZUvR/iDwzQ/JPnoCkwCunHAy7
2lORJG+r3bYOSnrfgq1fNk0E7iT9WuD5bXI2eb/W1jUyS2ik3V59Mm13PVr9
9CUYiygkBfLnzvpZjvcbzRiB/RRm884o6gswkOk7LTavmgOPOaLbM7fUYWIk
pk8hmgJPs+JJ5opyVHwV4o8i/r9ANkL/hUsL5pwSTbm9k8b/ALFT82c=
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs01Pkbx6l0VQohhIiwtWxJRN5iKKWbyCU7VOiyY0iSVUuxlR9JSZqo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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVHk41AsbdaUu8V1KKLTwaZm06PYl3YvDJXRLtHhKC1mq272KS5F0b74s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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 119->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lV0XFXozJmWIJDI1p5LKp5ZcigxFSFKG0O0lGYpUqPtVQjJkiCRJ
vRUyhHLLdE3X9OEa4lIvJTmNNKAyfKc/nt/zO79znn32WnutvR9V1+PW7oIC
AgKJ9Pnz3tu345qdJxen5Gbkz5kS5Gl1uv10KYOIkkr+kw0EPtbi9dbuCRDq
zlc8r0YQMucieGZ89Jypf9N4lcD+Y8/i1fO5UDuQxHXeTfDdc0CB+bgNr75L
f5I5RddSR9eOZsdCeNd7mNPvtdW+xA1lXIV1dMaX/KUEY1Y1fiIJ3ZgR7hP3
DyY4xz7zaSraFiK6znaz6P6gS1Dyr6MVYD5/OfBWj0C4eq33Qs06cDbv9Flo
SNcHvsaXifNhoKYVal1CIGE1yp66WQOpRMM8my0Eym9lcrH5BSR6vcIk8wji
HfJkLzHaMF/53L2hPQSH4j3W/G7pRHHxBYFbSQSeyrltJartuM/uu8t1JBiK
nzPFSOEjkbk6ghNP4PzWzMf0ejO+lrpsumhB8HefGMNjmo+bb9Kvsm4SGEgu
/D001A0+W1JXO5GgIjUtyWXdbbxui/KZo07QFfe6zGFRJeK2MWTD9On5MaeZ
lOQaaGvKuy3aTiCmoNHyU7Ue6uE678wpvmGxsd8BnzogbK/hHOlNUH2k6cEL
hxdomhvh5PiQwHxXo2Lguw6wQ54vzEsm6J/rpJAblAVmcmxorxbl/4JL/oaa
OpRJjsp1UbyZoY9epcp2Yle50KhjDIFecYRh/WQrfDcpt0zaU76+WthsuFeB
TVdsny/ZShDjLaRk1FiFwnz/3HU0n2VdpZWFA9VIC/U0DNxGoHr+97q1j3mY
Jzkm9mEfwcf9ynozyVX40myeF0XxJY/wN4rr9EB52janm0XxL/x1qUa+F5mP
cfJ0B0G24I/8Sa9i6CfxradXUb1p5HDZHtl4n93wYs0yAoFsNfFn6towLI0d
+K1K41s79pdGtoF1QKlN3Ycg3TjtY8BQDRZe3GocakbAVNkhKebYjhuNkQ6j
l+i+1k1/ibZeRN+pnaPXQBDgVyXz6mgHuJf87gVQ/JrTZ28aqHDAQS0PVF9H
n5dYXXH9HyL/6kgHxaMSvaDg5fNqqO1xC+wyISh8KD3+quEpsu+K6vetpPnZ
j0nLZ+ugTS1TdZLmZy58vUxEuBoSP0p/SRsTiFSSuGe3KyGUMKDF+g/ByCh3
uXt7DjzSvI7LriBgRzO2W2x/hSKBg4PLhwmOHGSMmnF6ELTIZnWyP43Pzz0Q
LM2EUf/nCSnqh319+Q9ZIb2Y3XP/ttc/BJfURG2PR7aiQ3if4YO9BCf6FzEr
HSthkqoZztchSKuqWJe6jAfB7Jj30w4EpyX7NMi8RJi+DhA3o37U6XFwZRYV
oTh0wsmE5vOI+/1g8zGq/4RPojco/nt9k/wnCdUI2GrtHWhEcDhHfZ9pAQ98
Ec15mUEEjvvRlfK0F6Lp70VjKgiCy9XDf5m9wPiZX2o+f/zwcbuV5q0weJeo
x9+h+XeLZdh9Fr6L9TKFr0epH0ZWHSyo1c+Bce5fS0vo/cNOtb61NwvhYxdW
rkjXZ5tCznl28xATwVROofnrLv4xmxzpgq7dK5OjAbS+n0+mHFBKhWhM8xiL
xruUnqjIjeJgs3Gei8Amgr56DWPnc7kYaML4oCa9316lgLviX8z4lgpuGaf4
ZUIisjJ4iBXf+cQkhMCLCM/2f8SDXYB99oQvvf/Lt8KBgUpciw6UM6X651qa
zk+//AJesoeC0+9Qv633S1AwbUKqU0SP8n4av1BfJVKKg4YdL7UUaL2n45x8
Gqd68NMv899t0ZSvwa6wdn4jBHWWMO1sCEzCNKWm69hInNTRc19LYOwuZSvV
+RLyUWYO4bQfzXO18KwTfYC/HZpUPtD8o5hn01cW8eD7T5aOKPXTZv93s2yP
V8BZWunhMdrvVGQn321iZCDRRtQ0ifLhd8hbO+0UD+PL9ep1qZ6WlVtcfXas
EfO+uTukMAj2TG+Z0Zlgo99im4qILsHG6wL35zFawOmJaQ06RNBi03h6f0Er
HJ+O+etaUr4Z7X36NoVYempu5qY1BBuyfQVHCtuhYGL7ZuTsn/7umZ+Vk4Gf
ocXjbvT+EIEjnL1CpWAxTnbWU7/EV5SlCEq0I4vnWhz3X4LrDL/D/b3lsOxW
KLpF/Xef/bZhZ04r9c/bNKsTVP+nha01oktx+UR1Zuifevp+qBLQr0TGI/Om
GDqfuDn76rZK1GIP+aQlSPFsa5ELDhjkYqV2xnwX2r/62qO0H6m04zTrw5es
MIJUje+BSuGVcC0ne5xA592M8cTp63R/v1ze0lCa37X1zR6r23D9mMn5Qycp
nwqMhuCSeGQu73aJoH5ZMhpZNjm3EYEj9zhXaf2MVsicvOvdBNZH7zcvraif
q2pjj1nywFhQcPH3GdqvreXK2R5cnBgUyXxjQPVSNR1R9qsSu+0UlRxpvQwW
iTsqG7VAoflaEoNJ0MxufK853IBTQQuy1lA/GxQ9m1TzYCHOfSfbifonc3jf
HfkbbMSvG1nzmOJ/cDhrao1LB/aOasp0UT0Ir+KMPpfOx3rfY4lMyveEjSAn
yq8eCp9/yOlb03nbbHk4p7EVYUknYw9RvSp+tw0vk+pGeaHIErccipehdpwl
UwT2rGiepDbtz26DlmYKPdAxDw/poX726r+/sXRXMU6IdberUn+eujNts9Gi
CDujKxcEribIUNlwJCqQB50TB28UX6T1mxLyOy7RjOHZEwPS7lTvbVvV30VU
wfmso2we5f/pnF7JuIYSGH2SPxtL9TRSEyS993wnvEdaEhZ50H7L8p5lWMLB
yndjO2aoPr4HJXo/kGrHXU+rK0tc6fllhrLBow9xZM7UYBGdd2Fh2i/FVvfC
7C5rlT7t7yGll9uFdtfhwEBloxbl+/IDRm81jS9+y3mdGeXr427xlPg2LpYO
u3KH6f+L7myO0XrNx+AqbQ9RoPmkbvvWv8GvBvOT/SyHzAlk2ioeJzzphH7B
4vE+Om+f1rnJ6Cmyod7qtNment98QS/1LYMPnSvbz61gE/wflqCiSw==
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VV0bxhENMkUp3spYoUmSZLobhBJJokGlNAhFSoa8FamUIREyq0ik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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHk41Isadog2OWU56SpRTpRElKXoNW6pUxIixmlRBylryi6hLBVKOZaU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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs41AkXx5F1W3JJslGUotsqSyXJVy4lmtZLuS3r0pLUiomk9FIUi1zC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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 120->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk8lekbxhst0zKplDBiJDtJipBckuVkrahQxpLtZ1RGkqUOLaOIyRYy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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8ld8fV0YaRhIqDSMhRKU09EaFUFahkpSRsqJIkiQkJaNoKCmSUZnX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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk81Ikbxxl+pfhlJKmpZh3LtkqptGzkM3SRFaE2IVRyTs4dV9GikyVH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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs81AkbxaeUVEgS1rrkVkahLZfeYk+3162IsVldlndJal1CEcU2iqzK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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 121->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4VesXRkKGqER1VYbIyXglUfJSpswRGlQookFKl4SUS9FgyBGqn6nT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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lf8bxlGSUWZGJEl2KEXmJUlSRpIULaVEQyWkRWmQ1bayQ99QZsjO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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs81AkXxqWSzV1TSSVkQ7lEq2yTHk2876QW0YYoijTkVklU3kgJW22x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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGk81Isax0WSJeFYxpKjwmQpN53KcvOjugktFJLtDsVRpBIOJU2LlKND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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 122->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8VXkYxg0qLSJFmrKFiEqLphKeyEUIubKlKFeljTZjMtUlbkINhYTK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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8VH0fxiWllO4ShbJVJFSylAoXJWm1JCQtdpWd29ZGixQp6k5pFVqU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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs41AkXnlLo+mUqal3brf2wrbC7hfCmQraJrljJvYtKcrdII1MkDVGb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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk2k4lYsChTWIIk6ihDZbSk4iKalbLcXN6ZoaKA0yJNVNOBF1DSmuZEpF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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 123->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4VesXLpRCoYi6laFUV+JERaY3DSIlJBVCRJLMQ5Mc9AsVqaQSKlOn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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8Ve8fvymSfJGGUFZIVCgqo95UZDRQRqKQpGgSffGNEtGQpBJCMopI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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs41PkaZ6IjOSRKKbk0plFn040S20ctg03lViOmqUQuR5oucinpVEqo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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81AkDxifbocOxLC+pjeXtcFWOPlI8iiZJKUekEhWhtlGvc1nSoUvY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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 124->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk81Pkfx0e0NtlCfiL9WrUyHWgqpQMvxyTZ0LoXSYfIFiVUjsyWcqxN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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VesXxgklIhkKKRSNiiIX4aFBypCuokSpJN2QMiSE3IarVKbMRIRC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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHs41IsWHRQhdDwrj0qhcsiRV4XlxO0UUpJ7QqU6GKlDHlelrkdJElGm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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs41Ikax12W3GISG/J0yCW1S4esSh1f1akkJbprK5wQ2ym55ZRKF/da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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 125->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4VekblYrTqJQxJbdOYqjjUkOF1CpJoSi3OH5FUrnLMDqEbphkxi2X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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k41G0X1ooiVKoXlaVSqGgRottWiIgSSqWFFCmVUF4RyZpIKJRdlpCd
F2HE2Ndh7IrM/GYklRal+p7vr7lc4zrznHPu7UidvWJmO5+Hh+fUPB6e/3+G
xxo7cvUGUaeUdjPbl8Lb6F++oaN9GBMsjaQvZqMo5fl48ulOSOz4aVCuQ2Fc
VNRBKaYIC5xHd07upmDptT1fo60Dvj7rb7VocWD5dXlgUeNrpEjE5mvRKVwz
kTNYH92JvLqQXAEbCvpSoUUhDzthoPrm9foRDs5XGH670NSHwKClyT1b2aA3
0e8VmeajecvqjmPk91Yeykw+PK8LEirNTtpSbNh37JMREKejdaElKyiVjdjw
IUcLMQZUrLpvXGp7j4e+1+5+KMtF5gb6Wqm9FHRUL8z0ve2HDct01ZI8DtoO
q/7knutHurJYSI4mC1nnd4+ktHfglumNUPEvLMSrtSze2TgA/yx7v540CuEb
nW/Oj2+An9gvpx1f2LChb7fzbEnEY1mbVto6Cocf5pYfvz4EwUi5ggZvCo9H
I6Mf7OpDZp6GKn0LFzyFecJr3zWiU7JvddsqCq38PSI3+d+g5r6leL876XeJ
247cyg6orlijVuRIocrp7MvO7nvY91f9tKAMheeFJaWXGQP4lDksH6XCQi4t
RTAsvgv9J+pexmyh8IcdKs7zuxPLrEuK9UspsIWMElxiyzFF/73gMXm/5oN9
eVbiHqj9GJH9W5rCMpm6KkuRRjhzfH8N7GWjANJ3Gu7UwPMpJ2ezPgWbOXMp
b75yTF5EBm0rhYr9RlvFexn4yse+snctBz/n75rsWN+O4k3prpQRGznp50LX
7GiAl5LhMIvghydIQvKCWwn6LX1jLkaRv+NoT5PybwBv2lQEJClIbtvxONrz
NaKzZHmKKilYLygvu8bXhXi93MXfgymcqjpJNzvWjk77dSskJTiYM+f50yVU
izRqW03+PxRU7CSs9x4ZQVk7f6iqAYWuuKrh/P1M7PdMFuoIJd/3zRdJ+i8V
hy8fshJWoZCsMLRC168E08cDaEdJfz0Dmle2kfmXxMVvm+DngJm/n4v8StTL
Hfn9PoOCxNCYVXZwH75oVfaER3GwyvypdGR3Lw7S5H0PWXAxveDQeGBXC7Ib
FmzedZINZrRW/+/IHkxt6Vz0YpyDF5cW8H36U4LbZvfdaXUU1llEi4ROMNHz
1Oyi5gkW2G8+tjhdzIWb9YHI1XwU7NcInl0eV4CzynuUaPcpgrv57i8GalBu
bPEo6DMbuWJG9SrOtajNL6/mPU9h5p6jfeSVfBR4lCYuIf3FSq610H5Vij+v
xGt0DlJYFbK/Sr+PAeb+BRO8r1l4Wl3h2avYgWhmz9uNNaTetVRWhkcpxEZp
dhMOFB5kZgSWuwxiTXnBiDmbDfZKyxkfRyYip9kDtQwukuV7PpeLMaGr5+Dw
dA2pb3XFtvXfarxcnJRzpIDC0UlLpe+K3ch/6D9T1TWB5qWuFzdYNyAv0MmV
r5fgVVDC7cmnLrxQfdnwfpwNyYbReJ6oErDNeBlsOhteZputDG/TUFlZdLTu
OxvKjuLecbta8CcynqZ0gsLNH1XaOrNMWN3mPM6fpbA59u3FHBs6Kq/4nr19
iIPaDP/oeNMGtB/94re3fgI3NuSIiqysB4/VxMW5MTYK7SxXXTzch8eNs9aj
JRzcsDWZ3vO+DlfT2hmJJylcrWNKPXDIRLiwsF/TBgqnAzsPGHzoAY9ozGCe
LNmPzKSW6nEGeO403giVZSM+N6ep4kwRrEeZVrfsCb7LLjyZ3XANc/Hsx6GE
XzMzZ7/5yVYj1XDvlrCLZD68MsfLntbDfre5taUAG4ZHjnD/qepHdEJBjFEe
Gyv3uZ3jWuUjfGUOT58CBaNNlXk8xp3QLRY6N0bwE1+9e+d1u0I4JUpqz4iR
35vU8H46ko1TVxcNJ6yg8F6lf/LMix7MRq0oWm7JxWToWQ/6nW4ce1FlIf6B
QklZzJRDdR6YSkK/7xB8xAqa9OiX9+Hhf1kB1noTsD/wTjSZn4ljBzQC1Ike
DLlKH3xU0I115WeWRcZxUSLOLXfZ9BKz73YM2omT9yWrt+E+DZE2KqvKUsi+
NByOeF0rQbquaRfvLqKH2Q3CV/pi0KzOw3FaRmF0qsVlams2FjwemXmuTvh9
QXjva58GPHpKi629y8ap9VsfJC8dRva+9TUJMxQUBWUznGbaEBKybYc44YM9
1+vHWh0GBGNrzPU1uMgy9mVkNDEQd8xN12wBF2m6Sm+fnWBgeuvBd4eNKfBL
xHwfO9YPwXSHhWnjXPSg43yHUC+ubf8hJafNgbU8/xJve+IHuW+kbxD94KOF
iunZlEDuomCTAOGHv4hQocjqMhwaO1lucpNC7mVvO17/HHhzj3bKniL/n3cg
w3t7FaTFzxjY3yB8mq1HgE48ssNHrrsLULg/sTnwW3QvdPMeuY5kv0fVQMjO
ZcwasEp+iVaspPAj8U9bOXlfOndYuVWbjTmNGEPV5V0oHU48JKVL9Nix/Vel
OxPlasX6zeUcCCwxe+UgQfz1tq0VPXECpnGpq5O31aLm+oODpdEUBut4du5M
bcWNf5cvuJLGRv2KTybXTbqRSpO5aajCwZp3Z2A7XImsRyG324hebGV9DTid
2YrFedQyMTJvemmz3RmrJvRXvFMf385B3WDpidfmDIymLJ12+UTqtz35qvep
A8Y67n/HeSageWK/s8fqZ3jmUK0vTfAoXsjfr5zQirn7oTXT4hy4/hf4Onp+
Kwp6AkoW87GRYmPbcqKxC29OTvYMfOBgcv/NPxabGhFr8zHSJoGCQKPgjeGT
DFivFb4/Fs/Cms91nfK7e1Fw+WvA+UkK5s/a4sSE2hHerOTVwWTjqdXf1tKI
RvBtjTpMU6PgJb5Scp5yDDhjhy4lEbzl5svICs92gZF4v7uyn8Lwqe6OfU/6
4eOxPadk8h3U91h/ayZ6UBMk/CoyaByaakE9jaFNWDcbtF3qDqmX5ykfea4Y
fKe0GMarKUz/ExRuvScXTg+7wX+U8InVNZc6mIngMuVV4RuJvw55jpZdf4Md
98KNLhL/7153uIW2swym441e49cJ/sPeCVkaxoP5uynnIuGPxUqn3UpyDOgn
vXV/fokCxyeC/vFqFTjF/g7/nSf6+Czo+re2exCWa3StlyJ8k+TbYxzLhO2H
seGKAMKfwaaQg/v7oB+GvWNeHPD9V2RwV6AdTd9D1rxsZUNCqcqK7tOB/bwZ
carlFAKr+/dV9iVD8Gb56z55CmssYhUntAfwMbH+/n3Cn4J4/xxpqz44anSV
50ZzoHDggdzihY1Y6zBleU6LguP+pKJet37odsZfKVkyhoiM8SzNona8+C/1
NfsMB/0qbx8qjHRDe8Z56MvHCbgl8NCEaWUYlaq8+Yr0J/zJyi0yIwGWWvW/
Bgn+P29SWKzu2w7FFQYvo2gTOGxY7/nVLgrGNw+WxZN+S+Z136hQZWBiJnTD
fUc2qszUsoKnCqAwMTWvEhSceN3aXTxHkKKikbBHmovKhwYVfuhGbOx6k5d1
HCgycwzM1apgfYl3XjXJC+eHH45F+dSh8mzNgiuPyT7vClntssyGyq5Cn6ci
FILNJUUniP7pPl+wRY74/464tMFftUNwWRz2yXJmHE2Hpd/9Jv3Hf5vOrtQc
x/S6NqsAnxRs+Wfk56wyhcjlFZV71TpAE30k8VyPjelW5fQXub3Q/lfbwdaW
5ONA9T0v/WqwSC80qo3k4ReK9xYGqreAqfq38+0IGz0bQ8t51/aDL152dMtV
4m8RpfQlUR3Qqa8J9L9H8lK+U3GNTTcSeR+r1aZy8I2qTfnPvwCXpqWazQie
bC5scK742wDRHzRZeX9SX/mb4KRwPZpehEeXmLGxy/V4QZxQFiZEdbqKSP5S
XJc/dlw+HMfCeXRkybwjhrW+V+jXI3n2zmTGPDY8jv+MPkD4uzZK2vNyEAcb
hn3XmW2oQXHMo/feX1lw2rI1ccu8bjC+KivdfcICXS76c+6XMjS3Hfy8ZSHx
p+Xr4j+hEePN1ITXQTauvvklIn6sBJuOuY9wiV/NP1MnF3Z7GKoqMt15xI/d
jnsNNE43YVW4URWL6J32q38cl6owYBeX4uNM9GKNX96h2zn1cMspvsWfycYP
taQTw/IJ2ChUU3h0G5mXztC+gL8FKFs4GLmS5PED9brPR0uZ4H29Rkj8Apl/
6CmHfikalgVvczdyYcPN6VJSVEAF5m7+chQn+faHDpX6/HMftmsoLnWVZUFB
pEzs0DEmXlW0P/EY5MBLlDI3yiP8bkqbTbJnQzhQcOLo9koMH8luXdZJ+Caq
GLTNYQDj69b1O0tQuPHQXI1jUgjWNWExPeIHDyNbPvxaU4rjWtYl/59PycKz
UQZ/WyDRsrPrCeHL0fd3+H67d2M44ErYZR0O2kfeL+ujVeKoV1hDKvGDn9sz
Tu/pGQbvkl5H6eBJNBt/i8GyGry77WG2KYWFqnt7+ZmZTKw8ujfQlMwvcdGK
xs59b3CvZcy/opSNu7eMOzdLMzBz27ZBZZLkrfhVPjs1klDFZT9bo0T4McZn
69NFg95fpVVV6Wy0u/BoGn+oRL9fWMc3fTa6nUoe0QKJf1jcXBepSaE/z3uH
XVYH6L7vmKd+sLByMw9v8BwdxWFpX0I2kfsvzX3V9dkOrDHZ/kh8ig0VR4FL
FtOFeKq9+XLDeoJXGd0Pmn00CCr8ixKyLwVrvfinm0cgQYuzUXHiIDiIraFo
0oWomnPOzlpcKN5VV1hu3oTO7ezc0FsshDcJHDEj9YcX7Ax6Td6XO7k3qeBM
P1q/lt/dtWECXqXWgSGnvHCr0XfrA5Ln5p+cZrmodWKvpNrijxls6Kudrvdv
IffiXNAHiui3cYts4O6RdszrfGJq+oT4UVCC8uaLjRhaF5Ietprgz1Pb5blR
G+YXzh6tI/fYzJPuTUokL2tPKVYIiZH33Mr9mdHXiVbmqVCfZBb42j8ccttT
hp5r6aUbBIk/LHKma18rRmnrv0xDot8eCYnntBqbsIxbWnic6PF5dSWZs0fa
sKKKK3ya3Je57W8q+meLYCLzgLvrNPHrO97mAQc7sHN0oWCOJQeHFyXnaWjT
kONPH7PtIvOd55rx4HIWuOmlScr8RC8Ul0e0ZZYiKyN3IJnwPaPuY9AEpwvz
DBauPlHEwbhbz4lolx5UNhfGBN1+j3aNRYFqN5hYaubuINM3jiK+gDo+6V6Y
3/eN13nFhW66uqauMPHbwMStJv+R+2SMp12RrxCXAiMsW8l+eYrtDumdzsQX
5WMv9qwlev+qbKJ+PAWLf3w9cHQ3wbuLhJru4zrwMfeaKkeSfe80yJ1f0o+A
e/y68YQ/SXNaNmLDHVD4WK0U6EKhXNdikcyudvwIk1iuRfKwZPGBJGf5etDf
jzs8NKEwdDzClbewHpbhVUY/P7GR7ayRWSXXDC+WnWn6G6I39B8hXHJ/DB8Z
LFHOIfecu/qnfvMWyHHf/lxL8rD/knHXHwf6YW6tNHVv7SSiRExZ9Ye6EBuZ
U9RA7hmeHQ9OJvsexdErjwemiD46Vv/5cs6X5Fu5oVHJX0R/zqnf63reDdGZ
TpvzRH8Yv5ZUby7txMxF+4K3M2xMJvCkfw/Jh4+o/ZQ98Z/PblIr/55hYl2S
lNGEDQvWUcIH52W3YuXa4xt3k3w7Z3KP592CTLTuf7ZPhuhj8JeuBl31YXiq
bR10TOfgvOu1B34fO5CROmv4mPjV04loAc3ieoj0qIjphRA9GmBuEq6OhFPl
m1uJm8h7Fs1JvtdvR5RWXvkKgjd9fifjR3MpGK1lRqwh/HvIfVt4MIwJheKz
dm58E5jwj0tsW90Feem4WWklFs6GTHzNnM2DS0K5zlnyfkv6FH/04Sq0Gfq+
+VPNBv22XqCzTieCFXOFaggebHyKBW9aZ2LjzLHaklE21o/J3+fYdiNY2OGW
Pcl/bnuUjbzpmTiu+kGg9zcbqX+b4+O+dkBCV25JmS+51045P/9e0w3vL9Mx
P68T/bNMW6Hd+wyGlR02uUQfglV8PM5lNEPh2+69gZfZ2Nb7Td6/swl2xflt
TSS/qkTXpd/qaIPE/NLqCrIPo6LOpcM8TBw03tQpTuOiZmtITFYag/hwzpCL
G4X2KzQlXc9ahO9i+FyRInjRTOD/9Ksbnp9PJ/5L9l/7a+Efgx0kj+0TiFKw
I37p5LGcbVqFtSk+1+vOsbFhgWia+VAPIkorJjfUcqHvFnbw6tU+fFf5rXA6
9D3im1WPCZx+iiL35K5Eci9rFy8NZ0kzcepxzPdLc+QeMKKFnil5DqdMwW5J
og+fttfEXY1thyt//glbkqdsjquKCUwX4Lz7e9mLlynY9U3E3c3tw60ua/tD
8RSSNUUC3D41ojPxp7WsKxu3siNK2yyqQFfg/7uI9P9AytTPLWsIy7xXLOkn
+UT45NsTWhcYkDk0b/LJTzb4qsMjBQ6UwcKirN6Q+ONDrdmwd8K5aInesHSn
FakfXLDj+Ll62FUv3uyZwoE0TtLCTPphsFCl75kjB3M/t6W2qdNxVeSmB78+
B/T+oPvngtpxfUB6o20UBfUGnorpD7VI5Z4OTiD3E5MhMTf/XRUu1GSncTRI
PmnzsvX+yUC7qPwyayYHEgfKI7iKzeCEj34zecTCLotTtv0PBpD7JC78qzML
HtOGOdhCQxOtKtSZQQG81wLd2pgoE3Zte6RHYfV5zbPFmr1gWj1MSXSiEB0u
e7nTmwmbz8H2aU4syH65YHg3YhAzPySMI2I5+DGVdLZvZS1yP08tXJpFIdEz
4bX7pi4U1P68U76BDTPneepC9j24nC0g/4jcP++4t3Z59zKQEDueusKcBSOl
VMndj5tR1263torwz4vxzyb58+GYz2pTziV63qEqJzs71oslXLqajwEHHpRQ
+m2/TlyxCfq8LIyFMpH8VW4RDGTd4tlc2MjGQqcZ461+DDjnnLq7df8ECsbv
iPA/omHxez1FP0sKgk+GEj+bdmPb1Mu2S4NE77dlz/x4RPyR2d2+voDog+72
Iz1ZXTCTiTZrC+VCer3Vm/1vGhFeY5L0wYOF/wHN7RmB
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk81HkYxx1RJJUkkStlI2koGcSnpltFqcQSurWJDUlJyuTs0EqiLSpy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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk3k4lAsbxiedU1mK9k1SUU11ihJSubWhZFTKdqKTNCRbx1EqzfeFyFJa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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 126->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8VWkfv4UGrykheUMhOyFDltJXZatouRPCtSZKKkqhjAxlSdqm7Mu0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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2lcjV0bxRMlJAqRoZFKoUEqGhapVEiUCiURoaI5UkTymCKUQtIslQzN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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwdk3k41Ykexk/EqGzFY7tS2UaluJFB6ZUMkso4ppGaFlcle7RQh8d6RMZ0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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlWs81AkXx6ntptbWUpLQzUOeXfdkNfkhi5S7fCIajzvdLF2UyS1RSLJs
DJnd1hO6icolrHFpjFyaMRrDuMz1P1OskvSUxM7z4nzOm/PinN/vnO/ZGnzK
K2yJkpJSvCL+n5+RjHOXV7OxWRSQbPNAAkMibIr1lAvhtaOeBhQx5t03Ky9T
Hod9+sf0aK0xEMO3Kiaz+Rh25LX995YAPN37XVx9JnrDrY1/1CeQXdOy3+/B
IIz6VdyuTwmRXb4udj5uGNRfO2fqTSQoSWVyYlLqQdb2z5p/IoNVs4VDjrwe
zuRo6/RZGSQrnh2oft6KjsfBgTNXZWB9Tv23iNMO+Uni2sMLBDbWU1l+h/qw
yq32eupvUrhlUhe7Ktg4sUqwyYgtRhl/1i14Wx12YzF3g54c8xfIVjc/8RBi
pOquf0SIutA33zzO4iD/kqbFzxUSJKvMJB+8dBWxi4uGtC9yWN4PtRib4OPi
dERn2IwIFiXH53t7n8J4gv+3TCZDR3IkcaO7G6uLG8dqEggwTC/fC7RnI3Uu
l7bWXYrMQMac0R8D2JKEz74aUgQd6JeQnjCg8zZdr2EtgW439/H9C0OI313B
mYwSwif5b9uXL+9g4O64I/2yHMEz9wo+T7DwPHPGNX87AboWuVmf3IGbx/XI
0iwCZcJEV+NuDkKYBWY6rSKsfMzSsylhglv23U7v+1J8uhYVQTHrxBptx4DN
6wkMvGAdXhhl4PCUybffi6XgJQZWv1NuRgfNqWiOp9DXPrgwOZyJ6A8Zq9Q2
KeqzrN/as7ngMjM7hykiZK8w46TlcOASH9foESNBjIuqfNlCM9q8p81Co2Sw
dPeYj9rKBolvKVlOkcLDRLIwHc6Bb//iYOqCCDkGrj76xCvwplRC11Qq+rXm
nKvMeo60Sqlp5QQBZ+uykuJiBiaa2tbuUSNw2tHT5CyrD7rnptvCrQm4Cv1t
b5ZyMZqziXI3WQJS1GzrffNW7BS20//aJUOoeaKyvTYb7/pUne2iJIhsWvvb
vvbnyBbExqpqy+CRlhRLNnoEjQRGM8VSjvfLHrLbT7GxYW66sXdcjL0f63+u
YXLhZXvoEel7EQ5SUrqt9PpBav6sG1wrxqyZ+m1nEhf6g+EHvuhKELEfzhuu
9uIbd80hO3UCDgcp5rUhXdh2pdo+IU6KD5M3tuT9MIi8sUyP+QIhlDRN7dYf
rkDlxvSYhjQ5TDL+tfRMYh8ks97CxeNSuGiQSHnmPNSUl7ds8xEjskv0QND1
CntrthuoBIphYitekx/JQ+RrVl7I7yK8k8UUdPaMYmK8J6VqqRgWjas7nIJe
4ORXQVrkDgKhtI4oq1A2bHsyz06rSXCa9xM1PnYQkwm3lcKYQtDLbiXNeVfA
Oy7gkeEtOezq9k79mcRSzP1VI7xJipED9+ISqnpBNW1vdyqVQNAVUmJ3jAeL
/Cc5znIhGBvUjOQ/taFQFlQVChmCWy5HKJ1ngW68NcU2WgIv7zFP0lEOjNc4
Vt1xkWAueyrek/YcJZnU0dJIAibhBW1Oxj0waLAr5ZtKsZ14eN8ulIcUGk15
TlOC//XIyQbFNfCwKfZR81Dc49jH2TtOrciS3TCv9pPhST814eidLvi/dVX7
8ToB28ot4bo2D/AwMsLh4hk5hg+Nq7+7zAL5664ZjRdSHE+h7Rureorau582
J1rJsSNN3e0/+4ahbEn7deMLAfoMC38PuNcGdVN6X+lOGd5E70kM1+sDbcK8
gukgxUbG3sG2Z69wMlitWdtWBPqNJbJjKkMIzdNtStJX+Nu6fIRbGYsrBkae
autfg8cK2OKY0YKbDRT3YIU+QdZqtv7vX8GMus3vxIgI3bty9HLbB5C9y211
iYEYvkW5O/S5/UiF1Q9JNgq/7Rgh08Zs+JhlpaeXK/jxLbfS06UPTSON7x2Y
Eijx/bbva+/CrbqlnLQYAo3quWFVCn6MqYtLi4rkiClLOFwbVYiH70/EKgnl
OPnXh5M+e/hoCFrPLyYL4GjwMeaCCw8t/hvKf+EIYdX9dm7tTj5O72ZeNFHw
c2W1DVP5KQN3yYGHd0wSqNgzWJB5tB46987v2cySIVfTsuyYLwfUc2fFNYr/
oO+l0XBTsW/HtYwyrir2h1p2nb7PpwfqJ7IWi2YlUK+0J9K96PB8R6GoMmQQ
yS11/FaMoJGconrn4zjKhn/Zrunaj7rWs0dqt0oheJnxXfLin4jtPpHZUSiH
WhDT30g6hIxTk9YR+mLke75e8GXSMaC56vZ+ZRmWaL3QiW5hg5rPHBltEGOT
bXlhnH0/rJo6Pdd0SFB7LSnIO4WPtor0fudLAlBUnva1PavDyiR2VfCUDNlJ
xX/45reDb7q+VZdBQDuE5Wd4aQCq8SGJOgp+X9l5JW1JDx9njuR1pp8RgKTT
KFkceYWSL+fXLR0VIdPwZV9NwDDKaKKhS2/EcOgeGqBPKu4xiR9uVqTggdey
L81DHGgtq16nxRRDcCG2KqyrCqWrEhvnneT4B0lQ1l8=
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 127->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVWlcTWkcDsWVhopSMpVL5Ir2pNKTSkpFtEiypAkRUknNRDdlWkjLVLpJ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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lG0bxpFEZCkhpVRSKpIQUqfKFm2ikEKFFEmiFJUSZXltbaSytiF7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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHs01IkXt7IjpVKRlGT6CZWebCXqs+W9ZMUoj7JDKVnl2YotoQjJoxXl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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk2s81IkChoVNR21SubeKNs1WahIaxb5uXUi508YWIpeixNHU1NKQjbQp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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 128->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns81fcfx3XW6ScrEsWkrVAdySWKbS4vWrNIRQhJrZbdUIk43bBISHNL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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3dcTf//L0WliSIt+aqEtJHEMw2y0pYRIakIqchIQ6qPykgRkhZSae/S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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXtczFkfx4fubREVuVTSxSCX3Q0rPT6lJG1lQ1bJE4lVapsu0k1NYVBI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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGs41AkbxpElJVJtaYvEizYVmzY5rHsaUdnCChUqOUQ2OXUg5NCBvNZx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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 129->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwdlnk81Pkfx2c7WK2UHLVFm7Oii4iSXpItHZhaq3bdZyXXOsqZO6XWkYyi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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k8VGscRiUhoiJZkpAoe6nQI0uqS8mVKCEtVFooKhUia5KQJSoiEiEk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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8ldsexneGo65EKslQuobKLXSlaPAoyTZFToMUqUQkThmivRUNlFLo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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk81IsWn+rWbaOoULZMo+1qfSVJfbmpkGVK4UbSIhpZelxZmhJaLilb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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 130->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk0lWkYv6lpmYayVFeLuDfSLsuklJ/KlDUU1SiHbkyyJ2NN1tBCWaJk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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8V/8fxWWmJJWMIhpSKVQSGUehrCT6SpFRkTS0h5VdJA1RIYlSZsjM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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs01IsWxyecaJJHycWRtzh0KhMmlC9CdFNeKUMqlaZTiYrkKELIUsez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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVHk81IsWnxZLNYaSJbJUKJLQ4zHFV6U+dLVQRMmVS1e6niWkK1kaSyUh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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 131->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns81OkbHW2qVbonlxJpEHLZLqbIcal0kZBQ27KpKbeiUomUldv6qdWN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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3kgVNsfR55CFFoopEhEJSlEfYSQsiRPqCRLqWwlKUuI4knpp4WUxGsl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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlWs01AsXxqXo7jQllBJxdDmIkm7qISGUCCUcyRslEqOEKCFKJZ1kqERj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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81Ikfxh1tu25KSTHRli0hUjn68Uw6BpHJ2k7ZqEg/GR022lzl3EqS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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 132->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns8VOkbn0pqpQy1ymVdigwNpZXI5StRoiIkukgWJZQSlbSsHbIVMS7p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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VV8bxSWiDCkikpCZFKkkWkJFhlRCRUQkSaWBSjJkLiQNytyEX4PM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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81HkXx4fVVe7TFpFraJMkT9qUjy5CWjRJ0YiE0s6zdBNC1IaiYlVb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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlWs4lAkbx2n1pi2lE0LtiKLTZqUj25/yFqKG6KydVGojh9SGVA5Tb6JM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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 133->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXlYjGsbH2ScjlSnxHHsiUi7kUr5GRVRSugrDVG0nKgjKTUIhxY1yVDT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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4lF8bllRkKbuiRClCFEqJmxIV2UJEQmUpSYUkSVJpsySpVERFUsi+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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41HkbxlFCodFhaKOmqYhoy9IB+94SKZUQmXVeSZHCbiSphJUyOVc6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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs0lIsaxlV2RLsmKbdDR5G2iNKFksfU0I1VbLrI0RTOpq0tKomMUbtS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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 134->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lVsXP2mmkkSpuCQlDVRk6NRPIqI4iUzlM1NuSKYiyXcoFSEzF4dC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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c81P8fl1REkkKDUrYWFUnyVBpGw0qKSom0pFCSrCRZKcpMEhJCdtmy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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs41Ikax6lkklCb1q1cyjpHp5LIvS91kmQlJWNpbSRae5SSXLY1MkkX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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs81AsCxT1uiRKSdG+R67kJUZFW20lZtytye2mQolWhrtaukK6Q6qIw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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 135->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lekXp5oISYnS2JOtUorI0tdYb6IoS6m4DRWRRDGWDJKENKHsl6mm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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8Vf0fR4MiKySpiCIhKqN4nreUkvSQFJUURSXJqogkpKFlFaWipazM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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs4lGkfx0cJtXJKSKzRW7Yi1JZZo/rmUC+igy06IJVS2LANObSiHCYN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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs4lAkbxqWWTbVpOumg1UH6yFJtKIdbNm0OHVaTECVsFHIIU2qdoo2x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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 136->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns8lGkfxidl37LYrEgqixzKIKGo5LKdqLAoh0RshiU2lUNsalsNSpJy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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWGkgVG0bJpKoLCkUhRbySiqilKtoIRUlJZVkr1AJUSlbSIQIRSUSFVFp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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk41Gsbx0dpjqUiS9K8eDG9OmmzjyVfSdQp2bKcUKSdpE1TqtMroRKp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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81IsCxSnre3Kl5UrZSlOWNkuWyiFyS0qLUB+9JFv11KhrqWvJkq1S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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 137->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lesalVDJ6SjadZAkUsnQJVNqCVGZQqWkMmQ6IaTQ4Ny4JE22Sule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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VW0XxpFSkpAkEaFBkoSS1O0tiZKhVERFkkiSVPTKlMpQGRo0yGtM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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41AkXx71dKCvd18h1beSaWEqafBVplqKi66Ta0k2hfctWdkNNKeW+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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41AsXx1GJuO5kS125lP2qdFNafdMipeJmjWKMytw22lwVmdY30kKS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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 138->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk41fkbvdUolVJGi8pSI1mKaqiUnIqHkqmfJckWilSMGbvp4k6WDLKF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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c4le8fJqUSUkpaQopKKhTNm0hCJQ2KJEpL39JAUcnKSERDGUkI2dkj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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk41AkYx21o25JSRqsyi1RShEYK+WozJJQ0SdLuKEk2shoWZRqxriSJ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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs81IkaxienkEtJCiudyiWle61u8uTSVYQTq7SzjFtKVm2mmlNMCrG0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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 139->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns41Gkbx4VVWzmVNlJySrasJq9FKt95hYiSMURKCUm1OjhFL6HaFCHK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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3kgVW0XxVG8SVQaUEQiJWVq8FLvIimVFFFCKnMSQigNkkoDkbFIg7FQ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81XkfxWVJKg96UEllS2ouyVDqoUO2VGNLpWmkpK64KqrBkEpXJKkG
4dJGjISu0Fz7EpIlS9e93LFVWn6LJVMqjOb3/PF9ff8853ven8/5anufcDsi
LSUlFcKc/98SXb3CpL09UPfyvTi/kwar9KBx2LeXuORN6j3ToVERWBD9vPop
quYM9X7IIqEfuXJhc6AYA4vVqzQO0ZDqkKe9Enk4Gs1/LDhCQKp+QscsxBNr
i0y5bfoEwjn8A7U1ncjKJQZYIgo58WYfTW8K8G1a2tpGkQTnoPa89w6MnsXr
u+MPKIS8balp9a9EXaT9yrsbSeSZS2RGE7ogMHNZ/mCCgsMH2SiloT60sJXm
NuqNwHe38uhxoRCKLl0ZnYtp/KyW97Y8sBsVobO7i5RpCA4ZWwhnBYiovRPp
vIKElUXtJ6IrHwdHfYZM7xDwLXLP7ZjXiwLdz8/N6miMX+9PZKe2onuZB9Ht
ReH+2XJJ9tgL3No72jLDp8DhTp7QVkhAziIyQsWVgHvioWW3k19i7uCe3+UY
f5qz+p1hDU8g0TtCqi0gsX1YsTVtnxg6S0a7dKVo/NeQL1v6rQ1GS2NvODlS
uDzT02z4VzeebftxT18ZBdtNwenF75/D7W0U+94wib0r0zbuHmhATfFO7aIy
Ek1qw8sLEppwPJT1IlCTwvn1Szcfb5RA6uNnO0pjBFYGJv3TAy+we87aRbvc
KSxEWW3mcAMqQ7XZMikklOXFi9jGaTC4G/yo4AQB84dLdeMtW5GkHG68xpDR
v5CYrnyiD3JjxcHjBQxf2aQdQ4udIMM15BzTI1CjdcMk70o1zFV3+RNHSbCu
JY8H6vZgqixH1SqMhnvokJ3mUwl47Nyn7dojqLe2LHzPfY7it6vj84woGJJG
sldyupA7PRM1EEbB45qiwabj2RDNHbe7kkKgafHtoMvWD9DW7zybmkkg1G2C
fdlYDC3258Ulx2h0niwQ/mYqgqguU0lHgcbOtfHcBdHt8HGOY60KofApzVH3
lJ0Qp1lmC/e50+goW3fR3aIQ3Qqmp5oaGN5+LYpyfCG+bOHXterSuD4ZdCHt
1xK4ppqv0Z9DYsTX0keqoRvx1Z3l2ckUlNdlT1VffgnvLS3lh9RofDJa8cxu
twAWCiuXdGmTqLkSIzP3fTEm/L+2vJwgIIlou/hoxwDy1//t5evH7NOTyNVy
fXXIsfvlhCiGRKTikDV7lxgGEds/X52iMC/qD+5QaTMCPI5lpqtQcAnDiivp
OVhW99Vs/w0CejszeSnqneg5VdZ62J7C3RUSs1mZZ/iupOzmM4fJzz523/Q/
ZYgemnzgwPjXizXsejdVj2j+4beq0yTu82IGqzeWgnNT5Yy8CcM/pniTP7cA
MxmsErKQgFGFZc+qFAkcknQ0OxVGcDJikFB2b4Pmvcj1zToUwv0f7zuj0Y+y
i5ow4o5AypOTIkOVQpXQSOCySJycNxUfqiWB0Plqc9wMjZOn87dujerBTqVP
5jJ8GstvvU6JyRLBLT3o+7JaJs+wKZ1kpw7st0k0qU+lYMXa0F7ZGwve9gnv
V1YE+AFPYtI0ipE3RpaZtxDoCk9IqpKuwSMO/jxtQyJ7sKTNUr4cxRmEWtg8
EqdVx328TERQfVUuE5lPwcf2p62pv9Zh8nfv63sukYh/1OR63vIxbgbNidV+
wfSTvNU6Wi8DZ/aaqy28QECrmh0nyK1BvUphm7cviQq3ql0JkyJsKdlU3niU
hvoX+XaxvBCvN2ctSX5NQVg9tsP0Szf8VbaOrXGhwZuf/lk6tRZvoq34A9kk
uPW3bj6s6ENu9/wCtR9GwCGjOH7vOqDH1SqMNWbyPFWZFVbYDheNvOTubRQ+
bHPOuNFTDjJP5X8eDiQkTTKnA1gdGNAKCZl2omADLer9pBiiwYENJQE07pkO
//KsohP29+7xg20pGJ88fN10tAmF339oPiwmcSt1kcNXWyF6Rn9b42pFI/Ls
PwE223qQp/aVvP2GQgc7r6FfoQN33QyE0sUUhhsfuJjYdmC7esSFnSkMH7n8
V0EJ2Zi1ODVgcZWAQmuepmdLBw5kGFDxrhRuB4UfWyLIxPaHxwRVEQRyHz/5
VLO5F7w04Z1V52ho/XSbc7iuDQbpjqufnGP6ibRraJ7xwZ6Qc232awg0ynvc
ueQtxkqeU/66UBpbxgSuC7okWLLC1SVCdQR7Zay6nOIaQVuuLo9i+LllxkV/
9H4J6arzbZbvGH9c/YLawFyY3zzL+pJL4N01R9Uvon78aXgkqc92BH45b/QT
5URYG+x4/eMgBb602+QqViLsvZ5npXgQiNHoMfP8Ixcb1B5zWEy/+Co2N+Sr
i5l/gXd+sJDpA9mpUuuWOvznnWiRcyyJcdmi8p+rK3HcU7e03ZOEsS0vxW+t
GA+b4/ZXzlDIcHwxaqrUi8Ao1xD1R8z8L4gS2Lm0YFfw33YBH0iEq4rtpr5L
cL/yw61xG+Z9dQc0iiL6wPPXSMqvpvEvZKLIiw==
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81Pkfxymp9dNvh8FSEbp0bofNkbwkTTpsVqXDlqP0azT5YUmOpE0l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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 140->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8VW0XJcpQong1qSgUyRAKYUmTUgoZS4TCRUqmovJ1kUqlUihDhqSX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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2kgVG0fxhGlFCqFFksqkkQlqR4XkYfsW6WEsj4hypalUiEkKVJpJckS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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlGk8lAsUxpmUJG6L/ddiCSWFblxx86iIEimFFluLErJGJSIu0mJJRmVX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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs81IkaxsclqSi5dVmXqY2IDRESHtKRLGt2OpUioRTl6CJyiZDSKqeU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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 141->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lWkbxkhllOxSJGSLNNQJg6tspUwInwhpUUayREWEb8Rna1FGx6SN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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk8VP0fxRFRSilUKtlSUUhISaeiXSkkovJoURElRZJUaKGUbNlTSZJ9
qxBj38IwDIYSZu696FER9aR+399f85rXvO7cO99zPp/zPqPk4Gp+QkRISOiI
sJDQ/1+bDq8RVRV5jd2PwqP1FtFICvk4+8xEBQLeHDxxO57CqezVkq/OchCt
z83s+iXA/JBBDYnKQug3tulMjaawTyFonap3I4a+/6JV1BkoGk9ZofOhGZXC
V6JtjtJwUUnxXSDTiciltZL75IbQGaaxtqmrDInGu3bPVaPh8636sf9+DvjF
wdq/bw1CVX+/evvPSmS6brq0IpbGaF2L1iZuPcydmgsWFAsQvlZ2i0IMB3u3
J3sfuUPDRH8i6Pr3ZjCjaTrni2gcmjNaVxXShtieOtM6uwGIpnIien9245bN
xJW42YMoKH5gHfCjEA+GE7LPfaHw6W9RrU5hJB7d0MkcU6Rhv4dnZm37AJ97
TvRtJO8/RSZwuEadcF9Yzai4UKg/ukhXvKEaHz5yYl5tpJE/M1vzKFMDufkG
GVH1NHxVTu8Ns32P9ddnOhrfJd+nnjSnubMe84wWlZgZUwifGLlb+rgUz0I3
BJ8IpDHzovgs++x6LDJxsUvMFiDfqWXOPc12eP44p3CmlcFntsyIhEMP2mq/
t48W06CW7MqTe1CJBN7b6Dt/aOR8j/gbb8yGeKCn/DVjPjZd3pC3vdcfnX+5
KxvI82u//0fDqqkKEiybjMk2Gsc1ShO8enmoHxydI3FRAN2dcjyh2B6s9o7b
/jBiECFqA+u/lTch7kuWh54YjdYZNWaPpZqRMVoQpBfOIC4/zfyYaSdW5g1E
a/sJ4Jw51SchtBWr+qveC64PYvamBSkGr7lIa9qasuVPH+ytbP/eDQ+Hb0bd
tg1raCSXJfYf6X4Hn1EdLe0wCtFh0ia9rDJI7P830TOIgvY7n5NyH5/DQSZE
6/tSGqeav72UvZmHRGk1qZpRCgcjVbT5MzsxozDLP9JvAOVnJtX3jVfBvtl6
OhNNfm9BZJVNRDxuBxz6lSJFQ+b3wZ6fM8oQdazir6Md0Zst8UmtOAQy2Vw9
72XEX4EKlz1vVkLOwVxVvoGG+knPZLewLtwv5ojnGtNgVO/fue/QAe9SZ/+B
VwxaZYoFnT/aoVvBWEZ38NH3zsSs3KALIq9Uy/cFMUicxeIOW3LgMi1BMnEl
gwCRiUnRJV3gyt5mqT5jIPQqJFVX0wkLhW/nBynR0FXoq74nUgGrpDH3Y4M0
CnXXT9F/E4vU3MPjIkQ/oYY//5VWO8BgXSp/ijKNrJLdPZcOVKDpYsnOpx9p
SIu8zN17rBYyHywk7P0oDB3c/FjjcBlYbYGswgpyvd+ZwTwfJ1SPO9pqkuup
vARpQWwN4o1j3Z91Ucgoez1DXagEK08ZOJn2U/BdFx2fzcvFC0GcLfbSqD66
5YLFQDvCxY4ML73Ah8Ltnkc9x1rh1Wzo8fQw0Sdj4QVefglGO7blCv2kMCJf
LzStoQy+IbVS77gCcDNvqBxJK8PJq1lKnGQKncNDbMvoCuyIssvavYCG4q2x
JbrdbFjJxYr7NdPQP3c9uHmyGz8NPsbsSxGgcIXFqabUZuRMEeNHPmXgHnYx
VNkrFUHXajRE59JwqykLCa5oQb+2R5GXLA325be+N5OrcDKF32STS8Hr3h9O
kUk3Lvce1rf/S57He8W66o43WLkTceIpNCbePd87ls5FfGKsu28/H6OX7Wz+
U2KDvfGd/sg5Gp6v+nvf7KqAX+WjfwNeEH/Wl13e+LkeLonvD3/VYJAgsdgi
TqIV0o3KcjKaNI6oLKAMeIWYMdq0j29Doz92Bbu3sxRR2dMHvR/T0GteJqao
z4XoqriGAxMC+CYKeJskKnBbWUks/QmN8LMJ1RWvW9FXO+5XfYJBwZFTwVK9
jbi5u+gspchA94+puPmbBvTpDb9YcInBKQ9Vq1VOb3B/0cZ7h/TJvlK8uT/m
XCwe/na+aEH0XjbTnxdxgYfPAtHtIx4UGj+cvhR5vgv+Fdvf9X1iMJR9a1j+
YwGsVRSj2D8oKFZuORKzoQM/yh+pez8dxCzpQ1fWBbbhSf1HES7xg233vDyX
Cg6iTilsVzg/COvEi4qvjc7BVCJToYb4mav0Q6O05QUCI+tOZc2kMd3F/US8
bRvmec+vna5PwSTgv2CkNEF9Yq37GopCXIBDmrgQFxtef/ro+oGPLL3A2cdi
WxE0WF6SlMYgdbhst0lrFSiVJY9HyDydlP9lcPRyC5wFtJUILYDE/Aj/0ocl
aJg66nEtgsZF2S/DHsYc1Bb35rqfpZCj0zD9/T8cbHmkLp1C0XgQZV2yT6oH
CmGa2a7bBBh6575yrVEr7DTfp13dQsPZuHDrD6lqlHmxjlWsYeDsuHnooko+
1GVdFpZOUHgfJXRSz7kDr50vSNOdAlQLF9Q41GciAF/DLIxo3I9Xnr1gYT3k
AhoDYj5SmCiRWDmyJAc73HSl2XtoNKUob1J2K4a+OfSb+igU2nu8uGrThKjj
bd2cN2QernhUSu9tR/4GWc3l6QJsDTa5Nj2yFUMPFHMjtjBweTZNXPNJFSKZ
wG+u5Hns6G0NBn4F+JJutG0RmccNq3VGbSbqEVtuaNjeROG4q/T07KE2RMwW
iulLJX4pUZisM4iE3BzOwm7ijyBz9wDxRg40a0sbri8bgPUB14InmR3wkzc0
tnsnQErQ4bG/sWw0HS07MC2bQqnfAffT9SycXZTF2eZII2b1lFVG/2ShU1Ch
0KZHY9Pwyv8iBi5j6tKY5oXED/3y1TVWmY043Wqz942aANvqj3o0RLTAPLyg
62YEA5mAcVObKWxosqpEtGUYlIztG15r2wgdRd6q4jEadp9GvhibdCFe8oLn
zr2DKJUKjeIt6sQmp2+Clc8ZmM5ett/OuxVaCpN2iSw+eHNFN1+RbMRI6tOj
1xgK17rWeU4PYEM+8Mz1rBAaqt9Ps03MShBel6r6wpHChx+PzZuPd8FhUZ98
0pIBaCec2XlnaQVkm8OE9c7QKKj2eK4qVIdNexqy9b9TEPIfE9/A8oM883Gw
X4GG92BmN/pZkGq9sDjJgEaU2ls/VkYTrBLX/9YjfkzgXdqhKMFGZR/7ksFP
Adx7pg3n32vBbGV2l4oVg1rOs555ZVyEaCoWd2+mEXex93cKpwXfa2p0PnQJ
kPFL/PG5ggw4z9KTiif6+t4yaZ3lloMve2ZJmqqTfNK01Dj9qR1+uUqG1oY0
tj+OObFsRgPiLCVvmdVR2KAT3Pf3BAdh+ee0V64UYOLAjbDeNyx4bV/dPEL4
SmbV0xP9KdWYc2gXv+YQjaOo4JXLd2AGa53tb6kh+K6q3jDfjof1Hq8ktxcN
IuPJgWgNaQ5Gb13jGroIUPstRKlcvByx3t+2zEgifp6XJ6qq1YA3Xx4uU9/K
YNrUNzFXXXn4Pj11TtEIha4y7piiZQfckhh7Kz6F2xajYtEFXbCe26vFX8KH
8zNmxuJxNt5Hi807u2gQZ2WafT5yyiCp/ZEVSfws9Ut5+dASLjSanrmVCzG4
+uibfoxONbir/iZlVJO8czEI8l6Ug8T4NZpp2iTvVtxL3/GdjVem77IqVjGw
39+uFVzbgROuhypUzfmQT9NlHvKaELijQUTxAcnjsgu9Ay9YOL3gfPm2GAo/
OGM8WpgN5aY5y9fJ8LHP6KX915yXYL6VBrSR/Xbu04iJ9dsnOGS9nCUBGnUV
dm39+a048+d4/EzCLwlzLMZN+PmodArNKflMwVpOrz5UPhRX3q9J/P/nvg0q
r3jPQ7F2zQrl2OU0Aj5+/WPWySM6CJ+tFeuHvSYtopdbAAMJWbd/UykYbFyV
a094bMcX7yLrsQHY3YsynV9UDlvVxPtrptGwfi5ebJ1QBMMKqatUBoUCpnL7
I5lilERN2u4zIfN5eKGwYcEHKHD+NEQ9onDpqHVbx/42/P6983SQNx+L9rzJ
3pLzAVGu6BsnfCZhnqQ5X7gM5d5Xrg2SffFpd6bmBadE3Ao/u+IY4XeZv782
hK+vx/glkRBHPQYZ7CvLo3yD4CfYnBtHfo927dLZf84VIOhUVt4Xko9Wyys5
+/ye4djhnls55Hn/xEVvfG/RiTPVNryoSAG8E6x0eAIupISce0JcSd4m2j1b
4cfFxh6jeavcSF6JvmAOkHksy/nOiiO8zDh9/CF7sRl5paMCC38GR0pT7v98
3AEtseMzrE350E63Kjr94jm2RJVOddWgoeT7bl6nawtErI9Mv9UggMjK9J4X
1zl4Gm5T0GLGB+tf8eeOddVokv7U80yE5IFbq1nckXw46G74liRNeMhGeq0k
yV8N61y3mDmE55RKP62T7MZr3/bLHpMMkvdTWlE6hdBbfHLFyt3Ej8lLH/T7
eOF3+MTbq6o03B8+VGzdXIvMhPOFUYTPmg4eOKYYloqAvmh3LXI+b6te+/st
KYPeu2SLTMIvBetUMzcHVGF9q4XwSaK/4p7Fyxu96jD1yzerEqKHHE9lgT9d
DQmlK693jVPQNXef1DLvhovyaxTGf0Zbr095gTwHOUV7ZC0J74T+rPkRF0/6
QuxGuUARBvLKSUHzfNqxZnf/hQnwSf8LZhUnvkXKJMeBt5jot0eo+sK5Imzc
6pWQtZL43V/Zaby0GfYKLv5bH1J4nW9UqLG6C4PdWvGyPApbgoeCJ80IPwfr
ZpheEsDhZG577MYKHB1bOG39TuIfT/swW4Ri+QeHV0XkPEJfnC3ZT/a379Ov
j0Kukrw9qN352aoJ0l8FaoUkD29nHm7k5eVBKFFPyUOI+HeiQOgX6Xfqxelj
jiTP+fWv/GSE2sGf6C5zE2Pg23I5/XlgGSzoE87Pyf2G2iO0/G7UY8jrC5VM
+pPs5Qcjl6Vb0aEodFxp+SCabM2enLobBvfZmUzyChp+mf7l+oZcBB+v3aVl
TfRyCDZpiGnE53XCv/9l00hLbUzM/NkJJ8v4BzNbKMw/9bRyr1oCpOw5e/cT
Xs/TD9w92tEKbs5bt7hhBje0dxiLzmEjuspX7aQMjR+vVyms6WzBnNpTq2Ym
C6Dq+J7dEdSKghrP8abThG8/hZ6c1lEFkaIqvyyyny8pMtfMJVrw52GA43Mt
Cp7ZwaK/lpcgUsewyZLw87lC/VtzlZux3cBfYyc5T2u/uy6usm2IPC1Dz9xI
5nfOtbnuYaUI/+fAP0tJX3XNP3sJN1rwQdAmyyHz9uBdZrq3EA8K+2Mlpi7i
Y/b7b14HO+qQ4tJuwY8TYHTRZi3ZfSyk/TmjYthH8nzr7eOHq6rheyNlj9Au
Ck/ULOc7/mJDKCqeIzFO9LUvndl5uw0Nm8Jt05fykeBwSlZpAeG99NXP9EOJ
Hm0XXEvmJYNzsJy1RYtG/ZLzd6y2NmN55ucWORXSz4u2b1883ATV6U1r1XJo
qATo68nnd+PCjl27nMj8CX1+zFe2vAZz4crV3uS8jz9rCApyycBd/a4dRcT/
myL8itPNIqHlnuovTubjvBn63Gb24ILom+0zchksHZIy1j3MRqixdpz/FgFO
ifPP8rd9QO9g/J1qwjNfpootiRXuhld+b3qzPI2lYaa9j1TqMO3seuv7QUS/
WRPtHUOtiKvF4hNdDNKNRDz0MlpRkmE4sdyRnOdjl7X3q1nw6VD/Y0b2p4kv
VVByqAO++1NrdNfRmKX2mrdevQBHDee9TbtJ8iEz528ej4u+Ja8dzY4THkgK
39Z6nPQFSZvVteR+I2fM7QKWFKMnd8rhq2MUvmSd8ZmgKzAoLFw4soD4fWzs
9NjPCMy/0pISRvax6vWQI6+K2YgUPXPJ6fYA3O2vvpi3ux22I+LXm0eJfgVU
k2VYM2b6fzrhvp/weuiGKp5rM0yL3HjsSBpeZZe3/XrCQrKjQpoN4Ru+UYXy
8LI6JLgKe14n/ORyTG5De2YXdlXE7bpI9Pf87Lah+30tqjv+OC9dI4B27tcV
E4HVaLDtW3FegfDS1jmbaz6UIdKpCCU0hdEC3r2JqhbcLOXfG8hgsPFhi9LL
mRyM+Ip5RgYycItTjR8Oa4Hn09OWb2wZ3L4lZTMrPhd77ReGWk9SCLexnV6/
uxHuH9Q6Mo4wsHyU9ERfJweRn/fs/76DhuV6v+6z1ypwjyNZ8g/JW58tz3a2
u7chp/Oybp8T2edrl4vVD9ci4ESv6wwFBpNnV4y7q7bBzHKL6bI7pO/91y/c
S/bdg6sm/0qupxE5bfTKtNQIbPOs3ZdA/HaKcq+z//kG9uyneQfJ/E+qRD/P
Ga6Cj5Ld2u4pxN8nX4g7WRdDRKA64znxr/1Cn3vHp75F8e3vN3sIT/DVehcM
TZL+PF9xazi5v17M5H/MvlaMdJfHVP3//5WN/6mpybXDpsh1jVcdH8V1wl+Z
l+1IV88rkxVnILJrE0vqail2KAgt2UH8aZ/0auhZXjKEp4V5SZqT+YjedJcb
0AoJ7z+O1jWDiPolNFDm247x6Iz4udEUSpaWWgwWv0NwrLr9S8KnM3zs1siT
fnTQSI7r/Jdc/+t6tEL8RcKpal0+ZH78/HIaDTw78PupE3dTJIPyIf/zHvQz
rGPFLWWJ0TA4HGoqrV6Jxw+v765SZ7BEWGRKS0Ab+tdGpLiQflPQdDPi/oxa
sKu5bbP1BdiUqE2b6DxBX/BizRrSF5KU57H/FreA9fVxSynh51khYgvKzLrB
8ltnUZVHeFjBzfkIKw9GfXuGR9xoXN7cYmar+RZ75zr2T5J88Mip/DV5sgnH
lduOthI+V+REq8oHpeKh1qPbgaR/p488apu6txt22+48p+8z4B5tXntyvAir
TTnHp/dTONfv7XQ+oxgx1UZxkctoXFF1Ns7U+Yihpx2Zkg8Y3M9bozUztwvs
OMM20Yukj+dNj5WN44Da2Cpi9HAAWdsMLf+5W4Xb6/KOrHemoeY0HO3JSoFf
esaqibVkP/kPrI8XysDCV0PGYn8pcNWTUxPTq6Gd2tERSvyc6fwwW0+J8E2c
3ssPXD5+Y3xxyjQuJvYkp/2wGkCapIOHxpNW5A5riuI3g23Ccyx9qRpkzOu3
rlUh+v16snThqkp4RnjVFXyhIf9ZNE3tezPCXXaLtbxg8D/NhxsQ
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs01IkXnzJJ/fZMkxKV7MqqySMSIfGZltqSrcRqtjY9yOq3ESo5v4gi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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs01Ikbh91CGSmFlHRRq1gbSWkrn4TK1pYsRq65VJKyWxFzUsgtyboW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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 142->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx1EZTTFZEqGfpckyZbsI3fGRVEKilGViuC1MJQ1XpZSdapQl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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2cglW8bF8pMRqQlCqUhFYrKTyoJofKXQqFBUpTdlIRUUkZSCRUqshUq
e2/nOEbKdp7nUHYJ5b3fT8+n576v+7p+65KzdTp0mpuLi+v4HC6u/3+rcei/
rM4qlBvePBn1mI3NpYIit64xsITa0dDeQYPb3KNzojcGTztMvN0UaeRHvjSP
NaxC2rf9nYHfOahV8+/T/F6EF0kZ288fpZFTKPntXVANePq2rj6vRcG76AJ8
HVrxTzRiwztVDgZ9z9+2D2YgJEE/oi2zD1ztRf02zJ14e7dcmGslDclgGQ/7
iUa4PEn8uYXNgfbFG6Knq+Mh1Z/E7iD3G/laud5RbYc76/dPpeBBRDNGhK8v
zATDI3dd02IanSmMafuXeTAKTRloP0FD9PBOv21zWtGUcXiiK6QfvX2dkdNP
m+H7Qo4V5zuA/453b9KQbEVOqZN/2wgNmWevnlDdmVB94FKn40hD+MtcrudR
lXAY5Q7oKqcRoOfVpxWcClWdeUnDG2hEmfuHm0hVIjb6eYmUIgVBu8fij4RK
sCfS9eAuFRpc3+akGInmY/XW6WMxiyhsYxkKX5XswFS34ejsTwr2+67tNLKo
gIw3p+IhFwc22xMqr3/8CkZaoZMWOX+HxYmLHquqoJQl4BPyiYKJy7DczszX
YMY7/7zPRUO7ZPsWi/AEaIZb8nlupnGiR86x164Np2qfesULD2C0RL9lfRIL
qq4jZb2RHJjOmqYVWzCgraetv3SSgs7m9I6CmwysGF3WH+FJI4WpcNRZ5RNa
L4l97NegEdfsa2Qt1QGz62bfEl70w9P45Pqxh+loEdI++3SEQrvKumQuSwba
LCNWZKtx0CUrHXrBOwNbij7v4tMieDjHvSiCzcIxjdiQ/zo4SPl29KSQxBNY
cCmJMcVp2Adv+nNMpBqyvlsyM/ey8e37/lHlOiaWBOYp255kw8RM87qJQww+
+vKWGW2iofigN0upJwMqPgMmq2gKD41i2eZSJTCNutlfHkLhVfjPotnuLGwe
TBRcv4+G9+IyuCZnoe71OLeiCI2ECNcUOf4yHNwZYF6jS96fFmUSrdaA6qet
Bnvk2VgrVe8a+rAI0nInehRlaKydDvvZc7YVgjmrFL6c4iAjTNbc+jQLfNuy
F3znGYDl1JmRBQ7lUFeRcwu04oCrsHdc3u8QnnU+3PNRjkbeq31q53izMeoa
C3E+Uk9x2Z6hlnRsrY7WuDRAQfpQl9nyxrfQ89aIn6dGQ3NPrkTVlwbEmeUb
OzVyMO+g5V2N619hnee0ZRkPB40+pxsdxRjQ9R6fsmPQcPj2S4XObYG7lVHY
EREKx3+9uxb6oAXcv4ePTmVSEN0d8Oy/mXv4PiQ2NUL45evnwXCuq8WDny1X
wuQ4+PrvQafQrUaUHKjIzL1BY3BxQ/WWNywsqaRX1aoNQFjoeVHg/CacnOdQ
JbKFxrzWApMOmRYc/6L/tugChfpy36H1N9owpuItOSo5ANcfu6pXerfg2cp8
15RCDtwDmsRM7zKQFpH5T6SIhumMldzdTy2IU+z137+WxmTet1tnlT6Da76m
QNIo0Qs77/kS6u8x2pc/bixM+jWqZrVjbhS6Iw953yTzj2I2BplvzoK02Wzz
/UgawR8XP7miW4/bPxQGnzbSkH6a96k1KAXPHjcYBh6nYa7n9pz2rcYe3506
PyQ4WPLb08tQvRbXhRpd+G4SPByYx9D1rYdryXDyRm8Ohi2mdMyVWhG5hCqI
IfiPOFTO7ZDdiB91h3fozLIhW8pTEC/8FFntexriFtEosH59xkqigeCrl9UT
TkE4YoVE7vwCBHtleGm1Uqg+FiK+w6kMr4JKJRWuUVDZKLRg8UATIufaLnhL
5sGMMbV5tqAC9fe+WWpdZiNA5PHQvrCvWGix5677th4o3/bf3RTfgNeh5lxx
vEQfxjemCqR9xVBb3ePe1f0wFb/80ke9Gv5Vjllt+2mUp6VF2PEwIcVyf/+u
iQ1RxXszYXgGRWF9Mav1hG9Gu/lMn6aD9abv9ysQfVLP/pcl4wNKMzxsswLR
k4Oxs3o3QyHPuKfhuorGRxXhe44y7VC7anCRtZ8DZXbiZHNgNm4N+RRctaVR
/drssadaHV7w+9JzJNmIvhqilBRcjfe/NmSFvKEQndRQ632pALzGGS3UeRoG
Ux7QfVyKYb3/eh7kEzy2b1zYM12JHkdp5/IgMr/Ncwty/ashE3uwqYTg7UT2
w8LXH0pxmt/d5LkwBxvg46zrX4mkS1my0nwU9ntaqTNWvMLk3rTzV5bS8OyR
u36HToPO+X7B/+tv+PbVx+Vq6tGxk/nebZr0J4ij4q4Qh69zgg9UEr6prP1P
1Mo3BkkGlSV9mjSG48Y8uqQbsYs9Lefkx4ZuywXeu6cqcH1H2/03UjR4o08m
tnjlwFgzfKywhsKhY1M7/zkwcdlwjsZ8wn9Z7xuJGnOiIN+lJ9ssQPjCZX7X
MbUdOaLLF3QSfnQ+ujDwkicSKhF/rSSW03C8s+8e/a8CKdcjxKWusEHFvx9z
2VuDKYO08AZnCgs3/tUI7mEi4xF3/4qLA5B/Y5KQ8oEBnsSK17kH2VBeGShj
uL8dRwTePMu8Qc6PNGmOj6mAfE94y+xcDtIH5dqNVzXAfFpW7RiZ1/ofB15d
jCbnKdvMapB5JGwIrhCSykPXkjkZ8/iJ3+oae75enoTh41U9LUSfvSfub7MM
rILK7nXqmUfZaDmoOmeVSx1kj8qqhZhTUNob6lTwgQnp6czDu5JpUL33qw42
RWNYund0gsyjcWAgbCa/DqPLRwaTYyh8k+T9nD7RjJ8bDpzrsqTgaL5D1NQ9
A/atDn//Er9zXpWt9dw4A11Zf+abLaExunTXaJvBVyxdPtng2U8hatuc4D1x
lRiUe+tzk/h9sP1I9w3Cj/HaopUZ7mR+qwsUziQ24kpxnVLGEg74V6i/mggq
gYVJkah6AI3oDbXLVYKLoDj4q70nnsZlOQPOUsUY1KktHJcWoqGrE7igq7AB
L9pyylK3UnCfV/w3eZgFB/Fxh54OCrI5hbIsYQYGX9j9GnTkIJ/7j8sgXYxX
E65Jwy5sBIYdTxRxY2DKeLWywQKSH0If7bLc1YCtCy1GdNzZSPJpvlp5oRRP
l6/cphtO8D5i2+Vn3gjZngK7IxQF5wPX7CK73yEp7WZ7H/HXLVvvRNf9a8cL
A8bJsgYaa04s01zjWI1nfh/+Ugsp9E8bFWTqlaPv/uymrXEU+mwPNdzLLccx
nq9dzwm/Pmm1P6kKq0VdSVG5ihgN1Wtc6x3ra5CeFCBVZ0HjWV7gg7FWBsR/
CbvVkPtU0/h/D1i2YPTnuYsnHNg4mXOm8MueWpgILo6zkaaQsDC8d7SsDIuN
Ii6st6chfyLut29nG27w5S5TO0j8cPvxdZ3CWYgy5Gy5JUHyl5zk7g2FaTj1
Xf9wuR2N4jXXQpMuF2HymXtUCNGj2Bkuzeyo72iOyLmwvHEA9emso/3uYbhp
ntSd/X/9L7djdfDG4YvNYIgP0dvT8WNaT3uyMeekzCUlaRqCzzeFtTgxIKpW
suOOKxvB2kdeGp3+CNEHLyofEzz9PJztOff7Jwx2lRgm/Cb4GTn1gWtuFQb7
A256q1EY3mSmMhbdBLFw5j/XLzRWynpOyC1oxQon7uDPPzlwHn+44mNcMYpC
FFrSA4m+6Lm47cxNxX3Pxa3i5H0pCpnW8YuaMJWjO7LyMAfWH57mWp9uRlpI
82LlDwNQlOisuFfNQudBY5eNpjTqj+rouc+/i9UWDXl/SL4Y7rBpy1JgoC62
/7bjPA4itrc1TApkQKDY6vwk0SN7fXhob2UgSlZHePoR8aPkP8eUzOpxKFxI
35NNER4XpBXlliI+tieCO56CZcMeN92MBijbePx5eorC5Lk2zc0n8yGS723V
RfyIt3ihsmwaA7cF8kvTYvvhzcpO46whegxeOYspCi4TfXcsyfuOrQy35f9L
gcNZ8065vx7vm7t/6xC/jT4tC+XMVvAHZYa2kno+tV71acophOjVbTZJJF8N
fnjuWr+lDEF+t55sKCb5w+7ygpCgW+heqfryI/EXeaXAF4vfVqFbaBlVWNAP
UcFv3jP383GGO/iujx/pZ9qvmL+ED9xD9UkGlziQEtPUTNzegniFubeG5hI/
opJr1loVIzqEL2HOMIXyz511XEaNiMmRvMu0YuNLvu+im9ZMXLU0Fl3QTfyv
cPO+aJXvSJ57XOKr8gDU5p35vqizFPceqhbU9lCwTX/OGNJmwS2sI0/1EvEH
fypqeXAV/rxce4WHh0bTw6mKc/5NiNY7VruGRfqfRuXLLGJCs/Fjh70GyQMy
Rzw8ulpROTn4ZJlrPxIyrW5eFs/CxR7TH4bKpF6zdMt1c2uQtYQ555wNG8NX
WTeehFVDXVUkx+4gyTuzfeeeL3+LFxGTmcenKZgKlSjacXIwdH2kZlkKhceu
7/q/ljLhPKWQ6kn2E3MfhfGTcoVol6cCOYkUtMWVq78d+Qyma80wD9kP7JU0
FN34v8JUoE9zLLwbJuW7C2fLyxAlMpta6E34FDQbw9G8D6n8bJMvRJ+Nx8cX
fBiohuFXp1xtoscfjpv8unqgCZmsSL7cLFLf1kVWQvKF0OF9J/mJzGcPr5Tg
LccKRPiVzgx+pvFWVK831bsAWnx/72foUQgJMDjq9roZZn/Xtd2SJH4St3Zp
+nomIocOD0qQ/Mz0MMy3mmzGi1pXplvTAAZflfOeCcjAI8rgzsxXCj8rxN96
fc5DhuLt/ohTJJ80SF15a1CMQxALHQom+Nsuo89jnoAIl9UlGQSfItvuql8Q
rkbK+WsHJ2Vp3DmQ531OsADtLWPXSt9SqNK6G+at1IT43lMrM1ZQyJt/zlVJ
sxSdwmJ6Bwje7Wtc6941F8I9Z77uGpLHluT9WX5PpwEJNM8STQ82dti8Vnfw
KMPufYue1HBzEMAZW2faxoLna2vVLnJeaVmH3ryodowmXrjj38zBiXHn4qfD
DYjeN/nqfCcb6/6zczu1rx78pnfPZflSkGr+e03EvAmVLlavs7b3Y82m/PTJ
N3kwtPb3VvCnEFkJhfWrUiH5+/51WZI3OOzl7wRnypDDQ3+rJXnWV+n8mVuB
LfDaIJO4huzr3nptIysSb8JvRZKQJHm/rSPjIJ9LPdIejpq8us3GwvkpDpdH
CkE596wWJ3oT8fzKji1TSTDIWK34gujvkn0jZ/v4GzBzSXQni/Rrcuyo1hLT
TDzw40nob6bAFTyu7eh6Dh2ma5S0SR5UjRyO7DpbjzvmE+2NYv3YW7W1xMKH
iUM9zqmSZSTfThp7fxCvwYtrv0aWThB8xptOpM0G4cJ/giLq5H9m0+4XMhOV
WOMo9vOeDY2rMjUmD7cwoYutjbtDB8D1y23xyi5LlMH2EUX2pwu7AlJ3ddZA
R8hv1qmJ1FOsfXSvdR1EJlMjT2txcMB6IDJ8sASM9VK3dxC+vfXY0HHa+CtY
Nn5fGZcHYGtVm7GuqxmHLG782fSE5KOl6swjtcXg7ijtHe2jQFkyqnQESzF6
iT9yriTJW+OZjNHkAghE8lfMbiP+XBl02JduArKEQn8eYOPq5xr1ot5yuK+X
PlJF8pTs4ZPdM7yZUJmS67P8R0Gv3lxwU3kSPETaXnUcoLG5MtGrJZcJ+4Rg
PWOiX5TkKd6l/imIfZ7OKZCn8Ur35dUTm5hoH/rgIpBM8kXI7TP52y/Bx6+8
gZfg0bK17u7ukRIIeen5KV+l0eIjtMsmKQ/DCfeaKzJoBI0vXrJmTyskXOL0
A0ne7jrye/nuvXVYvOvEOm0G2S9nUk9r9X7HSYPSOpUrhP9xq3mOvizFn/vD
ORIGFIJPD62YXf8WXzLKVguTPGxUe4brU08NYq1WrM4i+4j1HPHKuWq52Gph
J6TmQ/in3HK3lY+JEpHBRdl1FKwV1jb19TyA85vL6U1kXusGN5aFM2oR4bbX
4hHxg3FuhwCPoibkxazSdFrGgfxNm5nv18rRseplnbEMBY2lwsfifAuQQwtP
Pz1DQ7zVJXErzcCv5OTGNFWyT03XSmmwa6D2sEZx9XuiP6lrO3TLWjFY0B3H
q8iBpkxoWfxsC96v4uN2/NYPYYVNez+KZKJ/Re2P9ZuJ3/7VsJM7wkKXmNGl
gEtsRMhNl12dqkS/cXWGLdm/t+lPeQn8LsL7n9cNjBYSv1klqvk3mQGjsy90
dXYQPPLvK8/28sbmG/rW9Yo09P2v3Kppa8AnG4dh+RMcBN9J23govR4LH9ek
jmlQWLmx6q+EIQMv+wrZDQEUWJaTH6LmsSARkh516QwbNbcct6RpvQSLNezs
t4zoW+sXJcOILEgln6M3q/8//zqtHrvYiPLEH2te7uBANIoxUnU1FrqhGyf2
riH9d/hsGXUhB4FMbcGPJC9qN8m3P6/Mg736CKP3BMHLwGuN1NFmNOjsFl97
fADScf7jBm4pEMzmCu///32yku/eNGXB8LXCUjOyLw7/834sL5CL/GiZVm0y
P86gaUReeD7ZG93m1RN/vcxMFD5p3wgv1Y+1RkR/TM5Wewim1KNYiy9ibREb
2vryWZ5lLDzjTRNzOsqBdxufrcaOApTGjc29RvK495L0V/pmPmhmGUlvJ3hv
MdNY+DKpEdvXNZRxNxI+h8qb892xQ+tKTTkXgnf5s056WmuZaDH/M/qB+M9F
v66eO6fakHlPJSZsjINdQk4zX/aXYjbl48n5zwi+rl28vNY+BfpB7D5+HTLv
Cel1Hr+LYT80NC79meyfwVcEWnXDUafxjF+J6N+2OO+Y8ZYSHHrw+D4viw1V
7cjkhUWVmOHa8q32OgeLbCu8eG82wck91vmHFskjy+/cLtjxAb6eLEENkme4
Ho0elc8vhF911oV5JI+Wjy6anS9QAutyuduXt5I8zX3Yo/FGDCY8Im3vrSP3
neOKjY2ox+BMd9Rwax9s95szPS/VgyWRmVzhRPQ06PdmboHvONqRUTx3Damn
Siw2QesLQm5Mdwp4kfu0wn+MLryCs57hRflE30cUJC+UDNZijqCA72aiJ6zh
5/vvqxM/MvMyf+vFxlvHW322N5pAcQWulfvdj/8BJNIQhA==
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41AkbhpGUNm0hZhHqi6IapYRSj+orKo0OKslpRTllE9mpxpIV2iQp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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwV1Hs41IkaB/ApcrC5lHVZFevQHCSRqYkHX9atRuiMS7qzSeXEVmTlYEXo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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 143->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns8VVkbRoqikjApDL5uOAmRxmUeGU2i5DYuZVS+45RriKRGSRozMrlH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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c4lu8bxiVJJWknI2RFqZSo1KlCklmiRaWykoQkZFUSoayMzISiUNYX
2Xu+eG1RMp7nRSSVivzu31+O+/Ac93vd1zivzylicuPEVXY2NjbjBWxs//9L
xTY9ceovx66FKuxRLyjskL8Xf6m7AfvuhoQpa7NQLHX/h1PyBxzt9xViX0Kj
2iaMjxFcg8P/zMxsTtAoNnrpZeSdCJ9/KSUr99GQquqsmY9phP6AmMfCYBYG
80XOJsUU4/h5w6LBzTRO2yeJrtpZhsH+B7ej6ymc/8bc5aNdDOuGR5ZxHhS8
RT7HfWithoDIOU7ZdzSuuZi8lLzbhkVck7ort9MIfPmzxqqiBQPG5zduDKOh
MiHaQb+qxa5566bG5+Ts6PbexLsRDfIBvel/aXDvOxSohl54LrVzPWbCQjbf
7sUpsi1weCwe5LWSBd5zhVv1/yvC0mq+ZeNtFJyyVbfWMVsQ/76DsTSWBYbn
Vn7xkThU3+cTNxagMa8qt+3+6Rh8e9WyQW4DDccS58J/fky8brY0fSRBg2vI
9+ISBgMCk7qqBeM02FbuL5jflAH3oGnVX8Y0fIVyggOzypE9c6Pvfj2NujP+
GhbDPQh/KO4o+n4Qpa9s47TtenDHseKqijPJb/ZPwwzuKsw8sHwxX04j0ZR/
h7ZDA45VXe54KTUCb0k/37CJBtgFpmwPJueEVRuXT9rEoiR055GA3TQU3G4p
PxlvROlgeC3dRMFxRYoWB3cRcldurOM5Q4Pdd7+/olE/hg3dYkriaSidje2T
eMdEeMiVtefmRvCcPzbS7HkR5Ob62R16KXBB7+OgVDp6RS6nawrS2KpU53bD
oBoR92pUrkfTMFdruDvByAOzgmtqUSKp580dmlEuDJhf8JqXSKUg/O9iE49H
MU40eggPKdAQ8dg9nyzdiu6vfuv02WkwzPyadTiTsO8l/1p2fhqzmqlOR7Xa
odNg8UL9yShc5TdRH0424/DU8qjcYzTOrl5aRe9mQPfrLcdl90eQGnHpSV5H
KWyF9xb4FVH45mLWGjjeCVd/ztVGmyjw5himmvm3YWBPReGhlhHM1ChfDf8Y
DxflG0GnVtJgcXUYLadbwLzSbJJxjYXO65bC567n4mI0t66DHIlHinKJuJID
Qb1HlpUGNAY2fVMYl+1BkGNBUR/bMHZ8DgpaGFcB9iVnA7ssKNS9kV/bXMeA
Y9X2x/PWFE7f4MxiGRWgPHj19zs5FNyzxM+JbnBCr+Sb+e+baJiJnM8X5GiG
7JMzniIiLFTvelpgO5KBxaZetf4LaQQb80wm/M4E40DRxPN/FCYd/p6LFulF
4so7qbyiI8hNrZAcXVSEJWcEPvC/oeBQ37nGwfwjbjyyO7ppnsIV5y9jrPIm
RCyM+nCji0Z65oUsN5JfxUPyC/56j8JbczC8wrgZXLennINEWTD/OB0ad78V
obttNYW/k/4O27xokKcOE4vDLt9jkXyKSuaLSeSDUWH9KWaAAlv1y6PSOZZI
f368pUqExvdVGfsT1duw+Qu3jfB+Ftg0HpgMlTnBpNXGcUCMhthFCN/I60Cp
+sqffzeRecxvXrb7aQmGnf3Vhico2Dodf5pg1YXn+rFjUdto8A2uWh+1vxhq
/AYvwvVJPhjCcatfZmClIOP7v2kKez6n56/RLIH5oyoD7nYKNn1S+bVqDfBu
UgkdIvVsacsSYlfswSksenBhigXb2JO6Zk3V+HP03eLH12mMKdCxf6LqYF6w
elO3Hgt2EqNmWhbNkHBxvfCBnI+f7I/aJ8CAdmPowb1JpF+5GoX/hlYhVG6v
Y+fYCCojGzh8nEtwy/s0b3QYhe5+h9C+yirwr19txCvPwgYJ372ZehXo1jl8
0+owBXuuuzxJXS3wXpO17XzCEMK4Nq/V4U2HgaauXuVSGlVVHTEpKh9h5pUe
lE7yxfnyFTp3tkI5WTPC7s0I7NX0VQV+M8HcJi5ftp8Gb6SKVUZFB6Y9gkN2
H2FBajYl/8l/VbAf1/3LIUXjcfOM3sY7TUj8Wh/1CCzk8FArD4QyccpZu9BN
gAVhlVDX4sFXaOxj1zEkev5VI7LCarwdnXHn9S0qKGTeFGcKvm7Glc8LTVOI
/kbrJP92WlmDh63miz9KkX6TGd78Vb8JlNS3oxsnhuC3zTf/3tomZAgYOPMf
pcB4vRHJWzOhxIw+1nuFhmz8Qs2mxlwkykWXo48CteLChRuxLVDpkTU7/p2F
vpZW0/qkYiSa3WWlLqexe7CAfce2Chife+aiF0Lq77rxVNrtJvA5/yyt7Cd6
pLP/kOeWdggtPcO27BeFdTLifNwWFWiq813O1UHir1j/rflBDrzEc3Yl91Co
Hq9yGNeoh9r3MPcrwTTUjRTnBnZnY3q5sbveAaKH2V0uw9Pl0FX+6vqRxMdT
tOognzUDHsO3grIDiL7bv2fs4kjFYYFKrUVraFhFG+Rdqq9DF6vwk1kVjYLV
MwN1fi2onB+/vmAxDc+7bpd3hrTA56jjtkgGhQTPBXqvN7QgdrPcJSGy/zTd
P5/SUilGJQfXCm2if5OT4mo2ZZXIq/8xNMVGg5n03ksoi4l9x/KMKXsWVPmf
FF2taAPla7dlh9IoqTdn1Cv/DDAELB7476QhHaaTMuBXiv8UtOXHHcj7Hpe1
i2plYdfPo2tVRyjQ/kORoaptOOvxL22ychiarLTRlzIt8DJy8Gclk/4XMkyL
9OnClWIfncA/NHK9apuSTqYj2a/y2JwwjfpXoT+WRpUgdImp0TFZGqFT31Ap
044aoWOHvbkp9B66Or6ulOh9xDXHi9dIPps4OO5EMSGveSS4LIOFhmaOG9Mp
nTh4VPZaUxTRF03Z4l2k/mM919a/yKMRLhyx1KK9C+1Oq7fvDh1F9ZYUkz8P
CxCwtUN28Q8Krn2aB7RJ/z+1eS0pk0Gjhg46zgotw/P70m5CZB+FRVgrS4qn
oWX29lm+GQoPlqBriUcndJ9x+4WUEP7QPJ1vs7YF0os2ySY+o2BZXKcpWJaL
9sQSLWczGt3UYJb//R4E+q87tmMLjfYjS7X3GrYhITxX/BTRs33txgsb77cg
8/YdybAAFspN71ioV9cjfoPL/OOJEVBBCfy3htrBEzjxIoXwBldGgcCxt+Xg
Mnycdr2T9G9nY2ngrhJM69gsFGJSWL9hwED/bC++relLsqkZxYKO98ZnPJn4
NDvmvJfM+7vYBrtos3rodMgePEXif2f/0L+wvwhh4s8XnnCiEatsXBB7rwp7
OB5c3vCW7GvD5NCQS/VQH/TxOL+MBZnwuNoN52twpP5Os4U86acgXllPcg57
5uRy+SsF/bHUm380ybxuOKJN/x4Be7bBE/vMNnRKuQ3r5Y9AVHZrnLtyM7a/
is6pOkz0nONZwdTN53CVlFG4JUn03PpD3vYkJnKiw8LjbEcx2NozXDvZCrU7
IjIxIRT2mcZYfXFswukVqieELIl+rjrU4v3mIx6cerTvXcgoghe+udjJ/wJi
abrffhH9e7Ll8etjH17j7tuQvFTCGzecow64nuzG9I3le7bMkH28zVy9MqAT
TgPFPANbR5GQ5Dj1dXstgvFamrubQi1jOFtrdSeYqjEK0V9ZUM+0e6QVwYCY
rph0mxaNCp9GLr7ELGhP7R7brkmj1l19Da9vCxr3+LIHED6Q4dUX4JB4jSUP
m7WeEX3l5jq+4vAzJood+9ec+EHm/8z+qfA3N/HnoV34CTIPsU0hhVVLUyD5
aC/3U8InJv9dUdH/k4/vsw2FnSkUpD1uvS9WrENvVBlzsy4NxStO1wTXlsBa
0dbYx5aGLZ/U/GvfJnAmRnscVyX9gr8yb1534XD4zz0vj45g3Qh8f8414/kX
fRPRx+T39a97NJzMgJrRlOVmGaL/8xmpLn+aIbn+jYfvEOnHeBbH/nAG+qsm
1khfZSGTY6Kj+XIIZmcbXFYRffl0+UTvcYMUdD2+xlLmJXx+UtpS9mcBFIvi
wgUfEt7sdzLhVGXCx6VFVNqG3O/dXCQh24jcbb98zNcSffiiNqUa1QGVyX0l
Nh0slHz70sTfmgne8S3nb5F9LGYf2+55rRjsetWRaeT9zNLW+Pal5L6u7kRj
NbIPp8VM+xBLuLR550E+wru/1F7eTLyPAmmdniohGtpyt0sLopth0Po04OAs
C9xK3TbGA0xQnoIfDJksuDnZN9yeYOJPsz0dE0Tjykh00LmTbbAWC/7tRXhs
5sjeoAH2TmzkUepYOf5/fR1826X3ETWHhmc3FRAeDpCY+706G5UFBzIFVWg8
d3+oF2pSBcVQ1k5jDhqpVmvHWM9LIfbVzaqAnUKxrQV7hkwXzlYkQ3UrC5N8
rrwJVjGY4XozJ8JDw0C+u2Lrr2b0cIZR85qEd13mBxuCc7Cyghnxm+yH7Fw+
tRyZZthomNla9VP4pKb1UW2kEYO7dcYyHSkoKixwMLrGBKOXlZJH/IT7ejed
oQtxsHdbdryS8OcOo65AG9NKODyriLr3awQcwcsujpP31BfOh9l9GoO6FZtr
QkwNplZzUd8uk3r1v+WVOJ0Mw07dSIEd5D6tpUOfl9uBK7WabZj0a62cSLVP
RjdOS+pVPzg5itAZDe1Te1vxH6fZoWfkfTE6hty8VtlYKn9TcS+px+X8/Wfk
RBnwfZgq2kv4K31Hp16qRB6UpuaKvuvR2NTi87VkTQkSla52jiXQWHEvMHOf
Wg+aIue1tlSPYNjEbKcr4TeBveUPFarI+9Pu3VPXqoESN1uKHw8L6RecPun+
KQdUed5Lkn2nd3dXQFZdBziPPOWjxFlQOeHqY2JQBTYf//d9y2jIcSzjfnqn
B+3J688Wt5H6y519axLQg5kDadUJv4agFKFibX+JgfkbNc7Sm4hfyk6JWS5Z
jNK3v547En2pVh6RmXzARL2K+lrWWgoz5b53xwhfWB7gsQuMp8BvGPR9Q1Mv
7EN2XUsnfvbTV+Po6RepiOv2cOYnfk44sUw5ckccpgRmlcb20Fj1rtP60o5u
TPqe5rLYPQrziMdTwZ8LsWC7qEljPuHBKsEqr6kGMFnyYavHKCTfc5s45p6F
sUs9J+9qk3lm7Q2oFPPEdgwekSa8l3si0jr5ChMnx3aKp9oOIfjU7S2ay5kY
tBVLu+xE/Fma+1AHbybYBQuVkoi//qfov/LqgXaIc+fK6T4expgYtWL15xDI
fflVw0/4+cr0iibLzHJ08K+rz62hIKXs4zkjUI/Dcqsj7Qnf9dH21jtuM9Bo
uXl/J4lnanJ6ciSTiQ0WmxneZWS/yzTuzU5thu71z9NHclh41W/XfovZjvM6
iS5f/IbBa56xqryiHsJKOx+/EBmB+lyG1TG/V0hWuKjusZ745UTO8L6wWmyy
mH/QdpP4tQ82JeP5zVj63/o3GmS/X3yaybnnZhZa51h0ONknTKWCxXV+5Vi9
JrLH0olC2HT9kfMkXnueXJXQOsL3BQWxp89lgXX2jmH8EaK3Rm48+lcLcUHU
pMS0lIaHwuI9l0Kz8dUmDlbhNEx1OP6tqGoA50SyrS+Jhy33bDCv2Hu0v8+8
uo68V4ojdsAjLgLT5/T1JrbSyIzTsG7c2IQZEV3BFuKvV93vO5EQ0gefX18M
zNhGYK6oMdvEqoGUvLPUGSsagzflh672dOGfReeLIvJ91G5H3rjZFhS4Z0TJ
jpPv/WckLLXeQ03Bf86DzGP0b/tkB/k2+Hhs4c64RfzTTPNKhbyrePsj+ous
KA2NY20SsvqlhBuEfCtuk37L6HxZ972X+DiB8LzbxC8J+HnXj5Yhwvzusmyi
z1MZTyyXT7dA49uGJ0KzFKxCGw49PMVElZia9nPCU2q2kffWoQPC12+7/hYn
ekTxP3woyMTx8cnFzxpGkP7vdVpHVghO1HuyXIn+JHsu/mRVlw5pvicRJuR7
n9y671aF7UiGX56i6giCe23pBrs8xC/98fQ+8bPKfof5+ZcV4EnMvBDfKdIv
R/VmF53uRbvK9qFawrciFh/e5BbVgs9+ue7VdzQor+CZLQqlMK2d7R7YTkMg
f+dFfcNWSNXulVUqI35BVEW9M4HoWeOfQ9JJI5C1t0rSu8XAYuF7kis+jUA4
REHuwUQLZnkquh4SXrHZcr9griED1zR4VnUQ/fDW9rlziPD902sxqxxIPWeO
2AlXybaCEjE4autBozG5IjOerwsxRk/nk1ZQmDh/VyJbkIFE36zZHZdG4CD5
b2t3Fenn2yaqp4le+tTM+1W864Z1Y9ftuVuj4JKOfSXcXweh2AemmSR+9wzu
9bGN9QiW8lb0ekD2t3LiOeUzufAPcJ+wvUnDa6o+veVuG2LTzpSGabKQOmh4
lC+zEvebqcahOQrx8fbp/Qmt+LMwn2nQxUJB0i5ta6VuFB5RL/xrOgqlsWlh
Lp3/4D/mE+DmTGPY6m7n2olKmAaESM1ysPBRu3bRjp5G3G9Nvm5fQfxDzhtJ
jbYe7PuroS9G5tdq84E0SrYN5u1zzvGhZB6bOLNKArpQ3lufF0r2z+GIy2Fu
AiV4xPNnzwTxO5mhdyWnQl5grdGtm7JKNJp7ebdPjDbj3tN0vUDhUegHwtvL
nPDh6DHPnDsszF7gm1dqbIOXemL2TgPiRyJbJA8dJ36N7+m3w8SPxXopMGyi
GPB7/a3FMp3C9OJF5ZN74rFzViKofSPhp9Q2F1owEXL/tmg4knxzbL5jf21t
JU5M/JNUIf+/bq5hcFC0G5pLMg6MXSD+7YCdCFXci5x3V6rfFRJ927zvUwJn
B5bJfPv7etEocpd36v6Wfkn4oj+1n+zfVbcOypqfKMNJoaSlHt6knoZticGF
fcTHmnOfi/8C9YfOf/rmusG5V5uq0BlDgpL9gBi5P1dnCsfnR6A7nHZR5QcT
eVfHlsSS+SugNNvF7Ytx5f0j2TUCpN883c33zFbh4vlSiduCLNyXl48rsy/C
pzNuqVee0eDpsLKyGerE2VWd8n8ODCNN746Win8LLr3jiXhizYJ7lrHizNdM
7Mg6v2yfG41l1ennl9/ogMbfo+80ST0C/ZT5Y9cyIZTemczwpKBCO88+LCjH
pZGcNJWyETC3LRBo6miHu3TWh408FP4Hic8IxQ==
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlWs81Ikax2en7FFHknLLiqVISURpbfkRRxuS1KyQ3K2GosimVGTKJLqt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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81Ikbx4dkK7FU6BBybVaHItloP+rn2vFLKVlXW1PRbBJRqt9Pjh9J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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 144->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lWkfx73SOKJoLCNtIoS3miIl6VsRKiK0kLJMljBUMqmEiLI0Y9+y
taCyRJKtY89JOTjncHA4otUtZkqWt1Lee/54rud6rue+7t/y/fy+v1Uuvtau
oiIiIsn0+fedfsd2p75UB45bjc2TMiVY8JWllDrWiVf+T1ZYWBNk6ZZcjfHn
QezRjmqjCwSDER1KPp8F4CZ6px26Q6CrqmGmur4FY/X60RP7Cdqv141OL+Gi
cK+TXNlFgsdVkkRsgIP0SBF/cT+CL/sShNz827jgvvpRshpB9lC/SHaXALrG
JhPcywQfC9rrg+2LEcQs1vHSJPhV7e2h+uFqGIcek2frEXjcbV/JKamAVGeb
wf5fCTIWq2xi51ZgnZSgZ4kWgeJNm7k9jEaclxHdV7yN4H8yTT1n2tnY2Hhq
yPkEgfGIiULw6FOcTXij89Cc5u/lzPukxwX3mVm9oQfB0AHX5DmjEvi9cmz7
SuNPel7pCnLjYozk1o8EETxinBNEOPOwSDd465tQgom6JBSq9yOr6eIvO1MJ
lBMTK/R7apBnnWjoqUuwrf+eQUy4AHwXWf06NkGOl2ylz/sEnPph+nanKkHk
xZN63Qdf4Ieqw2iQMcGODR9q2iMqMSlrXFyuTc//pewnzi6D5+L83+fT7zvz
wmwvyHdhlnuDZxhI89d3dOhj9CCLJ64SnENQsFHZa013L161CJXaEwhi/xYP
anQvR7N3z5mKNbT+Gq9vBtFCGi84UHaA4G6r/vIGVheuLdQizU4EAwscrDhv
OpH61D2s8gzBiay/2KVBfGz1Zfh15FE+5n/4J9VwEPx7Sg7BTJpPgqgw/koT
KmPH+9OpPh3z/hZZO78XnfE5Pk1ZBHt7VC5o6gkhFjVv5D3lJfxPCycTox4s
mhiNd/AhUD97/7XG0QqMxju5OW0kCEzsUMmzqUfpH2mccqqvouqUGMu2BHJM
iRZrWn+JoYJVWmc3nnPcPZJTCGR0ihar6TSDufW2nK0B7f/vhkKTMDYk1lq+
Y7lSfhJek7WmPVhqyn33+CyBuYFWSNJwG7Q+ZNpLHabnVfwu+kTVIT1gx9Jx
Gj919h+zRF82Btp8NtfZE2iVTseZFJfj1qBGpSuN/y3fXsxWrh7+96YVM2l+
oqV/vqx70ImHHVlDMvsI6oPOpWay+iDlaP3b/TqCI0G1gYd3V8FM0WjDBZ1/
9TAuTdJtR+7PmZfSrGi9Iaqz2mcb8MQyIsxFnyDlRvq2upx6FB9zaojcTDA+
5Cub2SzAgornaySiqd7re+VchU1wOPPym6UZwbvg92F2fjxsS8OWo24EZpf7
vzAj+gHNzBg/DkHloOXbhpf90Nfe9EvfVYIAV+v0lxIsBJ/jfV4HglMTl2fI
FAulwrqDcTR/q77DJQ/5RQiS9dxzU4PgYPWutEAuG7uYQ8JhF4LtW3p9F5nW
QqTmmG4Nza+9O9ZUwWoQZ9U7Nc/nExw/sVlfdl8fRiYtI2oLCCwMT6/QnseD
edfc3Epv2u+ixmbFVYXwNgu47KtO+Sm17inSeIjTRvL3pmm8J85aRbuNW5Gz
nm0raUewJsNY7H3sC4iXe8THUD6DpkKql53lwS87uJoTRVC8Tjzmp1wuQrlH
Z75TvxEo5Kh5cLsQGi6m0kv5791jNOR9iQuZmwnTwwcJaj+Ml7dWD6Dl00jE
my6CKLe5mMaPDQgXUdBT20Qw6/bG3/NbJ5octF/0HiUYyc/dkOVeCgfv6rvh
1F+MP0mflh8thXfCbv5hOk8ji6d2Xcu+h/PKjna3qZ9VRple8fJ/gSG9ZA8d
R8pL0/MOlwN9CI5+N9ZL80vsDpPVnHkGM/f79n5G1B++b9aPX9SM4djxypl/
/Sr6aj+WdWPbvpXHF1I912TqRFlEViGqnc/iUD7/2Huu8evJdkQvt7IuOkD1
u9P7zPklEyoLzdO/U34szm+S2viwA43SBvOP036VDCaGSpyg/mR3rPMwrdfb
MNuij8HHssmRIdEblKdqrUH54adQWK5uU7KHYMbybUG4WQ9cXiXXfE4jkCMt
WYoeXHxMT1Csp/oz9Iq1+mRaUbg/a1m2DcEuyf3nZ817YV+jGx97juCSybsD
LZkcaOfx9jo6Uz4NbpltlegHw+3L2JMWOs8aTnNxjQI82b6pVPk5nYe2w4ID
1Sys0Ez/dM6Ezs/XBfITSx7Bomz130Lqv0NWl9ftCW7D6umuL620Hw72jkoM
eSZs1ONja9ZTv1y1UPbG5RhsCfccY6rQb46k1MrR5zifZSiwd6D1f06JYO7M
gpapiXYH9dsAjl3Sga81KGpey3q/lvL4Hx3NuTe1yIubTYun/RvQ3m9/cVKA
SzPSDYnUr18p+c5WtfCQs5T7JDSSIEb1/tFFBs/g6yzqMUT340B9WkTQj2Lc
ZeRvXE75qPaPlks62I8Su8Z4syoCk1v7HJQdueBdUo1Kov3zmStgFH5mw7tg
bO43qt+QxKt/ruXV4Kf/OuUVUT8p4ZyMKxiuxZHiiiYhzWdd+aHPQr1uPJ6W
yvmJ8qz0zPJtqxUHNpOF02XUn+ROL3NfksbCx6XfM/LoPvvVXFMqbKwB0d+3
M6x3UP8uK/Nb6MnHYHHf1WunKK/7H/wcmN+E1cy2uTHKnyAu4NBC+06M/vVL
ZQi970jo/XdxUs8xz5V8PU7n5UrI8kPVXi3gW2VM2W6nvDrliiataIet7eou
N0+6jwXXs4QvmEhZXMu03EDQKnFR+v7WOuwSfkuWpPtPZO3U8OMVzsjo5O9m
UH3i1u966hTej8KlddkpSQRF63LTwibYKC7L0wqg83aNdX1xcEAVxBg2/Cl6
X4CMYWTyej500/5kPs0m2BKo4Wi0mYUf11ZJ82l9qV90q15LsyEcC7QZ3kv1
CVTZmRzZhzWaJzOYFQQKpupS/Y4CxNgKN9nfpvt84iartK8HHwMVmgRF9P4f
qreapDuQEeR5Uo3yZRXw1u5nl3KU6AY8uEH9/tTOwKhxHhtqPOWUYPp/xN88
falkF6rspB1nEglCGJMt4pLXkWPzI+UTrS9nY4dcyJ4mjL8eCdhA99H/ASC3
v8I=
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8Vf8fx30LKWkgGiqRUSEZKcULpVCkaSaVVGjKyCY7CamkSIiUUUhC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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXlYzGsfxsPbjpJBVOrQQl7J0nIV7oQkYcirOLy0ncMxRIVU0kIL0SJH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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwdVHs01AkbnmTpguTayEglq8IqlK+LRxsSSktbuqg5Eia6bBHrUqTPotJE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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 145->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8ldkbV0REoSw3jWg1UiSTNV8kUdbGeimSQk0zI7JnhtHVQgxCptXY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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Vl0Xh/GqaDCUSlEoJFQoUnh/eosUSSVTiCJkKEpSKlSGDBkis0SI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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81GsbxpVkOaOVlFdUR5pK6ThtJJdkSZtJC6pTM5SijhbUEHKEtlMR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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk81AkDxichuyuJiloJHaJVVusIeZQj0pZcO63S6m2KjjehiGxChy0i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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 146->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk81Okfx6YsbZH8EkthQzkSYh15YydZG7W2JCvUrIiKVM4cSXTIOnbl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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c81W0b1zBS1CNKIpRZiqRU5JvRUkZFhPBIVhpPJCQjsyVJRiGhzJDM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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlGk81Ykax08SiRgMRUZcJcso5dRgun6nkkilVLJkGUMJoRAqpRBlaiyl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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk3k81Ikbx2WFzdhUmAw2Wh2otmXtEvrIUaOfRCK1kjRiO4YKRbXRMVFi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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 147->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk81ekXthbqhxalEoquFKUh29CjIYylkJA0IhlbSgkppAiJbEnbRAnZ
IlEirn2Xe69rvT/LTKoXqfBJTJl554/v5/t5P+d9zznPOc95zibXUzYnBPj4
+FLp999f/mFyzbRhJWY9IxPyVAn4jmXUKMvLQzKuN+zvTQTiEhELWeE8RPPF
McyLCXLCp8KV4/rh3HNdZiaEwKo0MGtySzUWvFTXdugRNGfY+wlGdeD+XErz
sAM9q2aulCgsxsnvceyIrQSXBTxTGDO1uCLjNddpQOBgJrausPwVvn8+umxO
heBtUYDIDs0+7Kjzbsii8WYL7kg9LGjEevWwmAHq/9ID/QMitRx4PZKM5D9D
IF/iNMgeT0G6yREXIQWC9g2dY0sel+KumUfrzh0EBqeufZFLyIF73MbcIUVq
NxZ7pNvARFOF1sToLoKUubLKsakuKOmvPRJiTSDSP5YTeqsUL9dwXs3TetR+
cit8Xt+PRuUcm8RqgvyHiYajfzGRU3bazYi+X23E1Cqv7cayW/d8S7zo/WgF
2x02XJSz4wPaXAjC3TTTqm9VwWu1e1mpJkHVHT6l9xp90P22tV0yiqDQyHK0
/QkLZbKXTJJsKP7ijV7ztwagtqATfyORIIlf5SHHmoXRNNG1u49Q/DrbpQvf
liLUc0JwUI3g2r550Yq6PmSN/K7XTfvxzfSrXNjTFoQM9kpbHiBY4vqzdaBK
PuReFYx7MwgSdGb6GENdyL7wKJzPjqBrVaC24AoO9tuSED8nAtMLDXsmK54h
8F6Y0vw2AifJZLctrmwISYtt3BlOsDIx+IaOLBtlpVcbOy4QMH0CLqZ738TW
1MOrXGn9tybtz2X4cBHc0+D+5ATlk4tTmYs2G6t5SnbXKR8mDd4vt5BoRFhJ
LJ/dfnq+aqhtt6Qdv+zZouhmRiDtudixzaUMKYca14TT+i83WPOUNdQEZsp8
UjO97x/x0fzoX8Vw0+3THKT5fdaO9dgXV4nXPOPAI1oEocfGTT0cWWCesy4q
tKL8++yXOiNcCoWQ8OQRZQKuhEqi38EBeL/iuTyrpPiVRaRsZwthnSUYXE/9
Pc+83Gbm0AvHlh7z+lzqz7VsYIrXDsv2ag+Fo5T/Cpvm+BfaIN84qHfRmfKL
b7pd0fAl1IoOvbxJ31f+pbM99u8yCP8aZJ5E+9NVNJ3obtuN8zkBUgopBJtz
t5jL6bDRK/fJankQwcjq2QKZWRbsGPXCs+cp3sKN/JcYXFQeqtlUTeu7q99t
rO5qP66PGG7Io/1dPM44uPRSN+5F5W52Pkv5/0K3vdEgAXpLPOPnNhPc8zln
W3eSi6oTXTUztwncujMEbxo24p221zkHc1o/J/QXi3Hw5UFLUN4xej/QLHLd
nkb8VLBCdUqfwIfz91oDh04sNDwXV3IlCIppHmd5dEAxI/R0Oz3nOHr/KbWr
BWHvlo0J034a8ExyQpyuIOv7NXdDGr/5ypPE87/XoFcv7s1HdXpeaB6zfPIM
77vzTp6l9ef7FIMa/mdI/R57uJPOO8+qxHROk4OveCTgHUv7GeVYHLFYAsmb
9kbq1J4pVPnHBtFu2Mp8I8vjCdKUny2KajzH6eHogGFqr98rsfinegfGVUo1
V1L+Bttm1lueZaNqYcioiPI1utgzxiy/DbO3ORlptgTq+3M8fcZbcWtkfJ+H
PYEt84RM9plO2B6JYJZQfpmnvd02KtoPf57M5z3BdN5UupSxNx16Pw76+FP9
mPxhORP4jIuerDWrstMJjq0r/+b9OAoP/lx204XiX/Q2vBG/loeVghd378uk
9fuifX6TVReGGMXuj+k8Sqr8qr+FkYkdP+efUafzKF37/HGk5EtMOer/aryT
5s//G7eqnA2Lj5nMiTCa/8Y3F9IzW3D6rmpZMK23raw+1zO1CbJzFp2uVD9b
L/jsGh0ZRP74BjVbGu9thbyCs94AbHgd1d51lF/zN5Ijy0qgnT/aM0j10Ed/
VvN+QxPch/f0MYwpnjeTwl9y6yEdKJW1wpBAt/VrykRbKz585B3vpnbpfItj
sp7lML0dq1ZE81vgOMpa2XMhraJS9B9fp9IXYooq2cjP/mhznepxUYyYx83d
DXhtYRTvZ0H51rTKv0S8GVdTHGbyqL5KHj4emfCBjbqhZZPl0RQPY1L+ow0H
XdbF2aqRtP9qzu/1lHqwb4Uq3+lkgnQ97jjL+TV+9D6289Em8P72wqRbhIuI
GOkGaaovzsYW2z9IDWBB/m3S7iwaf3TIcUn7GxhsFyk47kvgUZLx2VqgAqxT
PVHnqJ541e92usZuQ6WM7uam36j+rm/850lmKcjd7Oya7QSRwXtrxSrYMPFf
DF5G568tL95rvqQGr7PjYsQ1aD6+Vk/UZP5A/cPOQxyqd61BuwS5Y70Qqhb6
vxuN380wzR7XeIFOlnyiJfXndlzFZ51RL+6JXL4oSvsz7bjT/8qxXnS+ibDR
DqX8drBSSPitFQJV/zMoo3osOVeSbR9Yjf02x5/+Q+NdL159zziLCy2lwrNH
6T749igjWuxtJep99QYKaT2k506wVo+0gCnsLiVmROC+KVNLdm8vGGj40ZdB
8F1jaWnLIxYM1MbV6g4SaNfvOkxUOzG1wbdwjPLx0r4Hl/vkBnDx8n3Dk5Rv
ktbsTxJfk2Clqc4TpfiE7KdDkgO5mIptty6l+lUl1jw8F9qHfn9/wyUv6X7e
3vTJ3oGNUI0J3jDVx4RMxRjdml6kOXjsnT5HYJy89MpzVS5aZ6IEi/yoP0Uz
M1nCQV6jUNC8B4FGruJm5XAWKvlX1lpTfdP2bPoc5vcK0kPiSkMUf+r7Cefx
cLoPv1yJetlMwJ8bkize0wqm3cnmMTrPzP58jS8/3UbQtlQtBTqf02ETPieE
ayHxTmF/Kt23BvJpVcO+t/DVZHhEiNr/6LrxS8FeFvSeFu90DCC4K9Q5us63
E/7rtWYT6b74aT764X25Hix6rDl0lfZLIHsk30y0GXda1ghcpPYtq2bvHBmu
wD+p4oMBVN/PDB/S4avpwbkDm7WvFtB5ZfpacnKrUSAYLD+hQ/AvPZ2yNA==

                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8le8fxiVpkNVSJDtUKKtIl0JGUim7IRWSZIekRSmK7C8qStIuKVv2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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41AkXx7EjFYuiG7kLSah1y+2bLhZvGG2SSyWViK1Rbis1osuqt80i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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs81IkCxaUUSatYYqJIiLS1JY/UQeRNWLStRyurB01PVkJDQl2r1Dbl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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 148->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk41M8fX0eHDj+6lEIkKaTokOiFJCRKSLawiEK5C6ElUroUckSnKIUi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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lV0XxhWhlGQolCFSxojES7mJV1JUGghJJUOaVIbKW6aiyFAiQirJ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs41fkWxnfIrdpocuuiopRLHhkqW3kRMjNpjEShwzSajqTjMimX2kbk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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs01AkbxpdYKRG6rGyoraSijSPKQ0guSQiVkC+mpNadpotbyYaWEG0+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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 149->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk81dkbx7XKNMWoJGUdW1nnWtLmg4kQdZVi7JS1bIUfatKkRHQpUclS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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4lG8XVpbQJkshSogUpSSR3CqVFlJKthDSRmSvFLIkSfJTSYqEVBKy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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHs41IsWHd2OSuXRqfSSZtLDSXKolEfrmOuo29VRdEqFEc0tUiTyipik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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXk4lQkfJUuWGFRCyJcWDLIlWhzLpC/hkVQiEkLajWyPQuTTIpO5SkPc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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 150->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4lOkbtqk2Za3aRdqopYNDlnJap27lGIXkVFYnp2JW0hC2A4pUNovQ
DylsEoomySFMaxwazIxDmhkmJanXyqmSWqvfu39813d91/t973c/9/Pc9/3+
ePCIq/88KSmpDHr9d7fsMzkY38hGTkfFw2EzglIH04x/O2sRYqYn265HcF0t
clOrlwBS3xYHX/ImiDGt5g3s6EDz0sm0fU4Ez4fTfX4vuYEvH0vjrq8l8PtT
Nb8wrxe56sKXHUUE1lZtqzT0hFDiJ48uPkfgFfu81vOPKvhFKi4Z2ETwfpR7
w89DiIg551+8YwnmJ9cEcxwegdH7t8jHmMDA/qhtmVY3Ri/W+zbEEcwmukwv
XdQMda6ikoU9QRiPdWP0QzdOtGzdZ+5LUH7suUMpoxSFWyYFThoERdLSG6o9
q1B8/FLWUn2Cvf2hge/+FeGzwzdysSkE4qWGg0dS+VC+sl25xZ1gob729M47
Ang588Lr3AikZH5OdQmqQ5gsq5JvQutJWB3lrvYAF57Fp93TpfwM1JsWL0iB
Uan29hXqBPO21VdNKfdjiLxtUhYTrBPlJvukPUV6R5g3KSGI6BeIxk8/xS7u
6xKtMPo/xoHX3mVCBIlqSm5VEciPey2Tls5EW8bXneN0P2Mr1YwFn/sh9ki1
+PAHre839xu8qXIsc71T868mwV8X9xZMSYTYd+GlJuMuwZ18lsnVuzwYO64Q
ue8kyLVPXMO06YFx7S9rzlP+2WvGi4MfcFAx5MHcu43yb/B65sQuES4aar/z
iyFQs34/d6aiG4X3zpocOUvft5JPnV1fDKnGQmYM7W8Pk3uot+wBep0Sk9Po
/9mZZjyvqUQc5Z2TXFOj/Q3bc8jvcAcqF2yqyvcksFz7duX52lbsZQYnl20h
GNYsKHwQ1YNorcAvS/wJzo4pvRupegx/u5vbdCj/RbrVD41UnmHxmT/j4yUE
o7z5A9+N9cOd45/CeUagx5g5/+JQEaQs08wZFE92+qLNGQwJpEJt78flEdhf
62wVmjdhj/TG7AobgixmTE6dDxcGU0s6y7zo/lfHfBtP9oE10qbi1U6wfMPH
sdV9fUjZrO0W30zna3l9u/9UL+qC5UMt6X6V1Yt2Gal2IuTm3obFvxL8/jZj
0+Z7fPgHDQQsovPRdKlMY/ZVL8oY8hdzTxFEyqfvtsvuhHyattGT0wSJz56H
H3lyH0STNZRN9VRRHe5/264S6vdeVl7ZQPneW6LB4LfA+R8ru1IQrDy8YcP0
ZA2s7TKbvtD1pOp5xRWtlVhZt9H3If3+/Y8x3RPHa6Eq67lRzYDgYJXB/aET
zZAbL2xScCTQ1ZV5vf8WH7nPHYvPHiZIGbdo1q/sxc+PVo96ZRIY3p4wPlEt
wPWwa94toZTPUKfaRxpVKOGGvBBQPbI6JP3pKncROZfeqK9NYDLmcTfVuhf1
hc53Wo9RvXQn/iPK7cYn7f2RSyIpXvaZ+sRVHGifurZmyJSgXVG3zTxGiOkw
sVs9XV/31bDc94NtUEvt39biStBgMhLtLHmKE8+YyxZmEySke5xqdODDenuj
cj5dP7G4pKhoERdBV22DRqypPq4bmt2qfwQ3fpd2NNXf6psHOd9HtcLC1OWl
zXbqR7y6vIV3TyNHZUjZmc7fSpaCw9h+HuyPz6ySDyIw1VT6kOwsRLlKmat+
AtXvgYyQ5dYd2PxT4TZQvlT7j+qwp/moeXB6Wkz5qkhWl24RP4FG04JcB9rv
/k+HhSFG3XA5ZPhhBdWD4eV3Dh6mPShSHrFwCSHYIxvFn0f9i8FIG3t8mc4P
J17O3qwbcuyVXCmqJ734muCZkTo0vTm+ZTnFnyCZTJXOFMDJyWDfqx0Esr6i
td+Ut+JOZZy62JLO60F51dJAAaxz49U4wQQ/MaKPmBU0QavBc1SZ8ht01L14
lY0A+h5iSTf1Yw0ud3dbIw/+PL2QWIo3P5J9IDKnC9Fix6y78QQC945b+tmP
EOE0cCjUkODLeM5LvykBxgfFTW7/+fkx+YKFHXxc1nIJ5QTQZ6N846Pqj1AU
etVWieKN/GheOvqwDT4DPxwIp377ZJdhQlxYD5KZbtI8JsH3rpzlZv9rwc+D
yy9NU31brnhXE7WEi1qJic5Nur99wKx/8AwP0xpFvrbOtB62TDHrV6p/Ez2T
N5SfkPtWUyVvO3FbLJCYUb1k7Lb2n3Kj9disrxn0oP77zUlmZVM7rrQVbEqh
/j57ulWx73A5dls31pyn/lNlGTLLr6fzX7djnSadh8hgmZXJW/MRmq+Q4Uv9
gR1w4IypBwe2W/8QKlkQnE5lB3jHP0H0vfd5ERS/w9MDRpXrO1G+vqtWzofm
jUlYgP/WZkx0kC0nab3/3LQ8xeGLcWV47YVP1H8XZJv1KEhEEA6dry26SmAb
1dLv86IHro662ipUT1UNDTJ1Rc24brNxLoHm46zdRF/UHA8hr0a7PlP8bi9Z
Wp5JzbBLv6I4QfPtaKaerrKVCIqBxlcSCwhCD/2Up0DYkEzNG+Rvpv3Imvub
axSBkaXh9evpfEu5zJEqyXHkyr6JNKDPDOmEASUVHtT+DB/QDKT8N3ZeDh3L
xpwOBmppfghymMYfP0vAL5/IS6Z4IyPEzemvqjDkUXJvmPpLuapdY+nx24jI
URCN07x8d8uxLpDm07k4Udf836n/jNYlsWR50PlhWMmBzmPx+Ntvr7sIwErZ
3r79F5pXrKQd4ylN+FRUofCanh/2z3DHE7WyocpfaBSwhuL1CnF16GzB1O0c
u88utB/hrotjlyXhKxnm43SK329pqpxulhg2epvbJy4QmA/Gls0ZV8DF+EGI
mOKZ3Gn1IiVbAkWLdCPOX5QfE8tAYfxDxM532xm6kfphnJN5z61+aMrNfHAZ
JLg8vuPkR89qTK7Tct1D8z7a4HDWyDUR6oWvPnmzCWo7GmSy9LqQce23sY+0
X7xztUmOrF4s42QYz9HzxeO/TMry80TYtJilM0zz+E2B+U6lje04ppIZo079
fs9WXppOeA+YX1WmJlG8X8t2SWmxn2LuxyIjBvW71l7P2LeTfeAbfzfMoP72
fyiPyF0=
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8lG0bxicpxOOxpFQqe6I8FKVUR9lSIUuK7EVJC1KUEm0qIcoWiigK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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHtYzAkXx0eyMy1WbFbYQi5hS6WQMN8KzSsloumG2qEirS2TKJXeCqNX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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs4lAkbxqlNihxaJq0+SliHmhLl8NluLBGRVauDqFRWB7QqhYucS6nF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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 151->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8ldkfxy2JZCylprGUsqsoWzfm+nhZWowuUZGRJlMRJSRJpki2BtlG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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8Vf0ft0KSyCiyiqSQkVWpN0oRT4siRJSH0EJTSkUlIwlpICopsskI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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs0lOsCxpE0nSjL6SK0uiwHJYW2shVPp+YoQi4VSbHRZXempFKjUERJ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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk01QkfxnWToppUQi+NjEL2UpOtHiZCEyNelEQLNdbLzZamuKJhJioh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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 152->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4lOkblqSIsqUtpVA5hEIOK5WbTA67OSQJFWGLbGtLRNJqSQebQ221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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lF8fxlUqSkhCqJClQrTTT24VrUpJKlmKklAipbRYkyIJZa0kWctO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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs41AkXFkrRp56UCJUlarOzcsstbwrLrrXuRKxHhSSVSkSlj8R0/ahd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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81IkfxlXSOrbVsWwNtiZF4yilS+qR2NJWjuhgk1qxixrlGNIlbLFu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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 153->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXlcjWkbbhHlizmVaaIZk1QqFdHEOOmSJnSKlEiLmRa0yNIyhlAnNS3I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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VH0bxi1ZkiQkRaJFKkQpW3VJlEpFIS1akESWJJSeiIqQRAlJnkiW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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41AkXx63IlPs1vMbS6ipFTTfk21aiFamtLYsWlTBdSMm2uqGWXAaR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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHlUzIsbxtM+uIeiVZG4SIvKEqEnS1ISqpGb03bL0L5IpA5d1dzEdHEr
S9s0EpKUkRZKt22aqWlnWqhpmvl+v5Er+SHJvb+5f7zn/eM9533f8zyf8yz/
NcLtmKKCgsIZef3Xdfv6jef/qMZOm7CL+TQKpm3lO0PODiAhuy9unasEqclm
CKptgTDU+EFzGYH0u2mvawkebETR9zTPE9h4fXVT0aFO6D12KYqMk8Hgq4m/
bF87NCXzF6XoE7DkWXwW8v9CTsCH14nPCRTT3ndr9fRj9I7G2xgHKfz6Rp74
HhLihM4j35UcKYykrt/NbrOg1+cZ7z0t/2db+2AC5yUOFBOfDNkSrKvgU+Vb
GsFcnm8wEkHC78+mntUDxWgxuGF3mkVB8xM31t3kASKjH5RXRFMoGtvbrSru
hSqrpHPejjHUR3UEDR+vQ6NBVFx7K4npHKUffK96HJhwppFDJDLcaHs3mQmQ
nmV4tKaZgI5j8+8LLvMhyKcZeWXK4F2i/e3Q0Qa4qjH+tAsicXAw5OQeRhGK
y55SJ9gUqs6kGWzVbUC7xx92Vt4kbGdSK+6HimBQp+65wF2CxfxfavuHaqF8
yWM2v5FE0bR60oszIljc2zNtqSiDJfd7r8fbJhiI/Bv+SSJgbaoYFr1wAKtf
aQrfCsWw5Wouyy4cxOF4e+MAlhhf3MLcnOTz0fDd1ECUFEvWi2ilsn5UzXdx
jcuQIPQIYwF/3yDU5j78kak8im5Vy2XGj4bRtPt7R/+WEWyOUXl9wJqLL5Fr
2gK0KGyr8xYWNzUiereTSZAtia/0pG/ujEEYby76ufSrBL/GnfDvn+BhS7LV
cMhPJCyTzh1+586GUCmkWeMFBYXsgMKJi6cwRTf8Nqsxjr9TfDY4O7yBxXJu
iZLvCKav8mkR5xqQQT9px7pL4Llg2ZIZDEJlvPLq+NoxBG4yCSSutuDei9xd
vlICS9Mr6VeCh8D4JfSU79AYpHyfAKP4dtziJZz8aCvDtNKN6svbmlHlwNT9
RifQ4V+mriXtQMnoy45jMQTsI1Smki1yEZt1gdbaQqH+/KLxNWQKsnjhRn8r
jcPo8mmvu9xHuFy3Orh0LYXIls93h8uKwKrm68mYFBIXHrVSM74E24MrLl37
TGHDw1DW9sNCMFKLbqXJ/UrcMT+q9+ML9CUTyrlRJBj/xKgL/Ltgf+Bmoi9P
iskf0p06zwpQr5fH8HhMwcgk+aHUpBnJg9c5dl4kSr7uba5NeooqRQ1rdxmJ
1naCPJeXj2ZGfRCrVa5nbYfV715tqNucYiUqkGENJzh+0KwNuwJPNc5GyO+v
Ws8MMm3FzI5d4aIPBNQUFsV2+jWjWtnaPSuQxPtr8XZv26pB6Im5mXLe/5dz
8aGvoAuq/pH84Go5b+fNvVdm3MEOdmh/Uo5cnwZngZ/HM1BrtZzDTpAwYk4I
k9PrcEVffx8zlITYSXuebEke5jqWnzStoeDXubKsdnM9LPbzVBwSSLy79Fd2
heoQZvdW9iusGsN1c/1j9NIhbNrxb8Jx5zFQSusS76VVQHfVe7/izRTsc9mL
IzxFmCAbK9NEo6iPjA1/nvoMNV0hpgd75HqoHj1EfydEe3T4xey1MgxvDJj6
EdEEGa057habQOQptaVfJLex/7TxQGceBamOnsA0W4SSOd4kw1KKsjXtv9ms
KsWeN02OCvI86GKqeNG38qDe9PHD/esEGiwywuy9X0Er/2XB/VwpXh/xZOfF
DqFFj85RdBFDva5yaem9GiiPDK2/VUpC96mOedCabrziGvfO+SzFlRusqYxF
XZgJLxKF2kgRoCFc/jCzFVnOVl3vfyIgbnqzyHqcj8rxm70aAhkWahhqfHLk
YsEZB6atGoXrWZw9PKteFD76uct6l5wX7S05YTYv8U6y8LjTYQnY+z3npD4v
hnKnj9/bVArswDDJjHYuti9WcTRvozCxfl1C1/FOTBaKP4akSXH2n5iWqMxe
WCQc3PgpewwrPjGnTL70IVx599bJgjHYH5nRnrz9B9oFewfeTFKIv8ibyCjs
gc2TWP9ZGoEn7Igj1zhynsuMbnFySDTSeC4NK0SwDRx4luQr36eV4pRn2AKd
O1WV+m4kJvPI2KiabIS5alWxBBTUnTa5eHwYgssJsxZzbTGMwtxnXe+yUNzo
czR4ikJrvLh28n4leraM++kto5AarKrrsKwbMUKOUs1aAjXsdKfwuD4k32y5
4K80BoWeUSI59gUUnTozV9uRoE56DtmMV0PCDRw5e42E4r/ThnPSe+FU4CMJ
ypKij2GxgaPyCvzXw46mV+X6KShUbJ33GANLshoZZhTEasOa2xZz0c0l/U1B
IeOGoeB8RDX0t8fUMeX+rgyYKUu+1gvOnjf7RxhjKJ85S7qlDODBxjP0KzYS
ZP1G1CQWtyM15NG5ch8ZqqZWMW7yBFhnWU1fbk5gsWHouArRgbb0c9FVgzKI
57GseU8LcKG2NH6mUM7fyi9LE+cW4mWaLdNGngf/B88Jx9U=
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 154->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk0ldsbVh1NpEQpQyUNkroypQyPOKVfSRQadDNEJDJc+gkRpUKjUFQ0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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VG0fVlQqyk4lRNleUikp6la0UCJJXlsUkSKVJC0qRBFeUhJSKUUR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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41AkXx8dl3y2EbojtybItNkoprdJ+Q6hsGdGFrCIlLbmld1AuYUJu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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81IsaxodUR4u0mGuPUBKRpTpye+q2OFESkVMiRFINdWLIkpwS0z1p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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 155->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk81ekXvmgo3X6/xjDSJBSl4lqKijueyRJDRKlkaIylMlqIJBNjz1q0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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3dcze8fTUOlIUqRJJUoyahI6CRKoiGjJFRCO3tFUiGVhgqFNlKkPWjv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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlGk81Asbhm2dpOLnoKQikqXFEjmU3CVOaHg7SqlDJEI50XLSKjFkZEvZ
CtFCRm+OkSVRllGkmTFDGFsoy39JkaLi7cz74fk9H55vz31dt7ZPsKufjJSU
1BnJ/H9z81TSP1pxUektK32JScIy3j0tWLcNGXOyK9vHKeTs/pz5KOQNskw9
47bG0Fjv8KUi3k+ICBfDqIQvFPqVzxqHWT9BFUel5tQUgakxHW21+2JsGR2L
j/SnkRV6MIht0wz1+rAIljYFua2xe7nDIlhfFm/1WkNjaK580THDNnzNzzzR
+4pCw6rTy+0ru8Fm3h4UH6YhYuwYa13ajPBrE4NVUySsr7nf0oqvh7bTuvw1
SSTkGOc5j/s68Ledyq6+hzRWxPrlnMi4DrOBbY8H/yBQ85X1TK9ICH6BZ51q
BIWW1wof+UlCzJYG7FnPpjA6x0X+Fq8Gi1d3n/QLJBHpNjUw5xUfd0LXa89w
KIRcTyo8HMXHY/ObS+LWUWDFx4y5j7fB2jagneJSSN84W+UT3QIOU9PjbAOF
A3o9A/OuCqHqWpix8zQF+V7el+xDzyCSzpy32ppEZY31ZAS7FwYnqT69yA+Y
0fgZ7KpRh8rtb1dEF5HQ1LE67PW+B6zR2qjt4zSk2NlNJbU3obj1d0N5fwJV
jTb31CaacYChf/q9IgWDG5cbdY/x8ceTEneuLIUZPaX4gJkG2If8lp0wScKt
/vqNpQpdyPsu3pNqT8PjTOUJRn01wpKTxoMcSQTZXv5WN9YK3dRvWrp2kruM
VqfacCvow4f8K5spLEpaNtd51xsIe2X3OgXSCKmel3dnnAOZAd82XyGBLc1T
55eyWmFLE2MGm2hMGxqzr+7lgjsQ+zk7l4RUhbx+Yn0jmB0JrCJDSb4jmufM
XMQ4nr7F66AJjYkDWnPVt4hQcieMXR5IYdJ3P3MZrwVlCgs3ptlQmLA4VXHG
rQXjj4pdzO9RCFg835V5lo/UP++xPaMl+XXZuTWFcGF6MDPWM4XE5PBlGZOv
Qqz1HX+5LZyCpsBRu9mfiw6O7f2ILBJ7jJaMJK/rgEFWgLeTNA1z04vO1s11
eBc/omaWSOKB8nTrLZN/IDeTLnuqgsCrpyeznqa9wZLbCabMEIkPHncznR3z
ER/6qPpSLIGNjhf3hra0wO6M1sFkJwrdzu9eS7nz4D274X2aBYWyBkaF3u/F
sEh1eHe7lEBms7O03ooGJBk9KPlZQ+JEvmtclnInbG3frlK9RaNWxVbgQfbB
aTq/J4RD41PVwpELvz6Br5f6ZruVJMzsPX5mWvDQWF3wYoE6BetfisUGjW3I
C6qNcGijYFJ0My7xKQ+aP8r5x/dTOLnSTS/bjA/FWP1B13MUTP+UPVFS/gKL
ci7+lccncbfpyNCCSDGqvJb7s6wkvFH7LXrzDsFE8e9olgGB8G0XdusyE+Hz
S8bkBycCyyZ0OAKtN/gxW35P+orEp3HOp0GyEgdC/Ba+0iFhYB+wPEnYg1xE
qlteotFfWD26z1cE48IZgYoSjc6ckKNrrJ6g/D8FakIpEhuFS26nm4jBa6qV
PsigEZBUnsGMaUAUL3jIZZTEw5QdSvMV2mGewY9V85TwsuxiRYqREP/EsGfy
LlMIZ+SY8L1aYGP4IrezXsJH5drAtfEt6P/VSCfrCIVjK2SeBU7VgdRucjd0
IxFRvfRlrkcrCn7TK/ZNkPCjJDvX8r+tuMhUOhzIozD3StXU80+1GLTrfh/m
KeE3dSBozUQmZG5Ev/gcQkDRbDTM278RL600WrevoLBzn2N6deEr+MoNqOks
oKBInM62ZHZi1wDbe2WJ5J9xzzcJ2kMxw9qg8NaUwIM1pOE8wxJYlroqXaIJ
9BnHXcvqFMJkyGWo5gGFGz9iW1eVNWOORVzXxx8kdL+opBybfoO1ezj3Czxo
pOpe2hxuwEWB24VwWwk/BmUX5g3nCSBv0+XzspaCKrE/5lauEIwqzuKpXgrV
xexn1eM9EAU4qv1so7Gbo1ywX60FPueK1h15LcnPtPu8O/0Qpoa2wxrVBEw9
x2bKonqgOPa9q7CQhrdqaaJpYi9mqkbW+SR8gJTyd8V8OhqqWrPJwZsJqAi6
VEvMerB7UW9nMIuGpXWyVVu+CEmNm2TZU5L+3KbMCGp8CN8KZ7FfLQHvitDt
UdOl0P6FkSI1S2BidS/BOipC3Wurfi95GgZ2RuajxgI8lonTv+En8clWIWHs
aAmi9ftjxMOSPu9dlHpUhofdNtPq5n9RyL+zwI57pRXqGhqaPTspPDSPk3sn
exd1gQudGsIIOEw26OaaPMauc8k/jHsIRDQ1qGcWiiFVezvjgBENu0M613KG
BGBwpCvU7SlY/u+r/jdahG6PHue17RRSNvKmLziIoBF2vEa1nML88o7SY6sE
aL+6rW/fBgqf5IoFGiVlWCDbn7BkhMBRmVWrOypEaM/lqSilUXA447I04H49
nkft6AqS9NPOhV+eITINgsXLstT3EfgXY/bJNQ==
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGs8lAkbxmcVIWXYt9I5RWWqyXbYVLgQpWyHrcEbYhyKpEQROiBDrfZF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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 156->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8VWkYx1XaCDGilBSyt4mU8BOyNKUoKpGlqGzFWEcZSpJUCmnKNrZU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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Ve8XxSlJk8qsUiqpyFAU+caSUKRIiKiECk2USqVShtBgiEKRMlQi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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41AsbHTeKFjd7JUtNm0ooCVcd2SqlZeKm3MpalNtXEpKmrnItkaVI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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwdlH00lIsWxiVDneSjFXVEUoly+6BSF3ncSpSOyldIknAcKqIkp+YonCal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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 157->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk81OkfFyU6WKn9YSmiGknKFWvzRs6wP0kqpWPK0SHCtlJKuZXWkQat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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3dcTe8fL/EVhSZFSJJKkpAo3hkVKVraJaFQNJAiqZSiITIrlGiQxq00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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk8lQkXx21RSSNlUlRyTaSU0cKb5WetLJU3yxX1hmFS0xAhKmuRUNq7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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlWs4lAkbx52KCilaspKJQujEeoX8taE3Fi0rtFQb1artoAivyGmtohix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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 158->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk41OsXF26rYrRQlEiSrbJnucdWWbJPuShEiUIpLUgoyRrmh8ZSUUrI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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8lf8bxpVEyviWFoqQIkWiULmUSJSEVKiUUL6lkiRKyCwNWWWkrGSU
LSt7ZB4cxy4yzvMcI/lqkOr3+f11Xs/rPPO+r/u63ve6s5eNbeZzcXGdmsfF
9f/fI0GKbjbVbbCX/RK9PZRCt+ghT8e/Tdhn/0D2/GEO8r42JbS6MfBWTuH9
Mf0R7LWcjfTZzYDawYgqg21sNORkKthyOpC/Wl1iyIMG7XlLSKyrA/dMOm4H
unNQ68xrMJj3DA/v/DvutJGG1mQIV8z9JlTurBMOTuNAr7FTYTy1DPH3ZvBK
iIbHmt0L5K81Y7fKSya3CQXL9DneU+o5WCdm9Gq1Ao14v6LSyfftSN2g8UbN
hAMtmZXnnltEAfq5W1VlacwPXX62KIAFEYdZzX/FRnF22/vQcIMazEh+29C4
ngPhnBMDZiPZ4HX6neqtTOPg4o3qNkV1mA6a1dWrpdGfNHL0dEk9zlded0tP
ZiM+Vp09MFUFF7pG0ceZRtP8XUf+K2QgteXwlIgrjRYN5pCFSTsoC4bWhBEN
f88EO6vTbZh9umZ02p7C45jh50xGLPj7nVa4r6chUnL0ksdKBl7Pr/R42sPG
MUsWd+0OJu6+e56sF0xBK0Yp4KpeHlx5E8O1LtAQXsgcC/yVhAiq2jZkLw3z
xpHKYKUGLDkqRY010bjota5K/GUN8nz7JCa/UXihbrVJ82AkskdPl53fROoR
/NHgXlUPvp/6OWguPorOAV+doxbdcHlTVHZdnwPJp4ahO8TqscbweNyAKoXC
/MJzRUqdKG53zljDR2PSb6XAdEQTbDVs+QUiyfPaF9spH03Dx5his4UtFExZ
f/Jz8irALf6slLOA9HfD5+e33BtgNBPr3hdBodJpfcZYIxPseRsrpI5yEOLH
e+jYowQwDku6vhajsUlZNmVfRxckdy6qOtM+hPOf3YdrvjYjzTXzWrkTG246
fj6LWj+i+ILFibfUKNR8rZoO2nXCf/EasxbREazeE97/2aQAYaHMFfv6KHhs
qNW5L5+Eiq28ybykv9M6c8aMFCb4JNIufPxIQaQw6LhjZDMi/UeLFLhpcKk5
Xfr81AZ7P9WYta2jwdeQW5doxsKXFjH5klwaLplcJmbpTYh42zs0SPS5SsEn
OcqiASZMs5mWAAr+e3vyeD4wcE2pi/u2AY3Sd2uFgueiEPTGN3OY3K+xqMvR
gRUPudqMUwO8NCrVrNQ2TzFQZ8CVM/8tB9dLpiKdnzDxRq0w1fUmmRfTQwZr
RLPwe3b/q3ek/iybwMbdZyvA472M+wWp12xLgKTL9lZ8GT4Qn6rChkfU33S9
mUbQHq2vkt+x4eRT8/vHExb0MgfaWwrYYFg+ed5+JhsNe6sDw67S8D5u07qt
shTU97AgFtHTkTSBL6sPd4NTvHhD/b4ROA8MxRqnM2AI5ssQNza43Id+NFZc
geRs2+l+KRraXOidbG/BgKoUzxT/KEIKGMGPDFrAH82Zp72Mgln8oxnr0nY8
MctPGFPnQKI/6980mY9ISNTVvHFiFBt19ZYHiJTj0OpuxppnFHalXzDKTC2A
KiN7ptiPhlGumVrc2nj0G/haieuT/ljtGFk4lwjdg7kbB8n8yLuXy6gd74Ks
ilDnosc0Ho2s49420AaJWGE+y5c0lKfLZBcWdyKL3cmPBgrTJROvf2S2wDdT
YMO6WxTm8Zh0SGn2gCX3yO56wyiCQ16HS5S04HjXtoHJexzYJ0hfPpZUhVTG
1OE9leT6OotrJv+0YSiEmp21Hca+rHtSU5NMLGWqydomcsByjlZLYHXgZrzf
lvduoyjky3inEN2BJycNjNar06jwlPYoMCqDtXL8zoJbNOZkKuwvFSXjvWO4
53lpGlE5UT5L0yohfqSCxTSmoXMx5lD3QAUM992c982HfL9G+be4rkwkJ80L
05iiYHU2bu3K0xUwj+MNf1NC9PeVW1fDtQip2549nCTzx2Uo0Gk0WIHk47Kc
z6AhcUh/dahWC5w1pDqOPqCwZUTqXcyWSsTy+GqNZ9CwD1l57HkeE/qfgpRm
ldnYozrswitTg9NXK8rUz1FIr/MYj/6Vh/RI2bL7W8n8H3jbl5L2Ab4jZnLB
uhQ2DjAuTGi2IIL9SrLAiQP5bV9P6jsywbVHMdz8OAVJbu+oYz+Z8Mq2S3MW
5kCUK+HuGfv3sH1u8fvHJAVPXkUrRfs2tP9dskDHhZxvXPjsS2whPAarX/91
oXHl2g1rjnMdTHlkHPVH2WDti7vydF0TVBNP9YdqcdC/8rfhOo06dK+KKU1w
o/HwnKt8bgATO5lqzhf2cuC/SiT03+JCaJZVtkaS5wlzTXRNXOxGK+feh1tk
3rQE5yb+jJfBzzqgQtKU+LXRq1KNK1kIaum6zG9LI513z83FXbl4deb+y1Om
NM4r8N9YYFaOsgfdIrvuk2P1KOs0/zrc3uYTbLKMDZsY1dbfdC3k43idOwto
MN/E3Gn6U4Zqffmbhl+IP7Lyq+ZP3AVHoiCqRoJcn9zJly7dg9/V5+ovPxiG
2nj8herialgG6Q9S6ymU5p40EA7sgFqry4laHpJ/ggsWVKm1YqI7LEqR9G+L
l0HX5Yl2PHVuGWucYqNA1jHwfmkHQv7hpcPvUuDrPGdZ65eFbpmDNwJJ/2o3
yx3YOy8b79w9RTVtiB6/mVyRpt5Dx6zZ0EeVxlcByVfnNlbjYUT/H5UXpF77
f/JIXG0FyyhGUUuYwrDD7jj5C814zVryV5j4wTqTnfPabDsQ25g87r2Sg3Nh
4+HFm2oQUzgd3dND8oF/91F9wSqwqMmAXn4aRSbVSgYvqyFsqXN8xJccB55p
KJHoRqedTMw/fqPYblsztNKpFNNC0WVXiV4lBy/q8zXkwMPB+27oReK/5z3/
WzleD2Nl8THezySf+awrXH8Vg2UmEivyiMavEosG4eRSaAyt+qPZS6FTPU19
Q1gedJtuMK+R+Tn6LKOT+0ErHKicgvilxG8eNKY3WoYiKkCI82ol8dsUNdWt
wwyM7pDan7CejVVD0ayalA94VHf12ta3FIoaF5nRw7UQtfzzSUCGgzWvHQ88
leoFxSX98GbcMGoDZuOvuzcjOUz1dj1FIe/7l1fL+xgIi6t0/5eLXH9dcv55
oTrMu8kttz+T1J+3eYuqYBm8R//6mN8k87V8aWjesTp8UsjivLhKeID/cHTb
6rcou1gtLEfq59PJsznun1qkun28e/AMDaWU1IG66Hb0lasT6iF+b1WdH/Ps
JWoZfvF1MjRuJdsMfM9qgkX/U+FNAzQ6l4kGmN9vgJZKLUOYn+RN142U//Ty
UTt3a02oFcm/zssLZNprMXa2xKDYmgN93Xq3b4/b4Ps7Mtd7F4XsmFt2q9d3
gVItdo9byoF42boJMelG7Fp5Z+OeXxRcBwwftW/tQ1Gf6Trf9lEo8X1b7J3f
gCdlSjMixA+1/Ooaw7NIvV3XmGXI0RiLl1VY/LIWijEKxZ6JbPALbLWosyuH
WXbT26lwClyRHlvVH0VjYuXCix8Jz1yJ8K0LmSjEU5UGvQYuGn/D1SUr7rfB
eblo9qdiDvg2J8zYfikD42TbZ1klGvsSDw+019SibLFQUPI1wgO3fKYlztRD
dF3ayFpjDs4vv1axS7cUTbdeBDfpEH742LwkptILLofXXjqyloaenoZUQG41
CgSHhUQYpD5+G10G5buRYTx3w2PHKEr3Gmfu9MjC1nh75j9baBirLD0os70X
19Lcj5ccHob8uOLRSKoT4fvcHpiYc6DN22ZipFSG/nXvjZtyKejmO7J0Y3NR
qb5txFeX6DFF6u7X/BwsjBo8Z1NKeC6ocOaFTgZWzHRoh5P+Wy73dvQc6oJZ
0n1rh/mjmKyvenj6UzaUldJ+KxE9FDj/JyMcxsRDlfZ4L5r4pamyLW3WgWWZ
jjM9LRz8TJB/d+puBTRXtD0LK6PwjpG6/j/eVqwaUf7FQ/zaaknE7RcNUUi8
smdVPfELne+WzkOOrUgaPFFh1Uvy5axG8+PnyWAvsBiqJDzz/WuD0iPxNhx6
UCVYzaZxfYnX+hM73mFIV5lb+DINheQDAgcXZ0P6JGdTjhbp/00bFZuRUEQw
BdRZRJ8ffANjYgaYGAu0qpHXGEVj9U0dv/oWzMlvvd5I/Oe6e6Bp9fEeKK03
85mxI3zFEBi9Z/sef7av4D0kQur1fdlp/ceJELPjEwvdRWPjMR3BXMI3I/+e
OCX3mULU0hyvaaoOgjVCn0+HsmH6druAsmUdTo3fZiheIny8dMWYqUsbukZn
PG5qc3DF60+V4t9GbFZtWtYSR/g78rS/gGYCpE4UxRoQ/U7++vEgs4MFqbCI
9RcIf6+WM1QNPN+LKiGOTbchG7F1Y7R4UC2+aoUKniT/BzJn5gZjGxDxunuV
4A0KY0JiYQ8uM/FK8vng1m7yvp1y1TkJ7+HCsz3HrZiG6D7TbOaFPsTP33I1
i/ixtDZj+aLHlXDa4mB1gqKxXWj5K4fUTliL/FlikkT46z0r/khkEzabXzhQ
epL4n2772lmBPkhJ732n7Uwhxec/oWe8DDieO22dMkpBJi/612XjBjj2s31Y
IaR+cQdDKn9lQL1m1x8VecIjSm57zx1pxYkJdmnYdrIvOE4NrT+VD13P5l6F
DTSSYvz2uBUWIdLnsfyH3xTCS9aedl/WAvXwUq3VhG/S67/xmiiUoluysOfL
IRo8HNHugvpKKFwRswTpj8fNS889RcrgyF2u8vI/ki8bemet3MowhgWDfGR/
S1pXcFa6MhNFggvPi+rQWLDqIm/T00Zs+bgy49AWDibFp6olDrTj1FpXrwyt
ESxQ/mm3bbYZDnrjJtMPOeDKfmO84sx95IWItDQS/s6c1pPPMGJhX7ska8My
0t8fvJOZKz8givq4aRnRk6aCxiPt2yw4ZKoXJy8hfHrPTD8hugz/xX3KgSQH
/LC2NlnRBFF/pcpPhB+2BKmp90p/wFEJ3sUBT2jskvVcI6NdBdlU6Uvhryi8
GVxeYXqtDuY3xUZ+DJP5Wiwyl/zgNbx8u4rzBWjo2/AnblDqwT/xMq6sPqIv
0wOPOve/wsXWWW9zomeuPXymP1VOQpW/b/cpkq976x4WOwh1AEaHNx4g+9dD
LeOEw8WleOZ+ct7RSuJnKYcq7fob4S/sOvWB7Av+fKa2+e3Z4Nv7pCee+Hnv
dsUpC0cG2qxHfQ8N0jATvvOmbKoGC5YkOu4PorDz3GXFbv0OFFbMGxv152CF
uZhw5AYmLpxdpCg7TfZljhP/2vgS1Mk13l37lULqSYbSapIHVdbdemo/OYi9
u6P0Um4XygX2a9+yHwGjIvrjqt9dyOHRAi/pl1VFs2vpeCcKAnVGoo4Qnkn8
89WlPRCmyZbGkmT+V3kPuDBfk/3FfOLnedKvGwNi+zYLMZDwq32pCsn/9N6D
7vFdBdA8SV25uoLs5xIjA+LzgrFpf8QRsVU0ZGbfFy0v7IZDjXPUQmk2fvpp
nPC1KIBtoIKM7AwFjUC7mvxdrbDKcGFHkjxTSSzfpv3wAz73eW1lWBK9PvGN
Fx1mwjJvWqRLk3zvxwwed4l2hJo4ysoUkXkTfe0xHtYGP/vDWRe1aZJDa4Jr
CC/zX1j5N8J4FALPqnStrzbAu8Nc67EEB/VuxvaC21uwpMI4ne1E4ydjcew3
5woIs9Ipfy5y/63G76Of5KK8SjPcWoPkycCjmvzKClimGiUnEH4vOj7mxWvZ
Bqv+Um190n8tPmp+ME8Rzl8/mc9N5knke6Toa8d63BhebZFE5nEwxeOAF18n
9riljM8uG0EOY3eedHk99i3ePHkplUaD82GHtpIyZErlTNTto/HSb7Oqqh0T
q9h3/PrJfi3uSl83qSiHvfjdM0nPKWQmhRdZOHVBPjax+5schZ9L6tz9/2nE
oYqgPVkJpF4Z9YY5B5kQd9rvkkzmo/PuN4va2EosHNze60L4W4NHJ0lqIRNG
jakmdoQXzmqlq9ifrkGccuFgYxvJc+5s081eVniskrtAi3xf7aWFb5vUe2B9
Y3c03wMaH89Wiij+aEHvroWNDa1scKQO1HwSq8Fq+SRp4bUcZK4qrama14Cg
O/ZwyeLA0dI3bVF1C8SjHPqXpNGw0l7hIJXXgYyGWwvVG8n+syFaUNShGYvb
B64ahtNYopRgMrmFgbE/9unVJM/4hIO1n/BXwcD/mKNaM40/d3Q1mRs7sKPp
gIkS0bu50baEGal3uMJrdNKE8KVSvBpt/zQGW48pZP4i9X/gkmKwkyqEt9zN
eM8JCk+ntyQ9FaiD1M71PweJXn/u2bgoQL4ZhdT25ztv03Dky6p93duB1Stm
hCbJfjr3djzEJqoD/b+5Yw9doeBy9vTmmTsdOBcg8lGvgfDnbUf2Dvcm+F7O
7z+nRqF5bWK3O9Gj1+dFOnVb2HgSXuA1HdMCjV2cVR9E2HhsLOdDnSmD5p8w
vZ/K5PnnRfZ81YnFwiU5jqWSJI/FddaeqGDAOzDiZFUYeZ+xnR72ysQfhF74
7DxF9BlY66M8V4FQQZPmsG/En0+VhfC/6cRlf16/3eWjENV943BpVy3mhYrn
e18g8ye3L+R4QCLxSemgULLPFPwQWPeArwMOqSN9FmNkXo8a7l2UF4b1VpYH
5AhPhZ1NrOR/wETpXGJ5x6lRpGf3c4XdSMPo347ldmRffWFseGtIswAPjzTJ
vSS8wx+ukyJa1IqvWzxU6k2In9ix6uZVtsK/6a9yxE8abxJVS/LXlMFJcUTG
U5DwmuOKxLmRdESZB7f9S/LQX35CQjmNgXvxU+UlNiOou2TC4/2yC+a7tbKV
xofg/0bH9Ut4Ffwuy9qL7Cf6Wca/y3aqE+uvlWlGGg3C/+HnKu0bKXCxeBHs
spDw8wvWrXqLDiR8j7DrX014ImWP8WPLLGQmOH5SIPtF/2IxieUeTYhlXo6v
J/xz/OGZsvAUFkxnD6uoWZF68uWvCXKrxlnPv/29+YRn9nALH/Dugvom31Q1
vVH0i8Y4vZn4AMFtO5bPfSN52SfCFI5MhLDP556ZPxRWvE7oy9ZlIPLTH0vD
Y4Qv9CcCpRS70dQjZH29ZxQMOfkdGocyEW+cd6GYQ+F/uTz2IQ==
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs01IkbxseuilKYVFus3IpcSqLk9iiS0MqskqKbsBERFem0QmsrRZEV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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs41IkXxqfpMoUs7bIqcptSUnrqVxH10kVqKRuLrUmUEtuFJoV1mWxb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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 159->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk81Fsbn1BRN6YuoVsYKUtaqAjlK6FSIdqUyrWUW4lCEYmKtBoVbZJC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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8Vf8bpxQlIaOsjGhYyUqJtyQJSUVJKkk0ZJWSIhoqkTJCU0ZZFSI7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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81HkXx9FIVKJcIlvD2hoMxstWUvnkkrYe9bQRSTwUSy2PUsqTCLlM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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVHs4lIkblbCU3FKxqcglSrY0ZBXHxhZl3SK0j5bkmnsMtVMss2Jdoqsk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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 160->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk4lVsbxjcHqVPpJOU0ODSZVVJJ6VaIT9FgyhBRpDjmoVRIKfWhzPNw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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VW0bxSlTlFRIikgyRHlFKCzVm4giqWiUyljmpHoTKRmiUplSGTJF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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs81IkW9yi1GKtuEWqkbFKxakXTWF+iB+khMiVZr0rWhuTRlceVNElW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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlG04FIgWxxElRYpaZQnZLCV2UhH5hxUql5H2Woq8F3lPFGXUVGguusnL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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 161->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk81ekbpYlsJRFto1HWyZIlSnQwspVGUtYKbcwSYkyWikaWGEmUbAmR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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VO0fxpEliqSyZElCosUrpbc3bmmjKKVFhdCiIlu2NkkqFSWJFltl
jbJEtmQXY2cwlpgsM+cMJUVF4vf8/pprrrnmnOf5Lp/7vpfau+w7KcDHx2fD
z8f3/0/t+YNy1sPPwd4soNmlQGNt849Lw9YtGMuICyxS4UH2kVXOoEwOSlW3
7eeup9Ftdio2zrwD7nVzh25O8BC75dlA6dw0PFM8O+/bYvL7z1+Xc9nVEE24
N6VQwIWP7SqNkt5S6HXX7DIOoXGQuS4yd2cnEk0vsZyu8WCZ3errkM6CZP++
hrWqQ7ANy+B16+dgyLb6eck0hSNS17y81jRhdeWkEec4hZ4g3WS7Lyy8S6OX
Hf5KgdYfXW1xphMW/osUTt/ngq9bavOE8UkEPEw5t1mFxmw37/d+EenQPHT1
+I11NJIuh99of1AK5TXj4bsu0fjdGlO9X78b5WPjM+kbOHi8eKWxdkYK7lMB
Tib/0Mi98njo1/4PGEkaGl6XTqOteodGsEMHsm3FlOsqaNxZpk8VnavDd1Vv
I+4mCj85V5YlBnfBKF+pUFeEh9ma94crv9VD6ZOUmd5cGo1d1fauqysRTjck
/7eVfF+i+7Pgbyp0uFfEQsl53z3yjZzrWA+P39bH2OkUlIvgYFH6HlZv1x2W
vU+DZRbEb7KvFAmR0gIrD9J4z5sQDeFn4r/rzbIeShTKvXqNQj43YscH2S7P
H6Qew5L7HFsDMDFrRWLDEnKfkFkxv0JTEP3lJTd1Aw0vzVbpl6RffGnV5vMP
UwiKOWLn4lmC7le2o73GpH62B+wbDjWDM+fN9jvWND4cyPn33WgFRr6HB6y6
T0FywGYL9pTB92bP880DNAKuGCU9z8gFtbu0MtibRsEHRfE4g1L89LhRZnaE
xtYKt1NXBJvRNz9zyH8zDzYbPq7aaVuM9qpJkQ3vaAy4HDlyKroYcxuvqSz0
o2H+cYV4bnIb2kLup6WX0Cg2UbpcI9EISwfmHmlbCt/UhDOXHmuEliNjya9A
cp8fAffjvnThmpGpYPk6DpQ/CS0a2ZYIu0L20WsraLxcYxTluJ2FC0Vx13eQ
ep+tkHu9T6EdrvLs28rRPPxuXjW/vakdsh71i5oKOFgkXK+1o6gTp7v/8H5u
HILyyrQFohkfwJz6tZrvKYUPZgp96G7GZRfbbc6VFOwvvRhWneyA17qCB3JM
GtOrOpM4y5tQ/F3z84QtDbUtk4YzmR1IP9N2UPgZB9TLS4nSSjW4k7Rv9VQk
F4ZyU1NO7uEQkHfMGtegcfLQuxDff9rAUFhzOkOTRpjUKoE3X+thcMxB0mgZ
jZFPpQq3Z7Ui7sQl90IpLgL7RooZVU3Y2BtSmkfmUflB8nq92y9gvvi8cqY4
mReXtYJhEd04667/yEqHi8h5Bj+KllWjXHPAKyWC9O/seYNh8VrUrlC/rqRF
w+CSt7u9XSMa5+iOXz7ExfHf2hYCCUz4F6X67eyhsNXt7R0j+WZk+LdXWZ/g
YkfM4Yz8KhZWfK1uYLVyoZufEafgWgf35AW6mkI8XDFqos2tAqEWpRZisJTM
c4X1AF1YgFWTS0RETGjc/Fd7ieRMK55vf+A8nUkjyzs9e1l1E5Yoy8zmfqCQ
5CSuaG+ZCbcIrX38ZJ9cV84ye5tThvyRjR94ZD6VrENrzP42wfQ9n4Z9GQ0/
A1bgf8YuOCVtZPaAvE/JrOvxeCID6ZuqG0+Q/1d+i+9afpkFKX1BUaftNJxd
QjJdSpgQyBzuEflNQVOy7672ZCui/zqfiBrngb1QpXbkYgJqi0JWXiJ82N3f
djOvsAv1K6Su/pw3iKAdEqkB7sXYP2AXHfqF7MfmFBl3l0rElK/5FplGQ7vq
hazC2m7M3NP/1VXHQZbWtZBtZXXQuaOqr/OawsSlmNgo5zYkfL6gYNJHw9RB
q2WckQwF6R9DertpKKyuPBmh1gJDfXrUMpbss2L8nsM/C+F0jiOpaEmen7jU
YG94DjyM9/7Y5Epjxv8ld/GiRvSEZc5hSPBQdev7y2iHDMiUT8zYdFGIPufx
4x91Ji7X15Uu4FC4PJ/yfeIWD2qg/ymtTeON87Mgtl8HPnix60tbaXhkTlWW
fWKA2e82/tWZh77QysuxC0rwXVROK+kcjZV0rIVZXh7ueb5iJhuR81Ue1g6r
acDrreaVJl1czJaycTB6XYnh98Ktd0h9bf84uPRMNePGgNO7O2M8hOwPDWWm
VSHpalYfJ47cV8bLI1i7Bm+omcxdUxQC2UuOKQg0Q9CNb0PRSnLeQwsMHftY
2LNATayP1ENj66NUv7o6vDiqJpJ3hYeV27QkBRY2gP/lvOqP8RQOLuOnwk8z
EOqSb9DcROG3vTR1MZcBRmDFxaM7aLjnVHYLEb7PMOWFvR9z0T2rRmugPQ++
kmdYCYdofHfuNJK5y8QjTzPzsX4uZCPuXBOdk4n4bbkcyXoKIcK6F76ZpWNh
hvR5m//rzXujZSuEq/Cvi6S11TThmbaC/mP9clSKBHvc51FgfDda1HWxBbxY
n3pvYS7YaZmay33eoul67jeQ/Wd5un05716P2X7WW/8Qfgy/nPVz78pe5Jo5
2sSofYHf6CvfoaZQOI0P3K9WpLFM3K8t+3AMTK8Zy9wXoGH76K9L+MlPYHAv
NAaOUKhMPFbgGp8PRbV/s0cMaQjaeYnCpQKUjqjKegaFKf6bp8Zet4BxeQOj
SZ7CgFVeusxgFU5UWnwtuUf0d7eBz5vZjejvMXiwQ430V0jDdUwpA+f9rOS7
GimURDdpXNNoRKyzyUFGNg3pa/NNHhsxEfiK80RxLRee6iH/PDbNhoDJ3dKu
nxTMpwxuBa2OQgVfWEE04dv7VQkdfkM9EM+ZEduqR8PH5c8zCSuy/5weKTqI
hxeKm/IOjJQi1y7Z+Fw8eX/D0pRKuV6c3m7coUv07FxQzMjn7a0Qy7grMv86
B7nbbwksDmzGWo/hqaPnhrDQFdNzbjYhUaBpaAvR37mKkgdZPh/hLOS3+eRX
Gqe3fU7ofJoF29i70S9IPfnOsJX+9p2F3HGjzzZELxqFYnS1YnPBX7/PO/E4
jYXaQrreghVYNmfF7sEWCuLFnDXsglboL5cWOfOIA7GQFXc3OLRCreDTQuFd
Q+Bjb33626sUCkdzwiyJv6FOrNuuWdMGbbvArbdLCc9GzlZ1PKnCsRdDCa8i
KPjeOhHnd7wLR7n+/YsNeTDUKKBHntbB53niRJg3D8Z9h1Tyfjdjn8zjUnYq
Dc3kc38VnzSjkm0wqED0XKNXQ9tkvBV6KZvddYlfGAicvujZ34RwxvLY/HuD
8ON/YGhq9xhvJe3WNa2ioU6vWc4pb0Xgl3mRLnE8BEoWnhx0KsOAmNpFrRcU
imcExHZHt0BwQirtlSEXTy07ZXK7y7H0wvTlFg4XzAvJhZdLalGgsU6fRfbb
L2rvZJOgL+I843VLSD0fPunfR4V3QqyR8+qjI9nXhSnnfcfbYB0fedjbgcax
JzEiR6zLYaQaXuV1g4bxR5m2GLcOaGaNjG0o5GHYzHjj8elsxH+8tNV7P430
P33U5HYGtILyb4wUk/24I9N+4VQbwgZ/cJN6aKhOuE+nZifAqYKlbyBPg7li
nOsn9BHG87NKuhwIfwoGrs0bCUXewQxFeXK+sLMHctLnvcFUxE7RCtJvoboZ
r/0ClTC3sKwLJnrR3T3aG1TSAOatOT7FT3h4P1LOOB7LhJfJv+ocKy52n93W
2m3YAs+N8p7B54ewkis28Ke/AT6TeiLdc2jsfJbW+dymDZ91GGt08yg45WvN
Cq1qxOKrgdrEzMEkX9e2XJyFr8HxFdH8PLiOyomEnYmFcezgTqFFNCxibyoG
tzEQckP76twXhLcpv1tXbSZ+XCQoZ/b9fhzDaORem1ZIF7Z6BmZyYf+w7Awd
UIbiLV629Z+J/3Zv/BA92oSy5QFn1Ffz8Pgj+PMvNIB9cFLHQYrw3FNrnQ3h
e5/h2B0Oj4v3ncuXR1+rhW/Ow6fZJ2gEip9YE5vQiI0DFz5d2clDrmW1V5TA
R7jP9T7udodCrNGq3X5eHzBZ8kKWRXhjqTp+LfdyC3p1Iv02HRtCbqTVPfl7
Nci8Lz8jF074QzveWzldiW/W716mJNEQ/u/e8ZrCbsw9n2q8S5SHV2k3M8Z/
1kB2nlnq8iUUNhYEs2P9qjBwLjjekviZV8vEJCQnmOj/tFZWopPGvj+HKvOJ
f4uYOe2euppGf8bT+akdzWAfzd+7sZDw1DzgqVt6ISKzJAu+7iL+yBlsllwD
/Bvfv79wkOjLpOX6Pek9mGFtOLwvl4ekY+Z2T/rioVSWHaKsRGMqQ8BMZ3s1
NMp7zzeT/KCxQX9u91QHjluUDD9hDyPhcS2/fFYL+LzTbcoKiP8w7BoYTwvA
U9a41gniP0J2+EYwg9JwU8LzhRjh1cCldwqhNp2YkAsM/21KQ+XSdxWDXyW4
f0DXtW8PjQ2SKYu2x7TDKOmXoakP8Z8WHacveL5B4Gmnr4LEz3/pUlHeO1YO
61SHPfmhNGTNuoTmZZaB1VOacP408fMHNfVeyL/HqXIL1vHPFHJvLktdtT4f
vC9HLyqQfY+c6F/5Y7oFtWayeg9vkH79OacyVNwBnv6WzDvx/bBaISc86FGK
UhURfwUroo/VDQ+2Lm1CIKMdt1QIX2YeBy73YmJbnN3W4VNDWMZLCGzd2wad
bQ6WDVM0GGz1Czy+Vszr6lp83nwI75zmv/0W1A7f2aNJFg+Jn/c++P4fmY9I
2tRbdZDwP1MyPWVPdQuCKovDFrWTfQl11j5p0YTavEhlPZIfWXM2+P6xaERq
1NAP5bdc9DjExYmndUF9TaT5RPcQXE2nK/RGQxCwseOZOKl38cbqHPc3hXjk
OnvvYeJPFMbH/FXUCS8dJG4E2RC94Quy3Vmfj36xZ4mbfAnfOn2uCZP93XBx
THNXAo365do7WmkmNq/9m6vawcOjkQc/CoZaYS46u+/VMxpBE2eD64Wr8ad2
4vr9A8SvrZ5c5zFWiTqXsznGBjTGen7+3KLLgsQH/qjqOAoBLx5qVn7pxp5H
nFvDo/0ocznpqSr4CW+Elv3pu85D0Nh4zN3NLTi4JqbfZAcXH60HruwXasGi
X3VfAmYRP2IyE/hfKBN+fpmKs8R5KD8qdz/n10ck6C0N7yT7GN7teEU9og2p
WwcTnkTTaM7d5LhxsBMKtROmqYd5MC9TNWZPVUFlr9WLBvK77hobob9VNWAM
n3lYfofGrLa2OnXpThwpE5c694AH1hXK8rldO7a9dWBOT3IxpcX2Lt3RgrNn
RFcY7yB8O/AgZGwuuS8lcb2W+AVtD/nNtwpS4NRw4MgpwlOxz5vX+vkQfvvo
9L625yFg2TXhP0FtiLUaeB3/lYufojfym281Qr11n1q0DQVZrQDJCfcG7L6a
0r74CDnv+n9V55rmwkZ48UYNsu8qucL2QXmVSMqL9X24h4fGKCPhCKkGXPLe
Ie03xcXK1ap9hqFVWK6/zsTbn+zDwkUpq7PfQjDPfHcui4Jw7Gv1VkYbQqKf
HakpIPr64N93EQsr0Nx7SMbyJtGHfWNK1wUYcBaUUYrJp8A2ijm24EsJbG/p
SHLO0lCWlWF09LtB5VnUPg6ZLzEl675fi7uQaNIjYl49AGXJ0aIPfC1o1FJR
ekt4qnymotTJtQA8AfaP9GYKzsWPIgMTmzH5yVTnKeEVn+vl3e/k3uJntuNu
fZInGOMM7yuhrchqjpN29R2CwoIWjfmxHdDt1RD1jOBAIy5qb0M1C9S0haGZ
4wAGlLr8yhZVQzyt8ZDEE3Kedhf7t7eZ0B3vza9x40K09PTrsxwWwhztVlsN
kPl6+flXTVg9Is/GCU1J82Cbmc33sPcp+t5ULa2VJnrpmDHke5vkNz29V0e7
aPgnZ6199U87TBb77jUj/bj34OqIG3m+cMehU33nKXR+Sb9ood+ID8/YwfJF
xD/R5U/9gxgYr5s2SSR8E5QoUJ0T1gw1v6UNusRfaX//IaGuW4eSxdaDmuY8
zM4Tzc2eKcGmxPCQyTqS77QWZi/RY8L3sGJMnDkFQfu6bim3Imx82/mnnk0h
PYG/M7koCT4pf29JkDyf3qxuJL6uFf6ckFPdDwdxuj5fe6NaKZqjTA0NiT7G
jSlEB4YxYFpYuSWO5NmFUxIfuJrFqGQ5f93yiviFuD3rXa6zkH5L+mDoLh7o
sjk+yddLIbVrbUpUFQ0e03idh1M7XLwPGr0cIXoT9Uv/Ca8ZRV+n+FeIcFA7
mG6wdLQR31auZjGIPgfqT/42jHiLGv6AtbsIXzzsTXdWiDXCvjBUdfdaGr+P
2vvOiATjHTYFL1SmMc++dGvShTaoJuV3fS7loV6l5vFWcv7BtlLpzUySfw/o
vG9a3w3XLdPJE7OGoCNnkt21oQtD/n8PFKnx4GN9iGra1YQs31rVnWSeX2jP
a7DVbMGowKqFRwivdep39/J3MNHndqo6fifJexeP9PlHdiP72OJ3PVID2NRF
j0x+b4K6sqyWLU1BpyztynHC3/f+S5bfHuRC+1vVm9kkH9rmmDc36VFwFeby
F5J+6QnEB98meXF0xX8D8tfr8fiZ6I+8PB4UjP/WHf7cCM75NT1dFBeBedIz
PruYqD1lbBZE+mWYoaLtevoBsuKF5gaS/MC+90/Iicdl6DRaWjeSQ/hx9IDG
NvY7aF2sb2nroZAw61Jt91EW5DKz2m9u4sLKX0fO7lQxZArvrjdto6BaezWt
bLAZbvLJm09t40Hze7tY854OtIxdv7p01yC46q7zjmvXIbSp0LDAiAfZhN33
Ppc0Q8fTaMVhbS7eRHQ8jGpqwcsN+2uvk3n3eG6YO6u+DBpRCw+EEB4dXpDV
/3E9E2yVvtJnO4h+/lNwm034JZjmNzFaQvKUv4FSH68CHJtjRqtIPk3XullU
kNwMynmVQOQFLs4pnpiQMCmHwSYNg/+In2Vnnc+8nJCPgpds71cWRC+ee5qL
zqmB2sSQ5WsyD+Ud7cHjBq34+901da4HjdmO1TdMPrZi/tyLd5eXUgh1m39v
8fFWLLqa+uMoyfcRkwYrfRq74eFduYf5kgcdn5Fsv+AunGE5hdoRvv8PaNop
7Q==
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVkms41AkDxSfZkmzpKkUuabVbK5WNEkdCxYQm5JIu45KkSPXm1ZDXPdYl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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk41AsXxyd5hCRSjWupiKIoI++0aPqqi7QoV7ZyFd0sKa8lFb0ZpHGF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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 162->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8lekbxk8NhSHSlKYiYSQkEb9jyVW2yBKyNLYWkWXaDGkxCamTolBh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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Ve8Xxa+hVFLKkAxFhVRKQkIWJRpESYokQiJJCJVMlVBJJSSVqShz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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs41AkXxycvUrTSo3KJklRDMt3Uys5XYQvblnKp1bTposuTtCVdZN3K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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs4lAkbxlFJJHalpNDYmpSyTqWk7iiHpVJdhUqzWIfR7kZRJMoh7aIc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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 163->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs4lGkYxh1T7W4OK2k3KaciLJEouRUdtEiiZHPoXBslJWxhqCQsWodI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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4lO/bxm2lkB8iJURSkeSLSgunUpKlFKUIlRZJi1TaSTtCaCXZKlki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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHk41AsXtiWFyr3qukylmkpCZYni9o4lKUuiULdFk+2TbBGVhnBHXaIS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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs41AkbnVy2x6gllKwUm3xdrIYtbeE5WtYqWnf1RSJJbYtohYxcUmwm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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 164->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs4lOkbHmWjWKdqI2cK0UisY3R3TgezyiEhOeaQKCI7sWTLdlCyymFD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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8lW8ftkKpjOinKaMioyGS6JIopaSFiJaMlKSUoggpUshIyKqsEBFl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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41IkbxV26oFhR1nYjI5cSKTZFnQkhlNu06boTCkWy1kZJSrW6q2R1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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk2k81AsXxydRlFRXRXVlYipF2uSWW/0sXakkRYu1SN08FG7KktAkIkIU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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 165->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs4lOkfxpFVFhEdbEXWYVhsJGEKdwnZmiRLK4dCNqXdJMdiKduqhJVW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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHc8ld8fvxEpKommr0pJQ0JIRm+VkUiSFrITElpSEUkqSsOopLKyIpK9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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs41IkXxvELEbKlosv6haRETBOieiW3JqFQuaZ7bVZqZbUqdJFck8it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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs4lAkbxgfZtB2/HZFj1OeQQ6uIMNyZ2MpKGj7RKsoIZdNBS0JUK1rk
lK+TopCEmhppy+cwzkMZTBhLMYf3fW2xNqSDw873x3M9/9x/3Nd1P7/70T8Y
zgpSpNFoUfL5/zZ23SCjrxEi9henwXcrZWjxaYzNiurE80jjsbw0GWgJMzqZ
gcVgpu4djThO4dX/3LjZ872gghIVjMKH0XSWHhxo0o0DorgMfzUZGgTlL/fH
dMNb9x3vkq0UeY/LbV7ZNyFg1U5zjXwCZk+G9QJCG+FjZ5nz31oCtRb3pkTT
PJwqb8px3EKiZd7j4uhINw4NpsWc0pIg/tQ8o8evB2H2sxExLVJkb3Ua1VzQ
Be7ifWfITVLE+K4S/lXIA1NQf3uwigDN627yl3X56K+8e7CihkJm8wmaUbsA
w7bjKZetZPjQUbnAyvQVDm+gjRG3ZXC/1bLyXEAz+NGF38T6E1DJplu3l3Yi
qpBZsXetDNu3DuqXqT/FPtMCkXcTCVflhmRL9XZEzoq2uG6W4YanjvFi/QGw
Fdj8+ktifPdb5pjJ/h6EWKa8nF0gBn/GW6t18jUmX4vLFR9LUfBxsdHV850w
Xhqzq0tbii/Bv7aZuwhQ9TBbdNJBiviRn+IOJhWCtTW0ZCqDwqeTxxO25nTh
he8DJ2GsBC2l8/SMGCFs1nw7YaMpw3cGJV7TNwfACzqzZLTzLTz4vg2zn/Ph
IxH2h9VRCFloGJfCvoYu3tMdukIKBd1KLO77XnAYqWZvi8UwJi5kx4VXYtdP
e6ra1Cloe7nkflDuR6Oird1rCymGnvkRudmXUJtk63lhhgJtIU0lKO1nSDr1
yixWjWBmZ2hpfeIjMLfQGFrBFPRCKquVe19A2uh4z4hD4pEk1jmRV43QNLrd
YCOJYuepKtZ4K9QnvB+as2WYMzxxgrdhAF0xP6y9cXcYf1LWRd4B3bCyOLow
fbMEjAhyNnWiA15L0+M1IcOYmfjSwhEhNOgbHbINZPhDU3wjY6Yf4Y99HHwv
SqD8NSdvSu8NynyiP5/8XQLqx6yCBxrdqPs4Vqx8WYKQzCXmOasG0PCVdbT2
wBCK3WN9Sps7cJa+xmL6tBQBP19WUlVqxZujB5+P3ydwRNU5tF9VAHdraXxi
DIGGmKm7q017cax3+YppVTHctrGG/HdVYEPqTiU9BgUVqL3j+j0D3yljjt5H
YijrPJnFL4XSmfXH5o5QiKgutFz8pROxnO5Fn69J8EiUFVZX0gnhYPlK33oZ
BI/Hj0x2cuEsWxOnpUqh3J2MZZACzC3NGHa3ksKV7eNpLZLzwGv8l+YmCY45
6jnv2F0EoXpPq9ZtCm7nG2yLTvPg0WtQ73+TRNh27YsZat2QLt83d2JUrrcs
djNsyQNv77vxMvl9MFjnkirdhbAO+/GJG0cKw77bJWaHujDtOqn9dYUMKoZV
jHOaT3HwiRsRZibP/+63b/J3eyAvU3mesXoE40Vj3ytk3UGV9jeJZBWFiUMG
J0K8+mCzsXr1ZXmeEYeOJVxZJsKkqQafOSQGdyxFWbWpHgnKUZx5ZRJJumGn
JBF8FHMPrbvlTeDNaTJl3Ww14oK3bq4rIbGCuWLcXacUuseNZiz9KLgcz0vy
jOTBRaXYV9+exKKp9fvuUQK8n7A4XhQgRcSQfbqVwVMkVmjZ2XxP4UKFj01G
aQeIPV6Ly8Zl6LqVL7wqGcDK354ozgdIoOfBer7LvwFhLkWvHP9D4JWn+dIa
6wHouKYuc/Qcgl4Gn6vxsQeW95Lt3utKEHVdkR/b0odz+cM20VHDYNJdnaIU
hLjm0Do1OiaFQMVxYvrME3xtaw7s/ErCjxMmWOY1AP7vND+DZ28R+OySoLKy
EWxffeYVDwI+GzcmlbHakFt3nhPtSaDKk64W3NcERtInl4JIAkTI27Q2sdx/
e8WSIjUCF3Iu41f2a6T1KsQwl0nAfkDP6+2sgLe+1dRHMYmITwscInvqYWc6
N9DGkfdreO62yqQ7MDlyYW9ovpxvk1FmzY1aCJdd2fbAlUTI3G7R86JyxEf5
J3F+oCDMTPh74GQjklMV7EoWEgja9Mf6X0gRXN1XR+84LMH6RwcSlyeXw6R9
yb8H5fq+XLhcTH6Omycb7Vl/kki/deOtQ3wh7N7XHHa9R+HqnrNre2oqYJ0y
kh79koSO8my1d/9rOHsV+tc8FEN704uGDn492JyLn/PVSPCTo+7rWnfhZbg/
w6pXApOu9E95c43oIJ0NQ/zk/X5szadADg/clzKfqkQSfcYKuVMaIpQOtWd/
sBhGrVIQFVjVjJol9vrFowQGxNuu3bRtgblR7p1qUwJ72VMbDtcJUbP7r/vN
M1KEDVk/oxYJoKlYV26iQaAlruFwQjkX7L9vle3/QqIgKG9pDasV10V9wbR0
GUZubq8RFnVhbuWVuYBIKaT3bZyYiZWIVkgMuL5KzkfmZLaimh9U4lJ2WuqM
YPPQg7OGqgVIPq3irs6lYJZRkZP1sRaa6uOpI/J/9w/CrMqQ
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 166->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk41Pkflw7VhrIUGkJWSFi1thQvW3KNjh+hFBXlmA5KIQrFppIrRywr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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VW0Xxg9FkinKlKRJkiQRb9RdEqKIpJCxQdFb0WBIeEVJRGgkEaLI
kFmEjJkd8xSFY+9jLCoq9T3fX+c6176eaz97rXvd92+ttr9gcoqTwWBYczAY
//9lXI2xD3trgRNRlf+OrKYxFPJ3/d/iUmiFPS5NN6fRFSgmwNvQCaVLwefG
JWhMnNXsy9Bvh0yIUIla8Chmv+zrK1PIAR+HVfd6ARo10VNm29a3Qv7pqVjp
Sgp+bL95+32VMN3QNTSlRmFFFN+a6sheeM+J0varaHzPMK1IjuqG2RtLMYFU
GqHXdeNcVZpw+pEJ46g8G8rsN7g/2Aqhv9N+bQrDsDj/zdo8owXRizZrTilT
8BTTNX4/3Ikx9/kVnduGsUdY8+1dRhM2ydEhBe9oSOumMhbzk/uOLFmSemEU
u5s1DvfyvsZd+aZCM18a8Ydech1d3o6cYFd+F6NR5BXttrFZXQCvg+yrB7ho
mKQ9P1o7zsRoQejkbU42ZIwbnFyUulD4gzOw2IyNfa8Yz9P0muH5dGPD1Xg2
WN9qewXDWhDha6rRHzUCrxMedcf8O8CseVeeY8UGQy3Mt3R/DFxel3tVr6fx
9IdQR2NQNt5Udb81/0WhqWfQB2ef4HvLuf1zMjTcIictKjbkQ/LJscIcURoy
z9/9kBAIx34JS92EtTREVY+oiot/wBKxcb7MPTSCfGp+Rvk3Yfni5ZTWcRoM
9cJ/D/maoj+qU4x3DY2LvG/lfoa8BctwMfgW0fANjNp3b6oPYwmj7jUlNB5F
2llILuhA7NLWTzvPUNBZ79l+eG0veP8Zoe5TFPgzpOIGrpeghyvj3BtDGrk8
ThdfTLfAVdY5/7kHG3nBZXdWT7YgnXnbKlyXgus/OV92ZrQhsDzeLuQlG8f5
+wPKayrhmHbO4GsWhe8S76dM3ZsQMKbtrFZJvs/xcpr6qnSkenFo6MmT+/Tb
feXobMTKh1l/Vuym8fFKdlaycg3Sx12jzMZpmC0VfcKe70a0R4AWY5iFg1UH
PpTXtqBclW/skzEbtk2BNp5dyfi4bhfrPieNsZCHir2/MvD74N/EuTpS78jH
YWszfHFzWGrCltRnpaWnrZFtL/Qa8xqfP2FhyMDo0J+wAizyiF7oKUJjR2Kx
tUpTF6Y5/T2Sl9DgEVStUbEqAc97Z2XDJArnQmdzrmx7Ae/7Od6ysjT2Dkom
8wm2Qmxblk3xw1E8MAtYmH2yE8XCe39uPzsK1wCPWCX3XoxFZm+pW8nCujRn
2U+XSrFdXaXseAWFko7fraXcCdBK1Nl+g7yPxbS2YBY3Iea0vsDBLhop74wF
GM5MPF/lfOKTIxtBcg+FAxgfoBI1KaV+kIbjylXpimfeY3pj2L6ijUQPd18+
yVnjDRWf048Uib48Z5XSvht34a95u67GYfLc9MS8dbMuFvpes/pB/GBuP6xP
ibVhq5RB/5LnFBw9vf9czO3E0QqxSF51GpWN+iIiZR1IdUzy5a8fhUyhwDk6
7h2Wx0afeLyZRvnAk2ue0a3YE9u7cnBoGD7V7GZrtTfg9Bfff5WDhlajUVXg
uh64VHtzhjCGENO0r89g4xs4Klg8fyxE4/JFq9DdFfXwS+6NfmlLYcCqyyVF
9QMSLvc8HC2kIVdhMd2Z1gb3wWv6Xmw2tHdGz/BrNWEZRxWfSyAbChcGTOrV
2pDGrP777QcbJt+s4u3Ga8HVPqE4/pmFj99vSh6uLsdFFc0eUV0ao8Hdezpj
29BXqTQhPEfmxeln9g+1OEx9/VbG2kGjPei8BN0VD173l2oW62h4x0ZLX7rQ
BDn/y6re3yhcnr1js1yyFcetkoxCeGkkrVpXyyteBZPaT27lnhRmzUUtLGsz
cZHTj9uN+GuvOb8THZcJDoFzVwRyKaTw8XJv1ymBzlTDrQ3vKcwMNUfL9VSB
KmZt/TVIQWbQ9sfk4iIIRnVGvf7/PO9RN5CISsCJZl2GtBjRQ9Ff2fUhFWjL
bVcsW8dGQNHnf5f97ICLq3KG1QsWLgZfMBfLbkb6R/Y+lR/D0Mo6VyYW0otj
U8WRZygaC+NunxLf0wxWQ8Tg1zlSb5O4vaIOnRDukeNadpKN3vNl3xtX1eOB
5WET8x4amprj8oMlHyHpOt8V8XsEvLavogMtu1Dp4Fcs08SGkEHmcqvwWlgd
0Zvidqfw2OI1W2RXB0aq3okXbKdAmyQVnHpeBQPpF0bqO9hoKtkhmGLVhZoo
37QtxRSGVHonOlJLcffwnURuYTZOGm/pzJZqxxvqaux/taOQzHKu2ZfCxHut
k+7D39ionXhN1xpXwjVB68rzazQEG6y0axXboGki72KwkQJrywKBgxV1eHUg
46mTBYXQNQVfsiOZOGnF05fuQvSfGVtywKALUQeDpwpq2NityPBiSjzDTIHh
UzVFGvK1j0MXbG7DRtm/cnorKRzY/uFy7mw5TB0LdlQxKfAwYop4z1ZhYrVX
wo7hESgN6QgWr0pEHAdPdrUKDSnOKxrWKq3Qd2eMMs/S0GcHbe22aIKttX+K
Hgcbcb6xe6039cC0ad+3xcNsKLZb/PPlRzs8zy0dm9g4gkPXLQy+Z7dhYenX
88Mrid4Nl1xV9a/FtYDRZZn0CKR+NWsp81dhUUPjOCNzBM33+Qbii7pw0eN9
y+OdbGzYu1s65C8TpZ23Py/5jw3Jv2K3bdgdYIlo7HkTPoodd1ILWyfb4PDa
/o7mLeK/zxIcLH0K0VA3YW/0h0JQzAofk/5STH8OtTheQGFXWYf1DvVexBst
iOXaxMKAaceiY2EZ2LXB/dT4LvK9Aa6/v0tVInPzzO3UcBp1J/okDvt1Q3KP
l9Jk5hjEXd5P2xa3om3Xz6D8f0bhUzKg2ODhAcODEbOCRN/HVwp5P9zZjB3d
ev0cLylIr1rH1pBjQsa1Uj18G42YBYs4l8oVYDpfqt/sGMnzi2uz75WUgKts
e5b+Xwq7A1eYjVS9wFidsd8fwhsbroqYNMm1wfotlW7CzQbPoGb07+5SyD5N
udvcRGNXX+z04pRqTPGETitfoaD09G2wvX0qHmhUXrtO/FzxSD+re7IVJf84
JehOjcCt5nfqkdgcXJJL2OlB+llyqhvzb8pBq/qXmcXQOLTcsfVaUSw+ji+r
PCFI/KJmx3Evr2bCP9q+YyTv9T2cB1OjmdjiXjiQ+5NCOt9mMSXqA87Hp7iP
7iX+z+jy55Kqx1TImXqBCQr2i/gC5hX7MFQU6LpqIRs+6nm8OpzxePvKTK2a
5NPQS4/zZzcxMZscc7L1KY3ZTcYp8xFVYPjtWqTyjNTD051qGQrAqbTPyvkr
aaj/sNV9aHATFnct1O3+n3+5GyWbl3fDWui/Y7fGyftjQ5e9zajDtM8zXdsG
FtQDM+7qt+SAe+3+Rj47GukV/wb9EalB/jtBRrQdhU5V+nyLfw9Se2+lepHz
2qo/FFn+raDYcuaJ7qMQfOvTfzUyD1m5HOqZMRThrbJG7yWVUDora8hPeG9l
W8epiZs1kBzhrukQYWNPnkVexJpG+EoUR/J7k7wJ/p4nrtCDJw64eJ53DIyB
60FLuduhb7R5/kwjCycdGINGE824vqfg9dZEMn+rLxYw3mRj3b/hhd8JPwVl
mAk2JTEh+cJfOTRoBD7bVrK3c4eCoeB3Zyl5/tvV7W86dw1OLgxorCV8mHJa
c+bsmzisiXmQ2U7qGzSrU1LwpQRGbgpaPjmknuE3uZxXdeGr7SZ//RjiP0+E
7k7P1qCx+D/b2L80Bh5ESDdqJuGycMHoQ8JPKZdv2EcaFcFb6xqfhD6FbN5G
e6st/Yi0/2Ye3seCraGfoNGrQEjGCaxtJ/kiUibs5lbRBbmYzc86Mkm9F/ww
/m6STXglQKOZ8NvuLVZG4jX14FRyKVqxmIbXJec7M7t7cOqsU5UsexjZytF7
GU+q4ZgbGRs/Q0Hs/KKp8yJt0JqUFtk4T/Lz6c/Daf15mA8Ca7KMglDckLVU
Rjw2fTBr5iD5rSAQygjVbEMXzeESpkT8d1/+vKNaKd63RuQ8SSZ8eqYmMmVZ
FULLuudGcwmPHd24xEaUCal9J1mnCH/LDNwc36/GxPkYmyF+bwqHmGW/zLVr
EQHe+SDi/yUFm7XD1lyGx87C4DjCG7ZKPCNtYlkwNFbR7SbzJvcwOXp/fQnq
5I3U5l4R3ndvPbpmNRMfrfbPXLIjvH03V/2XXS+2NBd/FrNhQ676Z/LuwU6s
/yZkaRJP4WmdzsDJX63kHo+TmB+GwVJrFb/B24E5zr2jf4VI/1c7xVzlasWG
+fHFuidYkKnzv9exrQab9G3LvcXY0LQos+cKeg/u/M2CsokUcsJFH+upx2HG
atxckofkRZ6yeLlBJA7m9dT9JrzK+PffwqcO93DD6Ow5O8JXAQp+0131+fil
ree7xYRGXjnPr3uW1Si52zEZ9IToLe5k+ZrnH/BNJ9iXVUDjgLWoj+vnRvj5
2Z1IExuBb2TIvTOsQghohf9XmU2B8ej8ouakV1h1+8t1x6WkPtcuHm9Lroab
phG4yTwL3BsokTrZAfvT/JFVu9hINxovqHyRg4hJjrirqjT+fM7ysuRqh5/I
mcyDf9h45Od9K/DTPSg6R/tGkvseN1TLPRDXjszPTJlvN2lkLPj6STK0G2uW
uZb09LKxVlbgq1UHk/D4TUFTZ5LPa5M5bwy0wEd7cC6rcgRntvBmF5oUo3tM
ZjyxhYK7hLOJqHgRRDNShXLnKfjo1jg+1ioF48/LbUfNaLzzu/i47CgTVsb7
Z98QfXXKx0YzvDOh9ZunzZ74u3K3m0xHTRv+czxxptZ5FIfEyp8uulIBgTG3
Gz7rKLTvFm1o8GqHi3bJutE8GpOaYUrParNgzJlsnk94zo8roj80ogy5ObpW
d0geNZl+T9OZfgs98Ty1ZG2ST9zZutLabWhd5HhK+iPZB8aPaHQyXsB31vP1
cWly/mu2sHJsN3ZM7HP9UEvjjBhHqDjXB8QIiVk9GiV5uLX25mqHEsgqVm+7
spzM54Ykp0TvdESfr4/8QM573TFasvh+K9R4HaTMlhC9Vj+Ikp9qA9Ns4EaO
7hDODefoxB2qhF2xsMPwJRrnGJ+HFoa2Yvv9NTC9ysaBKqpfwakY6wyXGj6+
R/oj/81jcGENqMttuxpOjqDwV1wYb2IHAuo/P+hZz0bojp8TyX5p4Pxmwr5H
/ONzbO/VzIQ2OKUKSXRuZJO9domkUEUHFpSJJe1PGIGFTYCdRlI7VAwtuP8U
jGDiuUTtCYrw3ESGUfmCUfC8PmB7tbMBqqJ+bJYphYba89oczzJgWpzV6ELq
m2UjGeJ+qwHdUvz00U4a68w/CJ4pJH7wvvJe6QuyX4QZDfKOlEJYuEf62zKS
h2M5VlwXamDvo5pY/Il8T66GqEBSL26M9Q1o+7DxSXPYr1S1CfYXj1kdySd+
eDpEb1KeCfmDc0FrY4leq6Su2T7oxD+n5q1NRVm4b5p0RuR0C+zzVrp65lGY
Oqk2KFGdjUfSwuNWK2jodeWryGxLx/Sauo4cwgfc7WHG0guZ4FLS23GW3Dfn
Ok+kjUYHvkgt2GRH9uXjzs+SVWzfwyn8RoQC4cW+rI4KtRvVWB+rU3ma+I9P
X37toN07xB05FGxL8iB+70pDBcd3wMLdmQtJv2NZI1VJys34FRXqlXiX5Pml
old8YgVonzoT00vuUyk3NDvHiIXM7QUh28i8JtnvPHCB5BGPR+ZsqyoF8fae
18FHwvHSu+tr5P/3NevkJcLFJ7DrefC+BJLPelN/7lUOk/1OxiHp//zdqieX
+N6rEXFpGv5OY4RPHAtSHlS2QWD57lXMrWzofRkt0+TMQMeI7LlCfhqnghgG
Kh8/Qtpy+nDWQQrxRQnPNduKIB2umZFF9mvx6qbpvulmxPzx3RVE9L35Q510
uk0rZjr2f5zPJXw+02NxaHcOTrvEtdxXJvlzbrRM+kskOue+hrutJfvDpP2S
19vL8chM74vpbRotlp0bb4kzsWRFM6fDHxo/u0Zv6ff3YuaG5s0Tn0dg/IkV
pLuhG/2JJzN2EP+LmZedEFUuh8rX5fUyHsTvhKdzuabrQbJm6IAGyc8mTXt+
q0ZobX+g4M9PQdF1//rPM434VNXZkSxO6jN7LLalrh4jFiItMleIn2TsrK4u
z8WNBOv7+wm/HhJ1fOww1IX0u26hP8i8peraXMuju8F0vnWk6fUoQu+6Hl2z
KwVGu3QecRLeKtGe8FtxNRzZxyxFHhB+FBfe1hgi0AdO8a231/JSGEyJuHvP
MA/DrTFG7h4kD50UsmMOl6GLU+BSsCUbdw2thqwLW8Dj0Ox9SoIF0T3yL8SC
P6Cm3fzm1R6yL7ilrDQRrMP7+791tWUoaD7u3c+yrYa4wrudjyTY+J1wga//
cC0Uv1b8qSA8khdbHG08Xo0W3YhPYjJsHHdUf/CwNgG9hpUrlEl/PdfbG0hI
tkEjZp419pKNYfpg7iLhHlAOadzf+4awQkdH8NMM4VeZkFXhhE9WDA9dSrzf
BKaTzSnTNDYqt/ys+WvZhFCxgYJUwsN5nC/Xqc6V48tWdZ0mLjaOZft5mwYx
YXZdxvwt6f+M8YWf36cbEez0RlDbhvx3i4qXkqjDxS+xD6JZFIQzVFaJHulD
zonn5oH3RnBE9qvpOYMWWBSr5p7koNC7+mvXo+Rc/NK5Z7aR8AzPPxTX5fP1
cLkSkHDnPQ3KM8JUwTgZkxvNpcL0aZRH8zdf12wADA6VGK1mY5fxwUvOYq2Q
71LPKCf9+mP4cqSY8J9sbWDIvqMUsqyDF9jfKMB9oZlnK5KI3t2b1/PWNMHj
1aOmwAsj6JfvG8k/3QYPU/5Sl9dsRDltLq+fLgV/g3Vc3SYaSmYVea3OFeDd
IRr+m+TFkEfkM/btblybULBpTBnE5ze05IBSD26xDjVIEl45wxX944tNA1pl
gv7xFmLD0yi0K+VtMcK8NPLPchP9u81FPL3ThD/yfOoKbmys2/r4nfu+Tojt
9Yy9tG0EMsscEsWze/Hpht4qE5shVFuLbrdbUI9rH106vnNSeCBbN2cZ0QFF
fRHzoQiy37sWsozU36Bre/7em8Qv0vwm87YWNaHFc1N8mSCF/wGUOATU
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81Akfx4cctXlCYumwshJDKVZEPR/dyFGjNKKWEqJV0bqSdGzpcdbW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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs81IkaxuliZTtdJF2OoqJmLSNdD7UeFUrZTrlEpahcxohu22URdlSU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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 167->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk8lWkbx01mbOVQjNSkGiSMJETWH6YcVDq8qkNliyyVaI6loZyyVLYs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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VG8bxpFKUkSEhJQSKkklpQuVlCVbpVJpk6UFWSNUIkJkTUS7hBD9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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs01Pkfxi3yi7JEF6tEEtlQViORnmHLpdsql2xRKpbUipIilpRLm3tE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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHlYjAsbxjM5lU4XOSelPrTrmC9J0oK6i5C1qLEl0jo0lqO0WkYSEfWF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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 168->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlns8lGkbxyc5VZTQySqjlLIl21rrtPOTZK0kGi8qlSQmpYR1iKyOpJTD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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHc8le8bVvqSsqNUskpGQplJXdqlNJTKKBIlJESIpBLRUiFERkaDbJkl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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41IsXxudGuPkRQhSFJom0KaTlpeUq2Soh0R2SshSRVPfS7pZUlnRt
RW7G0nqTYkQjM8YSjbFNJuuofBdRU1LX1W/uH+c5/5znPOc5530/xzggfPu+
KQwG45g8/suZEWJ1NqsFy819ChY4U/hup+nFDhfhyKW+Fp3jFKqqQm9PjolQ
tUXlBc+TAi9HlOrL4WM0a4fpZCOJkNVr25Nj2jER4h+jNoUGI/iKUVnIFXyQ
5R22cyJg1vXsauooD3FSv/O3XpNgztWfYWDagiPm2mdLBRS4Hp+WXAl6haiT
A2BdpaAtEAePqouxWX+cljFp0CmqxiV1XShevjJw4Q8atZaurhynTpj7D2zy
HKOQVn4uObj+IZSslvm21BLoM/ugpnaFh1z9CHO/NyTUJE4L9QY5UJ+zX5U3
RqBrjtVe7xoJUipmJW9YNQyNWEGU091KpGfb7Q/3JzEUNj3zqFEr4lz7SxVf
UpilbySsnBQirK0k5/4PCuXv1zyYs60b48p7a4wzaWTKbP7oYAshrhIq9LAo
nCnvv6Vt1Qi19Tacq20kvJXGDulal2GWht667xYk5jW93za04g7eOEdkxOYS
YC3qrUudX4XNPQOn82aTOLCem6FCPgfTwaH0M4sEd+fPvsEq0ThsYc/+sYSA
bW2b/YSgBunXGUFZbBIcj4PPYtI64LrpY8m9lTQSvXa9Pj+1GEoB0RW3rxBY
r/trwXNpPRYkXNhhaUqhuTBnw/IuIRxdzPkP8yhcCHv2+GTWQzA6J8bHRAQ2
1rqfiDJsR8zJGV7Nq2ho8L91ZvFqEcdgL3J4TyKCnTf0PbgD8ct6I9bE0tA7
v6XunqQA0bser9p3i8CpF5XVNj3PkaaX48rzITGprWWYqNAKUV1IO+snGl4p
+5kXTgkw7e0Tx5in8n57c8qOmQsh0rIcMfhDrged38/nN9VDOIM3ocsnsSB7
WoGfUwdsvdfpRFZTaPN/YsGPakBt/urFNkZyfb6yMnkwtw1vpLHKO01oGO3o
ZXHKSnFf0bCX/JfAqpn2Ci6JYow+W0E+MqfRd0Ac3nP+FcbP1TCi7lHQ+PZ1
StTluygbMjGryidg/3zNxYKlTzGFCE3p/UaAIblk+j/PNOiqsdwMdhPYHNRY
5xTPgwl3aW9/EQmNzma7q6w0WC34aerTHQQi+8P6TOdmQOFkgSo/gIDRbyu2
WhZ04OIM3X9DtGn87TonqPNgG/7s09VuVJLP+0kSHPaxHl7vdD+nyEgEnbGU
JVmUIUT7wQ3uBwK5FkoSbmEzGlNVKo4XU5DOtL17dzYX9JtMF6kNibLvxLHh
hAoktrIiw1aTOPMuduXeUSG0lSoDwq9RyOs/8Vn9jgTFnjOXbmHTGF2oGb/y
Wi0UGi/Fpw+TEBr47q7OZ2N92tjKmDQCdIthkGgjH5NzXazcukmIZ1urTYol
YOUxizNX0LD/Yq14MPoU6ErZ5mobAtaql9NrCjuQ5PeLods7uX+1WnUSOSWQ
KU3/6NJPQDNUaLbT5CVead0P5OtRcPbLjZKGcrHdw/7y6mMkcqz0ZPldEvx6
e0l2li+Neo8b6c36AuxxdV57XUrCpCi4qILfij47TVGFFY3Y6RNN7Oo2aPvI
ON6ecj6UhvUkmItR4sZNdXpHY9BhpFVHpxtVdYT6/thhxPFN/vTo5SEx6ZG/
2VkSbQbMFaKyauS5BYgVj5IIfHBaWzCvFibltp7xQvk905mJgoASLD691/+9
fP/ZHW+VVc340NrWcf1GJglbe4umlnwBmD9qmrz+JmE11E1vC+GBvfim+/BL
Es56FzRHtBrQfcQgw3QdBY97pLtOgwjis4W3eRUU1gXmmv441Im1F7eOFyTQ
cCbfRue8boLP5ILnWikUnnYtjB/ld8OrJsPPN5mG981TlX4HJZjuY/dX53/1
oXmBX1RfoK45WjoWT6JvZEa7YLgQg0Ip834eAeeEDEf1vLvw/JZoq19E4OvI
4fSpL9pQMC+yLLeOQqEC0/bLrUdQtiw1su0lwLG/mTvYLYJtpCKx4QSFEMU4
Lie0CEkV7rbRcj4dWJQa3L2sBo6BuY1j60kcydxRXbmpE7JAzb8eyP0/7XCt
UbBTK97ti3M/KqSQfnxgKMGjBt7fJMZPH5L48MT4ifJ8CY41b9l5yH0YSd+t
P5QHVGCQ/Vhg/Yucb28xmux4DdsPcNWVPQjoCdRVkt14KGzYEheTQ4KR3udw
sWQbmFFLegeZcj94MfaNyP/Jz1RJW3IiCRVBssK5xhaEbDVerPCawoD67lZ3
6w4sbsh3q5dRmHDO8rofJsKAZPy4xn4KH/8xnwg9wIfdwItCsfyePmljzs0j
QlzPFyZJA+U82CPQS5lWhPGt9bsSMuX+Lba6kazVCW/vBDs/Ob+cSpM0OCpc
1Ol8HcuNIDFnfvYlacRrRN5ZIrvHonHOb7bD2dnt2HOy4c7u3+R63L6xSjzQ
jLN6/nG3IyiEZb5x/PKpHH3H79jBkMT/AfEM0oM=
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwV1Hs41IkaB/ChOQqRkyhK2EQ3XRyN0uWLlDilrda0m4pSrRi55Ayt5NoW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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 169->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lfkbtVQqaUE1DS3XnjZFisGZ6k7IVkglhKRCkb2yL5FKJlmKGpVU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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k81O/3Vb4pQkhSVLJE9iwpyQmVNUtKKqFEhLSgTZtKKltSIZ9IsiWE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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41Hkbxl1kqaVkq9XJIkSsRWJadFtZJK2UogMdtgMZSVE2HeitLUIS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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk4lQkDxV0zI0ol2ijJFCFNipEMHTVRYoyt0oPSuJUGUe5T0lQ0biI7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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 170->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs4lOkbx4fsphxKrJTDShKWTYRGh6+mSJYkQpYh6eAsWoeOknaRQSpJ
CiWtssi5MAaNQ8IwYtSkQvRErWqrXaLf8/vjvd7rua73fe7D93N/72U+ITv3
STIYjHT6/P+NJflr3cxFcDh67vvfTxPwDFmnf1qShei7FwS5ywnaqn/Qvf6p
G5MayvOjDhEUftxq8KV8AIGVneZbuQS6nHbjW+IGBM5jVsyaEngcmv52VtiL
LNN1zm/jCF6bba6UmRBhkoi0a68SlGi8euFiPQCBslXMsZMELtcUpH/d3gbL
m8t/m2tHIBJLdv1jyod1tUxc+DaC8jYZC8fgZki7fbHz3EhgFJGis8ynFQ/1
LnHfbCJgqFi2u6sfRgO/oM5Ai2B36qg4S+4pvCo1q6/fJUiNtgndK9OEo1Ie
K8h6gv4CBc99Hd2ojrbxtdtDEBcpbijKr8ftA0+U2T8T7PEStwUON6KgqCnH
dS2Bf/eSvDVMEVyXffpRPYdAWy4t/fjCUgjOafyx2oBgQpp1y9S1C2xTi+B7
OwjUpkvfu+p1wj58d7m2L4H9juFOzfAOKBf+M+nvT7DDc9FavduNMOBpxew0
I+CH56nZberBuba8H2qjCJKzBixWGvVDIlj16kQBwaRRqGHz323gsKZKBLRe
0YT6VvbUTUSNfVkq1CHIf795tHN9L7T7ymx2HSbQ27Qk0LGsC93PC5ku7rS/
0jL7zNb14MbW1aPykbSfNUkK2UptmJfKllej91lyC9P/DkqAwM84+xjtX4z/
QOastABMxk/yB4KoXo9eT5StrsGi+867so0JtsypPnBnqg7lsvw/HcwJ9qk5
yG560YYGD0+5AKpPjqndgP2VGkzpPopsWEVgUTq26z+9x2jyeP372wQCuzlh
fR8eD0AzqX2TKo/gs+dRJ8O7HVAPdtdy8qL5hD+berYsDk+qdugdpvnouNso
Pw3pxKzF+ONce4Ik9x5Tc9kmKDsNWN+nvEV5ORhM/SeAxJ0Z8xSqp57KeP2c
ih7M7ZjiqlNeFx3JLnqV0IS0ax2azVR/3oQPjNRrkJowuqLKhGA758tIhWUf
vo4NbshiE8QfVz2REtKA/UPxXEcLAo7B8sBtx0S4T+x+1iql+v1YOv6vRAvi
LmjbVTvS/phGRg36liBOTXfLJX2CdVc938X6CsFZNPju+CkClmEYl7GjH6dF
gvKYMIJjqsREx0KEgBe2Qw50PlRsz6U9PCDEdkVFm5N0/t6YOd4oXdAI+Rcb
ZL1pf0Upy/3aOZ04dEJJ4fJ2Wo/uO+sgJSHii4tVPeMJvM6EWitd7gXrAH/l
yhAC8R7z5/5DtYiQnDP3GP1fyaT1yj7JDmSlLv3I8aHxIthOa0v6cN1GRWs8
n+qpHMJ+aFOO/dLz1XVp/n+aJOVy1rRAe8pK/doGApvniYs/H+1Gl/zChl8o
n691PazWhHZj4x3HWAatT9YyLL9H9BRhLGmHl0ICqUTmrdGiQTi35uakfyaY
jTrPM6vqwfI3x+55hxK4ndLsFxrmgbPS64gj5XdIWHFDIoIP705eWRONF6rb
rN6qXgEp696QFMoPY0TQnFHHgXakd8045cHSaazfkXkdRXUj8stWUD+wjmat
ulWAmFOJybH07GI4OGPC7UdKnpGpGvWbkMVHvVSi2jGumCE3603wUnP19Ezm
IKI77716cY3APGxhsFxAN3hBthcyfiM4nO9X9XFBD1K/W5J3hM6TvFThjEjl
NmT1V/uNrSTIrB269PjzAITZTiesH1D9w4zycsKfob8p5UxaJc2fkRve4n8D
N2f+UGRq03pd4xe+3SLE5PebE85T/RmfFOdx08PA9mDG69B6el++CTI63wmL
G1dyjag/sIZt/1mwtw/JvZoBB6MJ0h+a6QyoPoBP8jrRuXVUvx0SV0PuNYLl
4bNHmeorbimYiZnfjNv67vVzqH++HpDk10w/xvBc78T6dMprnUgwmVyKBSE3
ZTWovhGOfV7vnLtgGzR5s9+Txi/zPhF7shlG62W2PgVB65yiZ8yDQpjE/XTr
5UECrkHAXn1mLz6HR0wKKW+To855zlZVKA09+4VN/aBcBY35X4TQkL/ulXqG
wNjJP7dSshuFGsmVr1zovJLXmcMzfMTJLN4da03w5MoSk4TdQiR8/SvuM73P
aJ9Eo3FLMXod7zrI6RIEtbPOujV1QuaR3GF7Vxrvo6HKab0G1E43sS/SeHlS
ss7JtQ/QeNJZaWoLPRuvT79h2ALrB0NSo9R/SsxGPkg4d+B++u6hMOq/R6b7
tMaYT7EoRL9hbw0Bu3peTfx+IRZVx3GqYqkfWMbXePgWQFvhnWI95eeFU8X8
uJBU2CaNH++n+titz0v/fl0rskL93kfQ/pR8jJdZsbMMxjUPOWN69Hu3bPv3
jGL8e6GwO5ryUf0hMFlc2IbsPbyDs3QfyHun5Wtu4EFtVjLxDPUb1Uv8Yg0G
D0bBj0xt6X7xzeBtk0jpxqqApS4ZxwkWnqpqXdpfh8LhOtdOJo1ntzv1Aa8H
Kl/31HApv0qtY9/pPObhm+fGWo81lFfL+u8u0H3YcTFxVoJFoPzv/tYfrAax
rHijuvUA7fddRkOXggjPQt+SQxkE3lNMrRH/TFi/+0UsTfn8Wt2R9otPG6zF
ne5ymwlObJmw6fpQCDf9FM57Ws+1uwLJGunnaCjZHL/4NuU77o9DP7YXAwqv
xqspTxN7A3vP/94O1m9P+0eoHtJXjK5+E9QjsyfWsYbWuysjzenWeA/UTTzN
dlKe1i52nk6MKsFgkUi5heptOXT5eTy7EWu1Z+qnab2My4eCdL5yoWPAmHlL
eU82D6hPSuqBn79bitWvdL9k/vXyZg4fhtsuloko71FPht7s3CVGiukWiejn
BBc7PhxJ0+fD9qKL+1l6n86uOxonfQXgV17QOxpOMHyb/3eZrhiWI5JW9hyC
Ne5pB20yhSjw+rRK+izlJXK7VYEUFydbuSNqq6m+TVk65X+VwyVGMfgZ3fdi
r/Drf8o0gFvpV29BeVQWsuZVyIvBzvFh6t+h+yfydJZ/pADnrKT92XQ//A8c
wpsm
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Ve8XxQmFyJC5vhVJocEYSi1KlIQUSZlKlFKaZEiGSipKUlTKkCEh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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHs01IkXHxLakh7ED5tXSg+7eZVKPkxITSuHyCskJJUiFTIT2mzkkVf0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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVHs01AkDnUqtVEhqbSRUiGSKisKNHiT5wqz0ohSyoYkepG30eawlafVF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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 171->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lfkbxpVpotUUKqJNZY0siZpuiRhaaBQtOI4lYSwxypI9yRYGNQ6t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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8lN0bxiUhW9okVJKt5bVEEXKJLJUkJIlSiWhB9aYkqUQiRQiRbFFR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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs81GkbxofoQCuMUKRmmmSLqCgbuQZb8UbpwIoWW2HLIcKi1qbDiCKH
UqyQpaKwbJJCTZZEExmTY04dNL8D0RY57Hh/+8fzeT7XX/d9X8/3vh7OgaO7
veVZLFYEc/67DyyPpwryahBz4LJ4aTgJodvrHQ+y07BFKH094E5AQXU8KiG1
HTHanW7L9GhsPZkbs+T3dqxyaZk0TKHhZVH0tPJ9BW5+td4xS4uEVymRs+zB
E8gc2uMqPUhcDznyg0vqXxjpnmvV2kfA7tyn+caryyDxdF2dOEaAX7FHRJtl
oEJ0ZvG1Q4x+b2XX0P8c+3s6p7Y7URgJ0sOwpBIfWaEHfueRyN8XLH3oVI+l
H1dfyeggYUmXhCpdFSGw8e35eGcKxOHuohkzIQKlH/8dCiGxzM65vUz3HjIL
N+YHfyEQdD3B4t1gBkziyzInDhJg5a031nz4He4uqdNRXs7oi6W5SjkFUB8q
f3PwBqPliq/E3ctHVlGKIJXRXcFjH8RTLzHt0xIis6EwbOSyUFfcBdXqAB25
3YwfrwcNTE4kI70nub/JiYC9LqxjvIXQEx0tlTiSGGneqGioVYLcstiX8fUE
RCpcaVC1CN/UZV9fc4LCiR7LBqLzFfIRoLnWncZX6+22xyXlCIxQ4w7KkVDd
vMVPfXY9ZAF77p7RpBD927Z91gaPAa293BgbEhEf3E+kcNvBUnt28PF5Gi7B
CaF+ak/h7b/8xwt3SSQtqzxmoR4NpSx7wcuNjB+Ol6/U6XYjNmdLb9Ilpl5S
lN+GERE0o1RMz22lIJjrwZVovEKkYbuPPodG9Pg/ck3PQiA139vguYZAZaZW
APhiVBSMru8TUpgzsOiW/ZgE8iZDw//yaZzwdQ5NrRAjpGZF+WQbBcdkVqTd
zm7clRLLNnjRCF2uG5jg3oiL9umKOn4UJM+yzaYURCAyXXgcpv68w5yuwI4O
1IrM/3Tl0nANmWI7O/ai2GRJpFMWjebJb33TF3TguGNyWGM6Db6LvFz0tqvo
1+IZdbkRuJh6ORZyTdA4/u3m7vkUtKeWjIa31SO5qi30XBeJvqqo3SctxahJ
jTu95iQFk5EB/hj5F2yi5Y6aDhMQLvDuGho/h5FIDbtTfAJOOvKCYfN7UMvW
rtncQGDtJytlLrsL1x6WmpYw8+iyZSuPqXbAxq0ld+MdGg7jL/J+CpJAnGyk
X+JCI/7wqZWzkkqQ9r8fju0rZfgKyOD1IgE89qCG1zYCN2f4ui9eteKD6R2+
/RTTz5wn84/ffobNLck+riMkNHBsVH5MiJj9cSl96SRKCgydN+W1oue8Vm7V
ewrv9Le1JKk1wfm3wmD7QAqsz5ZJOz5owUU17N4mLoG5dr6Rmlc7QP1oK6nz
ppFkrjzuXydCWtRzs388KThVX1P3lD1Cn/ro5OO9JKZPReJBjxCFRbIVqkEk
oo/vDF70pwQewyXBNk0Mf1FJ9Q3G58G2zVK6yfhzaXtB2NiiZhwJ0+xzDaMw
oxtcHEi0QOW67dy8AgoH7v+ip2PeCQvb6UPf/ZcfjRRHx1yM3WcptUWxFB6+
NeOwLcRQCzRJnFlHQ3uXoneZcQWuTOsnDKuQEPy8XLbz+3aori+cF8bwlVJ2
8/HEnTb4X1p1eCCDhvS0Q233cwn8J1X3WEZQ4H8aycnV7MWZscM1bOMh6PeM
h/Q3xyJr7cqoQmsCh5Qd7RxcRNihdCm6dR2FvdoS0e3upzAjTncf+UKCtTjg
a+Psg3BMk9luMiDwXN/0/vyyV2h0Oa/Mv0Xj4Z40XpxGN9y+sDWq/WmsWqlm
nPhLF6oCeT5KdjRy+G9Dq7limIWqt457UOid7x7RQ7eAe/rWRbKPwlyDwfW1
Bo/QVjdUNnyURH9x2jfvfXtROPq0c3b4EBxi7AytSmrBK/n8Jf8sCen6DXtv
vhHj1yUBr6Y3MPOOZj2Wfd8IT2stoR2zL3lPVyk/MfobBX6T3YpVTP5ymh8t
dL8LmY9wZojJP4WaFer75tTivezqp63xJN7lTbESd72AFsuXXcPwYrVQu19j
gQT85DGFqF5mX9RuXEvgPMO1e0k1lwcY3jwnhg+SQuQb6e3wYPJ1OCZNsOVC
DaQ1NwpUIknwHfbIjTunY+AlsVnoS8BrtfOAY5AY70rn3b86TeGJICFN4eUL
uJf/LHJ0ZfiZMLzO2dkCncp1JrtCKZSMpb3JTKjCHzETBjqbSLgK1PS8yEqc
PfSgM43JT8sz5cKFWrUwTNhfaZPP/FeyxLVZ4WeRopLupmJJIHaxx+cibiea
rNip1RM0GmcvbWcrdiKx6UaUQi0N/7Otj3izxKAtwv1MBym0KmY00+86oHpq
y+LINzQMcjZciS/6G5Ys5VWFp0iULa3nlYeXQYAo8qOMgHzTpcQ5Pm2IuJ0h
E2QzeSQ4Kk2urkXEF/WFmcUksksHpT6cJnyqa9BJMmDe9/PJcxnF9+EY95w3
o8b0/8FymvNTLy5kfzUyMBzC/wEoPsEg
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlX081IkaxSVbRm0piXQppBJlxE2FjiRLq0tCkgoVGonUFiGUYgslpVJq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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 172->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwdlXs81GkbxklJVtuyKishFbI5lLeaYrpU0iKhpETWKVpElA5LESVJqK1Y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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VPsftoXKLSnKki1liZKQUr1KZatIkiRJIZW4EoUrJBGpXFuFpA0p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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs81HkbnaRSTdFq1yXeVMLU0CQiMUdWiMotqt1kKFtoh7AubbmHQilK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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs0lIsaxiftbElbF5U6JGxSbEo3Jnno6hTS3VEuzXQ5LqU6myTJrlEM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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 173->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVWk8lWkf9trHGG0SMYVorEllynoxUxJZDsaSNKfBUFGRLYNsUyhb1MgW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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHk4lG0bxmVXlvcTr2yRoqSyVKLoLG2ShBZUJEUS0qIkiUgqSaulUiFb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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41Isax60lQsc5RI8sUaeLurKUNl+ESt2oqcgWSqdSUSNblKV76Tay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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk3s4lAkDxbW7tXpKkVuU+qLSFqLLp8tyQkmKSopVKFYG7Q6rhmd8SavL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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 174->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk81ekalyWNLZW6aVHIoWRJlqxf28gQY1zZl6KiIkuJ4spWVNKZsYyU
dcaWkmQJTUiWgzh2Dqks8VruKJSi7n3nj/M5n/fz/p73eb7P8/1+H0l3X+uT
3FxcXMn098//idjWpLyPjRBDvJeAFYFysV3fQeNOqI7Oyg9ZEyx/nJV+9qUS
iqNpdwXVCQayvHgs0rqQcfuC2mg0QSZ/RZnndzYWRSst3On3YgKD+zu5WGg8
KewkrktQy1/aY8u4ARurPoV6KXrmaYn5WuiPKhn5qR303NNchXaXWnSMlZp+
Uyb4F8OBAf2XmBrbkTVM45VNGJoN69kwrFPI9j1DoDUeu10pshsSpb+PiHgS
bDf40nviSx3cJDj+OqoEnI73f3p9qMeLV73eC9oEN6JXQjSKa6H+Tilunt5z
zcsndnpVIv2BsIyVPMExHyPm3MN+XBRYkP7zDkFs0z1dhmQ1ipI9fztI8e52
DvYoDA3HBcfxjda0Xq5fXC+VZV/DXkbLcS96vvJDyscO39eIGjuUZ55PIJLU
2HByayeOnPq5eX0ggXN+L0OJl4VqEcXFH40I4pf4Dz9N7Ma8bGN6RRSBlOWM
XrpOL+rV9atKaP6Zv6QG+Y/3Q/F5nlbYZYLiIGO1Mk4aCjMD+rGHwOrDZq9x
oQaI7rtnx21I6zEq+bhe4xm0LmmLmSvR/g9HbV17vBO52TOPP3gQ7CmRMXNb
YcE5c1fIDw4Eot8u+ec7ZSMzhOm/jr5nmx6dcX2Mg7/Hj4qWVxJ804orPRrZ
Bsv5MCJqSTDyIk+lz4kNjtsa1bJTBPs9j3bYag9DLtX1yEgCrW+HzrYakTqo
bcqx01YhKOIUrn6368bxlC/L2n4Erl0S/xFfasGn8+qLu+0ITvStXLBWKUMs
Z7n6wX4C9t1jmTy27SjfJyeeZE5Qdsjjj1sb6tASFW/icZDA/2yOwtuZeiQe
WAjy1ad8c+OM6SW3Y8dmfg+xnwimbr8bXLF7hpdzSW5Vhyi/BGLyHQVykBm0
682vDNp/U9kVf91ebH/WsPryEsGwTc/F4jddUFk50CMaQaDn4Zk/mdKClJ8T
zDm0n3KPcyPnC6oxfd+wUVuB4neYO1O+1IuA3o1LOVkEYVZ3KtY+ZePrzWpc
sKH9M2DIFJixIfeZyXeD4hXN63+oxl+O88kXuQIoPvmB7ECD8w1g+d6ev2dC
8aaz7c9uGYbriVvbJx4RhPe5HFyKLkNvh/xMAeW/33n28CexIrxU+lo3u5dg
a7yyrqtLK3a3GcWFuRO8vXPr7LvnLWDy7j1sdpQgOjTIfv6nLmQXHeOs/+c+
TN7Ze+oxzsg2WnEov9f2zTx+r9ePa7Z2x1x+p/oJenZB6F0btvmMNz0/RvlT
y2MZM6AL7rThqFVJgkOxceVBgY0o79OYDreg/E+IMHJ43g7edAvrcKo35UtD
zsGjlfio/uRssCKNn2g2a8s0xPdK5dh/4q24vh7mPpEP76ceYkkyBLz2Z9ID
B7uhyho/tOEmQcwZScGM029QoGodzpVN+XlqznGxho2t19PrZmg/I3bvMZX4
Nkh1rzbrnUGgwXefM6hRgdaajuoKiqfKZ9Wop7cd2jyv5z0dCZj5Bvcju5/A
7Ckfp2MfwSzDMZx19xX2txi6JVP+d1RFL1a1dCPxyRW5Qqqn8fS8K5dzmzBl
5Sr75t8Et5bXj3P2c8BkKHC35dD+e1vWppfkgGOjJu9E65czmTcI7mnFyNgX
Hyfqj9NCmy25lfoxcWpvekgJQbvG6VKHzj5Y5pvHV1O9y6U03W827AAfuyKV
7xeCq6+kxTq+N+CVohZLh/J33ZxiXp34KyS/3mJ2jeL1HlqImSythb3LHzbH
qT9B7aYbn2QZekLe64lS/myx3rNGYA0bc/GCOYyzlC+b4pVT/AbxZ2rIBqk0
gnw1qxrB0BqExn5aNKB6Sd3TEzKiNQT91zMZ8s/o+9XznDdH6xH2EpVZVB/F
4idV+rk5uHDO9V4hnUdtZKf7asRzXBY+q/9Vk8B+u9x5KdluiKsyJotcaD7P
97ZD8q1QrxOR/OxE0Fa8yDMj2ot72cuaIjS/XIbvmY2SL/B2Q1u0E/U3e+Wr
3QtSTeCNfz3mT/03dsRQU1/lD7TpnhK/SP1mXXCSIK9/MYITXApG6TzfGuu0
dZReh+TDW03R1E9DYTkdq9ABiSYpaRfqV7aZwrtWk0Zg4bvzsu4wwafLKJyc
ZYNZp3k79Rz178xfuqZ7/4Ks1E83Rik+iZciP5Zta0Oqu63/GNVbe71g6T6X
EXzd5FC67W+ClCo/PQ21ejh79U60aBDsnEwT7jIZhL6NtfZcKIGKgZSPzL5h
zDwQssiqovluW4oU5gxAS2Aq824h3X9L7AALFguucoe7+qk+koU+6xSlNaL0
wwMNbRBM/Ouv3IObOmG/tjY4y5Xi7Ul2zxIsRF/GSmk/5ZPE+bgD/OWdSCo3
tpil/GPLP7/6YlcTdgsXBl+n+26riY9pjH0JLrKDzBPo/Jnielu/2/Zi1O3b
DmYigT5L3WHtfAJyB4T2rJcmOLJT9KGSdQPst+0yiaLxqzsPc67ca0RXYvaa
BWPqxzLLiBocQLys9IniVALzKjPhlDEW+h0lHt2h9zwuE47nsofRLCOa+F+6
f1qjff8nrd8E65jwiSM/0v2U9f1pQGIzeL9FMn43IJg0+I0xuNiO5fDQj+uo
/3htzBHae5MFLebSJWF7AhtNVe+h7B7cvfy2XtCHoGXTmmmc68QPwbk7r/lS
fjRX/PrrhxJ45D6KkKb4/KQ+5zcmt6Km4O+hGlMCPgWzMNOhblyzOhDoF0Bw
WvZLbqQP9X8+5pM11J+Zsu5c5f6PUDSpkhZF9c4lbxyRFFWFo09Zr0Xp/nmx
gWnevFyP6YDNvpKUj1xSBVrC9YMQSZia20j9JNBY6K1cbht+u7PLPo/uj4zE
cIkq6qcbry74eNB5xtY94BJ8XIxE3sEKZzk6P4uRxri5Tgxo1sQdpvwwXTEa
3dL0As1NO1l7tej7hzb7TSqWg3n1dFUgxVO8Tmy3jg4b9o7B9RF0f/4fPBmf
XA==
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVWHk8VP0bpZAtSSmvspUoUUQqpSNJSCJLyVKhXpW8tChRabFUQmUpSkih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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41Gkbx6VVki2xG6ktSsTrEIu00VeRaskplArtS0hdRWxNhURtVi2S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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGs0lIsbxUdJKREjFLUoKhLVqXQ9u0JNpRNHSa4hudTIJZFE/TkdlRVT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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 175->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk41WkUx1VGDTUjpEXJVpYkaVPRV0luSSUqWSKpyFb2UJEtaaGRKEmy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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8Vd3bxqkoklSazApRQlRIuRQZ+kWSNHgyJeVRSJShTA2GR9IkhBQZ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVk2k81AsXx+13upWUZElZUiG6tqTCr4UWhK6K1IOiBU8Z1aVNRYula6lc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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVHs41IkanpAulHKLo1xyCie3g2qz6tVtsyXkUnbVkrCRdFMkle06XVza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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 176->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk4lekfxk0UNbJkNDIjSuqEyja2DrctCqNQWc6kOm1EllRkIqc5zlSo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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VfsbxakMlTQpciWSIQ2EqAwLqSg3hCKSyhAJ3SRRUsZKpjQXEiKF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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHs81GkXn0QupVWry9uOctntfSvUug+131GSZN1CrpPWNZSUbiJC0a4U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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk81Akfx7EkdsKWIknSk1LSo1wr+thISqUdOkRCq1zRCnnUypGjknQ4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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 177->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns0lGkYl1xaq5IKuZSsCJGkjlXNTyKKbCFNChmXEjvIJqELNYduSDcV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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2cglW8bl5QySltFJDvJaCn5SSohSYhI0hINRUv+kjISIlIhImVmRVE2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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk41AsXx0cmIalUKrmhvOFehcgS+VraSF0pXhVRUolKSEiSbiTDVeFG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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs41IkXxtncUhijn21ji8JO0Y1NlHqtS1IqSbRIVkQ/FSm0SpHSpJS2
QqRIrkVIEtG4zbgMxhh3aczl+51uRCIqdvaP85znPO9z/ng/z3ueo+sd6OT7
k4yMzClp/dfN1LPDTAY6cILZZ70nSwS6gvq9Sa8M0MdfFa4rl2C8JEBpqVs/
shY8OZrCFCCHu/dobmEhjpXzNdatkuqa0786LW3A6x9jCThO4G7VOW/zLbUI
fr5FUUuPRJ2rw59Gd1ggZFUfhdII6D1u/2ntfA4iRt+0LA4X4UOukim7sgbp
Ki/d3xwioWnwMsdKyMPSPrnFMa8FWJHP3Ph4thJGbv7UnmUkFmSWECtsepHK
/MN1CUsAo/gujSsfmnBIr0z9XTwB51HOADW4GPHVo5ptMyT4skz9nRZFoPi/
Zl9wkGBzrtwOe6Nu5KTOJROlfn9f2Rq7/HYFNoRns+lnSfh/NPOJOB2N2ZMW
FAuFt7DZ2Ndr08OBxvwHuU2mIuhM6S5T9E7HV8cBzXkMCZIin7VuD2kAs/GK
i8wmAjXldb6xWh2wMa/q6ygXIXywfKDkUq+UZ8dA4nwRMqK/bduawMZ3i++h
eSZSHrKhUUHpDdAypqdYWxOIVLVK3GUSguqRKx/8qG+hMzK9er1JET6vdjXh
b5fAwquwTCmvGaZpBf3Ppfs+UYd4b9ZXQm80blzjMolgkZyLPr0OrWtHbHdS
SRQevx9SJazH00HW4D+rCVB7eb7+5+rxjN8xkb+ekPKZ3nsntButfYkjkSVD
aB98n2cW1wUKU+mw8XkBZFr1PQLO1MDsZn/j9XYC9hGBwdzsZiQlh8QPaRKw
NGzJGhkugFVeYqa7uwR5zsJjDiX1WBWvOfnxJgHtWNkhOw4PT6NOUTKk+ZHR
dS3muVdD9MggY/F+Et+jUjdQlThQiFxuG1shRkPaMsqJ4YfQslNMC0+XoOwG
bYP9skqU7Bna67CDhOMS7fWWcx/i2rwqTtUTCRQWZFdkqHTAY1S8XW6JGF4T
eq2RWrkwfVR78Oo1CQpVqufNs+kEZWGsxYUDQkQNqPtYcMuQUBP3lv2ZhAxf
vk1zthFVVMLosohAw7Dy/cuxZaC7rEgZIUm0JEQYhK3qxpi5t5IgVwAntb/0
3WZ4OCAa9ZwKFEIveQ3zl7YWRLNn3MvzxXD+R2FCn1eLL3addWkMAhGC0JFz
hxrg2R2XN61DIl7sSLcVsMAXfQ2fliMQ9uaySomoCY7aZ69+mRXjgH0V+zSF
hZKoJffq6AQey/TcTtxWi8TsAK3STAK3tm7xzB6vg2nWpGeAHYkL188H+Bo0
4lbN3HMSConinhqBk1sXkpx1w/qbRPCYrjzydEUFJAfD5k49JVEr6TfP6ebB
zcBxvkmHCJs5cWfnLOairNIj3MFPDP/nNcMn5/TDOkV8Y+iTEEH8rF0NEwy4
xNJsuY4kJnWM9yWt7odgg51ftJSnT3u1Ivv/nXC89q7Z56IQ+0YTVP1+PMdL
oWBir7wEmjoBDavXdID28NCkWEOMffnf1jB31GOxHa3Y8DAB5eqt9unCHuhZ
GhfW/D2ERafWeMju6oJDjndGrr4QcQic+cZoRl2KanZFzn95jXpW3JKIip93
r7s/JEEyk/+9wK8NmytmaH7TYsQrG/lHmzRhIqYx7GspgZyTK5R7nhegLJVL
+GyRwFlVrkz+HA9qHqEH/jQUwjHg/cHyB3UwkBzV6/9B4IL89bX7rnWCFShb
6uEtQFXWwiVFja9x0D5rTdHfQmQe068U2jZjgd8Y+3iMGIMfz1y6mNQJ74XF
nB3SfDRMPflQym6HIDx5z/g2EfaenmJcSO7A2S6GE6giWLaPWR9OvIy7Ky9W
dX+TwF2W9X6miA0dcc3gGRUCGjbvjsu+rseNOTEOugQBBR93euHuWoSw7qVv
9CBBGRpTTgx8IfXbFhVQT+LIb1d9XZsz4R6jFmSaJQHnnbn3dLwXRBFXqr20
34IRcW2RldlFyJibnzCUl85HjNW0al/hU5BrfZE/CRpV8eSlbWnI4Of37Xkh
QdoEddnKPQ8hDOwvnU2W4NM6vnV+yyvMXBQxO7VJuATImrbo8zBOJTw/OYrR
E8g1Mk7ohXxQ3ugf3iK0Ts+8CKpuASvkmJ6kQIzIleeP6sjRMR4/4NIxI4F/
SuTyJ2qNUBmZ6981SIB2JJgrSOXhnu4iM4WbIvx6tol+encGSnvNlN2KpH5+
2z6lY83AjEfc8OQD6b1upYu3hHYhh5Gp8sxTgHzGLF/xFgeGu2rbS2JFUh7R
Vsa1XXh6emfr/3wEYB+xDb7D42I4x+z4z8FCJL3VTxr7vQ3jv+wP1wgWIUTD
Vz1IvRuczx+cDGKEUM38wv5ItGOtj36feECMU4asVMpfD3HXt4eyX/oPaTQn
NXEJF9GsvuxKKzEcXyYVdDuUQofm3M41kkD7dopX26ZufFcNeXwsRADL/QWd
3Vt5oNtmBdzfJATD+8rR8nU1OHOKu1vJksS/k6DXSg==
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 178->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4VesbpSIdla7cBrkpMpNURNNKJUNpEG6uCNHNFClTF0klKXMZThnL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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VX0XRSKSJETGBioZSpQpC0lIKpFSSdKkRD4popAhUlSmJmTKHBKS
Oco8u64IKe45lyZJRPX93r/Oc54z7bP2WmuvvcLBxfIEFwcHhx0nB8d/x7f6
878v+ZaF1Gf0ePEshbWzpl3mx9rgYfbk0+YYFgKebjgq8LcJoboq0nQbjeRO
/dGlcnUYfHD93mABjalNlg6C2xgQnxE5POjKRlqbgWhyZSOYLyYLV0WxEbmr
3LpNuhYDdhe/Bv2loO24ObGipwEGrJCT5cdpVBdYJTct6YDgtHb2Lw8Kyfc9
X7rldMJvxx/+w+T9MieSvootrMfy1Ny9FvU0OMR+9G2RacFk6sph6xBy/1v+
DiZXDy6Jn/TzOkHBRqY/6fVLJmZjLRHCP4rxFoGVaXQX4rad1l6/gULkTHg5
v9ZbhH0LXl19nYJhqeL+vYxudA7/EdRUoWD1eOjh7I9aiIf4J0T30dDvPenD
UMzB6eV8wm5baNTcTlnyblcENn/Y9VpiJY1zP3fkx85/ioUlyh0npWjEtivf
MUzuhq6xr110/Shi2/hPqQ714tWVx9NP2eNoutOWUPyoFzryu4Vbk1gwib/f
f12sEJYe/tyGVRSayhft0V7bAO4AzVMSyTRct0R5cGb1YiB5yuDiC1IfW2by
8tZutI3cv/YlewzVpzbsfsxgQq6//y5ryTg4vpnVCUvfxeGMpqs6a2koyRs/
eHWtEh5xglVJ6RQqr58KYLyPw7fqy4f3raZxMpbbXudAHxR4DpkuXTAMofqM
Mt0FTERY7ePYmUKj9otxlptZH3TanKcHH7Jh4nw10M+7Dfkz4Xxn5Ngw4wld
clOjEG5ttyykDtEo264+UXK9F5mntURCvcn1P4GTTcJ9YBaZGd8SHoNQ3mZ+
L9MIbM8J42kk+Kn47olb79mNsiT/88U2bAis5DaT5y5GwqC9TKAJjaU1oZU9
2zqxuT1cSvoLG3fP2K4JWdUOelbj8Z1yNqgmLpkckxYIpikwnHTY0IzaoP91
uBgnC0xnHvZScMyfyXn4ioEBTvUKynUUJgFcXs9CuqF/eK1ElRML3/iEfMNd
uqBLn9G4KUTjxpPJGp+yLhwQaVRceodG2ptw+4d11WjuarO28Sf91d/i9fpV
AnidNG2S1tE4IH/VZCyjGXG2cZqDeRT2z7texuJvxbPitAdh/oRvzrp2LVmd
uCpolxLdRMPx80H5mSNvoN5vPaN0l8at6XOZwVerYBG2qLNchkZcHe+fHNNO
JCV4XmOR70uUiNbrCiVjgPI6kqBOQ+6kR1WYYyUsLp3VdtpJnvf7Jyzxuxt3
BMQ3uQiwIbI0L8zjWg0WSMcaKvDS8N7trLk6IBXntSPbAxVobNBO+Pk4LQuz
pgajKQvI+9Z3WPtqdcHxsd6HQW0WPnl5h04z6jEkJN4dYkYhKHFOy8K6GwEy
B/TmK1AQ2au5we9ZE9Z+Vljx+CHRhyCe/vhciz0/KtZ5PSf/Z3uGzWHXCSef
xmZnci6xZThHUuYNpmYSR54SvnG78CtcHChD1RIVlzyC31zgSMLKvmakyZjd
dFdmo4E3s47xuQebj0r6cTmxkbxv8Gx9aR0SpOnlnoMUZDriJx7cboej/mHH
ElEKdabeqQyxIrjp/1XUtqbRFXuj4BCqcEFgTu5vDo3KfdKOJ76H4Kb1h9Uv
19BYy21WNm3zEvaN6i42fRRWalyhbTdVQ19i2kavl0ZAo8Skzo02OFal+G2c
T2HZoyObSgi+/qfXHk9fRvR+OZy/mfEWXE+LTaYyaYQHM183RHdjbUbwxvTL
LLRyCa/Q0u/G74toWpxJ9G3kFn8zvgj8PI/yvL5T4Ch3XXJRNQf+jLexqkto
2LfIWf078D+MTy0xz5Mj9a6cGBrQeIIbDcZGoyo03PgM78V15aL0zF2tFcfI
deb2k/sG6iDSx7OsuoKCg8+JVWXc7zFj+Uxz1pLgu8fl+93fndCdN8/fK56N
XINziWfNs3F81vvtaeIHqxkjSRWfqsEOkEx/UUbwsNjnkOjdhCPrkgReOxN/
pS3lHsUHwNvd4rIsqUd8NM5vV1EzLuZlZ3ExaFhd/dqvd2kAaoK2BlmjI5ga
lU+c/FSI7BnD1zM+NHwFFFNkLEvQceiuvgepX65gPIzxtAHFBiPfn/PRGOLk
TWMn3INmsNseO8J3uT02WWytbBiZ/FXeoUr4mj8YaxCTCSfpZ1H3/1BYXBNo
OBXeA7HAF3O2AuT+KIl738TLYNHd2HLwNdFXc4aJXVArlKQkHNUGWTD6W77K
lG6B6fz2utIfLHALDObnJXaAZ1o1a06bDf1+C8GQ+CYY6pR2qtWM4rS7/lbT
hUzkyL3P6e8Zw1N1Q036bSOuKgbvSY2m4B75ZLUZTzEK574UyeyjwfY4a2Y1
0IneGr9IQy425nM65Sc96Ib3bV2TgF2jEOZ/8qh5fwt2VZkblv6H5/DzrmzE
kTqZsknraexR3qVgrJCM/a++5yXL0qhb3nAi8H43Km8VbrOfZCErVz1U6Xoz
lJgysTpXKGTU7RY3KegGpTbNOzZA4Vxqlof6TAHm6kuEHz6gcDhQqt5xsBIB
39ZdaDWkMd5maB9p+g7JH7OC5cMoPIxMyXyoU4MEYcqFSerxjg9LunC0EVbm
PsecvCgsav62o9P5Nc7vqUn/eYmC39C2/Pjlg8jIculY7TyGdcm5qmLru+Ei
eOmrxioWVI/8jPjJ14F/1ZXCy8jz+6M+tt4ty8VMTAdsrWjouiqXMllN8OKy
E/PzJfPlyavEv3YNqDj55JSgN/F7BdE5XsleDK0YS0s1Y2GrasSAQng77EeY
v9KIH2TkDk8sVuqA02XdsVPE/9tfl96z9uvFsWiOK/2VbFxWiXO/G9cM2TNv
E5vnkXMDudyr6Q043vuS3+gHBa8Xxeem5jHQTR/x8S1hQah5sVnDrkpY3d90
rzKDQsFIq1Tjimo0tOUfv19Jo4XP+s/hw0y8uamSvqmajQXLas5/WlyNmleR
EdN+/+UNpf7EK5fwweKIq8oKGkHDV28psavBjPviWcygEJwf7CcT/QxWXvq1
Vz9T8FX+tNupIwdLmznv3pKnocgIXO4l3YkKjduBqu+IHx7ex7kirQHN5vXJ
ZzcRvxTK5cyMqsEXWs/13DI2xrdL2D1ze4cS+brSWXU2nrZczfda2Y6mCLX4
3yQ/efgnS2cwa+CWcN7Wl/j/ms8CsodWdkJxQOb4Vhc23hRpFqw59AJ2a9bL
7Cb1ckRn+Ae2P4Dil77I3eI0hMqqvD6croSPlOiy0ML/5snJA7/bkxFxdJpv
HeFnQtgYw6D3Leq6UnZ4htE4OuWw9kNXBUbnpS582UbyIO9wRONIO7YoL6Rj
hVkwTl6kVTdYhFYDRePi5yRfbL3qE9WQCvWaNTMz5HuOC7+kSqv1QsZPbEPi
T5Jnfp4p/MOZDiFHB1EQv/6WnRxVqBMI6uhZkd/SZJ54cpp5FtVCq0ihY470
3/J6s93Gti70H3xgnLODDY7YWn15+WB8K92ik0TmyVCjmuEF9WYECm9lahK8
eltG3N2CmITXZTxGFylcUcgoa+3pwXSDc9WA4yjJtzJlGbldiP9fvp+YBguR
VpG3sy50IC7GuPveNpIHObNOvRTuxJy00K/EUwS/tPmOpuaFWH/ng2lTGwW7
jqKMUsE6dFbb19x1pRAh974mIJ+BiVhJ1xUOLFzW1yw/n1+LlTexU2g1hVm+
IereiSbcoEW10nto7H+rsEjjSh3ib2782hpL+uF3J+7SiRS81s/jzCH9+n3i
V6b083Y0nOoIzCX5d3LP0IxReSUa8jljtEheVvwbdeTAxnYki+4I6yR58f3z
IMfp+g74G3gf4hulIDvL7+a9uhMcXPn7j0SQ/oYvyO7Qfof9/1taqveJ4Pfc
cST/cD68Ug5LP9Qj/pNydCdjUSNiVTy5Z4h/mnMnh29hVuGWjcn1rcTvrMrP
HP36hvhnj9L/GHkkD40f9PD1DcU7yae/5knQUF8rfOifdj4WBxVNehK+T19g
L3vRWwyRuVmvj8tp/HE3M1wU2IWKc68SiydYUOISXOXwkvA9OOy8KPm+0lNL
52OGpZDiaRg794tC3Cd1ZS2RJrTIrvadfc6CZmmkB9+dAfjUzSr0DY3CqP5x
gOejApywcWDaknykW+DDjLNsx5n5Vd4HsmkEHtzPN+r8HpuHdwTPXmehOOqH
VE/Sa5Q8t40pJ/pZMJz4Y3hJNea+eH4qIfn2kbCS8q/4d7ia3m/X2TGG0+vP
ceuoMmAcU/lgiuw7U2lfhh1+dED9AMeSiHejUBHj0jNYmI+pNcv9TpF9oDjQ
sqdQNA9yjDS+x4sJf234ZB1uMrC39JncpNcIoq9H7a3hqIatfnr2GrJ/BHBs
iWnVaUfq6UpHyV00JN/ZXDoxWocdxjsEK+IJHqWCKp9738Nh2wtR+9sjkIsU
OTlXGAP7iIfpvkQfrkfi97mHxmO91MNT34leC3Y5rbpztBjFiba5gR7k+ohk
spLrS8ia+3JquJB+qOn9EGssw64czm2XiD/bPcmjZEs6YaFRLdG1leTdrzPG
Rmn1GO9ZonSa8LFmqZ9KrkgHtMc+pf5KYSFI4Nbgu5R2cNW0TlrvGcO4dfyB
F4XtCBnyqZkcJHwdbNimmteByfTQt9e5CR8cTzAWve5G04q1ByYXs1H8cXpM
guSXueTTwjEk72wM5J6yMW1HZl+w4+PKUUS4KOqHFTEQcaZm/5PkMfiuLvhZ
J96K7zlzZWdNCf7XuQt/5A0g9c12Or7pI+lXgMvFtF6S4ydvz+gS/3i0YqV8
VTOmzty3MFpI8lHGMpnxvZW4pOjeERpDI2KOT24z+T+tJpMME142Nkw+5nsZ
kgqLF9uT8whfHweZShQcYaKZ97lt8BfC95aEDFH6PZyeCR04pUXyk7Phzz9r
M9DKY2s/QeZ1bso5H2n+PLw8ltlVaUbD6NfBBrN7xF90Pi6aP0Khi6fLfHKG
7DML5Tg1SX+qNzpblcY+Q679eo9r5PlhhbfRjYHt4G/JqK1fzYbSAp3e78aV
YGcuviZH9scwA/HOpPEWcHZ8KqeXs+H9O/2KlgcD5h3Fjkkk/1zOvNxMvyjD
1WPaD3LJvLEO65O8o1MELwnV0Cgyr+wDeydt0kogvPTBG6EiCuIuG1Va1pTi
QKjuFgbhz41sH6dZ7xYMj614Hj6fxjv5NzrRJe8g/Hewp3wvG06CT+7uNO8A
w0jreTGpZ6jv+3W5kzHwZTyZH0L+Z/OFc/Hz+pgY3iB7+58RwXvcZ1vJkRdw
2sl1fx3Rr+6KTUq77TuwsUI/3motG2t/Lt3Y0pqLVKkYf/VVJH/ovHGmvneA
XSgq1ldOYf7LOVbM/Gp8kLQb0D9Ko0lLqGf8QA+OfWW53/qP7xcPKywK6kXk
ZZF/C5lsqBt83fZpKdETY9arQYvMY2X+1riNb8Af/fnIXQcK62XO8iyY6IT4
sk1SHm1jsD/ru6R+qgmHdqTkcGRSoMZyVcO1eyB347xLtiyFR3f0bb5c68bU
imD/t+FspPkZuf2Lf4su4ZaUyBJS7yu9Vedtu9H/NFHm/k2yXy3Knj5l1oDL
wkvUfG9TsDVbIcVrkgtDz+p3naTeCAfnZfYbU7CxTV0gSJngEzh2YcOaMKhp
vSj7K0ZDttZDeoF6O1I8bxnmMFkYmrg9q3XnDXYKdG/SqaSQP+/LBYO2djDW
VCnpkf7ol//y411XiLGnl4OMyPkN6n3CuTW9YM3o/g4VGEM00+tk3PYmhDnf
fp0RzUKRQU+BUC7R74CZlvEEhdVxyZq1svUYMRm8EibGhtDmMyyruUYEaf9v
3mle4kfL3s6u421B1LSz8ncNCt/Mxz5KOnSh79SYMBfB45bRwP69fm1YIH/t
gqk0Bf0KEmCV4rHH4cjYf3xirlX5rV1VhqW+h5XlSgm+H5QT+y/mQHHJxZRm
sj+4jr4yUz/4CnvsqkYElGhQCxmCiXWFWFbvZ1UmScO90yfXoICB5RXKld92
sLDyt7jUmroW8NzRjasj/AnuH5bNlKwFV+vYni8jNCI3dTwyvlUA82dBB+XJ
vp6s2x11YYIJG9+CxJH7bCTwlyc8KGzFxZ1pEpk+FFwjY1SmjSvgIevuAYrC
ZadZo5VcZXjK4pF7HEphMjKkWKO3D32ZanVjVmwww3dzWghkQo1Pbewcmcdh
GplcgkqdEOSuau5OZyEnyzs52a4ebaI//yk8oxDbqPPAVr8Q3K2PuxZvJ/qs
2qU+KdYOjQ83GZbyJJ+K5L2TJXnG9b7towYPCkPXgiRucORggbIMEgl/7QM+
nwvQDcLltJhoPZJnbrVn6o6HdOLC/TeqvmRe2vPK9Z+2j4I+q+2NM/GrhIqK
1dtS/SH850mfKqlPoFD3/LGFbXAbOftRhIvk7XBrT9O/zZhXYa0bbMmG7qa/
njejalEZL2x/3J3ouUvDxN6uGA18zJeLSX/EZp9pvnNsRMxP16P2/BT4L+r5
Sl5owNTrfbXlJF/LLY7UW/otAjLfjt9pIPoV/vDQ1pAvBWb+ZTyVpJ5IVu/x
Bf2VGBQtqRYtptF9X6p2TXAVotUunYk7T6GlaL2CRkUH3A25LymuHEPoaLJF
p0QD7qkE3/pzkejjVq/BxN4uuL1af7tUmuhv1+1FU3wleCTk/6NtI42Kpj/m
98b70PtxiCtojIZoiHzMToHX8PZWm5Ak+UPubshRq+QHsFNbvOMc2ScTzt/U
TQ57AQs+yTjXXgq5VeLu4m4JOJm/Q/Q3yaP7frpvEuFpwsrv6/+JlNPI/7ts
ckKkDRbOruK1bmSeDf34W9Y9AAfblL987uO4ZFm4Jme0F3ctby/VMiX7O5dU
gUuCDYzm9L5TBP9DsRn+BjNM3Fj/XjR2kvjnMld/5ggT2z0GVQNv07A+vfRY
3Zn3MOedGGC8If3gzN7170cJQoMfDI0rkn39veWHWTShO030fFkWyZtJd87y
3o/GlGxfqjLRR8JV2SydsDbMDXUEBtjSqD+Q+WHCuAcyu03TBch83jkk+lc2
ux2L0wwfrSP9C0rlrg/h7oGemWEV+xQb/wfEXPEq
                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41QkXx7lRzMhrLjVSiV6U8ipGEeprlKJuulmKRsVtHyrFKGbsKhSD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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlWs41AkbxodWrM1hlVE6bCTbAeuUzSG36K22qFZUq2zJaJEyRVbkkOaV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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 179->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXs8ldkXxk841EyFaqRySco1lyExbo9bE5qRLhQRhUqi4xCJGgkjNKOo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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k8VW8XxW+lEiWkSRIZo8xFRctQphAyVfLTgEoiKlJUSFKiQppkKBRl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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHtcjGkbntKHSKHkVA59SVOJrEjhkpatsCq0Y20n6YgYbEVKG9tGKo3d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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVXs41AkXHqas1H5pQ5GE7a7QVUKvTc36KFFJ0oekHVvTVTxdGPcauZPY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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 180->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lVsbxsnQtBtRUSjJrEgO0enOkDGShKgMHdq0E6KjlKnsvlKRIqWE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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2lczG8XxrMkkgopStIilBbtCy5aSBSFFkVkq6Rk6R+FdkoUWqRFlCRJ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHs41AkXRpoUMV+URF83bEmx0Wo3vEwp4WtDWRFNdJlKIluLSsK65VYR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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHlczIsaxqckLUKom1GpkEqk7cOhPKHF0sLJTZJyLQntOjXhUpYKhcjp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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 181->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8lWkbPjH5TlQfpWjTyITQaDRElutYElNJWRIKLfYtRCqytCiylLFE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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHc8lf0fxo8nIzOJQpIyiiSVjJLLbKEf6kFpCAmpKEpJWkZIKqMoKTOV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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41AkbhuVQCpN0Uq1tlUpsJ1ms01Nmt9jCJHw5hERpyWFymCSqZZFI
ilDRtiXpIDWichqKMY1pjGGk1jQln99B0qcUYuf7473ef9/red77NgyMcAtW
VVFR4Sjn/1vXpvkD4V4PUrLsQRebRNAKQ5ZqRhMqBGot0edJ3Nu+10Cm6AYt
YYkK62h8DHnvfeyTGDMGosofelBwqWjbqzEshvN9V9ON1RRCjM7ZFsQ1IaB8
r++idBJXXQ9Wv2y/jdqkW0nJLQTetm3X/sX0KQp5VlK7PBIBvFNz4nSzEe5Z
yOA7EYiM7zuul1IDzQkNtX4mieiaxxFkmhTSrIrUtYdoiNMuN0tjxYgPN7K9
8ZmEdd/Cw/fCHiKSEzNtx3QSPf9j2kxLlOH7w/dY2ek05maqLx9w6YFkl6v2
wDsaFmnB7EDyGSaGrl6oPkhB0ecXkxjTCbdFk5sOOdHoYgiexLt2YGlIr1ed
FY2GBW+e2WwRwmIme9w6iIK+3p69w6pVsBc2G5uMKe9NrvvRMLsdDnSG5dZv
FMzo4WWDA2IUqV/9XS+OwqZLetfbkpqwbyDGJ+ERCd2NWPsXrxjq9X/8qH2Q
wK4ui7HG3+Rg2w9pFecNwlEm2ix15+P4karLojMk+gzfKx63dyNIkMU1zqVR
MvF+WUFcDU7oOjen/EoiIXakkWv3HK8XyjN/2k+hulkttUGjEz2n/bd0r6BB
SjNf++3pxT0PNuufSzQ0v/Xa13ILYGucXt21m8B3sreFbYN8GHcfmFw0RqJ8
v/9EsLkYLmmjvqv2UXjwvEdb1eEmAlLC64VFBOZJdsY/oVuQVbqE/QuTwjyn
0szRr0KcsWM0v/ibAletrnhdtBRtvpyJkxUU+gZk19xOSsDew40f2UFhVxrj
O1cnGXodNvDdX9AwKhn4NJX+HAr/EbnHSgrHbpdN6Wt1QfjxfoqtNw03Ty+D
mIJOOCZ5Wv5dSOGut+KdvVktbBqHsxPNSfDdHUTMITEiF+97JfxKYfrLIwvK
taRoqFVUFZnTiDxRFpAzuxTvGkbYasUErHI/Tl4OegLOtQhPJx4JlTMZyRZz
gjHa5rHiv8YE+N0q/ec/tCA4cI0Pi0Hhda1aNvtxFahezvHYRSTWf3vnvN+0
GSWv2wN7X5CQ+C+zvJLdihVdWqsN35A4Zh+mf7yoAuZnZ8xeWE0g33BpyIpW
AV4ym8JvzFLyEZuqufLYS3AUU+FagTReB7txU2qKcT0x5eGcKAJdEt9KWZgU
5q3f99+cT8MqM0Y8ChHeLFjHWrqVgsHo8yOLBmVg6Ef/pBNLo/tx6zbZCBd5
Qxt8awgCZpmKoSXVArjw2MtHNClM+rl2j8V14aHGxPU/3Wg8OGU1W22+GDo/
M9VnKnkNfxlx7uC6RswN5QW4hCn/KXy5RrrabYRxA6s2lRHo1vh860qkFHJm
UwqpQsMxlnDjbriLdUknX13kEVg//3gF278T2mOZsYZZNIJMS5nejDrUCrXq
ZywlIRB7sIeLZPDe5izscaXBij96MfDkVbi/mvU5NZnATL688HKAGGJJi7Po
mZKvRq158p1tmPr9P8GqJ5R9v08Mt8itR0n7uL3EXplvIe/d9oRQlEz2rR4w
IRBy4+YnY24TMtKiHN6WkWB7GefouHRj1gHThLpGGvqOZ2OcLR/BV99w5sBC
Zd8s168dA0+hK19rMXhf2Weo4LRqYSUmx4M4X6YI5IUOMmXRrTBs0Yut1KLA
UU8PMzjdhjyOY9Ww8h6WiWL321Qe9Cy8D+w4SeLR/oZRFasXcNAysbuwicZk
9iPb5FApNM/rtjOX0yBES66MnOuBSX5+i/ZnGouNrKM8WVL0zVwny7hL4Yfq
hNvl/jUwkx+hvFaTSJbJTb+8EiAypKSjeC4Fo3/iOlcdeIpuxuiz91dIcEK3
xQePS1C9Zq3mmECZz902/zyfW+jObc/64w4Bx0N9P2zd1oSWraMKg0Mkgh8v
fHTHV4BLpzr6G3dSYBSbv5qx6gkWzzkXu6Zc6d+VHRnqmZcQm2XKMwghwJm8
9vOxyQ4UJS7hKNbTyLeuKis1agJnItXS8YQyr0NDNhe3nMPqPwt85nkQ8A0O
avLs7ITft7n9abuUvO08dV6nTALLedf7L/EopLXox7hvrsSv0VL7qUECuju0
HiZ7SfBBNpFTU0ThgzA0wmFrOzaEjs+uZ1Ngig5bq31W+pg/WFyZT6OI3vM1
RyhDXuMBv+zzNGzv6AYlsHsQdfRiP3/pIByeKiJEIqUf95m/qTVV+iTHR+qU
IUDT6vQk+WIKDVYXvrhfL4BXHGtafCiBy2Y+rcszinDRv9+uNYxA49ttzQkh
QuiU2j3f3UlC3c7O7mxtCZYpRgU2ZwnU+AQ30nEt0F2i/unpbRI5dO59uVE7
dKRRWbucKIjyFH5qgZ0wmciu5NYpfaGezym8wYdlyua9czQo5DI+muls5OOv
zgaL36Yr/VbBGD8akgdrhiUrw5vAvwTc1yA=
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVGs4lAsXFaWUEJFEksKRFDEpaal0U8cnXWg+OboYFRJJoyg6Q42k1Ekq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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 182->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlXk4lekfxmlijL0oMkaoUdmitNi6T0oTyTbWaIikMKGkM9WUJTJnzJQG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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4VG8bRmXPVraslSRJqKSim0glihKSkCQtlkRJJUlalEIhSSKFIhLZ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs4lOkfxtGJQrW1GkpNOuyGsLEjkjunaLOEWoefSkUH6XIIxbJasTtR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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk3s41AkXxyVCSmxoN7RJIlEpucV+kVZvpBBZKvK6rIwi2lzjQS6VbKWI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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 183->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lPkfF5Zsa1KrrWRTjhLpdlbecuRa0UGJWkdZOTYZhUJGB1NoHNnJ
ovwc5ZbbxibrruwYM8aVZm1aX1vYtnUu+/v2x/N6Xs/r9Xk+1/v4bPQ4f+Ss
pISERAp9Pr3dDl9aSHIrhcqi/+7RzQQPDg6NSaZ2oWR8Q3T2ZQJOge3LvOky
RD2Lzc/YSuB2qrjlg3U27BwZBSx1ApN/83QFDC5G61guh9UIxEzRLYcBLhTE
Mjpv6Xf9RItpjmwPxqdzWl/RfHuiK+Z1fTvh3Xyq7o4DgWYtv7d8lA8PX8Vv
3D0JOvkmk7bhz3C7MPLVWj2C++0Rk2WBAjATtk9n+hLsuPL17w0tv4C5Pnk4
yZRgMDwi92FUP5wq5sU6v9L+Lrn0xf5Yi5ZKpZns3bSeYMjG4GUX9lzz0iin
9V3F/mPpbU1wmgjr2m1D8EgY0z4VysPK/TV6qt/T/Ow49ZqFAjTGx9Ss0yTI
L+LtSjAVwezVm+VlmQQXgpVtVkj3I8sqOK4yg8AF6sdnFXpxXZHd7ptK+9Vc
ukLTVQhWzANMBBO0pWp/yVjZC1XNNb8G0fjCINnLq1JfQe0Db0S9hECB/6Uw
uzQRWc6VDFe6L7/xs2fXs5phE+Fe+9GWYM3ktKPvEj68qjtGRlwIVp4oixP/
+QIBr4qWXbaj+Kzrq9ZZXY+te732SuwheD3WKjVxRoSfU9qkTG4QXE++eu29
eSM25MyOS5kRlMZc9E9XakTx9jsusboE637zTDt+vR3dt/WVYUHjn8v0Htw5
BOs1Xwc+SiLYMLbcyv09B34BYdvmVAkmGQ/D/UsFGNPb1PziJsFF7z+nftg2
gFS1Dp3gFIKgQi9Va78upDxn/L0ijCBE7aBh2nQ/Dv6rbjnAIdBX8HgaOSOC
zYUntossgsgwfUX05yDKJkeTS/kUcy/JemSiCzuqeqU5ARSfd14l60NaELlC
oi/BnsDoY51416M2SMH9QqgxweLShydOeIjQMSx9YTibIO3GG1eeCgu2lUoG
zrTflT+HN10basL3KvenCs3p/pP++11J3ASF+qZ7Z0DnS/9DxvEqB+aM3PpP
81nJ8nRTW+rxVvD4u9CdBMlKorT0ez04Lb0YmptM9XHFSGtUNw+uS/uNE6le
NsYv3NhW3o77LOH22gMEy4II7+iGATxfKS1zNYTAp30Lc0dLL+Jnnl67TfGW
cHW/5LnTHrxVnIyFjXTeB6V3w6UGEb52zxOzfgLFg4Zh0pYDKLjh7aZ6lyD7
JDuoQIWHULvB8j5Hgmb19nkFQTeU98qNHj1H9x1gP/fGtxfbtLvsOsMpXw5K
HWMncNE/W8+9QvlkIrsxYvZsHJRSsfkunS+SXR2q4fIaM9+8j5ql+fl1Jl84
jYmgUMS4ZBlIIJTLy3R83opSjibn5D6K92e2ykdIIUqiuuWVqB4UT9z+fuwJ
H5MWbTWiM1RPeczQD6ZlsPrgKfaj/mDC7NJbOH4H71afFM/QeibEMDfRkgXP
3F/8TD7VF8Qn8FszsJ4943zzk194J/A+dgug5dX2JzuWQOtbC5ksh2cYul/9
twfdf665RorKP01INCuIljMikDH1t1sS1QferfgjCWyC/vT/kmQbBzHrlNkl
bqb5/80ssBgvgmIbNzmX9tsrL5vuE9eBR3v+qlS0pv7iYKzxh7cQHQkLEyev
Uv34nry45W4WEjcE15zbROCwXl80r5iJlijl17IaBPvGG570GLaiscozL/0Q
QR0jwKFhvgnrKt9Hj1kRBPQUzl3fwQNDqKHdf5igzMzIjl3XBcmVP9fLU7xK
i1+cZrsXQdOQ7dtG+bIv76qWBacKYSqr3K9oERgouq6+oNSJQgv9vhrqf0f1
Jy9KH+7BaqZxjHo+QbHGVsNo+X7MVEiKzZ4QzFSZfpYrKofkZ198XqJN+4++
3XRU7RlcKzj7ubsov3IOl6SKfSDh+W5Yge7b1IzjGLm8D7HD+cQghyCqx1qT
7O7DdPAyrVWUj5caC9hew0JUMs5kD1J/cpgdfnjUnPrPD3ESmwwI5IoO1OS2
8xHYFc967U/1N7Sd6fuUjxWbx6q/oP02LElrcDOKgd649ZHztN7b8//j9B0W
wult2Zf7aHyb5BqtxcpOKJn5/HXHi2Bum+S5VmYzJo6pGX1F/W2pKTn9h9tj
FKiGZ1lQ/phOeNqYtwjwILLjsn4i/d9jugUh9dDT0a1MofdgrFK75qKwD7uU
P26KovhbLQ96eMS+Exn5A7JePgTcpK+4zV314IiPTnyg/i86HXSt2P4ZnJjT
8i/pfoKOPbM2rxYgcNi5uDGGoNwkOdMmiY+h7IbRnZEE3mucpa7oNmIkr/sf
piHBVvk+lp6eEFNaMiM3qX9NpraGbT7zC7be0+Dq7af3wfi3LJ5/C/SEoVsU
qZ8UNo3OZbR3w0/5PaP8FvUfPxk++8Jr/DC4oJlbSFAT9s1ZIasNDTqWhgl0
fjf7v86Yp/VBV3b+x+km6kcRryJc1rUicnr2hBLV34tFucHjt/n46aRUp991
6s8S1kUGvkL4BBlKd3oQsCc6k2ake2HSzvsv7BrFg51S3Sv5GLy5Tawpyi/u
ja/0FZ6KsKHgyE9V5wli65MVmIlNqGhpjRjaS/nELTl0JZaP2TS5bw9RPzee
GtoldbMbkqfOHeJR/339aOHrbPmXMHh7p2ot5beXV1pg3IAImgP3bSyz6P0N
28U54NuIrUFJst4Un9h+7cDehHqY/r6++VeKZy1D4vTnbQMIG+xNUqklcApe
et5ToR8Z3WYPDtB5FXrOuui87wCnKpivc4JAeswtxDCOhx65vXVd9N7HmxS/
lJtvR8ySEKN3TrS/yxO1qsUCCK4ablZLp3w6/fxuTQQfFd22ownfEsympKg+
qhNhME3Le08U1UPCubVK2S/AzVe39Kb7Lo32NNO1L8UYb61b+RbqN8bLhHgj
wHda7pE/0ftfkbGzKMq5A0NzvXY3nen+PjC6LZgN8GCHyQRRPEK6Naa0r3fg
jbJJvtypT3pVvinF4qNxRL3+PPVf7wDHxez9T+Hzzy0rPxr/f3uMssc=
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3kglN0fxZFspYQ2Uray5lUJCYdSaZdCZWmhIiohiRcVZV680kulUlmL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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk41Wkbxy1RpoVUZF8qUWpoCknnyyRcbQbRThxRURSa8zYcsqsGpXTG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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVHs41Akbna5ySWpVU0mUJMIqRZev0xYipRCpaZeQSDXablPIdaVS26jV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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 184->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs8lFkfl5Yt1eYNpY1CGqWNIZeuvpToolLYZEsokUaElHaXidyNptza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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k0VW0fJSpFmqSSFFESUWSotGVKRJHCW4akSZShQaVCZZ5FvUiUCOE1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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81PsaxycRaRM6behUikqIQutnIqFTQkp1XtdJGWlSiRzqproSmhzM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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXs81IkaxgfZhhQ6VEfkktun1cV20aZ6kFWuRbJIckkiVhNOxHRBWeEk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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 185->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs41GkbnuXb6KCirkk2KjZNsnKoVsXcaiSVSpTIITm0VlZymE8RyQiF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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c81f0bxoWMspoaUlQoiqcyKnWRlCIhyoMyMisjoyhKisoKKcIvSgPJ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41QkXlmSMUFGZFNFeKI2i0nhtbZq03Uo3YYg7thBF4suIMsp2JzN8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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVHk41IsaHnNKQirK2u1OUTxRHFFZ6rWkVQyVZMkhS50jpc2cGoo2lNCC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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 186->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVns4VekbPenEDJkxRoh+yCW5VChSmRaRUR3XOpp0V45rLkWKNEedFErK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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3k4lGsfRkiiRFmzVLYi0iJF7sKpFLIfaUOUPakkp4WSIiFbQkVJSXzZ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81GsbxkcJh0Q1ee1LyrG0SNJy1MVRjFKKc6IoGk22SF4lS5020sFg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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk41AsXxyVZQrdcT8iSkXu1XI3qhpbbV5eKbqls9ZBiohoisqTervCm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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 187->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk81Okfn9WPnytFRVJtIqsJG9oalLdQIaVjKulUSOWKWkdlUFZkqFVu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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2kglGsbFqXSORJZkiShTSVJqOOS0CYJ4UTSIVREJW1IlkJpQRIqW5Rs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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs41AkXx+VSltKuWuk+LhWivCpS6svo7bIkhLKlhkhtKsktbWqRTYkk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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk41Isax0VJZI1GUZajsidFdaKvtB8tWuiGkpGyZClKRLYzkWurY5hu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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 188->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs0lGkcnlTSHkkmUilFoiSTLVKmh6KIRUTEtoS2iyki17aUmkEuEyep
1KJCbhWqoUZoSJPRuE6uG932laSL2ET79sd3vvOe33fe7/k9z/N7fot3H3Ly
k2MwGKn0+fkejbfPzOBLYPTX3Y7Z2whaI6ySmPw2vEryfbQnl+DWmdg0wZ58
iGzMXhJdgngOv485IoDPOgdNp5UEjE9CL1+fCvAdLHjP1xP8bR/zrnukFRlu
7Vo3uQTPjyl4TfJ7gM0rf7U9t4rg1W69Nn21NnwPmRHrvY/Aqb495M21Ksxz
8RgbNCOIiowv4V4Nwk7bOl1tLYKwtcFbnPPKYdiq6s3/lcBq7biwjNGAz4ZJ
C+1sCRbVuKo9ZBbBd6uH71GKTylgYprSWDO+DsnUYuMJZvsG2isuFiPLV61/
mivB0YbXBk0iCXb7/tGf4kvxF8mNsr+7IT+coz+Z/u9rTNPaoOQukO8dPomX
CATfh+V91NqhM7DQLayAgOt0TYWr24x5JbN7Ik8QbI/aOulwQg0ypqqPvbEk
uL18v/zCmDaEPY3lLqd1VpZu/3bve4hTulEesYKgSGOHNSupFIrGdUu2Laf3
e8fYqq+X4JzWcqGdH+0n4d88izIpPMP3WtpRvOp70wurD2ajz6F0VYkOAd9Z
xEr4IYOTkc64IITgT8GORc2rOsHtmmxbc4EgQ/7b71WsO5gSnRrEpf/b+7bS
P1SrBrXZL16/MieYIjhod3JNI7bfiBCK/yRYa2LG+43/ACtnmh7+uIZAOns8
y0KvHq4hHbPZ1gReKvu1l9U9RcSCuI5KK4KPbAsHQvmoa/qLGXKbQMu3zHsk
vwXbKwOC8yjfgyExpyssWnDnsWvvJoqHgVRFa+smJDObGiM8CVYPf4hWMq5G
99hSloopQSWmflO3qcEnzmAmg55zm2TC3t4axCWybv5FzzrJ4iCGdjMqClO+
GEUTbIvPW6DDlkIupXetnQOBSNRXlzwmxfEROf2qYII9s27E2ii3Imp07vQu
qq9x8rOtMXHNWGiYdCSI+nFIc3J17w8xNppwBqwcCYLZLZpGyo14KhgXmlI+
RSVFvAN3WrDmx0xF9yAC+6wDwydPStE9v0JtQyDlVz00+JXFCZiveKHhRP1i
beljviyuFsbvZBxTEIS8MOE+qLiFgDzHAs4yWv8YMGewrx359ZdSEm8SiIt+
9IlampDdL9SVUbwx9QapSxsqYao+cDFoHYHKAz+rd4LHWMGOXRxmQ6DXrcRi
RAqhhy91/6ym+hgHP7nMLcFKPxisofdfVOUZbjhTjtGlMzWCDQnk3/8oPe3e
CqasiHed4g8fWjJLoFWGlNTra5bSes4mSdmTwg5cTHnuJ6B+fi7ZOaVP1IyY
DrkTnxMJ3g0qqnx51oEeLw/XxLNUr8uP+fYdnYjKiuT9IqL++1LN2qh2A2Ec
2cyXP+fNYdyvoLYZPYfGN7hT/SvZ/BVvLO4gpMS2PVef+i/LVN3xRylC7Ry6
zVgEK3N9GKe1uqGQeSv81r8ED+6+Zc66LoN55f3jvxURyM1+meXd0QjFRuKi
6k757j9au60uFYuKphee0yb44qjrzposRd+8DP+cgzQ/Lmh2KQubkKp/sGeA
6q1Sxx+bcbsRWWfGnLS9CN4cizJgjIpwz06se9mC+v+yTbycphAe0cydN00I
8kyE7dEGPVjINLtw9zMBJ3m52sKKOpTnKggK7Wge2ZX65XU2wVOTm34kisD8
aOhIP/saejLsq1WXEmgMZocv+yYBi23jfIh+v7040FayWoLhsnR/LW/K38nE
LpP5Mkx32WeWfoXgcgpnyFpVhmKedLTjDMVvUq7skH4fCdEznzDp/KWmbpZj
tLaB9bq47H4y7fdtorh4rhSOq85msjgE9ecmqTOOtCLxsHtRLe2XxfE459vS
AuPH8+5G0Hrdrm0u8/eUoPi0X12WAYHCPzsOvXt2FQVCTztnmh+JxpzRLdZd
iDgl2nWxkfbrkPPCc343BM9yasRpNG8VC6ICO6sQMBIYe8yYICC39KRCczJc
3eyP11K/e0zlDOjel0Cub4u+qg/dBztE1TtzG7C++v73sa103iV736dWJeBL
eMEqeaoXP6hk3+bzMrQyKmr1CgmUgx7zxgNKEPc27UgOzaeM43My247JsKic
Kc0tJtC+wNEZ/ViFZy5exzJoXk1cjEtO027HPIkvi0v5Fw1tnSPQaYNO9bpa
bbo/PmSu/+AmLceeSI3+E3QfxbQcd96hJ0S1v0uaPOUzYtrgaw2TJnxmv+K9
CaD4AnfrV3iE4MW4cdkS2k95ikOBWnwb0pzHrnvSeags+3rMX00MleH1k+Jp
P0PG81J4M6qhEtrE/cYmSPo0l9tqWguXoGsGVbR+Oyspo3ByI+Susa/kHSZo
SFm9qTesGRM5YuXpsQSahyvfXvVvQXnZq6uZuym/dh7iABQi3ZEROULnh/Xp
q8QyLx/s+JuERc/LE+p3WQW2wVXbV5ZwlebhvYopew07UMfgxfvRfTSlK8Rm
umMjwhenVUojaT4PH72fz8/G67emoTupvmn71ed6TUjxPqu02zic4HvOvpAr
FjWYnBPRxaN6FggslSZ2NyL5ZqzLm1CCFU5/xEyb8xjy+zrZm2nem/GcZy65
I8O0vhrDnmvU38yr8huqZTi7j6Uyp5TAtX+d/X/ZHXDjXDnw6S7ly3tTVdyK
Tgi6Y8UWTwiMNLRMEp41YZfhXNyg+hi5+6xLMRChwUoh34DmuXlY7inJpQAU
HMlPUPrJ/6TiGdFjT8C1Yf0+1Z72O23RgmFhFbTqT5XfW0v9LO2ZcEl/hKFt
H+y7N1J8Dtk3dp1Pg+epHNkh6i/5R8qn3le0QmqUW/X5IkH/2U1BD9nPEb4j
x3EVzRP/WhurX/a0oMtDnvM39atlYNEydfUGCPX0sl/+zBd1Bc/bDWIE37Wq
qXCh9/u0dU69R/Wa8HzHPESQ7Z7x9PJoK86qzgrfcJTqZXrlXIW5G2Y0VLbL
Ufz+/w0MXFJpg3Z1r38qn9ZTzz90e9KGqXPszWzoPvkfQfClZg==
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl2k8VWsbxlE6pQxJAxlTlKlJqORykKGkkhTpJJUmiQZjCcmclAgZM4+l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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXk81QkXxildu5SlUHoTDbJrhmwP6vVSpJHUSEabELoZM6UmpE2LvQhZ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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlXk41AsXx4dQ7lvSptLEUImyhaJe+Y4suUioq1KELKWUvJrGRUqKFnuX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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 189->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVmk4lVsYPVKhNHBVGoRCp0JCyLQOuYokcYkiNNIgoUTHSRpMDSKcUuRm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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2k4lG0UplQqIW2KRCGFTFmS1K2SVMqSbJUUKkokSnZZSkn4WilJEors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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk01YsWx/GQkBQq0TVEV4YMlSfTF42oVxcNwumkFClNnItMkToNuqYK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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlH041IkWx11SUivTi7rlulaUSjcyN2T5jpJEtSVsUd5aare9uOUtVGYk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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 190->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk41VkYJsskTdFiyUiFiOKKsky8dpUlLVqobCkZKUyRjG6GmmTJEkpK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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8le0b13jVG0laSKG8kYTGa6YvmQ1eJKmQUVpEVkIaIkkSMgpJdpIK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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlWs4lIkbxhEl24pllxSJ6bRJ0iQbuZVd1CoSKkVEaE3FpoOUv1KymlpS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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGs81IkaxyXlUimVJboo5ZLLKrQzYX8JpTGh2S50kSwdFZVdIjllShYr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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 191->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8lVsX1lEdokEj1b2iQkTqqgw3D5WhPhGfIVEKyZSIOKlEUhJRJFFu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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3c8le8bx6WFikppUaKMkiSVlY9QKUSS0RAaRCKhYaRIRVnF14pC0UJW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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk41AsXZkxS9yI3W2lRTW5UkpJC3qkoSpKQInXVSF+ihxYUXVHhk8oS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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGs0lIkDxhE1XVT6/7u4lIRSjS4UauWRWEpb2GojVmzkFtKutEkc1qUL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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 192->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk8ldkbN0khTSotSNaQJJUtyVdXSQbXqCvlRwkliUYYZV9+0iaRm0pI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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3dYTX8Dj4ZEg0ihXUJJRKXwCUmoJEnSUmhpGSEhaamkpSWVFG3RkOSn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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs41GkbxydpEh201KKEUNOuonMU3xSRWkmSLb2hbCSHYpcmnaaDiOjg
MIq8bQ6dUEMZlSaRYWRmJIYYQul3cEo5Le37e/94rvt6rut7X/d1Pd/P/X2M
fIJdfVVYLFYEc/5fxV+3XGdlNcBsO0d0U0xD9EKiqXR7jJgR/qTpVQSah8w5
gVM/4Njmtm9FIhqKsufxr0Mqsb4p8nzmFApqfVk9c/6oQLpwk7GeksRVf6OO
qie1mL1qnN5TQIH1y48TN0VvocU2aNG1oRD6/LcfvUHViE+d3zj6kUSumfHj
6M/NcN6tYmpxlwaLPlxYyrVFGnFgUbAxAROj8qoy3VqocbXGz52hME34p8Px
hbXQiSuxqNCmcSdQ9EL2RQ5Fbo3RVhUaYQMBhUYz5Jgry7yh5UfhzZFLfmoz
6xGgdXptRR+FAq/EUYr7CC6I6fFqIiDia8odWmsRO0MyuvI0hYy6EPXM3Xxo
j4Wse+ZDoHhfo+/r8HfQ0fyUYgEaTcWGllyeHKEPrZdwt1KY/fSCY7OgAf/R
v6K2Yj/zPjf0FR29TdjUoT16ckM3ZMFvGu8eEMKlyyT5nikJ9cG99u1+MsiG
Q21qTlCIWP6yKV6jCppVLu67llMwNHn7bryuHry96odOHKER6UCofZbL0Nug
jHJXUFiQMEnNO64ewoArk8SMXyucbgsEslJIL2u/TD9Dwj2JrX0n5j3c/5Da
dnNo0HFjAyH+chT6dqatzqGQFKm8zLauherWD2enPaSwnle3pJknwkme2pIP
Nkx/mfXyS3ca4XzRPd5vEQ3O9gBbx/O1eBPCLxhh5itSCgU31UtgaXH5ZZML
Ca+DAakPtYvQt8JOt9mYRGdr7weTqipkeffHGhhS8BPrxc57LcHWQQ//7D0U
vDR2jNkHJGJwScy3jl0E2PoNCZcmKkHdZx/vWtYNv2VtpS4DFTh0X3VboAbD
V/b9Lh+XAhS07Db16CbQk15Uvr9JgT5b7eh/TGm0xd4Q6lx9gKNZ5yuLsgkM
m0n2lXUV4qpR6d8FbBJuGfELEs/KwI2VSfbnM/P3TktRZJeDzasq3dlPwqVw
sFIvvw58/e1rJ2+hoeMa/JyzMBd+vW2WgnICkcdWtzdtEGFUZWPngh0k5OdV
wqO8q1Fv6BC8T5/x64REGlgsRQQLeas6KHB+9Y84rlUIq8a8P1dPIKFat9q3
1L8BSWHcCKknjc1zW+P2jL5GQ3O6R8wDEn28rEUbzIvR4r7BIGkaCYmOl++t
+CJUr+bvap9I4ssLLTfDQ5UYsPXdUj5MwsQ9pszZqBE/saYqdzylsdZpSqj+
xHpY1lq4kwzf6zs8pwuJaCzLzpH02BEIow84xi+qgGuCXba0gdk3+xn1EyLr
4Wg5xHtWQkPT+VTIufNZWPGz2PlsIoGUoTnOG4reY0qk1f0YNg0vvopGpHM4
jj1WbVy3lMDtyY5PTugq4NR/MJWypxF9slzQO1KPoDU23I3RNMRDF+qD8oRY
M3usx5dFQuT5PSQ39xkyqkMf9juQaPN4se/9QjmG/B1mqbdSuNd+jo4xqIW3
Q7i5VQ8FkXG1fJGkCbxHrSbfamisOb7b5RqvBVurT6WGhzH5YOgqeBkrw+LP
I3WmGRT+ihhUL0mqxdKXZw1LRBTaztRW8m1eIcVlZOWckyT6Pxcndwc8wXfV
DP66Lmbf5eU+43ZNOPrr198Dv9Nwevvhl3FLGdor/QOSDzJ5pfwoyOHtwQWt
+WlRCwi4rcnLONYpQ5fPmOBMBYUEj1PfxQM1MIsrLnnF6Klb1eyopw2oU3Za
WrUwfOnWGbxx/BuRbkbG42cJlCVbaDwazodVbMudxaUE5n66e03vnQSmGveD
nI5RmK4/K4nmS/GDM7Z4czAF8eGudNblOnT65fdrzaaR/2//lSt55RidL1Yx
HyBhGMW3fn89HR3SxoHBUAJ26Ue6bryTQcxNlt3Oo9Bns8fdXPc1VKbTDZmX
GL40iNyCtru4MKNjAjuVQN2z3zzNVXNQbzllWuZ15n66e/iW8C3+e1R77sUV
FMJqrll9vyFGouLT0f52hj+zlVRUGpM3gXpNHCZvrnu38uS6SuzeJ1USm7qh
prZgi8gkBy8KZ59KTiCwSmPOtn+G3yOny2DxA18aB7gtzl97n2Jp5Tz3C1NJ
rFPdIQzaLkD7/pJ1+a0EPHYmXgyLF+HJtYvJkz1JnO47M7R4ohTjbU+inVIo
fBPfk61R1qBO/eFhk28kEqxEM9O2KMCXlFiXfqbxsz3tUslm+H5k0NqaR6Jg
mO0037scqUFjV4RVJFjVPhbzMiR4uyPhQR6HgmuctfGSbCVubuTEzTvSjZye
WZlmz0WIecANux3A6D1L0kwWFiJ158zkL8z/52Uvp39a1QorX39BjZxG8+FP
vKdfRXAp5mg6H2B4zhH+HuhRBrdVkcWd5ST8nCYq2grKkB7Xbchl/CosSNV5
Fa6AbaDeRztXGmX8W9vWbpbCSz905C8TCv8DSIbg4A==
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGs41Akbxh26nNvVyaHNhCaVECovkttWDhXpzaFspXKxSSpkhUWkJBu9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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 193->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVlnk41Gsbx+WVSjmUojoldLJkCeEoyzdJaTk6DTIpS6QRUYmyFV0iIjol
Td43S2lUtsnSKcKQPTpjmLHToqmnhJYJJ07vc/74XXP9rud3Pfd9f+/v/blH
3esYw0daSkoqjT7//i5YJqOY6C+EF8d+POEKgWLf+ZmHziVY7l6iPaNLENw1
uON45DMkxg45l+wiiFNFuuKRHnzeHZjrUE4QWj693kyFAzXH9ysWriE4fvKP
Q0+XZiH6pEbh9GoCQ9UIF13bAfjue7U9mhBsOT3oOljfB88kQ3GpgECK4dPT
ctAFc8/kfZTSIHhvcH1nSLIQ5e9X14kzCMzDd/7Y1v0cX3sDSJ8/jTepRk6J
2iFd4Ve3Oowgem0Ra/pKKua7Cc/doPHOXjhrfMCtC2yPRfzaewRq3u62z9se
QXQk6EXDOgLNz30eXgcFYKnteMU+RzDuut2HHyOC77iVzVg6geVoT62nbB0m
gkwK0uzoeR+H/VBtAE5X+6dW9xH4bPuDqN9vhvmXLTdPbKfxuffXBF2/BoP/
Wdvl0vibD2c7tZX9hU9LNrk5/k7wy9RJc06uEMzwL5O5Nwn6DOUW6ASJcGAD
U/9DHIGvl3RiBrsB49+2mMZZEjyxurBLxq4WIzULlN5ZEZSGVlu3HSiDw+aE
Umt9AomCZO/bOZ0w9srM3xVI9Z5cEd2fWoJvHiMFpgYEk6dNb6QHlEL7kIeq
gR6B8p0jGeOybRhbofB0lSvtX07Sw+p7fNjudTlw7CDVXzE86m1WGyqsF393
dCE4HyNW98vkoT7y2AoWzae1cWpJb2wrUs323PR3J+hN1UiOVOhG3gBr9ASX
wMnIfUwxrgcMYcd66VoCpgr7JWOsBT6mTLaY3lfT4vzyxbdamOvfXWphS1Ao
GXtWVSDExEDBVufbBNonM4L6hdWwZ0sv7PyVgH1DIh4va8diy4KowsP0XN2t
KbmrAtrRF8a3mhGkbrxTYc1qRVP6aFnoAYJP6ilDUxtqIUxqlY42p/l4J3jE
RKejShwb9ID2Iydf8/Wvo/VYv1L3xm9bCQQ7mxJUR+qQov1z6l0Lgpt7dcJW
rvwLF29n3bm0m8Dvg0KDRS8fjD+eR7b4EcQnbNPN+k2EyPjt6gknqD5jJHPa
VIS9Acn39RMJvp6exQ0x7sKcL4qxi7IIPJUdXsd8yUecisZbpbUEJqcYA6sq
BrF5dB97/yitZ2pGy1uFi6CwOq6iNu1XsL/8XfCQKvBokmyk+ilzvRpbq7Ge
8T6IbUSQr67GcrJ/hjQjiX7tFoIpdb5Xp1gAd9eNM5nH/tVLfkrPthK153tu
XzQmKJJO+6dppgOPuAO6xiEEcz0C+oMgwrDdT7JXaD1MbrexjGwHDO/q326M
J7DVK7PKtejHrJi84JxG6o/DrKvN91rAK5tambqD4EVWeKFJ5n/hbvDS69ov
tB62q8w/xdU45L1YesaEgP8mQcPMqgfrn34sXEv7+WNo3leGNheWtga7vulQ
PaIctjl/TcGVvN7cEjrfnmSFFG8gCzsZt+czKS/mLh4d9/N9jHALdvNO6tfs
x8UVN9OfQTbCfCGbxl8YX1p/S74VMgyZV+nbCGbb7p3oLBdg/5NkkyofAla3
d3FAZAcM4jlLeCl0Hi/ZXt7WcgYjSm+HTGk8rpNYLUS7Hf1bDTmabgRyf1vU
efb1YHlRQuKiSlpfza6Lp8auwWzhO6eN1C+Lkg+6SV51gW8167HNScpDVsN3
ZdvnaMpfVqR0iPa79QvnDmlHazBTpZRB9UgsMlL5XgzLuH7Tbpr/8cLkgOns
BogPVsmF0/y9TmX/U1MzAPG95rbcPykf3Aq8PnFqMTc0IqiK9vvpreBfuGFC
BLoE3q+OovleP7omKaYIhtqzDeWpP07XVweMLOLhuE1Jox/9frZjYfnFeBFG
z6R1652n3+9+sFs07z7etEfFS7ToPAzbsFh+PWj3GN+/tITOa6Sc5O3aLjAX
MLu2RxAomWsvT7ksxKvq3ecmfGl9Rb4fhs52Il4vV9+G8nXt7eMzv53qBblr
VHOnjvproDFHolOJo+wpzgk6fytYght+s7thst+dPfSAQEZ5SO7t2UHc4mmO
Maj/eYcbBmtvnIfno2TPQKo/b9+VzKTATOyQHp32of7xPKOuZxYthN2dq6zP
lLfslvEMfh4PvslGRl8pb9iDGgLNNXzM+jt3QTHlm33o1R/3puvBnhD6P3Eg
OKrUqBQa0oyqyVNKv++h+u8xzvgu14xun4m+E/T9eJNKdLC1EIdeST2Iv0ww
kufh3Z3GgdSqrZmXNCnvuqzSRnTdUPuibZUszW/Ot2cmOYsfo1xgb/OJ8jW4
7KP8u8E61G94vXCU8mTE3vtPSW0Dqif2DVfbE/TvFGevWtsBk3zDd9PUTxpO
ivPrXtSBsXwD+zDovOaJHZ6U1IOzWcycT3mnmBR7sK4wHxkhkgx12k+eZ5br
opRzCE6JvOVC4++R07rwn5pOFHfczxfTfhjaOx/1G+9C0JaIGONQuj80tqsu
G28DU4HPPUv9xFyZO7hH9BBpG/OsWw1pvUu/WhRM5uOanYny33Se8kP17DTb
G/A6/OS7AcqL4TUXf3cbrgFHsKltMeVr4YbojvaQDoSva4zQpX5Qk6StmzNc
gXtijqDZlPJys0ZUQBQPTkVrrn+i/bY/Z5UYri6AtWus24/9lJdWtrMre0Uo
DdDTWkL3l8mbz9kRrvXIzlv94Qndl76fdr9USG+CavHjeEu6v3jLDm96KTUA
y6pcNPZQXkz9vCCL24JuF/8wbcrb5Bx1nWd5fGTsXQl5ev9lzg5zraFKpHou
P/0T1Z/7a80UT7kcowr9hvNofmbXOhN2DJfh6aW4YmW67zy1NjobyD7EpEqJ
/FL6f+WRTl7srvV8dDsy2S+O0v1X3qcyECfAgwIFT0s6X3WnDSqdS5pgZ6GV
9dGG3r/JvHfDJREeFV1vqMwhKPYPa31fLcKDeYHzZLPpefZ3YXJZF4xNXfp0
CigvvEIdzJqSECfmm7+h/ZNRWsKscuqD6tOwsXeUJ1lH9c5rOD6EY5P78FbK
7/8DJHy4ZQ==
                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8ld8ft/JVUZIoK0nZQpFS3pIUKQ0ZJbQloWVlFJJESRFFVEKRrZAy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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXs41NsariEkHUWFilxiV4SoRLVfodJzkFs2oqRiKGJ3VZwh9s7t2TWU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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHk01IsDxccvhCQV78n2SnilsVVahDtKZVBJ6JW19RSZFKkYvUhe+dnC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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 194->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVWk4lVsYlXTT7OJeKuGa0mCIMkUrGpCpkMyVMpWiiSiZKdwyEwkliZIy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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VWsbxsmQkFDklBxKpVJJZnJrlohwpEIRIXEqZEqEJGToREKSJmkb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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVXk4lAsXn6TuID63m6XF0PLdNOSWZIt+lqTHTYnStSWllbJUN0qyFN+t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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGs4lAkbx6dIr41EaUsO6wq79OqwpVVb/nIIraXoYJVDlBRRSemgiERF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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 195->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVnk4lekbPqPG2tRpRibCGJXkWMeSRHeWGJJETCKJyTJC2qaUrEn4TbRg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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVmHc8lf0fxpXKSEZDkkpG8bSoqISLjEhGSCplJEpIkQgPIkkaRmWFR1LK
yB5Rh+y9N0nGfR9EKgnx+/7+Oq/7dZ/znZ/Pdb2vs9Xiqv7FpSwsLOeXsLD8
/3MZrvFfFfkPDZGPZnQEaQxf8dZ3CGxH3cEzjLuraFQEvb+uTlciX07D7FYD
BaXuP/7l0Smwm3mvoC5Jo2vP2sunf7wDv2xm3k5dGupN05/HwxtwWKlcmf0c
Ez/fPc3N/lOCCPq4mpknDeHMoAnthTfoX2+tnqVC417fZlWJiRqsDfISP1NB
gcfi1I6Aw81wXryiMr6FxjuLWDEfozw8m2DoPhmhoFxOn1Cda8K/o60qQv+O
QEg5eSgxuhhVnyMOKYXR8H/su3q1ewOsQguMkt1G0GAsXXfX+x322j0PqDan
kZ/46NelxWKovvRVPbxAIUC//2jp71IMdzrL/GtJkXmzYsUlm2D/4PKnPzuY
0CoVUfTKbsTYnEGtqjOFUHcvh1r7dri07x6rlKHQ4HdFINAuG2vuPDOdOUZD
yI7DXdqhE9+mV/LbfaLBklwmteZxDOSYUopW/DSuz6ubNn7sxM6AifLXWmMw
09cJHlFphqZoZ9HOF+R8LT799D3mgwOFS7RvCtMwYcbMMIR6YLTJtm9TNBNv
muVNhEprYSKRzR0QPAI37RMrVw71ILdD6vb0PA0vg7YavlWvEGitPanBSp4D
vuf4uORAZuBYxrcPFGbY9idUhnThWzTfvXX+FI7fm9jKk1+LS7xaP4NSaZhN
BlxiyStCge41sbJpGqFJBZbJ5Q1orzgVZWHIRENqSxz741h0ZbEwCsn9SGfO
GzjvqcV+0/lfoT9G4GQ7cNCMoxFKbRIRSzjIfioTCp1zbyPXNCt0A/n+IM/f
z1LSnzCwqPXSYj9ZX6aawQ2JNOQ89xTKY6Gx+/2rgLU+TRg+FSnknUYhO8Cs
ehVLCXr+mjmk29OYGddQSHjYiy0Ppy3DRSlou/Bf2uTVC40zCiWephTYs4V+
WDz4BHk3K1bejzTKfLzL6srLsSXt12GdDgrJTz12ayp0YOelf8KqS4Yxxsk8
cUOxCQPjGVyK6RRWHN/AVJZtxXzrymBHFiZkK3kLGzXTIfFchhmvT6OhdtMk
PifDxpVv+U6yHxabGe9+NRfY2Jx3u7iVhv4Lg+h9nMUYDJXoS7hK4evS5a51
ra3wonnjs1/TYMi9ZfO7lozPXs4bog+Q83bmDHFMbQfVxbulYTUTO4PGBfyk
c/CE0dKm6UjeM+qO3Xj0HDf5WO09ST/qTU5d+ctVhIiSi694TGmkJe0wd7nQ
iYx1b1ee56FhfKk530KjAbufBV6/fpaJgrwkT+kjpchrZBWS2UAj9kzVTUu9
EgQOSn+pPEPBbM/83Kp9L+HUsEV8kJcGe7S3w2xSBVYFaFhaCVHoqLV6Zq3c
A0PLxdy5Jgrl+o/kqn53YP0lmWkuUg8uze0HbR7VIOqRjdzxQRoJR1gVew/W
Qsh0dO6bBIXXKb/nc1vyMGE//xek/gYv5vj+devC05j+dQ52w3BhVrzq5S+E
+8RZriFyX1T3cy3z4/dgYi2WmbSdhmXOufPyaUWokGY4d8tSSPKReVSwvRor
N2T0hJnQOH+BV5D1VzEy/S7ts4+msH/sapF5eyP858/qWYozwebw42Alewdc
VOwVSuXJfYXIvmbkRqLHJz3DfzMNJ+kNX6x4s8D9ac+2N+S9wKOKx14jYQj+
sVZdTYLG8V+K+h7CfXhcKOJvLToGId+5908mMqArr64eLkv0Zues7o3xMjzc
4CMcRuqj5mRVU69XC1pUyhs6LjDB4n3wh/j4M7jvPe3sI0bqIzHD8a5xFtxX
KportFO4rf1V2d+6GaxnpB7+Naax7MH+/pds5WANu5p1Y5SC1+UtefmNd+Ab
dOHnB6IHkylFC5mJDWgQMdPaspOCX/e5ZuuGKnwZKZi78HkEzNHD7NPL2rGC
z0ZL/i8F47upO0Yq0rE6XERHi0FBgJf7GPt0L24e6l7xU3YQ/cOlA2ItzYj4
mqpato1ChdFOr9rAdOjMuOXw7qThvqC2EH+0Ej9buWmjIgpU0E69iNt14OQT
m26Yp+BQJbhL7GUzmoI2H+g9TCNwe0v3e0YVqvT4E/Y4MnHjQ+/hfONGBE0Z
x7KrU5hdTKv+1NeA2dtjncHxTAh7lb7s2haGWzu3Fi6S/VkFhMjvXdKNtYqG
271XDsPyeE4z56Z6VM8cfVZeTGPcOffR6hPtkK/O0tbpZiJq5+wPmfFSKLCK
mSttpNBqajV96WUj1PKc1YLfjSBeKGf5ra2leLG2s348mEIYY/yOo8c7fAju
TrPTpJG5uzU2arwOCbT0zXFOJpxt7agp7zpwtY30pQ5SWBPg+qT3aC+UvsXy
2MuOgKteO6i3txQmzZ81RLxoCF7ki0nd1YSQu30vBG9R6CnO13p6pQ7cahLp
ufdH0B9p+FauohPntOXM15/4CqHKvoW3G7twS02RjU98AOo1B1vMCovhFVYS
Jk762f2u8IO6uQZsN3Lz9eWjsPtk6rhyXBdcrtV/P15FI5L/WLDonR4sdV2S
qaQwCsM6LZeMkFqcWnVltetz0t/L01tjf2RBLMyIt/1fGoa72cUPmVZCVFHT
5G73CB5P7pPk29yMfOeQdSsejsJYi9HIkvkJ3tfKQ9TLSD3vZUsMlXwFlZaj
vTdEST/4OA41GXWgTtzwPwOfUUj8deJJU/iE/T8TqBO+RC/O/QqRyqrB9iuH
vQXaRjA5PvzBoLkFOnzCJ2bYmDg0HfTko34j3q3tq6y6SeFVsKaKXHYRglXe
P417QaOH61niGqN3sLw9IXKS6E9mwPU/R7g6wc7b1jgqRubTXbOfl5kN/67n
cT5XaEiJcAS8PPICWdqtK6SI3krMb+DbF56AZazKvQcO0VgZxppjVNgG/y0H
9e+tIH6DH5u7NDtxZqvnmaAKcr6Tp/X83GMwtXrFWAuZz/c8uyArVwumQ/5G
R6kxMRN09nqNWiGk824ecCN6wJvpdWn5BQaEYzwkBdbSkIx4vXH/u0q0ieWx
BuUSfzwks2/Auw2aX05LriS8sOfcxw9iuyogsZVu4jpOw0FszdULJ1vBtC/n
HWIw0f936/ZehVpoZ5y6fY/U30+B2a0P1zbA5fS6BMlS0n8ZqahDBh4q/O6j
OYje+8W5nd78FvackknvpAiP9V3XMqwpwilBG5ZVT2nEDB+uEa9rRPpwWUMn
8XvDUM/35qlNuBHOWlisSXjmaInwP5PNkCu4PDepTaHsF2qb6huxEKXsZkT4
pWt9YuHXnwzkmzZVnHQg9238u7qk7T2C/x4LUJylIGddc1c5tBkF9nbNHMsp
0LNnplpVqiD8wemVP+kXCc4HK5W8MnBQidklJkf4jtf1jUyeOTxy37PvF6Gx
M0fu3t4nxI9GBar2uRL9SuPSWjJcjOHvb1+wk/uL1T5Z8oYzGt812m7xr6GR
5KzwlUOeATE5vTMqJ2hEnOyXDFXKg8+piKy15Dw1uLwlHINLkP1mS47+NRqa
t8NarrjWIaxAkiXrNhN6E5eMH0f2IKzH6XWRDoWfDZYuQfrV2P+6Xr7QgwmH
jTdN3hW+gfyBWp5VG2nIhRwSrQ8vg+1t85z1ahQkhhI6hSb7oH05Ytvm40zE
avb5lG/OwOhod7YuqSeH8BVO3CtaIKFsUqr4YATG1fmFiumtSLlwXncD4YWk
IDnJRLd8dH0QaATRz1DnKXWj0E9YdyPRy2qI+FsXSipamyEhqH98YGgEYgeO
TClf64DvmJ9zqPoo0VOXIb67BbA/3p0p40thMs/n89qEVvjVC7a9GiZ+EsbK
iIg5CXnpFbaryPlW1Cdaz70sRsg70wx2ivDoVh6pzIRylHGwGUmcpbFPLkx6
Sq8WBf8YGXGaMxEdZiL877IOHOJ/tjFTZBShptlGDVVN0J9TOhkxOgL/c2ye
rq+aUCY7L3GF8FaTf26wwdJG+NHjFfsnyHjJe3ZNWTRh22mbsCgPGi5On13S
lIsxIMD3sZToZWitr5/g1xZQuucX1vweRtRwie4d+ybc7fhuEepJ/F/reYtq
STUox3nrkkUKVQIFXmFpn1Ai8L3FK4+C+8Ze9+nwLkyav9EYqKTAFv5nKUO+
CT/Z2tmVN43i9qr6yhffimEtfTL7L/Gbb+kpc04NNVjGUcqwCib177CY9ka9
F0yfyUkblmF4vI9TDN/diRcRnoKFM8PoaBxdF2uQAeVpSqezhQLvoJZR3VrC
l9W3vZ1CKSzzj6v5Q/j2SLKgcMA2GlzvhUNExGux62g/Y38vBVtevaniqzkI
tejhqT1P6nfioV+Vfh/4aq7kdwl8xaRI2PbqY8Wo+bSw4/4Rch+LB/dHJDcj
nfM/mVnCC4F1cf4Lhz7CPFigStWZxgoPTdONd9oRIxsmW580ggDD7r38S8uQ
4PvTtfoZDaVEt/M1Uf+hqV1jYCvRo2iR5shQc6IX5ozgNXYUBi79irw41YI+
lpZ7SoQfVddc2HSXJw0bo38sWUn8lP5c9AFsdZA3ieMQ7xxB7hODVRPSFdAP
ryixInrAsHT8pWqWjPx7l3NOk/Hlt6gaBRE/z5/L7Ze6PwzDl7NhwZ4NuMHH
sf02O+HBZQdTW1t6sOjBeU1VjwlRr+yA+KwmiK3m1gkaplGQ4Lhux7MqNLSt
ExWMo2B4riVB/nMt0vYu5altpdDHemDCtLUdKb5mR408R8Gz8WbVd4M2rB40
6i+RJ/lCXWhM+2ICOK0Ufipy03iY2OP+4nIJ0j9EMnLvEP1ffkxn32Azjuod
e815joLwVe9b6V/aoLQ+yGXpNJlvTLC8fV0Xjj4OmXdPIvwfu92JuvwaZ0St
RfiJPk1tWtDUNWvEg/NmY37+NGykGg3ytjfA6O6WOy63RjB3L9o3mqsHlL+O
Ly/hw3g3M5NowhvcN4c2vJ6h8NggWl03pAHW0ZOXGs/RqLuWvmliVynGnA6c
HCB5hnFCMLLfNAy6nz/quZP6GWSUPRDUr8LUt1cBu0g+lQkd4GK93ox48ygb
EeYwXpc0ct0n/DU9qP89kW8Uy2L8Pn4aLYOkv2TkKqK3vPf/4f6umwnnAwm2
wqS/TGaiNu5TLUbayhvOz8h8K1QX7ocbNkAs09DS9hTJt3eqfS+09kJZujyi
spnwmvl1D4HP6TBTa98loUD82l96rlcnBb2OL/yCDWk4HliVS2m04UkZV9kX
pxFEf2Q5UXShCeslJX8dXkah5YVUH+1E+NfVofNCwijis+Rq+hOb4OtwdljF
jej9/cl19SOlYLkjaHAjm+TfYo2cofkmmP1ovRXmMQKW2BOBh2eyMc86aXKT
5A+pHTd90x6m4Qq3q2SgKo3Ho4Le70tTYLd+jiOMjfjzrNnufIEusKfoFHdQ
o7DaLnDyY3I3Zu0GRYstR5AsY/Hcv6AI6Wd77leXUIizj33XWlSCkmcOW3Xi
KUxbPvleuY3wh0/Gytf+I/CqD+WLWJOOnqWOG4eIny0MzbjV5BagOFMqXvYB
jQ6NfLfW8hK4XlPW2kN45FfyN2Pn1GaoBUwNvdnOBNe+XXvPXm5Hx8YCjukA
Gme8FN6xenSj4NSm1DdEL41HfTbExGYhs94oNVCSRnHg57pCi15M7H5QlKM5
BmEzIdUltm8xrJc5zP///UeNv7mVkQA5Ht6A1UIk/25xvNWxKRZLXW6qhpI8
qKetdtkpsRRNX56xTP1LIXBL2vnoDe3YzPcyjlWUiUkLd4VX5Z2oypU4tCNg
FEpGAy6SVCKmuFPnxIj+l0nKyNznqoXgoUsKX04TvxLcwaJKzssW+//uIuNJ
tV8MOaOeD2Mz/1Idwhdce/Nn75ytRsM549R9JB8HMtLi4hNqkLJw958wonfG
K67M8UQ3YjaWQyyL6G/ES9drXiaEz8blHTkjh9ARuIbd3rwC+Xa/isXsyPqv
GYVb2/wH96ykP4/30Oi/ajXL3/8WD46VNi4SvU6aPF1WQfiqRc629cBT0k/X
1hubm6chvvRY9YIGydcPlB8f2BGH558ndmuTfB2dbPl4T3URNr+6f0RZj+Rh
NUHLh6JJYBc73VJEznNt9Yr53MASeFWmrIx6S4NtTEFlXVwFBBlmoWYdpN4v
+iwmiWcg8we15iP5vRFXhNj3rz3Q57YcrFw3hmwFT7cKrmYEHncV9vAehWBZ
3UwTbzOOB3aUCy+hId5jXC36vApunc7z/CT/Vtid9NgtW4NIbg2bXpJXTVKN
Jv5bU4azF8MTrqVS4GTKLoVPJ1Ss2X9IxQyD98Gh5S3chbB1O1WT4E5BQ9j1
gHhnLHzZ+St+76ZxKYG77fJAKF7XW/cOEh7KKN96m6HYij9OkuzBhBeO99mm
PtoQB6XlEZ/MBEl/8aoKx6t+gLGk7Jb5HSRvauX9bOTOwqGj32+mhBC/eORp
7zCciDnDlpQEFfLsrM57d7EAtn85PFzI/Qtvi2DPrSvCzqRt8YfsSV5ep+be
srQF6c3/vf3GMoqTbtYse9mIvvJwbj1A9LOkSsHVV7EKPlk3bnFOUVDyVpwS
lArHg70pz5TJeg1tjI8kW3RgTFhktxGDRrnnAt9yyT4YCvmmLJI8HHvKYf6f
8+mIZzqpvib6G3t53k4a1ci9mVnOQ3iKJcKsZ2maMfYO/aP5m4xHvbl+O/Jx
OT5Wb9oQR3hP7ETXh8PD7VgIE3h4f3QUvLYHpcydotAm6dkktYvwuc3mL53d
jfjm31ZhEEFhlfLintKpVkgcXf80TJBCwdnhExmeRRhbIpr6t5FCFF+cgs/1
MlioRRcObKLBf+t76TGhZnzYcVf5LOnnj+Km0+vONaG/+KJFkBXhLfaU9fJs
MeDc7/YlkvSLcbzAUq7DxdgoW/71NzuN3JjwjASWFlRyr//EZcREtgDH4dmc
dugEZIhOloyg22q1n9uFbog2K6uXPSQ8cGvWkbcyDxJKdizDUcS/h8spux11
UN1q73+H8KpGzze/c7oFiAlpGwr7//8TD/o32G9jIDB77nsS0YvQGEmXGbVa
5PYPVchF0jjFbD9YrtKBh5XL+G2J3rE02b3Uru/EdNlj0xtfKPwPy2HzWw==

                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlXs41AkXx+fNbCs2StlKE5Uit5KN4qm+uuwQTe6KkC3lslZhFJJGqVWv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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVk3s01AkfxjUKafJGKrUKFZGRaiWUntatV0mbaqhVVCS0uey+uZSysnJr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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 196->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk41PkfH5v91ZJdV02r7Doqi5wplHpJqc38cqyjQ86SXLFy5WjVUpat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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV3c8le0bJxKJJOK1UkYkUaRBvkLDyKhQaEpJJSFpmCUqSeXVeK1EUhnJ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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHk81ekex11LyZbKlqap7EmyVOM2mY9sV4XBSDL3otGiUoyQXGTKkntM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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHlYzIkDxlNU7NoOldSEtkyFJ4TED+8oKbJKutOpDWOQ6NhpEApLd7pT
OlylU7aD7FAx07FNNdNUhpqZ78x8kWNbEdnafn+8z/vv532e932Ng4+7/qqs
pKQUPaP/uw7VIjjncz+krqPuGY+lUDJ8coX+6SEsk/xP63AUGN3Mb3C+V42P
+vSquE0kwoim7N1ThfhLVVw/3EBCOOfVK/tZIkS3mBTpj0vRwJ66/GJ9EyIH
8lK2PVeAJ/1csUG3Fh6m7osZy0hYujL3Tar3wPvqbYa0SIY9cX7jyglCXBhu
FFpekECVM3e9NqMV/cNf2JdsFeA2jFN5tQOg2czRcimTILa5YrbCOALODh/C
Fmm/Bsf0J98oqhDY2347Zz+BWIHszcKP11G2bqWfXTcJc7vww3ZlAyir6Qg/
uY9AoO/kQRPdLDD9GoffSkgkM67adY7yEeT74ETmMQL6S3a1nxt5jhM7f5+n
9VAGvUVml0r62mHrr3zm4mY5HoVE9NbRSxAqFN0LuUMiE5eyiSohHi9xm0MI
xAg5onVry2kuRE3XVr4pl6Nlv2qkzWAHvuX8b5nNVwKM5QsK6zdVYzo2LY0d
SsKmO/try/c6DC27oV5mTSLwu0Zktt55pK+wp9XNeQ03miYrm9WKU7MMRMiT
Y8JR8o9gqg2O7xXn+9QVeKVZtevqNB/doXPb0y2l2Nn0gL7mugA/DWj705cT
sLkZX3ijrRbBq9bouhqSYDsx3ansIYz3fWF06Y5g5Cz9h3lGIjgdfO2RrSZB
SryNyUvTWtge8LjcuZ8ETZ/lYKCcD9cHwx5m7STaDW7WtQT1wevg0i20w1L0
nvpGzbsrgHGVhbQxhsB381yVgs29sAqa/ccFRxk6/TKsj4z342M5l1O9QALH
x6kqzDoBJiZ5Hr6rJLjnk7BRhSGAftYBw266BB1Xt3uvffsC45Ths1nPZvpo
3OXgoJWDx0Z3k6ZfknBMoyaEvqhHQ/pf9nvaFHDxbjhJM7mP9/bpsqXzSJiW
N/WEWnXBnGWSsNVcBq83c89pK5XhTIJ6zPNkEjv3sj1d9AZxQpjKHtOXQNPp
3c9dJ1Nx7U+aKv1vEq2zVtN5AQP4t8bm97keBCRR1TQDrX5YUuv17n8kwE8X
FaRS+PCaw22doBNIGD9szKoVoCzzmU9xPoHKVObnsdxeVGcFCpytZUg8b+Fy
zEeEsNNNNTXOUgTa5qVv5D2C3dGwu5DP8Lu3l2wey8NNn2iztD4Su6IXJK3L
qYRB/cNvZtEk3KxSBKPcQVhrdxjv1hNDfeMW7s3CZ8he4ak1f1oG1m1KxtZB
IXbBwjexeIZXNaDyUFcbFlc0LtRQU+DZuA7NwYIPxT+tfkEbpLjXI7S9c5GD
lQZZOlci5FDanfJRb5ETdlyplOcteY3vyWvaKrYNIvPsCg/37hEc2rc7P1Eh
RLxuupF9rhj31l6iHu3kYSoypOXybDlOJVZs9aqpQbeDZJnRKhKLh46vpIRx
cG2RBZP5swKfhts4SpMD2HVgv0OrjRi62wv2Lf6BD/ahzhV7OwhwlPtv5saL
wJRMHPnKGsZSK+qPEmYz6BEWOV0z+4+daAym1Ofh6dtOdcozEmrPj+fXNwsh
uqaHg1VSZHuHVBZ9qIOVGjfq0FsFGqLSpnx0G7BVs8GjS6hA4fdbkoztXAQa
FrSEimSYpeblGbdWgHauSkKjFYFbsTrlKUs7QIYfszubKsNAOTVm24leBG8Y
C4oKkGKk5OvR9Vc6QZqraKTWEKC5W7eUlvQh0Vtth/sTKbbrJzqMRTUicpLx
G6tAAZt1EYKemoeYV3KkI5angA6fVWs20QvnJI2s5j0yuOWeMDC81A3KfdLn
g64cppXbvE8VdMLTcr5lo5IMJb+46N7ZyIMX97p6EiHD+76hAMtf+BidLv3g
NvNPudSg0vzhIYTvKaYs0CAQreGnee4FH4LSLfyXbjIoLbzstDZzAMw3lXF/
F4nRxdVLOPjrEKYeWfsc2CJF7PrQ7aQ+G+/Y/5qXsBSIDuz2FAW0wnTU30E1
R46Mp3oFceX9oLE3ZCsKJNA3Gp23J/4Jduwslpv4KvCe+e5c/G8CdFZf6A3b
JAEninkm+pwIURcjqHXmIyiyO7ZKx42PYEMjiztBBJJYr8uL4ngIXuNpdzKZ
gGYfY5uI04atq1uGDtvLQfugZrh29AaGPBXh/DYSZfWddyLZHWhrdnb0b5Jj
cNrs+d6QAVAOj3Vks8Uo9dgdMT+tB7NvvwoIGpnJc2u5OLmiF92Ul8nuy6XI
bdU5sNSahz/3yULs5TK40rS9HhoMgsqtVF9fLMWpNwvbbG/0ILfQsKthWAaX
/NEv+xkpaPVwT29+R2IZ54tYxUwIw9X02Y3fxPiDp0IPf8SHZWZVznl/GdJ+
cpk8IhXitpPY6/G0BMkbj8d4be7B02vLrxsGECiLsS7N4PKw7r1fKqNUhrfF
T5fEUITov/XJJFWNgI7dfOGTyV4oFxA/znWQ4T/4J77q
                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 197->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lVkclrFExjSJhDTFpJSdEHo1IdmKypLk0qIkMmQbXFokQzRFZUkL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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4Ve8XxVVUMiRkrihJKiopvskSQkoRSUrGDIUoSTI3F4WQypyEVOah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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41Pkex4XCpK2sMsNozziUts21VJJ3Bxkxidhy22q7CNVyqGiL2iXJ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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlGs41AkDxal2Y7tZFVZqXaNV0s7mUnFEZUVui9XsRJRcKtRSIa1KGhnS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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 198->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXs41OkXV+0iuy3ttqI8iphS2HaakPCpMYQoqYguupDrRm4bjcqlGiq3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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k4VO8bxpWivZSl1RZRSZQiS7cWkVSKtNgirWSvVIokEr6k7FosqSRL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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVVHk41WkbNpHSZ85kyRQmpWiyR30V1U05lmqUnepMxoe+JMtJDa6IOhOy
lKVpsWZJVJPIWk4GyXCKc5xjSyV0zG85Ummxzvf7/niv93qu633u677f537u
1b4hLv4L5OTkIpjz/9ujm31s65QIuoJX3jaraIyaRGuteyBGWM51zu9/U6hW
/hjzubUHd3aGFV0foTDheKwwyushnkXf1LtoS6Jx8X4znZgHGJFn5QgJAgb9
yzQI12JsjEwTyscT8LmelK2wshCP2IYwiGNqZa1XthcF6PizQM7Yk8LQ+KB+
VGcF6l9f8CkeIpDexFGc2SvGAWGFhVo8hVVR3YmWKW2Izeqo39dOYl20p8x8
QITxVpst7UkU8mdalnCY97vnUzdIuyjInXlpzP3uAQxu7gkLmySwgG+kUVwm
wKBCSXT7SgrneeY+t+d70eMSN+sZRSNmVcQv2WM1cHdZb6G7kET10xvHK1UH
UBZxlmUaSGOvu6ZPX/ZDuL+YNxlaQ0IuXf7DYHI26JLLh5/7E2j81oG2dJXA
oNFIuYdNo6T1l6mlbAk87067abUzfPoNzb3UahG/sY/zfiWJW7Y3/Y9G/wXL
fkeL2T4Sjz43aR6Qe4n8Bme1d4YyDJ0L3Zn65z0EVtZK86sZfC6/2UF2C+Mn
Zjf2XiOQLdeWvMdRgBP9iqzaHRQiVryIDrKoxyEXI3mWOomUpVE6j30laNkw
HD/hQmOBa5Vq4LgQFd6/Bh+tphDwwLvqq4cQp/I0RQd9KPjmP3l2Lq8XNZkX
bZbY0gjtfsf6rfs5RoWLippyKVza11nML6hHIWERFGlB4tX+q7+bcnqRbHP2
a14kjT9MDZSK7cVQ0RTIp6ynYeYSFhPjWwVz9ridXx/Df+ulocovWTh/ecZO
KYRAbUGyzaHjfAx2Wu06yWX+c12WegqVi6B3Q9YpYQS4j6iTArty8PKPxYh7
CNjPJLjZeZWh790Pta0lBGJ9ZZo6DnUQT3nLV6iSSFaZm94WVY26435lG6YJ
7D9jd6NlOga2R44oeW4iIOjQ5m91G4Byluu6PW00HJ1MghrqSqC+1YFz4wKB
zDfmsoUjA+A5cSQL7tJIz9rpxs0SYan/7qDsRTSqLRYt/rBQCHNF1oajaRSs
4c8R+aVgy2Ss66g9o2cN/8rtEgn+mJLkcrNoSO2UnEs5Pdho0qRaFkJDzkb/
c9L+p3Bp90gNLiHB0xa2eMgLUfer4+c1MRS2V84Xpa4fhDTZTMZh+r/s2vRp
32w/7tvzItqsacQ+1d+rodwMZccGSG+QmHyb+LOZWwe0RfeqlLkUPix8N195
pwc7qW2LBXI0wuPjWPFNLThp5NK5S0BiVPD2buHXpzj9n9LlekMkVjqrWbl7
9SL40J09FLPP1p/uNYh0u5AdWXThTguFWw0HvVPr60BX85oMtEjUVLZEcxh9
6x5yqwNW0Kgoq/yrlcmH09Rhac5qJi+iO3YY2A+gQOfESN0Mjcyq7Yky735w
7cZYCeY0Vk0sNjlDtqHUKOPZyDeMXyM/eBc5dyJgfOwf4XUKsZxrltur0hBR
YFN/3olAeUeiYDIjBz+kf+wwCiQQud01b0nYKzhF5NBqsTTM5cVu7wP6oKN6
6CCrk8YtX8ux7OCbYFtz+ljJTL4c3p0TJOTjyUrh603ujP5r9ep6rEbkv+k4
Vr+Z8UvIqd2bLJugG8m3Ms4k8ePHaOOD3dXYwVNRukIx/mELTm1nl8Pi7L+t
wtsZvJNSbY+t9Xi0eTDAyozE6br5KI0jImw5nNTjz6dQdOb7HPcnjD+0hnX8
r1LgujePbokUYtQ2Q2STR0HJWeVBR4YE+ZsDQj8l0DjoYl2lerQbJ7ou/Wwy
QcGBbzni90WM+gDFQU0RhYRlOWZv7brxXjFzWo3B/9H47b/oFw34GlEnvc0m
oZBbyp+wFeJAXADXpZaCbmbGR/KxBPrWgdJvCQrhby15si9dMLGytvtmkILH
nGdcyN8SLFPa5/miiAYvetlVvn4zNB4P692+RuJ45Oi2kboBLDlv6JzqyczP
RKqg19qF0J9WSAYDKfh43TI2fV4KaZJZ03ApgfAFxyo0CvMgMgr3M2X2OfSS
m/Hz30RoiBP+k8jwyfbkzFxNEGGyokD6kqn/O9cgLVapwOfe9hqZhMD0d4GT
XkNiTIfk8m0Yv70Yk9nJbreBZzq8L0mBgpcsgZ2pLUaiuD9o8xyFtQeWRWWG
SiDJ9slaK6YwpzxmZl3Ygqk9wSre90gIOLMhpPl9pBuevZFZQ0C/X2n89NgA
ci9+DT7M5NNyRYfMl2N9iLDu4lEfaASlHe1sWd0Lh+KWK8ExNMoF5VssukvB
vtumaHOfQP6rcNXlWc14rTzzPiSVxKWg4ZnctGYEnzNy4rSRmOj31dByfww/
f+03NbtJlL9xXVspFSKj2V7hzUMKZvm9uxpZaWg8mW6QsJfAoWr5hbPlbVBT
XnSneYKEemSvypxWL8j4sMsrdGn8D/AP1b0=
                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlWs4lAkDhoXYSDm0RBFKJCSlg1qPFI1PFGlTapuUYumilnYomrXr9JWI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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 199->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk4lWkfVkKJNBmm+aw1yFRkLDOWU7ehQsmEhDRE1rEvDaMUQkxCJVuR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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVl3k41H0XxlFkK0UKKaKQkn1LuqVFVLakoiSyRnkUIXt6kjYKrcpSIorK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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs4lIsWxudUtEcpRXKIkJLb7NLOMdp5VaKUOErtdEOThEmEFCW6kOSS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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVVWs41IkXnkSki5aVSemRrEQ0lVtsvWTb5I+wpNIFrSJyabVbE7mLjVpS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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}], 200->
                GraphicsBox[{
                  {RGBColor[1, 0, 0], PointBox[CompressedData["
1:eJwVVXk8ldkbv6V0EzJaKC1iosWWRIiv0NA1GTVDkm4ImRZDachSSNaSXSXT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                    "]]}, 
                  {RGBColor[0, 0, 1], PointBox[CompressedData["
1:eJwVV2cglW8bV9kNDSRJ1l8ShayUfsmICiWzMlJJG9FOUgqpiCRbKYXsnZW9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                    "]]}, 
                  {RGBColor[0, 1, 0], PointBox[CompressedData["
1:eJwVlHs41HkbxmXT9iqiYqfUrA46TkfTkbolCmGJa8MWEtKGZOS1JVQUm8No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                    "]]}, 
                  {RGBColor[0.6, 0.4, 0.2], PointBox[CompressedData["
1:eJwVlHs4lIsaxSe37CSjSFRCUbuNOoWkWKkUDts13ZAkKffpYlySSkpoU6KS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                    "]]}},
                 AspectRatio->1,
                 Axes->True,
                 AxesLabel->{
                   FormBox["\"mesh\"", TraditionalForm], 
                   FormBox["\"value\"", TraditionalForm]},
                 AxesOrigin->{0, 0.5},
                 PlotRange->{{0, 0.5}, {0.4, 0.9}}]}, 
                Dynamic[$CellContext`i4$$],
                Alignment->Automatic,
                ImageSize->All],
               Identity,
               Editable->True,
               Selectable->True],
              ImageMargins->10],
             Deployed->False,
             StripOnInput->False,
             ScriptLevel->0,
             GraphicsBoxOptions->{PreserveImageOptions->True},
             Graphics3DBoxOptions->{PreserveImageOptions->True}],
            Identity,
            Editable->False,
            Selectable->False],
           Alignment->{Left, Center},
           Background->GrayLevel[1],
           Frame->1,
           FrameStyle->GrayLevel[0, 0.2],
           ItemSize->Automatic,
           StripOnInput->False]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Top}}, 
          "RowsIndexed" -> {}},
        GridBoxDividers->{
         "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
          "RowsIndexed" -> {}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.7], {
             Offset[0.5599999999999999]}, 
            Offset[0.7]}, "ColumnsIndexed" -> {}, "Rows" -> {
            Offset[0.4], {
             Offset[0.8]}, 
            Offset[0.4]}, "RowsIndexed" -> {}}], If[
        CurrentValue["SelectionOver"], 
        Manipulate`Dump`ReadControllerState[
         Map[Manipulate`Dump`updateOneVar[#, 
           CurrentValue["PreviousFormatTime"], 
           CurrentValue["CurrentFormatTime"]]& , {
           
           Manipulate`Dump`controllerLink[{$CellContext`i4$$, \
$CellContext`i4$1923$$}, "X1", 
            If["DefaultAbsolute", True, "JB1"], False, {1, 200, 1}, 200, 
            1.]}], 
         CurrentValue[{
          "ControllerData", {
           "Gamepad", "Joystick", "Multi-Axis Controller"}}], {}]],
       ImageSizeCache->{391., {195.75, 200.75}}],
      DefaultBaseStyle->{},
      FrameMargins->{{5, 5}, {5, 5}}],
     BaselinePosition->Automatic,
     ImageMargins->0],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "ListAnimate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.545756187932728*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{697, 787},
WindowMargins->{{Automatic, 384}, {Automatic, 52}},
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (October 6, 2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 253, 3, 83, "Title"],
Cell[835, 27, 2603, 69, 114, "Section"],
Cell[CellGroupData[{
Cell[3463, 100, 211, 3, 41, "Section"],
Cell[3677, 105, 692, 15, 65, "Text"],
Cell[4372, 122, 489, 11, 31, "Input"],
Cell[4864, 135, 3205, 78, 352, "Input"],
Cell[8072, 215, 2301, 61, 232, "Input"],
Cell[10376, 278, 1452, 38, 132, "Input"],
Cell[11831, 318, 3113, 77, 372, "Input"],
Cell[14947, 397, 549, 10, 112, "Input"],
Cell[15499, 409, 809, 20, 52, "Input"],
Cell[16311, 431, 871, 23, 72, "Input"],
Cell[17185, 456, 573, 12, 52, "Input"],
Cell[17761, 470, 2484, 58, 352, "Input"],
Cell[20248, 530, 595, 13, 52, "Input"],
Cell[20846, 545, 5649, 112, 792, "Input"],
Cell[26498, 659, 286, 8, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[26821, 672, 91, 1, 71, "Section"],
Cell[CellGroupData[{
Cell[26937, 677, 92, 1, 36, "Subsection"],
Cell[27032, 680, 834, 20, 92, "Input"],
Cell[27869, 702, 2661, 64, 172, "Input"],
Cell[30533, 768, 2588, 62, 172, "Input"],
Cell[33124, 832, 2273, 57, 172, "Input"],
Cell[35400, 891, 2325, 58, 172, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[37762, 954, 100, 1, 36, "Subsection"],
Cell[37865, 957, 1297, 32, 132, "Input",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[39187, 993, 1436, 32, 72, "Input"],
Cell[40626, 1027, 6727, 116, 354, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[47390, 1148, 1217, 30, 72, "Input"],
Cell[48610, 1180, 6742, 117, 225, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[55389, 1302, 2333, 60, 312, "Input"],
Cell[57725, 1364, 16124, 274, 354, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[73886, 1643, 2324, 59, 332, "Input"],
Cell[76213, 1704, 17336, 294, 354, "Output"]
}, Open  ]],
Cell[93564, 2001, 3076, 70, 312, "Input",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[96665, 2075, 3181666, 53978, 3566, InheritFromParent],
Cell[3278334, 56055, 3178405, 53977, 18887, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6456776, 110037, 3219, 72, 332, "Input",
 Evaluatable->False],
Cell[6459998, 110111, 3425447, 58201, 18887, "Output"]
}, Open  ]],
Cell[9885460, 168315, 196, 3, 31, "Input"],
Cell[CellGroupData[{
Cell[9885681, 168322, 141, 2, 31, "Input"],
Cell[9885825, 168326, 3471241, 58314, 432, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13357103, 226645, 1746, 45, 232, "Input"],
Cell[13358852, 226692, 12227, 245, 506, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13371116, 226942, 1718, 44, 232, "Input"],
Cell[13372837, 226988, 12039, 242, 506, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13384913, 227235, 3428703, 58202, 3566, InheritFromParent],
Cell[16813619, 285439, 3425447, 58201, 18887, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20239103, 343645, 188, 3, 31, "Input"],
Cell[20239294, 343650, 3471228, 58314, 432, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23710559, 401969, 141, 2, 31, "Input"],
Cell[23710703, 401973, 3224186, 54090, 432, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
